#include <tree_sitter/parser.h>

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 18538
#define LARGE_STATE_COUNT 2415
#define SYMBOL_COUNT 327
#define ALIAS_COUNT 4
#define TOKEN_COUNT 110
#define EXTERNAL_TOKEN_COUNT 15
#define FIELD_COUNT 32
#define MAX_ALIAS_SEQUENCE_LENGTH 8
#define PRODUCTION_ID_COUNT 184

enum {
  sym__alpha_identifier = 1,
  anon_sym_enum = 2,
  anon_sym_COLON = 3,
  anon_sym_LBRACE = 4,
  anon_sym_RBRACE = 5,
  anon_sym_case = 6,
  anon_sym_COMMA = 7,
  anon_sym_package = 8,
  anon_sym_DOT = 9,
  anon_sym_object = 10,
  anon_sym_import = 11,
  anon_sym_export = 12,
  anon_sym_STAR = 13,
  anon_sym__ = 14,
  anon_sym_given = 15,
  anon_sym_EQ_GT = 16,
  anon_sym_as = 17,
  anon_sym_class = 18,
  anon_sym_trait = 19,
  anon_sym_LBRACK = 20,
  anon_sym_RBRACK = 21,
  anon_sym_PLUS = 22,
  anon_sym_DASH = 23,
  anon_sym_LT_COLON = 24,
  anon_sym_GT_COLON = 25,
  anon_sym_LT_PERCENT = 26,
  anon_sym_end = 27,
  anon_sym_if = 28,
  anon_sym_while = 29,
  anon_sym_for = 30,
  anon_sym_match = 31,
  anon_sym_try = 32,
  anon_sym_new = 33,
  anon_sym_this = 34,
  anon_sym_extension = 35,
  anon_sym_val = 36,
  anon_sym_AT = 37,
  anon_sym_EQ = 38,
  anon_sym_var = 39,
  anon_sym_type = 40,
  anon_sym_def = 41,
  anon_sym_opaque = 42,
  anon_sym_with = 43,
  anon_sym_abstract = 44,
  anon_sym_final = 45,
  anon_sym_sealed = 46,
  anon_sym_implicit = 47,
  anon_sym_lazy = 48,
  anon_sym_override = 49,
  anon_sym_private = 50,
  anon_sym_protected = 51,
  anon_sym_inline = 52,
  anon_sym_infix = 53,
  anon_sym_open = 54,
  anon_sym_transparent = 55,
  anon_sym_extends = 56,
  anon_sym_derives = 57,
  anon_sym_LPAREN = 58,
  anon_sym_using = 59,
  anon_sym_RPAREN = 60,
  anon_sym_SEMI = 61,
  anon_sym_POUND = 62,
  anon_sym_QMARK_EQ_GT = 63,
  anon_sym_EQ_GT_GT = 64,
  anon_sym_PIPE = 65,
  anon_sym_else = 66,
  anon_sym_then = 67,
  anon_sym_catch = 68,
  anon_sym_finally = 69,
  anon_sym_macro = 70,
  anon_sym_BANG = 71,
  anon_sym_TILDE = 72,
  anon_sym_DOLLAR = 73,
  anon_sym_SQUOTE = 74,
  sym_symbol_literal = 75,
  sym__interpolation_identifier = 76,
  sym__backquoted_id = 77,
  sym_operator_identifier = 78,
  sym_integer_literal = 79,
  sym_floating_point_literal = 80,
  anon_sym_true = 81,
  anon_sym_false = 82,
  sym_character_literal = 83,
  anon_sym_DQUOTE = 84,
  sym__interpolated_multiline_string_start = 85,
  sym_null_literal = 86,
  anon_sym_return = 87,
  anon_sym_throw = 88,
  anon_sym_do = 89,
  anon_sym_yield = 90,
  anon_sym_LT_DASH = 91,
  aux_sym__shebang_token1 = 92,
  anon_sym_SLASH_SLASH = 93,
  sym__comment_text = 94,
  anon_sym_GT = 95,
  sym_using_directive_key = 96,
  sym_using_directive_value = 97,
  anon_sym_SLASH_STAR = 98,
  aux_sym_block_comment_token1 = 99,
  anon_sym_STAR_SLASH = 100,
  sym__automatic_semicolon = 101,
  sym__indent = 102,
  sym__interpolated_string_middle = 103,
  sym__interpolated_string_end = 104,
  sym__interpolated_multiline_string_middle = 105,
  sym__interpolated_multiline_string_end = 106,
  sym__outdent = 107,
  sym__simple_multiline_string = 108,
  sym__simple_string = 109,
  sym_compilation_unit = 110,
  sym__top_level_definition = 111,
  sym_enum_definition = 112,
  sym__enum_block = 113,
  sym_enum_body = 114,
  sym_enum_case_definitions = 115,
  sym_simple_enum_case = 116,
  sym_full_enum_case = 117,
  sym__full_enum_def = 118,
  sym_package_clause = 119,
  sym_package_identifier = 120,
  sym_package_object = 121,
  sym_import_declaration = 122,
  sym_export_declaration = 123,
  sym__namespace_expression = 124,
  sym_namespace_wildcard = 125,
  sym__namespace_given_by_type = 126,
  sym_namespace_selectors = 127,
  sym_arrow_renamed_identifier = 128,
  sym_as_renamed_identifier = 129,
  sym_object_definition = 130,
  sym__object_definition = 131,
  sym_class_definition = 132,
  sym__class_definition = 133,
  sym__definition_body = 134,
  sym__class_constructor = 135,
  sym_trait_definition = 136,
  sym_type_parameters = 137,
  sym__variant_type_parameter = 138,
  sym_covariant_type_parameter = 139,
  sym_contravariant_type_parameter = 140,
  sym__type_parameter = 141,
  sym_upper_bound = 142,
  sym_lower_bound = 143,
  sym_view_bound = 144,
  sym_context_bound = 145,
  sym_template_body = 146,
  sym__indented_template_body = 147,
  sym__braced_template_body = 148,
  sym__braced_template_body1 = 149,
  sym__braced_template_body2 = 150,
  sym_with_template_body = 151,
  sym__extension_template_body = 152,
  sym__end_marker = 153,
  sym_self_type = 154,
  sym__self_type_ascription = 155,
  sym_annotation = 156,
  sym_val_definition = 157,
  sym_val_declaration = 158,
  sym__start_val = 159,
  sym_var_declaration = 160,
  sym_var_definition = 161,
  sym__start_var = 162,
  sym_type_definition = 163,
  sym__type_constructor = 164,
  sym_function_definition = 165,
  sym_function_declaration = 166,
  sym__function_declaration = 167,
  sym__function_constructor = 168,
  sym_opaque_modifier = 169,
  sym_extension_definition = 170,
  sym_given_definition = 171,
  sym__given_constructor = 172,
  sym__structural_instance = 173,
  sym__constructor_application = 174,
  sym__constructor_applications = 175,
  sym_modifiers = 176,
  sym_access_modifier = 177,
  sym_access_qualifier = 178,
  sym_inline_modifier = 179,
  sym_infix_modifier = 180,
  sym_open_modifier = 181,
  sym_transparent_modifier = 182,
  sym_extends_clause = 183,
  sym_derives_clause = 184,
  sym_class_parameters = 185,
  sym_parameters = 186,
  sym__using_parameters_clause = 187,
  sym_class_parameter = 188,
  sym_parameter = 189,
  sym__block = 190,
  sym__indentable_expression = 191,
  sym_block = 192,
  sym_indented_block = 193,
  sym_indented_cases = 194,
  sym__indented_type_cases = 195,
  sym__type = 196,
  sym__annotated_type = 197,
  sym_annotated_type = 198,
  sym__simple_type = 199,
  sym_compound_type = 200,
  sym__structural_type = 201,
  sym__refinement = 202,
  sym__infix_type_choice = 203,
  sym_infix_type = 204,
  sym_tuple_type = 205,
  sym_singleton_type = 206,
  sym_stable_type_identifier = 207,
  sym_stable_identifier = 208,
  sym_generic_type = 209,
  sym_projected_type = 210,
  sym_match_type = 211,
  sym_type_case_clause = 212,
  sym_function_type = 213,
  sym__arrow_then_type = 214,
  sym_parameter_types = 215,
  sym_lazy_parameter_type = 216,
  sym_repeated_parameter_type = 217,
  sym__type_identifier = 218,
  sym_type_lambda = 219,
  sym_case_class_pattern = 220,
  sym_infix_pattern = 221,
  sym_capture_pattern = 222,
  sym_repeat_pattern = 223,
  sym_typed_pattern = 224,
  sym_given_pattern = 225,
  sym_alternative_pattern = 226,
  sym_tuple_pattern = 227,
  sym_expression = 228,
  sym__simple_expression = 229,
  sym_lambda_expression = 230,
  sym_if_expression = 231,
  sym__if_condition = 232,
  sym_match_expression = 233,
  sym_try_expression = 234,
  sym_catch_clause = 235,
  sym__expr_case_clause = 236,
  sym_finally_clause = 237,
  sym_binding = 238,
  sym_bindings = 239,
  sym_case_block = 240,
  sym_case_clause = 241,
  sym__case_pattern = 242,
  sym_guard = 243,
  sym_assignment_expression = 244,
  sym_generic_function = 245,
  sym_call_expression = 246,
  sym_colon_argument = 247,
  sym_field_expression = 248,
  sym_instance_expression = 249,
  sym_ascription_expression = 250,
  sym_infix_expression = 251,
  sym_postfix_expression = 252,
  sym__postfix_expression_choice = 253,
  sym_macro_body = 254,
  sym_prefix_expression = 255,
  sym_tuple_expression = 256,
  sym_parenthesized_expression = 257,
  sym_type_arguments = 258,
  sym_arguments = 259,
  sym__exprs_in_parens = 260,
  sym_splice_expression = 261,
  sym_quote_expression = 262,
  sym_identifier = 263,
  sym__soft_identifier = 264,
  sym_identifiers = 265,
  sym_wildcard = 266,
  sym__non_null_literal = 267,
  sym_literal_type = 268,
  sym_boolean_literal = 269,
  sym_interpolated_string_expression = 270,
  sym__interpolated_string_start = 271,
  sym__dollar_escape = 272,
  sym__aliased_interpolation_identifier = 273,
  sym_interpolation = 274,
  sym_interpolated_string = 275,
  sym_string = 276,
  sym_unit = 277,
  sym_return_expression = 278,
  sym_throw_expression = 279,
  sym_while_expression = 280,
  sym_do_while_expression = 281,
  sym_for_expression = 282,
  sym_enumerators = 283,
  sym_enumerator = 284,
  sym__shebang = 285,
  sym_comment = 286,
  sym_using_directive = 287,
  sym_block_comment = 288,
  aux_sym_compilation_unit_repeat1 = 289,
  aux_sym_enum_definition_repeat1 = 290,
  aux_sym__enum_block_repeat1 = 291,
  aux_sym_enum_case_definitions_repeat1 = 292,
  aux_sym__full_enum_def_repeat1 = 293,
  aux_sym_package_identifier_repeat1 = 294,
  aux_sym_import_declaration_repeat1 = 295,
  aux_sym_namespace_selectors_repeat1 = 296,
  aux_sym__class_constructor_repeat1 = 297,
  aux_sym_type_parameters_repeat1 = 298,
  aux_sym__type_parameter_repeat1 = 299,
  aux_sym__type_parameter_repeat2 = 300,
  aux_sym_annotation_repeat1 = 301,
  aux_sym_val_declaration_repeat1 = 302,
  aux_sym__function_constructor_repeat1 = 303,
  aux_sym_extension_definition_repeat1 = 304,
  aux_sym__constructor_applications_repeat1 = 305,
  aux_sym__constructor_applications_repeat2 = 306,
  aux_sym_modifiers_repeat1 = 307,
  aux_sym_derives_clause_repeat1 = 308,
  aux_sym_class_parameters_repeat1 = 309,
  aux_sym_parameters_repeat1 = 310,
  aux_sym__using_parameters_clause_repeat1 = 311,
  aux_sym__block_repeat1 = 312,
  aux_sym_indented_cases_repeat1 = 313,
  aux_sym__indented_type_cases_repeat1 = 314,
  aux_sym_compound_type_repeat1 = 315,
  aux_sym_tuple_type_repeat1 = 316,
  aux_sym_type_lambda_repeat1 = 317,
  aux_sym_case_class_pattern_repeat1 = 318,
  aux_sym_bindings_repeat1 = 319,
  aux_sym_tuple_expression_repeat1 = 320,
  aux_sym_identifiers_repeat1 = 321,
  aux_sym_interpolated_string_repeat1 = 322,
  aux_sym_interpolated_string_repeat2 = 323,
  aux_sym_enumerators_repeat1 = 324,
  aux_sym_enumerator_repeat1 = 325,
  aux_sym_block_comment_repeat1 = 326,
  anon_alias_sym__end_ident = 327,
  alias_sym_refinement = 328,
  alias_sym_structural_type = 329,
  alias_sym_type_identifier = 330,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym__alpha_identifier] = "_alpha_identifier",
  [anon_sym_enum] = "enum",
  [anon_sym_COLON] = ":",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_case] = "case",
  [anon_sym_COMMA] = ",",
  [anon_sym_package] = "package",
  [anon_sym_DOT] = ".",
  [anon_sym_object] = "object",
  [anon_sym_import] = "import",
  [anon_sym_export] = "export",
  [anon_sym_STAR] = "*",
  [anon_sym__] = "_",
  [anon_sym_given] = "given",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_as] = "as",
  [anon_sym_class] = "class",
  [anon_sym_trait] = "trait",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_LT_COLON] = "<:",
  [anon_sym_GT_COLON] = ">:",
  [anon_sym_LT_PERCENT] = "<%",
  [anon_sym_end] = "end",
  [anon_sym_if] = "if",
  [anon_sym_while] = "while",
  [anon_sym_for] = "for",
  [anon_sym_match] = "match",
  [anon_sym_try] = "try",
  [anon_sym_new] = "new",
  [anon_sym_this] = "this",
  [anon_sym_extension] = "extension",
  [anon_sym_val] = "val",
  [anon_sym_AT] = "@",
  [anon_sym_EQ] = "=",
  [anon_sym_var] = "var",
  [anon_sym_type] = "type",
  [anon_sym_def] = "def",
  [anon_sym_opaque] = "opaque",
  [anon_sym_with] = "with",
  [anon_sym_abstract] = "abstract",
  [anon_sym_final] = "final",
  [anon_sym_sealed] = "sealed",
  [anon_sym_implicit] = "implicit",
  [anon_sym_lazy] = "lazy",
  [anon_sym_override] = "override",
  [anon_sym_private] = "private",
  [anon_sym_protected] = "protected",
  [anon_sym_inline] = "inline",
  [anon_sym_infix] = "infix",
  [anon_sym_open] = "open",
  [anon_sym_transparent] = "transparent",
  [anon_sym_extends] = "extends",
  [anon_sym_derives] = "derives",
  [anon_sym_LPAREN] = "(",
  [anon_sym_using] = "using",
  [anon_sym_RPAREN] = ")",
  [anon_sym_SEMI] = ";",
  [anon_sym_POUND] = "#",
  [anon_sym_QMARK_EQ_GT] = "\?=>",
  [anon_sym_EQ_GT_GT] = "=>>",
  [anon_sym_PIPE] = "|",
  [anon_sym_else] = "else",
  [anon_sym_then] = "then",
  [anon_sym_catch] = "catch",
  [anon_sym_finally] = "finally",
  [anon_sym_macro] = "macro",
  [anon_sym_BANG] = "!",
  [anon_sym_TILDE] = "~",
  [anon_sym_DOLLAR] = "$",
  [anon_sym_SQUOTE] = "'",
  [sym_symbol_literal] = "symbol_literal",
  [sym__interpolation_identifier] = "identifier",
  [sym__backquoted_id] = "_backquoted_id",
  [sym_operator_identifier] = "operator_identifier",
  [sym_integer_literal] = "integer_literal",
  [sym_floating_point_literal] = "floating_point_literal",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [sym_character_literal] = "character_literal",
  [anon_sym_DQUOTE] = "\"",
  [sym__interpolated_multiline_string_start] = "_interpolated_multiline_string_start",
  [sym_null_literal] = "null_literal",
  [anon_sym_return] = "return",
  [anon_sym_throw] = "throw",
  [anon_sym_do] = "do",
  [anon_sym_yield] = "yield",
  [anon_sym_LT_DASH] = "<-",
  [aux_sym__shebang_token1] = "comment",
  [anon_sym_SLASH_SLASH] = "//",
  [sym__comment_text] = "_comment_text",
  [anon_sym_GT] = ">",
  [sym_using_directive_key] = "using_directive_key",
  [sym_using_directive_value] = "using_directive_value",
  [anon_sym_SLASH_STAR] = "/*",
  [aux_sym_block_comment_token1] = "block_comment_token1",
  [anon_sym_STAR_SLASH] = "*/",
  [sym__automatic_semicolon] = "_automatic_semicolon",
  [sym__indent] = "_indent",
  [sym__interpolated_string_middle] = "_interpolated_string_middle",
  [sym__interpolated_string_end] = "_interpolated_string_end",
  [sym__interpolated_multiline_string_middle] = "_interpolated_multiline_string_middle",
  [sym__interpolated_multiline_string_end] = "_interpolated_multiline_string_end",
  [sym__outdent] = "_outdent",
  [sym__simple_multiline_string] = "_simple_multiline_string",
  [sym__simple_string] = "_simple_string",
  [sym_compilation_unit] = "compilation_unit",
  [sym__top_level_definition] = "_top_level_definition",
  [sym_enum_definition] = "enum_definition",
  [sym__enum_block] = "_enum_block",
  [sym_enum_body] = "enum_body",
  [sym_enum_case_definitions] = "enum_case_definitions",
  [sym_simple_enum_case] = "simple_enum_case",
  [sym_full_enum_case] = "full_enum_case",
  [sym__full_enum_def] = "_full_enum_def",
  [sym_package_clause] = "package_clause",
  [sym_package_identifier] = "package_identifier",
  [sym_package_object] = "package_object",
  [sym_import_declaration] = "import_declaration",
  [sym_export_declaration] = "export_declaration",
  [sym__namespace_expression] = "_namespace_expression",
  [sym_namespace_wildcard] = "namespace_wildcard",
  [sym__namespace_given_by_type] = "_namespace_given_by_type",
  [sym_namespace_selectors] = "namespace_selectors",
  [sym_arrow_renamed_identifier] = "arrow_renamed_identifier",
  [sym_as_renamed_identifier] = "as_renamed_identifier",
  [sym_object_definition] = "object_definition",
  [sym__object_definition] = "_object_definition",
  [sym_class_definition] = "class_definition",
  [sym__class_definition] = "_class_definition",
  [sym__definition_body] = "_definition_body",
  [sym__class_constructor] = "_class_constructor",
  [sym_trait_definition] = "trait_definition",
  [sym_type_parameters] = "type_parameters",
  [sym__variant_type_parameter] = "_variant_type_parameter",
  [sym_covariant_type_parameter] = "covariant_type_parameter",
  [sym_contravariant_type_parameter] = "contravariant_type_parameter",
  [sym__type_parameter] = "_type_parameter",
  [sym_upper_bound] = "upper_bound",
  [sym_lower_bound] = "lower_bound",
  [sym_view_bound] = "view_bound",
  [sym_context_bound] = "context_bound",
  [sym_template_body] = "template_body",
  [sym__indented_template_body] = "_indented_template_body",
  [sym__braced_template_body] = "_braced_template_body",
  [sym__braced_template_body1] = "_braced_template_body1",
  [sym__braced_template_body2] = "_braced_template_body2",
  [sym_with_template_body] = "with_template_body",
  [sym__extension_template_body] = "_extension_template_body",
  [sym__end_marker] = "_end_marker",
  [sym_self_type] = "self_type",
  [sym__self_type_ascription] = "_self_type_ascription",
  [sym_annotation] = "annotation",
  [sym_val_definition] = "val_definition",
  [sym_val_declaration] = "val_declaration",
  [sym__start_val] = "_start_val",
  [sym_var_declaration] = "var_declaration",
  [sym_var_definition] = "var_definition",
  [sym__start_var] = "_start_var",
  [sym_type_definition] = "type_definition",
  [sym__type_constructor] = "_type_constructor",
  [sym_function_definition] = "function_definition",
  [sym_function_declaration] = "function_declaration",
  [sym__function_declaration] = "_function_declaration",
  [sym__function_constructor] = "_function_constructor",
  [sym_opaque_modifier] = "opaque_modifier",
  [sym_extension_definition] = "extension_definition",
  [sym_given_definition] = "given_definition",
  [sym__given_constructor] = "_given_constructor",
  [sym__structural_instance] = "_structural_instance",
  [sym__constructor_application] = "_constructor_application",
  [sym__constructor_applications] = "_constructor_applications",
  [sym_modifiers] = "modifiers",
  [sym_access_modifier] = "access_modifier",
  [sym_access_qualifier] = "access_qualifier",
  [sym_inline_modifier] = "inline_modifier",
  [sym_infix_modifier] = "infix_modifier",
  [sym_open_modifier] = "open_modifier",
  [sym_transparent_modifier] = "transparent_modifier",
  [sym_extends_clause] = "extends_clause",
  [sym_derives_clause] = "derives_clause",
  [sym_class_parameters] = "class_parameters",
  [sym_parameters] = "parameters",
  [sym__using_parameters_clause] = "_using_parameters_clause",
  [sym_class_parameter] = "class_parameter",
  [sym_parameter] = "parameter",
  [sym__block] = "_block",
  [sym__indentable_expression] = "_indentable_expression",
  [sym_block] = "block",
  [sym_indented_block] = "indented_block",
  [sym_indented_cases] = "indented_cases",
  [sym__indented_type_cases] = "_indented_type_cases",
  [sym__type] = "_type",
  [sym__annotated_type] = "_annotated_type",
  [sym_annotated_type] = "annotated_type",
  [sym__simple_type] = "_simple_type",
  [sym_compound_type] = "compound_type",
  [sym__structural_type] = "_structural_type",
  [sym__refinement] = "_refinement",
  [sym__infix_type_choice] = "_infix_type_choice",
  [sym_infix_type] = "infix_type",
  [sym_tuple_type] = "tuple_type",
  [sym_singleton_type] = "singleton_type",
  [sym_stable_type_identifier] = "stable_type_identifier",
  [sym_stable_identifier] = "stable_identifier",
  [sym_generic_type] = "generic_type",
  [sym_projected_type] = "projected_type",
  [sym_match_type] = "match_type",
  [sym_type_case_clause] = "type_case_clause",
  [sym_function_type] = "function_type",
  [sym__arrow_then_type] = "_arrow_then_type",
  [sym_parameter_types] = "parameter_types",
  [sym_lazy_parameter_type] = "lazy_parameter_type",
  [sym_repeated_parameter_type] = "repeated_parameter_type",
  [sym__type_identifier] = "_type_identifier",
  [sym_type_lambda] = "type_lambda",
  [sym_case_class_pattern] = "case_class_pattern",
  [sym_infix_pattern] = "infix_pattern",
  [sym_capture_pattern] = "capture_pattern",
  [sym_repeat_pattern] = "repeat_pattern",
  [sym_typed_pattern] = "typed_pattern",
  [sym_given_pattern] = "given_pattern",
  [sym_alternative_pattern] = "alternative_pattern",
  [sym_tuple_pattern] = "tuple_pattern",
  [sym_expression] = "expression",
  [sym__simple_expression] = "_simple_expression",
  [sym_lambda_expression] = "lambda_expression",
  [sym_if_expression] = "if_expression",
  [sym__if_condition] = "_if_condition",
  [sym_match_expression] = "match_expression",
  [sym_try_expression] = "try_expression",
  [sym_catch_clause] = "catch_clause",
  [sym__expr_case_clause] = "_expr_case_clause",
  [sym_finally_clause] = "finally_clause",
  [sym_binding] = "binding",
  [sym_bindings] = "bindings",
  [sym_case_block] = "case_block",
  [sym_case_clause] = "case_clause",
  [sym__case_pattern] = "_case_pattern",
  [sym_guard] = "guard",
  [sym_assignment_expression] = "assignment_expression",
  [sym_generic_function] = "generic_function",
  [sym_call_expression] = "call_expression",
  [sym_colon_argument] = "colon_argument",
  [sym_field_expression] = "field_expression",
  [sym_instance_expression] = "instance_expression",
  [sym_ascription_expression] = "ascription_expression",
  [sym_infix_expression] = "infix_expression",
  [sym_postfix_expression] = "postfix_expression",
  [sym__postfix_expression_choice] = "_postfix_expression_choice",
  [sym_macro_body] = "macro_body",
  [sym_prefix_expression] = "prefix_expression",
  [sym_tuple_expression] = "tuple_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_type_arguments] = "type_arguments",
  [sym_arguments] = "arguments",
  [sym__exprs_in_parens] = "_exprs_in_parens",
  [sym_splice_expression] = "splice_expression",
  [sym_quote_expression] = "quote_expression",
  [sym_identifier] = "identifier",
  [sym__soft_identifier] = "_soft_identifier",
  [sym_identifiers] = "identifiers",
  [sym_wildcard] = "wildcard",
  [sym__non_null_literal] = "_non_null_literal",
  [sym_literal_type] = "literal_type",
  [sym_boolean_literal] = "boolean_literal",
  [sym_interpolated_string_expression] = "interpolated_string_expression",
  [sym__interpolated_string_start] = "_interpolated_string_start",
  [sym__dollar_escape] = "_dollar_escape",
  [sym__aliased_interpolation_identifier] = "_aliased_interpolation_identifier",
  [sym_interpolation] = "interpolation",
  [sym_interpolated_string] = "interpolated_string",
  [sym_string] = "string",
  [sym_unit] = "unit",
  [sym_return_expression] = "return_expression",
  [sym_throw_expression] = "throw_expression",
  [sym_while_expression] = "while_expression",
  [sym_do_while_expression] = "do_while_expression",
  [sym_for_expression] = "for_expression",
  [sym_enumerators] = "enumerators",
  [sym_enumerator] = "enumerator",
  [sym__shebang] = "_shebang",
  [sym_comment] = "comment",
  [sym_using_directive] = "using_directive",
  [sym_block_comment] = "block_comment",
  [aux_sym_compilation_unit_repeat1] = "compilation_unit_repeat1",
  [aux_sym_enum_definition_repeat1] = "enum_definition_repeat1",
  [aux_sym__enum_block_repeat1] = "_enum_block_repeat1",
  [aux_sym_enum_case_definitions_repeat1] = "enum_case_definitions_repeat1",
  [aux_sym__full_enum_def_repeat1] = "_full_enum_def_repeat1",
  [aux_sym_package_identifier_repeat1] = "package_identifier_repeat1",
  [aux_sym_import_declaration_repeat1] = "import_declaration_repeat1",
  [aux_sym_namespace_selectors_repeat1] = "namespace_selectors_repeat1",
  [aux_sym__class_constructor_repeat1] = "_class_constructor_repeat1",
  [aux_sym_type_parameters_repeat1] = "type_parameters_repeat1",
  [aux_sym__type_parameter_repeat1] = "_type_parameter_repeat1",
  [aux_sym__type_parameter_repeat2] = "_type_parameter_repeat2",
  [aux_sym_annotation_repeat1] = "annotation_repeat1",
  [aux_sym_val_declaration_repeat1] = "val_declaration_repeat1",
  [aux_sym__function_constructor_repeat1] = "_function_constructor_repeat1",
  [aux_sym_extension_definition_repeat1] = "extension_definition_repeat1",
  [aux_sym__constructor_applications_repeat1] = "_constructor_applications_repeat1",
  [aux_sym__constructor_applications_repeat2] = "_constructor_applications_repeat2",
  [aux_sym_modifiers_repeat1] = "modifiers_repeat1",
  [aux_sym_derives_clause_repeat1] = "derives_clause_repeat1",
  [aux_sym_class_parameters_repeat1] = "class_parameters_repeat1",
  [aux_sym_parameters_repeat1] = "parameters_repeat1",
  [aux_sym__using_parameters_clause_repeat1] = "_using_parameters_clause_repeat1",
  [aux_sym__block_repeat1] = "_block_repeat1",
  [aux_sym_indented_cases_repeat1] = "indented_cases_repeat1",
  [aux_sym__indented_type_cases_repeat1] = "_indented_type_cases_repeat1",
  [aux_sym_compound_type_repeat1] = "compound_type_repeat1",
  [aux_sym_tuple_type_repeat1] = "tuple_type_repeat1",
  [aux_sym_type_lambda_repeat1] = "type_lambda_repeat1",
  [aux_sym_case_class_pattern_repeat1] = "case_class_pattern_repeat1",
  [aux_sym_bindings_repeat1] = "bindings_repeat1",
  [aux_sym_tuple_expression_repeat1] = "tuple_expression_repeat1",
  [aux_sym_identifiers_repeat1] = "identifiers_repeat1",
  [aux_sym_interpolated_string_repeat1] = "interpolated_string_repeat1",
  [aux_sym_interpolated_string_repeat2] = "interpolated_string_repeat2",
  [aux_sym_enumerators_repeat1] = "enumerators_repeat1",
  [aux_sym_enumerator_repeat1] = "enumerator_repeat1",
  [aux_sym_block_comment_repeat1] = "block_comment_repeat1",
  [anon_alias_sym__end_ident] = "_end_ident",
  [alias_sym_refinement] = "refinement",
  [alias_sym_structural_type] = "structural_type",
  [alias_sym_type_identifier] = "type_identifier",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym__alpha_identifier] = sym__alpha_identifier,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_package] = anon_sym_package,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_object] = anon_sym_object,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_export] = anon_sym_export,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym__] = anon_sym__,
  [anon_sym_given] = anon_sym_given,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_trait] = anon_sym_trait,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_LT_COLON] = anon_sym_LT_COLON,
  [anon_sym_GT_COLON] = anon_sym_GT_COLON,
  [anon_sym_LT_PERCENT] = anon_sym_LT_PERCENT,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_match] = anon_sym_match,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_new] = anon_sym_new,
  [anon_sym_this] = anon_sym_this,
  [anon_sym_extension] = anon_sym_extension,
  [anon_sym_val] = anon_sym_val,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_var] = anon_sym_var,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_def] = anon_sym_def,
  [anon_sym_opaque] = anon_sym_opaque,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_abstract] = anon_sym_abstract,
  [anon_sym_final] = anon_sym_final,
  [anon_sym_sealed] = anon_sym_sealed,
  [anon_sym_implicit] = anon_sym_implicit,
  [anon_sym_lazy] = anon_sym_lazy,
  [anon_sym_override] = anon_sym_override,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_protected] = anon_sym_protected,
  [anon_sym_inline] = anon_sym_inline,
  [anon_sym_infix] = anon_sym_infix,
  [anon_sym_open] = anon_sym_open,
  [anon_sym_transparent] = anon_sym_transparent,
  [anon_sym_extends] = anon_sym_extends,
  [anon_sym_derives] = anon_sym_derives,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_using] = anon_sym_using,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_POUND] = anon_sym_POUND,
  [anon_sym_QMARK_EQ_GT] = anon_sym_QMARK_EQ_GT,
  [anon_sym_EQ_GT_GT] = anon_sym_EQ_GT_GT,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_then] = anon_sym_then,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_finally] = anon_sym_finally,
  [anon_sym_macro] = anon_sym_macro,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [sym_symbol_literal] = sym_symbol_literal,
  [sym__interpolation_identifier] = sym_identifier,
  [sym__backquoted_id] = sym__backquoted_id,
  [sym_operator_identifier] = sym_operator_identifier,
  [sym_integer_literal] = sym_integer_literal,
  [sym_floating_point_literal] = sym_floating_point_literal,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [sym_character_literal] = sym_character_literal,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [sym__interpolated_multiline_string_start] = sym__interpolated_multiline_string_start,
  [sym_null_literal] = sym_null_literal,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_throw] = anon_sym_throw,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_yield] = anon_sym_yield,
  [anon_sym_LT_DASH] = anon_sym_LT_DASH,
  [aux_sym__shebang_token1] = sym_comment,
  [anon_sym_SLASH_SLASH] = anon_sym_SLASH_SLASH,
  [sym__comment_text] = sym__comment_text,
  [anon_sym_GT] = anon_sym_GT,
  [sym_using_directive_key] = sym_using_directive_key,
  [sym_using_directive_value] = sym_using_directive_value,
  [anon_sym_SLASH_STAR] = anon_sym_SLASH_STAR,
  [aux_sym_block_comment_token1] = aux_sym_block_comment_token1,
  [anon_sym_STAR_SLASH] = anon_sym_STAR_SLASH,
  [sym__automatic_semicolon] = sym__automatic_semicolon,
  [sym__indent] = sym__indent,
  [sym__interpolated_string_middle] = sym__interpolated_string_middle,
  [sym__interpolated_string_end] = sym__interpolated_string_end,
  [sym__interpolated_multiline_string_middle] = sym__interpolated_multiline_string_middle,
  [sym__interpolated_multiline_string_end] = sym__interpolated_multiline_string_end,
  [sym__outdent] = sym__outdent,
  [sym__simple_multiline_string] = sym__simple_multiline_string,
  [sym__simple_string] = sym__simple_string,
  [sym_compilation_unit] = sym_compilation_unit,
  [sym__top_level_definition] = sym__top_level_definition,
  [sym_enum_definition] = sym_enum_definition,
  [sym__enum_block] = sym__enum_block,
  [sym_enum_body] = sym_enum_body,
  [sym_enum_case_definitions] = sym_enum_case_definitions,
  [sym_simple_enum_case] = sym_simple_enum_case,
  [sym_full_enum_case] = sym_full_enum_case,
  [sym__full_enum_def] = sym__full_enum_def,
  [sym_package_clause] = sym_package_clause,
  [sym_package_identifier] = sym_package_identifier,
  [sym_package_object] = sym_package_object,
  [sym_import_declaration] = sym_import_declaration,
  [sym_export_declaration] = sym_export_declaration,
  [sym__namespace_expression] = sym__namespace_expression,
  [sym_namespace_wildcard] = sym_namespace_wildcard,
  [sym__namespace_given_by_type] = sym__namespace_given_by_type,
  [sym_namespace_selectors] = sym_namespace_selectors,
  [sym_arrow_renamed_identifier] = sym_arrow_renamed_identifier,
  [sym_as_renamed_identifier] = sym_as_renamed_identifier,
  [sym_object_definition] = sym_object_definition,
  [sym__object_definition] = sym__object_definition,
  [sym_class_definition] = sym_class_definition,
  [sym__class_definition] = sym__class_definition,
  [sym__definition_body] = sym__definition_body,
  [sym__class_constructor] = sym__class_constructor,
  [sym_trait_definition] = sym_trait_definition,
  [sym_type_parameters] = sym_type_parameters,
  [sym__variant_type_parameter] = sym__variant_type_parameter,
  [sym_covariant_type_parameter] = sym_covariant_type_parameter,
  [sym_contravariant_type_parameter] = sym_contravariant_type_parameter,
  [sym__type_parameter] = sym__type_parameter,
  [sym_upper_bound] = sym_upper_bound,
  [sym_lower_bound] = sym_lower_bound,
  [sym_view_bound] = sym_view_bound,
  [sym_context_bound] = sym_context_bound,
  [sym_template_body] = sym_template_body,
  [sym__indented_template_body] = sym__indented_template_body,
  [sym__braced_template_body] = sym__braced_template_body,
  [sym__braced_template_body1] = sym__braced_template_body1,
  [sym__braced_template_body2] = sym__braced_template_body2,
  [sym_with_template_body] = sym_with_template_body,
  [sym__extension_template_body] = sym__extension_template_body,
  [sym__end_marker] = sym__end_marker,
  [sym_self_type] = sym_self_type,
  [sym__self_type_ascription] = sym__self_type_ascription,
  [sym_annotation] = sym_annotation,
  [sym_val_definition] = sym_val_definition,
  [sym_val_declaration] = sym_val_declaration,
  [sym__start_val] = sym__start_val,
  [sym_var_declaration] = sym_var_declaration,
  [sym_var_definition] = sym_var_definition,
  [sym__start_var] = sym__start_var,
  [sym_type_definition] = sym_type_definition,
  [sym__type_constructor] = sym__type_constructor,
  [sym_function_definition] = sym_function_definition,
  [sym_function_declaration] = sym_function_declaration,
  [sym__function_declaration] = sym__function_declaration,
  [sym__function_constructor] = sym__function_constructor,
  [sym_opaque_modifier] = sym_opaque_modifier,
  [sym_extension_definition] = sym_extension_definition,
  [sym_given_definition] = sym_given_definition,
  [sym__given_constructor] = sym__given_constructor,
  [sym__structural_instance] = sym__structural_instance,
  [sym__constructor_application] = sym__constructor_application,
  [sym__constructor_applications] = sym__constructor_applications,
  [sym_modifiers] = sym_modifiers,
  [sym_access_modifier] = sym_access_modifier,
  [sym_access_qualifier] = sym_access_qualifier,
  [sym_inline_modifier] = sym_inline_modifier,
  [sym_infix_modifier] = sym_infix_modifier,
  [sym_open_modifier] = sym_open_modifier,
  [sym_transparent_modifier] = sym_transparent_modifier,
  [sym_extends_clause] = sym_extends_clause,
  [sym_derives_clause] = sym_derives_clause,
  [sym_class_parameters] = sym_class_parameters,
  [sym_parameters] = sym_parameters,
  [sym__using_parameters_clause] = sym__using_parameters_clause,
  [sym_class_parameter] = sym_class_parameter,
  [sym_parameter] = sym_parameter,
  [sym__block] = sym__block,
  [sym__indentable_expression] = sym__indentable_expression,
  [sym_block] = sym_block,
  [sym_indented_block] = sym_indented_block,
  [sym_indented_cases] = sym_indented_cases,
  [sym__indented_type_cases] = sym__indented_type_cases,
  [sym__type] = sym__type,
  [sym__annotated_type] = sym__annotated_type,
  [sym_annotated_type] = sym_annotated_type,
  [sym__simple_type] = sym__simple_type,
  [sym_compound_type] = sym_compound_type,
  [sym__structural_type] = sym__structural_type,
  [sym__refinement] = sym__refinement,
  [sym__infix_type_choice] = sym__infix_type_choice,
  [sym_infix_type] = sym_infix_type,
  [sym_tuple_type] = sym_tuple_type,
  [sym_singleton_type] = sym_singleton_type,
  [sym_stable_type_identifier] = sym_stable_type_identifier,
  [sym_stable_identifier] = sym_stable_identifier,
  [sym_generic_type] = sym_generic_type,
  [sym_projected_type] = sym_projected_type,
  [sym_match_type] = sym_match_type,
  [sym_type_case_clause] = sym_type_case_clause,
  [sym_function_type] = sym_function_type,
  [sym__arrow_then_type] = sym__arrow_then_type,
  [sym_parameter_types] = sym_parameter_types,
  [sym_lazy_parameter_type] = sym_lazy_parameter_type,
  [sym_repeated_parameter_type] = sym_repeated_parameter_type,
  [sym__type_identifier] = sym__type_identifier,
  [sym_type_lambda] = sym_type_lambda,
  [sym_case_class_pattern] = sym_case_class_pattern,
  [sym_infix_pattern] = sym_infix_pattern,
  [sym_capture_pattern] = sym_capture_pattern,
  [sym_repeat_pattern] = sym_repeat_pattern,
  [sym_typed_pattern] = sym_typed_pattern,
  [sym_given_pattern] = sym_given_pattern,
  [sym_alternative_pattern] = sym_alternative_pattern,
  [sym_tuple_pattern] = sym_tuple_pattern,
  [sym_expression] = sym_expression,
  [sym__simple_expression] = sym__simple_expression,
  [sym_lambda_expression] = sym_lambda_expression,
  [sym_if_expression] = sym_if_expression,
  [sym__if_condition] = sym__if_condition,
  [sym_match_expression] = sym_match_expression,
  [sym_try_expression] = sym_try_expression,
  [sym_catch_clause] = sym_catch_clause,
  [sym__expr_case_clause] = sym__expr_case_clause,
  [sym_finally_clause] = sym_finally_clause,
  [sym_binding] = sym_binding,
  [sym_bindings] = sym_bindings,
  [sym_case_block] = sym_case_block,
  [sym_case_clause] = sym_case_clause,
  [sym__case_pattern] = sym__case_pattern,
  [sym_guard] = sym_guard,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_generic_function] = sym_generic_function,
  [sym_call_expression] = sym_call_expression,
  [sym_colon_argument] = sym_colon_argument,
  [sym_field_expression] = sym_field_expression,
  [sym_instance_expression] = sym_instance_expression,
  [sym_ascription_expression] = sym_ascription_expression,
  [sym_infix_expression] = sym_infix_expression,
  [sym_postfix_expression] = sym_postfix_expression,
  [sym__postfix_expression_choice] = sym__postfix_expression_choice,
  [sym_macro_body] = sym_macro_body,
  [sym_prefix_expression] = sym_prefix_expression,
  [sym_tuple_expression] = sym_tuple_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_type_arguments] = sym_type_arguments,
  [sym_arguments] = sym_arguments,
  [sym__exprs_in_parens] = sym__exprs_in_parens,
  [sym_splice_expression] = sym_splice_expression,
  [sym_quote_expression] = sym_quote_expression,
  [sym_identifier] = sym_identifier,
  [sym__soft_identifier] = sym__soft_identifier,
  [sym_identifiers] = sym_identifiers,
  [sym_wildcard] = sym_wildcard,
  [sym__non_null_literal] = sym__non_null_literal,
  [sym_literal_type] = sym_literal_type,
  [sym_boolean_literal] = sym_boolean_literal,
  [sym_interpolated_string_expression] = sym_interpolated_string_expression,
  [sym__interpolated_string_start] = sym__interpolated_string_start,
  [sym__dollar_escape] = sym__dollar_escape,
  [sym__aliased_interpolation_identifier] = sym__aliased_interpolation_identifier,
  [sym_interpolation] = sym_interpolation,
  [sym_interpolated_string] = sym_interpolated_string,
  [sym_string] = sym_string,
  [sym_unit] = sym_unit,
  [sym_return_expression] = sym_return_expression,
  [sym_throw_expression] = sym_throw_expression,
  [sym_while_expression] = sym_while_expression,
  [sym_do_while_expression] = sym_do_while_expression,
  [sym_for_expression] = sym_for_expression,
  [sym_enumerators] = sym_enumerators,
  [sym_enumerator] = sym_enumerator,
  [sym__shebang] = sym__shebang,
  [sym_comment] = sym_comment,
  [sym_using_directive] = sym_using_directive,
  [sym_block_comment] = sym_block_comment,
  [aux_sym_compilation_unit_repeat1] = aux_sym_compilation_unit_repeat1,
  [aux_sym_enum_definition_repeat1] = aux_sym_enum_definition_repeat1,
  [aux_sym__enum_block_repeat1] = aux_sym__enum_block_repeat1,
  [aux_sym_enum_case_definitions_repeat1] = aux_sym_enum_case_definitions_repeat1,
  [aux_sym__full_enum_def_repeat1] = aux_sym__full_enum_def_repeat1,
  [aux_sym_package_identifier_repeat1] = aux_sym_package_identifier_repeat1,
  [aux_sym_import_declaration_repeat1] = aux_sym_import_declaration_repeat1,
  [aux_sym_namespace_selectors_repeat1] = aux_sym_namespace_selectors_repeat1,
  [aux_sym__class_constructor_repeat1] = aux_sym__class_constructor_repeat1,
  [aux_sym_type_parameters_repeat1] = aux_sym_type_parameters_repeat1,
  [aux_sym__type_parameter_repeat1] = aux_sym__type_parameter_repeat1,
  [aux_sym__type_parameter_repeat2] = aux_sym__type_parameter_repeat2,
  [aux_sym_annotation_repeat1] = aux_sym_annotation_repeat1,
  [aux_sym_val_declaration_repeat1] = aux_sym_val_declaration_repeat1,
  [aux_sym__function_constructor_repeat1] = aux_sym__function_constructor_repeat1,
  [aux_sym_extension_definition_repeat1] = aux_sym_extension_definition_repeat1,
  [aux_sym__constructor_applications_repeat1] = aux_sym__constructor_applications_repeat1,
  [aux_sym__constructor_applications_repeat2] = aux_sym__constructor_applications_repeat2,
  [aux_sym_modifiers_repeat1] = aux_sym_modifiers_repeat1,
  [aux_sym_derives_clause_repeat1] = aux_sym_derives_clause_repeat1,
  [aux_sym_class_parameters_repeat1] = aux_sym_class_parameters_repeat1,
  [aux_sym_parameters_repeat1] = aux_sym_parameters_repeat1,
  [aux_sym__using_parameters_clause_repeat1] = aux_sym__using_parameters_clause_repeat1,
  [aux_sym__block_repeat1] = aux_sym__block_repeat1,
  [aux_sym_indented_cases_repeat1] = aux_sym_indented_cases_repeat1,
  [aux_sym__indented_type_cases_repeat1] = aux_sym__indented_type_cases_repeat1,
  [aux_sym_compound_type_repeat1] = aux_sym_compound_type_repeat1,
  [aux_sym_tuple_type_repeat1] = aux_sym_tuple_type_repeat1,
  [aux_sym_type_lambda_repeat1] = aux_sym_type_lambda_repeat1,
  [aux_sym_case_class_pattern_repeat1] = aux_sym_case_class_pattern_repeat1,
  [aux_sym_bindings_repeat1] = aux_sym_bindings_repeat1,
  [aux_sym_tuple_expression_repeat1] = aux_sym_tuple_expression_repeat1,
  [aux_sym_identifiers_repeat1] = aux_sym_identifiers_repeat1,
  [aux_sym_interpolated_string_repeat1] = aux_sym_interpolated_string_repeat1,
  [aux_sym_interpolated_string_repeat2] = aux_sym_interpolated_string_repeat2,
  [aux_sym_enumerators_repeat1] = aux_sym_enumerators_repeat1,
  [aux_sym_enumerator_repeat1] = aux_sym_enumerator_repeat1,
  [aux_sym_block_comment_repeat1] = aux_sym_block_comment_repeat1,
  [anon_alias_sym__end_ident] = anon_alias_sym__end_ident,
  [alias_sym_refinement] = alias_sym_refinement,
  [alias_sym_structural_type] = alias_sym_structural_type,
  [alias_sym_type_identifier] = alias_sym_type_identifier,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym__alpha_identifier] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_package] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_object] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_export] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_given] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_trait] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_match] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_this] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_val] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_var] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_def] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_opaque] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_abstract] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_final] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sealed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_implicit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lazy] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_override] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_protected] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_inline] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_infix] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_open] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_transparent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extends] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_derives] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_using] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_then] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_finally] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_macro] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym_symbol_literal] = {
    .visible = true,
    .named = true,
  },
  [sym__interpolation_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__backquoted_id] = {
    .visible = false,
    .named = true,
  },
  [sym_operator_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_integer_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_floating_point_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [sym_character_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym__interpolated_multiline_string_start] = {
    .visible = false,
    .named = true,
  },
  [sym_null_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_throw] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_yield] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__shebang_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SLASH_SLASH] = {
    .visible = true,
    .named = false,
  },
  [sym__comment_text] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [sym_using_directive_key] = {
    .visible = true,
    .named = true,
  },
  [sym_using_directive_value] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SLASH_STAR] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_block_comment_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_STAR_SLASH] = {
    .visible = true,
    .named = false,
  },
  [sym__automatic_semicolon] = {
    .visible = false,
    .named = true,
  },
  [sym__indent] = {
    .visible = false,
    .named = true,
  },
  [sym__interpolated_string_middle] = {
    .visible = false,
    .named = true,
  },
  [sym__interpolated_string_end] = {
    .visible = false,
    .named = true,
  },
  [sym__interpolated_multiline_string_middle] = {
    .visible = false,
    .named = true,
  },
  [sym__interpolated_multiline_string_end] = {
    .visible = false,
    .named = true,
  },
  [sym__outdent] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_multiline_string] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_string] = {
    .visible = false,
    .named = true,
  },
  [sym_compilation_unit] = {
    .visible = true,
    .named = true,
  },
  [sym__top_level_definition] = {
    .visible = false,
    .named = true,
  },
  [sym_enum_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__enum_block] = {
    .visible = false,
    .named = true,
  },
  [sym_enum_body] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_case_definitions] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_enum_case] = {
    .visible = true,
    .named = true,
  },
  [sym_full_enum_case] = {
    .visible = true,
    .named = true,
  },
  [sym__full_enum_def] = {
    .visible = false,
    .named = true,
  },
  [sym_package_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_package_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_package_object] = {
    .visible = true,
    .named = true,
  },
  [sym_import_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_export_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__namespace_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_namespace_wildcard] = {
    .visible = true,
    .named = true,
  },
  [sym__namespace_given_by_type] = {
    .visible = false,
    .named = true,
  },
  [sym_namespace_selectors] = {
    .visible = true,
    .named = true,
  },
  [sym_arrow_renamed_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_as_renamed_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_object_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__object_definition] = {
    .visible = false,
    .named = true,
  },
  [sym_class_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__class_definition] = {
    .visible = false,
    .named = true,
  },
  [sym__definition_body] = {
    .visible = false,
    .named = true,
  },
  [sym__class_constructor] = {
    .visible = false,
    .named = true,
  },
  [sym_trait_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym__variant_type_parameter] = {
    .visible = false,
    .named = true,
  },
  [sym_covariant_type_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_contravariant_type_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym__type_parameter] = {
    .visible = false,
    .named = true,
  },
  [sym_upper_bound] = {
    .visible = true,
    .named = true,
  },
  [sym_lower_bound] = {
    .visible = true,
    .named = true,
  },
  [sym_view_bound] = {
    .visible = true,
    .named = true,
  },
  [sym_context_bound] = {
    .visible = true,
    .named = true,
  },
  [sym_template_body] = {
    .visible = true,
    .named = true,
  },
  [sym__indented_template_body] = {
    .visible = false,
    .named = true,
  },
  [sym__braced_template_body] = {
    .visible = false,
    .named = true,
  },
  [sym__braced_template_body1] = {
    .visible = false,
    .named = true,
  },
  [sym__braced_template_body2] = {
    .visible = false,
    .named = true,
  },
  [sym_with_template_body] = {
    .visible = true,
    .named = true,
  },
  [sym__extension_template_body] = {
    .visible = false,
    .named = true,
  },
  [sym__end_marker] = {
    .visible = false,
    .named = true,
  },
  [sym_self_type] = {
    .visible = true,
    .named = true,
  },
  [sym__self_type_ascription] = {
    .visible = false,
    .named = true,
  },
  [sym_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_val_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_val_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__start_val] = {
    .visible = false,
    .named = true,
  },
  [sym_var_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_var_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__start_var] = {
    .visible = false,
    .named = true,
  },
  [sym_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__type_constructor] = {
    .visible = false,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__function_declaration] = {
    .visible = false,
    .named = true,
  },
  [sym__function_constructor] = {
    .visible = false,
    .named = true,
  },
  [sym_opaque_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_extension_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_given_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__given_constructor] = {
    .visible = false,
    .named = true,
  },
  [sym__structural_instance] = {
    .visible = false,
    .named = true,
  },
  [sym__constructor_application] = {
    .visible = false,
    .named = true,
  },
  [sym__constructor_applications] = {
    .visible = false,
    .named = true,
  },
  [sym_modifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_access_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_access_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_inline_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_open_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_transparent_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_extends_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_derives_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_class_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym__using_parameters_clause] = {
    .visible = false,
    .named = true,
  },
  [sym_class_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym__block] = {
    .visible = false,
    .named = true,
  },
  [sym__indentable_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_indented_block] = {
    .visible = true,
    .named = true,
  },
  [sym_indented_cases] = {
    .visible = true,
    .named = true,
  },
  [sym__indented_type_cases] = {
    .visible = false,
    .named = true,
  },
  [sym__type] = {
    .visible = false,
    .named = true,
  },
  [sym__annotated_type] = {
    .visible = false,
    .named = true,
  },
  [sym_annotated_type] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_type] = {
    .visible = false,
    .named = true,
  },
  [sym_compound_type] = {
    .visible = true,
    .named = true,
  },
  [sym__structural_type] = {
    .visible = false,
    .named = true,
  },
  [sym__refinement] = {
    .visible = false,
    .named = true,
  },
  [sym__infix_type_choice] = {
    .visible = false,
    .named = true,
  },
  [sym_infix_type] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_type] = {
    .visible = true,
    .named = true,
  },
  [sym_singleton_type] = {
    .visible = true,
    .named = true,
  },
  [sym_stable_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_stable_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_type] = {
    .visible = true,
    .named = true,
  },
  [sym_projected_type] = {
    .visible = true,
    .named = true,
  },
  [sym_match_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_case_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_function_type] = {
    .visible = true,
    .named = true,
  },
  [sym__arrow_then_type] = {
    .visible = false,
    .named = true,
  },
  [sym_parameter_types] = {
    .visible = true,
    .named = true,
  },
  [sym_lazy_parameter_type] = {
    .visible = true,
    .named = true,
  },
  [sym_repeated_parameter_type] = {
    .visible = true,
    .named = true,
  },
  [sym__type_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_type_lambda] = {
    .visible = true,
    .named = true,
  },
  [sym_case_class_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_capture_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_repeat_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_given_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_alternative_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__simple_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_lambda_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_if_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__if_condition] = {
    .visible = false,
    .named = true,
  },
  [sym_match_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_try_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__expr_case_clause] = {
    .visible = false,
    .named = true,
  },
  [sym_finally_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_binding] = {
    .visible = true,
    .named = true,
  },
  [sym_bindings] = {
    .visible = true,
    .named = true,
  },
  [sym_case_block] = {
    .visible = true,
    .named = true,
  },
  [sym_case_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__case_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_guard] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_function] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_colon_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_instance_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_ascription_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_infix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_postfix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__postfix_expression_choice] = {
    .visible = false,
    .named = true,
  },
  [sym_macro_body] = {
    .visible = true,
    .named = true,
  },
  [sym_prefix_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym__exprs_in_parens] = {
    .visible = false,
    .named = true,
  },
  [sym_splice_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_quote_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__soft_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_identifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_wildcard] = {
    .visible = true,
    .named = true,
  },
  [sym__non_null_literal] = {
    .visible = false,
    .named = true,
  },
  [sym_literal_type] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolated_string_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__interpolated_string_start] = {
    .visible = false,
    .named = true,
  },
  [sym__dollar_escape] = {
    .visible = false,
    .named = true,
  },
  [sym__aliased_interpolation_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_interpolation] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolated_string] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_unit] = {
    .visible = true,
    .named = true,
  },
  [sym_return_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_while_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_do_while_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_for_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_enumerators] = {
    .visible = true,
    .named = true,
  },
  [sym_enumerator] = {
    .visible = true,
    .named = true,
  },
  [sym__shebang] = {
    .visible = false,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_using_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_block_comment] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_compilation_unit_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__enum_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_case_definitions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__full_enum_def_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_package_identifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_import_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_namespace_selectors_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__class_constructor_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__type_parameter_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__type_parameter_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_annotation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_val_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__function_constructor_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_extension_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__constructor_applications_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__constructor_applications_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_modifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_derives_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__using_parameters_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_indented_cases_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__indented_type_cases_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_compound_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tuple_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_lambda_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_class_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bindings_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tuple_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_identifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interpolated_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interpolated_string_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enumerators_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enumerator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_comment_repeat1] = {
    .visible = false,
    .named = false,
  },
  [anon_alias_sym__end_ident] = {
    .visible = true,
    .named = false,
  },
  [alias_sym_refinement] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_structural_type] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_type_identifier] = {
    .visible = true,
    .named = true,
  },
};

enum {
  field_alias = 1,
  field_alternative = 2,
  field_arguments = 3,
  field_base = 4,
  field_body = 5,
  field_bound = 6,
  field_class_parameters = 7,
  field_condition = 8,
  field_consequence = 9,
  field_default_value = 10,
  field_derive = 11,
  field_enumerators = 12,
  field_extend = 13,
  field_extra = 14,
  field_field = 15,
  field_function = 16,
  field_interpolator = 17,
  field_lambda_start = 18,
  field_left = 19,
  field_name = 20,
  field_operator = 21,
  field_parameter_types = 22,
  field_parameters = 23,
  field_path = 24,
  field_pattern = 25,
  field_return_type = 26,
  field_right = 27,
  field_selector = 28,
  field_type = 29,
  field_type_arguments = 30,
  field_type_parameters = 31,
  field_value = 32,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alias] = "alias",
  [field_alternative] = "alternative",
  [field_arguments] = "arguments",
  [field_base] = "base",
  [field_body] = "body",
  [field_bound] = "bound",
  [field_class_parameters] = "class_parameters",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_default_value] = "default_value",
  [field_derive] = "derive",
  [field_enumerators] = "enumerators",
  [field_extend] = "extend",
  [field_extra] = "extra",
  [field_field] = "field",
  [field_function] = "function",
  [field_interpolator] = "interpolator",
  [field_lambda_start] = "lambda_start",
  [field_left] = "left",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_parameter_types] = "parameter_types",
  [field_parameters] = "parameters",
  [field_path] = "path",
  [field_pattern] = "pattern",
  [field_return_type] = "return_type",
  [field_right] = "right",
  [field_selector] = "selector",
  [field_type] = "type",
  [field_type_arguments] = "type_arguments",
  [field_type_parameters] = "type_parameters",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 4},
  [2] = {.index = 4, .length = 1},
  [3] = {.index = 5, .length = 1},
  [4] = {.index = 6, .length = 4},
  [5] = {.index = 10, .length = 1},
  [6] = {.index = 11, .length = 1},
  [9] = {.index = 12, .length = 3},
  [10] = {.index = 15, .length = 6},
  [11] = {.index = 21, .length = 3},
  [13] = {.index = 24, .length = 1},
  [14] = {.index = 25, .length = 1},
  [15] = {.index = 26, .length = 3},
  [16] = {.index = 29, .length = 3},
  [17] = {.index = 32, .length = 5},
  [18] = {.index = 37, .length = 2},
  [19] = {.index = 39, .length = 2},
  [20] = {.index = 41, .length = 1},
  [21] = {.index = 42, .length = 2},
  [22] = {.index = 44, .length = 2},
  [23] = {.index = 46, .length = 4},
  [24] = {.index = 50, .length = 1},
  [25] = {.index = 51, .length = 4},
  [26] = {.index = 55, .length = 6},
  [27] = {.index = 61, .length = 2},
  [28] = {.index = 63, .length = 3},
  [29] = {.index = 66, .length = 1},
  [30] = {.index = 67, .length = 2},
  [31] = {.index = 69, .length = 2},
  [32] = {.index = 71, .length = 2},
  [33] = {.index = 73, .length = 2},
  [34] = {.index = 75, .length = 3},
  [35] = {.index = 78, .length = 1},
  [36] = {.index = 79, .length = 6},
  [38] = {.index = 85, .length = 1},
  [39] = {.index = 86, .length = 1},
  [40] = {.index = 87, .length = 2},
  [41] = {.index = 89, .length = 2},
  [42] = {.index = 91, .length = 1},
  [43] = {.index = 92, .length = 5},
  [44] = {.index = 97, .length = 4},
  [45] = {.index = 101, .length = 4},
  [46] = {.index = 105, .length = 2},
  [47] = {.index = 107, .length = 2},
  [48] = {.index = 109, .length = 1},
  [49] = {.index = 110, .length = 1},
  [50] = {.index = 111, .length = 1},
  [51] = {.index = 112, .length = 2},
  [52] = {.index = 114, .length = 2},
  [53] = {.index = 116, .length = 2},
  [54] = {.index = 118, .length = 2},
  [55] = {.index = 120, .length = 2},
  [56] = {.index = 122, .length = 5},
  [57] = {.index = 127, .length = 3},
  [58] = {.index = 130, .length = 3},
  [59] = {.index = 133, .length = 3},
  [60] = {.index = 136, .length = 2},
  [61] = {.index = 138, .length = 2},
  [62] = {.index = 140, .length = 2},
  [63] = {.index = 142, .length = 3},
  [64] = {.index = 145, .length = 2},
  [65] = {.index = 147, .length = 3},
  [66] = {.index = 150, .length = 2},
  [67] = {.index = 152, .length = 1},
  [68] = {.index = 153, .length = 2},
  [69] = {.index = 155, .length = 5},
  [70] = {.index = 160, .length = 5},
  [71] = {.index = 165, .length = 2},
  [72] = {.index = 167, .length = 4},
  [73] = {.index = 171, .length = 3},
  [74] = {.index = 174, .length = 4},
  [75] = {.index = 178, .length = 2},
  [76] = {.index = 180, .length = 2},
  [77] = {.index = 182, .length = 2},
  [78] = {.index = 184, .length = 2},
  [79] = {.index = 186, .length = 2},
  [80] = {.index = 188, .length = 1},
  [81] = {.index = 189, .length = 2},
  [82] = {.index = 191, .length = 2},
  [83] = {.index = 193, .length = 6},
  [84] = {.index = 199, .length = 5},
  [85] = {.index = 204, .length = 6},
  [86] = {.index = 210, .length = 3},
  [87] = {.index = 213, .length = 2},
  [88] = {.index = 215, .length = 2},
  [89] = {.index = 217, .length = 1},
  [90] = {.index = 218, .length = 2},
  [91] = {.index = 220, .length = 2},
  [92] = {.index = 222, .length = 3},
  [93] = {.index = 225, .length = 4},
  [94] = {.index = 229, .length = 3},
  [95] = {.index = 232, .length = 3},
  [96] = {.index = 235, .length = 3},
  [97] = {.index = 238, .length = 4},
  [98] = {.index = 242, .length = 2},
  [99] = {.index = 244, .length = 2},
  [100] = {.index = 246, .length = 1},
  [101] = {.index = 247, .length = 2},
  [102] = {.index = 249, .length = 2},
  [103] = {.index = 251, .length = 2},
  [104] = {.index = 253, .length = 2},
  [105] = {.index = 255, .length = 4},
  [106] = {.index = 259, .length = 6},
  [107] = {.index = 265, .length = 6},
  [108] = {.index = 271, .length = 3},
  [109] = {.index = 274, .length = 2},
  [110] = {.index = 276, .length = 2},
  [111] = {.index = 278, .length = 4},
  [112] = {.index = 282, .length = 4},
  [113] = {.index = 286, .length = 3},
  [114] = {.index = 289, .length = 3},
  [115] = {.index = 292, .length = 3},
  [116] = {.index = 295, .length = 2},
  [117] = {.index = 297, .length = 2},
  [118] = {.index = 299, .length = 2},
  [119] = {.index = 301, .length = 6},
  [120] = {.index = 307, .length = 5},
  [121] = {.index = 312, .length = 6},
  [122] = {.index = 318, .length = 6},
  [123] = {.index = 324, .length = 1},
  [124] = {.index = 325, .length = 5},
  [125] = {.index = 330, .length = 7},
  [126] = {.index = 337, .length = 3},
  [127] = {.index = 340, .length = 4},
  [128] = {.index = 344, .length = 2},
  [129] = {.index = 346, .length = 4},
  [130] = {.index = 350, .length = 3},
  [131] = {.index = 353, .length = 4},
  [132] = {.index = 357, .length = 2},
  [133] = {.index = 359, .length = 4},
  [134] = {.index = 363, .length = 2},
  [135] = {.index = 365, .length = 5},
  [136] = {.index = 370, .length = 5},
  [137] = {.index = 375, .length = 4},
  [138] = {.index = 379, .length = 6},
  [139] = {.index = 385, .length = 6},
  [140] = {.index = 391, .length = 3},
  [141] = {.index = 394, .length = 2},
  [142] = {.index = 396, .length = 1},
  [143] = {.index = 397, .length = 3},
  [144] = {.index = 400, .length = 4},
  [145] = {.index = 404, .length = 1},
  [146] = {.index = 405, .length = 2},
  [147] = {.index = 407, .length = 2},
  [148] = {.index = 409, .length = 4},
  [149] = {.index = 413, .length = 3},
  [150] = {.index = 416, .length = 4},
  [151] = {.index = 420, .length = 3},
  [152] = {.index = 423, .length = 3},
  [153] = {.index = 426, .length = 5},
  [154] = {.index = 431, .length = 4},
  [155] = {.index = 435, .length = 3},
  [156] = {.index = 438, .length = 6},
  [157] = {.index = 444, .length = 2},
  [158] = {.index = 446, .length = 4},
  [159] = {.index = 450, .length = 2},
  [160] = {.index = 452, .length = 1},
  [161] = {.index = 453, .length = 2},
  [162] = {.index = 455, .length = 2},
  [163] = {.index = 457, .length = 4},
  [164] = {.index = 461, .length = 5},
  [165] = {.index = 466, .length = 5},
  [166] = {.index = 471, .length = 3},
  [167] = {.index = 474, .length = 2},
  [168] = {.index = 476, .length = 4},
  [169] = {.index = 480, .length = 3},
  [170] = {.index = 483, .length = 5},
  [171] = {.index = 488, .length = 4},
  [172] = {.index = 492, .length = 2},
  [173] = {.index = 494, .length = 3},
  [174] = {.index = 497, .length = 4},
  [175] = {.index = 501, .length = 7},
  [176] = {.index = 508, .length = 6},
  [177] = {.index = 514, .length = 3},
  [178] = {.index = 517, .length = 2},
  [179] = {.index = 519, .length = 2},
  [180] = {.index = 521, .length = 2},
  [181] = {.index = 523, .length = 7},
  [182] = {.index = 530, .length = 3},
  [183] = {.index = 533, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 0, .inherited = true},
    {field_parameters, 0, .inherited = true},
    {field_return_type, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [4] =
    {field_name, 0},
  [5] =
    {field_name, 1},
  [6] =
    {field_body, 1, .inherited = true},
    {field_derive, 1, .inherited = true},
    {field_extend, 1, .inherited = true},
    {field_name, 1, .inherited = true},
  [10] =
    {field_path, 0},
  [11] =
    {field_path, 1, .inherited = true},
  [12] =
    {field_arguments, 1, .inherited = true},
    {field_body, 1, .inherited = true},
    {field_return_type, 1},
  [15] =
    {field_body, 1, .inherited = true},
    {field_class_parameters, 1, .inherited = true},
    {field_derive, 1, .inherited = true},
    {field_extend, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [21] =
    {field_class_parameters, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [24] =
    {field_body, 1},
  [25] =
    {field_arguments, 1, .inherited = true},
  [26] =
    {field_bound, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [29] =
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [32] =
    {field_body, 1},
    {field_name, 0, .inherited = true},
    {field_parameters, 0, .inherited = true},
    {field_return_type, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [37] =
    {field_function, 0},
    {field_type_arguments, 1},
  [39] =
    {field_arguments, 1},
    {field_function, 0},
  [41] =
    {field_interpolator, 0},
  [42] =
    {field_name, 0},
    {field_type_parameters, 1},
  [44] =
    {field_class_parameters, 1},
    {field_name, 0},
  [46] =
    {field_body, 2},
    {field_class_parameters, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [50] =
    {field_pattern, 1, .inherited = true},
  [51] =
    {field_body, 2, .inherited = true},
    {field_derive, 2, .inherited = true},
    {field_extend, 2, .inherited = true},
    {field_name, 2, .inherited = true},
  [55] =
    {field_body, 2, .inherited = true},
    {field_class_parameters, 2, .inherited = true},
    {field_derive, 2, .inherited = true},
    {field_extend, 2, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [61] =
    {field_body, 2},
    {field_name, 1},
  [63] =
    {field_body, 1},
    {field_body, 1, .inherited = true},
    {field_name, 0},
  [66] =
    {field_body, 0},
  [67] =
    {field_extend, 1},
    {field_name, 0},
  [69] =
    {field_derive, 1},
    {field_name, 0},
  [71] =
    {field_path, 0},
    {field_path, 1},
  [73] =
    {field_path, 1, .inherited = true},
    {field_path, 2, .inherited = true},
  [75] =
    {field_bound, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [78] =
    {field_type_parameters, 0},
  [79] =
    {field_arguments, 2, .inherited = true},
    {field_body, 2, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_return_type, 2},
    {field_type_parameters, 1, .inherited = true},
  [85] =
    {field_base, 0},
  [86] =
    {field_arguments, 1},
  [87] =
    {field_base, 0},
    {field_extra, 1, .inherited = true},
  [89] =
    {field_type, 0},
    {field_type_arguments, 1},
  [91] =
    {field_parameters, 0},
  [92] =
    {field_body, 1},
    {field_body, 1, .inherited = true},
    {field_class_parameters, 0, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [97] =
    {field_class_parameters, 0, .inherited = true},
    {field_extend, 1},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [101] =
    {field_class_parameters, 0, .inherited = true},
    {field_derive, 1},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [105] =
    {field_condition, 1},
    {field_consequence, 2},
  [107] =
    {field_body, 2},
    {field_condition, 1},
  [109] =
    {field_type, 1},
  [110] =
    {field_condition, 1},
  [111] =
    {field_pattern, 0},
  [112] =
    {field_body, 2},
    {field_type_parameters, 1},
  [114] =
    {field_body, 2},
    {field_parameters, 1},
  [116] =
    {field_arguments, 2},
    {field_name, 1},
  [118] =
    {field_bound, 1},
    {field_name, 0},
  [120] =
    {field_name, 0},
    {field_parameters, 1},
  [122] =
    {field_body, 2},
    {field_name, 0, .inherited = true},
    {field_parameters, 0, .inherited = true},
    {field_return_type, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [127] =
    {field_bound, 2, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [130] =
    {field_arguments, 2, .inherited = true},
    {field_body, 2, .inherited = true},
    {field_return_type, 2},
  [133] =
    {field_name, 2, .inherited = true},
    {field_parameters, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [136] =
    {field_body, 2},
    {field_value, 0},
  [138] =
    {field_field, 2},
    {field_value, 0},
  [140] =
    {field_left, 0},
    {field_right, 2},
  [142] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [145] =
    {field_arguments, 2},
    {field_function, 0},
  [147] =
    {field_class_parameters, 2},
    {field_name, 0},
    {field_type_parameters, 1},
  [150] =
    {field_class_parameters, 2},
    {field_name, 0},
  [152] =
    {field_arguments, 0, .inherited = true},
  [153] =
    {field_arguments, 1, .inherited = true},
    {field_type, 1},
  [155] =
    {field_body, 3},
    {field_class_parameters, 1, .inherited = true},
    {field_extend, 2},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [160] =
    {field_body, 3},
    {field_class_parameters, 1, .inherited = true},
    {field_derive, 2},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [165] =
    {field_body, 2},
    {field_pattern, 1, .inherited = true},
  [167] =
    {field_body, 2},
    {field_body, 2, .inherited = true},
    {field_extend, 1},
    {field_name, 0},
  [171] =
    {field_derive, 2},
    {field_extend, 1},
    {field_name, 0},
  [174] =
    {field_body, 2},
    {field_body, 2, .inherited = true},
    {field_derive, 1},
    {field_name, 0},
  [178] =
    {field_path, 0, .inherited = true},
    {field_path, 1, .inherited = true},
  [180] =
    {field_parameter_types, 0},
    {field_return_type, 1, .inherited = true},
  [182] =
    {field_parameters, 1},
    {field_type_parameters, 0},
  [184] =
    {field_arguments, 0, .inherited = true},
    {field_body, 2},
  [186] =
    {field_body, 3},
    {field_return_type, 1},
  [188] =
    {field_extra, 1},
  [189] =
    {field_extra, 0, .inherited = true},
    {field_extra, 1, .inherited = true},
  [191] =
    {field_selector, 2},
    {field_type, 0},
  [193] =
    {field_body, 2},
    {field_body, 2, .inherited = true},
    {field_class_parameters, 0, .inherited = true},
    {field_extend, 1},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [199] =
    {field_class_parameters, 0, .inherited = true},
    {field_derive, 2},
    {field_extend, 1},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [204] =
    {field_body, 2},
    {field_body, 2, .inherited = true},
    {field_class_parameters, 0, .inherited = true},
    {field_derive, 1},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [210] =
    {field_body, 3},
    {field_condition, 1},
    {field_condition, 2},
  [213] =
    {field_pattern, 0},
    {field_type, 2},
  [215] =
    {field_name, 0},
    {field_pattern, 2},
  [217] =
    {field_type, 0},
  [218] =
    {field_body, 3},
    {field_enumerators, 1},
  [220] =
    {field_body, 1, .inherited = true},
    {field_pattern, 1, .inherited = true},
  [222] =
    {field_body, 3},
    {field_parameters, 2},
    {field_type_parameters, 1},
  [225] =
    {field_bound, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type, 3},
    {field_type_parameters, 1, .inherited = true},
  [229] =
    {field_bound, 2},
    {field_name, 0},
    {field_type_parameters, 1},
  [232] =
    {field_bound, 1},
    {field_bound, 2},
    {field_name, 0},
  [235] =
    {field_name, 0},
    {field_parameters, 2},
    {field_type_parameters, 1},
  [238] =
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_return_type, 3},
    {field_type_parameters, 1, .inherited = true},
  [242] =
    {field_parameters, 0},
    {field_parameters, 1},
  [244] =
    {field_name, 0},
    {field_type, 2},
  [246] =
    {field_type, 2},
  [247] =
    {field_body, 1},
    {field_condition, 3},
  [249] =
    {field_name, 1},
    {field_type, 3},
  [251] =
    {field_pattern, 1},
    {field_value, 3},
  [253] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [255] =
    {field_body, 3, .inherited = true},
    {field_derive, 3, .inherited = true},
    {field_extend, 3, .inherited = true},
    {field_name, 3, .inherited = true},
  [259] =
    {field_body, 3, .inherited = true},
    {field_class_parameters, 3, .inherited = true},
    {field_derive, 3, .inherited = true},
    {field_extend, 3, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_type_parameters, 3, .inherited = true},
  [265] =
    {field_arguments, 3, .inherited = true},
    {field_body, 3, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_parameters, 2, .inherited = true},
    {field_return_type, 3},
    {field_type_parameters, 2, .inherited = true},
  [271] =
    {field_bound, 3, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_type_parameters, 3, .inherited = true},
  [274] =
    {field_condition, 2},
    {field_consequence, 3},
  [276] =
    {field_body, 3},
    {field_value, 1},
  [278] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
    {field_right, 3},
  [282] =
    {field_body, 3},
    {field_class_parameters, 2, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [286] =
    {field_arguments, 3, .inherited = true},
    {field_body, 3, .inherited = true},
    {field_return_type, 3},
  [289] =
    {field_name, 3, .inherited = true},
    {field_parameters, 3, .inherited = true},
    {field_type_parameters, 3, .inherited = true},
  [292] =
    {field_class_parameters, 3},
    {field_name, 0},
    {field_type_parameters, 1},
  [295] =
    {field_class_parameters, 3},
    {field_name, 0},
  [297] =
    {field_arguments, 0, .inherited = true},
    {field_arguments, 1, .inherited = true},
  [299] =
    {field_type, 1},
    {field_type, 2, .inherited = true},
  [301] =
    {field_body, 4},
    {field_class_parameters, 1, .inherited = true},
    {field_derive, 3},
    {field_extend, 2},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [307] =
    {field_body, 3},
    {field_body, 3, .inherited = true},
    {field_derive, 2},
    {field_extend, 1},
    {field_name, 0},
  [312] =
    {field_bound, 1, .inherited = true},
    {field_bound, 2, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [318] =
    {field_bound, 0, .inherited = true},
    {field_bound, 1, .inherited = true},
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
    {field_type_parameters, 1, .inherited = true},
  [324] =
    {field_return_type, 1},
  [325] =
    {field_body, 4},
    {field_name, 1, .inherited = true},
    {field_parameters, 1, .inherited = true},
    {field_return_type, 2},
    {field_type_parameters, 1, .inherited = true},
  [330] =
    {field_body, 3},
    {field_body, 3, .inherited = true},
    {field_class_parameters, 0, .inherited = true},
    {field_derive, 2},
    {field_extend, 1},
    {field_name, 0, .inherited = true},
    {field_type_parameters, 0, .inherited = true},
  [337] =
    {field_alternative, 4},
    {field_condition, 1},
    {field_consequence, 2},
  [340] =
    {field_body, 4},
    {field_enumerators, 1},
    {field_enumerators, 2},
    {field_enumerators, 3},
  [344] =
    {field_pattern, 2},
    {field_type, 0},
  [346] =
    {field_bound, 2},
    {field_bound, 3},
    {field_name, 0},
    {field_type_parameters, 1},
  [350] =
    {field_name, 1},
    {field_name, 2, .inherited = true},
    {field_type, 4},
  [353] =
    {field_bound, 2, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type, 4},
    {field_type_parameters, 2, .inherited = true},
  [357] =
    {field_body, 4},
    {field_return_type, 2},
  [359] =
    {field_name, 2, .inherited = true},
    {field_parameters, 2, .inherited = true},
    {field_return_type, 4},
    {field_type_parameters, 2, .inherited = true},
  [363] =
    {field_lambda_start, 0},
    {field_lambda_start, 1},
  [365] =
    {field_body, 4},
    {field_class_parameters, 2, .inherited = true},
    {field_extend, 3},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [370] =
    {field_body, 4},
    {field_class_parameters, 2, .inherited = true},
    {field_derive, 3},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [375] =
    {field_body, 4, .inherited = true},
    {field_derive, 4, .inherited = true},
    {field_extend, 4, .inherited = true},
    {field_name, 4, .inherited = true},
  [379] =
    {field_body, 4, .inherited = true},
    {field_class_parameters, 4, .inherited = true},
    {field_derive, 4, .inherited = true},
    {field_extend, 4, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_type_parameters, 4, .inherited = true},
  [385] =
    {field_arguments, 4, .inherited = true},
    {field_body, 4, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_parameters, 3, .inherited = true},
    {field_return_type, 4},
    {field_type_parameters, 3, .inherited = true},
  [391] =
    {field_bound, 4, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_type_parameters, 4, .inherited = true},
  [394] =
    {field_default_value, 2},
    {field_name, 0},
  [396] =
    {field_name, 2},
  [397] =
    {field_class_parameters, 4},
    {field_name, 0},
    {field_type_parameters, 1},
  [400] =
    {field_class_parameters, 1, .inherited = true},
    {field_extend, 1, .inherited = true},
    {field_name, 0},
    {field_type_parameters, 1, .inherited = true},
  [404] =
    {field_class_parameters, 0},
  [405] =
    {field_type, 0, .inherited = true},
    {field_type, 1, .inherited = true},
  [407] =
    {field_alias, 2},
    {field_name, 0},
  [409] =
    {field_bound, 1},
    {field_bound, 2},
    {field_bound, 3},
    {field_name, 0},
  [413] =
    {field_alternative, 5},
    {field_condition, 1},
    {field_consequence, 2},
  [416] =
    {field_body, 5},
    {field_enumerators, 1},
    {field_enumerators, 2},
    {field_enumerators, 3},
  [420] =
    {field_pattern, 2},
    {field_pattern, 3},
    {field_type, 0},
  [423] =
    {field_pattern, 1},
    {field_type, 3},
    {field_value, 5},
  [426] =
    {field_body, 5},
    {field_name, 2, .inherited = true},
    {field_parameters, 2, .inherited = true},
    {field_return_type, 3},
    {field_type_parameters, 2, .inherited = true},
  [431] =
    {field_bound, 3, .inherited = true},
    {field_name, 3, .inherited = true},
    {field_type, 5},
    {field_type_parameters, 3, .inherited = true},
  [435] =
    {field_alternative, 5},
    {field_condition, 2},
    {field_consequence, 3},
  [438] =
    {field_body, 5},
    {field_class_parameters, 2, .inherited = true},
    {field_derive, 4},
    {field_extend, 3},
    {field_name, 2, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [444] =
    {field_body, 5},
    {field_return_type, 3},
  [446] =
    {field_name, 3, .inherited = true},
    {field_parameters, 3, .inherited = true},
    {field_return_type, 5},
    {field_type_parameters, 3, .inherited = true},
  [450] =
    {field_default_value, 3},
    {field_name, 1},
  [452] =
    {field_name, 3},
  [453] =
    {field_class_parameters, 1},
    {field_type_parameters, 0},
  [455] =
    {field_class_parameters, 0},
    {field_extend, 1},
  [457] =
    {field_bound, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_return_type, 4},
    {field_type_parameters, 1, .inherited = true},
  [461] =
    {field_bound, 2},
    {field_bound, 3},
    {field_bound, 4},
    {field_name, 0},
    {field_type_parameters, 1},
  [466] =
    {field_bound, 1},
    {field_bound, 2},
    {field_bound, 3},
    {field_bound, 4},
    {field_name, 0},
  [471] =
    {field_default_value, 4},
    {field_name, 0},
    {field_type, 2},
  [474] =
    {field_name, 2},
    {field_type, 4},
  [476] =
    {field_pattern, 2},
    {field_pattern, 3},
    {field_pattern, 4},
    {field_type, 0},
  [480] =
    {field_alternative, 6},
    {field_condition, 2},
    {field_consequence, 3},
  [483] =
    {field_body, 6},
    {field_name, 3, .inherited = true},
    {field_parameters, 3, .inherited = true},
    {field_return_type, 4},
    {field_type_parameters, 3, .inherited = true},
  [488] =
    {field_bound, 4, .inherited = true},
    {field_name, 4, .inherited = true},
    {field_type, 6},
    {field_type_parameters, 4, .inherited = true},
  [492] =
    {field_default_value, 4},
    {field_name, 2},
  [494] =
    {field_class_parameters, 1},
    {field_extend, 2},
    {field_type_parameters, 0},
  [497] =
    {field_bound, 1, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_return_type, 5},
    {field_type_parameters, 1, .inherited = true},
  [501] =
    {field_bound, 1, .inherited = true},
    {field_bound, 2, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_return_type, 5},
    {field_type_parameters, 1, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [508] =
    {field_bound, 2},
    {field_bound, 3},
    {field_bound, 4},
    {field_bound, 5},
    {field_name, 0},
    {field_type_parameters, 1},
  [514] =
    {field_default_value, 5},
    {field_name, 1},
    {field_type, 3},
  [517] =
    {field_body, 2},
    {field_return_type, 2, .inherited = true},
  [519] =
    {field_name, 3},
    {field_type, 5},
  [521] =
    {field_default_value, 5},
    {field_name, 3},
  [523] =
    {field_bound, 1, .inherited = true},
    {field_bound, 2, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_return_type, 6},
    {field_type_parameters, 1, .inherited = true},
    {field_type_parameters, 2, .inherited = true},
  [530] =
    {field_default_value, 6},
    {field_name, 2},
    {field_type, 4},
  [533] =
    {field_default_value, 7},
    {field_name, 3},
    {field_type, 5},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [7] = {
    [0] = alias_sym_type_identifier,
  },
  [8] = {
    [0] = alias_sym_structural_type,
  },
  [12] = {
    [1] = anon_alias_sym__end_ident,
  },
  [37] = {
    [0] = alias_sym_refinement,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_template_body, 3,
    sym_template_body,
    alias_sym_refinement,
    alias_sym_structural_type,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 2,
  [5] = 2,
  [6] = 2,
  [7] = 2,
  [8] = 2,
  [9] = 2,
  [10] = 2,
  [11] = 2,
  [12] = 2,
  [13] = 2,
  [14] = 2,
  [15] = 2,
  [16] = 2,
  [17] = 2,
  [18] = 2,
  [19] = 2,
  [20] = 2,
  [21] = 2,
  [22] = 2,
  [23] = 2,
  [24] = 2,
  [25] = 2,
  [26] = 2,
  [27] = 2,
  [28] = 2,
  [29] = 2,
  [30] = 2,
  [31] = 2,
  [32] = 2,
  [33] = 2,
  [34] = 2,
  [35] = 2,
  [36] = 2,
  [37] = 2,
  [38] = 2,
  [39] = 2,
  [40] = 2,
  [41] = 2,
  [42] = 2,
  [43] = 2,
  [44] = 2,
  [45] = 2,
  [46] = 2,
  [47] = 2,
  [48] = 2,
  [49] = 2,
  [50] = 2,
  [51] = 2,
  [52] = 2,
  [53] = 2,
  [54] = 2,
  [55] = 2,
  [56] = 2,
  [57] = 2,
  [58] = 2,
  [59] = 2,
  [60] = 2,
  [61] = 2,
  [62] = 2,
  [63] = 2,
  [64] = 2,
  [65] = 2,
  [66] = 2,
  [67] = 2,
  [68] = 2,
  [69] = 2,
  [70] = 2,
  [71] = 2,
  [72] = 2,
  [73] = 2,
  [74] = 2,
  [75] = 2,
  [76] = 2,
  [77] = 2,
  [78] = 2,
  [79] = 2,
  [80] = 2,
  [81] = 2,
  [82] = 2,
  [83] = 2,
  [84] = 2,
  [85] = 2,
  [86] = 2,
  [87] = 2,
  [88] = 2,
  [89] = 2,
  [90] = 2,
  [91] = 2,
  [92] = 2,
  [93] = 2,
  [94] = 2,
  [95] = 2,
  [96] = 2,
  [97] = 2,
  [98] = 2,
  [99] = 2,
  [100] = 2,
  [101] = 2,
  [102] = 2,
  [103] = 2,
  [104] = 2,
  [105] = 2,
  [106] = 2,
  [107] = 2,
  [108] = 2,
  [109] = 2,
  [110] = 2,
  [111] = 2,
  [112] = 2,
  [113] = 2,
  [114] = 2,
  [115] = 2,
  [116] = 2,
  [117] = 2,
  [118] = 2,
  [119] = 2,
  [120] = 2,
  [121] = 2,
  [122] = 2,
  [123] = 2,
  [124] = 2,
  [125] = 2,
  [126] = 2,
  [127] = 2,
  [128] = 128,
  [129] = 128,
  [130] = 128,
  [131] = 128,
  [132] = 128,
  [133] = 128,
  [134] = 128,
  [135] = 135,
  [136] = 128,
  [137] = 128,
  [138] = 128,
  [139] = 128,
  [140] = 140,
  [141] = 128,
  [142] = 128,
  [143] = 128,
  [144] = 144,
  [145] = 128,
  [146] = 128,
  [147] = 128,
  [148] = 128,
  [149] = 128,
  [150] = 128,
  [151] = 128,
  [152] = 128,
  [153] = 128,
  [154] = 154,
  [155] = 128,
  [156] = 128,
  [157] = 157,
  [158] = 157,
  [159] = 157,
  [160] = 157,
  [161] = 157,
  [162] = 157,
  [163] = 157,
  [164] = 157,
  [165] = 157,
  [166] = 157,
  [167] = 157,
  [168] = 157,
  [169] = 157,
  [170] = 157,
  [171] = 157,
  [172] = 157,
  [173] = 157,
  [174] = 157,
  [175] = 157,
  [176] = 157,
  [177] = 157,
  [178] = 157,
  [179] = 157,
  [180] = 157,
  [181] = 157,
  [182] = 157,
  [183] = 157,
  [184] = 157,
  [185] = 157,
  [186] = 157,
  [187] = 157,
  [188] = 157,
  [189] = 157,
  [190] = 157,
  [191] = 157,
  [192] = 157,
  [193] = 157,
  [194] = 157,
  [195] = 157,
  [196] = 157,
  [197] = 197,
  [198] = 157,
  [199] = 157,
  [200] = 157,
  [201] = 157,
  [202] = 157,
  [203] = 157,
  [204] = 157,
  [205] = 157,
  [206] = 157,
  [207] = 157,
  [208] = 157,
  [209] = 157,
  [210] = 157,
  [211] = 157,
  [212] = 157,
  [213] = 157,
  [214] = 157,
  [215] = 215,
  [216] = 157,
  [217] = 157,
  [218] = 157,
  [219] = 157,
  [220] = 157,
  [221] = 157,
  [222] = 157,
  [223] = 157,
  [224] = 157,
  [225] = 157,
  [226] = 157,
  [227] = 227,
  [228] = 227,
  [229] = 229,
  [230] = 227,
  [231] = 229,
  [232] = 227,
  [233] = 227,
  [234] = 227,
  [235] = 227,
  [236] = 227,
  [237] = 227,
  [238] = 227,
  [239] = 227,
  [240] = 227,
  [241] = 227,
  [242] = 242,
  [243] = 227,
  [244] = 227,
  [245] = 227,
  [246] = 227,
  [247] = 227,
  [248] = 227,
  [249] = 227,
  [250] = 227,
  [251] = 227,
  [252] = 227,
  [253] = 227,
  [254] = 227,
  [255] = 229,
  [256] = 227,
  [257] = 227,
  [258] = 227,
  [259] = 227,
  [260] = 227,
  [261] = 227,
  [262] = 227,
  [263] = 227,
  [264] = 227,
  [265] = 227,
  [266] = 227,
  [267] = 227,
  [268] = 268,
  [269] = 227,
  [270] = 227,
  [271] = 227,
  [272] = 227,
  [273] = 227,
  [274] = 227,
  [275] = 227,
  [276] = 227,
  [277] = 227,
  [278] = 227,
  [279] = 227,
  [280] = 227,
  [281] = 227,
  [282] = 227,
  [283] = 227,
  [284] = 227,
  [285] = 227,
  [286] = 227,
  [287] = 227,
  [288] = 227,
  [289] = 227,
  [290] = 227,
  [291] = 227,
  [292] = 227,
  [293] = 227,
  [294] = 227,
  [295] = 227,
  [296] = 227,
  [297] = 227,
  [298] = 229,
  [299] = 299,
  [300] = 300,
  [301] = 227,
  [302] = 227,
  [303] = 227,
  [304] = 227,
  [305] = 227,
  [306] = 227,
  [307] = 227,
  [308] = 227,
  [309] = 227,
  [310] = 227,
  [311] = 227,
  [312] = 227,
  [313] = 227,
  [314] = 227,
  [315] = 227,
  [316] = 227,
  [317] = 227,
  [318] = 227,
  [319] = 227,
  [320] = 227,
  [321] = 242,
  [322] = 227,
  [323] = 227,
  [324] = 227,
  [325] = 227,
  [326] = 227,
  [327] = 227,
  [328] = 227,
  [329] = 227,
  [330] = 227,
  [331] = 227,
  [332] = 227,
  [333] = 333,
  [334] = 227,
  [335] = 227,
  [336] = 227,
  [337] = 227,
  [338] = 227,
  [339] = 227,
  [340] = 268,
  [341] = 227,
  [342] = 227,
  [343] = 227,
  [344] = 227,
  [345] = 227,
  [346] = 227,
  [347] = 227,
  [348] = 227,
  [349] = 227,
  [350] = 227,
  [351] = 227,
  [352] = 227,
  [353] = 227,
  [354] = 227,
  [355] = 227,
  [356] = 227,
  [357] = 227,
  [358] = 227,
  [359] = 227,
  [360] = 227,
  [361] = 227,
  [362] = 299,
  [363] = 227,
  [364] = 227,
  [365] = 365,
  [366] = 365,
  [367] = 365,
  [368] = 365,
  [369] = 369,
  [370] = 365,
  [371] = 365,
  [372] = 365,
  [373] = 365,
  [374] = 374,
  [375] = 375,
  [376] = 365,
  [377] = 365,
  [378] = 365,
  [379] = 365,
  [380] = 365,
  [381] = 365,
  [382] = 365,
  [383] = 365,
  [384] = 365,
  [385] = 369,
  [386] = 365,
  [387] = 387,
  [388] = 387,
  [389] = 389,
  [390] = 375,
  [391] = 387,
  [392] = 365,
  [393] = 365,
  [394] = 394,
  [395] = 387,
  [396] = 365,
  [397] = 365,
  [398] = 394,
  [399] = 365,
  [400] = 365,
  [401] = 387,
  [402] = 365,
  [403] = 365,
  [404] = 387,
  [405] = 365,
  [406] = 365,
  [407] = 365,
  [408] = 365,
  [409] = 365,
  [410] = 365,
  [411] = 365,
  [412] = 365,
  [413] = 365,
  [414] = 375,
  [415] = 365,
  [416] = 365,
  [417] = 365,
  [418] = 365,
  [419] = 365,
  [420] = 375,
  [421] = 387,
  [422] = 365,
  [423] = 375,
  [424] = 365,
  [425] = 375,
  [426] = 365,
  [427] = 427,
  [428] = 365,
  [429] = 387,
  [430] = 365,
  [431] = 365,
  [432] = 365,
  [433] = 387,
  [434] = 375,
  [435] = 387,
  [436] = 365,
  [437] = 375,
  [438] = 365,
  [439] = 365,
  [440] = 365,
  [441] = 365,
  [442] = 387,
  [443] = 365,
  [444] = 365,
  [445] = 365,
  [446] = 365,
  [447] = 365,
  [448] = 365,
  [449] = 365,
  [450] = 387,
  [451] = 365,
  [452] = 365,
  [453] = 387,
  [454] = 365,
  [455] = 365,
  [456] = 365,
  [457] = 375,
  [458] = 365,
  [459] = 387,
  [460] = 365,
  [461] = 365,
  [462] = 365,
  [463] = 365,
  [464] = 365,
  [465] = 375,
  [466] = 365,
  [467] = 365,
  [468] = 365,
  [469] = 387,
  [470] = 365,
  [471] = 374,
  [472] = 365,
  [473] = 365,
  [474] = 427,
  [475] = 387,
  [476] = 365,
  [477] = 375,
  [478] = 365,
  [479] = 375,
  [480] = 365,
  [481] = 365,
  [482] = 365,
  [483] = 365,
  [484] = 365,
  [485] = 365,
  [486] = 365,
  [487] = 387,
  [488] = 375,
  [489] = 365,
  [490] = 375,
  [491] = 365,
  [492] = 365,
  [493] = 365,
  [494] = 365,
  [495] = 365,
  [496] = 365,
  [497] = 365,
  [498] = 365,
  [499] = 375,
  [500] = 375,
  [501] = 387,
  [502] = 375,
  [503] = 375,
  [504] = 365,
  [505] = 387,
  [506] = 387,
  [507] = 365,
  [508] = 365,
  [509] = 427,
  [510] = 365,
  [511] = 365,
  [512] = 365,
  [513] = 365,
  [514] = 394,
  [515] = 365,
  [516] = 365,
  [517] = 387,
  [518] = 365,
  [519] = 394,
  [520] = 387,
  [521] = 365,
  [522] = 365,
  [523] = 387,
  [524] = 365,
  [525] = 375,
  [526] = 365,
  [527] = 365,
  [528] = 375,
  [529] = 375,
  [530] = 387,
  [531] = 389,
  [532] = 365,
  [533] = 387,
  [534] = 387,
  [535] = 387,
  [536] = 375,
  [537] = 365,
  [538] = 427,
  [539] = 365,
  [540] = 365,
  [541] = 375,
  [542] = 365,
  [543] = 365,
  [544] = 365,
  [545] = 375,
  [546] = 365,
  [547] = 365,
  [548] = 387,
  [549] = 365,
  [550] = 365,
  [551] = 375,
  [552] = 387,
  [553] = 365,
  [554] = 365,
  [555] = 365,
  [556] = 365,
  [557] = 365,
  [558] = 365,
  [559] = 559,
  [560] = 560,
  [561] = 561,
  [562] = 561,
  [563] = 561,
  [564] = 564,
  [565] = 559,
  [566] = 561,
  [567] = 560,
  [568] = 564,
  [569] = 569,
  [570] = 569,
  [571] = 571,
  [572] = 571,
  [573] = 571,
  [574] = 574,
  [575] = 574,
  [576] = 574,
  [577] = 574,
  [578] = 574,
  [579] = 579,
  [580] = 579,
  [581] = 579,
  [582] = 579,
  [583] = 579,
  [584] = 579,
  [585] = 579,
  [586] = 579,
  [587] = 587,
  [588] = 579,
  [589] = 587,
  [590] = 579,
  [591] = 587,
  [592] = 579,
  [593] = 587,
  [594] = 587,
  [595] = 587,
  [596] = 579,
  [597] = 587,
  [598] = 587,
  [599] = 587,
  [600] = 579,
  [601] = 587,
  [602] = 579,
  [603] = 587,
  [604] = 587,
  [605] = 579,
  [606] = 579,
  [607] = 587,
  [608] = 579,
  [609] = 587,
  [610] = 579,
  [611] = 587,
  [612] = 587,
  [613] = 579,
  [614] = 587,
  [615] = 587,
  [616] = 587,
  [617] = 587,
  [618] = 587,
  [619] = 587,
  [620] = 587,
  [621] = 579,
  [622] = 579,
  [623] = 587,
  [624] = 587,
  [625] = 587,
  [626] = 579,
  [627] = 587,
  [628] = 579,
  [629] = 587,
  [630] = 587,
  [631] = 631,
  [632] = 631,
  [633] = 631,
  [634] = 631,
  [635] = 587,
  [636] = 631,
  [637] = 587,
  [638] = 631,
  [639] = 587,
  [640] = 631,
  [641] = 631,
  [642] = 631,
  [643] = 631,
  [644] = 631,
  [645] = 579,
  [646] = 579,
  [647] = 631,
  [648] = 631,
  [649] = 631,
  [650] = 587,
  [651] = 587,
  [652] = 587,
  [653] = 587,
  [654] = 587,
  [655] = 631,
  [656] = 631,
  [657] = 631,
  [658] = 631,
  [659] = 631,
  [660] = 631,
  [661] = 631,
  [662] = 631,
  [663] = 631,
  [664] = 631,
  [665] = 631,
  [666] = 631,
  [667] = 631,
  [668] = 631,
  [669] = 587,
  [670] = 631,
  [671] = 631,
  [672] = 587,
  [673] = 631,
  [674] = 631,
  [675] = 579,
  [676] = 631,
  [677] = 631,
  [678] = 587,
  [679] = 631,
  [680] = 631,
  [681] = 681,
  [682] = 587,
  [683] = 681,
  [684] = 684,
  [685] = 685,
  [686] = 685,
  [687] = 684,
  [688] = 685,
  [689] = 685,
  [690] = 684,
  [691] = 684,
  [692] = 684,
  [693] = 681,
  [694] = 681,
  [695] = 681,
  [696] = 685,
  [697] = 684,
  [698] = 681,
  [699] = 681,
  [700] = 685,
  [701] = 681,
  [702] = 681,
  [703] = 684,
  [704] = 681,
  [705] = 587,
  [706] = 685,
  [707] = 684,
  [708] = 681,
  [709] = 684,
  [710] = 684,
  [711] = 587,
  [712] = 684,
  [713] = 684,
  [714] = 684,
  [715] = 684,
  [716] = 587,
  [717] = 681,
  [718] = 685,
  [719] = 684,
  [720] = 684,
  [721] = 681,
  [722] = 685,
  [723] = 684,
  [724] = 681,
  [725] = 681,
  [726] = 684,
  [727] = 587,
  [728] = 587,
  [729] = 685,
  [730] = 681,
  [731] = 685,
  [732] = 685,
  [733] = 684,
  [734] = 681,
  [735] = 684,
  [736] = 681,
  [737] = 685,
  [738] = 685,
  [739] = 685,
  [740] = 681,
  [741] = 681,
  [742] = 684,
  [743] = 684,
  [744] = 684,
  [745] = 685,
  [746] = 684,
  [747] = 685,
  [748] = 684,
  [749] = 684,
  [750] = 685,
  [751] = 681,
  [752] = 685,
  [753] = 685,
  [754] = 684,
  [755] = 681,
  [756] = 685,
  [757] = 681,
  [758] = 685,
  [759] = 685,
  [760] = 684,
  [761] = 685,
  [762] = 684,
  [763] = 681,
  [764] = 684,
  [765] = 685,
  [766] = 684,
  [767] = 681,
  [768] = 681,
  [769] = 681,
  [770] = 685,
  [771] = 681,
  [772] = 681,
  [773] = 681,
  [774] = 684,
  [775] = 684,
  [776] = 685,
  [777] = 684,
  [778] = 685,
  [779] = 684,
  [780] = 684,
  [781] = 685,
  [782] = 681,
  [783] = 681,
  [784] = 684,
  [785] = 685,
  [786] = 684,
  [787] = 681,
  [788] = 681,
  [789] = 685,
  [790] = 685,
  [791] = 587,
  [792] = 685,
  [793] = 684,
  [794] = 681,
  [795] = 681,
  [796] = 684,
  [797] = 685,
  [798] = 684,
  [799] = 681,
  [800] = 681,
  [801] = 685,
  [802] = 684,
  [803] = 681,
  [804] = 685,
  [805] = 685,
  [806] = 685,
  [807] = 685,
  [808] = 685,
  [809] = 681,
  [810] = 684,
  [811] = 681,
  [812] = 684,
  [813] = 684,
  [814] = 681,
  [815] = 685,
  [816] = 681,
  [817] = 684,
  [818] = 681,
  [819] = 685,
  [820] = 681,
  [821] = 685,
  [822] = 684,
  [823] = 685,
  [824] = 684,
  [825] = 685,
  [826] = 684,
  [827] = 684,
  [828] = 681,
  [829] = 685,
  [830] = 681,
  [831] = 685,
  [832] = 587,
  [833] = 681,
  [834] = 681,
  [835] = 685,
  [836] = 681,
  [837] = 685,
  [838] = 684,
  [839] = 681,
  [840] = 685,
  [841] = 684,
  [842] = 684,
  [843] = 685,
  [844] = 681,
  [845] = 684,
  [846] = 684,
  [847] = 685,
  [848] = 685,
  [849] = 685,
  [850] = 685,
  [851] = 681,
  [852] = 685,
  [853] = 684,
  [854] = 681,
  [855] = 681,
  [856] = 681,
  [857] = 857,
  [858] = 858,
  [859] = 859,
  [860] = 857,
  [861] = 861,
  [862] = 858,
  [863] = 863,
  [864] = 858,
  [865] = 865,
  [866] = 866,
  [867] = 858,
  [868] = 868,
  [869] = 857,
  [870] = 859,
  [871] = 871,
  [872] = 872,
  [873] = 873,
  [874] = 868,
  [875] = 875,
  [876] = 876,
  [877] = 877,
  [878] = 871,
  [879] = 875,
  [880] = 866,
  [881] = 881,
  [882] = 882,
  [883] = 868,
  [884] = 858,
  [885] = 861,
  [886] = 866,
  [887] = 866,
  [888] = 876,
  [889] = 882,
  [890] = 876,
  [891] = 882,
  [892] = 881,
  [893] = 866,
  [894] = 866,
  [895] = 863,
  [896] = 896,
  [897] = 875,
  [898] = 873,
  [899] = 871,
  [900] = 858,
  [901] = 901,
  [902] = 861,
  [903] = 859,
  [904] = 857,
  [905] = 905,
  [906] = 858,
  [907] = 868,
  [908] = 858,
  [909] = 877,
  [910] = 881,
  [911] = 868,
  [912] = 877,
  [913] = 877,
  [914] = 868,
  [915] = 873,
  [916] = 866,
  [917] = 857,
  [918] = 868,
  [919] = 858,
  [920] = 858,
  [921] = 859,
  [922] = 861,
  [923] = 866,
  [924] = 871,
  [925] = 863,
  [926] = 873,
  [927] = 927,
  [928] = 868,
  [929] = 875,
  [930] = 871,
  [931] = 875,
  [932] = 873,
  [933] = 881,
  [934] = 876,
  [935] = 882,
  [936] = 872,
  [937] = 927,
  [938] = 905,
  [939] = 866,
  [940] = 866,
  [941] = 901,
  [942] = 896,
  [943] = 943,
  [944] = 944,
  [945] = 881,
  [946] = 859,
  [947] = 868,
  [948] = 948,
  [949] = 858,
  [950] = 950,
  [951] = 951,
  [952] = 873,
  [953] = 868,
  [954] = 868,
  [955] = 876,
  [956] = 882,
  [957] = 863,
  [958] = 868,
  [959] = 861,
  [960] = 873,
  [961] = 881,
  [962] = 882,
  [963] = 859,
  [964] = 857,
  [965] = 875,
  [966] = 877,
  [967] = 871,
  [968] = 873,
  [969] = 858,
  [970] = 871,
  [971] = 875,
  [972] = 882,
  [973] = 943,
  [974] = 866,
  [975] = 881,
  [976] = 882,
  [977] = 866,
  [978] = 587,
  [979] = 866,
  [980] = 881,
  [981] = 876,
  [982] = 866,
  [983] = 877,
  [984] = 858,
  [985] = 875,
  [986] = 863,
  [987] = 873,
  [988] = 868,
  [989] = 861,
  [990] = 859,
  [991] = 857,
  [992] = 871,
  [993] = 857,
  [994] = 859,
  [995] = 861,
  [996] = 858,
  [997] = 863,
  [998] = 868,
  [999] = 873,
  [1000] = 927,
  [1001] = 873,
  [1002] = 876,
  [1003] = 877,
  [1004] = 858,
  [1005] = 873,
  [1006] = 868,
  [1007] = 876,
  [1008] = 871,
  [1009] = 876,
  [1010] = 875,
  [1011] = 881,
  [1012] = 882,
  [1013] = 881,
  [1014] = 876,
  [1015] = 873,
  [1016] = 866,
  [1017] = 951,
  [1018] = 863,
  [1019] = 861,
  [1020] = 859,
  [1021] = 866,
  [1022] = 857,
  [1023] = 905,
  [1024] = 877,
  [1025] = 858,
  [1026] = 871,
  [1027] = 875,
  [1028] = 882,
  [1029] = 873,
  [1030] = 868,
  [1031] = 881,
  [1032] = 872,
  [1033] = 882,
  [1034] = 876,
  [1035] = 901,
  [1036] = 882,
  [1037] = 868,
  [1038] = 873,
  [1039] = 896,
  [1040] = 863,
  [1041] = 861,
  [1042] = 858,
  [1043] = 881,
  [1044] = 859,
  [1045] = 875,
  [1046] = 871,
  [1047] = 863,
  [1048] = 857,
  [1049] = 877,
  [1050] = 871,
  [1051] = 875,
  [1052] = 877,
  [1053] = 881,
  [1054] = 882,
  [1055] = 587,
  [1056] = 876,
  [1057] = 863,
  [1058] = 866,
  [1059] = 861,
  [1060] = 882,
  [1061] = 857,
  [1062] = 877,
  [1063] = 863,
  [1064] = 877,
  [1065] = 866,
  [1066] = 871,
  [1067] = 875,
  [1068] = 881,
  [1069] = 882,
  [1070] = 868,
  [1071] = 873,
  [1072] = 858,
  [1073] = 861,
  [1074] = 876,
  [1075] = 857,
  [1076] = 579,
  [1077] = 858,
  [1078] = 858,
  [1079] = 863,
  [1080] = 861,
  [1081] = 873,
  [1082] = 859,
  [1083] = 868,
  [1084] = 861,
  [1085] = 863,
  [1086] = 868,
  [1087] = 859,
  [1088] = 877,
  [1089] = 857,
  [1090] = 877,
  [1091] = 875,
  [1092] = 871,
  [1093] = 875,
  [1094] = 876,
  [1095] = 881,
  [1096] = 866,
  [1097] = 882,
  [1098] = 876,
  [1099] = 873,
  [1100] = 873,
  [1101] = 863,
  [1102] = 861,
  [1103] = 944,
  [1104] = 859,
  [1105] = 587,
  [1106] = 857,
  [1107] = 877,
  [1108] = 868,
  [1109] = 873,
  [1110] = 882,
  [1111] = 871,
  [1112] = 871,
  [1113] = 866,
  [1114] = 858,
  [1115] = 875,
  [1116] = 881,
  [1117] = 859,
  [1118] = 881,
  [1119] = 857,
  [1120] = 858,
  [1121] = 875,
  [1122] = 876,
  [1123] = 871,
  [1124] = 863,
  [1125] = 877,
  [1126] = 861,
  [1127] = 858,
  [1128] = 859,
  [1129] = 857,
  [1130] = 877,
  [1131] = 866,
  [1132] = 871,
  [1133] = 875,
  [1134] = 881,
  [1135] = 873,
  [1136] = 868,
  [1137] = 857,
  [1138] = 882,
  [1139] = 876,
  [1140] = 873,
  [1141] = 877,
  [1142] = 868,
  [1143] = 868,
  [1144] = 863,
  [1145] = 873,
  [1146] = 871,
  [1147] = 861,
  [1148] = 859,
  [1149] = 857,
  [1150] = 858,
  [1151] = 877,
  [1152] = 871,
  [1153] = 857,
  [1154] = 950,
  [1155] = 859,
  [1156] = 861,
  [1157] = 875,
  [1158] = 866,
  [1159] = 863,
  [1160] = 859,
  [1161] = 881,
  [1162] = 882,
  [1163] = 876,
  [1164] = 863,
  [1165] = 861,
  [1166] = 863,
  [1167] = 866,
  [1168] = 859,
  [1169] = 858,
  [1170] = 857,
  [1171] = 866,
  [1172] = 873,
  [1173] = 868,
  [1174] = 877,
  [1175] = 871,
  [1176] = 861,
  [1177] = 876,
  [1178] = 875,
  [1179] = 861,
  [1180] = 881,
  [1181] = 882,
  [1182] = 876,
  [1183] = 868,
  [1184] = 873,
  [1185] = 859,
  [1186] = 857,
  [1187] = 587,
  [1188] = 863,
  [1189] = 858,
  [1190] = 861,
  [1191] = 863,
  [1192] = 859,
  [1193] = 882,
  [1194] = 857,
  [1195] = 877,
  [1196] = 871,
  [1197] = 875,
  [1198] = 881,
  [1199] = 882,
  [1200] = 866,
  [1201] = 881,
  [1202] = 876,
  [1203] = 876,
  [1204] = 875,
  [1205] = 951,
  [1206] = 948,
  [1207] = 871,
  [1208] = 865,
  [1209] = 875,
  [1210] = 866,
  [1211] = 881,
  [1212] = 863,
  [1213] = 858,
  [1214] = 866,
  [1215] = 861,
  [1216] = 873,
  [1217] = 868,
  [1218] = 859,
  [1219] = 857,
  [1220] = 877,
  [1221] = 877,
  [1222] = 871,
  [1223] = 875,
  [1224] = 881,
  [1225] = 882,
  [1226] = 868,
  [1227] = 873,
  [1228] = 876,
  [1229] = 882,
  [1230] = 881,
  [1231] = 876,
  [1232] = 863,
  [1233] = 861,
  [1234] = 858,
  [1235] = 876,
  [1236] = 859,
  [1237] = 857,
  [1238] = 866,
  [1239] = 857,
  [1240] = 877,
  [1241] = 882,
  [1242] = 871,
  [1243] = 859,
  [1244] = 861,
  [1245] = 875,
  [1246] = 857,
  [1247] = 863,
  [1248] = 943,
  [1249] = 944,
  [1250] = 882,
  [1251] = 868,
  [1252] = 858,
  [1253] = 950,
  [1254] = 876,
  [1255] = 866,
  [1256] = 873,
  [1257] = 868,
  [1258] = 863,
  [1259] = 861,
  [1260] = 859,
  [1261] = 857,
  [1262] = 877,
  [1263] = 871,
  [1264] = 876,
  [1265] = 875,
  [1266] = 881,
  [1267] = 863,
  [1268] = 882,
  [1269] = 868,
  [1270] = 873,
  [1271] = 873,
  [1272] = 861,
  [1273] = 863,
  [1274] = 859,
  [1275] = 876,
  [1276] = 861,
  [1277] = 858,
  [1278] = 863,
  [1279] = 866,
  [1280] = 861,
  [1281] = 859,
  [1282] = 877,
  [1283] = 858,
  [1284] = 871,
  [1285] = 875,
  [1286] = 858,
  [1287] = 881,
  [1288] = 881,
  [1289] = 882,
  [1290] = 857,
  [1291] = 858,
  [1292] = 866,
  [1293] = 948,
  [1294] = 865,
  [1295] = 876,
  [1296] = 873,
  [1297] = 868,
  [1298] = 877,
  [1299] = 882,
  [1300] = 863,
  [1301] = 866,
  [1302] = 861,
  [1303] = 881,
  [1304] = 859,
  [1305] = 875,
  [1306] = 857,
  [1307] = 877,
  [1308] = 871,
  [1309] = 873,
  [1310] = 871,
  [1311] = 875,
  [1312] = 881,
  [1313] = 868,
  [1314] = 873,
  [1315] = 875,
  [1316] = 877,
  [1317] = 882,
  [1318] = 865,
  [1319] = 858,
  [1320] = 876,
  [1321] = 868,
  [1322] = 866,
  [1323] = 871,
  [1324] = 859,
  [1325] = 863,
  [1326] = 948,
  [1327] = 866,
  [1328] = 861,
  [1329] = 859,
  [1330] = 858,
  [1331] = 857,
  [1332] = 877,
  [1333] = 871,
  [1334] = 873,
  [1335] = 868,
  [1336] = 875,
  [1337] = 857,
  [1338] = 866,
  [1339] = 881,
  [1340] = 859,
  [1341] = 861,
  [1342] = 882,
  [1343] = 857,
  [1344] = 863,
  [1345] = 876,
  [1346] = 877,
  [1347] = 863,
  [1348] = 877,
  [1349] = 861,
  [1350] = 876,
  [1351] = 859,
  [1352] = 868,
  [1353] = 873,
  [1354] = 871,
  [1355] = 857,
  [1356] = 866,
  [1357] = 877,
  [1358] = 882,
  [1359] = 871,
  [1360] = 875,
  [1361] = 866,
  [1362] = 857,
  [1363] = 858,
  [1364] = 881,
  [1365] = 881,
  [1366] = 875,
  [1367] = 944,
  [1368] = 875,
  [1369] = 882,
  [1370] = 881,
  [1371] = 871,
  [1372] = 873,
  [1373] = 877,
  [1374] = 859,
  [1375] = 873,
  [1376] = 868,
  [1377] = 859,
  [1378] = 861,
  [1379] = 877,
  [1380] = 863,
  [1381] = 876,
  [1382] = 866,
  [1383] = 882,
  [1384] = 882,
  [1385] = 876,
  [1386] = 881,
  [1387] = 863,
  [1388] = 861,
  [1389] = 875,
  [1390] = 943,
  [1391] = 871,
  [1392] = 857,
  [1393] = 859,
  [1394] = 868,
  [1395] = 873,
  [1396] = 859,
  [1397] = 857,
  [1398] = 863,
  [1399] = 866,
  [1400] = 882,
  [1401] = 881,
  [1402] = 875,
  [1403] = 861,
  [1404] = 858,
  [1405] = 861,
  [1406] = 877,
  [1407] = 858,
  [1408] = 871,
  [1409] = 858,
  [1410] = 877,
  [1411] = 877,
  [1412] = 873,
  [1413] = 868,
  [1414] = 857,
  [1415] = 859,
  [1416] = 861,
  [1417] = 863,
  [1418] = 871,
  [1419] = 866,
  [1420] = 875,
  [1421] = 881,
  [1422] = 876,
  [1423] = 882,
  [1424] = 857,
  [1425] = 882,
  [1426] = 859,
  [1427] = 861,
  [1428] = 863,
  [1429] = 881,
  [1430] = 863,
  [1431] = 873,
  [1432] = 876,
  [1433] = 875,
  [1434] = 868,
  [1435] = 873,
  [1436] = 868,
  [1437] = 871,
  [1438] = 866,
  [1439] = 863,
  [1440] = 943,
  [1441] = 876,
  [1442] = 868,
  [1443] = 877,
  [1444] = 857,
  [1445] = 871,
  [1446] = 858,
  [1447] = 859,
  [1448] = 863,
  [1449] = 858,
  [1450] = 861,
  [1451] = 873,
  [1452] = 868,
  [1453] = 859,
  [1454] = 873,
  [1455] = 861,
  [1456] = 857,
  [1457] = 863,
  [1458] = 876,
  [1459] = 877,
  [1460] = 858,
  [1461] = 950,
  [1462] = 866,
  [1463] = 877,
  [1464] = 882,
  [1465] = 881,
  [1466] = 875,
  [1467] = 882,
  [1468] = 881,
  [1469] = 871,
  [1470] = 871,
  [1471] = 875,
  [1472] = 875,
  [1473] = 866,
  [1474] = 871,
  [1475] = 876,
  [1476] = 875,
  [1477] = 881,
  [1478] = 868,
  [1479] = 877,
  [1480] = 873,
  [1481] = 896,
  [1482] = 857,
  [1483] = 859,
  [1484] = 944,
  [1485] = 882,
  [1486] = 858,
  [1487] = 858,
  [1488] = 861,
  [1489] = 863,
  [1490] = 876,
  [1491] = 873,
  [1492] = 868,
  [1493] = 901,
  [1494] = 905,
  [1495] = 877,
  [1496] = 881,
  [1497] = 876,
  [1498] = 871,
  [1499] = 876,
  [1500] = 875,
  [1501] = 882,
  [1502] = 866,
  [1503] = 863,
  [1504] = 861,
  [1505] = 859,
  [1506] = 857,
  [1507] = 881,
  [1508] = 857,
  [1509] = 863,
  [1510] = 896,
  [1511] = 859,
  [1512] = 927,
  [1513] = 901,
  [1514] = 861,
  [1515] = 863,
  [1516] = 866,
  [1517] = 905,
  [1518] = 875,
  [1519] = 871,
  [1520] = 868,
  [1521] = 881,
  [1522] = 873,
  [1523] = 877,
  [1524] = 861,
  [1525] = 859,
  [1526] = 877,
  [1527] = 857,
  [1528] = 857,
  [1529] = 876,
  [1530] = 859,
  [1531] = 858,
  [1532] = 861,
  [1533] = 927,
  [1534] = 858,
  [1535] = 873,
  [1536] = 868,
  [1537] = 863,
  [1538] = 877,
  [1539] = 882,
  [1540] = 866,
  [1541] = 871,
  [1542] = 875,
  [1543] = 881,
  [1544] = 866,
  [1545] = 876,
  [1546] = 882,
  [1547] = 866,
  [1548] = 871,
  [1549] = 882,
  [1550] = 882,
  [1551] = 881,
  [1552] = 875,
  [1553] = 871,
  [1554] = 876,
  [1555] = 882,
  [1556] = 875,
  [1557] = 868,
  [1558] = 873,
  [1559] = 881,
  [1560] = 872,
  [1561] = 877,
  [1562] = 866,
  [1563] = 881,
  [1564] = 881,
  [1565] = 875,
  [1566] = 875,
  [1567] = 871,
  [1568] = 861,
  [1569] = 871,
  [1570] = 859,
  [1571] = 857,
  [1572] = 858,
  [1573] = 857,
  [1574] = 858,
  [1575] = 882,
  [1576] = 873,
  [1577] = 868,
  [1578] = 882,
  [1579] = 872,
  [1580] = 859,
  [1581] = 861,
  [1582] = 863,
  [1583] = 877,
  [1584] = 876,
  [1585] = 858,
  [1586] = 866,
  [1587] = 877,
  [1588] = 871,
  [1589] = 875,
  [1590] = 877,
  [1591] = 876,
  [1592] = 881,
  [1593] = 882,
  [1594] = 881,
  [1595] = 882,
  [1596] = 868,
  [1597] = 873,
  [1598] = 873,
  [1599] = 875,
  [1600] = 871,
  [1601] = 857,
  [1602] = 877,
  [1603] = 858,
  [1604] = 868,
  [1605] = 866,
  [1606] = 873,
  [1607] = 857,
  [1608] = 868,
  [1609] = 859,
  [1610] = 861,
  [1611] = 876,
  [1612] = 863,
  [1613] = 863,
  [1614] = 865,
  [1615] = 858,
  [1616] = 951,
  [1617] = 859,
  [1618] = 861,
  [1619] = 863,
  [1620] = 873,
  [1621] = 863,
  [1622] = 861,
  [1623] = 866,
  [1624] = 948,
  [1625] = 857,
  [1626] = 859,
  [1627] = 868,
  [1628] = 876,
  [1629] = 857,
  [1630] = 861,
  [1631] = 876,
  [1632] = 877,
  [1633] = 871,
  [1634] = 876,
  [1635] = 857,
  [1636] = 868,
  [1637] = 873,
  [1638] = 858,
  [1639] = 875,
  [1640] = 881,
  [1641] = 882,
  [1642] = 858,
  [1643] = 858,
  [1644] = 876,
  [1645] = 859,
  [1646] = 882,
  [1647] = 882,
  [1648] = 881,
  [1649] = 875,
  [1650] = 871,
  [1651] = 876,
  [1652] = 877,
  [1653] = 859,
  [1654] = 881,
  [1655] = 866,
  [1656] = 861,
  [1657] = 863,
  [1658] = 866,
  [1659] = 861,
  [1660] = 875,
  [1661] = 871,
  [1662] = 859,
  [1663] = 857,
  [1664] = 857,
  [1665] = 857,
  [1666] = 859,
  [1667] = 861,
  [1668] = 863,
  [1669] = 858,
  [1670] = 877,
  [1671] = 859,
  [1672] = 876,
  [1673] = 873,
  [1674] = 868,
  [1675] = 951,
  [1676] = 868,
  [1677] = 873,
  [1678] = 876,
  [1679] = 861,
  [1680] = 871,
  [1681] = 877,
  [1682] = 875,
  [1683] = 881,
  [1684] = 858,
  [1685] = 863,
  [1686] = 882,
  [1687] = 863,
  [1688] = 863,
  [1689] = 882,
  [1690] = 881,
  [1691] = 875,
  [1692] = 871,
  [1693] = 876,
  [1694] = 857,
  [1695] = 861,
  [1696] = 950,
  [1697] = 866,
  [1698] = 877,
  [1699] = 866,
  [1700] = 859,
  [1701] = 579,
  [1702] = 579,
  [1703] = 1703,
  [1704] = 1703,
  [1705] = 1703,
  [1706] = 1703,
  [1707] = 579,
  [1708] = 1703,
  [1709] = 579,
  [1710] = 1703,
  [1711] = 1703,
  [1712] = 1703,
  [1713] = 1703,
  [1714] = 1703,
  [1715] = 1703,
  [1716] = 1703,
  [1717] = 1703,
  [1718] = 1703,
  [1719] = 579,
  [1720] = 1703,
  [1721] = 1703,
  [1722] = 579,
  [1723] = 1703,
  [1724] = 1703,
  [1725] = 1703,
  [1726] = 1703,
  [1727] = 1703,
  [1728] = 579,
  [1729] = 579,
  [1730] = 1703,
  [1731] = 1703,
  [1732] = 1703,
  [1733] = 1703,
  [1734] = 1703,
  [1735] = 1703,
  [1736] = 1703,
  [1737] = 1703,
  [1738] = 1703,
  [1739] = 1703,
  [1740] = 579,
  [1741] = 1703,
  [1742] = 579,
  [1743] = 1703,
  [1744] = 1703,
  [1745] = 579,
  [1746] = 1703,
  [1747] = 1703,
  [1748] = 1703,
  [1749] = 1703,
  [1750] = 1703,
  [1751] = 1703,
  [1752] = 579,
  [1753] = 1703,
  [1754] = 1703,
  [1755] = 1703,
  [1756] = 579,
  [1757] = 1703,
  [1758] = 1703,
  [1759] = 1703,
  [1760] = 1703,
  [1761] = 1703,
  [1762] = 1703,
  [1763] = 1703,
  [1764] = 1703,
  [1765] = 1703,
  [1766] = 1703,
  [1767] = 1703,
  [1768] = 1703,
  [1769] = 1703,
  [1770] = 1703,
  [1771] = 579,
  [1772] = 1703,
  [1773] = 1703,
  [1774] = 1703,
  [1775] = 1703,
  [1776] = 1703,
  [1777] = 1703,
  [1778] = 1703,
  [1779] = 1703,
  [1780] = 1703,
  [1781] = 1703,
  [1782] = 579,
  [1783] = 1703,
  [1784] = 1703,
  [1785] = 1703,
  [1786] = 579,
  [1787] = 1703,
  [1788] = 1703,
  [1789] = 1703,
  [1790] = 579,
  [1791] = 587,
  [1792] = 1703,
  [1793] = 1703,
  [1794] = 1703,
  [1795] = 1703,
  [1796] = 1703,
  [1797] = 1703,
  [1798] = 1703,
  [1799] = 579,
  [1800] = 1703,
  [1801] = 1703,
  [1802] = 1703,
  [1803] = 579,
  [1804] = 1703,
  [1805] = 1703,
  [1806] = 1703,
  [1807] = 1703,
  [1808] = 1703,
  [1809] = 1703,
  [1810] = 1703,
  [1811] = 1703,
  [1812] = 1703,
  [1813] = 579,
  [1814] = 1703,
  [1815] = 1703,
  [1816] = 1703,
  [1817] = 1703,
  [1818] = 1703,
  [1819] = 579,
  [1820] = 1703,
  [1821] = 1703,
  [1822] = 1703,
  [1823] = 1703,
  [1824] = 1703,
  [1825] = 1703,
  [1826] = 1703,
  [1827] = 1703,
  [1828] = 579,
  [1829] = 1703,
  [1830] = 1703,
  [1831] = 1703,
  [1832] = 1703,
  [1833] = 1703,
  [1834] = 1703,
  [1835] = 579,
  [1836] = 1703,
  [1837] = 1703,
  [1838] = 1703,
  [1839] = 1703,
  [1840] = 587,
  [1841] = 1703,
  [1842] = 1703,
  [1843] = 1703,
  [1844] = 1703,
  [1845] = 1703,
  [1846] = 1703,
  [1847] = 579,
  [1848] = 1703,
  [1849] = 1703,
  [1850] = 1703,
  [1851] = 1703,
  [1852] = 579,
  [1853] = 1703,
  [1854] = 1703,
  [1855] = 1703,
  [1856] = 1703,
  [1857] = 1857,
  [1858] = 1857,
  [1859] = 1857,
  [1860] = 1857,
  [1861] = 1857,
  [1862] = 1857,
  [1863] = 1857,
  [1864] = 1857,
  [1865] = 1857,
  [1866] = 1857,
  [1867] = 1857,
  [1868] = 1857,
  [1869] = 1857,
  [1870] = 1857,
  [1871] = 1857,
  [1872] = 1857,
  [1873] = 1857,
  [1874] = 1857,
  [1875] = 587,
  [1876] = 1857,
  [1877] = 1857,
  [1878] = 1857,
  [1879] = 1857,
  [1880] = 1857,
  [1881] = 1857,
  [1882] = 587,
  [1883] = 1857,
  [1884] = 1857,
  [1885] = 1857,
  [1886] = 1886,
  [1887] = 1886,
  [1888] = 1886,
  [1889] = 1889,
  [1890] = 1889,
  [1891] = 1886,
  [1892] = 1886,
  [1893] = 1893,
  [1894] = 1886,
  [1895] = 1886,
  [1896] = 1886,
  [1897] = 1889,
  [1898] = 1886,
  [1899] = 1886,
  [1900] = 1886,
  [1901] = 1893,
  [1902] = 1886,
  [1903] = 1889,
  [1904] = 1886,
  [1905] = 1889,
  [1906] = 1886,
  [1907] = 1889,
  [1908] = 1889,
  [1909] = 1893,
  [1910] = 1886,
  [1911] = 1893,
  [1912] = 1886,
  [1913] = 1886,
  [1914] = 1886,
  [1915] = 1889,
  [1916] = 1886,
  [1917] = 1886,
  [1918] = 1889,
  [1919] = 1886,
  [1920] = 1889,
  [1921] = 1889,
  [1922] = 1886,
  [1923] = 1886,
  [1924] = 1886,
  [1925] = 1886,
  [1926] = 1886,
  [1927] = 1889,
  [1928] = 1893,
  [1929] = 1889,
  [1930] = 1893,
  [1931] = 1886,
  [1932] = 1889,
  [1933] = 1886,
  [1934] = 1886,
  [1935] = 1886,
  [1936] = 1889,
  [1937] = 1886,
  [1938] = 1886,
  [1939] = 1889,
  [1940] = 1889,
  [1941] = 1893,
  [1942] = 1889,
  [1943] = 1889,
  [1944] = 1886,
  [1945] = 1889,
  [1946] = 1886,
  [1947] = 1886,
  [1948] = 1886,
  [1949] = 1889,
  [1950] = 1889,
  [1951] = 1886,
  [1952] = 1893,
  [1953] = 1886,
  [1954] = 1886,
  [1955] = 1886,
  [1956] = 1886,
  [1957] = 1893,
  [1958] = 1886,
  [1959] = 1889,
  [1960] = 1886,
  [1961] = 1886,
  [1962] = 1886,
  [1963] = 1889,
  [1964] = 1889,
  [1965] = 1893,
  [1966] = 1889,
  [1967] = 1886,
  [1968] = 1886,
  [1969] = 1889,
  [1970] = 1886,
  [1971] = 1893,
  [1972] = 1886,
  [1973] = 1886,
  [1974] = 1889,
  [1975] = 1889,
  [1976] = 1889,
  [1977] = 1889,
  [1978] = 1886,
  [1979] = 1886,
  [1980] = 1886,
  [1981] = 1893,
  [1982] = 1886,
  [1983] = 1886,
  [1984] = 1886,
  [1985] = 1886,
  [1986] = 1889,
  [1987] = 1889,
  [1988] = 1886,
  [1989] = 1886,
  [1990] = 1889,
  [1991] = 1886,
  [1992] = 1886,
  [1993] = 1886,
  [1994] = 1886,
  [1995] = 1893,
  [1996] = 1889,
  [1997] = 1893,
  [1998] = 1886,
  [1999] = 1886,
  [2000] = 1886,
  [2001] = 1886,
  [2002] = 1889,
  [2003] = 1886,
  [2004] = 1889,
  [2005] = 1886,
  [2006] = 1886,
  [2007] = 1889,
  [2008] = 1886,
  [2009] = 1893,
  [2010] = 1889,
  [2011] = 1886,
  [2012] = 1886,
  [2013] = 1889,
  [2014] = 1886,
  [2015] = 1886,
  [2016] = 1886,
  [2017] = 1886,
  [2018] = 1886,
  [2019] = 1886,
  [2020] = 1886,
  [2021] = 1893,
  [2022] = 1886,
  [2023] = 1889,
  [2024] = 1889,
  [2025] = 1886,
  [2026] = 1886,
  [2027] = 1886,
  [2028] = 1893,
  [2029] = 1893,
  [2030] = 1886,
  [2031] = 1889,
  [2032] = 1889,
  [2033] = 2033,
  [2034] = 1889,
  [2035] = 1889,
  [2036] = 1886,
  [2037] = 1886,
  [2038] = 1889,
  [2039] = 1886,
  [2040] = 1886,
  [2041] = 1893,
  [2042] = 1886,
  [2043] = 1889,
  [2044] = 1886,
  [2045] = 1886,
  [2046] = 1886,
  [2047] = 1886,
  [2048] = 1886,
  [2049] = 1886,
  [2050] = 1886,
  [2051] = 1886,
  [2052] = 1889,
  [2053] = 1886,
  [2054] = 1889,
  [2055] = 2055,
  [2056] = 1889,
  [2057] = 1886,
  [2058] = 1893,
  [2059] = 1893,
  [2060] = 1886,
  [2061] = 1886,
  [2062] = 1893,
  [2063] = 1886,
  [2064] = 1886,
  [2065] = 1886,
  [2066] = 1886,
  [2067] = 1886,
  [2068] = 1886,
  [2069] = 1886,
  [2070] = 1889,
  [2071] = 1886,
  [2072] = 1886,
  [2073] = 1886,
  [2074] = 1886,
  [2075] = 1886,
  [2076] = 1889,
  [2077] = 1886,
  [2078] = 1886,
  [2079] = 1893,
  [2080] = 1889,
  [2081] = 1886,
  [2082] = 1886,
  [2083] = 1886,
  [2084] = 1886,
  [2085] = 1886,
  [2086] = 1886,
  [2087] = 1893,
  [2088] = 1886,
  [2089] = 1889,
  [2090] = 1893,
  [2091] = 1886,
  [2092] = 1886,
  [2093] = 1886,
  [2094] = 1886,
  [2095] = 1889,
  [2096] = 1886,
  [2097] = 1886,
  [2098] = 2098,
  [2099] = 2099,
  [2100] = 2099,
  [2101] = 2101,
  [2102] = 2102,
  [2103] = 2098,
  [2104] = 2104,
  [2105] = 2098,
  [2106] = 2106,
  [2107] = 2107,
  [2108] = 2104,
  [2109] = 2109,
  [2110] = 2110,
  [2111] = 2111,
  [2112] = 2112,
  [2113] = 2098,
  [2114] = 2098,
  [2115] = 2111,
  [2116] = 2107,
  [2117] = 2109,
  [2118] = 2109,
  [2119] = 2104,
  [2120] = 2109,
  [2121] = 2112,
  [2122] = 2104,
  [2123] = 2106,
  [2124] = 2098,
  [2125] = 2098,
  [2126] = 2104,
  [2127] = 2104,
  [2128] = 2109,
  [2129] = 2111,
  [2130] = 2098,
  [2131] = 2107,
  [2132] = 2104,
  [2133] = 2104,
  [2134] = 2109,
  [2135] = 2104,
  [2136] = 2112,
  [2137] = 2106,
  [2138] = 2104,
  [2139] = 2109,
  [2140] = 2098,
  [2141] = 2112,
  [2142] = 2109,
  [2143] = 2111,
  [2144] = 2098,
  [2145] = 2107,
  [2146] = 2111,
  [2147] = 2098,
  [2148] = 2104,
  [2149] = 2104,
  [2150] = 2106,
  [2151] = 2106,
  [2152] = 2098,
  [2153] = 2099,
  [2154] = 2154,
  [2155] = 2104,
  [2156] = 2110,
  [2157] = 2098,
  [2158] = 2109,
  [2159] = 2107,
  [2160] = 2160,
  [2161] = 2104,
  [2162] = 2104,
  [2163] = 2112,
  [2164] = 2098,
  [2165] = 2098,
  [2166] = 2109,
  [2167] = 2167,
  [2168] = 2104,
  [2169] = 2107,
  [2170] = 2099,
  [2171] = 2098,
  [2172] = 2112,
  [2173] = 2109,
  [2174] = 2104,
  [2175] = 2099,
  [2176] = 2160,
  [2177] = 2109,
  [2178] = 2111,
  [2179] = 2112,
  [2180] = 2104,
  [2181] = 2104,
  [2182] = 2104,
  [2183] = 2099,
  [2184] = 2112,
  [2185] = 2112,
  [2186] = 2104,
  [2187] = 2109,
  [2188] = 2109,
  [2189] = 2098,
  [2190] = 2111,
  [2191] = 2106,
  [2192] = 2107,
  [2193] = 2109,
  [2194] = 2106,
  [2195] = 2112,
  [2196] = 2104,
  [2197] = 2107,
  [2198] = 2111,
  [2199] = 2107,
  [2200] = 2104,
  [2201] = 2099,
  [2202] = 2106,
  [2203] = 2110,
  [2204] = 2204,
  [2205] = 2098,
  [2206] = 2109,
  [2207] = 2098,
  [2208] = 2104,
  [2209] = 2111,
  [2210] = 2109,
  [2211] = 2211,
  [2212] = 2109,
  [2213] = 2098,
  [2214] = 2109,
  [2215] = 2104,
  [2216] = 2098,
  [2217] = 2109,
  [2218] = 2104,
  [2219] = 2109,
  [2220] = 2109,
  [2221] = 2099,
  [2222] = 2112,
  [2223] = 2106,
  [2224] = 2098,
  [2225] = 2109,
  [2226] = 2104,
  [2227] = 2112,
  [2228] = 2111,
  [2229] = 2109,
  [2230] = 2112,
  [2231] = 2109,
  [2232] = 2111,
  [2233] = 2107,
  [2234] = 2107,
  [2235] = 2112,
  [2236] = 2109,
  [2237] = 2098,
  [2238] = 2111,
  [2239] = 2098,
  [2240] = 2167,
  [2241] = 2241,
  [2242] = 2106,
  [2243] = 2112,
  [2244] = 2104,
  [2245] = 2109,
  [2246] = 2109,
  [2247] = 2098,
  [2248] = 2112,
  [2249] = 2098,
  [2250] = 2099,
  [2251] = 2106,
  [2252] = 2106,
  [2253] = 2098,
  [2254] = 2112,
  [2255] = 2099,
  [2256] = 2112,
  [2257] = 2104,
  [2258] = 2099,
  [2259] = 2259,
  [2260] = 2104,
  [2261] = 2098,
  [2262] = 2098,
  [2263] = 2112,
  [2264] = 2109,
  [2265] = 2098,
  [2266] = 2104,
  [2267] = 2111,
  [2268] = 2107,
  [2269] = 2107,
  [2270] = 2098,
  [2271] = 2271,
  [2272] = 2104,
  [2273] = 2104,
  [2274] = 2104,
  [2275] = 2109,
  [2276] = 2104,
  [2277] = 2106,
  [2278] = 2099,
  [2279] = 2104,
  [2280] = 2104,
  [2281] = 2109,
  [2282] = 2098,
  [2283] = 2112,
  [2284] = 2098,
  [2285] = 2107,
  [2286] = 2109,
  [2287] = 2109,
  [2288] = 2112,
  [2289] = 2104,
  [2290] = 2098,
  [2291] = 2111,
  [2292] = 2112,
  [2293] = 2111,
  [2294] = 2107,
  [2295] = 2295,
  [2296] = 2106,
  [2297] = 2098,
  [2298] = 2099,
  [2299] = 2299,
  [2300] = 2107,
  [2301] = 2104,
  [2302] = 2109,
  [2303] = 2099,
  [2304] = 2104,
  [2305] = 2109,
  [2306] = 2112,
  [2307] = 2109,
  [2308] = 2098,
  [2309] = 2098,
  [2310] = 2112,
  [2311] = 2111,
  [2312] = 2312,
  [2313] = 2099,
  [2314] = 2112,
  [2315] = 2111,
  [2316] = 2112,
  [2317] = 2160,
  [2318] = 2109,
  [2319] = 2109,
  [2320] = 2112,
  [2321] = 2112,
  [2322] = 2099,
  [2323] = 2098,
  [2324] = 2107,
  [2325] = 2098,
  [2326] = 2104,
  [2327] = 2109,
  [2328] = 2104,
  [2329] = 2109,
  [2330] = 2107,
  [2331] = 2106,
  [2332] = 2109,
  [2333] = 2109,
  [2334] = 2111,
  [2335] = 2098,
  [2336] = 2112,
  [2337] = 2098,
  [2338] = 2104,
  [2339] = 2111,
  [2340] = 2098,
  [2341] = 2107,
  [2342] = 2167,
  [2343] = 2112,
  [2344] = 2098,
  [2345] = 2098,
  [2346] = 2109,
  [2347] = 2098,
  [2348] = 2107,
  [2349] = 2107,
  [2350] = 2111,
  [2351] = 2112,
  [2352] = 2104,
  [2353] = 2109,
  [2354] = 2109,
  [2355] = 2098,
  [2356] = 2104,
  [2357] = 2109,
  [2358] = 2106,
  [2359] = 2107,
  [2360] = 2104,
  [2361] = 2104,
  [2362] = 2111,
  [2363] = 2109,
  [2364] = 2098,
  [2365] = 2098,
  [2366] = 2111,
  [2367] = 2098,
  [2368] = 2111,
  [2369] = 2107,
  [2370] = 2106,
  [2371] = 2109,
  [2372] = 2104,
  [2373] = 2104,
  [2374] = 2109,
  [2375] = 2111,
  [2376] = 2098,
  [2377] = 2098,
  [2378] = 2112,
  [2379] = 2104,
  [2380] = 2104,
  [2381] = 2111,
  [2382] = 2107,
  [2383] = 2098,
  [2384] = 2107,
  [2385] = 2109,
  [2386] = 2109,
  [2387] = 2109,
  [2388] = 2098,
  [2389] = 2111,
  [2390] = 2098,
  [2391] = 2109,
  [2392] = 2109,
  [2393] = 2099,
  [2394] = 2104,
  [2395] = 2104,
  [2396] = 2109,
  [2397] = 2107,
  [2398] = 2112,
  [2399] = 2111,
  [2400] = 2104,
  [2401] = 2099,
  [2402] = 2112,
  [2403] = 2112,
  [2404] = 2104,
  [2405] = 2106,
  [2406] = 2109,
  [2407] = 2098,
  [2408] = 2408,
  [2409] = 2098,
  [2410] = 2104,
  [2411] = 2112,
  [2412] = 2412,
  [2413] = 2412,
  [2414] = 2412,
  [2415] = 2415,
  [2416] = 2415,
  [2417] = 2415,
  [2418] = 2415,
  [2419] = 2415,
  [2420] = 2415,
  [2421] = 2415,
  [2422] = 2415,
  [2423] = 2415,
  [2424] = 2415,
  [2425] = 2415,
  [2426] = 2415,
  [2427] = 2415,
  [2428] = 2415,
  [2429] = 2415,
  [2430] = 2415,
  [2431] = 2415,
  [2432] = 2415,
  [2433] = 2415,
  [2434] = 2415,
  [2435] = 2415,
  [2436] = 2415,
  [2437] = 2415,
  [2438] = 2415,
  [2439] = 2415,
  [2440] = 2415,
  [2441] = 2415,
  [2442] = 2415,
  [2443] = 2415,
  [2444] = 2415,
  [2445] = 2415,
  [2446] = 2415,
  [2447] = 2415,
  [2448] = 2415,
  [2449] = 2415,
  [2450] = 2415,
  [2451] = 2415,
  [2452] = 2415,
  [2453] = 2415,
  [2454] = 2415,
  [2455] = 2415,
  [2456] = 2415,
  [2457] = 2415,
  [2458] = 2415,
  [2459] = 2415,
  [2460] = 2415,
  [2461] = 2415,
  [2462] = 2415,
  [2463] = 2463,
  [2464] = 2464,
  [2465] = 2465,
  [2466] = 2464,
  [2467] = 2467,
  [2468] = 2467,
  [2469] = 2463,
  [2470] = 2470,
  [2471] = 2470,
  [2472] = 2472,
  [2473] = 2467,
  [2474] = 2470,
  [2475] = 2475,
  [2476] = 2475,
  [2477] = 2475,
  [2478] = 2475,
  [2479] = 2475,
  [2480] = 2475,
  [2481] = 2475,
  [2482] = 2475,
  [2483] = 2475,
  [2484] = 2475,
  [2485] = 2475,
  [2486] = 2475,
  [2487] = 2475,
  [2488] = 2475,
  [2489] = 2475,
  [2490] = 2475,
  [2491] = 2475,
  [2492] = 2475,
  [2493] = 2475,
  [2494] = 2475,
  [2495] = 2475,
  [2496] = 2475,
  [2497] = 2475,
  [2498] = 2475,
  [2499] = 2499,
  [2500] = 2500,
  [2501] = 2500,
  [2502] = 2500,
  [2503] = 2500,
  [2504] = 2499,
  [2505] = 2499,
  [2506] = 2499,
  [2507] = 2499,
  [2508] = 2508,
  [2509] = 2500,
  [2510] = 2500,
  [2511] = 2500,
  [2512] = 2500,
  [2513] = 2499,
  [2514] = 2500,
  [2515] = 2508,
  [2516] = 2499,
  [2517] = 2500,
  [2518] = 2500,
  [2519] = 2499,
  [2520] = 2499,
  [2521] = 2500,
  [2522] = 2499,
  [2523] = 2500,
  [2524] = 2500,
  [2525] = 2500,
  [2526] = 2499,
  [2527] = 2499,
  [2528] = 2499,
  [2529] = 2499,
  [2530] = 2500,
  [2531] = 2499,
  [2532] = 2500,
  [2533] = 2499,
  [2534] = 2500,
  [2535] = 2499,
  [2536] = 2499,
  [2537] = 2500,
  [2538] = 2499,
  [2539] = 2499,
  [2540] = 2508,
  [2541] = 2500,
  [2542] = 2499,
  [2543] = 2499,
  [2544] = 2500,
  [2545] = 2500,
  [2546] = 2499,
  [2547] = 2499,
  [2548] = 2500,
  [2549] = 2500,
  [2550] = 2500,
  [2551] = 2499,
  [2552] = 2552,
  [2553] = 2499,
  [2554] = 2499,
  [2555] = 2500,
  [2556] = 2500,
  [2557] = 2500,
  [2558] = 2499,
  [2559] = 2500,
  [2560] = 2499,
  [2561] = 2499,
  [2562] = 2500,
  [2563] = 2499,
  [2564] = 2499,
  [2565] = 2500,
  [2566] = 2566,
  [2567] = 2500,
  [2568] = 2566,
  [2569] = 2500,
  [2570] = 2500,
  [2571] = 2499,
  [2572] = 2499,
  [2573] = 2499,
  [2574] = 2499,
  [2575] = 2500,
  [2576] = 2500,
  [2577] = 2499,
  [2578] = 2500,
  [2579] = 2500,
  [2580] = 2500,
  [2581] = 2500,
  [2582] = 2499,
  [2583] = 2500,
  [2584] = 2499,
  [2585] = 2499,
  [2586] = 2499,
  [2587] = 2499,
  [2588] = 2499,
  [2589] = 2500,
  [2590] = 2499,
  [2591] = 2500,
  [2592] = 2412,
  [2593] = 2500,
  [2594] = 2500,
  [2595] = 2499,
  [2596] = 2499,
  [2597] = 2500,
  [2598] = 2500,
  [2599] = 2500,
  [2600] = 2499,
  [2601] = 2499,
  [2602] = 2500,
  [2603] = 2499,
  [2604] = 2499,
  [2605] = 2499,
  [2606] = 2500,
  [2607] = 2500,
  [2608] = 2500,
  [2609] = 2499,
  [2610] = 2500,
  [2611] = 2499,
  [2612] = 2499,
  [2613] = 2500,
  [2614] = 2499,
  [2615] = 2566,
  [2616] = 2499,
  [2617] = 2500,
  [2618] = 2500,
  [2619] = 2499,
  [2620] = 2499,
  [2621] = 2621,
  [2622] = 2500,
  [2623] = 2500,
  [2624] = 2500,
  [2625] = 2499,
  [2626] = 2499,
  [2627] = 2499,
  [2628] = 2499,
  [2629] = 2500,
  [2630] = 2500,
  [2631] = 2499,
  [2632] = 2499,
  [2633] = 2500,
  [2634] = 2499,
  [2635] = 2500,
  [2636] = 2500,
  [2637] = 2500,
  [2638] = 2638,
  [2639] = 2639,
  [2640] = 2412,
  [2641] = 2641,
  [2642] = 2642,
  [2643] = 2643,
  [2644] = 2644,
  [2645] = 2645,
  [2646] = 2646,
  [2647] = 2412,
  [2648] = 2648,
  [2649] = 2649,
  [2650] = 2412,
  [2651] = 2651,
  [2652] = 2412,
  [2653] = 2412,
  [2654] = 2412,
  [2655] = 2655,
  [2656] = 2656,
  [2657] = 2656,
  [2658] = 2658,
  [2659] = 2658,
  [2660] = 2660,
  [2661] = 2656,
  [2662] = 2658,
  [2663] = 2655,
  [2664] = 2658,
  [2665] = 2656,
  [2666] = 2655,
  [2667] = 2655,
  [2668] = 2660,
  [2669] = 2660,
  [2670] = 2656,
  [2671] = 2655,
  [2672] = 2658,
  [2673] = 2658,
  [2674] = 2660,
  [2675] = 2658,
  [2676] = 2655,
  [2677] = 2655,
  [2678] = 2660,
  [2679] = 2655,
  [2680] = 2658,
  [2681] = 2655,
  [2682] = 2660,
  [2683] = 2656,
  [2684] = 2655,
  [2685] = 2658,
  [2686] = 2660,
  [2687] = 2660,
  [2688] = 2412,
  [2689] = 2656,
  [2690] = 2656,
  [2691] = 2656,
  [2692] = 2656,
  [2693] = 2656,
  [2694] = 2660,
  [2695] = 2660,
  [2696] = 2658,
  [2697] = 2656,
  [2698] = 2655,
  [2699] = 2658,
  [2700] = 2660,
  [2701] = 2660,
  [2702] = 2660,
  [2703] = 2656,
  [2704] = 2660,
  [2705] = 2658,
  [2706] = 2656,
  [2707] = 2655,
  [2708] = 2658,
  [2709] = 2655,
  [2710] = 2658,
  [2711] = 2658,
  [2712] = 2656,
  [2713] = 2655,
  [2714] = 2655,
  [2715] = 2660,
  [2716] = 2658,
  [2717] = 2655,
  [2718] = 2656,
  [2719] = 2656,
  [2720] = 2660,
  [2721] = 2660,
  [2722] = 2660,
  [2723] = 2660,
  [2724] = 2656,
  [2725] = 2656,
  [2726] = 2658,
  [2727] = 2658,
  [2728] = 2658,
  [2729] = 2655,
  [2730] = 2656,
  [2731] = 2655,
  [2732] = 2656,
  [2733] = 2655,
  [2734] = 2655,
  [2735] = 2658,
  [2736] = 2660,
  [2737] = 2658,
  [2738] = 2655,
  [2739] = 2655,
  [2740] = 2660,
  [2741] = 2658,
  [2742] = 2655,
  [2743] = 2655,
  [2744] = 2655,
  [2745] = 2656,
  [2746] = 2655,
  [2747] = 2660,
  [2748] = 2656,
  [2749] = 2658,
  [2750] = 2660,
  [2751] = 2656,
  [2752] = 2656,
  [2753] = 2658,
  [2754] = 2656,
  [2755] = 2660,
  [2756] = 2660,
  [2757] = 2656,
  [2758] = 2656,
  [2759] = 2655,
  [2760] = 2660,
  [2761] = 2660,
  [2762] = 2656,
  [2763] = 2660,
  [2764] = 2656,
  [2765] = 2658,
  [2766] = 2658,
  [2767] = 2656,
  [2768] = 2658,
  [2769] = 2658,
  [2770] = 2412,
  [2771] = 2658,
  [2772] = 2655,
  [2773] = 2660,
  [2774] = 2660,
  [2775] = 2655,
  [2776] = 2660,
  [2777] = 2656,
  [2778] = 2660,
  [2779] = 2655,
  [2780] = 2658,
  [2781] = 2655,
  [2782] = 2656,
  [2783] = 2660,
  [2784] = 2658,
  [2785] = 2656,
  [2786] = 2656,
  [2787] = 2660,
  [2788] = 2658,
  [2789] = 2658,
  [2790] = 2656,
  [2791] = 2655,
  [2792] = 2655,
  [2793] = 2658,
  [2794] = 2658,
  [2795] = 2655,
  [2796] = 2655,
  [2797] = 2655,
  [2798] = 2656,
  [2799] = 2655,
  [2800] = 2655,
  [2801] = 2658,
  [2802] = 2660,
  [2803] = 2658,
  [2804] = 2660,
  [2805] = 2658,
  [2806] = 2656,
  [2807] = 2656,
  [2808] = 2660,
  [2809] = 2658,
  [2810] = 2656,
  [2811] = 2658,
  [2812] = 2655,
  [2813] = 2656,
  [2814] = 2660,
  [2815] = 2656,
  [2816] = 2658,
  [2817] = 2656,
  [2818] = 2660,
  [2819] = 2660,
  [2820] = 2656,
  [2821] = 2660,
  [2822] = 2658,
  [2823] = 2655,
  [2824] = 2660,
  [2825] = 2655,
  [2826] = 2660,
  [2827] = 2660,
  [2828] = 2656,
  [2829] = 2656,
  [2830] = 2660,
  [2831] = 2656,
  [2832] = 2655,
  [2833] = 2655,
  [2834] = 2655,
  [2835] = 2658,
  [2836] = 2658,
  [2837] = 2655,
  [2838] = 2658,
  [2839] = 2656,
  [2840] = 2658,
  [2841] = 2660,
  [2842] = 2658,
  [2843] = 2660,
  [2844] = 2656,
  [2845] = 2655,
  [2846] = 2656,
  [2847] = 2658,
  [2848] = 2660,
  [2849] = 2658,
  [2850] = 2658,
  [2851] = 2655,
  [2852] = 2658,
  [2853] = 2660,
  [2854] = 2660,
  [2855] = 2655,
  [2856] = 2660,
  [2857] = 2660,
  [2858] = 2655,
  [2859] = 2656,
  [2860] = 2660,
  [2861] = 2660,
  [2862] = 2655,
  [2863] = 2656,
  [2864] = 2656,
  [2865] = 2656,
  [2866] = 2655,
  [2867] = 2658,
  [2868] = 2658,
  [2869] = 2658,
  [2870] = 2655,
  [2871] = 2655,
  [2872] = 2658,
  [2873] = 2660,
  [2874] = 2660,
  [2875] = 2412,
  [2876] = 2658,
  [2877] = 2658,
  [2878] = 2660,
  [2879] = 2656,
  [2880] = 2655,
  [2881] = 2658,
  [2882] = 2660,
  [2883] = 2656,
  [2884] = 2658,
  [2885] = 2655,
  [2886] = 2660,
  [2887] = 2656,
  [2888] = 2656,
  [2889] = 2655,
  [2890] = 2655,
  [2891] = 2660,
  [2892] = 2655,
  [2893] = 2655,
  [2894] = 2660,
  [2895] = 2656,
  [2896] = 2656,
  [2897] = 2658,
  [2898] = 2660,
  [2899] = 2655,
  [2900] = 2656,
  [2901] = 2658,
  [2902] = 2658,
  [2903] = 2656,
  [2904] = 2412,
  [2905] = 2660,
  [2906] = 2660,
  [2907] = 2660,
  [2908] = 2655,
  [2909] = 2656,
  [2910] = 2658,
  [2911] = 2660,
  [2912] = 2658,
  [2913] = 2658,
  [2914] = 2660,
  [2915] = 2656,
  [2916] = 2655,
  [2917] = 2660,
  [2918] = 2656,
  [2919] = 2656,
  [2920] = 2655,
  [2921] = 2658,
  [2922] = 2658,
  [2923] = 2655,
  [2924] = 2656,
  [2925] = 2658,
  [2926] = 2655,
  [2927] = 2660,
  [2928] = 2658,
  [2929] = 2655,
  [2930] = 2658,
  [2931] = 2655,
  [2932] = 2656,
  [2933] = 2658,
  [2934] = 2658,
  [2935] = 2660,
  [2936] = 2660,
  [2937] = 2660,
  [2938] = 2658,
  [2939] = 2658,
  [2940] = 2655,
  [2941] = 2660,
  [2942] = 2655,
  [2943] = 2656,
  [2944] = 2658,
  [2945] = 2655,
  [2946] = 2660,
  [2947] = 2658,
  [2948] = 2658,
  [2949] = 2656,
  [2950] = 2656,
  [2951] = 2656,
  [2952] = 2658,
  [2953] = 2658,
  [2954] = 2656,
  [2955] = 2656,
  [2956] = 2655,
  [2957] = 2660,
  [2958] = 2660,
  [2959] = 2655,
  [2960] = 2656,
  [2961] = 2660,
  [2962] = 2660,
  [2963] = 2656,
  [2964] = 2660,
  [2965] = 2655,
  [2966] = 2660,
  [2967] = 2655,
  [2968] = 2656,
  [2969] = 2660,
  [2970] = 2658,
  [2971] = 2656,
  [2972] = 2658,
  [2973] = 2656,
  [2974] = 2655,
  [2975] = 2655,
  [2976] = 2660,
  [2977] = 2655,
  [2978] = 2660,
  [2979] = 2658,
  [2980] = 2658,
  [2981] = 2656,
  [2982] = 2658,
  [2983] = 2658,
  [2984] = 2658,
  [2985] = 2660,
  [2986] = 2655,
  [2987] = 2658,
  [2988] = 2658,
  [2989] = 2660,
  [2990] = 2655,
  [2991] = 2660,
  [2992] = 2656,
  [2993] = 2658,
  [2994] = 2658,
  [2995] = 2655,
  [2996] = 2656,
  [2997] = 2656,
  [2998] = 2656,
  [2999] = 2658,
  [3000] = 2660,
  [3001] = 2660,
  [3002] = 2660,
  [3003] = 2655,
  [3004] = 2660,
  [3005] = 2658,
  [3006] = 2656,
  [3007] = 2655,
  [3008] = 2655,
  [3009] = 2658,
  [3010] = 2656,
  [3011] = 2660,
  [3012] = 2658,
  [3013] = 2656,
  [3014] = 2660,
  [3015] = 2660,
  [3016] = 2658,
  [3017] = 2658,
  [3018] = 2656,
  [3019] = 2658,
  [3020] = 2658,
  [3021] = 2655,
  [3022] = 2660,
  [3023] = 2658,
  [3024] = 2655,
  [3025] = 2656,
  [3026] = 2660,
  [3027] = 2660,
  [3028] = 2660,
  [3029] = 2656,
  [3030] = 2658,
  [3031] = 2660,
  [3032] = 2660,
  [3033] = 2658,
  [3034] = 2655,
  [3035] = 2660,
  [3036] = 2660,
  [3037] = 2660,
  [3038] = 2660,
  [3039] = 2656,
  [3040] = 2655,
  [3041] = 2655,
  [3042] = 2656,
  [3043] = 2658,
  [3044] = 2655,
  [3045] = 2655,
  [3046] = 2658,
  [3047] = 2658,
  [3048] = 2655,
  [3049] = 2660,
  [3050] = 2658,
  [3051] = 2656,
  [3052] = 2658,
  [3053] = 2660,
  [3054] = 2656,
  [3055] = 2658,
  [3056] = 2660,
  [3057] = 2660,
  [3058] = 2658,
  [3059] = 2660,
  [3060] = 2655,
  [3061] = 2660,
  [3062] = 2660,
  [3063] = 2656,
  [3064] = 2656,
  [3065] = 2656,
  [3066] = 2658,
  [3067] = 2658,
  [3068] = 2655,
  [3069] = 2660,
  [3070] = 2658,
  [3071] = 2658,
  [3072] = 2658,
  [3073] = 2655,
  [3074] = 2658,
  [3075] = 2655,
  [3076] = 2655,
  [3077] = 2658,
  [3078] = 2655,
  [3079] = 2658,
  [3080] = 2655,
  [3081] = 2656,
  [3082] = 2656,
  [3083] = 2656,
  [3084] = 2655,
  [3085] = 2660,
  [3086] = 2660,
  [3087] = 2658,
  [3088] = 2660,
  [3089] = 2658,
  [3090] = 2655,
  [3091] = 2656,
  [3092] = 2658,
  [3093] = 2660,
  [3094] = 2658,
  [3095] = 2660,
  [3096] = 2660,
  [3097] = 2655,
  [3098] = 2660,
  [3099] = 2655,
  [3100] = 2658,
  [3101] = 2660,
  [3102] = 2656,
  [3103] = 2655,
  [3104] = 2655,
  [3105] = 2656,
  [3106] = 2660,
  [3107] = 2655,
  [3108] = 2660,
  [3109] = 2655,
  [3110] = 2658,
  [3111] = 2658,
  [3112] = 2658,
  [3113] = 2660,
  [3114] = 2660,
  [3115] = 2658,
  [3116] = 2658,
  [3117] = 2660,
  [3118] = 2656,
  [3119] = 2660,
  [3120] = 2656,
  [3121] = 2660,
  [3122] = 2658,
  [3123] = 2660,
  [3124] = 2656,
  [3125] = 2660,
  [3126] = 2658,
  [3127] = 2660,
  [3128] = 2655,
  [3129] = 2658,
  [3130] = 2656,
  [3131] = 2658,
  [3132] = 2656,
  [3133] = 2655,
  [3134] = 2658,
  [3135] = 2658,
  [3136] = 2656,
  [3137] = 2660,
  [3138] = 2660,
  [3139] = 2655,
  [3140] = 2658,
  [3141] = 2656,
  [3142] = 2656,
  [3143] = 2656,
  [3144] = 2658,
  [3145] = 2656,
  [3146] = 2655,
  [3147] = 2655,
  [3148] = 2660,
  [3149] = 2656,
  [3150] = 2655,
  [3151] = 2660,
  [3152] = 2658,
  [3153] = 2660,
  [3154] = 2658,
  [3155] = 2660,
  [3156] = 2655,
  [3157] = 2660,
  [3158] = 2655,
  [3159] = 2656,
  [3160] = 2660,
  [3161] = 2660,
  [3162] = 2658,
  [3163] = 2656,
  [3164] = 2658,
  [3165] = 2655,
  [3166] = 2658,
  [3167] = 2660,
  [3168] = 2658,
  [3169] = 2656,
  [3170] = 2660,
  [3171] = 2658,
  [3172] = 2658,
  [3173] = 2655,
  [3174] = 2660,
  [3175] = 2656,
  [3176] = 2660,
  [3177] = 2658,
  [3178] = 2655,
  [3179] = 2655,
  [3180] = 2660,
  [3181] = 3181,
  [3182] = 3182,
  [3183] = 3183,
  [3184] = 3181,
  [3185] = 3185,
  [3186] = 3186,
  [3187] = 3181,
  [3188] = 3182,
  [3189] = 3182,
  [3190] = 3182,
  [3191] = 3191,
  [3192] = 3181,
  [3193] = 3193,
  [3194] = 3194,
  [3195] = 3181,
  [3196] = 3196,
  [3197] = 2412,
  [3198] = 3198,
  [3199] = 3196,
  [3200] = 3185,
  [3201] = 3196,
  [3202] = 3186,
  [3203] = 3193,
  [3204] = 3185,
  [3205] = 3191,
  [3206] = 3186,
  [3207] = 3207,
  [3208] = 3196,
  [3209] = 3185,
  [3210] = 3186,
  [3211] = 3191,
  [3212] = 3182,
  [3213] = 3181,
  [3214] = 3193,
  [3215] = 3181,
  [3216] = 3182,
  [3217] = 3193,
  [3218] = 3191,
  [3219] = 3186,
  [3220] = 3191,
  [3221] = 3185,
  [3222] = 3182,
  [3223] = 3181,
  [3224] = 3186,
  [3225] = 3193,
  [3226] = 3185,
  [3227] = 3191,
  [3228] = 3193,
  [3229] = 3196,
  [3230] = 3181,
  [3231] = 3207,
  [3232] = 3198,
  [3233] = 3196,
  [3234] = 3234,
  [3235] = 3182,
  [3236] = 3181,
  [3237] = 3237,
  [3238] = 3181,
  [3239] = 3185,
  [3240] = 3182,
  [3241] = 3191,
  [3242] = 3207,
  [3243] = 3198,
  [3244] = 3182,
  [3245] = 3181,
  [3246] = 3186,
  [3247] = 3185,
  [3248] = 3191,
  [3249] = 3196,
  [3250] = 3186,
  [3251] = 3185,
  [3252] = 3182,
  [3253] = 3196,
  [3254] = 3193,
  [3255] = 3196,
  [3256] = 3207,
  [3257] = 3182,
  [3258] = 3181,
  [3259] = 3193,
  [3260] = 3196,
  [3261] = 3193,
  [3262] = 3185,
  [3263] = 3182,
  [3264] = 3186,
  [3265] = 3191,
  [3266] = 3186,
  [3267] = 3181,
  [3268] = 3182,
  [3269] = 3234,
  [3270] = 3198,
  [3271] = 3181,
  [3272] = 3207,
  [3273] = 3196,
  [3274] = 3185,
  [3275] = 3182,
  [3276] = 3182,
  [3277] = 3186,
  [3278] = 3191,
  [3279] = 3181,
  [3280] = 3193,
  [3281] = 3234,
  [3282] = 3182,
  [3283] = 3193,
  [3284] = 3196,
  [3285] = 3186,
  [3286] = 3185,
  [3287] = 3181,
  [3288] = 3182,
  [3289] = 3181,
  [3290] = 3193,
  [3291] = 3181,
  [3292] = 3196,
  [3293] = 3186,
  [3294] = 3182,
  [3295] = 3182,
  [3296] = 3181,
  [3297] = 3193,
  [3298] = 3234,
  [3299] = 3198,
  [3300] = 3196,
  [3301] = 3185,
  [3302] = 3186,
  [3303] = 3198,
  [3304] = 3193,
  [3305] = 3305,
  [3306] = 3182,
  [3307] = 3181,
  [3308] = 3191,
  [3309] = 3186,
  [3310] = 3185,
  [3311] = 3193,
  [3312] = 3191,
  [3313] = 3196,
  [3314] = 3182,
  [3315] = 3181,
  [3316] = 3185,
  [3317] = 3181,
  [3318] = 3207,
  [3319] = 3186,
  [3320] = 3320,
  [3321] = 3185,
  [3322] = 3193,
  [3323] = 3196,
  [3324] = 2412,
  [3325] = 3182,
  [3326] = 3182,
  [3327] = 3181,
  [3328] = 3196,
  [3329] = 3193,
  [3330] = 3191,
  [3331] = 3181,
  [3332] = 3186,
  [3333] = 3191,
  [3334] = 3185,
  [3335] = 3181,
  [3336] = 3196,
  [3337] = 3182,
  [3338] = 3191,
  [3339] = 3339,
  [3340] = 3182,
  [3341] = 3191,
  [3342] = 3186,
  [3343] = 3181,
  [3344] = 3185,
  [3345] = 3196,
  [3346] = 3191,
  [3347] = 3186,
  [3348] = 3185,
  [3349] = 3349,
  [3350] = 3234,
  [3351] = 3194,
  [3352] = 3352,
  [3353] = 3196,
  [3354] = 3207,
  [3355] = 3183,
  [3356] = 3196,
  [3357] = 3305,
  [3358] = 3198,
  [3359] = 3185,
  [3360] = 3193,
  [3361] = 3186,
  [3362] = 3207,
  [3363] = 3196,
  [3364] = 3185,
  [3365] = 3186,
  [3366] = 3191,
  [3367] = 3181,
  [3368] = 3207,
  [3369] = 3191,
  [3370] = 3196,
  [3371] = 3196,
  [3372] = 3198,
  [3373] = 3185,
  [3374] = 3191,
  [3375] = 3181,
  [3376] = 3182,
  [3377] = 3181,
  [3378] = 3185,
  [3379] = 3181,
  [3380] = 3186,
  [3381] = 3182,
  [3382] = 3182,
  [3383] = 3383,
  [3384] = 2412,
  [3385] = 3193,
  [3386] = 3191,
  [3387] = 3186,
  [3388] = 3185,
  [3389] = 3193,
  [3390] = 3198,
  [3391] = 3182,
  [3392] = 3181,
  [3393] = 3186,
  [3394] = 3191,
  [3395] = 3234,
  [3396] = 3198,
  [3397] = 2412,
  [3398] = 3182,
  [3399] = 3181,
  [3400] = 3193,
  [3401] = 3193,
  [3402] = 3196,
  [3403] = 3193,
  [3404] = 3234,
  [3405] = 3182,
  [3406] = 3182,
  [3407] = 3181,
  [3408] = 3185,
  [3409] = 3191,
  [3410] = 3186,
  [3411] = 3185,
  [3412] = 3193,
  [3413] = 3196,
  [3414] = 3193,
  [3415] = 3182,
  [3416] = 3186,
  [3417] = 3207,
  [3418] = 3181,
  [3419] = 3181,
  [3420] = 3193,
  [3421] = 3181,
  [3422] = 3191,
  [3423] = 3182,
  [3424] = 3198,
  [3425] = 3181,
  [3426] = 3181,
  [3427] = 3191,
  [3428] = 3191,
  [3429] = 3429,
  [3430] = 3207,
  [3431] = 3196,
  [3432] = 3185,
  [3433] = 3186,
  [3434] = 3191,
  [3435] = 3182,
  [3436] = 3186,
  [3437] = 3198,
  [3438] = 3191,
  [3439] = 3182,
  [3440] = 3185,
  [3441] = 3182,
  [3442] = 3320,
  [3443] = 3186,
  [3444] = 3234,
  [3445] = 3182,
  [3446] = 3196,
  [3447] = 3181,
  [3448] = 3185,
  [3449] = 3196,
  [3450] = 3182,
  [3451] = 3234,
  [3452] = 3185,
  [3453] = 3193,
  [3454] = 3186,
  [3455] = 3181,
  [3456] = 3193,
  [3457] = 3198,
  [3458] = 3191,
  [3459] = 3182,
  [3460] = 3181,
  [3461] = 3182,
  [3462] = 3182,
  [3463] = 3193,
  [3464] = 3464,
  [3465] = 3182,
  [3466] = 3182,
  [3467] = 3198,
  [3468] = 3181,
  [3469] = 3181,
  [3470] = 3181,
  [3471] = 3196,
  [3472] = 3193,
  [3473] = 3182,
  [3474] = 3182,
  [3475] = 3181,
  [3476] = 3181,
  [3477] = 3185,
  [3478] = 3181,
  [3479] = 3193,
  [3480] = 3181,
  [3481] = 3182,
  [3482] = 3181,
  [3483] = 3181,
  [3484] = 3207,
  [3485] = 3181,
  [3486] = 3193,
  [3487] = 3487,
  [3488] = 3196,
  [3489] = 3464,
  [3490] = 3234,
  [3491] = 3181,
  [3492] = 3181,
  [3493] = 3182,
  [3494] = 3196,
  [3495] = 3181,
  [3496] = 3191,
  [3497] = 3186,
  [3498] = 3181,
  [3499] = 3185,
  [3500] = 3181,
  [3501] = 3181,
  [3502] = 3196,
  [3503] = 3191,
  [3504] = 3196,
  [3505] = 3186,
  [3506] = 3185,
  [3507] = 3185,
  [3508] = 3182,
  [3509] = 3207,
  [3510] = 3196,
  [3511] = 3185,
  [3512] = 3196,
  [3513] = 3186,
  [3514] = 3191,
  [3515] = 3207,
  [3516] = 3182,
  [3517] = 3185,
  [3518] = 3186,
  [3519] = 3186,
  [3520] = 3193,
  [3521] = 3182,
  [3522] = 3181,
  [3523] = 3191,
  [3524] = 3191,
  [3525] = 3181,
  [3526] = 3191,
  [3527] = 3527,
  [3528] = 3193,
  [3529] = 3181,
  [3530] = 3181,
  [3531] = 3186,
  [3532] = 3182,
  [3533] = 3207,
  [3534] = 3181,
  [3535] = 3185,
  [3536] = 3181,
  [3537] = 3198,
  [3538] = 3196,
  [3539] = 3182,
  [3540] = 3191,
  [3541] = 3181,
  [3542] = 3186,
  [3543] = 3181,
  [3544] = 3194,
  [3545] = 3185,
  [3546] = 3352,
  [3547] = 3182,
  [3548] = 3181,
  [3549] = 3191,
  [3550] = 3185,
  [3551] = 3234,
  [3552] = 3183,
  [3553] = 3182,
  [3554] = 3181,
  [3555] = 3305,
  [3556] = 3196,
  [3557] = 3182,
  [3558] = 3181,
  [3559] = 3182,
  [3560] = 3181,
  [3561] = 3185,
  [3562] = 3186,
  [3563] = 3191,
  [3564] = 3181,
  [3565] = 3181,
  [3566] = 3182,
  [3567] = 3193,
  [3568] = 3182,
  [3569] = 3196,
  [3570] = 3185,
  [3571] = 3181,
  [3572] = 3193,
  [3573] = 3181,
  [3574] = 3181,
  [3575] = 3186,
  [3576] = 3576,
  [3577] = 3193,
  [3578] = 3193,
  [3579] = 3191,
  [3580] = 3352,
  [3581] = 3181,
  [3582] = 3207,
  [3583] = 3193,
  [3584] = 3191,
  [3585] = 3196,
  [3586] = 3185,
  [3587] = 3186,
  [3588] = 3191,
  [3589] = 3193,
  [3590] = 3181,
  [3591] = 3198,
  [3592] = 3182,
  [3593] = 3234,
  [3594] = 3186,
  [3595] = 2412,
  [3596] = 3191,
  [3597] = 3597,
  [3598] = 3182,
  [3599] = 3181,
  [3600] = 3185,
  [3601] = 3196,
  [3602] = 3234,
  [3603] = 3193,
  [3604] = 3185,
  [3605] = 3193,
  [3606] = 3198,
  [3607] = 3607,
  [3608] = 3182,
  [3609] = 3196,
  [3610] = 3234,
  [3611] = 3193,
  [3612] = 3181,
  [3613] = 3181,
  [3614] = 3198,
  [3615] = 3429,
  [3616] = 3191,
  [3617] = 3198,
  [3618] = 3237,
  [3619] = 3234,
  [3620] = 3182,
  [3621] = 3181,
  [3622] = 3185,
  [3623] = 3186,
  [3624] = 3182,
  [3625] = 3182,
  [3626] = 3185,
  [3627] = 3182,
  [3628] = 3628,
  [3629] = 3181,
  [3630] = 3630,
  [3631] = 3196,
  [3632] = 3207,
  [3633] = 3196,
  [3634] = 3181,
  [3635] = 3186,
  [3636] = 3186,
  [3637] = 3196,
  [3638] = 3182,
  [3639] = 3181,
  [3640] = 3607,
  [3641] = 3193,
  [3642] = 3191,
  [3643] = 3186,
  [3644] = 3193,
  [3645] = 3182,
  [3646] = 3181,
  [3647] = 3181,
  [3648] = 3191,
  [3649] = 3649,
  [3650] = 3185,
  [3651] = 3196,
  [3652] = 3185,
  [3653] = 3191,
  [3654] = 3654,
  [3655] = 3182,
  [3656] = 3181,
  [3657] = 3181,
  [3658] = 3186,
  [3659] = 3659,
  [3660] = 3186,
  [3661] = 3181,
  [3662] = 3181,
  [3663] = 3191,
  [3664] = 3196,
  [3665] = 3665,
  [3666] = 3182,
  [3667] = 3196,
  [3668] = 3181,
  [3669] = 3191,
  [3670] = 3191,
  [3671] = 3193,
  [3672] = 3186,
  [3673] = 3181,
  [3674] = 3185,
  [3675] = 3196,
  [3676] = 3207,
  [3677] = 3181,
  [3678] = 3181,
  [3679] = 3182,
  [3680] = 3207,
  [3681] = 3681,
  [3682] = 3181,
  [3683] = 3207,
  [3684] = 3191,
  [3685] = 3196,
  [3686] = 3198,
  [3687] = 3185,
  [3688] = 3186,
  [3689] = 3193,
  [3690] = 3181,
  [3691] = 3182,
  [3692] = 3181,
  [3693] = 3181,
  [3694] = 3191,
  [3695] = 3193,
  [3696] = 3182,
  [3697] = 3234,
  [3698] = 3186,
  [3699] = 3699,
  [3700] = 3182,
  [3701] = 3181,
  [3702] = 3659,
  [3703] = 3182,
  [3704] = 3181,
  [3705] = 3185,
  [3706] = 3181,
  [3707] = 3182,
  [3708] = 3196,
  [3709] = 3196,
  [3710] = 3193,
  [3711] = 3185,
  [3712] = 3181,
  [3713] = 3527,
  [3714] = 3198,
  [3715] = 3182,
  [3716] = 3181,
  [3717] = 3181,
  [3718] = 3193,
  [3719] = 3576,
  [3720] = 3193,
  [3721] = 3186,
  [3722] = 3182,
  [3723] = 3699,
  [3724] = 3196,
  [3725] = 3181,
  [3726] = 3182,
  [3727] = 3649,
  [3728] = 3181,
  [3729] = 3234,
  [3730] = 3191,
  [3731] = 3181,
  [3732] = 3186,
  [3733] = 3597,
  [3734] = 3193,
  [3735] = 3607,
  [3736] = 3185,
  [3737] = 3654,
  [3738] = 3665,
  [3739] = 3681,
  [3740] = 3193,
  [3741] = 3182,
  [3742] = 3649,
  [3743] = 3181,
  [3744] = 3196,
  [3745] = 3182,
  [3746] = 3746,
  [3747] = 3207,
  [3748] = 3191,
  [3749] = 3182,
  [3750] = 3181,
  [3751] = 3699,
  [3752] = 3654,
  [3753] = 3186,
  [3754] = 3185,
  [3755] = 3649,
  [3756] = 3196,
  [3757] = 3182,
  [3758] = 3181,
  [3759] = 3193,
  [3760] = 3182,
  [3761] = 3182,
  [3762] = 3193,
  [3763] = 3182,
  [3764] = 3181,
  [3765] = 3193,
  [3766] = 3630,
  [3767] = 3185,
  [3768] = 3185,
  [3769] = 3186,
  [3770] = 3628,
  [3771] = 3237,
  [3772] = 3196,
  [3773] = 3191,
  [3774] = 3181,
  [3775] = 3182,
  [3776] = 3185,
  [3777] = 3186,
  [3778] = 3191,
  [3779] = 3191,
  [3780] = 3181,
  [3781] = 3576,
  [3782] = 3186,
  [3783] = 3185,
  [3784] = 3182,
  [3785] = 3191,
  [3786] = 3186,
  [3787] = 3185,
  [3788] = 3181,
  [3789] = 3234,
  [3790] = 3196,
  [3791] = 3182,
  [3792] = 3181,
  [3793] = 3198,
  [3794] = 3207,
  [3795] = 3193,
  [3796] = 3234,
  [3797] = 3194,
  [3798] = 3527,
  [3799] = 3193,
  [3800] = 3181,
  [3801] = 3234,
  [3802] = 3182,
  [3803] = 3659,
  [3804] = 3182,
  [3805] = 3352,
  [3806] = 3234,
  [3807] = 3182,
  [3808] = 3181,
  [3809] = 3198,
  [3810] = 3191,
  [3811] = 3186,
  [3812] = 3185,
  [3813] = 3198,
  [3814] = 3196,
  [3815] = 3181,
  [3816] = 3198,
  [3817] = 3181,
  [3818] = 3182,
  [3819] = 3182,
  [3820] = 3181,
  [3821] = 3191,
  [3822] = 3181,
  [3823] = 3464,
  [3824] = 3196,
  [3825] = 3320,
  [3826] = 3181,
  [3827] = 3182,
  [3828] = 3181,
  [3829] = 3181,
  [3830] = 3654,
  [3831] = 3193,
  [3832] = 3186,
  [3833] = 3182,
  [3834] = 3185,
  [3835] = 3182,
  [3836] = 3185,
  [3837] = 3183,
  [3838] = 3196,
  [3839] = 3193,
  [3840] = 3193,
  [3841] = 3746,
  [3842] = 3305,
  [3843] = 3185,
  [3844] = 3207,
  [3845] = 3193,
  [3846] = 3191,
  [3847] = 3186,
  [3848] = 3185,
  [3849] = 3196,
  [3850] = 3181,
  [3851] = 3196,
  [3852] = 3185,
  [3853] = 3196,
  [3854] = 3186,
  [3855] = 3186,
  [3856] = 3191,
  [3857] = 3191,
  [3858] = 3181,
  [3859] = 3193,
  [3860] = 3182,
  [3861] = 3191,
  [3862] = 3186,
  [3863] = 3186,
  [3864] = 3185,
  [3865] = 3196,
  [3866] = 3191,
  [3867] = 3181,
  [3868] = 3182,
  [3869] = 3207,
  [3870] = 3193,
  [3871] = 3193,
  [3872] = 3181,
  [3873] = 3196,
  [3874] = 3181,
  [3875] = 3185,
  [3876] = 3196,
  [3877] = 3186,
  [3878] = 3185,
  [3879] = 3181,
  [3880] = 3305,
  [3881] = 3182,
  [3882] = 3186,
  [3883] = 3464,
  [3884] = 3198,
  [3885] = 3191,
  [3886] = 3193,
  [3887] = 3191,
  [3888] = 3193,
  [3889] = 3182,
  [3890] = 3191,
  [3891] = 3429,
  [3892] = 3181,
  [3893] = 3183,
  [3894] = 3234,
  [3895] = 3182,
  [3896] = 3181,
  [3897] = 3182,
  [3898] = 3659,
  [3899] = 3628,
  [3900] = 3182,
  [3901] = 3191,
  [3902] = 3597,
  [3903] = 3181,
  [3904] = 3352,
  [3905] = 3196,
  [3906] = 3186,
  [3907] = 3182,
  [3908] = 3182,
  [3909] = 3234,
  [3910] = 3181,
  [3911] = 3182,
  [3912] = 3186,
  [3913] = 3185,
  [3914] = 3193,
  [3915] = 3194,
  [3916] = 3196,
  [3917] = 3191,
  [3918] = 3186,
  [3919] = 3185,
  [3920] = 3196,
  [3921] = 3196,
  [3922] = 3182,
  [3923] = 3193,
  [3924] = 3181,
  [3925] = 3181,
  [3926] = 3182,
  [3927] = 3198,
  [3928] = 3207,
  [3929] = 3182,
  [3930] = 3699,
  [3931] = 3196,
  [3932] = 3182,
  [3933] = 3182,
  [3934] = 3181,
  [3935] = 3198,
  [3936] = 3191,
  [3937] = 3181,
  [3938] = 3665,
  [3939] = 3185,
  [3940] = 3181,
  [3941] = 3193,
  [3942] = 3182,
  [3943] = 3576,
  [3944] = 3234,
  [3945] = 3681,
  [3946] = 3191,
  [3947] = 3237,
  [3948] = 3628,
  [3949] = 3746,
  [3950] = 3182,
  [3951] = 3181,
  [3952] = 3234,
  [3953] = 3630,
  [3954] = 3186,
  [3955] = 3193,
  [3956] = 3182,
  [3957] = 3185,
  [3958] = 3181,
  [3959] = 3181,
  [3960] = 3186,
  [3961] = 3191,
  [3962] = 2412,
  [3963] = 3186,
  [3964] = 3182,
  [3965] = 3181,
  [3966] = 3196,
  [3967] = 3182,
  [3968] = 3654,
  [3969] = 3649,
  [3970] = 3630,
  [3971] = 3198,
  [3972] = 3193,
  [3973] = 2412,
  [3974] = 2412,
  [3975] = 2412,
  [3976] = 2412,
  [3977] = 2412,
  [3978] = 3978,
  [3979] = 3978,
  [3980] = 3978,
  [3981] = 3978,
  [3982] = 3978,
  [3983] = 2412,
  [3984] = 3978,
  [3985] = 3985,
  [3986] = 3978,
  [3987] = 3987,
  [3988] = 3978,
  [3989] = 3978,
  [3990] = 3978,
  [3991] = 3978,
  [3992] = 3978,
  [3993] = 3978,
  [3994] = 3978,
  [3995] = 3978,
  [3996] = 3978,
  [3997] = 3978,
  [3998] = 3978,
  [3999] = 3978,
  [4000] = 3978,
  [4001] = 3978,
  [4002] = 3978,
  [4003] = 3978,
  [4004] = 3978,
  [4005] = 3978,
  [4006] = 3978,
  [4007] = 3978,
  [4008] = 3978,
  [4009] = 3978,
  [4010] = 3978,
  [4011] = 3978,
  [4012] = 3978,
  [4013] = 3978,
  [4014] = 3978,
  [4015] = 3978,
  [4016] = 3978,
  [4017] = 3978,
  [4018] = 3978,
  [4019] = 3978,
  [4020] = 3978,
  [4021] = 3978,
  [4022] = 3978,
  [4023] = 3978,
  [4024] = 3978,
  [4025] = 3978,
  [4026] = 3978,
  [4027] = 3978,
  [4028] = 3978,
  [4029] = 3978,
  [4030] = 3978,
  [4031] = 3978,
  [4032] = 3978,
  [4033] = 3978,
  [4034] = 3978,
  [4035] = 3978,
  [4036] = 3978,
  [4037] = 4037,
  [4038] = 4037,
  [4039] = 4037,
  [4040] = 4037,
  [4041] = 4037,
  [4042] = 4037,
  [4043] = 4043,
  [4044] = 4043,
  [4045] = 4037,
  [4046] = 4037,
  [4047] = 4037,
  [4048] = 4048,
  [4049] = 4037,
  [4050] = 3985,
  [4051] = 4037,
  [4052] = 4037,
  [4053] = 4043,
  [4054] = 4043,
  [4055] = 4037,
  [4056] = 4037,
  [4057] = 4043,
  [4058] = 4043,
  [4059] = 4037,
  [4060] = 4043,
  [4061] = 4043,
  [4062] = 3987,
  [4063] = 4037,
  [4064] = 4043,
  [4065] = 4037,
  [4066] = 4043,
  [4067] = 4043,
  [4068] = 4043,
  [4069] = 4043,
  [4070] = 4037,
  [4071] = 4037,
  [4072] = 4037,
  [4073] = 4043,
  [4074] = 4037,
  [4075] = 4037,
  [4076] = 4037,
  [4077] = 4043,
  [4078] = 4043,
  [4079] = 4037,
  [4080] = 3987,
  [4081] = 4043,
  [4082] = 4043,
  [4083] = 4043,
  [4084] = 4043,
  [4085] = 4037,
  [4086] = 4037,
  [4087] = 4043,
  [4088] = 4043,
  [4089] = 4037,
  [4090] = 4043,
  [4091] = 4037,
  [4092] = 4037,
  [4093] = 4043,
  [4094] = 4043,
  [4095] = 4037,
  [4096] = 4043,
  [4097] = 4043,
  [4098] = 4043,
  [4099] = 4043,
  [4100] = 4037,
  [4101] = 4037,
  [4102] = 4102,
  [4103] = 4043,
  [4104] = 4043,
  [4105] = 4037,
  [4106] = 4048,
  [4107] = 4037,
  [4108] = 4037,
  [4109] = 4043,
  [4110] = 4037,
  [4111] = 4037,
  [4112] = 4037,
  [4113] = 4043,
  [4114] = 4043,
  [4115] = 4043,
  [4116] = 4043,
  [4117] = 4037,
  [4118] = 4043,
  [4119] = 4043,
  [4120] = 4043,
  [4121] = 4037,
  [4122] = 4037,
  [4123] = 4037,
  [4124] = 4043,
  [4125] = 4037,
  [4126] = 4037,
  [4127] = 4043,
  [4128] = 4043,
  [4129] = 4037,
  [4130] = 4043,
  [4131] = 4043,
  [4132] = 4037,
  [4133] = 4037,
  [4134] = 4043,
  [4135] = 4037,
  [4136] = 4102,
  [4137] = 4037,
  [4138] = 4043,
  [4139] = 4043,
  [4140] = 4043,
  [4141] = 4037,
  [4142] = 4043,
  [4143] = 4043,
  [4144] = 3985,
  [4145] = 4037,
  [4146] = 4037,
  [4147] = 4037,
  [4148] = 4043,
  [4149] = 4043,
  [4150] = 4037,
  [4151] = 4043,
  [4152] = 4043,
  [4153] = 4037,
  [4154] = 4043,
  [4155] = 4037,
  [4156] = 4043,
  [4157] = 3987,
  [4158] = 3987,
  [4159] = 3985,
  [4160] = 3987,
  [4161] = 4161,
  [4162] = 3987,
  [4163] = 3985,
  [4164] = 4164,
  [4165] = 3985,
  [4166] = 3985,
  [4167] = 3985,
  [4168] = 3987,
  [4169] = 4169,
  [4170] = 3985,
  [4171] = 4171,
  [4172] = 3985,
  [4173] = 3987,
  [4174] = 4171,
  [4175] = 4171,
  [4176] = 3987,
  [4177] = 3985,
  [4178] = 3987,
  [4179] = 3985,
  [4180] = 3987,
  [4181] = 3985,
  [4182] = 3987,
  [4183] = 3987,
  [4184] = 3985,
  [4185] = 3987,
  [4186] = 3987,
  [4187] = 3985,
  [4188] = 3985,
  [4189] = 3987,
  [4190] = 3985,
  [4191] = 3987,
  [4192] = 3987,
  [4193] = 3985,
  [4194] = 3985,
  [4195] = 4195,
  [4196] = 3985,
  [4197] = 3987,
  [4198] = 3985,
  [4199] = 3985,
  [4200] = 3987,
  [4201] = 4195,
  [4202] = 3987,
  [4203] = 4203,
  [4204] = 3985,
  [4205] = 3987,
  [4206] = 4206,
  [4207] = 3985,
  [4208] = 3985,
  [4209] = 3987,
  [4210] = 3987,
  [4211] = 4211,
  [4212] = 4211,
  [4213] = 4211,
  [4214] = 4214,
  [4215] = 4211,
  [4216] = 4211,
  [4217] = 4217,
  [4218] = 4218,
  [4219] = 4211,
  [4220] = 4211,
  [4221] = 4221,
  [4222] = 4211,
  [4223] = 4214,
  [4224] = 4206,
  [4225] = 4217,
  [4226] = 4218,
  [4227] = 4211,
  [4228] = 4211,
  [4229] = 4211,
  [4230] = 4211,
  [4231] = 4211,
  [4232] = 4211,
  [4233] = 4211,
  [4234] = 4217,
  [4235] = 4211,
  [4236] = 4211,
  [4237] = 4214,
  [4238] = 4211,
  [4239] = 4211,
  [4240] = 4211,
  [4241] = 4211,
  [4242] = 4221,
  [4243] = 4211,
  [4244] = 4211,
  [4245] = 4245,
  [4246] = 4211,
  [4247] = 4218,
  [4248] = 4211,
  [4249] = 4217,
  [4250] = 4214,
  [4251] = 4211,
  [4252] = 4211,
  [4253] = 4245,
  [4254] = 4254,
  [4255] = 4211,
  [4256] = 4218,
  [4257] = 4221,
  [4258] = 4217,
  [4259] = 4221,
  [4260] = 4211,
  [4261] = 4245,
  [4262] = 4214,
  [4263] = 4211,
  [4264] = 4211,
  [4265] = 4211,
  [4266] = 4211,
  [4267] = 4211,
  [4268] = 4245,
  [4269] = 4211,
  [4270] = 4211,
  [4271] = 4254,
  [4272] = 4272,
  [4273] = 4273,
  [4274] = 4274,
  [4275] = 4275,
  [4276] = 4276,
  [4277] = 4277,
  [4278] = 4278,
  [4279] = 4279,
  [4280] = 4280,
  [4281] = 4279,
  [4282] = 4280,
  [4283] = 4278,
  [4284] = 3985,
  [4285] = 4278,
  [4286] = 4272,
  [4287] = 4280,
  [4288] = 4288,
  [4289] = 4289,
  [4290] = 4279,
  [4291] = 4288,
  [4292] = 4275,
  [4293] = 4272,
  [4294] = 4272,
  [4295] = 4273,
  [4296] = 4280,
  [4297] = 4278,
  [4298] = 4277,
  [4299] = 4279,
  [4300] = 4273,
  [4301] = 4278,
  [4302] = 4302,
  [4303] = 4302,
  [4304] = 4274,
  [4305] = 4273,
  [4306] = 4275,
  [4307] = 4274,
  [4308] = 4288,
  [4309] = 4289,
  [4310] = 4275,
  [4311] = 4273,
  [4312] = 4277,
  [4313] = 4302,
  [4314] = 4275,
  [4315] = 4289,
  [4316] = 3987,
  [4317] = 4277,
  [4318] = 4318,
  [4319] = 4319,
  [4320] = 2463,
  [4321] = 4321,
  [4322] = 2464,
  [4323] = 4323,
  [4324] = 4323,
  [4325] = 4325,
  [4326] = 4323,
  [4327] = 4327,
  [4328] = 4328,
  [4329] = 4328,
  [4330] = 4328,
  [4331] = 4331,
  [4332] = 4327,
  [4333] = 4333,
  [4334] = 4327,
  [4335] = 4335,
  [4336] = 4336,
  [4337] = 4327,
  [4338] = 4328,
  [4339] = 4328,
  [4340] = 4340,
  [4341] = 4335,
  [4342] = 4331,
  [4343] = 4333,
  [4344] = 4344,
  [4345] = 4333,
  [4346] = 4331,
  [4347] = 4344,
  [4348] = 4348,
  [4349] = 4333,
  [4350] = 4331,
  [4351] = 4351,
  [4352] = 4333,
  [4353] = 4353,
  [4354] = 4354,
  [4355] = 4355,
  [4356] = 4356,
  [4357] = 4357,
  [4358] = 4358,
  [4359] = 4356,
  [4360] = 4360,
  [4361] = 4361,
  [4362] = 4362,
  [4363] = 4363,
  [4364] = 4364,
  [4365] = 4365,
  [4366] = 4366,
  [4367] = 4367,
  [4368] = 4368,
  [4369] = 4369,
  [4370] = 4336,
  [4371] = 4368,
  [4372] = 4372,
  [4373] = 4358,
  [4374] = 4374,
  [4375] = 4375,
  [4376] = 4364,
  [4377] = 4363,
  [4378] = 4378,
  [4379] = 4379,
  [4380] = 4365,
  [4381] = 4381,
  [4382] = 4382,
  [4383] = 4378,
  [4384] = 4367,
  [4385] = 4340,
  [4386] = 4386,
  [4387] = 4387,
  [4388] = 4365,
  [4389] = 4360,
  [4390] = 4357,
  [4391] = 4369,
  [4392] = 4374,
  [4393] = 4368,
  [4394] = 4363,
  [4395] = 4395,
  [4396] = 4340,
  [4397] = 4397,
  [4398] = 4361,
  [4399] = 4374,
  [4400] = 4400,
  [4401] = 4382,
  [4402] = 4402,
  [4403] = 4378,
  [4404] = 4357,
  [4405] = 4367,
  [4406] = 4375,
  [4407] = 4356,
  [4408] = 4374,
  [4409] = 4409,
  [4410] = 4348,
  [4411] = 4379,
  [4412] = 4336,
  [4413] = 4382,
  [4414] = 4363,
  [4415] = 4358,
  [4416] = 4369,
  [4417] = 4417,
  [4418] = 4400,
  [4419] = 4369,
  [4420] = 4355,
  [4421] = 4336,
  [4422] = 4357,
  [4423] = 4336,
  [4424] = 4378,
  [4425] = 4369,
  [4426] = 4367,
  [4427] = 4369,
  [4428] = 4365,
  [4429] = 4358,
  [4430] = 4356,
  [4431] = 4379,
  [4432] = 4369,
  [4433] = 4358,
  [4434] = 4434,
  [4435] = 4356,
  [4436] = 4348,
  [4437] = 4353,
  [4438] = 4357,
  [4439] = 4439,
  [4440] = 4379,
  [4441] = 4382,
  [4442] = 4368,
  [4443] = 4443,
  [4444] = 4444,
  [4445] = 3987,
  [4446] = 4353,
  [4447] = 4353,
  [4448] = 4448,
  [4449] = 4351,
  [4450] = 4355,
  [4451] = 4336,
  [4452] = 4452,
  [4453] = 4444,
  [4454] = 4444,
  [4455] = 4444,
  [4456] = 4456,
  [4457] = 4444,
  [4458] = 4458,
  [4459] = 3985,
  [4460] = 4434,
  [4461] = 4354,
  [4462] = 4355,
  [4463] = 4456,
  [4464] = 4355,
  [4465] = 4452,
  [4466] = 4444,
  [4467] = 4336,
  [4468] = 4336,
  [4469] = 4397,
  [4470] = 4353,
  [4471] = 4348,
  [4472] = 4472,
  [4473] = 4348,
  [4474] = 4474,
  [4475] = 4355,
  [4476] = 4476,
  [4477] = 4444,
  [4478] = 4321,
  [4479] = 4434,
  [4480] = 4444,
  [4481] = 4444,
  [4482] = 4482,
  [4483] = 4458,
  [4484] = 4444,
  [4485] = 4485,
  [4486] = 4456,
  [4487] = 4452,
  [4488] = 4448,
  [4489] = 4444,
  [4490] = 4444,
  [4491] = 4443,
  [4492] = 4340,
  [4493] = 4452,
  [4494] = 4494,
  [4495] = 4456,
  [4496] = 4353,
  [4497] = 4444,
  [4498] = 4443,
  [4499] = 4354,
  [4500] = 4444,
  [4501] = 4458,
  [4502] = 4444,
  [4503] = 4448,
  [4504] = 4504,
  [4505] = 4443,
  [4506] = 4336,
  [4507] = 4348,
  [4508] = 4444,
  [4509] = 4397,
  [4510] = 4448,
  [4511] = 4444,
  [4512] = 4353,
  [4513] = 4336,
  [4514] = 4354,
  [4515] = 4452,
  [4516] = 4456,
  [4517] = 4340,
  [4518] = 4444,
  [4519] = 4458,
  [4520] = 4444,
  [4521] = 4336,
  [4522] = 3987,
  [4523] = 4444,
  [4524] = 4336,
  [4525] = 4444,
  [4526] = 3985,
  [4527] = 4444,
  [4528] = 4458,
  [4529] = 4529,
  [4530] = 4444,
  [4531] = 4444,
  [4532] = 4340,
  [4533] = 4355,
  [4534] = 4444,
  [4535] = 4443,
  [4536] = 4448,
  [4537] = 4397,
  [4538] = 4538,
  [4539] = 4397,
  [4540] = 4336,
  [4541] = 4386,
  [4542] = 4372,
  [4543] = 4355,
  [4544] = 3985,
  [4545] = 4340,
  [4546] = 3985,
  [4547] = 3987,
  [4548] = 4325,
  [4549] = 4353,
  [4550] = 4504,
  [4551] = 4355,
  [4552] = 4353,
  [4553] = 3985,
  [4554] = 4439,
  [4555] = 4402,
  [4556] = 4381,
  [4557] = 4387,
  [4558] = 4340,
  [4559] = 4362,
  [4560] = 4353,
  [4561] = 4353,
  [4562] = 4321,
  [4563] = 4354,
  [4564] = 4397,
  [4565] = 4565,
  [4566] = 4397,
  [4567] = 3987,
  [4568] = 4434,
  [4569] = 4485,
  [4570] = 4474,
  [4571] = 4321,
  [4572] = 4397,
  [4573] = 4472,
  [4574] = 3987,
  [4575] = 4472,
  [4576] = 4348,
  [4577] = 4348,
  [4578] = 4336,
  [4579] = 4321,
  [4580] = 4366,
  [4581] = 3987,
  [4582] = 4395,
  [4583] = 4355,
  [4584] = 4409,
  [4585] = 4355,
  [4586] = 4336,
  [4587] = 4336,
  [4588] = 4354,
  [4589] = 4354,
  [4590] = 4353,
  [4591] = 4591,
  [4592] = 4354,
  [4593] = 4504,
  [4594] = 3985,
  [4595] = 4595,
  [4596] = 3985,
  [4597] = 4336,
  [4598] = 4434,
  [4599] = 4485,
  [4600] = 4397,
  [4601] = 3987,
  [4602] = 4474,
  [4603] = 4472,
  [4604] = 4355,
  [4605] = 4353,
  [4606] = 3985,
  [4607] = 4434,
  [4608] = 3987,
  [4609] = 4482,
  [4610] = 4591,
  [4611] = 4336,
  [4612] = 4353,
  [4613] = 4417,
  [4614] = 4353,
  [4615] = 4354,
  [4616] = 4351,
  [4617] = 4336,
  [4618] = 4482,
  [4619] = 4355,
  [4620] = 4351,
  [4621] = 4351,
  [4622] = 4355,
  [4623] = 4348,
  [4624] = 4474,
  [4625] = 4336,
  [4626] = 4340,
  [4627] = 4318,
  [4628] = 4474,
  [4629] = 4472,
  [4630] = 4355,
  [4631] = 4538,
  [4632] = 3987,
  [4633] = 4336,
  [4634] = 3985,
  [4635] = 3987,
  [4636] = 4355,
  [4637] = 4351,
  [4638] = 4402,
  [4639] = 4321,
  [4640] = 4336,
  [4641] = 4409,
  [4642] = 4642,
  [4643] = 4474,
  [4644] = 4472,
  [4645] = 4395,
  [4646] = 4355,
  [4647] = 4647,
  [4648] = 4366,
  [4649] = 4366,
  [4650] = 4472,
  [4651] = 4439,
  [4652] = 4395,
  [4653] = 4353,
  [4654] = 4409,
  [4655] = 4474,
  [4656] = 4656,
  [4657] = 3987,
  [4658] = 3985,
  [4659] = 3985,
  [4660] = 4397,
  [4661] = 4351,
  [4662] = 4353,
  [4663] = 4538,
  [4664] = 4340,
  [4665] = 4472,
  [4666] = 4474,
  [4667] = 4336,
  [4668] = 4353,
  [4669] = 4354,
  [4670] = 4351,
  [4671] = 3987,
  [4672] = 4318,
  [4673] = 4355,
  [4674] = 4336,
  [4675] = 4472,
  [4676] = 4474,
  [4677] = 4381,
  [4678] = 4354,
  [4679] = 4336,
  [4680] = 3987,
  [4681] = 4397,
  [4682] = 4682,
  [4683] = 4355,
  [4684] = 4348,
  [4685] = 4417,
  [4686] = 4591,
  [4687] = 4402,
  [4688] = 4372,
  [4689] = 4472,
  [4690] = 4397,
  [4691] = 4474,
  [4692] = 4321,
  [4693] = 4529,
  [4694] = 3985,
  [4695] = 4591,
  [4696] = 3987,
  [4697] = 4434,
  [4698] = 4321,
  [4699] = 4472,
  [4700] = 4354,
  [4701] = 4348,
  [4702] = 3987,
  [4703] = 3985,
  [4704] = 4386,
  [4705] = 4538,
  [4706] = 4351,
  [4707] = 4595,
  [4708] = 4397,
  [4709] = 4709,
  [4710] = 4474,
  [4711] = 4538,
  [4712] = 4336,
  [4713] = 4354,
  [4714] = 3987,
  [4715] = 4474,
  [4716] = 4336,
  [4717] = 4362,
  [4718] = 4336,
  [4719] = 3985,
  [4720] = 4355,
  [4721] = 4721,
  [4722] = 4538,
  [4723] = 4387,
  [4724] = 4325,
  [4725] = 4336,
  [4726] = 4336,
  [4727] = 4381,
  [4728] = 4397,
  [4729] = 4402,
  [4730] = 4434,
  [4731] = 4417,
  [4732] = 4351,
  [4733] = 4355,
  [4734] = 3987,
  [4735] = 4485,
  [4736] = 4434,
  [4737] = 4353,
  [4738] = 4348,
  [4739] = 4372,
  [4740] = 4387,
  [4741] = 4340,
  [4742] = 4439,
  [4743] = 4321,
  [4744] = 4434,
  [4745] = 4386,
  [4746] = 4485,
  [4747] = 4417,
  [4748] = 4353,
  [4749] = 4485,
  [4750] = 4434,
  [4751] = 4439,
  [4752] = 4321,
  [4753] = 4351,
  [4754] = 4321,
  [4755] = 3985,
  [4756] = 4402,
  [4757] = 4372,
  [4758] = 4354,
  [4759] = 4348,
  [4760] = 4340,
  [4761] = 4397,
  [4762] = 4591,
  [4763] = 4355,
  [4764] = 4381,
  [4765] = 4591,
  [4766] = 4318,
  [4767] = 4482,
  [4768] = 4387,
  [4769] = 4325,
  [4770] = 4366,
  [4771] = 3987,
  [4772] = 4340,
  [4773] = 4362,
  [4774] = 4353,
  [4775] = 4395,
  [4776] = 4504,
  [4777] = 4409,
  [4778] = 4409,
  [4779] = 4504,
  [4780] = 4355,
  [4781] = 3985,
  [4782] = 4472,
  [4783] = 4395,
  [4784] = 4362,
  [4785] = 4318,
  [4786] = 4595,
  [4787] = 4354,
  [4788] = 3987,
  [4789] = 4417,
  [4790] = 3985,
  [4791] = 4336,
  [4792] = 4325,
  [4793] = 4386,
  [4794] = 4353,
  [4795] = 4355,
  [4796] = 4353,
  [4797] = 3985,
  [4798] = 4798,
  [4799] = 4372,
  [4800] = 4366,
  [4801] = 4482,
  [4802] = 4386,
  [4803] = 4362,
  [4804] = 4504,
  [4805] = 4336,
  [4806] = 4482,
  [4807] = 4318,
  [4808] = 4538,
  [4809] = 4325,
  [4810] = 4387,
  [4811] = 4591,
  [4812] = 4381,
  [4813] = 4353,
  [4814] = 4439,
  [4815] = 4362,
  [4816] = 4355,
  [4817] = 4355,
  [4818] = 4348,
  [4819] = 4336,
  [4820] = 4820,
  [4821] = 4325,
  [4822] = 4538,
  [4823] = 4366,
  [4824] = 4395,
  [4825] = 4409,
  [4826] = 4318,
  [4827] = 4827,
  [4828] = 4595,
  [4829] = 4417,
  [4830] = 4336,
  [4831] = 4354,
  [4832] = 4386,
  [4833] = 4397,
  [4834] = 4325,
  [4835] = 4340,
  [4836] = 4409,
  [4837] = 4395,
  [4838] = 4595,
  [4839] = 4355,
  [4840] = 3985,
  [4841] = 4366,
  [4842] = 4417,
  [4843] = 4721,
  [4844] = 4397,
  [4845] = 4591,
  [4846] = 4336,
  [4847] = 4354,
  [4848] = 4362,
  [4849] = 4472,
  [4850] = 4682,
  [4851] = 4529,
  [4852] = 4417,
  [4853] = 4798,
  [4854] = 4474,
  [4855] = 4591,
  [4856] = 4325,
  [4857] = 4656,
  [4858] = 4858,
  [4859] = 4387,
  [4860] = 4709,
  [4861] = 4656,
  [4862] = 4647,
  [4863] = 4642,
  [4864] = 4366,
  [4865] = 4318,
  [4866] = 4591,
  [4867] = 4336,
  [4868] = 4318,
  [4869] = 4372,
  [4870] = 4386,
  [4871] = 4336,
  [4872] = 4386,
  [4873] = 4474,
  [4874] = 4417,
  [4875] = 4439,
  [4876] = 3985,
  [4877] = 4402,
  [4878] = 4381,
  [4879] = 4321,
  [4880] = 4321,
  [4881] = 4387,
  [4882] = 4362,
  [4883] = 4482,
  [4884] = 3985,
  [4885] = 4372,
  [4886] = 4336,
  [4887] = 4386,
  [4888] = 4318,
  [4889] = 4472,
  [4890] = 4439,
  [4891] = 4402,
  [4892] = 4381,
  [4893] = 4434,
  [4894] = 4472,
  [4895] = 4381,
  [4896] = 4538,
  [4897] = 4387,
  [4898] = 4355,
  [4899] = 4362,
  [4900] = 4325,
  [4901] = 4336,
  [4902] = 4902,
  [4903] = 4402,
  [4904] = 4591,
  [4905] = 4591,
  [4906] = 4351,
  [4907] = 4434,
  [4908] = 4474,
  [4909] = 4325,
  [4910] = 3985,
  [4911] = 4397,
  [4912] = 4395,
  [4913] = 4340,
  [4914] = 4351,
  [4915] = 4434,
  [4916] = 4709,
  [4917] = 4336,
  [4918] = 3987,
  [4919] = 4434,
  [4920] = 4485,
  [4921] = 4434,
  [4922] = 4682,
  [4923] = 4798,
  [4924] = 4642,
  [4925] = 4925,
  [4926] = 4321,
  [4927] = 4902,
  [4928] = 4504,
  [4929] = 4647,
  [4930] = 3987,
  [4931] = 4409,
  [4932] = 4439,
  [4933] = 4656,
  [4934] = 4538,
  [4935] = 4472,
  [4936] = 4372,
  [4937] = 4353,
  [4938] = 4397,
  [4939] = 3987,
  [4940] = 4348,
  [4941] = 4386,
  [4942] = 4355,
  [4943] = 4351,
  [4944] = 4439,
  [4945] = 4318,
  [4946] = 4409,
  [4947] = 4642,
  [4948] = 4395,
  [4949] = 4647,
  [4950] = 4366,
  [4951] = 4434,
  [4952] = 4402,
  [4953] = 4925,
  [4954] = 4397,
  [4955] = 4354,
  [4956] = 4381,
  [4957] = 4656,
  [4958] = 4318,
  [4959] = 4474,
  [4960] = 4318,
  [4961] = 4434,
  [4962] = 4355,
  [4963] = 4472,
  [4964] = 4362,
  [4965] = 4348,
  [4966] = 4387,
  [4967] = 4355,
  [4968] = 4538,
  [4969] = 4372,
  [4970] = 4354,
  [4971] = 4434,
  [4972] = 4354,
  [4973] = 4538,
  [4974] = 4362,
  [4975] = 4353,
  [4976] = 4325,
  [4977] = 4351,
  [4978] = 4321,
  [4979] = 4472,
  [4980] = 4647,
  [4981] = 4321,
  [4982] = 4858,
  [4983] = 4366,
  [4984] = 4351,
  [4985] = 4336,
  [4986] = 4474,
  [4987] = 4340,
  [4988] = 4504,
  [4989] = 3985,
  [4990] = 4366,
  [4991] = 4336,
  [4992] = 4355,
  [4993] = 4591,
  [4994] = 4353,
  [4995] = 4642,
  [4996] = 4395,
  [4997] = 4409,
  [4998] = 3987,
  [4999] = 4434,
  [5000] = 4409,
  [5001] = 4395,
  [5002] = 4366,
  [5003] = 4351,
  [5004] = 4529,
  [5005] = 4340,
  [5006] = 4472,
  [5007] = 4395,
  [5008] = 4417,
  [5009] = 4474,
  [5010] = 3985,
  [5011] = 4351,
  [5012] = 4353,
  [5013] = 3987,
  [5014] = 4409,
  [5015] = 4529,
  [5016] = 4353,
  [5017] = 4472,
  [5018] = 4387,
  [5019] = 4381,
  [5020] = 4474,
  [5021] = 4402,
  [5022] = 4355,
  [5023] = 4397,
  [5024] = 4397,
  [5025] = 4353,
  [5026] = 3987,
  [5027] = 4321,
  [5028] = 4439,
  [5029] = 4387,
  [5030] = 4529,
  [5031] = 3987,
  [5032] = 4318,
  [5033] = 4354,
  [5034] = 4434,
  [5035] = 4354,
  [5036] = 4591,
  [5037] = 4336,
  [5038] = 3985,
  [5039] = 4682,
  [5040] = 4709,
  [5041] = 3985,
  [5042] = 4482,
  [5043] = 4434,
  [5044] = 4485,
  [5045] = 4721,
  [5046] = 3985,
  [5047] = 4355,
  [5048] = 4336,
  [5049] = 4381,
  [5050] = 4417,
  [5051] = 4348,
  [5052] = 4474,
  [5053] = 4353,
  [5054] = 4538,
  [5055] = 4417,
  [5056] = 4372,
  [5057] = 4336,
  [5058] = 4325,
  [5059] = 4386,
  [5060] = 4595,
  [5061] = 4353,
  [5062] = 4351,
  [5063] = 3987,
  [5064] = 3985,
  [5065] = 4474,
  [5066] = 4372,
  [5067] = 4321,
  [5068] = 4321,
  [5069] = 4336,
  [5070] = 4386,
  [5071] = 4353,
  [5072] = 3987,
  [5073] = 4434,
  [5074] = 4336,
  [5075] = 4439,
  [5076] = 4372,
  [5077] = 4402,
  [5078] = 4381,
  [5079] = 4387,
  [5080] = 4362,
  [5081] = 4591,
  [5082] = 4402,
  [5083] = 4472,
  [5084] = 4439,
  [5085] = 4353,
  [5086] = 4538,
  [5087] = 3987,
  [5088] = 3985,
  [5089] = 4355,
  [5090] = 4353,
  [5091] = 4538,
  [5092] = 4482,
  [5093] = 4485,
  [5094] = 3987,
  [5095] = 4355,
  [5096] = 4351,
  [5097] = 4591,
  [5098] = 4721,
  [5099] = 4353,
  [5100] = 4321,
  [5101] = 4798,
  [5102] = 4351,
  [5103] = 4902,
  [5104] = 4340,
  [5105] = 4362,
  [5106] = 4434,
  [5107] = 4387,
  [5108] = 4336,
  [5109] = 4348,
  [5110] = 5110,
  [5111] = 5111,
  [5112] = 4434,
  [5113] = 4353,
  [5114] = 4362,
  [5115] = 4387,
  [5116] = 4381,
  [5117] = 4325,
  [5118] = 4902,
  [5119] = 4402,
  [5120] = 4439,
  [5121] = 4355,
  [5122] = 4366,
  [5123] = 5123,
  [5124] = 4386,
  [5125] = 4351,
  [5126] = 4372,
  [5127] = 4434,
  [5128] = 4366,
  [5129] = 4902,
  [5130] = 4355,
  [5131] = 4395,
  [5132] = 4409,
  [5133] = 4902,
  [5134] = 4395,
  [5135] = 4434,
  [5136] = 4434,
  [5137] = 4591,
  [5138] = 4902,
  [5139] = 5139,
  [5140] = 4434,
  [5141] = 4409,
  [5142] = 4318,
  [5143] = 4827,
  [5144] = 4902,
  [5145] = 3987,
  [5146] = 4827,
  [5147] = 4381,
  [5148] = 4434,
  [5149] = 4504,
  [5150] = 4434,
  [5151] = 4325,
  [5152] = 5152,
  [5153] = 4325,
  [5154] = 4474,
  [5155] = 4402,
  [5156] = 4472,
  [5157] = 4721,
  [5158] = 4798,
  [5159] = 4386,
  [5160] = 4351,
  [5161] = 4397,
  [5162] = 4354,
  [5163] = 4439,
  [5164] = 4417,
  [5165] = 4682,
  [5166] = 4354,
  [5167] = 4372,
  [5168] = 4372,
  [5169] = 4434,
  [5170] = 4386,
  [5171] = 4485,
  [5172] = 4439,
  [5173] = 4925,
  [5174] = 4318,
  [5175] = 4402,
  [5176] = 4709,
  [5177] = 4434,
  [5178] = 4340,
  [5179] = 5110,
  [5180] = 4820,
  [5181] = 4355,
  [5182] = 5182,
  [5183] = 4381,
  [5184] = 5184,
  [5185] = 5185,
  [5186] = 4354,
  [5187] = 4387,
  [5188] = 4206,
  [5189] = 4434,
  [5190] = 4682,
  [5191] = 4336,
  [5192] = 3985,
  [5193] = 4354,
  [5194] = 4925,
  [5195] = 4709,
  [5196] = 4538,
  [5197] = 3985,
  [5198] = 4397,
  [5199] = 4538,
  [5200] = 4362,
  [5201] = 4325,
  [5202] = 4529,
  [5203] = 4538,
  [5204] = 4504,
  [5205] = 5110,
  [5206] = 4354,
  [5207] = 5110,
  [5208] = 3987,
  [5209] = 3985,
  [5210] = 4336,
  [5211] = 3987,
  [5212] = 3985,
  [5213] = 5213,
  [5214] = 4336,
  [5215] = 3987,
  [5216] = 4482,
  [5217] = 4642,
  [5218] = 4647,
  [5219] = 3985,
  [5220] = 4397,
  [5221] = 4348,
  [5222] = 4656,
  [5223] = 4336,
  [5224] = 4434,
  [5225] = 4354,
  [5226] = 4902,
  [5227] = 4372,
  [5228] = 5228,
  [5229] = 4397,
  [5230] = 4439,
  [5231] = 4351,
  [5232] = 4485,
  [5233] = 4402,
  [5234] = 4325,
  [5235] = 4381,
  [5236] = 4504,
  [5237] = 4642,
  [5238] = 4353,
  [5239] = 4647,
  [5240] = 4387,
  [5241] = 3987,
  [5242] = 4858,
  [5243] = 4591,
  [5244] = 4362,
  [5245] = 4434,
  [5246] = 4417,
  [5247] = 3987,
  [5248] = 4656,
  [5249] = 4353,
  [5250] = 3985,
  [5251] = 4386,
  [5252] = 4529,
  [5253] = 4397,
  [5254] = 4482,
  [5255] = 4472,
  [5256] = 4858,
  [5257] = 4595,
  [5258] = 4474,
  [5259] = 4372,
  [5260] = 4397,
  [5261] = 4472,
  [5262] = 4325,
  [5263] = 4366,
  [5264] = 3987,
  [5265] = 4474,
  [5266] = 4353,
  [5267] = 4395,
  [5268] = 4353,
  [5269] = 4591,
  [5270] = 4439,
  [5271] = 4402,
  [5272] = 4409,
  [5273] = 4318,
  [5274] = 4381,
  [5275] = 4387,
  [5276] = 4362,
  [5277] = 3985,
  [5278] = 4409,
  [5279] = 4386,
  [5280] = 4395,
  [5281] = 4321,
  [5282] = 4366,
  [5283] = 3987,
  [5284] = 5284,
  [5285] = 3985,
  [5286] = 4318,
  [5287] = 4409,
  [5288] = 4395,
  [5289] = 4366,
  [5290] = 4318,
  [5291] = 4318,
  [5292] = 4321,
  [5293] = 4372,
  [5294] = 4386,
  [5295] = 5295,
  [5296] = 4353,
  [5297] = 4355,
  [5298] = 4439,
  [5299] = 3985,
  [5300] = 4482,
  [5301] = 4321,
  [5302] = 4318,
  [5303] = 4409,
  [5304] = 4395,
  [5305] = 4366,
  [5306] = 4321,
  [5307] = 4351,
  [5308] = 4591,
  [5309] = 3987,
  [5310] = 4397,
  [5311] = 4353,
  [5312] = 5312,
  [5313] = 4472,
  [5314] = 4474,
  [5315] = 4409,
  [5316] = 4656,
  [5317] = 4402,
  [5318] = 4381,
  [5319] = 4353,
  [5320] = 4321,
  [5321] = 4395,
  [5322] = 4647,
  [5323] = 4321,
  [5324] = 4366,
  [5325] = 4472,
  [5326] = 4355,
  [5327] = 4529,
  [5328] = 3987,
  [5329] = 4387,
  [5330] = 4529,
  [5331] = 4538,
  [5332] = 4321,
  [5333] = 4642,
  [5334] = 4474,
  [5335] = 4591,
  [5336] = 4858,
  [5337] = 4353,
  [5338] = 4434,
  [5339] = 4362,
  [5340] = 4318,
  [5341] = 5341,
  [5342] = 4474,
  [5343] = 4354,
  [5344] = 3985,
  [5345] = 4353,
  [5346] = 4642,
  [5347] = 4529,
  [5348] = 4709,
  [5349] = 4642,
  [5350] = 4354,
  [5351] = 4647,
  [5352] = 4529,
  [5353] = 4591,
  [5354] = 4647,
  [5355] = 4595,
  [5356] = 4397,
  [5357] = 4417,
  [5358] = 4656,
  [5359] = 4656,
  [5360] = 4529,
  [5361] = 5139,
  [5362] = 4472,
  [5363] = 4682,
  [5364] = 4336,
  [5365] = 5123,
  [5366] = 4709,
  [5367] = 4682,
  [5368] = 4434,
  [5369] = 4538,
  [5370] = 4474,
  [5371] = 4472,
  [5372] = 4336,
  [5373] = 4474,
  [5374] = 4336,
  [5375] = 3987,
  [5376] = 4538,
  [5377] = 5110,
  [5378] = 4353,
  [5379] = 4336,
  [5380] = 4355,
  [5381] = 4472,
  [5382] = 4474,
  [5383] = 4656,
  [5384] = 4591,
  [5385] = 3985,
  [5386] = 4472,
  [5387] = 4321,
  [5388] = 4656,
  [5389] = 4321,
  [5390] = 4340,
  [5391] = 4925,
  [5392] = 4902,
  [5393] = 4647,
  [5394] = 4642,
  [5395] = 4351,
  [5396] = 5396,
  [5397] = 4351,
  [5398] = 4417,
  [5399] = 4417,
  [5400] = 4647,
  [5401] = 4351,
  [5402] = 4504,
  [5403] = 4336,
  [5404] = 4642,
  [5405] = 4386,
  [5406] = 4538,
  [5407] = 4656,
  [5408] = 4798,
  [5409] = 4417,
  [5410] = 4348,
  [5411] = 4647,
  [5412] = 4362,
  [5413] = 4538,
  [5414] = 4642,
  [5415] = 4902,
  [5416] = 4387,
  [5417] = 4336,
  [5418] = 4381,
  [5419] = 4402,
  [5420] = 4417,
  [5421] = 4439,
  [5422] = 5422,
  [5423] = 4504,
  [5424] = 4355,
  [5425] = 4336,
  [5426] = 5426,
  [5427] = 4474,
  [5428] = 4362,
  [5429] = 4387,
  [5430] = 4372,
  [5431] = 4925,
  [5432] = 3987,
  [5433] = 4485,
  [5434] = 4472,
  [5435] = 4366,
  [5436] = 4354,
  [5437] = 4395,
  [5438] = 4381,
  [5439] = 4409,
  [5440] = 4402,
  [5441] = 4538,
  [5442] = 4591,
  [5443] = 4340,
  [5444] = 4439,
  [5445] = 4355,
  [5446] = 4386,
  [5447] = 4353,
  [5448] = 4372,
  [5449] = 4325,
  [5450] = 3985,
  [5451] = 4709,
  [5452] = 4482,
  [5453] = 4721,
  [5454] = 4397,
  [5455] = 4417,
  [5456] = 4366,
  [5457] = 4395,
  [5458] = 4858,
  [5459] = 4336,
  [5460] = 4409,
  [5461] = 4318,
  [5462] = 4325,
  [5463] = 4372,
  [5464] = 4336,
  [5465] = 4820,
  [5466] = 4682,
  [5467] = 4386,
  [5468] = 4355,
  [5469] = 5469,
  [5470] = 4355,
  [5471] = 4353,
  [5472] = 4439,
  [5473] = 4336,
  [5474] = 4402,
  [5475] = 3985,
  [5476] = 4318,
  [5477] = 4381,
  [5478] = 4387,
  [5479] = 4925,
  [5480] = 4362,
  [5481] = 3987,
  [5482] = 4351,
  [5483] = 4355,
  [5484] = 4417,
  [5485] = 4434,
  [5486] = 4858,
  [5487] = 4318,
  [5488] = 5488,
  [5489] = 4336,
  [5490] = 4353,
  [5491] = 4325,
  [5492] = 4485,
  [5493] = 4355,
  [5494] = 4595,
  [5495] = 4348,
  [5496] = 5496,
  [5497] = 3987,
  [5498] = 3985,
  [5499] = 5499,
  [5500] = 4474,
  [5501] = 5139,
  [5502] = 4820,
  [5503] = 5499,
  [5504] = 4206,
  [5505] = 4439,
  [5506] = 4434,
  [5507] = 4858,
  [5508] = 4397,
  [5509] = 5499,
  [5510] = 4318,
  [5511] = 4595,
  [5512] = 4355,
  [5513] = 5499,
  [5514] = 5185,
  [5515] = 4472,
  [5516] = 5184,
  [5517] = 4366,
  [5518] = 3987,
  [5519] = 4395,
  [5520] = 4340,
  [5521] = 3985,
  [5522] = 4472,
  [5523] = 4353,
  [5524] = 5182,
  [5525] = 4372,
  [5526] = 5426,
  [5527] = 3987,
  [5528] = 4474,
  [5529] = 4395,
  [5530] = 4591,
  [5531] = 4409,
  [5532] = 5422,
  [5533] = 5499,
  [5534] = 4386,
  [5535] = 5535,
  [5536] = 4351,
  [5537] = 4372,
  [5538] = 5499,
  [5539] = 5539,
  [5540] = 5540,
  [5541] = 4656,
  [5542] = 5123,
  [5543] = 4434,
  [5544] = 4902,
  [5545] = 4434,
  [5546] = 4591,
  [5547] = 4434,
  [5548] = 5548,
  [5549] = 4858,
  [5550] = 4325,
  [5551] = 4925,
  [5552] = 5499,
  [5553] = 5499,
  [5554] = 5488,
  [5555] = 5312,
  [5556] = 4902,
  [5557] = 4647,
  [5558] = 4439,
  [5559] = 5499,
  [5560] = 4353,
  [5561] = 4642,
  [5562] = 4355,
  [5563] = 5499,
  [5564] = 4925,
  [5565] = 4366,
  [5566] = 4902,
  [5567] = 4409,
  [5568] = 4858,
  [5569] = 4902,
  [5570] = 4472,
  [5571] = 4351,
  [5572] = 5499,
  [5573] = 4336,
  [5574] = 4395,
  [5575] = 4721,
  [5576] = 5576,
  [5577] = 5577,
  [5578] = 4902,
  [5579] = 4366,
  [5580] = 4902,
  [5581] = 4472,
  [5582] = 5213,
  [5583] = 4417,
  [5584] = 5499,
  [5585] = 4381,
  [5586] = 4417,
  [5587] = 4402,
  [5588] = 4472,
  [5589] = 5139,
  [5590] = 4336,
  [5591] = 5469,
  [5592] = 4529,
  [5593] = 4642,
  [5594] = 4325,
  [5595] = 4538,
  [5596] = 4402,
  [5597] = 4353,
  [5598] = 4381,
  [5599] = 4642,
  [5600] = 4417,
  [5601] = 4325,
  [5602] = 4647,
  [5603] = 4858,
  [5604] = 5123,
  [5605] = 4366,
  [5606] = 4395,
  [5607] = 4409,
  [5608] = 4355,
  [5609] = 4902,
  [5610] = 5499,
  [5611] = 5611,
  [5612] = 4647,
  [5613] = 4336,
  [5614] = 4434,
  [5615] = 5499,
  [5616] = 4925,
  [5617] = 4656,
  [5618] = 5499,
  [5619] = 4474,
  [5620] = 4656,
  [5621] = 4474,
  [5622] = 4353,
  [5623] = 4820,
  [5624] = 4387,
  [5625] = 4504,
  [5626] = 5499,
  [5627] = 4434,
  [5628] = 5628,
  [5629] = 4362,
  [5630] = 4336,
  [5631] = 4387,
  [5632] = 5499,
  [5633] = 4538,
  [5634] = 4595,
  [5635] = 5635,
  [5636] = 4647,
  [5637] = 4362,
  [5638] = 4355,
  [5639] = 5499,
  [5640] = 4642,
  [5641] = 5312,
  [5642] = 5499,
  [5643] = 4321,
  [5644] = 4417,
  [5645] = 4362,
  [5646] = 5646,
  [5647] = 5647,
  [5648] = 4353,
  [5649] = 4474,
  [5650] = 5650,
  [5651] = 4336,
  [5652] = 4474,
  [5653] = 5312,
  [5654] = 4206,
  [5655] = 4434,
  [5656] = 4321,
  [5657] = 5657,
  [5658] = 4325,
  [5659] = 5499,
  [5660] = 5499,
  [5661] = 4858,
  [5662] = 4348,
  [5663] = 4472,
  [5664] = 5664,
  [5665] = 5665,
  [5666] = 4472,
  [5667] = 5182,
  [5668] = 5184,
  [5669] = 5185,
  [5670] = 4321,
  [5671] = 4902,
  [5672] = 4538,
  [5673] = 3985,
  [5674] = 4318,
  [5675] = 4925,
  [5676] = 5496,
  [5677] = 4336,
  [5678] = 4372,
  [5679] = 5679,
  [5680] = 4591,
  [5681] = 5499,
  [5682] = 5499,
  [5683] = 4538,
  [5684] = 5499,
  [5685] = 5499,
  [5686] = 5499,
  [5687] = 4434,
  [5688] = 4397,
  [5689] = 4386,
  [5690] = 4366,
  [5691] = 5499,
  [5692] = 4474,
  [5693] = 5499,
  [5694] = 5422,
  [5695] = 4351,
  [5696] = 4386,
  [5697] = 5426,
  [5698] = 4538,
  [5699] = 4642,
  [5700] = 4395,
  [5701] = 5396,
  [5702] = 5499,
  [5703] = 4409,
  [5704] = 4325,
  [5705] = 4647,
  [5706] = 5499,
  [5707] = 4318,
  [5708] = 4538,
  [5709] = 5499,
  [5710] = 4656,
  [5711] = 4353,
  [5712] = 4355,
  [5713] = 4362,
  [5714] = 4925,
  [5715] = 3985,
  [5716] = 4485,
  [5717] = 4351,
  [5718] = 4387,
  [5719] = 4504,
  [5720] = 4434,
  [5721] = 5499,
  [5722] = 4381,
  [5723] = 4434,
  [5724] = 4434,
  [5725] = 4820,
  [5726] = 5499,
  [5727] = 5284,
  [5728] = 4355,
  [5729] = 4402,
  [5730] = 5499,
  [5731] = 4439,
  [5732] = 5499,
  [5733] = 4417,
  [5734] = 4206,
  [5735] = 5295,
  [5736] = 4439,
  [5737] = 4827,
  [5738] = 4355,
  [5739] = 4656,
  [5740] = 4353,
  [5741] = 4353,
  [5742] = 5499,
  [5743] = 4372,
  [5744] = 4386,
  [5745] = 4439,
  [5746] = 5341,
  [5747] = 4402,
  [5748] = 4402,
  [5749] = 5228,
  [5750] = 5499,
  [5751] = 4381,
  [5752] = 5499,
  [5753] = 4656,
  [5754] = 4387,
  [5755] = 4351,
  [5756] = 4709,
  [5757] = 5757,
  [5758] = 5499,
  [5759] = 4372,
  [5760] = 5499,
  [5761] = 4482,
  [5762] = 4372,
  [5763] = 4355,
  [5764] = 5396,
  [5765] = 5488,
  [5766] = 4348,
  [5767] = 4351,
  [5768] = 5496,
  [5769] = 5499,
  [5770] = 5341,
  [5771] = 4902,
  [5772] = 4925,
  [5773] = 3985,
  [5774] = 4336,
  [5775] = 4529,
  [5776] = 4682,
  [5777] = 4642,
  [5778] = 4682,
  [5779] = 4434,
  [5780] = 3987,
  [5781] = 4647,
  [5782] = 3985,
  [5783] = 3987,
  [5784] = 5784,
  [5785] = 4354,
  [5786] = 4656,
  [5787] = 4709,
  [5788] = 4925,
  [5789] = 4656,
  [5790] = 5469,
  [5791] = 4474,
  [5792] = 4397,
  [5793] = 4647,
  [5794] = 4656,
  [5795] = 4321,
  [5796] = 4472,
  [5797] = 5295,
  [5798] = 5499,
  [5799] = 4925,
  [5800] = 3987,
  [5801] = 4472,
  [5802] = 4381,
  [5803] = 4353,
  [5804] = 4355,
  [5805] = 4387,
  [5806] = 4647,
  [5807] = 4642,
  [5808] = 4472,
  [5809] = 4362,
  [5810] = 3985,
  [5811] = 4474,
  [5812] = 3985,
  [5813] = 3987,
  [5814] = 5499,
  [5815] = 4591,
  [5816] = 4474,
  [5817] = 4798,
  [5818] = 4351,
  [5819] = 4827,
  [5820] = 4656,
  [5821] = 4482,
  [5822] = 4642,
  [5823] = 5469,
  [5824] = 3987,
  [5825] = 3985,
  [5826] = 5284,
  [5827] = 4647,
  [5828] = 5496,
  [5829] = 4354,
  [5830] = 4709,
  [5831] = 3987,
  [5832] = 4372,
  [5833] = 4353,
  [5834] = 4858,
  [5835] = 4354,
  [5836] = 3985,
  [5837] = 5499,
  [5838] = 4336,
  [5839] = 3987,
  [5840] = 4642,
  [5841] = 4417,
  [5842] = 5499,
  [5843] = 4682,
  [5844] = 5396,
  [5845] = 4325,
  [5846] = 5499,
  [5847] = 4902,
  [5848] = 4318,
  [5849] = 4434,
  [5850] = 5499,
  [5851] = 4355,
  [5852] = 4439,
  [5853] = 3985,
  [5854] = 4858,
  [5855] = 4434,
  [5856] = 4591,
  [5857] = 5499,
  [5858] = 4538,
  [5859] = 4351,
  [5860] = 4397,
  [5861] = 5861,
  [5862] = 3987,
  [5863] = 5341,
  [5864] = 4325,
  [5865] = 4402,
  [5866] = 4485,
  [5867] = 3985,
  [5868] = 3987,
  [5869] = 4355,
  [5870] = 4386,
  [5871] = 4381,
  [5872] = 3985,
  [5873] = 4858,
  [5874] = 5499,
  [5875] = 3987,
  [5876] = 4647,
  [5877] = 4354,
  [5878] = 4591,
  [5879] = 5295,
  [5880] = 4318,
  [5881] = 4387,
  [5882] = 3987,
  [5883] = 4355,
  [5884] = 5884,
  [5885] = 5499,
  [5886] = 3985,
  [5887] = 5887,
  [5888] = 4336,
  [5889] = 5123,
  [5890] = 4336,
  [5891] = 3985,
  [5892] = 5284,
  [5893] = 4409,
  [5894] = 4362,
  [5895] = 3987,
  [5896] = 4321,
  [5897] = 4529,
  [5898] = 5898,
  [5899] = 4529,
  [5900] = 4591,
  [5901] = 3985,
  [5902] = 4386,
  [5903] = 5499,
  [5904] = 4353,
  [5905] = 4439,
  [5906] = 4321,
  [5907] = 4402,
  [5908] = 5908,
  [5909] = 4902,
  [5910] = 4336,
  [5911] = 4355,
  [5912] = 5499,
  [5913] = 5422,
  [5914] = 4472,
  [5915] = 5426,
  [5916] = 4485,
  [5917] = 5139,
  [5918] = 4318,
  [5919] = 4529,
  [5920] = 4386,
  [5921] = 5499,
  [5922] = 4325,
  [5923] = 4381,
  [5924] = 4397,
  [5925] = 4386,
  [5926] = 4387,
  [5927] = 4362,
  [5928] = 5499,
  [5929] = 3985,
  [5930] = 4362,
  [5931] = 4482,
  [5932] = 4387,
  [5933] = 4434,
  [5934] = 4381,
  [5935] = 4595,
  [5936] = 4351,
  [5937] = 5499,
  [5938] = 4402,
  [5939] = 3987,
  [5940] = 4529,
  [5941] = 4642,
  [5942] = 4325,
  [5943] = 4439,
  [5944] = 4353,
  [5945] = 4353,
  [5946] = 4318,
  [5947] = 4709,
  [5948] = 4721,
  [5949] = 5949,
  [5950] = 4409,
  [5951] = 4372,
  [5952] = 5139,
  [5953] = 4318,
  [5954] = 4682,
  [5955] = 4321,
  [5956] = 4395,
  [5957] = 4366,
  [5958] = 4354,
  [5959] = 4409,
  [5960] = 4395,
  [5961] = 4366,
  [5962] = 5213,
  [5963] = 4354,
  [5964] = 4325,
  [5965] = 4321,
  [5966] = 4485,
  [5967] = 3987,
  [5968] = 4709,
  [5969] = 4336,
  [5970] = 4647,
  [5971] = 4721,
  [5972] = 4591,
  [5973] = 5973,
  [5974] = 4397,
  [5975] = 3987,
  [5976] = 4372,
  [5977] = 3985,
  [5978] = 5978,
  [5979] = 3987,
  [5980] = 3985,
  [5981] = 4318,
  [5982] = 4351,
  [5983] = 4656,
  [5984] = 4402,
  [5985] = 4397,
  [5986] = 4529,
  [5987] = 4351,
  [5988] = 4386,
  [5989] = 4434,
  [5990] = 4439,
  [5991] = 4318,
  [5992] = 4354,
  [5993] = 5185,
  [5994] = 4409,
  [5995] = 4682,
  [5996] = 5184,
  [5997] = 4798,
  [5998] = 4395,
  [5999] = 5499,
  [6000] = 4354,
  [6001] = 4709,
  [6002] = 5499,
  [6003] = 5499,
  [6004] = 4538,
  [6005] = 5182,
  [6006] = 4366,
  [6007] = 4682,
  [6008] = 5499,
  [6009] = 4417,
  [6010] = 5123,
  [6011] = 4417,
  [6012] = 5499,
  [6013] = 4591,
  [6014] = 5123,
  [6015] = 4538,
  [6016] = 4381,
  [6017] = 4397,
  [6018] = 5499,
  [6019] = 4409,
  [6020] = 4395,
  [6021] = 4321,
  [6022] = 4366,
  [6023] = 4656,
  [6024] = 4397,
  [6025] = 5228,
  [6026] = 5499,
  [6027] = 4318,
  [6028] = 3985,
  [6029] = 4372,
  [6030] = 4387,
  [6031] = 4902,
  [6032] = 4366,
  [6033] = 4417,
  [6034] = 4318,
  [6035] = 4321,
  [6036] = 4434,
  [6037] = 4362,
  [6038] = 4439,
  [6039] = 4482,
  [6040] = 4647,
  [6041] = 4827,
  [6042] = 4472,
  [6043] = 4351,
  [6044] = 4397,
  [6045] = 4353,
  [6046] = 5499,
  [6047] = 4355,
  [6048] = 4538,
  [6049] = 5499,
  [6050] = 5499,
  [6051] = 4402,
  [6052] = 4642,
  [6053] = 5139,
  [6054] = 4381,
  [6055] = 6055,
  [6056] = 4395,
  [6057] = 4351,
  [6058] = 5488,
  [6059] = 4354,
  [6060] = 3987,
  [6061] = 5499,
  [6062] = 4321,
  [6063] = 4387,
  [6064] = 5499,
  [6065] = 4417,
  [6066] = 4474,
  [6067] = 4434,
  [6068] = 4362,
  [6069] = 3985,
  [6070] = 4321,
  [6071] = 4321,
  [6072] = 3987,
  [6073] = 4642,
  [6074] = 4798,
  [6075] = 4504,
  [6076] = 4474,
  [6077] = 4336,
  [6078] = 4386,
  [6079] = 4366,
  [6080] = 4340,
  [6081] = 4591,
  [6082] = 4395,
  [6083] = 4504,
  [6084] = 4409,
  [6085] = 4351,
  [6086] = 4595,
  [6087] = 4591,
  [6088] = 4318,
  [6089] = 4354,
  [6090] = 4472,
  [6091] = 5499,
  [6092] = 4321,
  [6093] = 4538,
  [6094] = 4474,
  [6095] = 5499,
  [6096] = 4529,
  [6097] = 4472,
  [6098] = 4529,
  [6099] = 4409,
  [6100] = 4353,
  [6101] = 4474,
  [6102] = 4353,
  [6103] = 5499,
  [6104] = 4318,
  [6105] = 4354,
  [6106] = 4642,
  [6107] = 4417,
  [6108] = 5539,
  [6109] = 5426,
  [6110] = 4372,
  [6111] = 4381,
  [6112] = 5576,
  [6113] = 5540,
  [6114] = 4362,
  [6115] = 4439,
  [6116] = 4439,
  [6117] = 4351,
  [6118] = 4656,
  [6119] = 4642,
  [6120] = 5182,
  [6121] = 4387,
  [6122] = 4354,
  [6123] = 4647,
  [6124] = 4925,
  [6125] = 5396,
  [6126] = 5295,
  [6127] = 4362,
  [6128] = 4820,
  [6129] = 4387,
  [6130] = 4591,
  [6131] = 4354,
  [6132] = 4647,
  [6133] = 4439,
  [6134] = 4362,
  [6135] = 5577,
  [6136] = 4351,
  [6137] = 5184,
  [6138] = 4386,
  [6139] = 5908,
  [6140] = 4372,
  [6141] = 5185,
  [6142] = 5422,
  [6143] = 4402,
  [6144] = 4381,
  [6145] = 4402,
  [6146] = 4381,
  [6147] = 4372,
  [6148] = 4595,
  [6149] = 4434,
  [6150] = 4482,
  [6151] = 5228,
  [6152] = 5496,
  [6153] = 4656,
  [6154] = 4529,
  [6155] = 4351,
  [6156] = 4366,
  [6157] = 4386,
  [6158] = 4656,
  [6159] = 4206,
  [6160] = 4387,
  [6161] = 4529,
  [6162] = 4395,
  [6163] = 4439,
  [6164] = 4366,
  [6165] = 4325,
  [6166] = 4395,
  [6167] = 4362,
  [6168] = 4417,
  [6169] = 4409,
  [6170] = 4386,
  [6171] = 5887,
  [6172] = 4409,
  [6173] = 4402,
  [6174] = 4372,
  [6175] = 4206,
  [6176] = 4386,
  [6177] = 4318,
  [6178] = 4381,
  [6179] = 4387,
  [6180] = 3985,
  [6181] = 3985,
  [6182] = 4591,
  [6183] = 5898,
  [6184] = 4642,
  [6185] = 5228,
  [6186] = 5396,
  [6187] = 5784,
  [6188] = 4381,
  [6189] = 4386,
  [6190] = 4925,
  [6191] = 4595,
  [6192] = 4366,
  [6193] = 4395,
  [6194] = 4318,
  [6195] = 4409,
  [6196] = 4647,
  [6197] = 4485,
  [6198] = 5861,
  [6199] = 4858,
  [6200] = 3987,
  [6201] = 4721,
  [6202] = 5312,
  [6203] = 4402,
  [6204] = 5341,
  [6205] = 4538,
  [6206] = 5396,
  [6207] = 3985,
  [6208] = 4417,
  [6209] = 4538,
  [6210] = 4656,
  [6211] = 4366,
  [6212] = 4656,
  [6213] = 4386,
  [6214] = 4647,
  [6215] = 5284,
  [6216] = 4387,
  [6217] = 4529,
  [6218] = 4642,
  [6219] = 4318,
  [6220] = 4529,
  [6221] = 6055,
  [6222] = 4529,
  [6223] = 5213,
  [6224] = 4318,
  [6225] = 4372,
  [6226] = 4591,
  [6227] = 3985,
  [6228] = 5422,
  [6229] = 4709,
  [6230] = 4925,
  [6231] = 4336,
  [6232] = 3987,
  [6233] = 4318,
  [6234] = 4682,
  [6235] = 5426,
  [6236] = 4318,
  [6237] = 4355,
  [6238] = 4417,
  [6239] = 4397,
  [6240] = 5548,
  [6241] = 5611,
  [6242] = 4362,
  [6243] = 5949,
  [6244] = 4439,
  [6245] = 4366,
  [6246] = 6246,
  [6247] = 4325,
  [6248] = 4395,
  [6249] = 5341,
  [6250] = 4409,
  [6251] = 4529,
  [6252] = 5284,
  [6253] = 4417,
  [6254] = 4642,
  [6255] = 4351,
  [6256] = 6246,
  [6257] = 4325,
  [6258] = 4325,
  [6259] = 5182,
  [6260] = 4325,
  [6261] = 4647,
  [6262] = 5884,
  [6263] = 4721,
  [6264] = 4397,
  [6265] = 4925,
  [6266] = 5496,
  [6267] = 4321,
  [6268] = 3987,
  [6269] = 4902,
  [6270] = 4417,
  [6271] = 4656,
  [6272] = 4362,
  [6273] = 4902,
  [6274] = 4902,
  [6275] = 4354,
  [6276] = 4387,
  [6277] = 4538,
  [6278] = 4395,
  [6279] = 4409,
  [6280] = 4591,
  [6281] = 5628,
  [6282] = 4353,
  [6283] = 4355,
  [6284] = 4591,
  [6285] = 4381,
  [6286] = 4858,
  [6287] = 4325,
  [6288] = 4355,
  [6289] = 4321,
  [6290] = 4318,
  [6291] = 3985,
  [6292] = 4318,
  [6293] = 5973,
  [6294] = 4353,
  [6295] = 4397,
  [6296] = 4538,
  [6297] = 4402,
  [6298] = 4529,
  [6299] = 5535,
  [6300] = 4409,
  [6301] = 4858,
  [6302] = 4709,
  [6303] = 4366,
  [6304] = 4395,
  [6305] = 5295,
  [6306] = 4682,
  [6307] = 5139,
  [6308] = 5978,
  [6309] = 5295,
  [6310] = 5295,
  [6311] = 4504,
  [6312] = 4439,
  [6313] = 4474,
  [6314] = 4325,
  [6315] = 4366,
  [6316] = 5123,
  [6317] = 4472,
  [6318] = 4366,
  [6319] = 4321,
  [6320] = 4472,
  [6321] = 4395,
  [6322] = 4538,
  [6323] = 4709,
  [6324] = 4682,
  [6325] = 4798,
  [6326] = 4409,
  [6327] = 3987,
  [6328] = 3987,
  [6329] = 4351,
  [6330] = 3987,
  [6331] = 4321,
  [6332] = 5422,
  [6333] = 5426,
  [6334] = 4417,
  [6335] = 4321,
  [6336] = 4474,
  [6337] = 4351,
  [6338] = 5139,
  [6339] = 4372,
  [6340] = 5635,
  [6341] = 4395,
  [6342] = 5284,
  [6343] = 4351,
  [6344] = 3985,
  [6345] = 4902,
  [6346] = 4591,
  [6347] = 3987,
  [6348] = 4925,
  [6349] = 4642,
  [6350] = 4591,
  [6351] = 3985,
  [6352] = 4439,
  [6353] = 3987,
  [6354] = 4647,
  [6355] = 5123,
  [6356] = 5123,
  [6357] = 3987,
  [6358] = 5284,
  [6359] = 5185,
  [6360] = 4402,
  [6361] = 4409,
  [6362] = 5184,
  [6363] = 4656,
  [6364] = 4325,
  [6365] = 5182,
  [6366] = 5123,
  [6367] = 4381,
  [6368] = 4474,
  [6369] = 4387,
  [6370] = 4798,
  [6371] = 4472,
  [6372] = 4362,
  [6373] = 3985,
  [6374] = 4362,
  [6375] = 5341,
  [6376] = 3987,
  [6377] = 4485,
  [6378] = 4529,
  [6379] = 4372,
  [6380] = 4925,
  [6381] = 3985,
  [6382] = 4386,
  [6383] = 4386,
  [6384] = 4325,
  [6385] = 3987,
  [6386] = 4318,
  [6387] = 5535,
  [6388] = 4351,
  [6389] = 4372,
  [6390] = 4474,
  [6391] = 4397,
  [6392] = 4538,
  [6393] = 3985,
  [6394] = 4353,
  [6395] = 4354,
  [6396] = 4321,
  [6397] = 4439,
  [6398] = 4538,
  [6399] = 3987,
  [6400] = 4387,
  [6401] = 4372,
  [6402] = 4354,
  [6403] = 3985,
  [6404] = 3987,
  [6405] = 4504,
  [6406] = 5184,
  [6407] = 4820,
  [6408] = 5312,
  [6409] = 4386,
  [6410] = 4402,
  [6411] = 4336,
  [6412] = 4325,
  [6413] = 4656,
  [6414] = 3985,
  [6415] = 4355,
  [6416] = 4381,
  [6417] = 3985,
  [6418] = 3987,
  [6419] = 5576,
  [6420] = 5577,
  [6421] = 4206,
  [6422] = 3985,
  [6423] = 4439,
  [6424] = 4366,
  [6425] = 4538,
  [6426] = 4387,
  [6427] = 4402,
  [6428] = 4351,
  [6429] = 4472,
  [6430] = 4858,
  [6431] = 4381,
  [6432] = 4325,
  [6433] = 4353,
  [6434] = 4381,
  [6435] = 4402,
  [6436] = 4387,
  [6437] = 5887,
  [6438] = 4362,
  [6439] = 4362,
  [6440] = 6440,
  [6441] = 4402,
  [6442] = 4591,
  [6443] = 3985,
  [6444] = 5908,
  [6445] = 4827,
  [6446] = 5184,
  [6447] = 5185,
  [6448] = 4417,
  [6449] = 4397,
  [6450] = 4595,
  [6451] = 5488,
  [6452] = 5341,
  [6453] = 5611,
  [6454] = 5784,
  [6455] = 5898,
  [6456] = 4647,
  [6457] = 3987,
  [6458] = 4336,
  [6459] = 4318,
  [6460] = 4474,
  [6461] = 4386,
  [6462] = 5312,
  [6463] = 5861,
  [6464] = 6464,
  [6465] = 4647,
  [6466] = 4472,
  [6467] = 4858,
  [6468] = 4321,
  [6469] = 4472,
  [6470] = 4353,
  [6471] = 4474,
  [6472] = 4318,
  [6473] = 5647,
  [6474] = 4355,
  [6475] = 5628,
  [6476] = 4409,
  [6477] = 4409,
  [6478] = 4409,
  [6479] = 4656,
  [6480] = 4474,
  [6481] = 4417,
  [6482] = 4682,
  [6483] = 4474,
  [6484] = 4858,
  [6485] = 5635,
  [6486] = 4362,
  [6487] = 4354,
  [6488] = 4538,
  [6489] = 4395,
  [6490] = 5540,
  [6491] = 4395,
  [6492] = 4387,
  [6493] = 4858,
  [6494] = 4472,
  [6495] = 4591,
  [6496] = 4318,
  [6497] = 4472,
  [6498] = 4366,
  [6499] = 4351,
  [6500] = 6500,
  [6501] = 4395,
  [6502] = 5539,
  [6503] = 5185,
  [6504] = 5396,
  [6505] = 4709,
  [6506] = 6506,
  [6507] = 6507,
  [6508] = 6508,
  [6509] = 6509,
  [6510] = 4472,
  [6511] = 4381,
  [6512] = 4366,
  [6513] = 4439,
  [6514] = 5646,
  [6515] = 4538,
  [6516] = 4348,
  [6517] = 4321,
  [6518] = 4402,
  [6519] = 4321,
  [6520] = 4397,
  [6521] = 5228,
  [6522] = 4417,
  [6523] = 4434,
  [6524] = 6524,
  [6525] = 4798,
  [6526] = 4902,
  [6527] = 4642,
  [6528] = 3985,
  [6529] = 4474,
  [6530] = 5312,
  [6531] = 4372,
  [6532] = 5646,
  [6533] = 4485,
  [6534] = 5647,
  [6535] = 4417,
  [6536] = 5488,
  [6537] = 3987,
  [6538] = 5650,
  [6539] = 4321,
  [6540] = 5657,
  [6541] = 4591,
  [6542] = 4591,
  [6543] = 4355,
  [6544] = 4353,
  [6545] = 4902,
  [6546] = 4366,
  [6547] = 6547,
  [6548] = 4366,
  [6549] = 4439,
  [6550] = 4439,
  [6551] = 4395,
  [6552] = 4642,
  [6553] = 5650,
  [6554] = 4409,
  [6555] = 4386,
  [6556] = 5784,
  [6557] = 5664,
  [6558] = 4538,
  [6559] = 4353,
  [6560] = 4397,
  [6561] = 4353,
  [6562] = 4402,
  [6563] = 4647,
  [6564] = 4529,
  [6565] = 4372,
  [6566] = 4386,
  [6567] = 4372,
  [6568] = 4381,
  [6569] = 5213,
  [6570] = 4482,
  [6571] = 4656,
  [6572] = 5665,
  [6573] = 4656,
  [6574] = 4351,
  [6575] = 3987,
  [6576] = 3987,
  [6577] = 4798,
  [6578] = 4387,
  [6579] = 3985,
  [6580] = 3985,
  [6581] = 5949,
  [6582] = 4351,
  [6583] = 5679,
  [6584] = 4362,
  [6585] = 5469,
  [6586] = 4387,
  [6587] = 4381,
  [6588] = 4336,
  [6589] = 3985,
  [6590] = 5139,
  [6591] = 4362,
  [6592] = 5496,
  [6593] = 4647,
  [6594] = 4858,
  [6595] = 4325,
  [6596] = 3987,
  [6597] = 4595,
  [6598] = 4721,
  [6599] = 5123,
  [6600] = 4642,
  [6601] = 4336,
  [6602] = 4402,
  [6603] = 4439,
  [6604] = 4925,
  [6605] = 4366,
  [6606] = 5973,
  [6607] = 4647,
  [6608] = 5978,
  [6609] = 4538,
  [6610] = 4318,
  [6611] = 4409,
  [6612] = 4336,
  [6613] = 4386,
  [6614] = 5488,
  [6615] = 4386,
  [6616] = 4395,
  [6617] = 4366,
  [6618] = 4372,
  [6619] = 4351,
  [6620] = 4353,
  [6621] = 4858,
  [6622] = 4206,
  [6623] = 4472,
  [6624] = 4355,
  [6625] = 5548,
  [6626] = 4434,
  [6627] = 5469,
  [6628] = 5488,
  [6629] = 4591,
  [6630] = 5657,
  [6631] = 5139,
  [6632] = 3985,
  [6633] = 4325,
  [6634] = 4318,
  [6635] = 5884,
  [6636] = 4474,
  [6637] = 4656,
  [6638] = 4482,
  [6639] = 4656,
  [6640] = 4902,
  [6641] = 4474,
  [6642] = 4351,
  [6643] = 4351,
  [6644] = 4434,
  [6645] = 4417,
  [6646] = 4827,
  [6647] = 6246,
  [6648] = 4395,
  [6649] = 4395,
  [6650] = 4642,
  [6651] = 5496,
  [6652] = 5123,
  [6653] = 4321,
  [6654] = 4591,
  [6655] = 4642,
  [6656] = 4397,
  [6657] = 4529,
  [6658] = 5469,
  [6659] = 5396,
  [6660] = 4355,
  [6661] = 4472,
  [6662] = 4321,
  [6663] = 4409,
  [6664] = 6055,
  [6665] = 5341,
  [6666] = 4647,
  [6667] = 4353,
  [6668] = 4318,
  [6669] = 4827,
  [6670] = 5664,
  [6671] = 5422,
  [6672] = 4642,
  [6673] = 4925,
  [6674] = 5426,
  [6675] = 4902,
  [6676] = 4482,
  [6677] = 4372,
  [6678] = 3985,
  [6679] = 4647,
  [6680] = 4434,
  [6681] = 5295,
  [6682] = 4820,
  [6683] = 4362,
  [6684] = 5139,
  [6685] = 4434,
  [6686] = 4387,
  [6687] = 4434,
  [6688] = 4336,
  [6689] = 5284,
  [6690] = 4354,
  [6691] = 4709,
  [6692] = 4386,
  [6693] = 4318,
  [6694] = 4409,
  [6695] = 4409,
  [6696] = 4351,
  [6697] = 4538,
  [6698] = 4682,
  [6699] = 4395,
  [6700] = 4355,
  [6701] = 5469,
  [6702] = 4591,
  [6703] = 4902,
  [6704] = 4827,
  [6705] = 4366,
  [6706] = 4902,
  [6707] = 4417,
  [6708] = 4472,
  [6709] = 4318,
  [6710] = 4902,
  [6711] = 4434,
  [6712] = 4474,
  [6713] = 4354,
  [6714] = 5123,
  [6715] = 4321,
  [6716] = 4321,
  [6717] = 3987,
  [6718] = 4504,
  [6719] = 4472,
  [6720] = 4709,
  [6721] = 5213,
  [6722] = 4902,
  [6723] = 4325,
  [6724] = 4642,
  [6725] = 4472,
  [6726] = 4434,
  [6727] = 4325,
  [6728] = 4355,
  [6729] = 5182,
  [6730] = 3987,
  [6731] = 4682,
  [6732] = 5139,
  [6733] = 4336,
  [6734] = 4321,
  [6735] = 6735,
  [6736] = 4474,
  [6737] = 4709,
  [6738] = 4340,
  [6739] = 4402,
  [6740] = 5139,
  [6741] = 4362,
  [6742] = 4439,
  [6743] = 4642,
  [6744] = 4682,
  [6745] = 4439,
  [6746] = 4321,
  [6747] = 4387,
  [6748] = 4656,
  [6749] = 4827,
  [6750] = 4925,
  [6751] = 4434,
  [6752] = 4417,
  [6753] = 4485,
  [6754] = 4647,
  [6755] = 4366,
  [6756] = 4647,
  [6757] = 4381,
  [6758] = 5139,
  [6759] = 4395,
  [6760] = 4721,
  [6761] = 4642,
  [6762] = 5679,
  [6763] = 4409,
  [6764] = 4353,
  [6765] = 4902,
  [6766] = 4402,
  [6767] = 4902,
  [6768] = 4656,
  [6769] = 5123,
  [6770] = 4474,
  [6771] = 4397,
  [6772] = 5665,
  [6773] = 5496,
  [6774] = 4381,
  [6775] = 4372,
  [6776] = 4355,
  [6777] = 4336,
  [6778] = 4417,
  [6779] = 4362,
  [6780] = 4417,
  [6781] = 4827,
  [6782] = 4902,
  [6783] = 4336,
  [6784] = 4709,
  [6785] = 4529,
  [6786] = 4925,
  [6787] = 4682,
  [6788] = 4474,
  [6789] = 4472,
  [6790] = 4538,
  [6791] = 5182,
  [6792] = 4656,
  [6793] = 4647,
  [6794] = 4538,
  [6795] = 4351,
  [6796] = 4642,
  [6797] = 4355,
  [6798] = 5152,
  [6799] = 4386,
  [6800] = 4647,
  [6801] = 4434,
  [6802] = 3985,
  [6803] = 4355,
  [6804] = 4538,
  [6805] = 4709,
  [6806] = 4434,
  [6807] = 4474,
  [6808] = 4386,
  [6809] = 4351,
  [6810] = 4472,
  [6811] = 5496,
  [6812] = 5123,
  [6813] = 4321,
  [6814] = 4902,
  [6815] = 4409,
  [6816] = 5396,
  [6817] = 4642,
  [6818] = 4682,
  [6819] = 4395,
  [6820] = 4318,
  [6821] = 4434,
  [6822] = 5784,
  [6823] = 5341,
  [6824] = 4321,
  [6825] = 6825,
  [6826] = 4827,
  [6827] = 4902,
  [6828] = 4366,
  [6829] = 4362,
  [6830] = 4366,
  [6831] = 4682,
  [6832] = 5139,
  [6833] = 4355,
  [6834] = 6834,
  [6835] = 4642,
  [6836] = 4395,
  [6837] = 5295,
  [6838] = 3987,
  [6839] = 4409,
  [6840] = 4647,
  [6841] = 4395,
  [6842] = 6842,
  [6843] = 5284,
  [6844] = 6842,
  [6845] = 5679,
  [6846] = 5665,
  [6847] = 5496,
  [6848] = 4387,
  [6849] = 4366,
  [6850] = 4709,
  [6851] = 4409,
  [6852] = 3987,
  [6853] = 4591,
  [6854] = 4321,
  [6855] = 5664,
  [6856] = 4529,
  [6857] = 4321,
  [6858] = 5657,
  [6859] = 5184,
  [6860] = 5185,
  [6861] = 4381,
  [6862] = 4656,
  [6863] = 5650,
  [6864] = 6834,
  [6865] = 4417,
  [6866] = 5647,
  [6867] = 5646,
  [6868] = 5312,
  [6869] = 5396,
  [6870] = 4402,
  [6871] = 4656,
  [6872] = 4351,
  [6873] = 4591,
  [6874] = 5635,
  [6875] = 4318,
  [6876] = 4474,
  [6877] = 4362,
  [6878] = 5628,
  [6879] = 6879,
  [6880] = 4472,
  [6881] = 4709,
  [6882] = 4336,
  [6883] = 5611,
  [6884] = 5341,
  [6885] = 5422,
  [6886] = 5426,
  [6887] = 6834,
  [6888] = 5784,
  [6889] = 4439,
  [6890] = 3985,
  [6891] = 5139,
  [6892] = 4387,
  [6893] = 4381,
  [6894] = 4682,
  [6895] = 4858,
  [6896] = 4858,
  [6897] = 4902,
  [6898] = 5123,
  [6899] = 5185,
  [6900] = 5184,
  [6901] = 4827,
  [6902] = 4402,
  [6903] = 4529,
  [6904] = 4397,
  [6905] = 6842,
  [6906] = 4682,
  [6907] = 4386,
  [6908] = 4355,
  [6909] = 5139,
  [6910] = 4318,
  [6911] = 4439,
  [6912] = 5182,
  [6913] = 4318,
  [6914] = 4325,
  [6915] = 4372,
  [6916] = 6055,
  [6917] = 5577,
  [6918] = 5576,
  [6919] = 5123,
  [6920] = 5488,
  [6921] = 3985,
  [6922] = 4434,
  [6923] = 4682,
  [6924] = 4372,
  [6925] = 3987,
  [6926] = 5978,
  [6927] = 5228,
  [6928] = 4709,
  [6929] = 5228,
  [6930] = 4362,
  [6931] = 4682,
  [6932] = 5973,
  [6933] = 5295,
  [6934] = 5469,
  [6935] = 5139,
  [6936] = 5784,
  [6937] = 4827,
  [6938] = 5548,
  [6939] = 4827,
  [6940] = 4827,
  [6941] = 6834,
  [6942] = 4321,
  [6943] = 4387,
  [6944] = 5123,
  [6945] = 4709,
  [6946] = 4902,
  [6947] = 4656,
  [6948] = 4417,
  [6949] = 5535,
  [6950] = 5123,
  [6951] = 5540,
  [6952] = 5539,
  [6953] = 5284,
  [6954] = 4366,
  [6955] = 4366,
  [6956] = 4647,
  [6957] = 4386,
  [6958] = 4395,
  [6959] = 5949,
  [6960] = 5884,
  [6961] = 4642,
  [6962] = 6842,
  [6963] = 4381,
  [6964] = 4482,
  [6965] = 4409,
  [6966] = 4395,
  [6967] = 4417,
  [6968] = 6055,
  [6969] = 4325,
  [6970] = 4642,
  [6971] = 4318,
  [6972] = 4372,
  [6973] = 4409,
  [6974] = 5898,
  [6975] = 4362,
  [6976] = 4386,
  [6977] = 5887,
  [6978] = 4355,
  [6979] = 4439,
  [6980] = 4402,
  [6981] = 4434,
  [6982] = 4538,
  [6983] = 4402,
  [6984] = 4387,
  [6985] = 4504,
  [6986] = 4485,
  [6987] = 4381,
  [6988] = 4387,
  [6989] = 4362,
  [6990] = 5139,
  [6991] = 4381,
  [6992] = 4439,
  [6993] = 4827,
  [6994] = 4504,
  [6995] = 4647,
  [6996] = 4902,
  [6997] = 4402,
  [6998] = 4353,
  [6999] = 5139,
  [7000] = 5539,
  [7001] = 5540,
  [7002] = 4439,
  [7003] = 5426,
  [7004] = 4709,
  [7005] = 4434,
  [7006] = 5422,
  [7007] = 4325,
  [7008] = 4472,
  [7009] = 4529,
  [7010] = 4372,
  [7011] = 4827,
  [7012] = 6825,
  [7013] = 4372,
  [7014] = 5123,
  [7015] = 5884,
  [7016] = 4721,
  [7017] = 4321,
  [7018] = 5679,
  [7019] = 7019,
  [7020] = 5548,
  [7021] = 4656,
  [7022] = 4595,
  [7023] = 4474,
  [7024] = 4318,
  [7025] = 5665,
  [7026] = 5908,
  [7027] = 6055,
  [7028] = 4318,
  [7029] = 4353,
  [7030] = 4354,
  [7031] = 5426,
  [7032] = 4504,
  [7033] = 5784,
  [7034] = 5422,
  [7035] = 4902,
  [7036] = 4798,
  [7037] = 4318,
  [7038] = 4351,
  [7039] = 4538,
  [7040] = 5123,
  [7041] = 5657,
  [7042] = 5861,
  [7043] = 5664,
  [7044] = 5650,
  [7045] = 5647,
  [7046] = 5646,
  [7047] = 5784,
  [7048] = 5312,
  [7049] = 4538,
  [7050] = 4354,
  [7051] = 5635,
  [7052] = 4325,
  [7053] = 5628,
  [7054] = 4529,
  [7055] = 4325,
  [7056] = 4355,
  [7057] = 5611,
  [7058] = 5139,
  [7059] = 4721,
  [7060] = 6842,
  [7061] = 4321,
  [7062] = 5469,
  [7063] = 4351,
  [7064] = 4353,
  [7065] = 4472,
  [7066] = 5228,
  [7067] = 5577,
  [7068] = 5576,
  [7069] = 5139,
  [7070] = 5496,
  [7071] = 4325,
  [7072] = 4409,
  [7073] = 4591,
  [7074] = 4206,
  [7075] = 4354,
  [7076] = 4417,
  [7077] = 4474,
  [7078] = 5488,
  [7079] = 4395,
  [7080] = 4529,
  [7081] = 5535,
  [7082] = 4366,
  [7083] = 6834,
  [7084] = 4372,
  [7085] = 4355,
  [7086] = 5185,
  [7087] = 5184,
  [7088] = 4397,
  [7089] = 4386,
  [7090] = 4820,
  [7091] = 4321,
  [7092] = 5182,
  [7093] = 4591,
  [7094] = 4798,
  [7095] = 4858,
  [7096] = 5396,
  [7097] = 4591,
  [7098] = 4439,
  [7099] = 4397,
  [7100] = 4538,
  [7101] = 4402,
  [7102] = 7102,
  [7103] = 4321,
  [7104] = 4381,
  [7105] = 4206,
  [7106] = 4472,
  [7107] = 4336,
  [7108] = 4366,
  [7109] = 4387,
  [7110] = 4474,
  [7111] = 4395,
  [7112] = 4409,
  [7113] = 4721,
  [7114] = 4362,
  [7115] = 4325,
  [7116] = 4353,
  [7117] = 4409,
  [7118] = 4395,
  [7119] = 4318,
  [7120] = 4591,
  [7121] = 4366,
  [7122] = 5213,
  [7123] = 4434,
  [7124] = 4591,
  [7125] = 4820,
  [7126] = 4472,
  [7127] = 5548,
  [7128] = 4409,
  [7129] = 5284,
  [7130] = 4417,
  [7131] = 4474,
  [7132] = 5535,
  [7133] = 6842,
  [7134] = 3987,
  [7135] = 3985,
  [7136] = 4395,
  [7137] = 5576,
  [7138] = 5341,
  [7139] = 4709,
  [7140] = 5577,
  [7141] = 5295,
  [7142] = 4682,
  [7143] = 4366,
  [7144] = 4355,
  [7145] = 5611,
  [7146] = 4529,
  [7147] = 5123,
  [7148] = 5628,
  [7149] = 5884,
  [7150] = 4318,
  [7151] = 4529,
  [7152] = 5635,
  [7153] = 4325,
  [7154] = 4538,
  [7155] = 5139,
  [7156] = 4925,
  [7157] = 4386,
  [7158] = 5341,
  [7159] = 4355,
  [7160] = 4474,
  [7161] = 4591,
  [7162] = 4656,
  [7163] = 5123,
  [7164] = 4472,
  [7165] = 4372,
  [7166] = 4362,
  [7167] = 5540,
  [7168] = 5312,
  [7169] = 5539,
  [7170] = 4647,
  [7171] = 5295,
  [7172] = 4387,
  [7173] = 4642,
  [7174] = 3987,
  [7175] = 4397,
  [7176] = 4381,
  [7177] = 5396,
  [7178] = 4798,
  [7179] = 4591,
  [7180] = 4402,
  [7181] = 3985,
  [7182] = 4656,
  [7183] = 5646,
  [7184] = 4439,
  [7185] = 5284,
  [7186] = 5496,
  [7187] = 4858,
  [7188] = 4647,
  [7189] = 4318,
  [7190] = 4591,
  [7191] = 5647,
  [7192] = 4372,
  [7193] = 5650,
  [7194] = 4439,
  [7195] = 4642,
  [7196] = 4538,
  [7197] = 4820,
  [7198] = 4386,
  [7199] = 5657,
  [7200] = 4642,
  [7201] = 4529,
  [7202] = 7202,
  [7203] = 4386,
  [7204] = 4647,
  [7205] = 4206,
  [7206] = 5664,
  [7207] = 4858,
  [7208] = 3987,
  [7209] = 4402,
  [7210] = 4472,
  [7211] = 3985,
  [7212] = 4538,
  [7213] = 4474,
  [7214] = 4381,
  [7215] = 4656,
  [7216] = 4325,
  [7217] = 4321,
  [7218] = 4417,
  [7219] = 5665,
  [7220] = 4656,
  [7221] = 5488,
  [7222] = 5539,
  [7223] = 5540,
  [7224] = 4474,
  [7225] = 4472,
  [7226] = 4318,
  [7227] = 4647,
  [7228] = 4642,
  [7229] = 4925,
  [7230] = 7230,
  [7231] = 4372,
  [7232] = 4387,
  [7233] = 5679,
  [7234] = 3987,
  [7235] = 4409,
  [7236] = 4395,
  [7237] = 5426,
  [7238] = 4351,
  [7239] = 4321,
  [7240] = 4366,
  [7241] = 3987,
  [7242] = 5548,
  [7243] = 5469,
  [7244] = 4336,
  [7245] = 4925,
  [7246] = 3985,
  [7247] = 4656,
  [7248] = 4397,
  [7249] = 4925,
  [7250] = 4366,
  [7251] = 3985,
  [7252] = 4362,
  [7253] = 4439,
  [7254] = 4647,
  [7255] = 4353,
  [7256] = 4318,
  [7257] = 4642,
  [7258] = 3987,
  [7259] = 4351,
  [7260] = 4902,
  [7261] = 4409,
  [7262] = 4395,
  [7263] = 4395,
  [7264] = 4366,
  [7265] = 3985,
  [7266] = 4318,
  [7267] = 4591,
  [7268] = 4353,
  [7269] = 4409,
  [7270] = 5312,
  [7271] = 4325,
  [7272] = 4417,
  [7273] = 7273,
  [7274] = 4858,
  [7275] = 4402,
  [7276] = 3985,
  [7277] = 4925,
  [7278] = 4482,
  [7279] = 4642,
  [7280] = 4318,
  [7281] = 4354,
  [7282] = 4409,
  [7283] = 4595,
  [7284] = 4395,
  [7285] = 4647,
  [7286] = 4366,
  [7287] = 4858,
  [7288] = 5422,
  [7289] = 4858,
  [7290] = 5861,
  [7291] = 4591,
  [7292] = 4318,
  [7293] = 7293,
  [7294] = 4504,
  [7295] = 4354,
  [7296] = 4381,
  [7297] = 3987,
  [7298] = 4656,
  [7299] = 4372,
  [7300] = 4538,
  [7301] = 4417,
  [7302] = 4409,
  [7303] = 4395,
  [7304] = 4485,
  [7305] = 4366,
  [7306] = 4386,
  [7307] = 4439,
  [7308] = 4417,
  [7309] = 3985,
  [7310] = 4402,
  [7311] = 4381,
  [7312] = 4709,
  [7313] = 4642,
  [7314] = 4647,
  [7315] = 4656,
  [7316] = 4387,
  [7317] = 5185,
  [7318] = 3987,
  [7319] = 5887,
  [7320] = 5184,
  [7321] = 4642,
  [7322] = 4387,
  [7323] = 4827,
  [7324] = 4647,
  [7325] = 4397,
  [7326] = 5898,
  [7327] = 4362,
  [7328] = 4591,
  [7329] = 4902,
  [7330] = 3987,
  [7331] = 4656,
  [7332] = 4397,
  [7333] = 4925,
  [7334] = 5182,
  [7335] = 4529,
  [7336] = 4362,
  [7337] = 4417,
  [7338] = 5908,
  [7339] = 4362,
  [7340] = 4682,
  [7341] = 4362,
  [7342] = 4387,
  [7343] = 4925,
  [7344] = 4325,
  [7345] = 4925,
  [7346] = 3985,
  [7347] = 4318,
  [7348] = 4827,
  [7349] = 4387,
  [7350] = 3987,
  [7351] = 4354,
  [7352] = 4721,
  [7353] = 5949,
  [7354] = 4381,
  [7355] = 5213,
  [7356] = 4381,
  [7357] = 5213,
  [7358] = 3985,
  [7359] = 4325,
  [7360] = 4402,
  [7361] = 4402,
  [7362] = 6834,
  [7363] = 5973,
  [7364] = 4372,
  [7365] = 4386,
  [7366] = 5978,
  [7367] = 4595,
  [7368] = 4538,
  [7369] = 4439,
  [7370] = 6524,
  [7371] = 4827,
  [7372] = 4474,
  [7373] = 4321,
  [7374] = 4504,
  [7375] = 4439,
  [7376] = 4402,
  [7377] = 3987,
  [7378] = 4386,
  [7379] = 4381,
  [7380] = 4439,
  [7381] = 4372,
  [7382] = 4387,
  [7383] = 4472,
  [7384] = 4362,
  [7385] = 3987,
  [7386] = 4474,
  [7387] = 4472,
  [7388] = 4798,
  [7389] = 4386,
  [7390] = 4353,
  [7391] = 5887,
  [7392] = 4321,
  [7393] = 4354,
  [7394] = 4386,
  [7395] = 4434,
  [7396] = 4656,
  [7397] = 5898,
  [7398] = 4925,
  [7399] = 4325,
  [7400] = 4417,
  [7401] = 4409,
  [7402] = 4351,
  [7403] = 4372,
  [7404] = 4538,
  [7405] = 3985,
  [7406] = 4318,
  [7407] = 4395,
  [7408] = 4858,
  [7409] = 4642,
  [7410] = 4827,
  [7411] = 4387,
  [7412] = 6500,
  [7413] = 4366,
  [7414] = 4472,
  [7415] = 3985,
  [7416] = 4351,
  [7417] = 4647,
  [7418] = 4351,
  [7419] = 4372,
  [7420] = 4595,
  [7421] = 4538,
  [7422] = 4381,
  [7423] = 4386,
  [7424] = 4318,
  [7425] = 6524,
  [7426] = 4439,
  [7427] = 4642,
  [7428] = 3985,
  [7429] = 4925,
  [7430] = 4647,
  [7431] = 4647,
  [7432] = 4402,
  [7433] = 4409,
  [7434] = 4409,
  [7435] = 5949,
  [7436] = 4474,
  [7437] = 4402,
  [7438] = 4381,
  [7439] = 4206,
  [7440] = 4656,
  [7441] = 4709,
  [7442] = 4395,
  [7443] = 4325,
  [7444] = 4387,
  [7445] = 4362,
  [7446] = 4858,
  [7447] = 4439,
  [7448] = 4417,
  [7449] = 5469,
  [7450] = 4395,
  [7451] = 4366,
  [7452] = 4656,
  [7453] = 4417,
  [7454] = 4325,
  [7455] = 4642,
  [7456] = 4417,
  [7457] = 4682,
  [7458] = 3987,
  [7459] = 4351,
  [7460] = 4372,
  [7461] = 4354,
  [7462] = 4529,
  [7463] = 4529,
  [7464] = 5973,
  [7465] = 4409,
  [7466] = 4354,
  [7467] = 4362,
  [7468] = 4395,
  [7469] = 4387,
  [7470] = 4366,
  [7471] = 4355,
  [7472] = 4366,
  [7473] = 5908,
  [7474] = 4381,
  [7475] = 5488,
  [7476] = 4529,
  [7477] = 4402,
  [7478] = 5978,
  [7479] = 4858,
  [7480] = 4351,
  [7481] = 4439,
  [7482] = 4386,
  [7483] = 4682,
  [7484] = 4417,
  [7485] = 4372,
  [7486] = 4820,
  [7487] = 4397,
  [7488] = 4591,
  [7489] = 4336,
  [7490] = 4366,
  [7491] = 4395,
  [7492] = 4409,
  [7493] = 4709,
  [7494] = 6500,
  [7495] = 4351,
  [7496] = 4656,
  [7497] = 4318,
  [7498] = 5861,
  [7499] = 4647,
  [7500] = 4325,
  [7501] = 4642,
  [7502] = 3985,
  [7503] = 5185,
  [7504] = 4642,
  [7505] = 4362,
  [7506] = 4647,
  [7507] = 4409,
  [7508] = 4355,
  [7509] = 4656,
  [7510] = 7510,
  [7511] = 5535,
  [7512] = 4482,
  [7513] = 4351,
  [7514] = 4529,
  [7515] = 4798,
  [7516] = 6879,
  [7517] = 4336,
  [7518] = 4395,
  [7519] = 4538,
  [7520] = 4366,
  [7521] = 4642,
  [7522] = 4372,
  [7523] = 4647,
  [7524] = 4395,
  [7525] = 5139,
  [7526] = 7510,
  [7527] = 5646,
  [7528] = 4409,
  [7529] = 4656,
  [7530] = 4387,
  [7531] = 3985,
  [7532] = 5123,
  [7533] = 4353,
  [7534] = 4721,
  [7535] = 4325,
  [7536] = 7536,
  [7537] = 4366,
  [7538] = 4925,
  [7539] = 3987,
  [7540] = 4682,
  [7541] = 4206,
  [7542] = 4381,
  [7543] = 4318,
  [7544] = 7510,
  [7545] = 4529,
  [7546] = 5784,
  [7547] = 4439,
  [7548] = 4538,
  [7549] = 4642,
  [7550] = 4647,
  [7551] = 4318,
  [7552] = 4709,
  [7553] = 7510,
  [7554] = 4656,
  [7555] = 4402,
  [7556] = 4472,
  [7557] = 4372,
  [7558] = 4386,
  [7559] = 4439,
  [7560] = 5123,
  [7561] = 4417,
  [7562] = 4402,
  [7563] = 4325,
  [7564] = 4402,
  [7565] = 4417,
  [7566] = 4656,
  [7567] = 4474,
  [7568] = 4529,
  [7569] = 4381,
  [7570] = 4318,
  [7571] = 4387,
  [7572] = 7510,
  [7573] = 4381,
  [7574] = 4362,
  [7575] = 5577,
  [7576] = 7510,
  [7577] = 5469,
  [7578] = 4529,
  [7579] = 7510,
  [7580] = 5784,
  [7581] = 4647,
  [7582] = 5139,
  [7583] = 4709,
  [7584] = 5488,
  [7585] = 4439,
  [7586] = 6879,
  [7587] = 4351,
  [7588] = 4925,
  [7589] = 3985,
  [7590] = 5123,
  [7591] = 4362,
  [7592] = 4642,
  [7593] = 4355,
  [7594] = 4682,
  [7595] = 4529,
  [7596] = 4386,
  [7597] = 4656,
  [7598] = 5284,
  [7599] = 3987,
  [7600] = 5295,
  [7601] = 4925,
  [7602] = 4902,
  [7603] = 3985,
  [7604] = 7019,
  [7605] = 5341,
  [7606] = 4591,
  [7607] = 7510,
  [7608] = 4355,
  [7609] = 4827,
  [7610] = 4647,
  [7611] = 4642,
  [7612] = 5396,
  [7613] = 7510,
  [7614] = 5496,
  [7615] = 4820,
  [7616] = 4417,
  [7617] = 4372,
  [7618] = 4355,
  [7619] = 4858,
  [7620] = 5426,
  [7621] = 5422,
  [7622] = 4538,
  [7623] = 7510,
  [7624] = 4538,
  [7625] = 4351,
  [7626] = 7510,
  [7627] = 4798,
  [7628] = 4387,
  [7629] = 5139,
  [7630] = 4656,
  [7631] = 7510,
  [7632] = 4721,
  [7633] = 4925,
  [7634] = 7510,
  [7635] = 5576,
  [7636] = 4409,
  [7637] = 4321,
  [7638] = 4395,
  [7639] = 7510,
  [7640] = 4858,
  [7641] = 4366,
  [7642] = 4325,
  [7643] = 7510,
  [7644] = 5611,
  [7645] = 4647,
  [7646] = 7510,
  [7647] = 4827,
  [7648] = 4354,
  [7649] = 5628,
  [7650] = 4709,
  [7651] = 5635,
  [7652] = 4682,
  [7653] = 4925,
  [7654] = 7510,
  [7655] = 7510,
  [7656] = 4642,
  [7657] = 4355,
  [7658] = 5284,
  [7659] = 7510,
  [7660] = 4318,
  [7661] = 4682,
  [7662] = 4682,
  [7663] = 7510,
  [7664] = 3987,
  [7665] = 5312,
  [7666] = 5784,
  [7667] = 4709,
  [7668] = 5647,
  [7669] = 5650,
  [7670] = 5657,
  [7671] = 5213,
  [7672] = 4591,
  [7673] = 7510,
  [7674] = 5295,
  [7675] = 4858,
  [7676] = 5679,
  [7677] = 4474,
  [7678] = 7510,
  [7679] = 5665,
  [7680] = 4372,
  [7681] = 5884,
  [7682] = 5664,
  [7683] = 4642,
  [7684] = 4386,
  [7685] = 4647,
  [7686] = 4709,
  [7687] = 4858,
  [7688] = 7510,
  [7689] = 4366,
  [7690] = 7102,
  [7691] = 5123,
  [7692] = 4439,
  [7693] = 5664,
  [7694] = 4656,
  [7695] = 4472,
  [7696] = 7510,
  [7697] = 4656,
  [7698] = 4721,
  [7699] = 4591,
  [7700] = 4647,
  [7701] = 7510,
  [7702] = 7202,
  [7703] = 5123,
  [7704] = 5139,
  [7705] = 4642,
  [7706] = 7510,
  [7707] = 5657,
  [7708] = 4318,
  [7709] = 5887,
  [7710] = 5650,
  [7711] = 5647,
  [7712] = 5898,
  [7713] = 4595,
  [7714] = 4472,
  [7715] = 5665,
  [7716] = 4402,
  [7717] = 5123,
  [7718] = 7510,
  [7719] = 4325,
  [7720] = 5312,
  [7721] = 4474,
  [7722] = 5341,
  [7723] = 4381,
  [7724] = 7510,
  [7725] = 6055,
  [7726] = 5139,
  [7727] = 5679,
  [7728] = 5784,
  [7729] = 4709,
  [7730] = 5228,
  [7731] = 4827,
  [7732] = 4387,
  [7733] = 5635,
  [7734] = 5628,
  [7735] = 7735,
  [7736] = 7736,
  [7737] = 7510,
  [7738] = 4529,
  [7739] = 5611,
  [7740] = 4858,
  [7741] = 5949,
  [7742] = 5488,
  [7743] = 4409,
  [7744] = 7510,
  [7745] = 5396,
  [7746] = 4642,
  [7747] = 4395,
  [7748] = 4647,
  [7749] = 4386,
  [7750] = 7750,
  [7751] = 7510,
  [7752] = 4682,
  [7753] = 4351,
  [7754] = 4366,
  [7755] = 4798,
  [7756] = 4362,
  [7757] = 4858,
  [7758] = 4417,
  [7759] = 4656,
  [7760] = 4538,
  [7761] = 5576,
  [7762] = 5973,
  [7763] = 5978,
  [7764] = 4529,
  [7765] = 4351,
  [7766] = 4439,
  [7767] = 5577,
  [7768] = 4591,
  [7769] = 3987,
  [7770] = 5139,
  [7771] = 5496,
  [7772] = 7102,
  [7773] = 4354,
  [7774] = 4395,
  [7775] = 4409,
  [7776] = 4538,
  [7777] = 4321,
  [7778] = 7510,
  [7779] = 5535,
  [7780] = 3985,
  [7781] = 4318,
  [7782] = 4656,
  [7783] = 7510,
  [7784] = 4318,
  [7785] = 5469,
  [7786] = 7510,
  [7787] = 5213,
  [7788] = 5228,
  [7789] = 7510,
  [7790] = 5284,
  [7791] = 4318,
  [7792] = 3987,
  [7793] = 4366,
  [7794] = 5548,
  [7795] = 5123,
  [7796] = 7019,
  [7797] = 4827,
  [7798] = 4647,
  [7799] = 5784,
  [7800] = 5540,
  [7801] = 6500,
  [7802] = 5539,
  [7803] = 5426,
  [7804] = 5422,
  [7805] = 5139,
  [7806] = 4318,
  [7807] = 7510,
  [7808] = 4395,
  [7809] = 5284,
  [7810] = 5496,
  [7811] = 4642,
  [7812] = 4409,
  [7813] = 7510,
  [7814] = 5295,
  [7815] = 7510,
  [7816] = 4409,
  [7817] = 5396,
  [7818] = 4362,
  [7819] = 4682,
  [7820] = 4591,
  [7821] = 4395,
  [7822] = 5123,
  [7823] = 3985,
  [7824] = 3987,
  [7825] = 4538,
  [7826] = 5295,
  [7827] = 5341,
  [7828] = 4656,
  [7829] = 5341,
  [7830] = 4820,
  [7831] = 7202,
  [7832] = 5396,
  [7833] = 7510,
  [7834] = 5139,
  [7835] = 5496,
  [7836] = 4397,
  [7837] = 7510,
  [7838] = 4366,
  [7839] = 4387,
  [7840] = 4709,
  [7841] = 4647,
  [7842] = 5295,
  [7843] = 4709,
  [7844] = 4351,
  [7845] = 5422,
  [7846] = 5426,
  [7847] = 3985,
  [7848] = 4858,
  [7849] = 4642,
  [7850] = 5284,
  [7851] = 4682,
  [7852] = 4925,
  [7853] = 4538,
  [7854] = 4397,
  [7855] = 4321,
  [7856] = 4925,
  [7857] = 4529,
  [7858] = 7510,
  [7859] = 4529,
  [7860] = 4381,
  [7861] = 7861,
  [7862] = 3985,
  [7863] = 3987,
  [7864] = 4529,
  [7865] = 4318,
  [7866] = 3987,
  [7867] = 4402,
  [7868] = 5548,
  [7869] = 7510,
  [7870] = 6524,
  [7871] = 7510,
  [7872] = 7872,
  [7873] = 5784,
  [7874] = 7510,
  [7875] = 4354,
  [7876] = 4656,
  [7877] = 4325,
  [7878] = 4321,
  [7879] = 7510,
  [7880] = 5469,
  [7881] = 4325,
  [7882] = 5182,
  [7883] = 4925,
  [7884] = 4318,
  [7885] = 7510,
  [7886] = 4386,
  [7887] = 5341,
  [7888] = 5184,
  [7889] = 4647,
  [7890] = 5488,
  [7891] = 7510,
  [7892] = 7510,
  [7893] = 5908,
  [7894] = 5540,
  [7895] = 5539,
  [7896] = 4642,
  [7897] = 4642,
  [7898] = 4318,
  [7899] = 7510,
  [7900] = 4397,
  [7901] = 4827,
  [7902] = 4318,
  [7903] = 7510,
  [7904] = 4351,
  [7905] = 7872,
  [7906] = 4353,
  [7907] = 7861,
  [7908] = 4372,
  [7909] = 4354,
  [7910] = 4538,
  [7911] = 5396,
  [7912] = 7736,
  [7913] = 7510,
  [7914] = 7510,
  [7915] = 4820,
  [7916] = 5123,
  [7917] = 4538,
  [7918] = 7536,
  [7919] = 4353,
  [7920] = 4439,
  [7921] = 4351,
  [7922] = 4682,
  [7923] = 3987,
  [7924] = 4409,
  [7925] = 4362,
  [7926] = 4417,
  [7927] = 4402,
  [7928] = 7510,
  [7929] = 4325,
  [7930] = 4395,
  [7931] = 4387,
  [7932] = 4366,
  [7933] = 4381,
  [7934] = 4381,
  [7935] = 4858,
  [7936] = 4504,
  [7937] = 4402,
  [7938] = 4417,
  [7939] = 4372,
  [7940] = 4387,
  [7941] = 4372,
  [7942] = 7942,
  [7943] = 4439,
  [7944] = 4656,
  [7945] = 7510,
  [7946] = 4798,
  [7947] = 7510,
  [7948] = 4362,
  [7949] = 4709,
  [7950] = 4386,
  [7951] = 4372,
  [7952] = 3987,
  [7953] = 4321,
  [7954] = 4318,
  [7955] = 7735,
  [7956] = 4372,
  [7957] = 4409,
  [7958] = 4395,
  [7959] = 4386,
  [7960] = 4591,
  [7961] = 5861,
  [7962] = 4321,
  [7963] = 4472,
  [7964] = 4366,
  [7965] = 4591,
  [7966] = 7510,
  [7967] = 5139,
  [7968] = 4439,
  [7969] = 5185,
  [7970] = 5184,
  [7971] = 4827,
  [7972] = 7510,
  [7973] = 5646,
  [7974] = 5496,
  [7975] = 4402,
  [7976] = 6524,
  [7977] = 4647,
  [7978] = 4474,
  [7979] = 4348,
  [7980] = 4397,
  [7981] = 4381,
  [7982] = 5539,
  [7983] = 7510,
  [7984] = 4366,
  [7985] = 4902,
  [7986] = 3985,
  [7987] = 5182,
  [7988] = 4387,
  [7989] = 4409,
  [7990] = 5540,
  [7991] = 7510,
  [7992] = 4395,
  [7993] = 4820,
  [7994] = 4439,
  [7995] = 4340,
  [7996] = 4362,
  [7997] = 4409,
  [7998] = 7510,
  [7999] = 4206,
  [8000] = 3985,
  [8001] = 4721,
  [8002] = 5548,
  [8003] = 7510,
  [8004] = 4827,
  [8005] = 4395,
  [8006] = 4325,
  [8007] = 4386,
  [8008] = 3987,
  [8009] = 4402,
  [8010] = 4321,
  [8011] = 4397,
  [8012] = 5540,
  [8013] = 5539,
  [8014] = 4902,
  [8015] = 5548,
  [8016] = 4591,
  [8017] = 4381,
  [8018] = 4529,
  [8019] = 7510,
  [8020] = 7510,
  [8021] = 4709,
  [8022] = 4417,
  [8023] = 4372,
  [8024] = 3985,
  [8025] = 4354,
  [8026] = 4366,
  [8027] = 7750,
  [8028] = 4472,
  [8029] = 4682,
  [8030] = 4386,
  [8031] = 4485,
  [8032] = 4409,
  [8033] = 4387,
  [8034] = 4372,
  [8035] = 5213,
  [8036] = 4827,
  [8037] = 4902,
  [8038] = 7510,
  [8039] = 5228,
  [8040] = 7510,
  [8041] = 4321,
  [8042] = 7510,
  [8043] = 4682,
  [8044] = 3987,
  [8045] = 4325,
  [8046] = 4827,
  [8047] = 4362,
  [8048] = 4682,
  [8049] = 3985,
  [8050] = 7510,
  [8051] = 4397,
  [8052] = 4439,
  [8053] = 4409,
  [8054] = 4595,
  [8055] = 4387,
  [8056] = 4474,
  [8057] = 4362,
  [8058] = 4709,
  [8059] = 7750,
  [8060] = 6055,
  [8061] = 4827,
  [8062] = 4402,
  [8063] = 7510,
  [8064] = 5908,
  [8065] = 5548,
  [8066] = 4395,
  [8067] = 7510,
  [8068] = 4642,
  [8069] = 4395,
  [8070] = 4325,
  [8071] = 4381,
  [8072] = 4434,
  [8073] = 4591,
  [8074] = 4402,
  [8075] = 7510,
  [8076] = 5540,
  [8077] = 5539,
  [8078] = 5535,
  [8079] = 5139,
  [8080] = 4366,
  [8081] = 4381,
  [8082] = 4827,
  [8083] = 4439,
  [8084] = 5861,
  [8085] = 4366,
  [8086] = 5861,
  [8087] = 7510,
  [8088] = 4395,
  [8089] = 4409,
  [8090] = 4387,
  [8091] = 7510,
  [8092] = 4642,
  [8093] = 4409,
  [8094] = 4318,
  [8095] = 4395,
  [8096] = 4647,
  [8097] = 4366,
  [8098] = 4366,
  [8099] = 4318,
  [8100] = 4395,
  [8101] = 7510,
  [8102] = 4417,
  [8103] = 4656,
  [8104] = 8104,
  [8105] = 5908,
  [8106] = 4362,
  [8107] = 7872,
  [8108] = 4709,
  [8109] = 4474,
  [8110] = 5884,
  [8111] = 7510,
  [8112] = 3985,
  [8113] = 4417,
  [8114] = 4591,
  [8115] = 7510,
  [8116] = 7510,
  [8117] = 5123,
  [8118] = 4417,
  [8119] = 5978,
  [8120] = 7861,
  [8121] = 4902,
  [8122] = 4925,
  [8123] = 4417,
  [8124] = 4858,
  [8125] = 4647,
  [8126] = 4472,
  [8127] = 4366,
  [8128] = 7510,
  [8129] = 7510,
  [8130] = 5973,
  [8131] = 7750,
  [8132] = 5576,
  [8133] = 7736,
  [8134] = 5577,
  [8135] = 5123,
  [8136] = 5228,
  [8137] = 7510,
  [8138] = 7510,
  [8139] = 5284,
  [8140] = 5295,
  [8141] = 3987,
  [8142] = 7510,
  [8143] = 6524,
  [8144] = 5341,
  [8145] = 7510,
  [8146] = 5396,
  [8147] = 4351,
  [8148] = 7510,
  [8149] = 5496,
  [8150] = 4827,
  [8151] = 4439,
  [8152] = 7510,
  [8153] = 4472,
  [8154] = 4474,
  [8155] = 7510,
  [8156] = 4386,
  [8157] = 7536,
  [8158] = 5887,
  [8159] = 5898,
  [8160] = 7510,
  [8161] = 7861,
  [8162] = 5949,
  [8163] = 5611,
  [8164] = 5884,
  [8165] = 4325,
  [8166] = 7872,
  [8167] = 5949,
  [8168] = 6500,
  [8169] = 4656,
  [8170] = 4858,
  [8171] = 4409,
  [8172] = 5213,
  [8173] = 4351,
  [8174] = 5213,
  [8175] = 5628,
  [8176] = 7735,
  [8177] = 5973,
  [8178] = 4417,
  [8179] = 4321,
  [8180] = 5139,
  [8181] = 4642,
  [8182] = 4318,
  [8183] = 4386,
  [8184] = 4318,
  [8185] = 7202,
  [8186] = 7750,
  [8187] = 6055,
  [8188] = 7735,
  [8189] = 4318,
  [8190] = 4647,
  [8191] = 7510,
  [8192] = 5182,
  [8193] = 4827,
  [8194] = 5978,
  [8195] = 7536,
  [8196] = 4827,
  [8197] = 4206,
  [8198] = 6825,
  [8199] = 4656,
  [8200] = 4386,
  [8201] = 5184,
  [8202] = 4529,
  [8203] = 4902,
  [8204] = 4529,
  [8205] = 4362,
  [8206] = 5185,
  [8207] = 6500,
  [8208] = 5679,
  [8209] = 7510,
  [8210] = 4642,
  [8211] = 4325,
  [8212] = 4353,
  [8213] = 4827,
  [8214] = 4902,
  [8215] = 7510,
  [8216] = 4925,
  [8217] = 3985,
  [8218] = 7510,
  [8219] = 4472,
  [8220] = 5635,
  [8221] = 7102,
  [8222] = 4902,
  [8223] = 4474,
  [8224] = 4387,
  [8225] = 4351,
  [8226] = 4318,
  [8227] = 4647,
  [8228] = 4372,
  [8229] = 4925,
  [8230] = 4925,
  [8231] = 4538,
  [8232] = 7872,
  [8233] = 4529,
  [8234] = 7861,
  [8235] = 4381,
  [8236] = 5665,
  [8237] = 4591,
  [8238] = 4472,
  [8239] = 4321,
  [8240] = 7510,
  [8241] = 4827,
  [8242] = 4474,
  [8243] = 4325,
  [8244] = 7510,
  [8245] = 7510,
  [8246] = 4925,
  [8247] = 4642,
  [8248] = 4647,
  [8249] = 4402,
  [8250] = 4858,
  [8251] = 5548,
  [8252] = 5312,
  [8253] = 4656,
  [8254] = 4417,
  [8255] = 5646,
  [8256] = 7510,
  [8257] = 4858,
  [8258] = 5540,
  [8259] = 5539,
  [8260] = 5898,
  [8261] = 5647,
  [8262] = 5650,
  [8263] = 7510,
  [8264] = 7750,
  [8265] = 4321,
  [8266] = 5887,
  [8267] = 4362,
  [8268] = 4387,
  [8269] = 4439,
  [8270] = 4434,
  [8271] = 4858,
  [8272] = 4925,
  [8273] = 4381,
  [8274] = 5657,
  [8275] = 3987,
  [8276] = 4372,
  [8277] = 4656,
  [8278] = 7510,
  [8279] = 4386,
  [8280] = 5664,
  [8281] = 4402,
  [8282] = 4409,
  [8283] = 4439,
  [8284] = 4386,
  [8285] = 4351,
  [8286] = 4325,
  [8287] = 8287,
  [8288] = 4827,
  [8289] = 4439,
  [8290] = 4372,
  [8291] = 4858,
  [8292] = 5139,
  [8293] = 5139,
  [8294] = 5488,
  [8295] = 4902,
  [8296] = 3987,
  [8297] = 4656,
  [8298] = 8298,
  [8299] = 7102,
  [8300] = 5139,
  [8301] = 4386,
  [8302] = 4656,
  [8303] = 6524,
  [8304] = 4318,
  [8305] = 5123,
  [8306] = 5884,
  [8307] = 5469,
  [8308] = 4362,
  [8309] = 4682,
  [8310] = 4647,
  [8311] = 4858,
  [8312] = 4642,
  [8313] = 5426,
  [8314] = 4417,
  [8315] = 3987,
  [8316] = 8316,
  [8317] = 5139,
  [8318] = 4656,
  [8319] = 5422,
  [8320] = 4647,
  [8321] = 8321,
  [8322] = 4397,
  [8323] = 5898,
  [8324] = 4409,
  [8325] = 4351,
  [8326] = 4858,
  [8327] = 4642,
  [8328] = 4798,
  [8329] = 5887,
  [8330] = 4402,
  [8331] = 4529,
  [8332] = 5123,
  [8333] = 5123,
  [8334] = 4647,
  [8335] = 4642,
  [8336] = 6879,
  [8337] = 4366,
  [8338] = 4395,
  [8339] = 5123,
  [8340] = 4395,
  [8341] = 4529,
  [8342] = 5182,
  [8343] = 4709,
  [8344] = 5784,
  [8345] = 4472,
  [8346] = 4820,
  [8347] = 5973,
  [8348] = 4381,
  [8349] = 5184,
  [8350] = 4925,
  [8351] = 4355,
  [8352] = 5496,
  [8353] = 4366,
  [8354] = 4642,
  [8355] = 4647,
  [8356] = 5185,
  [8357] = 4381,
  [8358] = 4351,
  [8359] = 5228,
  [8360] = 5978,
  [8361] = 4858,
  [8362] = 4366,
  [8363] = 5973,
  [8364] = 4387,
  [8365] = 4656,
  [8366] = 4434,
  [8367] = 4529,
  [8368] = 5548,
  [8369] = 4206,
  [8370] = 4656,
  [8371] = 4372,
  [8372] = 3985,
  [8373] = 5884,
  [8374] = 8374,
  [8375] = 4372,
  [8376] = 4721,
  [8377] = 4318,
  [8378] = 4402,
  [8379] = 4321,
  [8380] = 4395,
  [8381] = 5978,
  [8382] = 4858,
  [8383] = 5469,
  [8384] = 5949,
  [8385] = 5396,
  [8386] = 4362,
  [8387] = 4409,
  [8388] = 5949,
  [8389] = 4439,
  [8390] = 8390,
  [8391] = 5540,
  [8392] = 5539,
  [8393] = 5784,
  [8394] = 5139,
  [8395] = 4925,
  [8396] = 3985,
  [8397] = 5535,
  [8398] = 5576,
  [8399] = 4647,
  [8400] = 5577,
  [8401] = 4362,
  [8402] = 4472,
  [8403] = 5123,
  [8404] = 6055,
  [8405] = 7102,
  [8406] = 4538,
  [8407] = 4409,
  [8408] = 5123,
  [8409] = 4827,
  [8410] = 5898,
  [8411] = 4395,
  [8412] = 4529,
  [8413] = 4366,
  [8414] = 4656,
  [8415] = 5887,
  [8416] = 4318,
  [8417] = 4387,
  [8418] = 4354,
  [8419] = 5341,
  [8420] = 5611,
  [8421] = 4366,
  [8422] = 4858,
  [8423] = 5628,
  [8424] = 5978,
  [8425] = 4474,
  [8426] = 4647,
  [8427] = 5635,
  [8428] = 4325,
  [8429] = 5182,
  [8430] = 4642,
  [8431] = 5488,
  [8432] = 4372,
  [8433] = 5284,
  [8434] = 4642,
  [8435] = 4395,
  [8436] = 5312,
  [8437] = 5646,
  [8438] = 4381,
  [8439] = 4642,
  [8440] = 5647,
  [8441] = 5548,
  [8442] = 5650,
  [8443] = 5657,
  [8444] = 4387,
  [8445] = 4402,
  [8446] = 5184,
  [8447] = 5185,
  [8448] = 6055,
  [8449] = 4409,
  [8450] = 5488,
  [8451] = 4538,
  [8452] = 4474,
  [8453] = 4439,
  [8454] = 5540,
  [8455] = 5539,
  [8456] = 5123,
  [8457] = 7202,
  [8458] = 5182,
  [8459] = 4647,
  [8460] = 5973,
  [8461] = 4827,
  [8462] = 5184,
  [8463] = 5496,
  [8464] = 5185,
  [8465] = 4386,
  [8466] = 4386,
  [8467] = 5123,
  [8468] = 5295,
  [8469] = 4325,
  [8470] = 5396,
  [8471] = 5295,
  [8472] = 4474,
  [8473] = 5664,
  [8474] = 4656,
  [8475] = 4439,
  [8476] = 4925,
  [8477] = 5665,
  [8478] = 4529,
  [8479] = 5949,
  [8480] = 5469,
  [8481] = 4827,
  [8482] = 8482,
  [8483] = 4362,
  [8484] = 5679,
  [8485] = 5284,
  [8486] = 4827,
  [8487] = 4656,
  [8488] = 5341,
  [8489] = 4417,
  [8490] = 4318,
  [8491] = 8491,
  [8492] = 5548,
  [8493] = 5861,
  [8494] = 4595,
  [8495] = 5422,
  [8496] = 4472,
  [8497] = 4858,
  [8498] = 6524,
  [8499] = 8499,
  [8500] = 6879,
  [8501] = 4318,
  [8502] = 4827,
  [8503] = 4351,
  [8504] = 4925,
  [8505] = 5284,
  [8506] = 5341,
  [8507] = 5295,
  [8508] = 4656,
  [8509] = 4538,
  [8510] = 4372,
  [8511] = 5341,
  [8512] = 5139,
  [8513] = 4366,
  [8514] = 4402,
  [8515] = 5396,
  [8516] = 4925,
  [8517] = 4820,
  [8518] = 5496,
  [8519] = 4647,
  [8520] = 5295,
  [8521] = 4325,
  [8522] = 8522,
  [8523] = 4417,
  [8524] = 5540,
  [8525] = 5396,
  [8526] = 5422,
  [8527] = 5496,
  [8528] = 4381,
  [8529] = 5426,
  [8530] = 6879,
  [8531] = 5646,
  [8532] = 4682,
  [8533] = 5539,
  [8534] = 4656,
  [8535] = 5341,
  [8536] = 5887,
  [8537] = 5228,
  [8538] = 5540,
  [8539] = 5908,
  [8540] = 5213,
  [8541] = 4591,
  [8542] = 5898,
  [8543] = 5396,
  [8544] = 4395,
  [8545] = 4642,
  [8546] = 4647,
  [8547] = 5295,
  [8548] = 5284,
  [8549] = 5898,
  [8550] = 4642,
  [8551] = 5284,
  [8552] = 4409,
  [8553] = 5887,
  [8554] = 4472,
  [8555] = 6055,
  [8556] = 6500,
  [8557] = 4925,
  [8558] = 4366,
  [8559] = 4387,
  [8560] = 4827,
  [8561] = 4647,
  [8562] = 4474,
  [8563] = 4439,
  [8564] = 4591,
  [8565] = 4591,
  [8566] = 4538,
  [8567] = 5496,
  [8568] = 4321,
  [8569] = 5496,
  [8570] = 4709,
  [8571] = 4397,
  [8572] = 4529,
  [8573] = 4709,
  [8574] = 5884,
  [8575] = 5139,
  [8576] = 4409,
  [8577] = 5396,
  [8578] = 4402,
  [8579] = 5908,
  [8580] = 4381,
  [8581] = 5861,
  [8582] = 4395,
  [8583] = 5539,
  [8584] = 8584,
  [8585] = 4387,
  [8586] = 4538,
  [8587] = 4354,
  [8588] = 4858,
  [8589] = 7019,
  [8590] = 4529,
  [8591] = 4318,
  [8592] = 5548,
  [8593] = 4538,
  [8594] = 5341,
  [8595] = 4362,
  [8596] = 7102,
  [8597] = 4362,
  [8598] = 5496,
  [8599] = 5784,
  [8600] = 7202,
  [8601] = 4417,
  [8602] = 4321,
  [8603] = 4409,
  [8604] = 4591,
  [8605] = 5396,
  [8606] = 5213,
  [8607] = 4827,
  [8608] = 4395,
  [8609] = 4366,
  [8610] = 4642,
  [8611] = 5949,
  [8612] = 5426,
  [8613] = 5548,
  [8614] = 4656,
  [8615] = 5341,
  [8616] = 5284,
  [8617] = 5213,
  [8618] = 5422,
  [8619] = 5123,
  [8620] = 4325,
  [8621] = 5228,
  [8622] = 4325,
  [8623] = 4827,
  [8624] = 5426,
  [8625] = 3987,
  [8626] = 4647,
  [8627] = 5295,
  [8628] = 4318,
  [8629] = 6500,
  [8630] = 4642,
  [8631] = 5284,
  [8632] = 4321,
  [8633] = 4336,
  [8634] = 4386,
  [8635] = 5540,
  [8636] = 4682,
  [8637] = 5539,
  [8638] = 4395,
  [8639] = 4409,
  [8640] = 5284,
  [8641] = 3985,
  [8642] = 4206,
  [8643] = 4387,
  [8644] = 3987,
  [8645] = 5973,
  [8646] = 4656,
  [8647] = 5539,
  [8648] = 3985,
  [8649] = 5978,
  [8650] = 4366,
  [8651] = 8651,
  [8652] = 4417,
  [8653] = 5540,
  [8654] = 4647,
  [8655] = 4417,
  [8656] = 5295,
  [8657] = 5784,
  [8658] = 5295,
  [8659] = 5139,
  [8660] = 4642,
  [8661] = 4409,
  [8662] = 5548,
  [8663] = 4386,
  [8664] = 6055,
  [8665] = 5139,
  [8666] = 4395,
  [8667] = 4827,
  [8668] = 4472,
  [8669] = 3985,
  [8670] = 3987,
  [8671] = 4709,
  [8672] = 8321,
  [8673] = 3985,
  [8674] = 5540,
  [8675] = 5539,
  [8676] = 5784,
  [8677] = 7273,
  [8678] = 7202,
  [8679] = 5679,
  [8680] = 3987,
  [8681] = 4318,
  [8682] = 4827,
  [8683] = 4925,
  [8684] = 4366,
  [8685] = 7019,
  [8686] = 5123,
  [8687] = 5213,
  [8688] = 5665,
  [8689] = 5496,
  [8690] = 5548,
  [8691] = 5228,
  [8692] = 4351,
  [8693] = 4372,
  [8694] = 5664,
  [8695] = 4827,
  [8696] = 5213,
  [8697] = 7293,
  [8698] = 5139,
  [8699] = 4472,
  [8700] = 5657,
  [8701] = 4827,
  [8702] = 8702,
  [8703] = 7230,
  [8704] = 7102,
  [8705] = 7102,
  [8706] = 5284,
  [8707] = 5295,
  [8708] = 5650,
  [8709] = 5647,
  [8710] = 4682,
  [8711] = 4721,
  [8712] = 4902,
  [8713] = 4858,
  [8714] = 8714,
  [8715] = 5646,
  [8716] = 8298,
  [8717] = 3985,
  [8718] = 5123,
  [8719] = 4381,
  [8720] = 5341,
  [8721] = 4409,
  [8722] = 5488,
  [8723] = 5341,
  [8724] = 4206,
  [8725] = 5312,
  [8726] = 4353,
  [8727] = 4386,
  [8728] = 5396,
  [8729] = 5396,
  [8730] = 4642,
  [8731] = 4395,
  [8732] = 5908,
  [8733] = 5496,
  [8734] = 4402,
  [8735] = 4642,
  [8736] = 5784,
  [8737] = 4642,
  [8738] = 4647,
  [8739] = 5139,
  [8740] = 4439,
  [8741] = 4591,
  [8742] = 4858,
  [8743] = 5635,
  [8744] = 4529,
  [8745] = 5628,
  [8746] = 4656,
  [8747] = 4647,
  [8748] = 4366,
  [8749] = 5884,
  [8750] = 4397,
  [8751] = 5611,
  [8752] = 4474,
  [8753] = 5341,
  [8754] = 5139,
  [8755] = 4925,
  [8756] = 3987,
  [8757] = 4402,
  [8758] = 4474,
  [8759] = 4325,
  [8760] = 4381,
  [8761] = 4355,
  [8762] = 5182,
  [8763] = 5469,
  [8764] = 4656,
  [8765] = 4798,
  [8766] = 5908,
  [8767] = 5548,
  [8768] = 5396,
  [8769] = 5861,
  [8770] = 4417,
  [8771] = 4353,
  [8772] = 5123,
  [8773] = 5577,
  [8774] = 4656,
  [8775] = 5576,
  [8776] = 4417,
  [8777] = 6524,
  [8778] = 5540,
  [8779] = 5539,
  [8780] = 5213,
  [8781] = 4709,
  [8782] = 4325,
  [8783] = 3985,
  [8784] = 4820,
  [8785] = 4827,
  [8786] = 4647,
  [8787] = 5184,
  [8788] = 5295,
  [8789] = 5185,
  [8790] = 4642,
  [8791] = 4318,
  [8792] = 4682,
  [8793] = 4387,
  [8794] = 4439,
  [8795] = 3987,
  [8796] = 4647,
  [8797] = 7202,
  [8798] = 5535,
  [8799] = 5284,
  [8800] = 5861,
  [8801] = 4362,
  [8802] = 5496,
  [8803] = 4355,
  [8804] = 3985,
  [8805] = 2412,
  [8806] = 5679,
  [8807] = 3985,
  [8808] = 3985,
  [8809] = 5665,
  [8810] = 8702,
  [8811] = 3987,
  [8812] = 4827,
  [8813] = 5182,
  [8814] = 4274,
  [8815] = 4538,
  [8816] = 4417,
  [8817] = 8817,
  [8818] = 4858,
  [8819] = 4288,
  [8820] = 4289,
  [8821] = 5664,
  [8822] = 4858,
  [8823] = 5548,
  [8824] = 4529,
  [8825] = 4321,
  [8826] = 4372,
  [8827] = 4682,
  [8828] = 4925,
  [8829] = 5488,
  [8830] = 4318,
  [8831] = 4409,
  [8832] = 4395,
  [8833] = 5184,
  [8834] = 5185,
  [8835] = 4366,
  [8836] = 4925,
  [8837] = 5679,
  [8838] = 7019,
  [8839] = 5139,
  [8840] = 5665,
  [8841] = 5657,
  [8842] = 5228,
  [8843] = 4925,
  [8844] = 5650,
  [8845] = 4372,
  [8846] = 4351,
  [8847] = 5664,
  [8848] = 4354,
  [8849] = 4925,
  [8850] = 4642,
  [8851] = 5422,
  [8852] = 8702,
  [8853] = 5426,
  [8854] = 5647,
  [8855] = 4206,
  [8856] = 5646,
  [8857] = 5312,
  [8858] = 5657,
  [8859] = 6055,
  [8860] = 5123,
  [8861] = 4529,
  [8862] = 4647,
  [8863] = 4656,
  [8864] = 5650,
  [8865] = 8865,
  [8866] = 4827,
  [8867] = 5647,
  [8868] = 8321,
  [8869] = 4318,
  [8870] = 4538,
  [8871] = 4591,
  [8872] = 5635,
  [8873] = 4529,
  [8874] = 4709,
  [8875] = 4656,
  [8876] = 5540,
  [8877] = 5628,
  [8878] = 4434,
  [8879] = 5539,
  [8880] = 7273,
  [8881] = 5611,
  [8882] = 5784,
  [8883] = 3987,
  [8884] = 4827,
  [8885] = 7293,
  [8886] = 4591,
  [8887] = 4355,
  [8888] = 4439,
  [8889] = 5635,
  [8890] = 5577,
  [8891] = 4529,
  [8892] = 5576,
  [8893] = 4366,
  [8894] = 5628,
  [8895] = 7230,
  [8896] = 4591,
  [8897] = 4858,
  [8898] = 4925,
  [8899] = 4325,
  [8900] = 3987,
  [8901] = 4397,
  [8902] = 4858,
  [8903] = 4321,
  [8904] = 4362,
  [8905] = 4709,
  [8906] = 4362,
  [8907] = 4387,
  [8908] = 5884,
  [8909] = 5611,
  [8910] = 4682,
  [8911] = 4386,
  [8912] = 4381,
  [8913] = 5535,
  [8914] = 4682,
  [8915] = 5469,
  [8916] = 4925,
  [8917] = 3985,
  [8918] = 4395,
  [8919] = 4402,
  [8920] = 4402,
  [8921] = 4682,
  [8922] = 8922,
  [8923] = 4820,
  [8924] = 5535,
  [8925] = 4709,
  [8926] = 5312,
  [8927] = 4387,
  [8928] = 4709,
  [8929] = 7202,
  [8930] = 5576,
  [8931] = 8931,
  [8932] = 5577,
  [8933] = 4372,
  [8934] = 4827,
  [8935] = 4386,
  [8936] = 4381,
  [8937] = 4409,
  [8938] = 4529,
  [8939] = 5784,
  [8940] = 4925,
  [8941] = 5548,
  [8942] = 5540,
  [8943] = 8298,
  [8944] = 5123,
  [8945] = 5978,
  [8946] = 8946,
  [8947] = 8946,
  [8948] = 4656,
  [8949] = 4538,
  [8950] = 5973,
  [8951] = 4321,
  [8952] = 4325,
  [8953] = 4827,
  [8954] = 4642,
  [8955] = 7202,
  [8956] = 8946,
  [8957] = 5469,
  [8958] = 5679,
  [8959] = 5539,
  [8960] = 6055,
  [8961] = 4682,
  [8962] = 5540,
  [8963] = 3985,
  [8964] = 4798,
  [8965] = 8946,
  [8966] = 8946,
  [8967] = 8946,
  [8968] = 4529,
  [8969] = 8946,
  [8970] = 5665,
  [8971] = 5908,
  [8972] = 4642,
  [8973] = 8946,
  [8974] = 5284,
  [8975] = 4366,
  [8976] = 4417,
  [8977] = 4355,
  [8978] = 4395,
  [8979] = 4538,
  [8980] = 8946,
  [8981] = 5664,
  [8982] = 4529,
  [8983] = 5396,
  [8984] = 5949,
  [8985] = 8946,
  [8986] = 4386,
  [8987] = 8946,
  [8988] = 8946,
  [8989] = 4472,
  [8990] = 7102,
  [8991] = 4409,
  [8992] = 5496,
  [8993] = 5123,
  [8994] = 8994,
  [8995] = 4351,
  [8996] = 5123,
  [8997] = 6524,
  [8998] = 5548,
  [8999] = 5784,
  [9000] = 4206,
  [9001] = 5657,
  [9002] = 5295,
  [9003] = 8946,
  [9004] = 5650,
  [9005] = 5647,
  [9006] = 8946,
  [9007] = 5123,
  [9008] = 5396,
  [9009] = 5422,
  [9010] = 5426,
  [9011] = 4858,
  [9012] = 4409,
  [9013] = 8946,
  [9014] = 8946,
  [9015] = 5213,
  [9016] = 4591,
  [9017] = 8946,
  [9018] = 4409,
  [9019] = 5908,
  [9020] = 5646,
  [9021] = 5139,
  [9022] = 5784,
  [9023] = 4366,
  [9024] = 4366,
  [9025] = 6500,
  [9026] = 4709,
  [9027] = 5341,
  [9028] = 4647,
  [9029] = 5123,
  [9030] = 4925,
  [9031] = 3985,
  [9032] = 8946,
  [9033] = 8946,
  [9034] = 5139,
  [9035] = 6524,
  [9036] = 8946,
  [9037] = 4902,
  [9038] = 4858,
  [9039] = 5139,
  [9040] = 4925,
  [9041] = 5469,
  [9042] = 7102,
  [9043] = 5539,
  [9044] = 7019,
  [9045] = 5540,
  [9046] = 8946,
  [9047] = 5341,
  [9048] = 4474,
  [9049] = 4395,
  [9050] = 8946,
  [9051] = 8946,
  [9052] = 8946,
  [9053] = 4372,
  [9054] = 4827,
  [9055] = 4395,
  [9056] = 5898,
  [9057] = 4395,
  [9058] = 5635,
  [9059] = 8946,
  [9060] = 8946,
  [9061] = 8946,
  [9062] = 4409,
  [9063] = 4820,
  [9064] = 8946,
  [9065] = 5887,
  [9066] = 5396,
  [9067] = 8946,
  [9068] = 4409,
  [9069] = 4709,
  [9070] = 8298,
  [9071] = 8946,
  [9072] = 5295,
  [9073] = 5488,
  [9074] = 4354,
  [9075] = 8946,
  [9076] = 4827,
  [9077] = 5284,
  [9078] = 5496,
  [9079] = 5182,
  [9080] = 5628,
  [9081] = 6055,
  [9082] = 4642,
  [9083] = 8946,
  [9084] = 5679,
  [9085] = 5396,
  [9086] = 5611,
  [9087] = 5228,
  [9088] = 4682,
  [9089] = 5861,
  [9090] = 4925,
  [9091] = 4386,
  [9092] = 4395,
  [9093] = 5469,
  [9094] = 8946,
  [9095] = 5341,
  [9096] = 7202,
  [9097] = 4827,
  [9098] = 4925,
  [9099] = 3987,
  [9100] = 9100,
  [9101] = 5184,
  [9102] = 6500,
  [9103] = 5665,
  [9104] = 4318,
  [9105] = 5422,
  [9106] = 4827,
  [9107] = 5295,
  [9108] = 4656,
  [9109] = 5422,
  [9110] = 4366,
  [9111] = 5284,
  [9112] = 5496,
  [9113] = 5426,
  [9114] = 5496,
  [9115] = 4642,
  [9116] = 8946,
  [9117] = 5679,
  [9118] = 4925,
  [9119] = 5139,
  [9120] = 9120,
  [9121] = 5185,
  [9122] = 4647,
  [9123] = 4362,
  [9124] = 4366,
  [9125] = 4642,
  [9126] = 5213,
  [9127] = 8946,
  [9128] = 8946,
  [9129] = 5426,
  [9130] = 5426,
  [9131] = 8946,
  [9132] = 5884,
  [9133] = 5422,
  [9134] = 5665,
  [9135] = 4386,
  [9136] = 4656,
  [9137] = 8946,
  [9138] = 5664,
  [9139] = 5548,
  [9140] = 5123,
  [9141] = 5123,
  [9142] = 4529,
  [9143] = 8994,
  [9144] = 4656,
  [9145] = 4318,
  [9146] = 5496,
  [9147] = 8946,
  [9148] = 8298,
  [9149] = 8298,
  [9150] = 5577,
  [9151] = 5861,
  [9152] = 5657,
  [9153] = 8994,
  [9154] = 5548,
  [9155] = 4387,
  [9156] = 5650,
  [9157] = 5576,
  [9158] = 5647,
  [9159] = 8946,
  [9160] = 4647,
  [9161] = 5540,
  [9162] = 5646,
  [9163] = 5312,
  [9164] = 8946,
  [9165] = 5213,
  [9166] = 5539,
  [9167] = 5539,
  [9168] = 5540,
  [9169] = 5396,
  [9170] = 5139,
  [9171] = 4647,
  [9172] = 8946,
  [9173] = 5228,
  [9174] = 4925,
  [9175] = 5139,
  [9176] = 5664,
  [9177] = 4647,
  [9178] = 4682,
  [9179] = 9179,
  [9180] = 5139,
  [9181] = 5548,
  [9182] = 4858,
  [9183] = 4902,
  [9184] = 4366,
  [9185] = 5139,
  [9186] = 8946,
  [9187] = 4386,
  [9188] = 5496,
  [9189] = 5535,
  [9190] = 8946,
  [9191] = 4409,
  [9192] = 4381,
  [9193] = 5123,
  [9194] = 4529,
  [9195] = 4709,
  [9196] = 4827,
  [9197] = 4827,
  [9198] = 5496,
  [9199] = 5635,
  [9200] = 5657,
  [9201] = 4402,
  [9202] = 5784,
  [9203] = 5650,
  [9204] = 8946,
  [9205] = 5396,
  [9206] = 8946,
  [9207] = 5123,
  [9208] = 2412,
  [9209] = 8946,
  [9210] = 5647,
  [9211] = 8946,
  [9212] = 4395,
  [9213] = 8946,
  [9214] = 5312,
  [9215] = 5341,
  [9216] = 5628,
  [9217] = 5488,
  [9218] = 8946,
  [9219] = 5884,
  [9220] = 4397,
  [9221] = 4409,
  [9222] = 4318,
  [9223] = 8946,
  [9224] = 3985,
  [9225] = 4409,
  [9226] = 4656,
  [9227] = 5295,
  [9228] = 4439,
  [9229] = 6055,
  [9230] = 8946,
  [9231] = 5284,
  [9232] = 4820,
  [9233] = 8946,
  [9234] = 8946,
  [9235] = 4647,
  [9236] = 4395,
  [9237] = 8946,
  [9238] = 8946,
  [9239] = 4474,
  [9240] = 4439,
  [9241] = 4538,
  [9242] = 7202,
  [9243] = 4386,
  [9244] = 5635,
  [9245] = 8946,
  [9246] = 4366,
  [9247] = 4318,
  [9248] = 5139,
  [9249] = 4206,
  [9250] = 6524,
  [9251] = 5341,
  [9252] = 4529,
  [9253] = 4642,
  [9254] = 4395,
  [9255] = 4647,
  [9256] = 4366,
  [9257] = 5628,
  [9258] = 4417,
  [9259] = 8946,
  [9260] = 8946,
  [9261] = 4642,
  [9262] = 5548,
  [9263] = 5488,
  [9264] = 5123,
  [9265] = 4591,
  [9266] = 8946,
  [9267] = 5611,
  [9268] = 8946,
  [9269] = 5539,
  [9270] = 5139,
  [9271] = 5908,
  [9272] = 5611,
  [9273] = 4325,
  [9274] = 4409,
  [9275] = 5341,
  [9276] = 4925,
  [9277] = 5539,
  [9278] = 4656,
  [9279] = 7102,
  [9280] = 5540,
  [9281] = 6500,
  [9282] = 4395,
  [9283] = 4642,
  [9284] = 3987,
  [9285] = 5540,
  [9286] = 8946,
  [9287] = 8946,
  [9288] = 4858,
  [9289] = 5540,
  [9290] = 4858,
  [9291] = 5539,
  [9292] = 8946,
  [9293] = 4362,
  [9294] = 4366,
  [9295] = 8946,
  [9296] = 4858,
  [9297] = 5139,
  [9298] = 4318,
  [9299] = 8946,
  [9300] = 7202,
  [9301] = 4529,
  [9302] = 4656,
  [9303] = 5123,
  [9304] = 8946,
  [9305] = 4362,
  [9306] = 8946,
  [9307] = 4529,
  [9308] = 5123,
  [9309] = 4372,
  [9310] = 4656,
  [9311] = 4417,
  [9312] = 8298,
  [9313] = 5469,
  [9314] = 8946,
  [9315] = 4682,
  [9316] = 6500,
  [9317] = 3985,
  [9318] = 5496,
  [9319] = 8946,
  [9320] = 8946,
  [9321] = 8946,
  [9322] = 4318,
  [9323] = 4472,
  [9324] = 8946,
  [9325] = 5396,
  [9326] = 5548,
  [9327] = 8298,
  [9328] = 5295,
  [9329] = 4355,
  [9330] = 5861,
  [9331] = 5213,
  [9332] = 5182,
  [9333] = 5184,
  [9334] = 4656,
  [9335] = 5341,
  [9336] = 8946,
  [9337] = 5548,
  [9338] = 5577,
  [9339] = 8946,
  [9340] = 6524,
  [9341] = 8946,
  [9342] = 8946,
  [9343] = 4417,
  [9344] = 4647,
  [9345] = 8946,
  [9346] = 4647,
  [9347] = 5295,
  [9348] = 3987,
  [9349] = 5139,
  [9350] = 4642,
  [9351] = 5284,
  [9352] = 5784,
  [9353] = 3985,
  [9354] = 5228,
  [9355] = 4925,
  [9356] = 7202,
  [9357] = 5185,
  [9358] = 5184,
  [9359] = 4827,
  [9360] = 4351,
  [9361] = 6055,
  [9362] = 7102,
  [9363] = 4827,
  [9364] = 5784,
  [9365] = 4642,
  [9366] = 5213,
  [9367] = 4827,
  [9368] = 7102,
  [9369] = 5182,
  [9370] = 4362,
  [9371] = 5577,
  [9372] = 6055,
  [9373] = 8946,
  [9374] = 8946,
  [9375] = 5978,
  [9376] = 6500,
  [9377] = 5576,
  [9378] = 5535,
  [9379] = 4709,
  [9380] = 5185,
  [9381] = 4902,
  [9382] = 5576,
  [9383] = 5488,
  [9384] = 4387,
  [9385] = 8946,
  [9386] = 4472,
  [9387] = 4925,
  [9388] = 8946,
  [9389] = 8946,
  [9390] = 3987,
  [9391] = 8946,
  [9392] = 3987,
  [9393] = 4362,
  [9394] = 5469,
  [9395] = 4381,
  [9396] = 4709,
  [9397] = 5539,
  [9398] = 8946,
  [9399] = 4642,
  [9400] = 5540,
  [9401] = 4709,
  [9402] = 5978,
  [9403] = 8374,
  [9404] = 5284,
  [9405] = 5973,
  [9406] = 8946,
  [9407] = 4642,
  [9408] = 8946,
  [9409] = 4402,
  [9410] = 5213,
  [9411] = 3987,
  [9412] = 4354,
  [9413] = 4925,
  [9414] = 4858,
  [9415] = 4387,
  [9416] = 8946,
  [9417] = 3985,
  [9418] = 8946,
  [9419] = 8946,
  [9420] = 4325,
  [9421] = 4387,
  [9422] = 4858,
  [9423] = 8946,
  [9424] = 5496,
  [9425] = 4321,
  [9426] = 5535,
  [9427] = 8298,
  [9428] = 4381,
  [9429] = 5426,
  [9430] = 5576,
  [9431] = 5949,
  [9432] = 8946,
  [9433] = 5577,
  [9434] = 4647,
  [9435] = 5396,
  [9436] = 5548,
  [9437] = 8946,
  [9438] = 5539,
  [9439] = 4206,
  [9440] = 4682,
  [9441] = 4439,
  [9442] = 5295,
  [9443] = 5422,
  [9444] = 8946,
  [9445] = 4647,
  [9446] = 7202,
  [9447] = 4402,
  [9448] = 8946,
  [9449] = 4591,
  [9450] = 4858,
  [9451] = 5908,
  [9452] = 4529,
  [9453] = 5884,
  [9454] = 5540,
  [9455] = 3987,
  [9456] = 5784,
  [9457] = 3985,
  [9458] = 5341,
  [9459] = 4682,
  [9460] = 4372,
  [9461] = 4647,
  [9462] = 8946,
  [9463] = 5488,
  [9464] = 4381,
  [9465] = 4482,
  [9466] = 8946,
  [9467] = 5884,
  [9468] = 5535,
  [9469] = 5973,
  [9470] = 8946,
  [9471] = 8946,
  [9472] = 8946,
  [9473] = 5123,
  [9474] = 4397,
  [9475] = 5539,
  [9476] = 5646,
  [9477] = 8946,
  [9478] = 4591,
  [9479] = 5887,
  [9480] = 4325,
  [9481] = 7019,
  [9482] = 5139,
  [9483] = 5898,
  [9484] = 5887,
  [9485] = 8946,
  [9486] = 5228,
  [9487] = 5295,
  [9488] = 6879,
  [9489] = 8298,
  [9490] = 8946,
  [9491] = 4474,
  [9492] = 4858,
  [9493] = 4325,
  [9494] = 5611,
  [9495] = 5496,
  [9496] = 5884,
  [9497] = 4439,
  [9498] = 5628,
  [9499] = 4402,
  [9500] = 5396,
  [9501] = 5861,
  [9502] = 5284,
  [9503] = 5908,
  [9504] = 4538,
  [9505] = 5548,
  [9506] = 5341,
  [9507] = 5396,
  [9508] = 5284,
  [9509] = 5784,
  [9510] = 5341,
  [9511] = 4402,
  [9512] = 4591,
  [9513] = 8946,
  [9514] = 5861,
  [9515] = 5295,
  [9516] = 5898,
  [9517] = 8946,
  [9518] = 5213,
  [9519] = 5284,
  [9520] = 8946,
  [9521] = 4387,
  [9522] = 4372,
  [9523] = 8946,
  [9524] = 4529,
  [9525] = 8946,
  [9526] = 4656,
  [9527] = 4858,
  [9528] = 8946,
  [9529] = 5887,
  [9530] = 5635,
  [9531] = 5548,
  [9532] = 5784,
  [9533] = 4721,
  [9534] = 8946,
  [9535] = 8946,
  [9536] = 8946,
  [9537] = 4372,
  [9538] = 5898,
  [9539] = 4417,
  [9540] = 5312,
  [9541] = 8946,
  [9542] = 8946,
  [9543] = 4656,
  [9544] = 5679,
  [9545] = 5123,
  [9546] = 5884,
  [9547] = 4642,
  [9548] = 5646,
  [9549] = 7273,
  [9550] = 5784,
  [9551] = 5284,
  [9552] = 4318,
  [9553] = 4647,
  [9554] = 8946,
  [9555] = 5647,
  [9556] = 5978,
  [9557] = 8946,
  [9558] = 4439,
  [9559] = 8298,
  [9560] = 5650,
  [9561] = 5973,
  [9562] = 5657,
  [9563] = 5295,
  [9564] = 6879,
  [9565] = 5540,
  [9566] = 3985,
  [9567] = 5539,
  [9568] = 7293,
  [9569] = 5664,
  [9570] = 4434,
  [9571] = 4656,
  [9572] = 7102,
  [9573] = 5665,
  [9574] = 4485,
  [9575] = 5949,
  [9576] = 7230,
  [9577] = 8374,
  [9578] = 3987,
  [9579] = 5784,
  [9580] = 4381,
  [9581] = 4656,
  [9582] = 5139,
  [9583] = 8946,
  [9584] = 8946,
  [9585] = 8946,
  [9586] = 6055,
  [9587] = 5949,
  [9588] = 5784,
  [9589] = 4372,
  [9590] = 6879,
  [9591] = 5284,
  [9592] = 4439,
  [9593] = 5978,
  [9594] = 3987,
  [9595] = 5628,
  [9596] = 9596,
  [9597] = 9597,
  [9598] = 4402,
  [9599] = 3985,
  [9600] = 9596,
  [9601] = 4381,
  [9602] = 5635,
  [9603] = 4529,
  [9604] = 5284,
  [9605] = 4642,
  [9606] = 4387,
  [9607] = 4858,
  [9608] = 5295,
  [9609] = 4858,
  [9610] = 4362,
  [9611] = 9611,
  [9612] = 5341,
  [9613] = 5139,
  [9614] = 5548,
  [9615] = 4366,
  [9616] = 5577,
  [9617] = 4925,
  [9618] = 5576,
  [9619] = 5396,
  [9620] = 5973,
  [9621] = 5496,
  [9622] = 7202,
  [9623] = 4647,
  [9624] = 5548,
  [9625] = 5535,
  [9626] = 4325,
  [9627] = 3985,
  [9628] = 4395,
  [9629] = 5488,
  [9630] = 5341,
  [9631] = 5295,
  [9632] = 5647,
  [9633] = 7102,
  [9634] = 5213,
  [9635] = 5949,
  [9636] = 5650,
  [9637] = 5784,
  [9638] = 5469,
  [9639] = 4858,
  [9640] = 5123,
  [9641] = 4206,
  [9642] = 5657,
  [9643] = 5908,
  [9644] = 6055,
  [9645] = 5540,
  [9646] = 5539,
  [9647] = 7102,
  [9648] = 4925,
  [9649] = 5898,
  [9650] = 5887,
  [9651] = 5488,
  [9652] = 5664,
  [9653] = 5469,
  [9654] = 5213,
  [9655] = 5396,
  [9656] = 5139,
  [9657] = 5548,
  [9658] = 5426,
  [9659] = 5422,
  [9660] = 6524,
  [9661] = 9661,
  [9662] = 4409,
  [9663] = 5426,
  [9664] = 5861,
  [9665] = 5496,
  [9666] = 5665,
  [9667] = 5341,
  [9668] = 4682,
  [9669] = 5884,
  [9670] = 8298,
  [9671] = 9671,
  [9672] = 5679,
  [9673] = 4656,
  [9674] = 5139,
  [9675] = 5496,
  [9676] = 4925,
  [9677] = 4642,
  [9678] = 4858,
  [9679] = 4827,
  [9680] = 5396,
  [9681] = 5548,
  [9682] = 4409,
  [9683] = 5396,
  [9684] = 5123,
  [9685] = 5341,
  [9686] = 5422,
  [9687] = 5539,
  [9688] = 5540,
  [9689] = 5540,
  [9690] = 5548,
  [9691] = 5576,
  [9692] = 2412,
  [9693] = 6055,
  [9694] = 5295,
  [9695] = 5540,
  [9696] = 5539,
  [9697] = 4642,
  [9698] = 5284,
  [9699] = 4395,
  [9700] = 7102,
  [9701] = 5540,
  [9702] = 5123,
  [9703] = 4858,
  [9704] = 5496,
  [9705] = 5539,
  [9706] = 4474,
  [9707] = 5535,
  [9708] = 7019,
  [9709] = 5396,
  [9710] = 5496,
  [9711] = 8374,
  [9712] = 4474,
  [9713] = 4709,
  [9714] = 5341,
  [9715] = 5540,
  [9716] = 3985,
  [9717] = 4709,
  [9718] = 5123,
  [9719] = 5139,
  [9720] = 4472,
  [9721] = 5884,
  [9722] = 7019,
  [9723] = 5295,
  [9724] = 5548,
  [9725] = 4647,
  [9726] = 5123,
  [9727] = 5284,
  [9728] = 5539,
  [9729] = 4472,
  [9730] = 5228,
  [9731] = 5548,
  [9732] = 5469,
  [9733] = 4709,
  [9734] = 4355,
  [9735] = 8374,
  [9736] = 5540,
  [9737] = 4529,
  [9738] = 5539,
  [9739] = 5548,
  [9740] = 5295,
  [9741] = 5469,
  [9742] = 4538,
  [9743] = 7102,
  [9744] = 4417,
  [9745] = 4682,
  [9746] = 5139,
  [9747] = 4397,
  [9748] = 7202,
  [9749] = 4858,
  [9750] = 5784,
  [9751] = 3985,
  [9752] = 5488,
  [9753] = 4827,
  [9754] = 9596,
  [9755] = 3987,
  [9756] = 5139,
  [9757] = 5182,
  [9758] = 4591,
  [9759] = 6879,
  [9760] = 4647,
  [9761] = 5422,
  [9762] = 9762,
  [9763] = 5184,
  [9764] = 4591,
  [9765] = 4366,
  [9766] = 5908,
  [9767] = 5577,
  [9768] = 5784,
  [9769] = 7202,
  [9770] = 5185,
  [9771] = 4925,
  [9772] = 3985,
  [9773] = 3987,
  [9774] = 4656,
  [9775] = 3985,
  [9776] = 4318,
  [9777] = 9596,
  [9778] = 4682,
  [9779] = 5488,
  [9780] = 7019,
  [9781] = 3987,
  [9782] = 5139,
  [9783] = 4529,
  [9784] = 9596,
  [9785] = 3987,
  [9786] = 5469,
  [9787] = 5861,
  [9788] = 5496,
  [9789] = 8298,
  [9790] = 5396,
  [9791] = 7019,
  [9792] = 9596,
  [9793] = 3985,
  [9794] = 8298,
  [9795] = 3985,
  [9796] = 9796,
  [9797] = 6055,
  [9798] = 6055,
  [9799] = 4386,
  [9800] = 4206,
  [9801] = 4647,
  [9802] = 5123,
  [9803] = 5341,
  [9804] = 5887,
  [9805] = 4827,
  [9806] = 5898,
  [9807] = 8298,
  [9808] = 3987,
  [9809] = 4642,
  [9810] = 9596,
  [9811] = 5295,
  [9812] = 5611,
  [9813] = 6879,
  [9814] = 9814,
  [9815] = 5884,
  [9816] = 5123,
  [9817] = 5284,
  [9818] = 4409,
  [9819] = 3987,
  [9820] = 4395,
  [9821] = 7202,
  [9822] = 4366,
  [9823] = 4925,
  [9824] = 5646,
  [9825] = 5908,
  [9826] = 5548,
  [9827] = 6524,
  [9828] = 4656,
  [9829] = 5884,
  [9830] = 5540,
  [9831] = 5539,
  [9832] = 5628,
  [9833] = 5213,
  [9834] = 5949,
  [9835] = 4642,
  [9836] = 5426,
  [9837] = 4529,
  [9838] = 8298,
  [9839] = 5646,
  [9840] = 4647,
  [9841] = 5635,
  [9842] = 5978,
  [9843] = 4827,
  [9844] = 6524,
  [9845] = 3985,
  [9846] = 5973,
  [9847] = 8298,
  [9848] = 5908,
  [9849] = 4656,
  [9850] = 9596,
  [9851] = 4656,
  [9852] = 4538,
  [9853] = 4529,
  [9854] = 3987,
  [9855] = 4827,
  [9856] = 4538,
  [9857] = 5679,
  [9858] = 5646,
  [9859] = 5647,
  [9860] = 4642,
  [9861] = 5650,
  [9862] = 8298,
  [9863] = 4647,
  [9864] = 9596,
  [9865] = 4656,
  [9866] = 7202,
  [9867] = 5540,
  [9868] = 5949,
  [9869] = 5884,
  [9870] = 4409,
  [9871] = 5784,
  [9872] = 5657,
  [9873] = 5973,
  [9874] = 5665,
  [9875] = 5978,
  [9876] = 5123,
  [9877] = 5139,
  [9878] = 5539,
  [9879] = 5679,
  [9880] = 4395,
  [9881] = 5284,
  [9882] = 5284,
  [9883] = 4538,
  [9884] = 4591,
  [9885] = 5213,
  [9886] = 5611,
  [9887] = 5295,
  [9888] = 5123,
  [9889] = 5664,
  [9890] = 5784,
  [9891] = 5861,
  [9892] = 4827,
  [9893] = 4366,
  [9894] = 5665,
  [9895] = 5213,
  [9896] = 7019,
  [9897] = 5139,
  [9898] = 5665,
  [9899] = 5679,
  [9900] = 9596,
  [9901] = 6500,
  [9902] = 5784,
  [9903] = 5341,
  [9904] = 5539,
  [9905] = 5228,
  [9906] = 9596,
  [9907] = 4354,
  [9908] = 5664,
  [9909] = 6055,
  [9910] = 5139,
  [9911] = 5396,
  [9912] = 4682,
  [9913] = 9596,
  [9914] = 6055,
  [9915] = 5535,
  [9916] = 5422,
  [9917] = 5496,
  [9918] = 7202,
  [9919] = 3987,
  [9920] = 5898,
  [9921] = 4827,
  [9922] = 6879,
  [9923] = 5664,
  [9924] = 5657,
  [9925] = 5650,
  [9926] = 4925,
  [9927] = 5647,
  [9928] = 8298,
  [9929] = 5646,
  [9930] = 5887,
  [9931] = 5312,
  [9932] = 5488,
  [9933] = 9596,
  [9934] = 5539,
  [9935] = 5540,
  [9936] = 9936,
  [9937] = 4858,
  [9938] = 5540,
  [9939] = 6524,
  [9940] = 4591,
  [9941] = 9596,
  [9942] = 5635,
  [9943] = 5139,
  [9944] = 5628,
  [9945] = 5657,
  [9946] = 4709,
  [9947] = 5887,
  [9948] = 9948,
  [9949] = 5650,
  [9950] = 5611,
  [9951] = 5861,
  [9952] = 5978,
  [9953] = 5647,
  [9954] = 5973,
  [9955] = 5576,
  [9956] = 8298,
  [9957] = 5577,
  [9958] = 9958,
  [9959] = 5123,
  [9960] = 5884,
  [9961] = 7102,
  [9962] = 4409,
  [9963] = 8374,
  [9964] = 7202,
  [9965] = 4395,
  [9966] = 8298,
  [9967] = 5548,
  [9968] = 3985,
  [9969] = 4366,
  [9970] = 4858,
  [9971] = 4827,
  [9972] = 9596,
  [9973] = 5123,
  [9974] = 5898,
  [9975] = 6879,
  [9976] = 5646,
  [9977] = 5577,
  [9978] = 4820,
  [9979] = 5576,
  [9980] = 7102,
  [9981] = 5312,
  [9982] = 7102,
  [9983] = 6500,
  [9984] = 5426,
  [9985] = 5784,
  [9986] = 6055,
  [9987] = 9596,
  [9988] = 9179,
  [9989] = 5784,
  [9990] = 5635,
  [9991] = 4925,
  [9992] = 5784,
  [9993] = 8298,
  [9994] = 6500,
  [9995] = 5535,
  [9996] = 5548,
  [9997] = 5611,
  [9998] = 9596,
  [9999] = 5539,
  [10000] = 5884,
  [10001] = 4925,
  [10002] = 4529,
  [10003] = 9596,
  [10004] = 6500,
  [10005] = 5628,
  [10006] = 5422,
  [10007] = 7019,
  [10008] = 8298,
  [10009] = 5426,
  [10010] = 5949,
  [10011] = 5539,
  [10012] = 5284,
  [10013] = 5679,
  [10014] = 5396,
  [10015] = 10015,
  [10016] = 5884,
  [10017] = 7102,
  [10018] = 5284,
  [10019] = 10019,
  [10020] = 4827,
  [10021] = 4318,
  [10022] = 5539,
  [10023] = 5540,
  [10024] = 8298,
  [10025] = 7102,
  [10026] = 5213,
  [10027] = 5540,
  [10028] = 5665,
  [10029] = 5539,
  [10030] = 5548,
  [10031] = 7202,
  [10032] = 5295,
  [10033] = 5548,
  [10034] = 5496,
  [10035] = 6055,
  [10036] = 6879,
  [10037] = 5548,
  [10038] = 6055,
  [10039] = 4595,
  [10040] = 4595,
  [10041] = 5341,
  [10042] = 5139,
  [10043] = 5213,
  [10044] = 4595,
  [10045] = 5341,
  [10046] = 10046,
  [10047] = 5539,
  [10048] = 5540,
  [10049] = 5540,
  [10050] = 8298,
  [10051] = 5539,
  [10052] = 7202,
  [10053] = 4409,
  [10054] = 5548,
  [10055] = 5396,
  [10056] = 5496,
  [10057] = 4858,
  [10058] = 4395,
  [10059] = 10059,
  [10060] = 4595,
  [10061] = 5664,
  [10062] = 4366,
  [10063] = 5213,
  [10064] = 8374,
  [10065] = 5884,
  [10066] = 5139,
  [10067] = 5539,
  [10068] = 5540,
  [10069] = 6524,
  [10070] = 4656,
  [10071] = 7102,
  [10072] = 5123,
  [10073] = 5548,
  [10074] = 4647,
  [10075] = 7202,
  [10076] = 4409,
  [10077] = 4642,
  [10078] = 5657,
  [10079] = 7102,
  [10080] = 5284,
  [10081] = 4395,
  [10082] = 5295,
  [10083] = 5650,
  [10084] = 5647,
  [10085] = 5861,
  [10086] = 4366,
  [10087] = 5123,
  [10088] = 4417,
  [10089] = 5646,
  [10090] = 10059,
  [10091] = 8298,
  [10092] = 5341,
  [10093] = 4595,
  [10094] = 7019,
  [10095] = 8298,
  [10096] = 4595,
  [10097] = 4529,
  [10098] = 10015,
  [10099] = 5139,
  [10100] = 5908,
  [10101] = 4321,
  [10102] = 5284,
  [10103] = 10019,
  [10104] = 5295,
  [10105] = 10046,
  [10106] = 5396,
  [10107] = 5123,
  [10108] = 5295,
  [10109] = 5341,
  [10110] = 5635,
  [10111] = 5396,
  [10112] = 5628,
  [10113] = 4656,
  [10114] = 4595,
  [10115] = 7202,
  [10116] = 4647,
  [10117] = 4798,
  [10118] = 5496,
  [10119] = 4642,
  [10120] = 4595,
  [10121] = 6500,
  [10122] = 10122,
  [10123] = 5611,
  [10124] = 5496,
  [10125] = 5784,
  [10126] = 7202,
  [10127] = 4656,
  [10128] = 8374,
  [10129] = 4595,
  [10130] = 4647,
  [10131] = 5426,
  [10132] = 10019,
  [10133] = 4642,
  [10134] = 5422,
  [10135] = 7019,
  [10136] = 4595,
  [10137] = 10015,
  [10138] = 5284,
  [10139] = 5496,
  [10140] = 5396,
  [10141] = 5535,
  [10142] = 7102,
  [10143] = 5341,
  [10144] = 5576,
  [10145] = 5577,
  [10146] = 10146,
  [10147] = 10147,
  [10148] = 5577,
  [10149] = 5295,
  [10150] = 5496,
  [10151] = 7102,
  [10152] = 5396,
  [10153] = 4325,
  [10154] = 5576,
  [10155] = 5213,
  [10156] = 4595,
  [10157] = 5341,
  [10158] = 7102,
  [10159] = 5469,
  [10160] = 5884,
  [10161] = 4827,
  [10162] = 8298,
  [10163] = 5295,
  [10164] = 5539,
  [10165] = 5540,
  [10166] = 10166,
  [10167] = 5284,
  [10168] = 8298,
  [10169] = 7202,
  [10170] = 5548,
  [10171] = 8298,
  [10172] = 5535,
  [10173] = 5611,
  [10174] = 7202,
  [10175] = 5488,
  [10176] = 5628,
  [10177] = 5635,
  [10178] = 5784,
  [10179] = 4595,
  [10180] = 4858,
  [10181] = 4858,
  [10182] = 10046,
  [10183] = 5646,
  [10184] = 5284,
  [10185] = 5647,
  [10186] = 5650,
  [10187] = 5657,
  [10188] = 4595,
  [10189] = 5664,
  [10190] = 5422,
  [10191] = 5426,
  [10192] = 5784,
  [10193] = 5665,
  [10194] = 7019,
  [10195] = 5295,
  [10196] = 5679,
  [10197] = 4595,
  [10198] = 4925,
  [10199] = 5284,
  [10200] = 5341,
  [10201] = 5488,
  [10202] = 5496,
  [10203] = 10122,
  [10204] = 7102,
  [10205] = 4351,
  [10206] = 5396,
  [10207] = 5496,
  [10208] = 5396,
  [10209] = 5341,
  [10210] = 5469,
  [10211] = 5295,
  [10212] = 5284,
  [10213] = 5784,
  [10214] = 5213,
  [10215] = 6500,
  [10216] = 8298,
  [10217] = 5496,
  [10218] = 4858,
  [10219] = 5139,
  [10220] = 5784,
  [10221] = 5784,
  [10222] = 6055,
  [10223] = 5396,
  [10224] = 5139,
  [10225] = 4595,
  [10226] = 5341,
  [10227] = 5295,
  [10228] = 5284,
  [10229] = 6879,
  [10230] = 3987,
  [10231] = 7202,
  [10232] = 6879,
  [10233] = 4595,
  [10234] = 5784,
  [10235] = 3987,
  [10236] = 5887,
  [10237] = 5898,
  [10238] = 4595,
  [10239] = 5139,
  [10240] = 5548,
  [10241] = 4538,
  [10242] = 5540,
  [10243] = 5539,
  [10244] = 6055,
  [10245] = 6524,
  [10246] = 4372,
  [10247] = 5949,
  [10248] = 5978,
  [10249] = 5973,
  [10250] = 5540,
  [10251] = 5548,
  [10252] = 5548,
  [10253] = 5973,
  [10254] = 5123,
  [10255] = 5949,
  [10256] = 7102,
  [10257] = 8298,
  [10258] = 5884,
  [10259] = 7102,
  [10260] = 4925,
  [10261] = 4397,
  [10262] = 10059,
  [10263] = 5978,
  [10264] = 5548,
  [10265] = 4595,
  [10266] = 5784,
  [10267] = 4439,
  [10268] = 5784,
  [10269] = 3985,
  [10270] = 5488,
  [10271] = 10271,
  [10272] = 10272,
  [10273] = 4529,
  [10274] = 5540,
  [10275] = 5884,
  [10276] = 5908,
  [10277] = 5539,
  [10278] = 4595,
  [10279] = 3985,
  [10280] = 5469,
  [10281] = 5898,
  [10282] = 4591,
  [10283] = 5284,
  [10284] = 5887,
  [10285] = 5295,
  [10286] = 8298,
  [10287] = 6524,
  [10288] = 4409,
  [10289] = 4595,
  [10290] = 4402,
  [10291] = 10046,
  [10292] = 5123,
  [10293] = 5341,
  [10294] = 5861,
  [10295] = 5139,
  [10296] = 4381,
  [10297] = 4395,
  [10298] = 3987,
  [10299] = 5123,
  [10300] = 6879,
  [10301] = 8298,
  [10302] = 5396,
  [10303] = 8374,
  [10304] = 7202,
  [10305] = 5139,
  [10306] = 5496,
  [10307] = 5540,
  [10308] = 5539,
  [10309] = 10019,
  [10310] = 4595,
  [10311] = 5123,
  [10312] = 5539,
  [10313] = 5540,
  [10314] = 10122,
  [10315] = 4366,
  [10316] = 4387,
  [10317] = 3987,
  [10318] = 6500,
  [10319] = 4529,
  [10320] = 5539,
  [10321] = 5540,
  [10322] = 7202,
  [10323] = 4925,
  [10324] = 10019,
  [10325] = 7019,
  [10326] = 10015,
  [10327] = 8298,
  [10328] = 5548,
  [10329] = 4595,
  [10330] = 5123,
  [10331] = 5540,
  [10332] = 10059,
  [10333] = 5539,
  [10334] = 4682,
  [10335] = 6524,
  [10336] = 6055,
  [10337] = 3985,
  [10338] = 4362,
  [10339] = 3985,
  [10340] = 3987,
  [10341] = 4709,
  [10342] = 5548,
  [10343] = 8298,
  [10344] = 7202,
  [10345] = 5548,
  [10346] = 4925,
  [10347] = 8298,
  [10348] = 7102,
  [10349] = 3987,
  [10350] = 5784,
  [10351] = 3985,
  [10352] = 3987,
  [10353] = 4386,
  [10354] = 3985,
  [10355] = 4595,
  [10356] = 5396,
  [10357] = 4925,
  [10358] = 10015,
  [10359] = 5295,
  [10360] = 5496,
  [10361] = 4595,
  [10362] = 5422,
  [10363] = 5341,
  [10364] = 5426,
  [10365] = 10365,
  [10366] = 5341,
  [10367] = 5496,
  [10368] = 8298,
  [10369] = 8298,
  [10370] = 5884,
  [10371] = 5784,
  [10372] = 5539,
  [10373] = 5540,
  [10374] = 5548,
  [10375] = 5548,
  [10376] = 5496,
  [10377] = 3985,
  [10378] = 5396,
  [10379] = 10379,
  [10380] = 3987,
  [10381] = 7202,
  [10382] = 5341,
  [10383] = 3985,
  [10384] = 5284,
  [10385] = 5784,
  [10386] = 4721,
  [10387] = 3987,
  [10388] = 3985,
  [10389] = 10379,
  [10390] = 5295,
  [10391] = 5295,
  [10392] = 3987,
  [10393] = 5396,
  [10394] = 5540,
  [10395] = 5341,
  [10396] = 5496,
  [10397] = 5396,
  [10398] = 5539,
  [10399] = 4721,
  [10400] = 5295,
  [10401] = 5284,
  [10402] = 5496,
  [10403] = 8298,
  [10404] = 4721,
  [10405] = 9814,
  [10406] = 7202,
  [10407] = 4721,
  [10408] = 10408,
  [10409] = 7102,
  [10410] = 5341,
  [10411] = 9762,
  [10412] = 8298,
  [10413] = 4721,
  [10414] = 5123,
  [10415] = 3985,
  [10416] = 5488,
  [10417] = 10417,
  [10418] = 4827,
  [10419] = 4925,
  [10420] = 3987,
  [10421] = 5295,
  [10422] = 5540,
  [10423] = 10379,
  [10424] = 10424,
  [10425] = 3985,
  [10426] = 5539,
  [10427] = 6055,
  [10428] = 5341,
  [10429] = 7019,
  [10430] = 10379,
  [10431] = 10431,
  [10432] = 4721,
  [10433] = 5213,
  [10434] = 5422,
  [10435] = 5548,
  [10436] = 5284,
  [10437] = 7102,
  [10438] = 9796,
  [10439] = 5284,
  [10440] = 5488,
  [10441] = 5295,
  [10442] = 6500,
  [10443] = 10443,
  [10444] = 5341,
  [10445] = 5548,
  [10446] = 5396,
  [10447] = 5887,
  [10448] = 10448,
  [10449] = 5213,
  [10450] = 5284,
  [10451] = 5540,
  [10452] = 5657,
  [10453] = 7102,
  [10454] = 5284,
  [10455] = 5539,
  [10456] = 7102,
  [10457] = 4721,
  [10458] = 10379,
  [10459] = 10379,
  [10460] = 5139,
  [10461] = 5496,
  [10462] = 4721,
  [10463] = 5284,
  [10464] = 10464,
  [10465] = 5295,
  [10466] = 4858,
  [10467] = 10467,
  [10468] = 5679,
  [10469] = 5539,
  [10470] = 5540,
  [10471] = 10379,
  [10472] = 4721,
  [10473] = 5341,
  [10474] = 7102,
  [10475] = 5469,
  [10476] = 4336,
  [10477] = 5396,
  [10478] = 5548,
  [10479] = 5139,
  [10480] = 10379,
  [10481] = 5496,
  [10482] = 5884,
  [10483] = 4721,
  [10484] = 6524,
  [10485] = 5784,
  [10486] = 10379,
  [10487] = 6879,
  [10488] = 6055,
  [10489] = 10489,
  [10490] = 4409,
  [10491] = 7202,
  [10492] = 8298,
  [10493] = 4721,
  [10494] = 8374,
  [10495] = 7102,
  [10496] = 10379,
  [10497] = 6879,
  [10498] = 8298,
  [10499] = 5577,
  [10500] = 4858,
  [10501] = 10379,
  [10502] = 3987,
  [10503] = 5295,
  [10504] = 4721,
  [10505] = 4858,
  [10506] = 5488,
  [10507] = 5469,
  [10508] = 10508,
  [10509] = 4721,
  [10510] = 5576,
  [10511] = 6500,
  [10512] = 5973,
  [10513] = 6500,
  [10514] = 10467,
  [10515] = 10515,
  [10516] = 10379,
  [10517] = 5949,
  [10518] = 5884,
  [10519] = 6055,
  [10520] = 4721,
  [10521] = 7202,
  [10522] = 5665,
  [10523] = 10379,
  [10524] = 5635,
  [10525] = 10379,
  [10526] = 3987,
  [10527] = 5611,
  [10528] = 5139,
  [10529] = 4925,
  [10530] = 5784,
  [10531] = 8374,
  [10532] = 5426,
  [10533] = 4925,
  [10534] = 4656,
  [10535] = 10408,
  [10536] = 8298,
  [10537] = 10379,
  [10538] = 3985,
  [10539] = 4647,
  [10540] = 4721,
  [10541] = 7019,
  [10542] = 4642,
  [10543] = 5426,
  [10544] = 7202,
  [10545] = 4529,
  [10546] = 6055,
  [10547] = 5548,
  [10548] = 10515,
  [10549] = 4366,
  [10550] = 7202,
  [10551] = 4925,
  [10552] = 5496,
  [10553] = 5284,
  [10554] = 5123,
  [10555] = 10555,
  [10556] = 6055,
  [10557] = 5540,
  [10558] = 4858,
  [10559] = 4721,
  [10560] = 6524,
  [10561] = 5123,
  [10562] = 5539,
  [10563] = 5396,
  [10564] = 10379,
  [10565] = 4721,
  [10566] = 7102,
  [10567] = 5469,
  [10568] = 10379,
  [10569] = 5426,
  [10570] = 5341,
  [10571] = 5295,
  [10572] = 4395,
  [10573] = 4642,
  [10574] = 5422,
  [10575] = 3987,
  [10576] = 10379,
  [10577] = 5535,
  [10578] = 4721,
  [10579] = 4721,
  [10580] = 10379,
  [10581] = 5884,
  [10582] = 5295,
  [10583] = 5978,
  [10584] = 10379,
  [10585] = 3985,
  [10586] = 5341,
  [10587] = 5341,
  [10588] = 4647,
  [10589] = 4721,
  [10590] = 6500,
  [10591] = 8298,
  [10592] = 7019,
  [10593] = 4656,
  [10594] = 5284,
  [10595] = 7202,
  [10596] = 7102,
  [10597] = 5548,
  [10598] = 10515,
  [10599] = 10408,
  [10600] = 7102,
  [10601] = 5213,
  [10602] = 9762,
  [10603] = 5540,
  [10604] = 5539,
  [10605] = 10379,
  [10606] = 5784,
  [10607] = 5422,
  [10608] = 5396,
  [10609] = 5784,
  [10610] = 5396,
  [10611] = 4721,
  [10612] = 7102,
  [10613] = 5628,
  [10614] = 3985,
  [10615] = 10615,
  [10616] = 5139,
  [10617] = 4336,
  [10618] = 5539,
  [10619] = 10379,
  [10620] = 5540,
  [10621] = 4529,
  [10622] = 6879,
  [10623] = 5548,
  [10624] = 5496,
  [10625] = 10379,
  [10626] = 5647,
  [10627] = 4827,
  [10628] = 9814,
  [10629] = 5469,
  [10630] = 4721,
  [10631] = 5396,
  [10632] = 5650,
  [10633] = 5784,
  [10634] = 10379,
  [10635] = 6500,
  [10636] = 7202,
  [10637] = 7202,
  [10638] = 5539,
  [10639] = 5548,
  [10640] = 8298,
  [10641] = 7202,
  [10642] = 9796,
  [10643] = 5540,
  [10644] = 5422,
  [10645] = 5884,
  [10646] = 10379,
  [10647] = 8374,
  [10648] = 10489,
  [10649] = 5898,
  [10650] = 5664,
  [10651] = 5123,
  [10652] = 4721,
  [10653] = 8374,
  [10654] = 4721,
  [10655] = 5284,
  [10656] = 5426,
  [10657] = 5496,
  [10658] = 5784,
  [10659] = 10365,
  [10660] = 5488,
  [10661] = 3987,
  [10662] = 5396,
  [10663] = 10467,
  [10664] = 5539,
  [10665] = 5540,
  [10666] = 5496,
  [10667] = 5213,
  [10668] = 5295,
  [10669] = 5548,
  [10670] = 5539,
  [10671] = 5784,
  [10672] = 7019,
  [10673] = 5488,
  [10674] = 5496,
  [10675] = 4858,
  [10676] = 5496,
  [10677] = 5284,
  [10678] = 5784,
  [10679] = 3985,
  [10680] = 5469,
  [10681] = 5422,
  [10682] = 3987,
  [10683] = 5426,
  [10684] = 5396,
  [10685] = 10685,
  [10686] = 8298,
  [10687] = 5496,
  [10688] = 5488,
  [10689] = 3985,
  [10690] = 5213,
  [10691] = 3985,
  [10692] = 5496,
  [10693] = 5396,
  [10694] = 5139,
  [10695] = 7102,
  [10696] = 10696,
  [10697] = 4340,
  [10698] = 3987,
  [10699] = 5341,
  [10700] = 3985,
  [10701] = 5496,
  [10702] = 8298,
  [10703] = 7102,
  [10704] = 5295,
  [10705] = 3987,
  [10706] = 10706,
  [10707] = 7202,
  [10708] = 5284,
  [10709] = 10709,
  [10710] = 5540,
  [10711] = 3987,
  [10712] = 7019,
  [10713] = 5284,
  [10714] = 8298,
  [10715] = 5396,
  [10716] = 5284,
  [10717] = 10706,
  [10718] = 5488,
  [10719] = 7019,
  [10720] = 7202,
  [10721] = 10721,
  [10722] = 10722,
  [10723] = 5213,
  [10724] = 5548,
  [10725] = 5548,
  [10726] = 6055,
  [10727] = 6879,
  [10728] = 5540,
  [10729] = 6055,
  [10730] = 8374,
  [10731] = 5213,
  [10732] = 5426,
  [10733] = 5539,
  [10734] = 5548,
  [10735] = 6879,
  [10736] = 5422,
  [10737] = 10737,
  [10738] = 10738,
  [10739] = 5540,
  [10740] = 5539,
  [10741] = 8298,
  [10742] = 5488,
  [10743] = 8374,
  [10744] = 5139,
  [10745] = 5784,
  [10746] = 5295,
  [10747] = 6879,
  [10748] = 5396,
  [10749] = 5295,
  [10750] = 10750,
  [10751] = 5548,
  [10752] = 5884,
  [10753] = 5295,
  [10754] = 5341,
  [10755] = 5469,
  [10756] = 7102,
  [10757] = 5884,
  [10758] = 5341,
  [10759] = 5548,
  [10760] = 7202,
  [10761] = 10738,
  [10762] = 5213,
  [10763] = 7202,
  [10764] = 10737,
  [10765] = 10738,
  [10766] = 10737,
  [10767] = 6055,
  [10768] = 5396,
  [10769] = 5469,
  [10770] = 10770,
  [10771] = 5123,
  [10772] = 8374,
  [10773] = 5539,
  [10774] = 5884,
  [10775] = 5341,
  [10776] = 5540,
  [10777] = 10777,
  [10778] = 5496,
  [10779] = 5540,
  [10780] = 5139,
  [10781] = 7202,
  [10782] = 5548,
  [10783] = 5396,
  [10784] = 5539,
  [10785] = 7102,
  [10786] = 7202,
  [10787] = 8298,
  [10788] = 5426,
  [10789] = 8374,
  [10790] = 7102,
  [10791] = 10424,
  [10792] = 5422,
  [10793] = 10685,
  [10794] = 5539,
  [10795] = 10722,
  [10796] = 7102,
  [10797] = 10721,
  [10798] = 4321,
  [10799] = 5884,
  [10800] = 8298,
  [10801] = 7019,
  [10802] = 5540,
  [10803] = 5540,
  [10804] = 3987,
  [10805] = 6879,
  [10806] = 5539,
  [10807] = 10722,
  [10808] = 5496,
  [10809] = 4340,
  [10810] = 5295,
  [10811] = 5539,
  [10812] = 4820,
  [10813] = 10721,
  [10814] = 5469,
  [10815] = 10709,
  [10816] = 9762,
  [10817] = 5539,
  [10818] = 5540,
  [10819] = 5396,
  [10820] = 7102,
  [10821] = 9796,
  [10822] = 5540,
  [10823] = 5422,
  [10824] = 6055,
  [10825] = 5341,
  [10826] = 4925,
  [10827] = 9814,
  [10828] = 10737,
  [10829] = 7202,
  [10830] = 4336,
  [10831] = 10738,
  [10832] = 5426,
  [10833] = 5341,
  [10834] = 8298,
  [10835] = 6879,
  [10836] = 5784,
  [10837] = 10837,
  [10838] = 7202,
  [10839] = 5213,
  [10840] = 10840,
  [10841] = 5548,
  [10842] = 5284,
  [10843] = 7019,
  [10844] = 10840,
  [10845] = 5295,
  [10846] = 5139,
  [10847] = 5295,
  [10848] = 5123,
  [10849] = 5123,
  [10850] = 5295,
  [10851] = 6500,
  [10852] = 7202,
  [10853] = 10722,
  [10854] = 5784,
  [10855] = 5123,
  [10856] = 5284,
  [10857] = 5295,
  [10858] = 7102,
  [10859] = 10721,
  [10860] = 8298,
  [10861] = 5548,
  [10862] = 10840,
  [10863] = 10837,
  [10864] = 5496,
  [10865] = 5228,
  [10866] = 5341,
  [10867] = 7019,
  [10868] = 10837,
  [10869] = 5539,
  [10870] = 5284,
  [10871] = 5548,
  [10872] = 4336,
  [10873] = 5284,
  [10874] = 7102,
  [10875] = 5548,
  [10876] = 5396,
  [10877] = 5496,
  [10878] = 3985,
  [10879] = 5284,
  [10880] = 5396,
  [10881] = 5496,
  [10882] = 4827,
  [10883] = 5341,
  [10884] = 5341,
  [10885] = 6524,
  [10886] = 7202,
  [10887] = 5341,
  [10888] = 5540,
  [10889] = 5295,
  [10890] = 5396,
  [10891] = 5284,
  [10892] = 5884,
  [10893] = 10555,
  [10894] = 4321,
  [10895] = 5539,
  [10896] = 5540,
  [10897] = 5422,
  [10898] = 10898,
  [10899] = 4340,
  [10900] = 10900,
  [10901] = 5469,
  [10902] = 10898,
  [10903] = 4321,
  [10904] = 5887,
  [10905] = 8374,
  [10906] = 8374,
  [10907] = 5898,
  [10908] = 5469,
  [10909] = 5422,
  [10910] = 10900,
  [10911] = 5884,
  [10912] = 10912,
  [10913] = 5426,
  [10914] = 4647,
  [10915] = 10915,
  [10916] = 8651,
  [10917] = 6055,
  [10918] = 5540,
  [10919] = 5539,
  [10920] = 10920,
  [10921] = 6879,
  [10922] = 10922,
  [10923] = 5784,
  [10924] = 5496,
  [10925] = 8865,
  [10926] = 10926,
  [10927] = 5396,
  [10928] = 10928,
  [10929] = 5422,
  [10930] = 10930,
  [10931] = 10931,
  [10932] = 10932,
  [10933] = 10933,
  [10934] = 4642,
  [10935] = 5908,
  [10936] = 5861,
  [10937] = 3987,
  [10938] = 10938,
  [10939] = 10939,
  [10940] = 10940,
  [10941] = 10941,
  [10942] = 5548,
  [10943] = 7202,
  [10944] = 6055,
  [10945] = 7019,
  [10946] = 3987,
  [10947] = 5679,
  [10948] = 5884,
  [10949] = 5488,
  [10950] = 5182,
  [10951] = 5184,
  [10952] = 3985,
  [10953] = 5185,
  [10954] = 10954,
  [10955] = 4656,
  [10956] = 10939,
  [10957] = 4321,
  [10958] = 5182,
  [10959] = 5496,
  [10960] = 10960,
  [10961] = 5784,
  [10962] = 10928,
  [10963] = 8931,
  [10964] = 5665,
  [10965] = 5548,
  [10966] = 10938,
  [10967] = 5548,
  [10968] = 7202,
  [10969] = 8287,
  [10970] = 5213,
  [10971] = 5488,
  [10972] = 10972,
  [10973] = 5664,
  [10974] = 5540,
  [10975] = 5539,
  [10976] = 7102,
  [10977] = 7102,
  [10978] = 8714,
  [10979] = 8714,
  [10980] = 4472,
  [10981] = 6055,
  [10982] = 8287,
  [10983] = 5657,
  [10984] = 5488,
  [10985] = 10985,
  [10986] = 5650,
  [10987] = 4206,
  [10988] = 5647,
  [10989] = 5469,
  [10990] = 5422,
  [10991] = 10991,
  [10992] = 10992,
  [10993] = 5646,
  [10994] = 5284,
  [10995] = 10938,
  [10996] = 6055,
  [10997] = 5469,
  [10998] = 10939,
  [10999] = 5312,
  [11000] = 5488,
  [11001] = 7102,
  [11002] = 5295,
  [11003] = 5295,
  [11004] = 5341,
  [11005] = 5284,
  [11006] = 4318,
  [11007] = 5548,
  [11008] = 5635,
  [11009] = 5396,
  [11010] = 5184,
  [11011] = 4336,
  [11012] = 4336,
  [11013] = 7202,
  [11014] = 5884,
  [11015] = 5496,
  [11016] = 5540,
  [11017] = 10912,
  [11018] = 11018,
  [11019] = 8390,
  [11020] = 5628,
  [11021] = 11021,
  [11022] = 5539,
  [11023] = 11018,
  [11024] = 5949,
  [11025] = 8865,
  [11026] = 5341,
  [11027] = 7102,
  [11028] = 5295,
  [11029] = 5185,
  [11030] = 4366,
  [11031] = 5341,
  [11032] = 7102,
  [11033] = 4353,
  [11034] = 10972,
  [11035] = 10972,
  [11036] = 5884,
  [11037] = 8298,
  [11038] = 4348,
  [11039] = 10900,
  [11040] = 5611,
  [11041] = 3985,
  [11042] = 4351,
  [11043] = 7102,
  [11044] = 10464,
  [11045] = 10898,
  [11046] = 5426,
  [11047] = 5548,
  [11048] = 5426,
  [11049] = 10417,
  [11050] = 10431,
  [11051] = 5469,
  [11052] = 5577,
  [11053] = 5576,
  [11054] = 5123,
  [11055] = 10920,
  [11056] = 5284,
  [11057] = 5539,
  [11058] = 7102,
  [11059] = 7202,
  [11060] = 5295,
  [11061] = 11061,
  [11062] = 5284,
  [11063] = 8390,
  [11064] = 11064,
  [11065] = 10443,
  [11066] = 5496,
  [11067] = 5284,
  [11068] = 5496,
  [11069] = 3987,
  [11070] = 5540,
  [11071] = 4395,
  [11072] = 5295,
  [11073] = 3987,
  [11074] = 8651,
  [11075] = 10448,
  [11076] = 5539,
  [11077] = 10972,
  [11078] = 5284,
  [11079] = 5396,
  [11080] = 5295,
  [11081] = 8482,
  [11082] = 5535,
  [11083] = 11083,
  [11084] = 10922,
  [11085] = 10931,
  [11086] = 11086,
  [11087] = 8491,
  [11088] = 5396,
  [11089] = 10448,
  [11090] = 5539,
  [11091] = 5341,
  [11092] = 5295,
  [11093] = 5341,
  [11094] = 10912,
  [11095] = 5396,
  [11096] = 5496,
  [11097] = 10920,
  [11098] = 5540,
  [11099] = 4348,
  [11100] = 4336,
  [11101] = 8499,
  [11102] = 5182,
  [11103] = 3985,
  [11104] = 3985,
  [11105] = 5341,
  [11106] = 11083,
  [11107] = 10443,
  [11108] = 10938,
  [11109] = 8522,
  [11110] = 4474,
  [11111] = 4409,
  [11112] = 4474,
  [11113] = 3987,
  [11114] = 5184,
  [11115] = 5978,
  [11116] = 5496,
  [11117] = 5185,
  [11118] = 3985,
  [11119] = 5295,
  [11120] = 5396,
  [11121] = 11121,
  [11122] = 11122,
  [11123] = 5548,
  [11124] = 4351,
  [11125] = 5284,
  [11126] = 10928,
  [11127] = 10431,
  [11128] = 5496,
  [11129] = 8584,
  [11130] = 8374,
  [11131] = 10417,
  [11132] = 8931,
  [11133] = 11086,
  [11134] = 7202,
  [11135] = 5396,
  [11136] = 10931,
  [11137] = 5284,
  [11138] = 10922,
  [11139] = 5396,
  [11140] = 5341,
  [11141] = 11141,
  [11142] = 5139,
  [11143] = 11064,
  [11144] = 5422,
  [11145] = 11061,
  [11146] = 5426,
  [11147] = 5341,
  [11148] = 5284,
  [11149] = 8482,
  [11150] = 8491,
  [11151] = 5426,
  [11152] = 10464,
  [11153] = 5295,
  [11154] = 4336,
  [11155] = 8390,
  [11156] = 5341,
  [11157] = 10555,
  [11158] = 8499,
  [11159] = 8522,
  [11160] = 8584,
  [11161] = 5488,
  [11162] = 11064,
  [11163] = 8374,
  [11164] = 3985,
  [11165] = 5973,
  [11166] = 3987,
  [11167] = 8298,
  [11168] = 6055,
  [11169] = 5396,
  [11170] = 5548,
  [11171] = 7202,
  [11172] = 5496,
  [11173] = 4472,
  [11174] = 11174,
  [11175] = 3987,
  [11176] = 3985,
  [11177] = 11018,
  [11178] = 4340,
  [11179] = 11061,
  [11180] = 5540,
  [11181] = 5213,
  [11182] = 10696,
  [11183] = 11083,
  [11184] = 7102,
  [11185] = 5284,
  [11186] = 5295,
  [11187] = 5341,
  [11188] = 4348,
  [11189] = 5496,
  [11190] = 5540,
  [11191] = 8482,
  [11192] = 8491,
  [11193] = 8499,
  [11194] = 5539,
  [11195] = 4395,
  [11196] = 5284,
  [11197] = 8522,
  [11198] = 8584,
  [11199] = 5295,
  [11200] = 5213,
  [11201] = 5341,
  [11202] = 5396,
  [11203] = 11203,
  [11204] = 5496,
  [11205] = 8865,
  [11206] = 5469,
  [11207] = 8931,
  [11208] = 4409,
  [11209] = 7202,
  [11210] = 5496,
  [11211] = 3985,
  [11212] = 5978,
  [11213] = 5973,
  [11214] = 5488,
  [11215] = 11215,
  [11216] = 11216,
  [11217] = 4366,
  [11218] = 11218,
  [11219] = 11219,
  [11220] = 5396,
  [11221] = 10770,
  [11222] = 11219,
  [11223] = 5548,
  [11224] = 11224,
  [11225] = 5284,
  [11226] = 11218,
  [11227] = 10750,
  [11228] = 5295,
  [11229] = 5341,
  [11230] = 5396,
  [11231] = 8651,
  [11232] = 3987,
  [11233] = 5496,
  [11234] = 5949,
  [11235] = 4336,
  [11236] = 4348,
  [11237] = 5341,
  [11238] = 4325,
  [11239] = 5396,
  [11240] = 5540,
  [11241] = 3985,
  [11242] = 7102,
  [11243] = 11243,
  [11244] = 11141,
  [11245] = 8374,
  [11246] = 11246,
  [11247] = 7102,
  [11248] = 11216,
  [11249] = 4325,
  [11250] = 11250,
  [11251] = 5539,
  [11252] = 11215,
  [11253] = 11253,
  [11254] = 5539,
  [11255] = 4355,
  [11256] = 5540,
  [11257] = 7102,
  [11258] = 4351,
  [11259] = 5539,
  [11260] = 8298,
  [11261] = 8287,
  [11262] = 8714,
  [11263] = 11224,
  [11264] = 5540,
  [11265] = 5898,
  [11266] = 11083,
  [11267] = 11086,
  [11268] = 4372,
  [11269] = 5295,
  [11270] = 5887,
  [11271] = 8298,
  [11272] = 4474,
  [11273] = 5548,
  [11274] = 3985,
  [11275] = 10555,
  [11276] = 4472,
  [11277] = 5184,
  [11278] = 4474,
  [11279] = 4386,
  [11280] = 10464,
  [11281] = 4336,
  [11282] = 10448,
  [11283] = 5284,
  [11284] = 3985,
  [11285] = 5496,
  [11286] = 4325,
  [11287] = 5884,
  [11288] = 4372,
  [11289] = 5548,
  [11290] = 5185,
  [11291] = 5184,
  [11292] = 10443,
  [11293] = 4439,
  [11294] = 4321,
  [11295] = 11295,
  [11296] = 5422,
  [11297] = 5396,
  [11298] = 4402,
  [11299] = 5426,
  [11300] = 5884,
  [11301] = 11301,
  [11302] = 11302,
  [11303] = 11303,
  [11304] = 5295,
  [11305] = 3987,
  [11306] = 11306,
  [11307] = 5341,
  [11308] = 4381,
  [11309] = 6055,
  [11310] = 11253,
  [11311] = 5426,
  [11312] = 5548,
  [11313] = 4472,
  [11314] = 5182,
  [11315] = 5422,
  [11316] = 11316,
  [11317] = 5548,
  [11318] = 10431,
  [11319] = 5284,
  [11320] = 4417,
  [11321] = 3987,
  [11322] = 8298,
  [11323] = 4366,
  [11324] = 5295,
  [11325] = 10417,
  [11326] = 5488,
  [11327] = 5284,
  [11328] = 11328,
  [11329] = 5213,
  [11330] = 5295,
  [11331] = 4387,
  [11332] = 3987,
  [11333] = 4321,
  [11334] = 4386,
  [11335] = 8374,
  [11336] = 5784,
  [11337] = 5341,
  [11338] = 4336,
  [11339] = 4395,
  [11340] = 4321,
  [11341] = 5540,
  [11342] = 4439,
  [11343] = 5539,
  [11344] = 5341,
  [11345] = 5284,
  [11346] = 4409,
  [11347] = 7202,
  [11348] = 4362,
  [11349] = 5469,
  [11350] = 7202,
  [11351] = 4386,
  [11352] = 6524,
  [11353] = 10696,
  [11354] = 5396,
  [11355] = 4321,
  [11356] = 3985,
  [11357] = 5784,
  [11358] = 5496,
  [11359] = 6055,
  [11360] = 11086,
  [11361] = 11215,
  [11362] = 7102,
  [11363] = 10750,
  [11364] = 11216,
  [11365] = 11216,
  [11366] = 4362,
  [11367] = 10770,
  [11368] = 11083,
  [11369] = 3987,
  [11370] = 5182,
  [11371] = 11218,
  [11372] = 11219,
  [11373] = 11253,
  [11374] = 11218,
  [11375] = 4402,
  [11376] = 11219,
  [11377] = 4336,
  [11378] = 4381,
  [11379] = 3985,
  [11380] = 5185,
  [11381] = 8390,
  [11382] = 4355,
  [11383] = 4353,
  [11384] = 11215,
  [11385] = 3987,
  [11386] = 11215,
  [11387] = 4351,
  [11388] = 5496,
  [11389] = 11216,
  [11390] = 3985,
  [11391] = 4591,
  [11392] = 11218,
  [11393] = 4318,
  [11394] = 4318,
  [11395] = 11219,
  [11396] = 11086,
  [11397] = 7202,
  [11398] = 11224,
  [11399] = 7202,
  [11400] = 3987,
  [11401] = 7102,
  [11402] = 5396,
  [11403] = 4387,
  [11404] = 3985,
  [11405] = 4417,
  [11406] = 3987,
  [11407] = 11407,
  [11408] = 11407,
  [11409] = 11409,
  [11410] = 11407,
  [11411] = 11407,
  [11412] = 5295,
  [11413] = 11413,
  [11414] = 11407,
  [11415] = 11407,
  [11416] = 11413,
  [11417] = 11417,
  [11418] = 11407,
  [11419] = 5539,
  [11420] = 11420,
  [11421] = 4387,
  [11422] = 11413,
  [11423] = 11413,
  [11424] = 4362,
  [11425] = 4647,
  [11426] = 5284,
  [11427] = 11407,
  [11428] = 11413,
  [11429] = 8714,
  [11430] = 4351,
  [11431] = 8287,
  [11432] = 11407,
  [11433] = 11413,
  [11434] = 11407,
  [11435] = 11413,
  [11436] = 11407,
  [11437] = 8374,
  [11438] = 3987,
  [11439] = 4355,
  [11440] = 11440,
  [11441] = 4381,
  [11442] = 11413,
  [11443] = 11407,
  [11444] = 3985,
  [11445] = 11413,
  [11446] = 11446,
  [11447] = 4321,
  [11448] = 11448,
  [11449] = 5295,
  [11450] = 3985,
  [11451] = 11407,
  [11452] = 4472,
  [11453] = 4362,
  [11454] = 7102,
  [11455] = 4318,
  [11456] = 4318,
  [11457] = 4381,
  [11458] = 11407,
  [11459] = 5341,
  [11460] = 11413,
  [11461] = 11409,
  [11462] = 11409,
  [11463] = 11413,
  [11464] = 11407,
  [11465] = 4402,
  [11466] = 4474,
  [11467] = 4439,
  [11468] = 4656,
  [11469] = 11413,
  [11470] = 11470,
  [11471] = 11471,
  [11472] = 4642,
  [11473] = 3987,
  [11474] = 11407,
  [11475] = 11407,
  [11476] = 11413,
  [11477] = 4386,
  [11478] = 3985,
  [11479] = 4351,
  [11480] = 11446,
  [11481] = 5396,
  [11482] = 5496,
  [11483] = 11446,
  [11484] = 11413,
  [11485] = 11407,
  [11486] = 11413,
  [11487] = 4372,
  [11488] = 11407,
  [11489] = 11489,
  [11490] = 11407,
  [11491] = 5341,
  [11492] = 11413,
  [11493] = 8651,
  [11494] = 11413,
  [11495] = 11407,
  [11496] = 4336,
  [11497] = 11407,
  [11498] = 11413,
  [11499] = 4529,
  [11500] = 11407,
  [11501] = 11413,
  [11502] = 11413,
  [11503] = 4386,
  [11504] = 11407,
  [11505] = 11413,
  [11506] = 5213,
  [11507] = 3987,
  [11508] = 11413,
  [11509] = 11407,
  [11510] = 11510,
  [11511] = 4351,
  [11512] = 4340,
  [11513] = 8390,
  [11514] = 11413,
  [11515] = 4318,
  [11516] = 4318,
  [11517] = 10696,
  [11518] = 5426,
  [11519] = 5422,
  [11520] = 11407,
  [11521] = 7019,
  [11522] = 5540,
  [11523] = 3985,
  [11524] = 4321,
  [11525] = 4387,
  [11526] = 4325,
  [11527] = 4417,
  [11528] = 5213,
  [11529] = 11407,
  [11530] = 11530,
  [11531] = 11407,
  [11532] = 11413,
  [11533] = 4355,
  [11534] = 5396,
  [11535] = 10750,
  [11536] = 4402,
  [11537] = 5548,
  [11538] = 4340,
  [11539] = 11407,
  [11540] = 11413,
  [11541] = 11407,
  [11542] = 11407,
  [11543] = 4340,
  [11544] = 4439,
  [11545] = 11407,
  [11546] = 11413,
  [11547] = 4409,
  [11548] = 11548,
  [11549] = 4372,
  [11550] = 3987,
  [11551] = 11413,
  [11552] = 4395,
  [11553] = 11413,
  [11554] = 5284,
  [11555] = 4366,
  [11556] = 10770,
  [11557] = 5185,
  [11558] = 11407,
  [11559] = 11413,
  [11560] = 4529,
  [11561] = 5184,
  [11562] = 11407,
  [11563] = 4321,
  [11564] = 5496,
  [11565] = 11407,
  [11566] = 11407,
  [11567] = 7202,
  [11568] = 4351,
  [11569] = 11413,
  [11570] = 11413,
  [11571] = 8714,
  [11572] = 8287,
  [11573] = 11413,
  [11574] = 11407,
  [11575] = 4409,
  [11576] = 5182,
  [11577] = 11413,
  [11578] = 4395,
  [11579] = 11413,
  [11580] = 11407,
  [11581] = 11413,
  [11582] = 11407,
  [11583] = 11407,
  [11584] = 11446,
  [11585] = 11413,
  [11586] = 11413,
  [11587] = 11407,
  [11588] = 5488,
  [11589] = 11413,
  [11590] = 11590,
  [11591] = 11407,
  [11592] = 11413,
  [11593] = 5469,
  [11594] = 11413,
  [11595] = 11413,
  [11596] = 3985,
  [11597] = 11407,
  [11598] = 6055,
  [11599] = 10424,
  [11600] = 11413,
  [11601] = 11407,
  [11602] = 11413,
  [11603] = 11407,
  [11604] = 11413,
  [11605] = 11417,
  [11606] = 11413,
  [11607] = 11407,
  [11608] = 11413,
  [11609] = 11407,
  [11610] = 11407,
  [11611] = 8482,
  [11612] = 8651,
  [11613] = 8491,
  [11614] = 11413,
  [11615] = 11413,
  [11616] = 4366,
  [11617] = 11407,
  [11618] = 11413,
  [11619] = 11409,
  [11620] = 11407,
  [11621] = 11407,
  [11622] = 4340,
  [11623] = 8499,
  [11624] = 11407,
  [11625] = 8522,
  [11626] = 11413,
  [11627] = 11627,
  [11628] = 11413,
  [11629] = 11471,
  [11630] = 11407,
  [11631] = 8931,
  [11632] = 11413,
  [11633] = 11407,
  [11634] = 4417,
  [11635] = 11413,
  [11636] = 11413,
  [11637] = 8584,
  [11638] = 11407,
  [11639] = 11413,
  [11640] = 11409,
  [11641] = 11446,
  [11642] = 5185,
  [11643] = 4325,
  [11644] = 5184,
  [11645] = 5496,
  [11646] = 5396,
  [11647] = 5182,
  [11648] = 11407,
  [11649] = 8482,
  [11650] = 8491,
  [11651] = 8499,
  [11652] = 11413,
  [11653] = 11407,
  [11654] = 11413,
  [11655] = 11407,
  [11656] = 8522,
  [11657] = 11413,
  [11658] = 3987,
  [11659] = 8584,
  [11660] = 11413,
  [11661] = 4321,
  [11662] = 5341,
  [11663] = 11407,
  [11664] = 11413,
  [11665] = 11407,
  [11666] = 5295,
  [11667] = 5284,
  [11668] = 11407,
  [11669] = 3987,
  [11670] = 11413,
  [11671] = 11407,
  [11672] = 4336,
  [11673] = 5884,
  [11674] = 4321,
  [11675] = 3985,
  [11676] = 11407,
  [11677] = 11413,
  [11678] = 11407,
  [11679] = 11413,
  [11680] = 11407,
  [11681] = 8865,
  [11682] = 11413,
  [11683] = 11407,
  [11684] = 4474,
  [11685] = 11407,
  [11686] = 11413,
  [11687] = 8931,
  [11688] = 11407,
  [11689] = 4472,
  [11690] = 11413,
  [11691] = 11413,
  [11692] = 11407,
  [11693] = 11413,
  [11694] = 11407,
  [11695] = 11413,
  [11696] = 11413,
  [11697] = 11407,
  [11698] = 11407,
  [11699] = 8865,
  [11700] = 11413,
  [11701] = 11413,
  [11702] = 8499,
  [11703] = 8522,
  [11704] = 8584,
  [11705] = 5978,
  [11706] = 8499,
  [11707] = 8491,
  [11708] = 8865,
  [11709] = 8931,
  [11710] = 5973,
  [11711] = 3985,
  [11712] = 8482,
  [11713] = 11246,
  [11714] = 11714,
  [11715] = 11715,
  [11716] = 11716,
  [11717] = 11717,
  [11718] = 4348,
  [11719] = 11719,
  [11720] = 11720,
  [11721] = 11721,
  [11722] = 5496,
  [11723] = 11723,
  [11724] = 5213,
  [11725] = 11725,
  [11726] = 11716,
  [11727] = 3987,
  [11728] = 11716,
  [11729] = 11716,
  [11730] = 11716,
  [11731] = 4386,
  [11732] = 4353,
  [11733] = 5949,
  [11734] = 8651,
  [11735] = 11735,
  [11736] = 8287,
  [11737] = 4417,
  [11738] = 11510,
  [11739] = 4325,
  [11740] = 8714,
  [11741] = 5295,
  [11742] = 5185,
  [11743] = 5184,
  [11744] = 4351,
  [11745] = 11716,
  [11746] = 8482,
  [11747] = 11716,
  [11748] = 8390,
  [11749] = 8482,
  [11750] = 8491,
  [11751] = 11420,
  [11752] = 8499,
  [11753] = 8522,
  [11754] = 8491,
  [11755] = 8584,
  [11756] = 4409,
  [11757] = 8499,
  [11758] = 8522,
  [11759] = 5396,
  [11760] = 8584,
  [11761] = 4409,
  [11762] = 8865,
  [11763] = 8714,
  [11764] = 8287,
  [11765] = 11716,
  [11766] = 11716,
  [11767] = 4395,
  [11768] = 5496,
  [11769] = 4395,
  [11770] = 5284,
  [11771] = 4336,
  [11772] = 11448,
  [11773] = 4472,
  [11774] = 4351,
  [11775] = 5978,
  [11776] = 4529,
  [11777] = 11243,
  [11778] = 4318,
  [11779] = 4351,
  [11780] = 5898,
  [11781] = 11716,
  [11782] = 8931,
  [11783] = 11716,
  [11784] = 11716,
  [11785] = 5973,
  [11786] = 11716,
  [11787] = 5887,
  [11788] = 11716,
  [11789] = 4474,
  [11790] = 5396,
  [11791] = 11791,
  [11792] = 4362,
  [11793] = 4472,
  [11794] = 5341,
  [11795] = 5341,
  [11796] = 5213,
  [11797] = 5341,
  [11798] = 4387,
  [11799] = 8931,
  [11800] = 4325,
  [11801] = 4366,
  [11802] = 11716,
  [11803] = 5396,
  [11804] = 5496,
  [11805] = 11716,
  [11806] = 4591,
  [11807] = 11716,
  [11808] = 11470,
  [11809] = 4472,
  [11810] = 5295,
  [11811] = 5949,
  [11812] = 5185,
  [11813] = 5184,
  [11814] = 4366,
  [11815] = 11716,
  [11816] = 11302,
  [11817] = 5182,
  [11818] = 8651,
  [11819] = 5182,
  [11820] = 5284,
  [11821] = 5295,
  [11822] = 11716,
  [11823] = 11716,
  [11824] = 8651,
  [11825] = 8287,
  [11826] = 11716,
  [11827] = 8714,
  [11828] = 11828,
  [11829] = 11829,
  [11830] = 11830,
  [11831] = 11716,
  [11832] = 4474,
  [11833] = 8865,
  [11834] = 8390,
  [11835] = 11295,
  [11836] = 11302,
  [11837] = 4372,
  [11838] = 4362,
  [11839] = 11716,
  [11840] = 7202,
  [11841] = 5284,
  [11842] = 11716,
  [11843] = 11716,
  [11844] = 4386,
  [11845] = 4439,
  [11846] = 4474,
  [11847] = 4351,
  [11848] = 4402,
  [11849] = 4381,
  [11850] = 11850,
  [11851] = 4387,
  [11852] = 5898,
  [11853] = 4362,
  [11854] = 11716,
  [11855] = 11855,
  [11856] = 11856,
  [11857] = 5887,
  [11858] = 3985,
  [11859] = 3987,
  [11860] = 8287,
  [11861] = 4387,
  [11862] = 8714,
  [11863] = 8390,
  [11864] = 11864,
  [11865] = 11716,
  [11866] = 11328,
  [11867] = 4381,
  [11868] = 4318,
  [11869] = 4318,
  [11870] = 5284,
  [11871] = 4348,
  [11872] = 11872,
  [11873] = 4353,
  [11874] = 5295,
  [11875] = 4402,
  [11876] = 4439,
  [11877] = 11716,
  [11878] = 11878,
  [11879] = 11872,
  [11880] = 5341,
  [11881] = 11881,
  [11882] = 11882,
  [11883] = 11883,
  [11884] = 5185,
  [11885] = 11885,
  [11886] = 5184,
  [11887] = 5396,
  [11888] = 5182,
  [11889] = 11889,
  [11890] = 11890,
  [11891] = 11735,
  [11892] = 11716,
  [11893] = 4381,
  [11894] = 7102,
  [11895] = 11895,
  [11896] = 11896,
  [11897] = 11897,
  [11898] = 4325,
  [11899] = 11716,
  [11900] = 4402,
  [11901] = 11901,
  [11902] = 8651,
  [11903] = 11716,
  [11904] = 11904,
  [11905] = 11448,
  [11906] = 5496,
  [11907] = 11716,
  [11908] = 4409,
  [11909] = 5284,
  [11910] = 4348,
  [11911] = 8931,
  [11912] = 11912,
  [11913] = 4395,
  [11914] = 11716,
  [11915] = 5295,
  [11916] = 8482,
  [11917] = 11716,
  [11918] = 8865,
  [11919] = 11716,
  [11920] = 11920,
  [11921] = 11716,
  [11922] = 11922,
  [11923] = 11716,
  [11924] = 11924,
  [11925] = 11735,
  [11926] = 11716,
  [11927] = 11927,
  [11928] = 8491,
  [11929] = 11716,
  [11930] = 11303,
  [11931] = 11301,
  [11932] = 4366,
  [11933] = 5496,
  [11934] = 4538,
  [11935] = 8522,
  [11936] = 11548,
  [11937] = 11716,
  [11938] = 11716,
  [11939] = 8584,
  [11940] = 4439,
  [11941] = 4362,
  [11942] = 4387,
  [11943] = 5341,
  [11944] = 5396,
  [11945] = 4381,
  [11946] = 4417,
  [11947] = 5396,
  [11948] = 11716,
  [11949] = 5496,
  [11950] = 4402,
  [11951] = 11250,
  [11952] = 4336,
  [11953] = 11716,
  [11954] = 11716,
  [11955] = 5539,
  [11956] = 5540,
  [11957] = 8584,
  [11958] = 8522,
  [11959] = 4372,
  [11960] = 11960,
  [11961] = 4348,
  [11962] = 4439,
  [11963] = 11590,
  [11964] = 4336,
  [11965] = 4474,
  [11966] = 4321,
  [11967] = 4386,
  [11968] = 4372,
  [11969] = 11510,
  [11970] = 11306,
  [11971] = 4472,
  [11972] = 11716,
  [11973] = 11716,
  [11974] = 8499,
  [11975] = 4925,
  [11976] = 4372,
  [11977] = 5185,
  [11978] = 5184,
  [11979] = 5182,
  [11980] = 8491,
  [11981] = 8390,
  [11982] = 8482,
  [11983] = 11716,
  [11984] = 4325,
  [11985] = 4386,
  [11986] = 5341,
  [11987] = 4318,
  [11988] = 8865,
  [11989] = 11716,
  [11990] = 5548,
  [11991] = 4366,
  [11992] = 4417,
  [11993] = 5295,
  [11994] = 4395,
  [11995] = 11716,
  [11996] = 11716,
  [11997] = 11997,
  [11998] = 11998,
  [11999] = 5284,
  [12000] = 4321,
  [12001] = 12001,
  [12002] = 11716,
  [12003] = 4409,
  [12004] = 8931,
  [12005] = 11716,
  [12006] = 11716,
  [12007] = 11716,
  [12008] = 11716,
  [12009] = 4529,
  [12010] = 11716,
  [12011] = 8390,
  [12012] = 8651,
  [12013] = 11716,
  [12014] = 5182,
  [12015] = 11716,
  [12016] = 12016,
  [12017] = 12017,
  [12018] = 5184,
  [12019] = 4318,
  [12020] = 5185,
  [12021] = 11246,
  [12022] = 11243,
  [12023] = 11716,
  [12024] = 11716,
  [12025] = 8287,
  [12026] = 8714,
  [12027] = 4336,
  [12028] = 4417,
  [12029] = 11716,
  [12030] = 11716,
  [12031] = 11716,
  [12032] = 11872,
  [12033] = 11716,
  [12034] = 11716,
  [12035] = 11716,
  [12036] = 5213,
  [12037] = 11295,
  [12038] = 11716,
  [12039] = 11716,
  [12040] = 11716,
  [12041] = 11716,
  [12042] = 11328,
  [12043] = 4336,
  [12044] = 11303,
  [12045] = 11301,
  [12046] = 11250,
  [12047] = 11306,
  [12048] = 4321,
  [12049] = 11716,
  [12050] = 11716,
  [12051] = 4336,
  [12052] = 12052,
  [12053] = 10933,
  [12054] = 12054,
  [12055] = 12054,
  [12056] = 4472,
  [12057] = 4351,
  [12058] = 12058,
  [12059] = 4474,
  [12060] = 3987,
  [12061] = 12054,
  [12062] = 12062,
  [12063] = 12054,
  [12064] = 12064,
  [12065] = 4355,
  [12066] = 12054,
  [12067] = 8714,
  [12068] = 12054,
  [12069] = 8390,
  [12070] = 8287,
  [12071] = 12071,
  [12072] = 8651,
  [12073] = 8931,
  [12074] = 12074,
  [12075] = 5213,
  [12076] = 12054,
  [12077] = 12054,
  [12078] = 8865,
  [12079] = 11448,
  [12080] = 12054,
  [12081] = 12054,
  [12082] = 12054,
  [12083] = 8584,
  [12084] = 12054,
  [12085] = 8522,
  [12086] = 8499,
  [12087] = 12054,
  [12088] = 8491,
  [12089] = 4318,
  [12090] = 8482,
  [12091] = 12054,
  [12092] = 12071,
  [12093] = 5496,
  [12094] = 12054,
  [12095] = 12054,
  [12096] = 4362,
  [12097] = 11302,
  [12098] = 4387,
  [12099] = 4381,
  [12100] = 4336,
  [12101] = 12054,
  [12102] = 12054,
  [12103] = 4402,
  [12104] = 12054,
  [12105] = 12054,
  [12106] = 4409,
  [12107] = 4439,
  [12108] = 4386,
  [12109] = 4372,
  [12110] = 12054,
  [12111] = 4321,
  [12112] = 4474,
  [12113] = 5396,
  [12114] = 4472,
  [12115] = 4355,
  [12116] = 12054,
  [12117] = 12054,
  [12118] = 4395,
  [12119] = 12054,
  [12120] = 8390,
  [12121] = 4355,
  [12122] = 12122,
  [12123] = 12123,
  [12124] = 12124,
  [12125] = 5185,
  [12126] = 5184,
  [12127] = 5182,
  [12128] = 12128,
  [12129] = 12129,
  [12130] = 4366,
  [12131] = 12054,
  [12132] = 12054,
  [12133] = 12071,
  [12134] = 4474,
  [12135] = 12054,
  [12136] = 4336,
  [12137] = 4325,
  [12138] = 5182,
  [12139] = 5341,
  [12140] = 5184,
  [12141] = 12122,
  [12142] = 5185,
  [12143] = 12054,
  [12144] = 12064,
  [12145] = 12062,
  [12146] = 11510,
  [12147] = 12054,
  [12148] = 8390,
  [12149] = 4340,
  [12150] = 4472,
  [12151] = 5295,
  [12152] = 12054,
  [12153] = 4351,
  [12154] = 5887,
  [12155] = 12054,
  [12156] = 12054,
  [12157] = 12157,
  [12158] = 12158,
  [12159] = 12159,
  [12160] = 12054,
  [12161] = 3987,
  [12162] = 12162,
  [12163] = 12054,
  [12164] = 5898,
  [12165] = 12054,
  [12166] = 3985,
  [12167] = 5884,
  [12168] = 8374,
  [12169] = 11721,
  [12170] = 12170,
  [12171] = 11960,
  [12172] = 12054,
  [12173] = 12054,
  [12174] = 11791,
  [12175] = 12054,
  [12176] = 12054,
  [12177] = 12054,
  [12178] = 12054,
  [12179] = 11927,
  [12180] = 12054,
  [12181] = 12159,
  [12182] = 12054,
  [12183] = 12183,
  [12184] = 12054,
  [12185] = 12158,
  [12186] = 5469,
  [12187] = 12187,
  [12188] = 11721,
  [12189] = 12054,
  [12190] = 12054,
  [12191] = 12054,
  [12192] = 5488,
  [12193] = 4362,
  [12194] = 3987,
  [12195] = 5496,
  [12196] = 5396,
  [12197] = 11448,
  [12198] = 5284,
  [12199] = 5949,
  [12200] = 3985,
  [12201] = 11924,
  [12202] = 12054,
  [12203] = 11922,
  [12204] = 5341,
  [12205] = 12158,
  [12206] = 12206,
  [12207] = 4387,
  [12208] = 12054,
  [12209] = 12159,
  [12210] = 11920,
  [12211] = 5295,
  [12212] = 3987,
  [12213] = 6055,
  [12214] = 12162,
  [12215] = 12054,
  [12216] = 4381,
  [12217] = 5284,
  [12218] = 12054,
  [12219] = 11882,
  [12220] = 12054,
  [12221] = 3985,
  [12222] = 12183,
  [12223] = 12223,
  [12224] = 11883,
  [12225] = 4386,
  [12226] = 12054,
  [12227] = 4417,
  [12228] = 4372,
  [12229] = 12054,
  [12230] = 5973,
  [12231] = 4362,
  [12232] = 4402,
  [12233] = 4439,
  [12234] = 12183,
  [12235] = 4321,
  [12236] = 4387,
  [12237] = 12054,
  [12238] = 4381,
  [12239] = 12187,
  [12240] = 12054,
  [12241] = 11246,
  [12242] = 11243,
  [12243] = 12054,
  [12244] = 4372,
  [12245] = 12054,
  [12246] = 5978,
  [12247] = 11912,
  [12248] = 12054,
  [12249] = 11850,
  [12250] = 12054,
  [12251] = 12054,
  [12252] = 12054,
  [12253] = 5213,
  [12254] = 4402,
  [12255] = 12054,
  [12256] = 4439,
  [12257] = 11855,
  [12258] = 12258,
  [12259] = 12170,
  [12260] = 11856,
  [12261] = 11864,
  [12262] = 4386,
  [12263] = 12159,
  [12264] = 12054,
  [12265] = 12265,
  [12266] = 11141,
  [12267] = 10930,
  [12268] = 12054,
  [12269] = 10932,
  [12270] = 4417,
  [12271] = 11904,
  [12272] = 11901,
  [12273] = 4529,
  [12274] = 11897,
  [12275] = 12054,
  [12276] = 12054,
  [12277] = 11896,
  [12278] = 12158,
  [12279] = 12054,
  [12280] = 5185,
  [12281] = 12054,
  [12282] = 12282,
  [12283] = 4362,
  [12284] = 11895,
  [12285] = 12054,
  [12286] = 12158,
  [12287] = 4387,
  [12288] = 8390,
  [12289] = 12159,
  [12290] = 11890,
  [12291] = 12054,
  [12292] = 5182,
  [12293] = 4336,
  [12294] = 11855,
  [12295] = 11889,
  [12296] = 11885,
  [12297] = 12054,
  [12298] = 11883,
  [12299] = 12054,
  [12300] = 11882,
  [12301] = 4381,
  [12302] = 11881,
  [12303] = 12054,
  [12304] = 11295,
  [12305] = 11878,
  [12306] = 11881,
  [12307] = 12054,
  [12308] = 11885,
  [12309] = 11889,
  [12310] = 8482,
  [12311] = 4417,
  [12312] = 4325,
  [12313] = 8931,
  [12314] = 8491,
  [12315] = 8499,
  [12316] = 5496,
  [12317] = 12317,
  [12318] = 4402,
  [12319] = 4439,
  [12320] = 8522,
  [12321] = 11510,
  [12322] = 4372,
  [12323] = 4366,
  [12324] = 12054,
  [12325] = 8584,
  [12326] = 12054,
  [12327] = 12054,
  [12328] = 11714,
  [12329] = 12054,
  [12330] = 12330,
  [12331] = 5396,
  [12332] = 12054,
  [12333] = 11890,
  [12334] = 4395,
  [12335] = 12335,
  [12336] = 12054,
  [12337] = 11895,
  [12338] = 12338,
  [12339] = 12339,
  [12340] = 11878,
  [12341] = 12341,
  [12342] = 12157,
  [12343] = 8482,
  [12344] = 11328,
  [12345] = 8491,
  [12346] = 12346,
  [12347] = 8499,
  [12348] = 12054,
  [12349] = 8865,
  [12350] = 8522,
  [12351] = 8584,
  [12352] = 4409,
  [12353] = 12054,
  [12354] = 11896,
  [12355] = 12355,
  [12356] = 8931,
  [12357] = 11715,
  [12358] = 12054,
  [12359] = 11897,
  [12360] = 12054,
  [12361] = 5341,
  [12362] = 10992,
  [12363] = 11717,
  [12364] = 12054,
  [12365] = 12054,
  [12366] = 12054,
  [12367] = 8865,
  [12368] = 11719,
  [12369] = 11901,
  [12370] = 4325,
  [12371] = 8287,
  [12372] = 11720,
  [12373] = 12054,
  [12374] = 5295,
  [12375] = 12054,
  [12376] = 4472,
  [12377] = 12377,
  [12378] = 5284,
  [12379] = 11904,
  [12380] = 12223,
  [12381] = 12162,
  [12382] = 5184,
  [12383] = 12054,
  [12384] = 4538,
  [12385] = 12054,
  [12386] = 11723,
  [12387] = 11912,
  [12388] = 12054,
  [12389] = 11864,
  [12390] = 8651,
  [12391] = 4395,
  [12392] = 4409,
  [12393] = 4474,
  [12394] = 12054,
  [12395] = 12157,
  [12396] = 11856,
  [12397] = 12054,
  [12398] = 11920,
  [12399] = 11922,
  [12400] = 11924,
  [12401] = 5426,
  [12402] = 12054,
  [12403] = 5422,
  [12404] = 11723,
  [12405] = 12054,
  [12406] = 12406,
  [12407] = 11850,
  [12408] = 12054,
  [12409] = 12054,
  [12410] = 12054,
  [12411] = 12054,
  [12412] = 4318,
  [12413] = 12054,
  [12414] = 8651,
  [12415] = 12415,
  [12416] = 12416,
  [12417] = 11719,
  [12418] = 11303,
  [12419] = 11717,
  [12420] = 11715,
  [12421] = 11301,
  [12422] = 12265,
  [12423] = 11714,
  [12424] = 8287,
  [12425] = 4340,
  [12426] = 8714,
  [12427] = 12054,
  [12428] = 12054,
  [12429] = 4417,
  [12430] = 12430,
  [12431] = 12054,
  [12432] = 12054,
  [12433] = 4366,
  [12434] = 12054,
  [12435] = 12054,
  [12436] = 11720,
  [12437] = 12054,
  [12438] = 4318,
  [12439] = 12054,
  [12440] = 3985,
  [12441] = 12054,
  [12442] = 11725,
  [12443] = 11791,
  [12444] = 4355,
  [12445] = 4321,
  [12446] = 4529,
  [12447] = 12170,
  [12448] = 8714,
  [12449] = 12258,
  [12450] = 4366,
  [12451] = 4395,
  [12452] = 11725,
  [12453] = 12054,
  [12454] = 12054,
  [12455] = 4409,
  [12456] = 12054,
  [12457] = 12054,
  [12458] = 11250,
  [12459] = 12054,
  [12460] = 11927,
  [12461] = 11306,
  [12462] = 12054,
  [12463] = 12054,
  [12464] = 4591,
  [12465] = 4318,
  [12466] = 12466,
  [12467] = 12467,
  [12468] = 12468,
  [12469] = 12468,
  [12470] = 11714,
  [12471] = 12466,
  [12472] = 11510,
  [12473] = 4321,
  [12474] = 12467,
  [12475] = 12475,
  [12476] = 12467,
  [12477] = 12467,
  [12478] = 11715,
  [12479] = 11717,
  [12480] = 12467,
  [12481] = 12466,
  [12482] = 12467,
  [12483] = 5228,
  [12484] = 12484,
  [12485] = 12485,
  [12486] = 4321,
  [12487] = 11719,
  [12488] = 12466,
  [12489] = 12466,
  [12490] = 12490,
  [12491] = 12466,
  [12492] = 11723,
  [12493] = 12466,
  [12494] = 11720,
  [12495] = 12467,
  [12496] = 12467,
  [12497] = 11723,
  [12498] = 12498,
  [12499] = 12466,
  [12500] = 3985,
  [12501] = 12467,
  [12502] = 11720,
  [12503] = 11719,
  [12504] = 12467,
  [12505] = 12466,
  [12506] = 4336,
  [12507] = 12507,
  [12508] = 12466,
  [12509] = 12466,
  [12510] = 4386,
  [12511] = 12467,
  [12512] = 12467,
  [12513] = 12466,
  [12514] = 12467,
  [12515] = 12498,
  [12516] = 12466,
  [12517] = 12466,
  [12518] = 11715,
  [12519] = 11717,
  [12520] = 7102,
  [12521] = 12466,
  [12522] = 11448,
  [12523] = 12467,
  [12524] = 12467,
  [12525] = 5496,
  [12526] = 12475,
  [12527] = 12468,
  [12528] = 3987,
  [12529] = 12529,
  [12530] = 12466,
  [12531] = 12531,
  [12532] = 5396,
  [12533] = 12466,
  [12534] = 12534,
  [12535] = 12467,
  [12536] = 12466,
  [12537] = 12466,
  [12538] = 4529,
  [12539] = 12466,
  [12540] = 12466,
  [12541] = 12529,
  [12542] = 12468,
  [12543] = 12475,
  [12544] = 12467,
  [12545] = 12545,
  [12546] = 12466,
  [12547] = 12466,
  [12548] = 12467,
  [12549] = 11714,
  [12550] = 4351,
  [12551] = 12466,
  [12552] = 5341,
  [12553] = 12466,
  [12554] = 4925,
  [12555] = 12534,
  [12556] = 12466,
  [12557] = 12557,
  [12558] = 12475,
  [12559] = 12467,
  [12560] = 12468,
  [12561] = 12561,
  [12562] = 12562,
  [12563] = 12466,
  [12564] = 12466,
  [12565] = 12565,
  [12566] = 12566,
  [12567] = 12567,
  [12568] = 12568,
  [12569] = 12468,
  [12570] = 12467,
  [12571] = 4351,
  [12572] = 12468,
  [12573] = 12467,
  [12574] = 12475,
  [12575] = 12467,
  [12576] = 12475,
  [12577] = 12498,
  [12578] = 12466,
  [12579] = 12466,
  [12580] = 12467,
  [12581] = 12466,
  [12582] = 12466,
  [12583] = 12282,
  [12584] = 12467,
  [12585] = 12467,
  [12586] = 12466,
  [12587] = 12466,
  [12588] = 4366,
  [12589] = 4395,
  [12590] = 4647,
  [12591] = 4409,
  [12592] = 12466,
  [12593] = 12467,
  [12594] = 12466,
  [12595] = 4529,
  [12596] = 12466,
  [12597] = 5295,
  [12598] = 4321,
  [12599] = 12467,
  [12600] = 4318,
  [12601] = 12475,
  [12602] = 12468,
  [12603] = 12467,
  [12604] = 12466,
  [12605] = 12466,
  [12606] = 4642,
  [12607] = 12466,
  [12608] = 5284,
  [12609] = 12609,
  [12610] = 12466,
  [12611] = 12467,
  [12612] = 4362,
  [12613] = 4325,
  [12614] = 12466,
  [12615] = 12468,
  [12616] = 12475,
  [12617] = 12467,
  [12618] = 12466,
  [12619] = 11725,
  [12620] = 4387,
  [12621] = 4366,
  [12622] = 12467,
  [12623] = 12467,
  [12624] = 4395,
  [12625] = 4409,
  [12626] = 11721,
  [12627] = 12475,
  [12628] = 12468,
  [12629] = 4381,
  [12630] = 4402,
  [12631] = 12466,
  [12632] = 11882,
  [12633] = 11883,
  [12634] = 12634,
  [12635] = 12466,
  [12636] = 4439,
  [12637] = 12466,
  [12638] = 4386,
  [12639] = 12534,
  [12640] = 4372,
  [12641] = 12641,
  [12642] = 12642,
  [12643] = 12466,
  [12644] = 12467,
  [12645] = 8390,
  [12646] = 12467,
  [12647] = 12468,
  [12648] = 12475,
  [12649] = 12475,
  [12650] = 3985,
  [12651] = 12466,
  [12652] = 3987,
  [12653] = 12467,
  [12654] = 3985,
  [12655] = 3987,
  [12656] = 12466,
  [12657] = 12498,
  [12658] = 4642,
  [12659] = 3985,
  [12660] = 4325,
  [12661] = 11723,
  [12662] = 12466,
  [12663] = 12466,
  [12664] = 3987,
  [12665] = 12665,
  [12666] = 12666,
  [12667] = 12467,
  [12668] = 12466,
  [12669] = 12466,
  [12670] = 12670,
  [12671] = 12467,
  [12672] = 12467,
  [12673] = 11927,
  [12674] = 12467,
  [12675] = 12675,
  [12676] = 12529,
  [12677] = 12467,
  [12678] = 11924,
  [12679] = 12466,
  [12680] = 11922,
  [12681] = 11920,
  [12682] = 12498,
  [12683] = 12466,
  [12684] = 4321,
  [12685] = 4656,
  [12686] = 4351,
  [12687] = 11448,
  [12688] = 12468,
  [12689] = 12475,
  [12690] = 12467,
  [12691] = 12691,
  [12692] = 5185,
  [12693] = 11912,
  [12694] = 12466,
  [12695] = 12490,
  [12696] = 12466,
  [12697] = 12466,
  [12698] = 12466,
  [12699] = 12466,
  [12700] = 4318,
  [12701] = 11864,
  [12702] = 12467,
  [12703] = 8714,
  [12704] = 8287,
  [12705] = 12705,
  [12706] = 12466,
  [12707] = 12466,
  [12708] = 12466,
  [12709] = 4647,
  [12710] = 12466,
  [12711] = 11904,
  [12712] = 12467,
  [12713] = 11901,
  [12714] = 12467,
  [12715] = 12466,
  [12716] = 12416,
  [12717] = 11897,
  [12718] = 12466,
  [12719] = 11896,
  [12720] = 12467,
  [12721] = 11895,
  [12722] = 12475,
  [12723] = 12466,
  [12724] = 12468,
  [12725] = 12475,
  [12726] = 11889,
  [12727] = 11890,
  [12728] = 12468,
  [12729] = 4336,
  [12730] = 11889,
  [12731] = 11885,
  [12732] = 12568,
  [12733] = 12466,
  [12734] = 11881,
  [12735] = 11878,
  [12736] = 12466,
  [12737] = 4336,
  [12738] = 12467,
  [12739] = 12466,
  [12740] = 12691,
  [12741] = 12466,
  [12742] = 4472,
  [12743] = 12534,
  [12744] = 12609,
  [12745] = 12317,
  [12746] = 12467,
  [12747] = 12467,
  [12748] = 4474,
  [12749] = 12468,
  [12750] = 12466,
  [12751] = 12467,
  [12752] = 12752,
  [12753] = 12475,
  [12754] = 12754,
  [12755] = 11791,
  [12756] = 12467,
  [12757] = 4472,
  [12758] = 12557,
  [12759] = 12468,
  [12760] = 12475,
  [12761] = 12466,
  [12762] = 4362,
  [12763] = 4474,
  [12764] = 11856,
  [12765] = 11855,
  [12766] = 12466,
  [12767] = 4656,
  [12768] = 4529,
  [12769] = 11720,
  [12770] = 12705,
  [12771] = 12466,
  [12772] = 12466,
  [12773] = 11850,
  [12774] = 3985,
  [12775] = 11719,
  [12776] = 8651,
  [12777] = 4858,
  [12778] = 12466,
  [12779] = 12467,
  [12780] = 4351,
  [12781] = 12466,
  [12782] = 12467,
  [12783] = 12466,
  [12784] = 12475,
  [12785] = 12466,
  [12786] = 12466,
  [12787] = 5182,
  [12788] = 5184,
  [12789] = 3987,
  [12790] = 12466,
  [12791] = 12466,
  [12792] = 12466,
  [12793] = 12467,
  [12794] = 5213,
  [12795] = 8931,
  [12796] = 12466,
  [12797] = 12529,
  [12798] = 11791,
  [12799] = 12466,
  [12800] = 4529,
  [12801] = 12705,
  [12802] = 12802,
  [12803] = 12475,
  [12804] = 12466,
  [12805] = 12467,
  [12806] = 12468,
  [12807] = 8865,
  [12808] = 4340,
  [12809] = 12467,
  [12810] = 4417,
  [12811] = 11721,
  [12812] = 4387,
  [12813] = 12466,
  [12814] = 12814,
  [12815] = 12815,
  [12816] = 12466,
  [12817] = 8584,
  [12818] = 12466,
  [12819] = 8522,
  [12820] = 4381,
  [12821] = 12466,
  [12822] = 4402,
  [12823] = 11717,
  [12824] = 4439,
  [12825] = 11715,
  [12826] = 4386,
  [12827] = 12467,
  [12828] = 4372,
  [12829] = 11714,
  [12830] = 12468,
  [12831] = 12475,
  [12832] = 8499,
  [12833] = 8491,
  [12834] = 12467,
  [12835] = 12466,
  [12836] = 12836,
  [12837] = 4321,
  [12838] = 12466,
  [12839] = 8482,
  [12840] = 12475,
  [12841] = 12467,
  [12842] = 5213,
  [12843] = 12466,
  [12844] = 12566,
  [12845] = 12468,
  [12846] = 12475,
  [12847] = 12466,
  [12848] = 12848,
  [12849] = 4321,
  [12850] = 5111,
  [12851] = 12467,
  [12852] = 12466,
  [12853] = 12467,
  [12854] = 12836,
  [12855] = 4353,
  [12856] = 4325,
  [12857] = 10933,
  [12858] = 12466,
  [12859] = 12466,
  [12860] = 12534,
  [12861] = 11897,
  [12862] = 12498,
  [12863] = 12468,
  [12864] = 12466,
  [12865] = 12475,
  [12866] = 12466,
  [12867] = 12467,
  [12868] = 12498,
  [12869] = 12466,
  [12870] = 12466,
  [12871] = 12466,
  [12872] = 12467,
  [12873] = 4348,
  [12874] = 12466,
  [12875] = 11850,
  [12876] = 10930,
  [12877] = 10932,
  [12878] = 12467,
  [12879] = 11510,
  [12880] = 12467,
  [12881] = 12466,
  [12882] = 12475,
  [12883] = 11927,
  [12884] = 12566,
  [12885] = 12466,
  [12886] = 11924,
  [12887] = 11725,
  [12888] = 12466,
  [12889] = 11855,
  [12890] = 11856,
  [12891] = 12467,
  [12892] = 11922,
  [12893] = 12466,
  [12894] = 12466,
  [12895] = 11920,
  [12896] = 11864,
  [12897] = 12467,
  [12898] = 12466,
  [12899] = 12466,
  [12900] = 12468,
  [12901] = 12475,
  [12902] = 12467,
  [12903] = 12466,
  [12904] = 12466,
  [12905] = 11912,
  [12906] = 12641,
  [12907] = 12475,
  [12908] = 12475,
  [12909] = 4472,
  [12910] = 4474,
  [12911] = 4472,
  [12912] = 12475,
  [12913] = 12468,
  [12914] = 12468,
  [12915] = 10992,
  [12916] = 12566,
  [12917] = 12467,
  [12918] = 4474,
  [12919] = 12467,
  [12920] = 11904,
  [12921] = 11901,
  [12922] = 12466,
  [12923] = 12475,
  [12924] = 12475,
  [12925] = 12468,
  [12926] = 12467,
  [12927] = 12467,
  [12928] = 4351,
  [12929] = 12466,
  [12930] = 12466,
  [12931] = 12534,
  [12932] = 12466,
  [12933] = 12466,
  [12934] = 11896,
  [12935] = 12815,
  [12936] = 12814,
  [12937] = 12802,
  [12938] = 11878,
  [12939] = 11881,
  [12940] = 11895,
  [12941] = 11890,
  [12942] = 12467,
  [12943] = 12634,
  [12944] = 4351,
  [12945] = 11885,
  [12946] = 12468,
  [12947] = 12705,
  [12948] = 4417,
  [12949] = 4348,
  [12950] = 5496,
  [12951] = 4387,
  [12952] = 12952,
  [12953] = 12953,
  [12954] = 12954,
  [12955] = 4409,
  [12956] = 5182,
  [12957] = 12957,
  [12958] = 5184,
  [12959] = 4395,
  [12960] = 11791,
  [12961] = 5185,
  [12962] = 12962,
  [12963] = 4366,
  [12964] = 4336,
  [12965] = 12534,
  [12966] = 4321,
  [12967] = 12534,
  [12968] = 4355,
  [12969] = 11721,
  [12970] = 12970,
  [12971] = 12971,
  [12972] = 12953,
  [12973] = 8390,
  [12974] = 12974,
  [12975] = 11723,
  [12976] = 12952,
  [12977] = 12977,
  [12978] = 4417,
  [12979] = 5284,
  [12980] = 12980,
  [12981] = 12954,
  [12982] = 11510,
  [12983] = 12974,
  [12984] = 12980,
  [12985] = 5548,
  [12986] = 5123,
  [12987] = 3985,
  [12988] = 12977,
  [12989] = 11448,
  [12990] = 12534,
  [12991] = 12991,
  [12992] = 12952,
  [12993] = 12534,
  [12994] = 12534,
  [12995] = 3987,
  [12996] = 12957,
  [12997] = 11720,
  [12998] = 12953,
  [12999] = 11719,
  [13000] = 12971,
  [13001] = 5540,
  [13002] = 12954,
  [13003] = 5539,
  [13004] = 5182,
  [13005] = 12954,
  [13006] = 12962,
  [13007] = 5184,
  [13008] = 5185,
  [13009] = 11717,
  [13010] = 11715,
  [13011] = 13011,
  [13012] = 12971,
  [13013] = 11714,
  [13014] = 11420,
  [13015] = 12962,
  [13016] = 12977,
  [13017] = 4642,
  [13018] = 12954,
  [13019] = 12980,
  [13020] = 12974,
  [13021] = 13021,
  [13022] = 13022,
  [13023] = 4647,
  [13024] = 12952,
  [13025] = 12952,
  [13026] = 5295,
  [13027] = 12534,
  [13028] = 12534,
  [13029] = 12954,
  [13030] = 12953,
  [13031] = 12954,
  [13032] = 4656,
  [13033] = 13033,
  [13034] = 4858,
  [13035] = 5139,
  [13036] = 12962,
  [13037] = 12957,
  [13038] = 12534,
  [13039] = 13039,
  [13040] = 4642,
  [13041] = 12954,
  [13042] = 12970,
  [13043] = 4647,
  [13044] = 4656,
  [13045] = 11850,
  [13046] = 13011,
  [13047] = 13047,
  [13048] = 11855,
  [13049] = 12534,
  [13050] = 12534,
  [13051] = 11725,
  [13052] = 4925,
  [13053] = 13053,
  [13054] = 13054,
  [13055] = 12971,
  [13056] = 12954,
  [13057] = 11856,
  [13058] = 11864,
  [13059] = 8491,
  [13060] = 12534,
  [13061] = 4325,
  [13062] = 5213,
  [13063] = 4417,
  [13064] = 13064,
  [13065] = 11470,
  [13066] = 11714,
  [13067] = 12534,
  [13068] = 13068,
  [13069] = 4417,
  [13070] = 12952,
  [13071] = 10992,
  [13072] = 12534,
  [13073] = 12954,
  [13074] = 13074,
  [13075] = 11878,
  [13076] = 11714,
  [13077] = 4372,
  [13078] = 13078,
  [13079] = 4409,
  [13080] = 13080,
  [13081] = 4402,
  [13082] = 4381,
  [13083] = 4387,
  [13084] = 4529,
  [13085] = 4362,
  [13086] = 5228,
  [13087] = 4318,
  [13088] = 11715,
  [13089] = 4386,
  [13090] = 5341,
  [13091] = 8714,
  [13092] = 4318,
  [13093] = 8287,
  [13094] = 11881,
  [13095] = 11885,
  [13096] = 4472,
  [13097] = 11889,
  [13098] = 11719,
  [13099] = 13099,
  [13100] = 13100,
  [13101] = 4321,
  [13102] = 11890,
  [13103] = 11924,
  [13104] = 11922,
  [13105] = 11920,
  [13106] = 12974,
  [13107] = 4351,
  [13108] = 12534,
  [13109] = 4474,
  [13110] = 11895,
  [13111] = 12954,
  [13112] = 12952,
  [13113] = 11720,
  [13114] = 11723,
  [13115] = 12952,
  [13116] = 11912,
  [13117] = 5396,
  [13118] = 11448,
  [13119] = 12952,
  [13120] = 11927,
  [13121] = 4439,
  [13122] = 12977,
  [13123] = 11896,
  [13124] = 11904,
  [13125] = 11901,
  [13126] = 11897,
  [13127] = 11896,
  [13128] = 11897,
  [13129] = 11895,
  [13130] = 12980,
  [13131] = 11901,
  [13132] = 11890,
  [13133] = 11904,
  [13134] = 13134,
  [13135] = 5496,
  [13136] = 11889,
  [13137] = 12991,
  [13138] = 11885,
  [13139] = 11881,
  [13140] = 11878,
  [13141] = 12977,
  [13142] = 12980,
  [13143] = 8482,
  [13144] = 13144,
  [13145] = 12954,
  [13146] = 11719,
  [13147] = 4395,
  [13148] = 4366,
  [13149] = 11864,
  [13150] = 4417,
  [13151] = 4529,
  [13152] = 11856,
  [13153] = 12952,
  [13154] = 8499,
  [13155] = 8522,
  [13156] = 11855,
  [13157] = 12534,
  [13158] = 8584,
  [13159] = 12954,
  [13160] = 4366,
  [13161] = 8931,
  [13162] = 4395,
  [13163] = 4409,
  [13164] = 11850,
  [13165] = 12952,
  [13166] = 12952,
  [13167] = 4538,
  [13168] = 5284,
  [13169] = 5295,
  [13170] = 10932,
  [13171] = 8865,
  [13172] = 11723,
  [13173] = 10930,
  [13174] = 8651,
  [13175] = 8584,
  [13176] = 12952,
  [13177] = 8499,
  [13178] = 8491,
  [13179] = 8482,
  [13180] = 5341,
  [13181] = 11717,
  [13182] = 12534,
  [13183] = 11720,
  [13184] = 12971,
  [13185] = 5396,
  [13186] = 8931,
  [13187] = 11912,
  [13188] = 13188,
  [13189] = 11791,
  [13190] = 4591,
  [13191] = 4318,
  [13192] = 13192,
  [13193] = 12952,
  [13194] = 12534,
  [13195] = 12954,
  [13196] = 12962,
  [13197] = 12952,
  [13198] = 12952,
  [13199] = 12974,
  [13200] = 4474,
  [13201] = 13021,
  [13202] = 12991,
  [13203] = 12952,
  [13204] = 13204,
  [13205] = 8522,
  [13206] = 4472,
  [13207] = 13011,
  [13208] = 12954,
  [13209] = 12952,
  [13210] = 11883,
  [13211] = 10933,
  [13212] = 11882,
  [13213] = 12952,
  [13214] = 11920,
  [13215] = 12954,
  [13216] = 11922,
  [13217] = 12952,
  [13218] = 12534,
  [13219] = 12954,
  [13220] = 12952,
  [13221] = 11924,
  [13222] = 11715,
  [13223] = 12952,
  [13224] = 4355,
  [13225] = 11717,
  [13226] = 11927,
  [13227] = 12957,
  [13228] = 4417,
  [13229] = 12952,
  [13230] = 4529,
  [13231] = 12953,
  [13232] = 4417,
  [13233] = 12952,
  [13234] = 12957,
  [13235] = 11721,
  [13236] = 12952,
  [13237] = 4474,
  [13238] = 4325,
  [13239] = 4472,
  [13240] = 12954,
  [13241] = 12952,
  [13242] = 12952,
  [13243] = 13134,
  [13244] = 12507,
  [13245] = 8390,
  [13246] = 4351,
  [13247] = 5185,
  [13248] = 5184,
  [13249] = 4372,
  [13250] = 5284,
  [13251] = 12952,
  [13252] = 4386,
  [13253] = 5182,
  [13254] = 4402,
  [13255] = 4381,
  [13256] = 12952,
  [13257] = 4387,
  [13258] = 4362,
  [13259] = 12954,
  [13260] = 12952,
  [13261] = 13021,
  [13262] = 5295,
  [13263] = 4472,
  [13264] = 3987,
  [13265] = 12952,
  [13266] = 3985,
  [13267] = 8865,
  [13268] = 4362,
  [13269] = 5213,
  [13270] = 4387,
  [13271] = 12952,
  [13272] = 3987,
  [13273] = 12531,
  [13274] = 12954,
  [13275] = 3985,
  [13276] = 4381,
  [13277] = 5341,
  [13278] = 12952,
  [13279] = 4439,
  [13280] = 12485,
  [13281] = 12484,
  [13282] = 3985,
  [13283] = 12952,
  [13284] = 12561,
  [13285] = 12562,
  [13286] = 12565,
  [13287] = 4538,
  [13288] = 4325,
  [13289] = 11510,
  [13290] = 4402,
  [13291] = 12545,
  [13292] = 12952,
  [13293] = 4474,
  [13294] = 3987,
  [13295] = 8287,
  [13296] = 12952,
  [13297] = 5396,
  [13298] = 4366,
  [13299] = 8714,
  [13300] = 8651,
  [13301] = 4395,
  [13302] = 4366,
  [13303] = 4439,
  [13304] = 4409,
  [13305] = 12952,
  [13306] = 4318,
  [13307] = 4372,
  [13308] = 13011,
  [13309] = 4386,
  [13310] = 4409,
  [13311] = 12952,
  [13312] = 4439,
  [13313] = 4386,
  [13314] = 4395,
  [13315] = 4395,
  [13316] = 4366,
  [13317] = 12952,
  [13318] = 4409,
  [13319] = 4321,
  [13320] = 12954,
  [13321] = 4351,
  [13322] = 5496,
  [13323] = 5228,
  [13324] = 4381,
  [13325] = 4387,
  [13326] = 12952,
  [13327] = 4362,
  [13328] = 4372,
  [13329] = 12952,
  [13330] = 12954,
  [13331] = 12952,
  [13332] = 12642,
  [13333] = 4591,
  [13334] = 12952,
  [13335] = 4474,
  [13336] = 4318,
  [13337] = 4472,
  [13338] = 4402,
  [13339] = 13339,
  [13340] = 8714,
  [13341] = 8287,
  [13342] = 13342,
  [13343] = 12952,
  [13344] = 4318,
  [13345] = 12954,
  [13346] = 5213,
  [13347] = 13011,
  [13348] = 12952,
  [13349] = 12952,
  [13350] = 5213,
  [13351] = 4325,
  [13352] = 12952,
  [13353] = 13353,
  [13354] = 13354,
  [13355] = 5908,
  [13356] = 4325,
  [13357] = 12952,
  [13358] = 12952,
  [13359] = 12952,
  [13360] = 5496,
  [13361] = 12954,
  [13362] = 4325,
  [13363] = 5861,
  [13364] = 4362,
  [13365] = 12952,
  [13366] = 12952,
  [13367] = 5396,
  [13368] = 4387,
  [13369] = 5341,
  [13370] = 5111,
  [13371] = 5295,
  [13372] = 12665,
  [13373] = 12666,
  [13374] = 5284,
  [13375] = 12670,
  [13376] = 12675,
  [13377] = 4372,
  [13378] = 4381,
  [13379] = 4386,
  [13380] = 8651,
  [13381] = 4402,
  [13382] = 8482,
  [13383] = 12952,
  [13384] = 12952,
  [13385] = 4439,
  [13386] = 4402,
  [13387] = 4381,
  [13388] = 8491,
  [13389] = 12952,
  [13390] = 8522,
  [13391] = 4529,
  [13392] = 4386,
  [13393] = 12954,
  [13394] = 4439,
  [13395] = 12752,
  [13396] = 12754,
  [13397] = 8931,
  [13398] = 8390,
  [13399] = 4362,
  [13400] = 8584,
  [13401] = 8865,
  [13402] = 4372,
  [13403] = 11725,
  [13404] = 12952,
  [13405] = 8499,
  [13406] = 13406,
  [13407] = 13407,
  [13408] = 11864,
  [13409] = 11448,
  [13410] = 8714,
  [13411] = 11720,
  [13412] = 5341,
  [13413] = 13047,
  [13414] = 11856,
  [13415] = 4417,
  [13416] = 5396,
  [13417] = 5295,
  [13418] = 11855,
  [13419] = 8287,
  [13420] = 11901,
  [13421] = 11725,
  [13422] = 11850,
  [13423] = 8651,
  [13424] = 11878,
  [13425] = 11881,
  [13426] = 4325,
  [13427] = 11885,
  [13428] = 11889,
  [13429] = 11719,
  [13430] = 11890,
  [13431] = 5496,
  [13432] = 4351,
  [13433] = 11723,
  [13434] = 11895,
  [13435] = 5861,
  [13436] = 13436,
  [13437] = 11896,
  [13438] = 13438,
  [13439] = 11897,
  [13440] = 5908,
  [13441] = 11904,
  [13442] = 12970,
  [13443] = 5185,
  [13444] = 11717,
  [13445] = 11715,
  [13446] = 4372,
  [13447] = 11721,
  [13448] = 4474,
  [13449] = 4386,
  [13450] = 5182,
  [13451] = 11912,
  [13452] = 4325,
  [13453] = 5184,
  [13454] = 12534,
  [13455] = 4656,
  [13456] = 13456,
  [13457] = 4439,
  [13458] = 11714,
  [13459] = 12534,
  [13460] = 11920,
  [13461] = 11922,
  [13462] = 4472,
  [13463] = 11924,
  [13464] = 13464,
  [13465] = 11927,
  [13466] = 11714,
  [13467] = 11883,
  [13468] = 11791,
  [13469] = 11882,
  [13470] = 12970,
  [13471] = 11510,
  [13472] = 11714,
  [13473] = 5284,
  [13474] = 5341,
  [13475] = 4351,
  [13476] = 12970,
  [13477] = 8522,
  [13478] = 5228,
  [13479] = 11715,
  [13480] = 11717,
  [13481] = 4372,
  [13482] = 4474,
  [13483] = 8482,
  [13484] = 11448,
  [13485] = 8491,
  [13486] = 11882,
  [13487] = 11883,
  [13488] = 13488,
  [13489] = 12970,
  [13490] = 8499,
  [13491] = 4386,
  [13492] = 8522,
  [13493] = 11510,
  [13494] = 4472,
  [13495] = 4529,
  [13496] = 8584,
  [13497] = 12534,
  [13498] = 4439,
  [13499] = 12970,
  [13500] = 5213,
  [13501] = 4402,
  [13502] = 13502,
  [13503] = 8499,
  [13504] = 13504,
  [13505] = 12970,
  [13506] = 8714,
  [13507] = 8287,
  [13508] = 4381,
  [13509] = 8865,
  [13510] = 4366,
  [13511] = 4395,
  [13512] = 8491,
  [13513] = 5548,
  [13514] = 13407,
  [13515] = 3985,
  [13516] = 12970,
  [13517] = 13517,
  [13518] = 8482,
  [13519] = 13519,
  [13520] = 12534,
  [13521] = 3987,
  [13522] = 12534,
  [13523] = 8931,
  [13524] = 5496,
  [13525] = 11719,
  [13526] = 5540,
  [13527] = 4409,
  [13528] = 4387,
  [13529] = 5539,
  [13530] = 4402,
  [13531] = 8714,
  [13532] = 5295,
  [13533] = 5396,
  [13534] = 5185,
  [13535] = 4381,
  [13536] = 5184,
  [13537] = 11720,
  [13538] = 11715,
  [13539] = 11717,
  [13540] = 5182,
  [13541] = 12534,
  [13542] = 11720,
  [13543] = 8651,
  [13544] = 8390,
  [13545] = 4362,
  [13546] = 4387,
  [13547] = 4353,
  [13548] = 4318,
  [13549] = 5496,
  [13550] = 13550,
  [13551] = 13551,
  [13552] = 11960,
  [13553] = 5213,
  [13554] = 11448,
  [13555] = 4529,
  [13556] = 4362,
  [13557] = 13557,
  [13558] = 13558,
  [13559] = 13559,
  [13560] = 13560,
  [13561] = 10992,
  [13562] = 8287,
  [13563] = 8584,
  [13564] = 13564,
  [13565] = 8931,
  [13566] = 8651,
  [13567] = 13567,
  [13568] = 5213,
  [13569] = 8390,
  [13570] = 5284,
  [13571] = 5123,
  [13572] = 11719,
  [13573] = 5295,
  [13574] = 4362,
  [13575] = 8390,
  [13576] = 4325,
  [13577] = 12534,
  [13578] = 5284,
  [13579] = 13354,
  [13580] = 13353,
  [13581] = 12534,
  [13582] = 5396,
  [13583] = 2412,
  [13584] = 8482,
  [13585] = 8865,
  [13586] = 12534,
  [13587] = 8491,
  [13588] = 11720,
  [13589] = 4366,
  [13590] = 5341,
  [13591] = 6464,
  [13592] = 5139,
  [13593] = 13407,
  [13594] = 13517,
  [13595] = 12534,
  [13596] = 8499,
  [13597] = 5295,
  [13598] = 8522,
  [13599] = 11723,
  [13600] = 5185,
  [13601] = 4387,
  [13602] = 4395,
  [13603] = 5184,
  [13604] = 5284,
  [13605] = 4409,
  [13606] = 13192,
  [13607] = 5182,
  [13608] = 8865,
  [13609] = 4529,
  [13610] = 10932,
  [13611] = 11791,
  [13612] = 11927,
  [13613] = 11448,
  [13614] = 8931,
  [13615] = 10930,
  [13616] = 5496,
  [13617] = 11510,
  [13618] = 8931,
  [13619] = 4647,
  [13620] = 11719,
  [13621] = 4321,
  [13622] = 5396,
  [13623] = 8865,
  [13624] = 11924,
  [13625] = 13022,
  [13626] = 8390,
  [13627] = 12970,
  [13628] = 4318,
  [13629] = 5341,
  [13630] = 13630,
  [13631] = 11922,
  [13632] = 11920,
  [13633] = 10933,
  [13634] = 8584,
  [13635] = 11721,
  [13636] = 5341,
  [13637] = 11723,
  [13638] = 5908,
  [13639] = 5295,
  [13640] = 13039,
  [13641] = 8584,
  [13642] = 4372,
  [13643] = 8651,
  [13644] = 5548,
  [13645] = 11725,
  [13646] = 4642,
  [13647] = 8522,
  [13648] = 13342,
  [13649] = 13339,
  [13650] = 12534,
  [13651] = 11850,
  [13652] = 12970,
  [13653] = 4386,
  [13654] = 11855,
  [13655] = 11856,
  [13656] = 4409,
  [13657] = 5540,
  [13658] = 5284,
  [13659] = 4381,
  [13660] = 4417,
  [13661] = 8499,
  [13662] = 8491,
  [13663] = 5539,
  [13664] = 8287,
  [13665] = 5182,
  [13666] = 11889,
  [13667] = 11885,
  [13668] = 11912,
  [13669] = 11881,
  [13670] = 11878,
  [13671] = 4366,
  [13672] = 4395,
  [13673] = 4402,
  [13674] = 8714,
  [13675] = 5396,
  [13676] = 11714,
  [13677] = 5396,
  [13678] = 4318,
  [13679] = 11510,
  [13680] = 5496,
  [13681] = 5496,
  [13682] = 11904,
  [13683] = 8390,
  [13684] = 4529,
  [13685] = 11901,
  [13686] = 11723,
  [13687] = 5184,
  [13688] = 11864,
  [13689] = 6547,
  [13690] = 5861,
  [13691] = 8390,
  [13692] = 11897,
  [13693] = 5295,
  [13694] = 11717,
  [13695] = 8482,
  [13696] = 11896,
  [13697] = 4417,
  [13698] = 13698,
  [13699] = 5185,
  [13700] = 13134,
  [13701] = 4439,
  [13702] = 11895,
  [13703] = 12970,
  [13704] = 13074,
  [13705] = 12534,
  [13706] = 13517,
  [13707] = 11510,
  [13708] = 13068,
  [13709] = 13099,
  [13710] = 11715,
  [13711] = 13100,
  [13712] = 11725,
  [13713] = 13407,
  [13714] = 13517,
  [13715] = 11890,
  [13716] = 5284,
  [13717] = 5341,
  [13718] = 11725,
  [13719] = 4642,
  [13720] = 11721,
  [13721] = 4529,
  [13722] = 11901,
  [13723] = 4656,
  [13724] = 11904,
  [13725] = 11864,
  [13726] = 11881,
  [13727] = 8584,
  [13728] = 13407,
  [13729] = 11720,
  [13730] = 12970,
  [13731] = 8522,
  [13732] = 5295,
  [13733] = 11912,
  [13734] = 11889,
  [13735] = 4409,
  [13736] = 8865,
  [13737] = 11890,
  [13738] = 11920,
  [13739] = 5284,
  [13740] = 5284,
  [13741] = 8491,
  [13742] = 4529,
  [13743] = 13407,
  [13744] = 4925,
  [13745] = 11922,
  [13746] = 5908,
  [13747] = 8482,
  [13748] = 13748,
  [13749] = 11896,
  [13750] = 11897,
  [13751] = 12534,
  [13752] = 11448,
  [13753] = 11924,
  [13754] = 12534,
  [13755] = 11927,
  [13756] = 11878,
  [13757] = 5184,
  [13758] = 5184,
  [13759] = 11791,
  [13760] = 11721,
  [13761] = 11721,
  [13762] = 11901,
  [13763] = 5295,
  [13764] = 11856,
  [13765] = 13517,
  [13766] = 12534,
  [13767] = 12970,
  [13768] = 5182,
  [13769] = 11904,
  [13770] = 11927,
  [13771] = 11714,
  [13772] = 11715,
  [13773] = 11717,
  [13774] = 11791,
  [13775] = 4529,
  [13776] = 11881,
  [13777] = 12970,
  [13778] = 13778,
  [13779] = 13779,
  [13780] = 13517,
  [13781] = 13517,
  [13782] = 13517,
  [13783] = 11855,
  [13784] = 12970,
  [13785] = 13407,
  [13786] = 13407,
  [13787] = 13517,
  [13788] = 13788,
  [13789] = 13789,
  [13790] = 11791,
  [13791] = 13407,
  [13792] = 13407,
  [13793] = 11850,
  [13794] = 8287,
  [13795] = 11882,
  [13796] = 4925,
  [13797] = 11850,
  [13798] = 8482,
  [13799] = 8491,
  [13800] = 4402,
  [13801] = 4366,
  [13802] = 4325,
  [13803] = 12970,
  [13804] = 11719,
  [13805] = 4858,
  [13806] = 4381,
  [13807] = 8499,
  [13808] = 13406,
  [13809] = 13488,
  [13810] = 11897,
  [13811] = 11927,
  [13812] = 12970,
  [13813] = 8522,
  [13814] = 12970,
  [13815] = 4858,
  [13816] = 11883,
  [13817] = 11720,
  [13818] = 11791,
  [13819] = 12534,
  [13820] = 13698,
  [13821] = 8584,
  [13822] = 11885,
  [13823] = 13564,
  [13824] = 12534,
  [13825] = 8714,
  [13826] = 13407,
  [13827] = 13436,
  [13828] = 11720,
  [13829] = 11924,
  [13830] = 12970,
  [13831] = 11719,
  [13832] = 11924,
  [13833] = 10926,
  [13834] = 13517,
  [13835] = 11895,
  [13836] = 3987,
  [13837] = 11883,
  [13838] = 13517,
  [13839] = 11882,
  [13840] = 8931,
  [13841] = 13778,
  [13842] = 13559,
  [13843] = 11890,
  [13844] = 11922,
  [13845] = 11889,
  [13846] = 11878,
  [13847] = 11922,
  [13848] = 11920,
  [13849] = 5341,
  [13850] = 11723,
  [13851] = 13557,
  [13852] = 11885,
  [13853] = 8499,
  [13854] = 12970,
  [13855] = 8931,
  [13856] = 8390,
  [13857] = 5396,
  [13858] = 11920,
  [13859] = 11912,
  [13860] = 8482,
  [13861] = 11883,
  [13862] = 8287,
  [13863] = 8714,
  [13864] = 5548,
  [13865] = 5185,
  [13866] = 4647,
  [13867] = 11882,
  [13868] = 4395,
  [13869] = 8714,
  [13870] = 4409,
  [13871] = 11856,
  [13872] = 11912,
  [13873] = 4474,
  [13874] = 8287,
  [13875] = 5861,
  [13876] = 4529,
  [13877] = 4386,
  [13878] = 11889,
  [13879] = 13407,
  [13880] = 11881,
  [13881] = 11890,
  [13882] = 11904,
  [13883] = 4417,
  [13884] = 11901,
  [13885] = 11510,
  [13886] = 13886,
  [13887] = 11901,
  [13888] = 13567,
  [13889] = 11121,
  [13890] = 5496,
  [13891] = 11721,
  [13892] = 8651,
  [13893] = 4318,
  [13894] = 11723,
  [13895] = 4318,
  [13896] = 11878,
  [13897] = 6547,
  [13898] = 4656,
  [13899] = 5185,
  [13900] = 13900,
  [13901] = 4395,
  [13902] = 4387,
  [13903] = 12970,
  [13904] = 4366,
  [13905] = 5182,
  [13906] = 11510,
  [13907] = 4417,
  [13908] = 3985,
  [13909] = 5295,
  [13910] = 5341,
  [13911] = 5185,
  [13912] = 8390,
  [13913] = 11895,
  [13914] = 13630,
  [13915] = 8522,
  [13916] = 11723,
  [13917] = 11896,
  [13918] = 13407,
  [13919] = 4656,
  [13920] = 11864,
  [13921] = 13921,
  [13922] = 11895,
  [13923] = 11920,
  [13924] = 11864,
  [13925] = 11895,
  [13926] = 11922,
  [13927] = 11896,
  [13928] = 11725,
  [13929] = 4372,
  [13930] = 5540,
  [13931] = 13551,
  [13932] = 5539,
  [13933] = 11717,
  [13934] = 11715,
  [13935] = 5284,
  [13936] = 5496,
  [13937] = 8491,
  [13938] = 4362,
  [13939] = 12970,
  [13940] = 11855,
  [13941] = 5284,
  [13942] = 12970,
  [13943] = 4472,
  [13944] = 11912,
  [13945] = 4372,
  [13946] = 5184,
  [13947] = 11725,
  [13948] = 13560,
  [13949] = 11850,
  [13950] = 4351,
  [13951] = 12534,
  [13952] = 11896,
  [13953] = 11856,
  [13954] = 11714,
  [13955] = 4647,
  [13956] = 5182,
  [13957] = 10940,
  [13958] = 4439,
  [13959] = 13558,
  [13960] = 11856,
  [13961] = 11855,
  [13962] = 11850,
  [13963] = 10991,
  [13964] = 13964,
  [13965] = 11897,
  [13966] = 12534,
  [13967] = 11719,
  [13968] = 10941,
  [13969] = 4402,
  [13970] = 12534,
  [13971] = 12534,
  [13972] = 4529,
  [13973] = 13517,
  [13974] = 11890,
  [13975] = 11723,
  [13976] = 13407,
  [13977] = 13517,
  [13978] = 5295,
  [13979] = 11510,
  [13980] = 11924,
  [13981] = 11889,
  [13982] = 4381,
  [13983] = 5341,
  [13984] = 11714,
  [13985] = 11122,
  [13986] = 8651,
  [13987] = 5396,
  [13988] = 11885,
  [13989] = 13502,
  [13990] = 11881,
  [13991] = 13504,
  [13992] = 11878,
  [13993] = 5496,
  [13994] = 8390,
  [13995] = 11510,
  [13996] = 10915,
  [13997] = 13550,
  [13998] = 13407,
  [13999] = 4642,
  [14000] = 6464,
  [14001] = 13517,
  [14002] = 12970,
  [14003] = 13438,
  [14004] = 8499,
  [14005] = 12970,
  [14006] = 4387,
  [14007] = 4647,
  [14008] = 12970,
  [14009] = 11897,
  [14010] = 12534,
  [14011] = 11714,
  [14012] = 11927,
  [14013] = 11885,
  [14014] = 8931,
  [14015] = 4362,
  [14016] = 8865,
  [14017] = 5213,
  [14018] = 8651,
  [14019] = 12970,
  [14020] = 5213,
  [14021] = 11715,
  [14022] = 8390,
  [14023] = 11720,
  [14024] = 12534,
  [14025] = 4355,
  [14026] = 11717,
  [14027] = 11448,
  [14028] = 8865,
  [14029] = 12534,
  [14030] = 11855,
  [14031] = 12534,
  [14032] = 5396,
  [14033] = 11719,
  [14034] = 10960,
  [14035] = 10954,
  [14036] = 4321,
  [14037] = 4538,
  [14038] = 5341,
  [14039] = 14039,
  [14040] = 11448,
  [14041] = 4642,
  [14042] = 11864,
  [14043] = 12534,
  [14044] = 8584,
  [14045] = 4591,
  [14046] = 13407,
  [14047] = 11904,
  [14048] = 13517,
  [14049] = 11717,
  [14050] = 11715,
  [14051] = 5496,
  [14052] = 13517,
  [14053] = 5396,
  [14054] = 4439,
  [14055] = 11896,
  [14056] = 13517,
  [14057] = 4381,
  [14058] = 4325,
  [14059] = 11723,
  [14060] = 14060,
  [14061] = 13517,
  [14062] = 4439,
  [14063] = 12970,
  [14064] = 4409,
  [14065] = 13407,
  [14066] = 11895,
  [14067] = 13517,
  [14068] = 12282,
  [14069] = 11721,
  [14070] = 11725,
  [14071] = 4538,
  [14072] = 14072,
  [14073] = 11850,
  [14074] = 12970,
  [14075] = 12970,
  [14076] = 4402,
  [14077] = 14077,
  [14078] = 14078,
  [14079] = 12670,
  [14080] = 10991,
  [14081] = 11864,
  [14082] = 13407,
  [14083] = 11856,
  [14084] = 11864,
  [14085] = 13407,
  [14086] = 14086,
  [14087] = 11855,
  [14088] = 13407,
  [14089] = 11912,
  [14090] = 10941,
  [14091] = 11878,
  [14092] = 14092,
  [14093] = 13407,
  [14094] = 11881,
  [14095] = 11714,
  [14096] = 14096,
  [14097] = 11885,
  [14098] = 13778,
  [14099] = 11889,
  [14100] = 14100,
  [14101] = 13517,
  [14102] = 11890,
  [14103] = 5139,
  [14104] = 10940,
  [14105] = 11895,
  [14106] = 14100,
  [14107] = 11897,
  [14108] = 11901,
  [14109] = 11904,
  [14110] = 11791,
  [14111] = 14111,
  [14112] = 11904,
  [14113] = 12642,
  [14114] = 11721,
  [14115] = 12970,
  [14116] = 11927,
  [14117] = 4362,
  [14118] = 14118,
  [14119] = 4417,
  [14120] = 13517,
  [14121] = 4591,
  [14122] = 13900,
  [14123] = 14039,
  [14124] = 10954,
  [14125] = 11896,
  [14126] = 11715,
  [14127] = 12970,
  [14128] = 11717,
  [14129] = 13517,
  [14130] = 10960,
  [14131] = 12561,
  [14132] = 14132,
  [14133] = 12970,
  [14134] = 14134,
  [14135] = 11924,
  [14136] = 14136,
  [14137] = 11791,
  [14138] = 4472,
  [14139] = 11714,
  [14140] = 11882,
  [14141] = 11922,
  [14142] = 12562,
  [14143] = 11920,
  [14144] = 14144,
  [14145] = 12565,
  [14146] = 13886,
  [14147] = 4386,
  [14148] = 13407,
  [14149] = 11920,
  [14150] = 14150,
  [14151] = 11850,
  [14152] = 14152,
  [14153] = 11725,
  [14154] = 11924,
  [14155] = 4395,
  [14156] = 11922,
  [14157] = 11715,
  [14158] = 13517,
  [14159] = 11927,
  [14160] = 14078,
  [14161] = 11717,
  [14162] = 4529,
  [14163] = 12282,
  [14164] = 13407,
  [14165] = 13407,
  [14166] = 11723,
  [14167] = 12970,
  [14168] = 11912,
  [14169] = 13407,
  [14170] = 12970,
  [14171] = 14077,
  [14172] = 11723,
  [14173] = 11897,
  [14174] = 11715,
  [14175] = 11717,
  [14176] = 11901,
  [14177] = 11878,
  [14178] = 12507,
  [14179] = 11901,
  [14180] = 11719,
  [14181] = 13964,
  [14182] = 11889,
  [14183] = 11791,
  [14184] = 12752,
  [14185] = 11883,
  [14186] = 13407,
  [14187] = 11897,
  [14188] = 11890,
  [14189] = 12754,
  [14190] = 14190,
  [14191] = 11720,
  [14192] = 4372,
  [14193] = 11896,
  [14194] = 11448,
  [14195] = 10926,
  [14196] = 13517,
  [14197] = 14197,
  [14198] = 11719,
  [14199] = 11122,
  [14200] = 11912,
  [14201] = 13407,
  [14202] = 11720,
  [14203] = 11895,
  [14204] = 11720,
  [14205] = 11121,
  [14206] = 13517,
  [14207] = 11855,
  [14208] = 11920,
  [14209] = 5123,
  [14210] = 13788,
  [14211] = 11890,
  [14212] = 5139,
  [14213] = 11881,
  [14214] = 11889,
  [14215] = 14215,
  [14216] = 11885,
  [14217] = 13789,
  [14218] = 11922,
  [14219] = 11720,
  [14220] = 11717,
  [14221] = 11881,
  [14222] = 13517,
  [14223] = 5123,
  [14224] = 11448,
  [14225] = 12675,
  [14226] = 12666,
  [14227] = 12665,
  [14228] = 4318,
  [14229] = 11878,
  [14230] = 11510,
  [14231] = 13517,
  [14232] = 12282,
  [14233] = 11715,
  [14234] = 12970,
  [14235] = 13517,
  [14236] = 11885,
  [14237] = 11904,
  [14238] = 11901,
  [14239] = 11850,
  [14240] = 12970,
  [14241] = 13188,
  [14242] = 4366,
  [14243] = 13407,
  [14244] = 13517,
  [14245] = 12282,
  [14246] = 13407,
  [14247] = 13517,
  [14248] = 12485,
  [14249] = 12484,
  [14250] = 11855,
  [14251] = 14251,
  [14252] = 11721,
  [14253] = 4474,
  [14254] = 11856,
  [14255] = 11719,
  [14256] = 11714,
  [14257] = 12970,
  [14258] = 13080,
  [14259] = 11719,
  [14260] = 12282,
  [14261] = 10915,
  [14262] = 11882,
  [14263] = 11883,
  [14264] = 14264,
  [14265] = 11904,
  [14266] = 11864,
  [14267] = 11927,
  [14268] = 11714,
  [14269] = 13407,
  [14270] = 4387,
  [14271] = 11723,
  [14272] = 12970,
  [14273] = 11924,
  [14274] = 11856,
  [14275] = 14144,
  [14276] = 11889,
  [14277] = 14277,
  [14278] = 14278,
  [14279] = 14264,
  [14280] = 14280,
  [14281] = 14281,
  [14282] = 11510,
  [14283] = 14283,
  [14284] = 13407,
  [14285] = 13517,
  [14286] = 14286,
  [14287] = 12534,
  [14288] = 11924,
  [14289] = 11715,
  [14290] = 11717,
  [14291] = 14291,
  [14292] = 14264,
  [14293] = 13517,
  [14294] = 13407,
  [14295] = 12970,
  [14296] = 14296,
  [14297] = 11714,
  [14298] = 14286,
  [14299] = 11927,
  [14300] = 13354,
  [14301] = 11723,
  [14302] = 13517,
  [14303] = 13407,
  [14304] = 14304,
  [14305] = 13517,
  [14306] = 4925,
  [14307] = 12970,
  [14308] = 5228,
  [14309] = 13407,
  [14310] = 11719,
  [14311] = 11885,
  [14312] = 11881,
  [14313] = 11878,
  [14314] = 11920,
  [14315] = 4858,
  [14316] = 13407,
  [14317] = 13407,
  [14318] = 11725,
  [14319] = 11721,
  [14320] = 11720,
  [14321] = 13517,
  [14322] = 12970,
  [14323] = 13517,
  [14324] = 14324,
  [14325] = 11720,
  [14326] = 13407,
  [14327] = 14304,
  [14328] = 11719,
  [14329] = 13517,
  [14330] = 13517,
  [14331] = 14331,
  [14332] = 11922,
  [14333] = 11904,
  [14334] = 13517,
  [14335] = 14335,
  [14336] = 12534,
  [14337] = 4656,
  [14338] = 13342,
  [14339] = 13407,
  [14340] = 13407,
  [14341] = 13517,
  [14342] = 12534,
  [14343] = 14343,
  [14344] = 14335,
  [14345] = 14278,
  [14346] = 13407,
  [14347] = 11791,
  [14348] = 11895,
  [14349] = 11717,
  [14350] = 11715,
  [14351] = 14100,
  [14352] = 4647,
  [14353] = 5228,
  [14354] = 14100,
  [14355] = 14355,
  [14356] = 11890,
  [14357] = 14152,
  [14358] = 13517,
  [14359] = 4642,
  [14360] = 14086,
  [14361] = 14361,
  [14362] = 3985,
  [14363] = 14363,
  [14364] = 14364,
  [14365] = 5228,
  [14366] = 12534,
  [14367] = 14367,
  [14368] = 14368,
  [14369] = 11896,
  [14370] = 14370,
  [14371] = 12534,
  [14372] = 12970,
  [14373] = 11912,
  [14374] = 11912,
  [14375] = 11897,
  [14376] = 13517,
  [14377] = 3987,
  [14378] = 13517,
  [14379] = 13517,
  [14380] = 11901,
  [14381] = 4529,
  [14382] = 11721,
  [14383] = 3985,
  [14384] = 12970,
  [14385] = 11924,
  [14386] = 11850,
  [14387] = 11897,
  [14388] = 12534,
  [14389] = 11864,
  [14390] = 14280,
  [14391] = 11927,
  [14392] = 14190,
  [14393] = 11855,
  [14394] = 14343,
  [14395] = 11922,
  [14396] = 13342,
  [14397] = 11856,
  [14398] = 14296,
  [14399] = 11864,
  [14400] = 14400,
  [14401] = 12970,
  [14402] = 12970,
  [14403] = 12970,
  [14404] = 11920,
  [14405] = 13354,
  [14406] = 11791,
  [14407] = 14283,
  [14408] = 11856,
  [14409] = 14281,
  [14410] = 11855,
  [14411] = 14411,
  [14412] = 14251,
  [14413] = 11723,
  [14414] = 12970,
  [14415] = 11878,
  [14416] = 11714,
  [14417] = 11850,
  [14418] = 13407,
  [14419] = 11881,
  [14420] = 11885,
  [14421] = 13407,
  [14422] = 12970,
  [14423] = 3987,
  [14424] = 11889,
  [14425] = 13407,
  [14426] = 14426,
  [14427] = 14355,
  [14428] = 14331,
  [14429] = 11890,
  [14430] = 11895,
  [14431] = 13407,
  [14432] = 11896,
  [14433] = 5396,
  [14434] = 5396,
  [14435] = 13698,
  [14436] = 14436,
  [14437] = 14291,
  [14438] = 4642,
  [14439] = 13517,
  [14440] = 13407,
  [14441] = 14436,
  [14442] = 5861,
  [14443] = 5908,
  [14444] = 13748,
  [14445] = 14436,
  [14446] = 14436,
  [14447] = 13339,
  [14448] = 14370,
  [14449] = 14368,
  [14450] = 5295,
  [14451] = 5139,
  [14452] = 13698,
  [14453] = 14436,
  [14454] = 10930,
  [14455] = 10932,
  [14456] = 14436,
  [14457] = 13517,
  [14458] = 10992,
  [14459] = 13558,
  [14460] = 14436,
  [14461] = 13353,
  [14462] = 14462,
  [14463] = 14355,
  [14464] = 14464,
  [14465] = 14278,
  [14466] = 13407,
  [14467] = 14278,
  [14468] = 8390,
  [14469] = 5540,
  [14470] = 14470,
  [14471] = 13517,
  [14472] = 14436,
  [14473] = 14473,
  [14474] = 13339,
  [14475] = 14475,
  [14476] = 5284,
  [14477] = 14477,
  [14478] = 5861,
  [14479] = 14479,
  [14480] = 13407,
  [14481] = 14481,
  [14482] = 13339,
  [14483] = 13517,
  [14484] = 14484,
  [14485] = 5539,
  [14486] = 14363,
  [14487] = 14361,
  [14488] = 5341,
  [14489] = 5496,
  [14490] = 14477,
  [14491] = 13407,
  [14492] = 5908,
  [14493] = 5396,
  [14494] = 13407,
  [14495] = 5341,
  [14496] = 13558,
  [14497] = 14296,
  [14498] = 13517,
  [14499] = 11719,
  [14500] = 13353,
  [14501] = 5295,
  [14502] = 5284,
  [14503] = 13407,
  [14504] = 14436,
  [14505] = 10933,
  [14506] = 13407,
  [14507] = 14507,
  [14508] = 14436,
  [14509] = 14436,
  [14510] = 14436,
  [14511] = 14436,
  [14512] = 13339,
  [14513] = 13921,
  [14514] = 14514,
  [14515] = 14436,
  [14516] = 14324,
  [14517] = 13342,
  [14518] = 14436,
  [14519] = 14436,
  [14520] = 5496,
  [14521] = 13407,
  [14522] = 13517,
  [14523] = 14436,
  [14524] = 14278,
  [14525] = 13047,
  [14526] = 5341,
  [14527] = 14527,
  [14528] = 14436,
  [14529] = 14529,
  [14530] = 14280,
  [14531] = 14531,
  [14532] = 5295,
  [14533] = 14436,
  [14534] = 5123,
  [14535] = 5548,
  [14536] = 4647,
  [14537] = 5548,
  [14538] = 14514,
  [14539] = 14539,
  [14540] = 5228,
  [14541] = 11717,
  [14542] = 11715,
  [14543] = 5284,
  [14544] = 14544,
  [14545] = 13779,
  [14546] = 4656,
  [14547] = 12970,
  [14548] = 11714,
  [14549] = 14277,
  [14550] = 8390,
  [14551] = 8390,
  [14552] = 14436,
  [14553] = 14553,
  [14554] = 4529,
  [14555] = 14555,
  [14556] = 14556,
  [14557] = 14343,
  [14558] = 14411,
  [14559] = 14559,
  [14560] = 14436,
  [14561] = 13354,
  [14562] = 12970,
  [14563] = 13353,
  [14564] = 14400,
  [14565] = 14331,
  [14566] = 14436,
  [14567] = 14436,
  [14568] = 5496,
  [14569] = 14559,
  [14570] = 11720,
  [14571] = 14571,
  [14572] = 14436,
  [14573] = 5908,
  [14574] = 13517,
  [14575] = 5861,
  [14576] = 13339,
  [14577] = 13099,
  [14578] = 13100,
  [14579] = 14436,
  [14580] = 5548,
  [14581] = 5539,
  [14582] = 13192,
  [14583] = 14436,
  [14584] = 5540,
  [14585] = 14585,
  [14586] = 5539,
  [14587] = 14587,
  [14588] = 14588,
  [14589] = 14589,
  [14590] = 5540,
  [14591] = 14591,
  [14592] = 13517,
  [14593] = 14593,
  [14594] = 4925,
  [14595] = 11723,
  [14596] = 14596,
  [14597] = 14436,
  [14598] = 14598,
  [14599] = 14599,
  [14600] = 5139,
  [14601] = 14601,
  [14602] = 14599,
  [14603] = 14603,
  [14604] = 14604,
  [14605] = 14605,
  [14606] = 14606,
  [14607] = 14599,
  [14608] = 14608,
  [14609] = 14609,
  [14610] = 14610,
  [14611] = 14599,
  [14612] = 14544,
  [14613] = 14599,
  [14614] = 13698,
  [14615] = 14615,
  [14616] = 12970,
  [14617] = 14599,
  [14618] = 14618,
  [14619] = 14599,
  [14620] = 14620,
  [14621] = 14599,
  [14622] = 14622,
  [14623] = 14623,
  [14624] = 14599,
  [14625] = 14625,
  [14626] = 5295,
  [14627] = 14599,
  [14628] = 14599,
  [14629] = 14629,
  [14630] = 14585,
  [14631] = 14599,
  [14632] = 14632,
  [14633] = 14633,
  [14634] = 14634,
  [14635] = 14635,
  [14636] = 14636,
  [14637] = 4656,
  [14638] = 14599,
  [14639] = 14639,
  [14640] = 14599,
  [14641] = 14599,
  [14642] = 14642,
  [14643] = 14643,
  [14644] = 14644,
  [14645] = 14645,
  [14646] = 14599,
  [14647] = 14462,
  [14648] = 14464,
  [14649] = 14400,
  [14650] = 14650,
  [14651] = 14599,
  [14652] = 14599,
  [14653] = 14653,
  [14654] = 14654,
  [14655] = 4647,
  [14656] = 14656,
  [14657] = 14657,
  [14658] = 13517,
  [14659] = 14659,
  [14660] = 13558,
  [14661] = 13567,
  [14662] = 13407,
  [14663] = 14599,
  [14664] = 14664,
  [14665] = 14665,
  [14666] = 14599,
  [14667] = 14667,
  [14668] = 14599,
  [14669] = 14599,
  [14670] = 14670,
  [14671] = 14653,
  [14672] = 14618,
  [14673] = 14673,
  [14674] = 13559,
  [14675] = 14675,
  [14676] = 14470,
  [14677] = 14665,
  [14678] = 14599,
  [14679] = 14679,
  [14680] = 14680,
  [14681] = 14681,
  [14682] = 14667,
  [14683] = 14683,
  [14684] = 14599,
  [14685] = 14675,
  [14686] = 14686,
  [14687] = 14687,
  [14688] = 4642,
  [14689] = 14599,
  [14690] = 14599,
  [14691] = 13517,
  [14692] = 12970,
  [14693] = 14636,
  [14694] = 14599,
  [14695] = 14599,
  [14696] = 13559,
  [14697] = 13407,
  [14698] = 14698,
  [14699] = 14599,
  [14700] = 14700,
  [14701] = 14555,
  [14702] = 12970,
  [14703] = 14703,
  [14704] = 14587,
  [14705] = 14705,
  [14706] = 5284,
  [14707] = 14589,
  [14708] = 14599,
  [14709] = 13517,
  [14710] = 14710,
  [14711] = 14711,
  [14712] = 13407,
  [14713] = 13407,
  [14714] = 5861,
  [14715] = 14715,
  [14716] = 14716,
  [14717] = 14717,
  [14718] = 14599,
  [14719] = 14599,
  [14720] = 14720,
  [14721] = 13551,
  [14722] = 14599,
  [14723] = 14723,
  [14724] = 14724,
  [14725] = 14725,
  [14726] = 14599,
  [14727] = 13438,
  [14728] = 14728,
  [14729] = 14729,
  [14730] = 14599,
  [14731] = 4858,
  [14732] = 14732,
  [14733] = 14711,
  [14734] = 14734,
  [14735] = 14735,
  [14736] = 14736,
  [14737] = 14507,
  [14738] = 14738,
  [14739] = 14529,
  [14740] = 14740,
  [14741] = 13560,
  [14742] = 13517,
  [14743] = 14743,
  [14744] = 14664,
  [14745] = 14745,
  [14746] = 5539,
  [14747] = 13551,
  [14748] = 14748,
  [14749] = 14749,
  [14750] = 14750,
  [14751] = 14751,
  [14752] = 14599,
  [14753] = 14753,
  [14754] = 14599,
  [14755] = 14599,
  [14756] = 14750,
  [14757] = 14599,
  [14758] = 14715,
  [14759] = 14683,
  [14760] = 14072,
  [14761] = 5540,
  [14762] = 13438,
  [14763] = 14763,
  [14764] = 14764,
  [14765] = 14599,
  [14766] = 14603,
  [14767] = 14599,
  [14768] = 14599,
  [14769] = 12970,
  [14770] = 14484,
  [14771] = 14771,
  [14772] = 14591,
  [14773] = 14599,
  [14774] = 13567,
  [14775] = 14599,
  [14776] = 14599,
  [14777] = 14777,
  [14778] = 14778,
  [14779] = 14779,
  [14780] = 14780,
  [14781] = 13504,
  [14782] = 13560,
  [14783] = 8390,
  [14784] = 14784,
  [14785] = 14785,
  [14786] = 14786,
  [14787] = 14787,
  [14788] = 14788,
  [14789] = 14789,
  [14790] = 13406,
  [14791] = 14791,
  [14792] = 14599,
  [14793] = 14793,
  [14794] = 14599,
  [14795] = 14599,
  [14796] = 14599,
  [14797] = 14797,
  [14798] = 5341,
  [14799] = 14799,
  [14800] = 14599,
  [14801] = 14801,
  [14802] = 14700,
  [14803] = 14803,
  [14804] = 14804,
  [14805] = 14805,
  [14806] = 14599,
  [14807] = 14599,
  [14808] = 14808,
  [14809] = 14724,
  [14810] = 14810,
  [14811] = 14599,
  [14812] = 14812,
  [14813] = 14599,
  [14814] = 14599,
  [14815] = 14815,
  [14816] = 14816,
  [14817] = 14599,
  [14818] = 14818,
  [14819] = 14819,
  [14820] = 14820,
  [14821] = 14821,
  [14822] = 5396,
  [14823] = 14763,
  [14824] = 5496,
  [14825] = 14599,
  [14826] = 5908,
  [14827] = 14650,
  [14828] = 14791,
  [14829] = 14599,
  [14830] = 14599,
  [14831] = 14831,
  [14832] = 14553,
  [14833] = 13560,
  [14834] = 14599,
  [14835] = 14835,
  [14836] = 14599,
  [14837] = 14599,
  [14838] = 14710,
  [14839] = 13406,
  [14840] = 14840,
  [14841] = 14599,
  [14842] = 14599,
  [14843] = 14843,
  [14844] = 14799,
  [14845] = 13504,
  [14846] = 14599,
  [14847] = 14847,
  [14848] = 14848,
  [14849] = 14849,
  [14850] = 14657,
  [14851] = 5548,
  [14852] = 14852,
  [14853] = 14853,
  [14854] = 3985,
  [14855] = 14763,
  [14856] = 14856,
  [14857] = 14622,
  [14858] = 14610,
  [14859] = 14426,
  [14860] = 14856,
  [14861] = 14861,
  [14862] = 14862,
  [14863] = 14670,
  [14864] = 14853,
  [14865] = 14656,
  [14866] = 14866,
  [14867] = 14862,
  [14868] = 14861,
  [14869] = 14853,
  [14870] = 14862,
  [14871] = 14871,
  [14872] = 14861,
  [14873] = 3987,
  [14874] = 14871,
  [14875] = 14866,
  [14876] = 14862,
  [14877] = 14615,
  [14878] = 14871,
  [14879] = 14879,
  [14880] = 14736,
  [14881] = 14881,
  [14882] = 14882,
  [14883] = 14856,
  [14884] = 14884,
  [14885] = 14862,
  [14886] = 14743,
  [14887] = 14882,
  [14888] = 14884,
  [14889] = 14664,
  [14890] = 14805,
  [14891] = 14664,
  [14892] = 14881,
  [14893] = 14642,
  [14894] = 14894,
  [14895] = 14849,
  [14896] = 14848,
  [14897] = 14862,
  [14898] = 14898,
  [14899] = 14861,
  [14900] = 14900,
  [14901] = 14190,
  [14902] = 14871,
  [14903] = 14871,
  [14904] = 14862,
  [14905] = 14884,
  [14906] = 14862,
  [14907] = 14907,
  [14908] = 14871,
  [14909] = 14853,
  [14910] = 14882,
  [14911] = 14853,
  [14912] = 14866,
  [14913] = 14913,
  [14914] = 14884,
  [14915] = 14882,
  [14916] = 14916,
  [14917] = 14862,
  [14918] = 14801,
  [14919] = 14862,
  [14920] = 14920,
  [14921] = 14861,
  [14922] = 14922,
  [14923] = 14862,
  [14924] = 14862,
  [14925] = 14780,
  [14926] = 14861,
  [14927] = 14862,
  [14928] = 14866,
  [14929] = 14929,
  [14930] = 14856,
  [14931] = 14856,
  [14932] = 14871,
  [14933] = 14862,
  [14934] = 14856,
  [14935] = 14861,
  [14936] = 14936,
  [14937] = 14861,
  [14938] = 14734,
  [14939] = 14732,
  [14940] = 14940,
  [14941] = 14856,
  [14942] = 14862,
  [14943] = 14819,
  [14944] = 14882,
  [14945] = 14884,
  [14946] = 14862,
  [14947] = 14947,
  [14948] = 14862,
  [14949] = 14862,
  [14950] = 14687,
  [14951] = 14951,
  [14952] = 14686,
  [14953] = 14856,
  [14954] = 14681,
  [14955] = 14679,
  [14956] = 14866,
  [14957] = 14882,
  [14958] = 14866,
  [14959] = 14861,
  [14960] = 14861,
  [14961] = 14882,
  [14962] = 14884,
  [14963] = 14862,
  [14964] = 14964,
  [14965] = 14884,
  [14966] = 14861,
  [14967] = 14862,
  [14968] = 14620,
  [14969] = 14969,
  [14970] = 14871,
  [14971] = 14971,
  [14972] = 14866,
  [14973] = 14871,
  [14974] = 14974,
  [14975] = 14609,
  [14976] = 14604,
  [14977] = 14977,
  [14978] = 14636,
  [14979] = 14853,
  [14980] = 14605,
  [14981] = 14606,
  [14982] = 14608,
  [14983] = 14866,
  [14984] = 14853,
  [14985] = 14871,
  [14986] = 14871,
  [14987] = 14987,
  [14988] = 14856,
  [14989] = 14862,
  [14990] = 14862,
  [14991] = 14853,
  [14992] = 14861,
  [14993] = 14862,
  [14994] = 14862,
  [14995] = 14720,
  [14996] = 14977,
  [14997] = 14723,
  [14998] = 14711,
  [14999] = 14039,
  [15000] = 14853,
  [15001] = 14740,
  [15002] = 14862,
  [15003] = 14748,
  [15004] = 15004,
  [15005] = 14799,
  [15006] = 14861,
  [15007] = 14884,
  [15008] = 14856,
  [15009] = 14856,
  [15010] = 15010,
  [15011] = 14884,
  [15012] = 14862,
  [15013] = 14871,
  [15014] = 14862,
  [15015] = 14862,
  [15016] = 14882,
  [15017] = 14862,
  [15018] = 14882,
  [15019] = 14866,
  [15020] = 14866,
  [15021] = 14884,
  [15022] = 14862,
  [15023] = 15023,
  [15024] = 14700,
  [15025] = 15025,
  [15026] = 15026,
  [15027] = 14808,
  [15028] = 14812,
  [15029] = 14816,
  [15030] = 14470,
  [15031] = 14882,
  [15032] = 14884,
  [15033] = 14862,
  [15034] = 15034,
  [15035] = 14653,
  [15036] = 14861,
  [15037] = 14856,
  [15038] = 14728,
  [15039] = 14871,
  [15040] = 15040,
  [15041] = 15041,
  [15042] = 14852,
  [15043] = 14847,
  [15044] = 14882,
  [15045] = 14843,
  [15046] = 14840,
  [15047] = 14862,
  [15048] = 14862,
  [15049] = 14936,
  [15050] = 14866,
  [15051] = 13789,
  [15052] = 13788,
  [15053] = 14797,
  [15054] = 14853,
  [15055] = 14788,
  [15056] = 14784,
  [15057] = 14815,
  [15058] = 14861,
  [15059] = 14861,
  [15060] = 14871,
  [15061] = 15061,
  [15062] = 14871,
  [15063] = 14764,
  [15064] = 14853,
  [15065] = 14871,
  [15066] = 14729,
  [15067] = 15067,
  [15068] = 14861,
  [15069] = 14717,
  [15070] = 14862,
  [15071] = 14853,
  [15072] = 14636,
  [15073] = 14871,
  [15074] = 14856,
  [15075] = 14866,
  [15076] = 14866,
  [15077] = 14862,
  [15078] = 15078,
  [15079] = 14725,
  [15080] = 14601,
  [15081] = 14884,
  [15082] = 14882,
  [15083] = 14882,
  [15084] = 14882,
  [15085] = 14884,
  [15086] = 15086,
  [15087] = 14853,
  [15088] = 14853,
  [15089] = 14625,
  [15090] = 14629,
  [15091] = 15091,
  [15092] = 15092,
  [15093] = 14884,
  [15094] = 14853,
  [15095] = 14632,
  [15096] = 14633,
  [15097] = 15097,
  [15098] = 14634,
  [15099] = 14884,
  [15100] = 14635,
  [15101] = 14862,
  [15102] = 14882,
  [15103] = 14639,
  [15104] = 14861,
  [15105] = 14598,
  [15106] = 14643,
  [15107] = 14644,
  [15108] = 14645,
  [15109] = 14763,
  [15110] = 15110,
  [15111] = 15023,
  [15112] = 14861,
  [15113] = 15113,
  [15114] = 15114,
  [15115] = 15010,
  [15116] = 14856,
  [15117] = 14964,
  [15118] = 14866,
  [15119] = 15119,
  [15120] = 14862,
  [15121] = 14964,
  [15122] = 14716,
  [15123] = 14862,
  [15124] = 14862,
  [15125] = 14871,
  [15126] = 14862,
  [15127] = 14735,
  [15128] = 14738,
  [15129] = 14871,
  [15130] = 14862,
  [15131] = 14793,
  [15132] = 14745,
  [15133] = 14749,
  [15134] = 14751,
  [15135] = 14853,
  [15136] = 14659,
  [15137] = 15137,
  [15138] = 14879,
  [15139] = 15139,
  [15140] = 15140,
  [15141] = 5123,
  [15142] = 13886,
  [15143] = 14871,
  [15144] = 14882,
  [15145] = 14785,
  [15146] = 14884,
  [15147] = 14861,
  [15148] = 15148,
  [15149] = 14866,
  [15150] = 14856,
  [15151] = 14786,
  [15152] = 15152,
  [15153] = 14856,
  [15154] = 14787,
  [15155] = 15155,
  [15156] = 14856,
  [15157] = 15061,
  [15158] = 14861,
  [15159] = 14862,
  [15160] = 14862,
  [15161] = 14871,
  [15162] = 14853,
  [15163] = 14871,
  [15164] = 14871,
  [15165] = 14871,
  [15166] = 14861,
  [15167] = 14866,
  [15168] = 14882,
  [15169] = 14862,
  [15170] = 14884,
  [15171] = 14862,
  [15172] = 14871,
  [15173] = 14866,
  [15174] = 14862,
  [15175] = 14871,
  [15176] = 15113,
  [15177] = 14853,
  [15178] = 14871,
  [15179] = 14190,
  [15180] = 14862,
  [15181] = 14884,
  [15182] = 14882,
  [15183] = 14861,
  [15184] = 14862,
  [15185] = 14866,
  [15186] = 14618,
  [15187] = 14856,
  [15188] = 14862,
  [15189] = 14861,
  [15190] = 14861,
  [15191] = 14862,
  [15192] = 15192,
  [15193] = 15193,
  [15194] = 15194,
  [15195] = 15195,
  [15196] = 15192,
  [15197] = 15197,
  [15198] = 15198,
  [15199] = 15199,
  [15200] = 15200,
  [15201] = 15201,
  [15202] = 15201,
  [15203] = 15203,
  [15204] = 15195,
  [15205] = 15192,
  [15206] = 15193,
  [15207] = 15192,
  [15208] = 5228,
  [15209] = 15200,
  [15210] = 15210,
  [15211] = 15201,
  [15212] = 15212,
  [15213] = 15193,
  [15214] = 15201,
  [15215] = 15195,
  [15216] = 15200,
  [15217] = 15192,
  [15218] = 15218,
  [15219] = 15219,
  [15220] = 15220,
  [15221] = 15219,
  [15222] = 15195,
  [15223] = 15192,
  [15224] = 15195,
  [15225] = 15225,
  [15226] = 15200,
  [15227] = 15227,
  [15228] = 15197,
  [15229] = 15201,
  [15230] = 15201,
  [15231] = 15231,
  [15232] = 15232,
  [15233] = 15200,
  [15234] = 15195,
  [15235] = 15235,
  [15236] = 15192,
  [15237] = 15237,
  [15238] = 15238,
  [15239] = 15239,
  [15240] = 15240,
  [15241] = 15192,
  [15242] = 15195,
  [15243] = 15231,
  [15244] = 15244,
  [15245] = 15200,
  [15246] = 15232,
  [15247] = 15201,
  [15248] = 15200,
  [15249] = 15201,
  [15250] = 15200,
  [15251] = 15251,
  [15252] = 15200,
  [15253] = 15195,
  [15254] = 15199,
  [15255] = 15192,
  [15256] = 15192,
  [15257] = 15200,
  [15258] = 15225,
  [15259] = 15192,
  [15260] = 15195,
  [15261] = 15261,
  [15262] = 15199,
  [15263] = 15263,
  [15264] = 15200,
  [15265] = 15201,
  [15266] = 15200,
  [15267] = 15201,
  [15268] = 15268,
  [15269] = 15263,
  [15270] = 15200,
  [15271] = 15195,
  [15272] = 15268,
  [15273] = 15192,
  [15274] = 15263,
  [15275] = 15268,
  [15276] = 15195,
  [15277] = 15192,
  [15278] = 15195,
  [15279] = 15263,
  [15280] = 15280,
  [15281] = 15268,
  [15282] = 15200,
  [15283] = 15201,
  [15284] = 15200,
  [15285] = 15201,
  [15286] = 15286,
  [15287] = 15263,
  [15288] = 15288,
  [15289] = 15195,
  [15290] = 15268,
  [15291] = 15192,
  [15292] = 15292,
  [15293] = 15263,
  [15294] = 15294,
  [15295] = 15192,
  [15296] = 15195,
  [15297] = 15268,
  [15298] = 15201,
  [15299] = 15263,
  [15300] = 15200,
  [15301] = 15201,
  [15302] = 15200,
  [15303] = 15201,
  [15304] = 15304,
  [15305] = 15268,
  [15306] = 15263,
  [15307] = 15195,
  [15308] = 15268,
  [15309] = 15192,
  [15310] = 15310,
  [15311] = 15263,
  [15312] = 15193,
  [15313] = 15192,
  [15314] = 15195,
  [15315] = 15268,
  [15316] = 15316,
  [15317] = 15263,
  [15318] = 15200,
  [15319] = 15201,
  [15320] = 15200,
  [15321] = 15201,
  [15322] = 15219,
  [15323] = 15268,
  [15324] = 15231,
  [15325] = 15195,
  [15326] = 15263,
  [15327] = 15192,
  [15328] = 15268,
  [15329] = 15263,
  [15330] = 15268,
  [15331] = 15192,
  [15332] = 15195,
  [15333] = 15333,
  [15334] = 15263,
  [15335] = 15335,
  [15336] = 15200,
  [15337] = 15201,
  [15338] = 15268,
  [15339] = 15201,
  [15340] = 15263,
  [15341] = 15341,
  [15342] = 15268,
  [15343] = 15195,
  [15344] = 15263,
  [15345] = 15192,
  [15346] = 15232,
  [15347] = 15268,
  [15348] = 15263,
  [15349] = 15192,
  [15350] = 15195,
  [15351] = 15268,
  [15352] = 15232,
  [15353] = 15263,
  [15354] = 15200,
  [15355] = 15201,
  [15356] = 15200,
  [15357] = 15201,
  [15358] = 15268,
  [15359] = 15268,
  [15360] = 15200,
  [15361] = 15195,
  [15362] = 15263,
  [15363] = 15192,
  [15364] = 15199,
  [15365] = 15268,
  [15366] = 15366,
  [15367] = 15192,
  [15368] = 15195,
  [15369] = 15369,
  [15370] = 15263,
  [15371] = 15231,
  [15372] = 15200,
  [15373] = 15201,
  [15374] = 15200,
  [15375] = 15201,
  [15376] = 15268,
  [15377] = 15197,
  [15378] = 15378,
  [15379] = 15195,
  [15380] = 15263,
  [15381] = 15192,
  [15382] = 15225,
  [15383] = 15268,
  [15384] = 15384,
  [15385] = 15192,
  [15386] = 15195,
  [15387] = 15387,
  [15388] = 15263,
  [15389] = 15389,
  [15390] = 15200,
  [15391] = 15201,
  [15392] = 15200,
  [15393] = 15201,
  [15394] = 15268,
  [15395] = 15395,
  [15396] = 15263,
  [15397] = 15195,
  [15398] = 15195,
  [15399] = 15192,
  [15400] = 15268,
  [15401] = 15192,
  [15402] = 15201,
  [15403] = 15192,
  [15404] = 15195,
  [15405] = 15263,
  [15406] = 15406,
  [15407] = 15268,
  [15408] = 15200,
  [15409] = 15201,
  [15410] = 15200,
  [15411] = 15201,
  [15412] = 15412,
  [15413] = 15263,
  [15414] = 15268,
  [15415] = 15195,
  [15416] = 15195,
  [15417] = 15192,
  [15418] = 15418,
  [15419] = 15263,
  [15420] = 15219,
  [15421] = 15192,
  [15422] = 15195,
  [15423] = 15268,
  [15424] = 15424,
  [15425] = 15197,
  [15426] = 15200,
  [15427] = 15201,
  [15428] = 15200,
  [15429] = 15201,
  [15430] = 15263,
  [15431] = 15431,
  [15432] = 15268,
  [15433] = 15195,
  [15434] = 15434,
  [15435] = 15192,
  [15436] = 15436,
  [15437] = 15263,
  [15438] = 15193,
  [15439] = 15192,
  [15440] = 15195,
  [15441] = 15268,
  [15442] = 15201,
  [15443] = 15443,
  [15444] = 15200,
  [15445] = 15201,
  [15446] = 15200,
  [15447] = 15201,
  [15448] = 15263,
  [15449] = 15268,
  [15450] = 15192,
  [15451] = 15195,
  [15452] = 15263,
  [15453] = 15192,
  [15454] = 15268,
  [15455] = 15455,
  [15456] = 15193,
  [15457] = 15192,
  [15458] = 15195,
  [15459] = 15263,
  [15460] = 15225,
  [15461] = 15268,
  [15462] = 15200,
  [15463] = 15201,
  [15464] = 15200,
  [15465] = 15201,
  [15466] = 15197,
  [15467] = 15467,
  [15468] = 15201,
  [15469] = 15195,
  [15470] = 15263,
  [15471] = 15192,
  [15472] = 15219,
  [15473] = 15268,
  [15474] = 15474,
  [15475] = 15192,
  [15476] = 15195,
  [15477] = 15477,
  [15478] = 15263,
  [15479] = 15268,
  [15480] = 15200,
  [15481] = 15201,
  [15482] = 15200,
  [15483] = 15201,
  [15484] = 15484,
  [15485] = 15485,
  [15486] = 15263,
  [15487] = 15195,
  [15488] = 15488,
  [15489] = 15192,
  [15490] = 15268,
  [15491] = 15491,
  [15492] = 15263,
  [15493] = 15192,
  [15494] = 15195,
  [15495] = 14190,
  [15496] = 15268,
  [15497] = 15497,
  [15498] = 15200,
  [15499] = 15201,
  [15500] = 15200,
  [15501] = 15201,
  [15502] = 15263,
  [15503] = 15261,
  [15504] = 15268,
  [15505] = 15195,
  [15506] = 15263,
  [15507] = 15192,
  [15508] = 15268,
  [15509] = 15263,
  [15510] = 15263,
  [15511] = 15192,
  [15512] = 15195,
  [15513] = 15513,
  [15514] = 15268,
  [15515] = 15195,
  [15516] = 15200,
  [15517] = 15517,
  [15518] = 15200,
  [15519] = 15201,
  [15520] = 15263,
  [15521] = 15521,
  [15522] = 15268,
  [15523] = 15195,
  [15524] = 15524,
  [15525] = 15192,
  [15526] = 15199,
  [15527] = 15263,
  [15528] = 15528,
  [15529] = 15192,
  [15530] = 15195,
  [15531] = 15268,
  [15532] = 15532,
  [15533] = 15533,
  [15534] = 15200,
  [15535] = 15201,
  [15536] = 15200,
  [15537] = 15201,
  [15538] = 15263,
  [15539] = 15200,
  [15540] = 15268,
  [15541] = 15195,
  [15542] = 15542,
  [15543] = 15192,
  [15544] = 15544,
  [15545] = 15263,
  [15546] = 15197,
  [15547] = 15192,
  [15548] = 15195,
  [15549] = 15268,
  [15550] = 15263,
  [15551] = 15551,
  [15552] = 15200,
  [15553] = 15201,
  [15554] = 15200,
  [15555] = 15201,
  [15556] = 15268,
  [15557] = 15557,
  [15558] = 15232,
  [15559] = 15195,
  [15560] = 15263,
  [15561] = 15192,
  [15562] = 15562,
  [15563] = 15268,
  [15564] = 15225,
  [15565] = 15192,
  [15566] = 15195,
  [15567] = 15263,
  [15568] = 15231,
  [15569] = 15268,
  [15570] = 15200,
  [15571] = 15201,
  [15572] = 15200,
  [15573] = 15201,
  [15574] = 15231,
  [15575] = 15575,
  [15576] = 15263,
  [15577] = 15195,
  [15578] = 15578,
  [15579] = 15192,
  [15580] = 15268,
  [15581] = 15581,
  [15582] = 15582,
  [15583] = 15192,
  [15584] = 15195,
  [15585] = 15263,
  [15586] = 15268,
  [15587] = 15232,
  [15588] = 15200,
  [15589] = 15201,
  [15590] = 15200,
  [15591] = 15201,
  [15592] = 15592,
  [15593] = 15263,
  [15594] = 15195,
  [15595] = 15195,
  [15596] = 15596,
  [15597] = 15192,
  [15598] = 15268,
  [15599] = 15599,
  [15600] = 15600,
  [15601] = 15192,
  [15602] = 15195,
  [15603] = 15263,
  [15604] = 14086,
  [15605] = 15268,
  [15606] = 15200,
  [15607] = 15201,
  [15608] = 15200,
  [15609] = 15201,
  [15610] = 15210,
  [15611] = 15611,
  [15612] = 15263,
  [15613] = 15195,
  [15614] = 15225,
  [15615] = 15192,
  [15616] = 15268,
  [15617] = 15263,
  [15618] = 15200,
  [15619] = 15192,
  [15620] = 15201,
  [15621] = 15268,
  [15622] = 15622,
  [15623] = 15263,
  [15624] = 15200,
  [15625] = 15201,
  [15626] = 15626,
  [15627] = 15201,
  [15628] = 15268,
  [15629] = 15199,
  [15630] = 15200,
  [15631] = 15195,
  [15632] = 15197,
  [15633] = 15192,
  [15634] = 15263,
  [15635] = 15635,
  [15636] = 15268,
  [15637] = 15637,
  [15638] = 15192,
  [15639] = 15195,
  [15640] = 15640,
  [15641] = 15263,
  [15642] = 15200,
  [15643] = 15192,
  [15644] = 15201,
  [15645] = 15268,
  [15646] = 15646,
  [15647] = 15201,
  [15648] = 15195,
  [15649] = 15649,
  [15650] = 15192,
  [15651] = 15263,
  [15652] = 15652,
  [15653] = 15200,
  [15654] = 15268,
  [15655] = 15655,
  [15656] = 15656,
  [15657] = 15192,
  [15658] = 15192,
  [15659] = 15200,
  [15660] = 15201,
  [15661] = 15263,
  [15662] = 15195,
  [15663] = 15195,
  [15664] = 15195,
  [15665] = 15268,
  [15666] = 15192,
  [15667] = 15667,
  [15668] = 15197,
  [15669] = 15263,
  [15670] = 15201,
  [15671] = 15671,
  [15672] = 15200,
  [15673] = 15268,
  [15674] = 15201,
  [15675] = 15675,
  [15676] = 15676,
  [15677] = 15677,
  [15678] = 15192,
  [15679] = 15263,
  [15680] = 15219,
  [15681] = 15268,
  [15682] = 15682,
  [15683] = 15192,
  [15684] = 15684,
  [15685] = 15201,
  [15686] = 14343,
  [15687] = 15263,
  [15688] = 15195,
  [15689] = 15192,
  [15690] = 15193,
  [15691] = 15268,
  [15692] = 15201,
  [15693] = 15261,
  [15694] = 15201,
  [15695] = 14481,
  [15696] = 15201,
  [15697] = 15263,
  [15698] = 14331,
  [15699] = 15268,
  [15700] = 15192,
  [15701] = 14296,
  [15702] = 15491,
  [15703] = 15200,
  [15704] = 14593,
  [15705] = 15263,
  [15706] = 15201,
  [15707] = 15201,
  [15708] = 15268,
  [15709] = 15197,
  [15710] = 15193,
  [15711] = 15192,
  [15712] = 15219,
  [15713] = 15263,
  [15714] = 15192,
  [15715] = 15195,
  [15716] = 15199,
  [15717] = 15268,
  [15718] = 15201,
  [15719] = 15599,
  [15720] = 15600,
  [15721] = 15195,
  [15722] = 15192,
  [15723] = 15263,
  [15724] = 14531,
  [15725] = 15268,
  [15726] = 15200,
  [15727] = 15200,
  [15728] = 15656,
  [15729] = 15201,
  [15730] = 15677,
  [15731] = 15263,
  [15732] = 15596,
  [15733] = 15192,
  [15734] = 15268,
  [15735] = 15192,
  [15736] = 15232,
  [15737] = 15225,
  [15738] = 15192,
  [15739] = 15263,
  [15740] = 15201,
  [15741] = 15231,
  [15742] = 15268,
  [15743] = 15195,
  [15744] = 15192,
  [15745] = 15210,
  [15746] = 15225,
  [15747] = 15200,
  [15748] = 15263,
  [15749] = 15201,
  [15750] = 15192,
  [15751] = 15201,
  [15752] = 15268,
  [15753] = 15197,
  [15754] = 15195,
  [15755] = 15192,
  [15756] = 15197,
  [15757] = 15263,
  [15758] = 15200,
  [15759] = 15219,
  [15760] = 15201,
  [15761] = 15268,
  [15762] = 15193,
  [15763] = 15192,
  [15764] = 15201,
  [15765] = 15261,
  [15766] = 15192,
  [15767] = 15201,
  [15768] = 15263,
  [15769] = 15195,
  [15770] = 15192,
  [15771] = 15268,
  [15772] = 15263,
  [15773] = 15268,
  [15774] = 15201,
  [15775] = 15201,
  [15776] = 15201,
  [15777] = 15192,
  [15778] = 15199,
  [15779] = 15200,
  [15780] = 15201,
  [15781] = 15200,
  [15782] = 15192,
  [15783] = 15195,
  [15784] = 15201,
  [15785] = 15263,
  [15786] = 15192,
  [15787] = 15268,
  [15788] = 15201,
  [15789] = 15192,
  [15790] = 15192,
  [15791] = 15195,
  [15792] = 15201,
  [15793] = 15232,
  [15794] = 15192,
  [15795] = 15210,
  [15796] = 15201,
  [15797] = 15201,
  [15798] = 15192,
  [15799] = 15192,
  [15800] = 15201,
  [15801] = 15200,
  [15802] = 15192,
  [15803] = 15218,
  [15804] = 15201,
  [15805] = 15227,
  [15806] = 15192,
  [15807] = 15231,
  [15808] = 15201,
  [15809] = 15192,
  [15810] = 15192,
  [15811] = 15195,
  [15812] = 15201,
  [15813] = 15225,
  [15814] = 15192,
  [15815] = 15210,
  [15816] = 15201,
  [15817] = 15201,
  [15818] = 15192,
  [15819] = 15231,
  [15820] = 15201,
  [15821] = 15200,
  [15822] = 15192,
  [15823] = 15200,
  [15824] = 15201,
  [15825] = 15237,
  [15826] = 15192,
  [15827] = 15238,
  [15828] = 15201,
  [15829] = 15192,
  [15830] = 15192,
  [15831] = 15195,
  [15832] = 15201,
  [15833] = 15244,
  [15834] = 15192,
  [15835] = 15251,
  [15836] = 15201,
  [15837] = 15200,
  [15838] = 15200,
  [15839] = 15199,
  [15840] = 15225,
  [15841] = 15261,
  [15842] = 15192,
  [15843] = 15195,
  [15844] = 15192,
  [15845] = 15286,
  [15846] = 15288,
  [15847] = 15201,
  [15848] = 15292,
  [15849] = 15294,
  [15850] = 15201,
  [15851] = 15200,
  [15852] = 15304,
  [15853] = 15193,
  [15854] = 15219,
  [15855] = 15192,
  [15856] = 15195,
  [15857] = 15195,
  [15858] = 15333,
  [15859] = 15341,
  [15860] = 15201,
  [15861] = 15369,
  [15862] = 15200,
  [15863] = 15378,
  [15864] = 15387,
  [15865] = 15389,
  [15866] = 15395,
  [15867] = 15192,
  [15868] = 15195,
  [15869] = 15195,
  [15870] = 15219,
  [15871] = 15406,
  [15872] = 15201,
  [15873] = 15412,
  [15874] = 15232,
  [15875] = 15192,
  [15876] = 15200,
  [15877] = 15227,
  [15878] = 15225,
  [15879] = 15201,
  [15880] = 15193,
  [15881] = 15477,
  [15882] = 15201,
  [15883] = 15484,
  [15884] = 15199,
  [15885] = 15562,
  [15886] = 15488,
  [15887] = 15192,
  [15888] = 15497,
  [15889] = 15195,
  [15890] = 15521,
  [15891] = 15528,
  [15892] = 15201,
  [15893] = 15532,
  [15894] = 15286,
  [15895] = 15575,
  [15896] = 15288,
  [15897] = 15578,
  [15898] = 15292,
  [15899] = 15200,
  [15900] = 15294,
  [15901] = 15201,
  [15902] = 15261,
  [15903] = 15199,
  [15904] = 15581,
  [15905] = 15197,
  [15906] = 15304,
  [15907] = 15582,
  [15908] = 15611,
  [15909] = 15684,
  [15910] = 15652,
  [15911] = 15675,
  [15912] = 15192,
  [15913] = 15557,
  [15914] = 15210,
  [15915] = 15195,
  [15916] = 15200,
  [15917] = 15268,
  [15918] = 15218,
  [15919] = 15201,
  [15920] = 15232,
  [15921] = 15195,
  [15922] = 15231,
  [15923] = 15200,
  [15924] = 15231,
  [15925] = 15192,
  [15926] = 15304,
  [15927] = 15232,
  [15928] = 15244,
  [15929] = 15263,
  [15930] = 15197,
  [15931] = 15225,
  [15932] = 15251,
  [15933] = 15200,
  [15934] = 15199,
  [15935] = 15261,
  [15936] = 15210,
  [15937] = 15201,
  [15938] = 15192,
  [15939] = 15201,
  [15940] = 15195,
  [15941] = 15219,
  [15942] = 15227,
  [15943] = 15201,
  [15944] = 15369,
  [15945] = 15378,
  [15946] = 15387,
  [15947] = 15200,
  [15948] = 15389,
  [15949] = 15225,
  [15950] = 15192,
  [15951] = 15395,
  [15952] = 15200,
  [15953] = 15195,
  [15954] = 15195,
  [15955] = 15412,
  [15956] = 15192,
  [15957] = 15192,
  [15958] = 15195,
  [15959] = 15199,
  [15960] = 15225,
  [15961] = 15562,
  [15962] = 15199,
  [15963] = 15199,
  [15964] = 15199,
  [15965] = 15199,
  [15966] = 15199,
  [15967] = 15199,
  [15968] = 15199,
  [15969] = 15199,
  [15970] = 15199,
  [15971] = 15199,
  [15972] = 15199,
  [15973] = 15199,
  [15974] = 15199,
  [15975] = 15199,
  [15976] = 15199,
  [15977] = 15199,
  [15978] = 15199,
  [15979] = 15219,
  [15980] = 15488,
  [15981] = 15521,
  [15982] = 15528,
  [15983] = 15200,
  [15984] = 15532,
  [15985] = 15201,
  [15986] = 15193,
  [15987] = 15557,
  [15988] = 15582,
  [15989] = 15201,
  [15990] = 15684,
  [15991] = 15675,
  [15992] = 15333,
  [15993] = 15210,
  [15994] = 15192,
  [15995] = 15261,
  [15996] = 15195,
  [15997] = 15218,
  [15998] = 15199,
  [15999] = 15195,
  [16000] = 15201,
  [16001] = 15200,
  [16002] = 15231,
  [16003] = 15232,
  [16004] = 15200,
  [16005] = 15244,
  [16006] = 15192,
  [16007] = 15232,
  [16008] = 15200,
  [16009] = 15231,
  [16010] = 15199,
  [16011] = 15261,
  [16012] = 15227,
  [16013] = 15225,
  [16014] = 15197,
  [16015] = 15192,
  [16016] = 15210,
  [16017] = 15195,
  [16018] = 15193,
  [16019] = 15219,
  [16020] = 15201,
  [16021] = 15333,
  [16022] = 15201,
  [16023] = 15195,
  [16024] = 15200,
  [16025] = 15225,
  [16026] = 15225,
  [16027] = 15192,
  [16028] = 15304,
  [16029] = 15412,
  [16030] = 15304,
  [16031] = 15192,
  [16032] = 15225,
  [16033] = 15562,
  [16034] = 15488,
  [16035] = 15557,
  [16036] = 15268,
  [16037] = 15225,
  [16038] = 15582,
  [16039] = 15192,
  [16040] = 15684,
  [16041] = 15263,
  [16042] = 15197,
  [16043] = 15675,
  [16044] = 15195,
  [16045] = 15210,
  [16046] = 15227,
  [16047] = 15195,
  [16048] = 15218,
  [16049] = 15219,
  [16050] = 15201,
  [16051] = 15199,
  [16052] = 15199,
  [16053] = 15199,
  [16054] = 15199,
  [16055] = 15199,
  [16056] = 15199,
  [16057] = 15199,
  [16058] = 15199,
  [16059] = 15200,
  [16060] = 15369,
  [16061] = 15231,
  [16062] = 15200,
  [16063] = 15232,
  [16064] = 15244,
  [16065] = 15193,
  [16066] = 15200,
  [16067] = 15201,
  [16068] = 15199,
  [16069] = 15261,
  [16070] = 15261,
  [16071] = 15201,
  [16072] = 15193,
  [16073] = 15225,
  [16074] = 15219,
  [16075] = 15192,
  [16076] = 15369,
  [16077] = 15195,
  [16078] = 15195,
  [16079] = 15201,
  [16080] = 15227,
  [16081] = 15201,
  [16082] = 15192,
  [16083] = 15225,
  [16084] = 15210,
  [16085] = 15200,
  [16086] = 15210,
  [16087] = 15199,
  [16088] = 15195,
  [16089] = 15304,
  [16090] = 15200,
  [16091] = 15192,
  [16092] = 15232,
  [16093] = 15231,
  [16094] = 15232,
  [16095] = 15244,
  [16096] = 15200,
  [16097] = 15197,
  [16098] = 15199,
  [16099] = 15231,
  [16100] = 15225,
  [16101] = 15225,
  [16102] = 15201,
  [16103] = 15192,
  [16104] = 15199,
  [16105] = 15199,
  [16106] = 15199,
  [16107] = 15199,
  [16108] = 15199,
  [16109] = 15199,
  [16110] = 15199,
  [16111] = 15199,
  [16112] = 15210,
  [16113] = 15195,
  [16114] = 15193,
  [16115] = 15219,
  [16116] = 15201,
  [16117] = 15369,
  [16118] = 15195,
  [16119] = 15225,
  [16120] = 15192,
  [16121] = 15225,
  [16122] = 15200,
  [16123] = 15192,
  [16124] = 15197,
  [16125] = 15195,
  [16126] = 15210,
  [16127] = 15219,
  [16128] = 15193,
  [16129] = 15304,
  [16130] = 15225,
  [16131] = 15227,
  [16132] = 15231,
  [16133] = 15192,
  [16134] = 15232,
  [16135] = 15195,
  [16136] = 15200,
  [16137] = 15199,
  [16138] = 15201,
  [16139] = 15261,
  [16140] = 15304,
  [16141] = 15261,
  [16142] = 15201,
  [16143] = 15201,
  [16144] = 15200,
  [16145] = 15193,
  [16146] = 15219,
  [16147] = 15197,
  [16148] = 15195,
  [16149] = 15200,
  [16150] = 15192,
  [16151] = 15261,
  [16152] = 15199,
  [16153] = 15199,
  [16154] = 15199,
  [16155] = 15199,
  [16156] = 15225,
  [16157] = 15200,
  [16158] = 15210,
  [16159] = 15227,
  [16160] = 15200,
  [16161] = 15231,
  [16162] = 15225,
  [16163] = 15232,
  [16164] = 15192,
  [16165] = 15200,
  [16166] = 15195,
  [16167] = 15199,
  [16168] = 15261,
  [16169] = 15201,
  [16170] = 15201,
  [16171] = 15201,
  [16172] = 15227,
  [16173] = 15193,
  [16174] = 15200,
  [16175] = 15219,
  [16176] = 15232,
  [16177] = 15304,
  [16178] = 15231,
  [16179] = 15195,
  [16180] = 15195,
  [16181] = 15192,
  [16182] = 15192,
  [16183] = 15225,
  [16184] = 15197,
  [16185] = 15225,
  [16186] = 15210,
  [16187] = 15225,
  [16188] = 15192,
  [16189] = 15225,
  [16190] = 15199,
  [16191] = 15199,
  [16192] = 15231,
  [16193] = 15232,
  [16194] = 15200,
  [16195] = 15199,
  [16196] = 15195,
  [16197] = 15195,
  [16198] = 15219,
  [16199] = 15201,
  [16200] = 15201,
  [16201] = 15193,
  [16202] = 15219,
  [16203] = 15200,
  [16204] = 15261,
  [16205] = 15193,
  [16206] = 15201,
  [16207] = 15227,
  [16208] = 15195,
  [16209] = 15197,
  [16210] = 15261,
  [16211] = 15192,
  [16212] = 15304,
  [16213] = 15225,
  [16214] = 15225,
  [16215] = 15200,
  [16216] = 15192,
  [16217] = 15210,
  [16218] = 15199,
  [16219] = 15197,
  [16220] = 15200,
  [16221] = 15231,
  [16222] = 15232,
  [16223] = 15195,
  [16224] = 15200,
  [16225] = 15199,
  [16226] = 15199,
  [16227] = 15199,
  [16228] = 15201,
  [16229] = 15261,
  [16230] = 15232,
  [16231] = 15201,
  [16232] = 15193,
  [16233] = 15219,
  [16234] = 15304,
  [16235] = 15195,
  [16236] = 15231,
  [16237] = 15201,
  [16238] = 15227,
  [16239] = 15195,
  [16240] = 15192,
  [16241] = 15225,
  [16242] = 15227,
  [16243] = 15225,
  [16244] = 15210,
  [16245] = 15192,
  [16246] = 15210,
  [16247] = 15304,
  [16248] = 15195,
  [16249] = 15192,
  [16250] = 15231,
  [16251] = 15232,
  [16252] = 15201,
  [16253] = 15200,
  [16254] = 15197,
  [16255] = 15199,
  [16256] = 15261,
  [16257] = 15225,
  [16258] = 15201,
  [16259] = 15193,
  [16260] = 15199,
  [16261] = 15219,
  [16262] = 15200,
  [16263] = 15195,
  [16264] = 15225,
  [16265] = 15192,
  [16266] = 15192,
  [16267] = 15195,
  [16268] = 15225,
  [16269] = 15219,
  [16270] = 15193,
  [16271] = 15210,
  [16272] = 15225,
  [16273] = 15200,
  [16274] = 15192,
  [16275] = 15201,
  [16276] = 15227,
  [16277] = 15195,
  [16278] = 15231,
  [16279] = 15232,
  [16280] = 15201,
  [16281] = 15304,
  [16282] = 15200,
  [16283] = 15199,
  [16284] = 15261,
  [16285] = 15261,
  [16286] = 15200,
  [16287] = 15199,
  [16288] = 15197,
  [16289] = 15201,
  [16290] = 15219,
  [16291] = 15195,
  [16292] = 15200,
  [16293] = 15197,
  [16294] = 15232,
  [16295] = 15192,
  [16296] = 15225,
  [16297] = 15231,
  [16298] = 15201,
  [16299] = 15210,
  [16300] = 15210,
  [16301] = 15225,
  [16302] = 15304,
  [16303] = 15192,
  [16304] = 15231,
  [16305] = 15195,
  [16306] = 15232,
  [16307] = 15200,
  [16308] = 15201,
  [16309] = 15227,
  [16310] = 15199,
  [16311] = 15261,
  [16312] = 15195,
  [16313] = 15200,
  [16314] = 15304,
  [16315] = 15201,
  [16316] = 15192,
  [16317] = 15193,
  [16318] = 15225,
  [16319] = 15219,
  [16320] = 15195,
  [16321] = 15197,
  [16322] = 15227,
  [16323] = 15192,
  [16324] = 15225,
  [16325] = 15225,
  [16326] = 15210,
  [16327] = 15192,
  [16328] = 15225,
  [16329] = 15195,
  [16330] = 15193,
  [16331] = 15232,
  [16332] = 15192,
  [16333] = 15200,
  [16334] = 15195,
  [16335] = 15199,
  [16336] = 15261,
  [16337] = 15201,
  [16338] = 15219,
  [16339] = 15201,
  [16340] = 15193,
  [16341] = 15200,
  [16342] = 15227,
  [16343] = 15219,
  [16344] = 15200,
  [16345] = 15193,
  [16346] = 15195,
  [16347] = 15304,
  [16348] = 15201,
  [16349] = 15261,
  [16350] = 15192,
  [16351] = 15225,
  [16352] = 15225,
  [16353] = 15199,
  [16354] = 15197,
  [16355] = 15210,
  [16356] = 15201,
  [16357] = 15231,
  [16358] = 15231,
  [16359] = 15192,
  [16360] = 15232,
  [16361] = 15195,
  [16362] = 15200,
  [16363] = 15199,
  [16364] = 15200,
  [16365] = 15261,
  [16366] = 15201,
  [16367] = 15232,
  [16368] = 15201,
  [16369] = 15193,
  [16370] = 15200,
  [16371] = 15219,
  [16372] = 15231,
  [16373] = 15197,
  [16374] = 15195,
  [16375] = 15227,
  [16376] = 15210,
  [16377] = 15195,
  [16378] = 15192,
  [16379] = 15225,
  [16380] = 15304,
  [16381] = 15225,
  [16382] = 15192,
  [16383] = 16383,
  [16384] = 16384,
  [16385] = 16385,
  [16386] = 16384,
  [16387] = 16387,
  [16388] = 16387,
  [16389] = 16383,
  [16390] = 16383,
  [16391] = 16391,
  [16392] = 16384,
  [16393] = 16387,
  [16394] = 16384,
  [16395] = 16385,
  [16396] = 16391,
  [16397] = 16384,
  [16398] = 16387,
  [16399] = 16383,
  [16400] = 16391,
  [16401] = 16383,
  [16402] = 16387,
  [16403] = 16383,
  [16404] = 16387,
  [16405] = 16385,
  [16406] = 16387,
  [16407] = 16384,
  [16408] = 16385,
  [16409] = 16387,
  [16410] = 16383,
  [16411] = 16384,
  [16412] = 16391,
  [16413] = 16383,
  [16414] = 16387,
  [16415] = 16387,
  [16416] = 16383,
  [16417] = 16384,
  [16418] = 16384,
  [16419] = 16387,
  [16420] = 16383,
  [16421] = 16385,
  [16422] = 16391,
  [16423] = 16384,
  [16424] = 16391,
  [16425] = 16383,
  [16426] = 16387,
  [16427] = 16384,
  [16428] = 16384,
  [16429] = 16387,
  [16430] = 16383,
  [16431] = 16387,
  [16432] = 16385,
  [16433] = 16384,
  [16434] = 16383,
  [16435] = 16385,
  [16436] = 16391,
  [16437] = 16384,
  [16438] = 16383,
  [16439] = 16387,
  [16440] = 16384,
  [16441] = 16385,
  [16442] = 16387,
  [16443] = 16383,
  [16444] = 16387,
  [16445] = 16383,
  [16446] = 16384,
  [16447] = 16391,
  [16448] = 16383,
  [16449] = 16387,
  [16450] = 16384,
  [16451] = 16385,
  [16452] = 16391,
  [16453] = 16384,
  [16454] = 16387,
  [16455] = 16383,
  [16456] = 16391,
  [16457] = 16383,
  [16458] = 16387,
  [16459] = 16384,
  [16460] = 16384,
  [16461] = 16385,
  [16462] = 16383,
  [16463] = 16387,
  [16464] = 16384,
  [16465] = 16384,
  [16466] = 16387,
  [16467] = 16384,
  [16468] = 16383,
  [16469] = 16385,
  [16470] = 16387,
  [16471] = 16383,
  [16472] = 16391,
  [16473] = 16383,
  [16474] = 16387,
  [16475] = 16387,
  [16476] = 16383,
  [16477] = 16385,
  [16478] = 16391,
  [16479] = 16383,
  [16480] = 16383,
  [16481] = 16387,
  [16482] = 16384,
  [16483] = 16387,
  [16484] = 16384,
  [16485] = 16385,
  [16486] = 16383,
  [16487] = 16384,
  [16488] = 16385,
  [16489] = 16384,
  [16490] = 16384,
  [16491] = 16387,
  [16492] = 16391,
  [16493] = 16383,
  [16494] = 16494,
  [16495] = 16383,
  [16496] = 16384,
  [16497] = 16387,
  [16498] = 16387,
  [16499] = 16383,
  [16500] = 16384,
  [16501] = 16385,
  [16502] = 16391,
  [16503] = 16387,
  [16504] = 16383,
  [16505] = 16505,
  [16506] = 16383,
  [16507] = 16387,
  [16508] = 16383,
  [16509] = 16387,
  [16510] = 16384,
  [16511] = 16384,
  [16512] = 16384,
  [16513] = 16385,
  [16514] = 16387,
  [16515] = 16383,
  [16516] = 16385,
  [16517] = 16384,
  [16518] = 16387,
  [16519] = 16391,
  [16520] = 16383,
  [16521] = 16384,
  [16522] = 16387,
  [16523] = 16383,
  [16524] = 16494,
  [16525] = 16505,
  [16526] = 16383,
  [16527] = 16387,
  [16528] = 16384,
  [16529] = 16387,
  [16530] = 16383,
  [16531] = 16384,
  [16532] = 16385,
  [16533] = 16385,
  [16534] = 16384,
  [16535] = 16387,
  [16536] = 16383,
  [16537] = 16387,
  [16538] = 16383,
  [16539] = 16384,
  [16540] = 16384,
  [16541] = 16384,
  [16542] = 16391,
  [16543] = 16384,
  [16544] = 16387,
  [16545] = 16387,
  [16546] = 16383,
  [16547] = 16383,
  [16548] = 16494,
  [16549] = 16505,
  [16550] = 16383,
  [16551] = 16387,
  [16552] = 16384,
  [16553] = 16387,
  [16554] = 16383,
  [16555] = 16384,
  [16556] = 16387,
  [16557] = 16383,
  [16558] = 16385,
  [16559] = 16559,
  [16560] = 16384,
  [16561] = 16391,
  [16562] = 16562,
  [16563] = 16563,
  [16564] = 16384,
  [16565] = 16383,
  [16566] = 16387,
  [16567] = 16567,
  [16568] = 16384,
  [16569] = 16387,
  [16570] = 16385,
  [16571] = 16494,
  [16572] = 16505,
  [16573] = 16383,
  [16574] = 16387,
  [16575] = 16384,
  [16576] = 5182,
  [16577] = 5185,
  [16578] = 5184,
  [16579] = 8390,
  [16580] = 8931,
  [16581] = 5646,
  [16582] = 8482,
  [16583] = 8491,
  [16584] = 8499,
  [16585] = 8522,
  [16586] = 16385,
  [16587] = 8584,
  [16588] = 5646,
  [16589] = 8651,
  [16590] = 8287,
  [16591] = 16383,
  [16592] = 16384,
  [16593] = 8714,
  [16594] = 16387,
  [16595] = 16387,
  [16596] = 16384,
  [16597] = 16383,
  [16598] = 8865,
  [16599] = 14687,
  [16600] = 14072,
  [16601] = 14687,
  [16602] = 14324,
  [16603] = 14553,
  [16604] = 14411,
  [16605] = 16605,
  [16606] = 16606,
  [16607] = 16607,
  [16608] = 14291,
  [16609] = 14591,
  [16610] = 16383,
  [16611] = 16611,
  [16612] = 16612,
  [16613] = 16613,
  [16614] = 16614,
  [16615] = 16615,
  [16616] = 16385,
  [16617] = 16617,
  [16618] = 16618,
  [16619] = 16619,
  [16620] = 16620,
  [16621] = 16621,
  [16622] = 5284,
  [16623] = 16384,
  [16624] = 16624,
  [16625] = 16625,
  [16626] = 16605,
  [16627] = 16383,
  [16628] = 16387,
  [16629] = 16387,
  [16630] = 16384,
  [16631] = 16383,
  [16632] = 16606,
  [16633] = 16607,
  [16634] = 16634,
  [16635] = 16635,
  [16636] = 16636,
  [16637] = 16637,
  [16638] = 5295,
  [16639] = 16639,
  [16640] = 16640,
  [16641] = 16641,
  [16642] = 16642,
  [16643] = 16643,
  [16644] = 16644,
  [16645] = 16645,
  [16646] = 16646,
  [16647] = 16385,
  [16648] = 5548,
  [16649] = 16385,
  [16650] = 16650,
  [16651] = 16384,
  [16652] = 16387,
  [16653] = 16383,
  [16654] = 16654,
  [16655] = 16655,
  [16656] = 16656,
  [16657] = 16657,
  [16658] = 5341,
  [16659] = 16611,
  [16660] = 16559,
  [16661] = 16383,
  [16662] = 16387,
  [16663] = 16385,
  [16664] = 16384,
  [16665] = 16391,
  [16666] = 16666,
  [16667] = 5540,
  [16668] = 5539,
  [16669] = 16562,
  [16670] = 16670,
  [16671] = 16671,
  [16672] = 16385,
  [16673] = 5396,
  [16674] = 16674,
  [16675] = 16383,
  [16676] = 16387,
  [16677] = 16567,
  [16678] = 16494,
  [16679] = 16505,
  [16680] = 16383,
  [16681] = 16387,
  [16682] = 5496,
  [16683] = 16384,
  [16684] = 16612,
  [16685] = 16685,
  [16686] = 16384,
  [16687] = 16563,
  [16688] = 16688,
  [16689] = 16688,
  [16690] = 16690,
  [16691] = 16691,
  [16692] = 16692,
  [16693] = 16693,
  [16694] = 16694,
  [16695] = 16688,
  [16696] = 16696,
  [16697] = 16697,
  [16698] = 16698,
  [16699] = 16699,
  [16700] = 16700,
  [16701] = 16701,
  [16702] = 16702,
  [16703] = 16703,
  [16704] = 16704,
  [16705] = 16705,
  [16706] = 16706,
  [16707] = 16707,
  [16708] = 16708,
  [16709] = 16709,
  [16710] = 16710,
  [16711] = 16693,
  [16712] = 16690,
  [16713] = 16688,
  [16714] = 16696,
  [16715] = 16697,
  [16716] = 16698,
  [16717] = 16691,
  [16718] = 16692,
  [16719] = 16700,
  [16720] = 16701,
  [16721] = 16694,
  [16722] = 16699,
  [16723] = 16702,
  [16724] = 16703,
  [16725] = 16691,
  [16726] = 16705,
  [16727] = 16706,
  [16728] = 16707,
  [16729] = 16708,
  [16730] = 16693,
  [16731] = 16705,
  [16732] = 16708,
  [16733] = 16688,
  [16734] = 16707,
  [16735] = 16696,
  [16736] = 16697,
  [16737] = 16698,
  [16738] = 16706,
  [16739] = 16701,
  [16740] = 16709,
  [16741] = 16710,
  [16742] = 16700,
  [16743] = 16701,
  [16744] = 16700,
  [16745] = 16690,
  [16746] = 16746,
  [16747] = 16694,
  [16748] = 16692,
  [16749] = 16704,
  [16750] = 16694,
  [16751] = 16703,
  [16752] = 16698,
  [16753] = 16699,
  [16754] = 16697,
  [16755] = 16696,
  [16756] = 16702,
  [16757] = 16688,
  [16758] = 16703,
  [16759] = 16704,
  [16760] = 16693,
  [16761] = 16746,
  [16762] = 16762,
  [16763] = 16688,
  [16764] = 16702,
  [16765] = 16696,
  [16766] = 16697,
  [16767] = 16698,
  [16768] = 16693,
  [16769] = 16705,
  [16770] = 16700,
  [16771] = 16701,
  [16772] = 16706,
  [16773] = 16707,
  [16774] = 16699,
  [16775] = 16694,
  [16776] = 16708,
  [16777] = 16704,
  [16778] = 16692,
  [16779] = 16691,
  [16780] = 16690,
  [16781] = 16709,
  [16782] = 16709,
  [16783] = 16710,
  [16784] = 16708,
  [16785] = 16690,
  [16786] = 16691,
  [16787] = 16693,
  [16788] = 16701,
  [16789] = 16692,
  [16790] = 16688,
  [16791] = 16700,
  [16792] = 16696,
  [16793] = 16697,
  [16794] = 16698,
  [16795] = 16707,
  [16796] = 16694,
  [16797] = 16700,
  [16798] = 16701,
  [16799] = 16698,
  [16800] = 16697,
  [16801] = 16699,
  [16802] = 16696,
  [16803] = 16688,
  [16804] = 16702,
  [16805] = 16705,
  [16806] = 16703,
  [16807] = 16704,
  [16808] = 16704,
  [16809] = 16762,
  [16810] = 16693,
  [16811] = 16705,
  [16812] = 16693,
  [16813] = 16706,
  [16814] = 16707,
  [16815] = 16688,
  [16816] = 16703,
  [16817] = 16696,
  [16818] = 16697,
  [16819] = 16698,
  [16820] = 16702,
  [16821] = 16699,
  [16822] = 16700,
  [16823] = 16701,
  [16824] = 16708,
  [16825] = 16692,
  [16826] = 16692,
  [16827] = 16691,
  [16828] = 16690,
  [16829] = 16709,
  [16830] = 16709,
  [16831] = 16710,
  [16832] = 16701,
  [16833] = 16690,
  [16834] = 16691,
  [16835] = 16700,
  [16836] = 16692,
  [16837] = 16693,
  [16838] = 16708,
  [16839] = 16694,
  [16840] = 16688,
  [16841] = 16707,
  [16842] = 16696,
  [16843] = 16697,
  [16844] = 16698,
  [16845] = 16698,
  [16846] = 16697,
  [16847] = 16700,
  [16848] = 16701,
  [16849] = 16699,
  [16850] = 16696,
  [16851] = 16688,
  [16852] = 16702,
  [16853] = 16706,
  [16854] = 16703,
  [16855] = 16704,
  [16856] = 16746,
  [16857] = 16762,
  [16858] = 16705,
  [16859] = 16705,
  [16860] = 16706,
  [16861] = 16707,
  [16862] = 16693,
  [16863] = 16693,
  [16864] = 16702,
  [16865] = 16702,
  [16866] = 16696,
  [16867] = 16697,
  [16868] = 16698,
  [16869] = 16708,
  [16870] = 16699,
  [16871] = 16700,
  [16872] = 16701,
  [16873] = 16694,
  [16874] = 16705,
  [16875] = 16691,
  [16876] = 16709,
  [16877] = 16690,
  [16878] = 16710,
  [16879] = 16709,
  [16880] = 16690,
  [16881] = 16691,
  [16882] = 16708,
  [16883] = 16692,
  [16884] = 16706,
  [16885] = 16694,
  [16886] = 16693,
  [16887] = 16701,
  [16888] = 16700,
  [16889] = 16688,
  [16890] = 16696,
  [16891] = 16697,
  [16892] = 16698,
  [16893] = 16699,
  [16894] = 16706,
  [16895] = 16700,
  [16896] = 16701,
  [16897] = 16705,
  [16898] = 16702,
  [16899] = 16702,
  [16900] = 16703,
  [16901] = 16704,
  [16902] = 16746,
  [16903] = 16762,
  [16904] = 16698,
  [16905] = 16705,
  [16906] = 16706,
  [16907] = 16707,
  [16908] = 16693,
  [16909] = 16697,
  [16910] = 16696,
  [16911] = 16688,
  [16912] = 16696,
  [16913] = 16697,
  [16914] = 16698,
  [16915] = 16708,
  [16916] = 16688,
  [16917] = 16700,
  [16918] = 16701,
  [16919] = 16699,
  [16920] = 16693,
  [16921] = 16694,
  [16922] = 16709,
  [16923] = 16692,
  [16924] = 16710,
  [16925] = 16691,
  [16926] = 16690,
  [16927] = 16691,
  [16928] = 16690,
  [16929] = 16692,
  [16930] = 16693,
  [16931] = 16709,
  [16932] = 16694,
  [16933] = 16688,
  [16934] = 16696,
  [16935] = 16697,
  [16936] = 16698,
  [16937] = 16708,
  [16938] = 16707,
  [16939] = 16700,
  [16940] = 16701,
  [16941] = 16699,
  [16942] = 16706,
  [16943] = 16705,
  [16944] = 16702,
  [16945] = 16702,
  [16946] = 16703,
  [16947] = 16704,
  [16948] = 16746,
  [16949] = 16762,
  [16950] = 16701,
  [16951] = 16705,
  [16952] = 16693,
  [16953] = 16706,
  [16954] = 16707,
  [16955] = 16688,
  [16956] = 16696,
  [16957] = 16697,
  [16958] = 16698,
  [16959] = 16700,
  [16960] = 16699,
  [16961] = 16700,
  [16962] = 16701,
  [16963] = 16708,
  [16964] = 16694,
  [16965] = 16698,
  [16966] = 16697,
  [16967] = 16696,
  [16968] = 16709,
  [16969] = 16688,
  [16970] = 16710,
  [16971] = 16706,
  [16972] = 16690,
  [16973] = 16691,
  [16974] = 16693,
  [16975] = 16692,
  [16976] = 16692,
  [16977] = 16688,
  [16978] = 16696,
  [16979] = 16697,
  [16980] = 16698,
  [16981] = 16693,
  [16982] = 16694,
  [16983] = 16700,
  [16984] = 16701,
  [16985] = 16691,
  [16986] = 16690,
  [16987] = 16699,
  [16988] = 16709,
  [16989] = 16708,
  [16990] = 16702,
  [16991] = 16707,
  [16992] = 16703,
  [16993] = 16704,
  [16994] = 16746,
  [16995] = 16762,
  [16996] = 16693,
  [16997] = 16706,
  [16998] = 16705,
  [16999] = 16688,
  [17000] = 16696,
  [17001] = 16697,
  [17002] = 16698,
  [17003] = 16706,
  [17004] = 16707,
  [17005] = 16700,
  [17006] = 16701,
  [17007] = 16702,
  [17008] = 16699,
  [17009] = 16708,
  [17010] = 16694,
  [17011] = 16701,
  [17012] = 16700,
  [17013] = 16692,
  [17014] = 16709,
  [17015] = 16691,
  [17016] = 16710,
  [17017] = 16707,
  [17018] = 16693,
  [17019] = 16690,
  [17020] = 16691,
  [17021] = 16688,
  [17022] = 16696,
  [17023] = 16697,
  [17024] = 16698,
  [17025] = 16698,
  [17026] = 16692,
  [17027] = 16700,
  [17028] = 16701,
  [17029] = 16697,
  [17030] = 16694,
  [17031] = 16696,
  [17032] = 16688,
  [17033] = 16699,
  [17034] = 16709,
  [17035] = 16693,
  [17036] = 16702,
  [17037] = 16690,
  [17038] = 16703,
  [17039] = 16704,
  [17040] = 16693,
  [17041] = 16746,
  [17042] = 16762,
  [17043] = 16688,
  [17044] = 16696,
  [17045] = 16697,
  [17046] = 16698,
  [17047] = 16708,
  [17048] = 16705,
  [17049] = 16700,
  [17050] = 16701,
  [17051] = 16706,
  [17052] = 16707,
  [17053] = 16707,
  [17054] = 16701,
  [17055] = 16708,
  [17056] = 16705,
  [17057] = 16702,
  [17058] = 16699,
  [17059] = 16694,
  [17060] = 16709,
  [17061] = 16699,
  [17062] = 16693,
  [17063] = 16710,
  [17064] = 16688,
  [17065] = 16696,
  [17066] = 16697,
  [17067] = 16698,
  [17068] = 16692,
  [17069] = 16690,
  [17070] = 16700,
  [17071] = 16701,
  [17072] = 16691,
  [17073] = 16691,
  [17074] = 16692,
  [17075] = 16690,
  [17076] = 16694,
  [17077] = 16701,
  [17078] = 16700,
  [17079] = 16699,
  [17080] = 16709,
  [17081] = 16698,
  [17082] = 16702,
  [17083] = 16693,
  [17084] = 16697,
  [17085] = 16688,
  [17086] = 16696,
  [17087] = 16697,
  [17088] = 16698,
  [17089] = 16696,
  [17090] = 16703,
  [17091] = 16700,
  [17092] = 16701,
  [17093] = 16704,
  [17094] = 16746,
  [17095] = 16762,
  [17096] = 16688,
  [17097] = 16705,
  [17098] = 16706,
  [17099] = 16707,
  [17100] = 16708,
  [17101] = 16693,
  [17102] = 16708,
  [17103] = 16707,
  [17104] = 16693,
  [17105] = 16706,
  [17106] = 16688,
  [17107] = 16696,
  [17108] = 16697,
  [17109] = 16698,
  [17110] = 16705,
  [17111] = 16702,
  [17112] = 16700,
  [17113] = 16701,
  [17114] = 16709,
  [17115] = 16699,
  [17116] = 16710,
  [17117] = 16694,
  [17118] = 16690,
  [17119] = 16691,
  [17120] = 16692,
  [17121] = 16692,
  [17122] = 16691,
  [17123] = 16694,
  [17124] = 16690,
  [17125] = 16693,
  [17126] = 16709,
  [17127] = 16688,
  [17128] = 16696,
  [17129] = 16697,
  [17130] = 16698,
  [17131] = 16746,
  [17132] = 16692,
  [17133] = 16700,
  [17134] = 16701,
  [17135] = 16700,
  [17136] = 16702,
  [17137] = 16708,
  [17138] = 16707,
  [17139] = 16703,
  [17140] = 16704,
  [17141] = 16690,
  [17142] = 16762,
  [17143] = 16706,
  [17144] = 16705,
  [17145] = 16706,
  [17146] = 16693,
  [17147] = 16707,
  [17148] = 16688,
  [17149] = 16696,
  [17150] = 16697,
  [17151] = 16698,
  [17152] = 16698,
  [17153] = 16697,
  [17154] = 16700,
  [17155] = 16701,
  [17156] = 16708,
  [17157] = 16696,
  [17158] = 16688,
  [17159] = 16705,
  [17160] = 16693,
  [17161] = 16709,
  [17162] = 16702,
  [17163] = 16710,
  [17164] = 16699,
  [17165] = 16690,
  [17166] = 16691,
  [17167] = 16693,
  [17168] = 16694,
  [17169] = 16688,
  [17170] = 16696,
  [17171] = 16697,
  [17172] = 16698,
  [17173] = 16692,
  [17174] = 16692,
  [17175] = 16700,
  [17176] = 16701,
  [17177] = 16694,
  [17178] = 16691,
  [17179] = 16690,
  [17180] = 16699,
  [17181] = 16709,
  [17182] = 16708,
  [17183] = 16702,
  [17184] = 16707,
  [17185] = 16706,
  [17186] = 16703,
  [17187] = 16704,
  [17188] = 16693,
  [17189] = 16746,
  [17190] = 16688,
  [17191] = 16696,
  [17192] = 16697,
  [17193] = 16698,
  [17194] = 16762,
  [17195] = 16701,
  [17196] = 16700,
  [17197] = 16701,
  [17198] = 16705,
  [17199] = 16706,
  [17200] = 16707,
  [17201] = 16700,
  [17202] = 16705,
  [17203] = 16708,
  [17204] = 16702,
  [17205] = 16699,
  [17206] = 16698,
  [17207] = 16697,
  [17208] = 16709,
  [17209] = 16693,
  [17210] = 16696,
  [17211] = 16688,
  [17212] = 16696,
  [17213] = 16697,
  [17214] = 16698,
  [17215] = 16710,
  [17216] = 16688,
  [17217] = 16700,
  [17218] = 16701,
  [17219] = 16694,
  [17220] = 16691,
  [17221] = 16693,
  [17222] = 16692,
  [17223] = 16692,
  [17224] = 16694,
  [17225] = 16691,
  [17226] = 16690,
  [17227] = 16699,
  [17228] = 16709,
  [17229] = 16708,
  [17230] = 16693,
  [17231] = 16702,
  [17232] = 16688,
  [17233] = 16696,
  [17234] = 16697,
  [17235] = 16698,
  [17236] = 16707,
  [17237] = 16706,
  [17238] = 16700,
  [17239] = 16701,
  [17240] = 16703,
  [17241] = 16704,
  [17242] = 16746,
  [17243] = 16762,
  [17244] = 16705,
  [17245] = 16705,
  [17246] = 16706,
  [17247] = 16707,
  [17248] = 16702,
  [17249] = 16701,
  [17250] = 16708,
  [17251] = 16693,
  [17252] = 16700,
  [17253] = 16688,
  [17254] = 16696,
  [17255] = 16697,
  [17256] = 16698,
  [17257] = 16694,
  [17258] = 16709,
  [17259] = 16700,
  [17260] = 16701,
  [17261] = 16698,
  [17262] = 16709,
  [17263] = 16697,
  [17264] = 16710,
  [17265] = 16696,
  [17266] = 16690,
  [17267] = 16691,
  [17268] = 16688,
  [17269] = 16692,
  [17270] = 16691,
  [17271] = 16694,
  [17272] = 16693,
  [17273] = 16693,
  [17274] = 16688,
  [17275] = 16696,
  [17276] = 16697,
  [17277] = 16698,
  [17278] = 16690,
  [17279] = 16699,
  [17280] = 16700,
  [17281] = 16701,
  [17282] = 16707,
  [17283] = 16708,
  [17284] = 16702,
  [17285] = 16707,
  [17286] = 16706,
  [17287] = 16703,
  [17288] = 16704,
  [17289] = 16746,
  [17290] = 16762,
  [17291] = 16705,
  [17292] = 16705,
  [17293] = 16693,
  [17294] = 16706,
  [17295] = 16688,
  [17296] = 16696,
  [17297] = 16697,
  [17298] = 16698,
  [17299] = 16707,
  [17300] = 16702,
  [17301] = 16701,
  [17302] = 16699,
  [17303] = 16708,
  [17304] = 16694,
  [17305] = 16692,
  [17306] = 16701,
  [17307] = 16700,
  [17308] = 16709,
  [17309] = 16691,
  [17310] = 16710,
  [17311] = 16690,
  [17312] = 16690,
  [17313] = 16693,
  [17314] = 16691,
  [17315] = 16688,
  [17316] = 16696,
  [17317] = 16697,
  [17318] = 16698,
  [17319] = 16699,
  [17320] = 16692,
  [17321] = 16701,
  [17322] = 16698,
  [17323] = 16694,
  [17324] = 16697,
  [17325] = 16696,
  [17326] = 16699,
  [17327] = 16688,
  [17328] = 16709,
  [17329] = 16702,
  [17330] = 16693,
  [17331] = 16708,
  [17332] = 16703,
  [17333] = 16693,
  [17334] = 16704,
  [17335] = 16688,
  [17336] = 16696,
  [17337] = 16697,
  [17338] = 16698,
  [17339] = 16746,
  [17340] = 16762,
  [17341] = 16701,
  [17342] = 16707,
  [17343] = 16705,
  [17344] = 16706,
  [17345] = 16707,
  [17346] = 16706,
  [17347] = 16705,
  [17348] = 16708,
  [17349] = 16702,
  [17350] = 16699,
  [17351] = 16694,
  [17352] = 16692,
  [17353] = 16709,
  [17354] = 16688,
  [17355] = 16696,
  [17356] = 16697,
  [17357] = 16698,
  [17358] = 16691,
  [17359] = 16710,
  [17360] = 16701,
  [17361] = 16690,
  [17362] = 16690,
  [17363] = 16691,
  [17364] = 16701,
  [17365] = 16692,
  [17366] = 16700,
  [17367] = 16694,
  [17368] = 16709,
  [17369] = 16708,
  [17370] = 16699,
  [17371] = 16698,
  [17372] = 16705,
  [17373] = 16688,
  [17374] = 16696,
  [17375] = 16697,
  [17376] = 16698,
  [17377] = 16702,
  [17378] = 16697,
  [17379] = 16701,
  [17380] = 16696,
  [17381] = 16703,
  [17382] = 16704,
  [17383] = 16746,
  [17384] = 16762,
  [17385] = 16688,
  [17386] = 16688,
  [17387] = 16706,
  [17388] = 16707,
  [17389] = 16693,
  [17390] = 16706,
  [17391] = 16708,
  [17392] = 16688,
  [17393] = 16696,
  [17394] = 16697,
  [17395] = 16698,
  [17396] = 16705,
  [17397] = 16702,
  [17398] = 16701,
  [17399] = 16699,
  [17400] = 16694,
  [17401] = 16709,
  [17402] = 16692,
  [17403] = 16710,
  [17404] = 16691,
  [17405] = 16690,
  [17406] = 16691,
  [17407] = 16690,
  [17408] = 16692,
  [17409] = 16709,
  [17410] = 16694,
  [17411] = 16688,
  [17412] = 16696,
  [17413] = 16697,
  [17414] = 16698,
  [17415] = 16708,
  [17416] = 16701,
  [17417] = 16701,
  [17418] = 16699,
  [17419] = 16700,
  [17420] = 16707,
  [17421] = 16702,
  [17422] = 16706,
  [17423] = 16705,
  [17424] = 16703,
  [17425] = 16704,
  [17426] = 16746,
  [17427] = 16762,
  [17428] = 16698,
  [17429] = 16705,
  [17430] = 16688,
  [17431] = 16696,
  [17432] = 16697,
  [17433] = 16698,
  [17434] = 16706,
  [17435] = 16707,
  [17436] = 16701,
  [17437] = 16697,
  [17438] = 16696,
  [17439] = 16708,
  [17440] = 16688,
  [17441] = 16702,
  [17442] = 16693,
  [17443] = 16699,
  [17444] = 16709,
  [17445] = 16694,
  [17446] = 16710,
  [17447] = 16699,
  [17448] = 16690,
  [17449] = 16688,
  [17450] = 16696,
  [17451] = 16697,
  [17452] = 16698,
  [17453] = 16701,
  [17454] = 16691,
  [17455] = 16692,
  [17456] = 16692,
  [17457] = 16691,
  [17458] = 16694,
  [17459] = 16690,
  [17460] = 16709,
  [17461] = 16699,
  [17462] = 16688,
  [17463] = 16696,
  [17464] = 16697,
  [17465] = 16698,
  [17466] = 16701,
  [17467] = 16708,
  [17468] = 16707,
  [17469] = 16702,
  [17470] = 16706,
  [17471] = 16705,
  [17472] = 16703,
  [17473] = 16704,
  [17474] = 16746,
  [17475] = 16688,
  [17476] = 16696,
  [17477] = 16697,
  [17478] = 16698,
  [17479] = 16701,
  [17480] = 16762,
  [17481] = 16701,
  [17482] = 16705,
  [17483] = 16706,
  [17484] = 16707,
  [17485] = 16700,
  [17486] = 16702,
  [17487] = 16708,
  [17488] = 16688,
  [17489] = 16696,
  [17490] = 16697,
  [17491] = 16698,
  [17492] = 16701,
  [17493] = 16699,
  [17494] = 16698,
  [17495] = 16697,
  [17496] = 16696,
  [17497] = 16709,
  [17498] = 16709,
  [17499] = 16710,
  [17500] = 16694,
  [17501] = 16688,
  [17502] = 16696,
  [17503] = 16697,
  [17504] = 16698,
  [17505] = 16701,
  [17506] = 16690,
  [17507] = 16691,
  [17508] = 16693,
  [17509] = 16692,
  [17510] = 16692,
  [17511] = 16694,
  [17512] = 16691,
  [17513] = 16690,
  [17514] = 16688,
  [17515] = 16696,
  [17516] = 16697,
  [17517] = 16698,
  [17518] = 16701,
  [17519] = 16706,
  [17520] = 16708,
  [17521] = 16707,
  [17522] = 16702,
  [17523] = 16706,
  [17524] = 16705,
  [17525] = 16703,
  [17526] = 16704,
  [17527] = 16688,
  [17528] = 16696,
  [17529] = 16697,
  [17530] = 16698,
  [17531] = 16701,
  [17532] = 16746,
  [17533] = 16762,
  [17534] = 16702,
  [17535] = 16705,
  [17536] = 16706,
  [17537] = 16707,
  [17538] = 16699,
  [17539] = 16701,
  [17540] = 16688,
  [17541] = 16696,
  [17542] = 16697,
  [17543] = 16698,
  [17544] = 16701,
  [17545] = 16708,
  [17546] = 16700,
  [17547] = 16694,
  [17548] = 16692,
  [17549] = 16691,
  [17550] = 16709,
  [17551] = 16698,
  [17552] = 16710,
  [17553] = 16688,
  [17554] = 16696,
  [17555] = 16697,
  [17556] = 16698,
  [17557] = 16701,
  [17558] = 16697,
  [17559] = 16690,
  [17560] = 16691,
  [17561] = 16696,
  [17562] = 16692,
  [17563] = 16688,
  [17564] = 16694,
  [17565] = 16690,
  [17566] = 16688,
  [17567] = 16696,
  [17568] = 16697,
  [17569] = 16698,
  [17570] = 16701,
  [17571] = 16693,
  [17572] = 16699,
  [17573] = 16709,
  [17574] = 16708,
  [17575] = 16702,
  [17576] = 16707,
  [17577] = 16706,
  [17578] = 16688,
  [17579] = 16696,
  [17580] = 16697,
  [17581] = 16698,
  [17582] = 16701,
  [17583] = 16703,
  [17584] = 16704,
  [17585] = 16746,
  [17586] = 16762,
  [17587] = 16705,
  [17588] = 16705,
  [17589] = 16706,
  [17590] = 16688,
  [17591] = 16696,
  [17592] = 16697,
  [17593] = 16698,
  [17594] = 16701,
  [17595] = 16707,
  [17596] = 16702,
  [17597] = 16699,
  [17598] = 16708,
  [17599] = 16694,
  [17600] = 16692,
  [17601] = 16691,
  [17602] = 16688,
  [17603] = 16696,
  [17604] = 16697,
  [17605] = 16698,
  [17606] = 16701,
  [17607] = 16701,
  [17608] = 16709,
  [17609] = 16690,
  [17610] = 16710,
  [17611] = 16705,
  [17612] = 16690,
  [17613] = 16709,
  [17614] = 16696,
  [17615] = 16697,
  [17616] = 16698,
  [17617] = 16701,
  [17618] = 16691,
  [17619] = 16700,
  [17620] = 16692,
  [17621] = 16709,
  [17622] = 16694,
  [17623] = 16698,
  [17624] = 16688,
  [17625] = 16696,
  [17626] = 16697,
  [17627] = 16698,
  [17628] = 16701,
  [17629] = 16697,
  [17630] = 16699,
  [17631] = 16696,
  [17632] = 16688,
  [17633] = 16702,
  [17634] = 16708,
  [17635] = 16701,
  [17636] = 16693,
  [17637] = 16703,
  [17638] = 16704,
  [17639] = 16746,
  [17640] = 16762,
  [17641] = 16707,
  [17642] = 16701,
  [17643] = 16709,
  [17644] = 16706,
  [17645] = 16707,
  [17646] = 16705,
  [17647] = 16702,
  [17648] = 16701,
  [17649] = 16708,
  [17650] = 16699,
  [17651] = 16694,
  [17652] = 16692,
  [17653] = 16691,
  [17654] = 16701,
  [17655] = 16709,
  [17656] = 16690,
  [17657] = 16710,
  [17658] = 16709,
  [17659] = 16690,
  [17660] = 16701,
  [17661] = 16691,
  [17662] = 16708,
  [17663] = 16692,
  [17664] = 16707,
  [17665] = 16694,
  [17666] = 16701,
  [17667] = 16706,
  [17668] = 16701,
  [17669] = 16705,
  [17670] = 16699,
  [17671] = 16700,
  [17672] = 16701,
  [17673] = 16702,
  [17674] = 16702,
  [17675] = 16699,
  [17676] = 16692,
  [17677] = 16703,
  [17678] = 16701,
  [17679] = 16704,
  [17680] = 16746,
  [17681] = 16762,
  [17682] = 16698,
  [17683] = 16705,
  [17684] = 16701,
  [17685] = 16706,
  [17686] = 16707,
  [17687] = 16697,
  [17688] = 16696,
  [17689] = 16688,
  [17690] = 16701,
  [17691] = 16708,
  [17692] = 16691,
  [17693] = 16690,
  [17694] = 17694,
  [17695] = 16693,
  [17696] = 16701,
  [17697] = 16709,
  [17698] = 16707,
  [17699] = 16710,
  [17700] = 16708,
  [17701] = 16690,
  [17702] = 16701,
  [17703] = 16691,
  [17704] = 16707,
  [17705] = 16692,
  [17706] = 16706,
  [17707] = 17707,
  [17708] = 16701,
  [17709] = 17709,
  [17710] = 16694,
  [17711] = 16705,
  [17712] = 16702,
  [17713] = 16699,
  [17714] = 16701,
  [17715] = 16699,
  [17716] = 16694,
  [17717] = 16692,
  [17718] = 16702,
  [17719] = 16691,
  [17720] = 16701,
  [17721] = 17721,
  [17722] = 16703,
  [17723] = 16704,
  [17724] = 16746,
  [17725] = 16762,
  [17726] = 16701,
  [17727] = 16690,
  [17728] = 16705,
  [17729] = 16706,
  [17730] = 16707,
  [17731] = 16694,
  [17732] = 16701,
  [17733] = 16709,
  [17734] = 16701,
  [17735] = 16708,
  [17736] = 16700,
  [17737] = 16708,
  [17738] = 16701,
  [17739] = 16707,
  [17740] = 16706,
  [17741] = 16705,
  [17742] = 16702,
  [17743] = 16699,
  [17744] = 16701,
  [17745] = 16709,
  [17746] = 16698,
  [17747] = 16710,
  [17748] = 16697,
  [17749] = 16694,
  [17750] = 16701,
  [17751] = 16696,
  [17752] = 16688,
  [17753] = 16690,
  [17754] = 16692,
  [17755] = 16691,
  [17756] = 16701,
  [17757] = 16691,
  [17758] = 17758,
  [17759] = 17694,
  [17760] = 16692,
  [17761] = 16690,
  [17762] = 16701,
  [17763] = 17707,
  [17764] = 17709,
  [17765] = 16693,
  [17766] = 16694,
  [17767] = 16709,
  [17768] = 16701,
  [17769] = 16708,
  [17770] = 16705,
  [17771] = 16699,
  [17772] = 16706,
  [17773] = 16705,
  [17774] = 16701,
  [17775] = 16702,
  [17776] = 16702,
  [17777] = 16699,
  [17778] = 16694,
  [17779] = 16703,
  [17780] = 16701,
  [17781] = 16704,
  [17782] = 16746,
  [17783] = 16762,
  [17784] = 16692,
  [17785] = 16705,
  [17786] = 16701,
  [17787] = 16706,
  [17788] = 16707,
  [17789] = 16691,
  [17790] = 16690,
  [17791] = 16709,
  [17792] = 16701,
  [17793] = 16708,
  [17794] = 16708,
  [17795] = 16707,
  [17796] = 16706,
  [17797] = 16705,
  [17798] = 16701,
  [17799] = 16702,
  [17800] = 16699,
  [17801] = 17721,
  [17802] = 16709,
  [17803] = 16694,
  [17804] = 16701,
  [17805] = 16710,
  [17806] = 16692,
  [17807] = 16691,
  [17808] = 16698,
  [17809] = 16690,
  [17810] = 16701,
  [17811] = 16697,
  [17812] = 16696,
  [17813] = 16701,
  [17814] = 16690,
  [17815] = 16709,
  [17816] = 16701,
  [17817] = 16700,
  [17818] = 16708,
  [17819] = 16707,
  [17820] = 16688,
  [17821] = 16691,
  [17822] = 16701,
  [17823] = 16706,
  [17824] = 16706,
  [17825] = 16702,
  [17826] = 16692,
  [17827] = 16699,
  [17828] = 16701,
  [17829] = 17707,
  [17830] = 17709,
  [17831] = 16694,
  [17832] = 16694,
  [17833] = 16692,
  [17834] = 16701,
  [17835] = 16691,
  [17836] = 16690,
  [17837] = 16709,
  [17838] = 16708,
  [17839] = 16707,
  [17840] = 16701,
  [17841] = 16706,
  [17842] = 17842,
  [17843] = 16699,
  [17844] = 17844,
  [17845] = 16705,
  [17846] = 16701,
  [17847] = 16702,
  [17848] = 16699,
  [17849] = 16702,
  [17850] = 16694,
  [17851] = 16692,
  [17852] = 16701,
  [17853] = 16703,
  [17854] = 16704,
  [17855] = 16746,
  [17856] = 16762,
  [17857] = 16698,
  [17858] = 16701,
  [17859] = 17859,
  [17860] = 16705,
  [17861] = 16706,
  [17862] = 16707,
  [17863] = 16697,
  [17864] = 16701,
  [17865] = 16691,
  [17866] = 16696,
  [17867] = 16690,
  [17868] = 16708,
  [17869] = 16688,
  [17870] = 16701,
  [17871] = 16709,
  [17872] = 16708,
  [17873] = 16707,
  [17874] = 16706,
  [17875] = 16705,
  [17876] = 16701,
  [17877] = 16702,
  [17878] = 16709,
  [17879] = 16699,
  [17880] = 16710,
  [17881] = 16694,
  [17882] = 16701,
  [17883] = 17758,
  [17884] = 16698,
  [17885] = 17694,
  [17886] = 16692,
  [17887] = 17887,
  [17888] = 16701,
  [17889] = 16697,
  [17890] = 16696,
  [17891] = 16693,
  [17892] = 16691,
  [17893] = 16690,
  [17894] = 16701,
  [17895] = 16709,
  [17896] = 16707,
  [17897] = 16690,
  [17898] = 17709,
  [17899] = 17899,
  [17900] = 16701,
  [17901] = 16702,
  [17902] = 16705,
  [17903] = 16702,
  [17904] = 16688,
  [17905] = 16691,
  [17906] = 16701,
  [17907] = 16699,
  [17908] = 17908,
  [17909] = 16694,
  [17910] = 16692,
  [17911] = 16691,
  [17912] = 16690,
  [17913] = 16709,
  [17914] = 16692,
  [17915] = 16708,
  [17916] = 17707,
  [17917] = 16707,
  [17918] = 16706,
  [17919] = 16694,
  [17920] = 16705,
  [17921] = 16702,
  [17922] = 16699,
  [17923] = 16694,
  [17924] = 16692,
  [17925] = 16691,
  [17926] = 16690,
  [17927] = 16708,
  [17928] = 17842,
  [17929] = 16699,
  [17930] = 17844,
  [17931] = 16707,
  [17932] = 17932,
  [17933] = 16702,
  [17934] = 17934,
  [17935] = 16699,
  [17936] = 17721,
  [17937] = 16692,
  [17938] = 16702,
  [17939] = 16691,
  [17940] = 16708,
  [17941] = 16708,
  [17942] = 16701,
  [17943] = 17943,
  [17944] = 16702,
  [17945] = 16700,
  [17946] = 16703,
  [17947] = 16704,
  [17948] = 16746,
  [17949] = 16762,
  [17950] = 16699,
  [17951] = 17859,
  [17952] = 17952,
  [17953] = 17953,
  [17954] = 16705,
  [17955] = 16706,
  [17956] = 16707,
  [17957] = 16692,
  [17958] = 16691,
  [17959] = 16708,
  [17960] = 16707,
  [17961] = 16699,
  [17962] = 16708,
  [17963] = 16699,
  [17964] = 16692,
  [17965] = 16691,
  [17966] = 16708,
  [17967] = 17967,
  [17968] = 16707,
  [17969] = 16702,
  [17970] = 16699,
  [17971] = 16692,
  [17972] = 16691,
  [17973] = 17973,
  [17974] = 16708,
  [17975] = 16709,
  [17976] = 16707,
  [17977] = 16701,
  [17978] = 16710,
  [17979] = 16702,
  [17980] = 17980,
  [17981] = 17973,
  [17982] = 17967,
  [17983] = 5496,
  [17984] = 17984,
  [17985] = 5284,
  [17986] = 5295,
  [17987] = 17934,
  [17988] = 16699,
  [17989] = 5341,
  [17990] = 16692,
  [17991] = 5396,
  [17992] = 5182,
  [17993] = 5185,
  [17994] = 5184,
  [17995] = 16691,
  [17996] = 16708,
  [17997] = 16707,
  [17998] = 8390,
  [17999] = 16692,
  [18000] = 8714,
  [18001] = 17980,
  [18002] = 8482,
  [18003] = 8491,
  [18004] = 16702,
  [18005] = 8499,
  [18006] = 16702,
  [18007] = 8522,
  [18008] = 8584,
  [18009] = 8865,
  [18010] = 8931,
  [18011] = 17980,
  [18012] = 16699,
  [18013] = 8651,
  [18014] = 16692,
  [18015] = 8287,
  [18016] = 16702,
  [18017] = 16692,
  [18018] = 16692,
  [18019] = 17980,
  [18020] = 16691,
  [18021] = 16702,
  [18022] = 16708,
  [18023] = 16691,
  [18024] = 16692,
  [18025] = 16707,
  [18026] = 17980,
  [18027] = 16708,
  [18028] = 16702,
  [18029] = 16708,
  [18030] = 16702,
  [18031] = 16699,
  [18032] = 16691,
  [18033] = 17980,
  [18034] = 16692,
  [18035] = 16699,
  [18036] = 16702,
  [18037] = 16708,
  [18038] = 16692,
  [18039] = 16691,
  [18040] = 17980,
  [18041] = 16691,
  [18042] = 16692,
  [18043] = 16707,
  [18044] = 16699,
  [18045] = 16702,
  [18046] = 16708,
  [18047] = 17980,
  [18048] = 16707,
  [18049] = 16708,
  [18050] = 16691,
  [18051] = 16692,
  [18052] = 16702,
  [18053] = 16699,
  [18054] = 17980,
  [18055] = 16702,
  [18056] = 16708,
  [18057] = 16699,
  [18058] = 16691,
  [18059] = 16692,
  [18060] = 16692,
  [18061] = 17980,
  [18062] = 16699,
  [18063] = 16702,
  [18064] = 16702,
  [18065] = 16691,
  [18066] = 16708,
  [18067] = 16691,
  [18068] = 17980,
  [18069] = 16692,
  [18070] = 16707,
  [18071] = 16699,
  [18072] = 16702,
  [18073] = 16708,
  [18074] = 16702,
  [18075] = 17980,
  [18076] = 16699,
  [18077] = 16691,
  [18078] = 16692,
  [18079] = 16699,
  [18080] = 16702,
  [18081] = 16708,
  [18082] = 17980,
  [18083] = 16692,
  [18084] = 16691,
  [18085] = 16691,
  [18086] = 16692,
  [18087] = 16708,
  [18088] = 16699,
  [18089] = 17980,
  [18090] = 16702,
  [18091] = 16708,
  [18092] = 16707,
  [18093] = 16702,
  [18094] = 16698,
  [18095] = 16691,
  [18096] = 17980,
  [18097] = 16692,
  [18098] = 16699,
  [18099] = 16699,
  [18100] = 16702,
  [18101] = 16708,
  [18102] = 16692,
  [18103] = 17980,
  [18104] = 16691,
  [18105] = 16708,
  [18106] = 16691,
  [18107] = 16692,
  [18108] = 16707,
  [18109] = 17887,
  [18110] = 17980,
  [18111] = 16699,
  [18112] = 16702,
  [18113] = 16702,
  [18114] = 16708,
  [18115] = 16699,
  [18116] = 17980,
  [18117] = 16692,
  [18118] = 16691,
  [18119] = 16691,
  [18120] = 16692,
  [18121] = 16708,
  [18122] = 17980,
  [18123] = 16699,
  [18124] = 16702,
  [18125] = 16707,
  [18126] = 16708,
  [18127] = 16697,
  [18128] = 17980,
  [18129] = 16702,
  [18130] = 16699,
  [18131] = 16692,
  [18132] = 16696,
  [18133] = 18133,
  [18134] = 17980,
  [18135] = 16691,
  [18136] = 16692,
  [18137] = 16691,
  [18138] = 16708,
  [18139] = 16699,
  [18140] = 17980,
  [18141] = 16702,
  [18142] = 16708,
  [18143] = 16702,
  [18144] = 16699,
  [18145] = 16692,
  [18146] = 17980,
  [18147] = 16691,
  [18148] = 16692,
  [18149] = 16691,
  [18150] = 16699,
  [18151] = 16702,
  [18152] = 17980,
  [18153] = 16708,
  [18154] = 16690,
  [18155] = 16691,
  [18156] = 16699,
  [18157] = 16692,
  [18158] = 17980,
  [18159] = 16691,
  [18160] = 16692,
  [18161] = 16708,
  [18162] = 16708,
  [18163] = 16699,
  [18164] = 17980,
  [18165] = 16702,
  [18166] = 16708,
  [18167] = 16702,
  [18168] = 16699,
  [18169] = 18169,
  [18170] = 17980,
  [18171] = 16692,
  [18172] = 16691,
  [18173] = 16692,
  [18174] = 16691,
  [18175] = 16708,
  [18176] = 17980,
  [18177] = 16699,
  [18178] = 16702,
  [18179] = 16708,
  [18180] = 17899,
  [18181] = 18181,
  [18182] = 17980,
  [18183] = 16702,
  [18184] = 16699,
  [18185] = 16692,
  [18186] = 16691,
  [18187] = 16692,
  [18188] = 17980,
  [18189] = 16691,
  [18190] = 16708,
  [18191] = 16699,
  [18192] = 16702,
  [18193] = 16708,
  [18194] = 17980,
  [18195] = 16702,
  [18196] = 16699,
  [18197] = 16692,
  [18198] = 16691,
  [18199] = 16692,
  [18200] = 17980,
  [18201] = 16691,
  [18202] = 16708,
  [18203] = 16699,
  [18204] = 16702,
  [18205] = 16708,
  [18206] = 17980,
  [18207] = 16708,
  [18208] = 16702,
  [18209] = 16699,
  [18210] = 16692,
  [18211] = 16688,
  [18212] = 17980,
  [18213] = 16691,
  [18214] = 18214,
  [18215] = 16692,
  [18216] = 18216,
  [18217] = 18217,
  [18218] = 17980,
  [18219] = 16691,
  [18220] = 16708,
  [18221] = 16699,
  [18222] = 16691,
  [18223] = 16702,
  [18224] = 17980,
  [18225] = 16708,
  [18226] = 16702,
  [18227] = 16699,
  [18228] = 16692,
  [18229] = 17908,
  [18230] = 17980,
  [18231] = 16691,
  [18232] = 16692,
  [18233] = 16691,
  [18234] = 16708,
  [18235] = 16699,
  [18236] = 17980,
  [18237] = 16702,
  [18238] = 16692,
  [18239] = 16708,
  [18240] = 16702,
  [18241] = 16699,
  [18242] = 17980,
  [18243] = 16692,
  [18244] = 16691,
  [18245] = 16692,
  [18246] = 16691,
  [18247] = 16699,
  [18248] = 17980,
  [18249] = 16702,
  [18250] = 16708,
  [18251] = 16702,
  [18252] = 16699,
  [18253] = 16692,
  [18254] = 17980,
  [18255] = 16691,
  [18256] = 16692,
  [18257] = 16692,
  [18258] = 16691,
  [18259] = 17707,
  [18260] = 17980,
  [18261] = 16691,
  [18262] = 17709,
  [18263] = 16699,
  [18264] = 16702,
  [18265] = 16708,
  [18266] = 17980,
  [18267] = 16702,
  [18268] = 16699,
  [18269] = 16692,
  [18270] = 16691,
  [18271] = 16692,
  [18272] = 17980,
  [18273] = 16691,
  [18274] = 16708,
  [18275] = 16699,
  [18276] = 16702,
  [18277] = 16708,
  [18278] = 17980,
  [18279] = 16702,
  [18280] = 16699,
  [18281] = 16692,
  [18282] = 16702,
  [18283] = 16692,
  [18284] = 17980,
  [18285] = 16691,
  [18286] = 17932,
  [18287] = 16708,
  [18288] = 16699,
  [18289] = 16694,
  [18290] = 17980,
  [18291] = 16702,
  [18292] = 16708,
  [18293] = 16702,
  [18294] = 16699,
  [18295] = 16692,
  [18296] = 17980,
  [18297] = 16691,
  [18298] = 16692,
  [18299] = 16691,
  [18300] = 16708,
  [18301] = 18301,
  [18302] = 17980,
  [18303] = 16699,
  [18304] = 16702,
  [18305] = 16708,
  [18306] = 16702,
  [18307] = 16699,
  [18308] = 17980,
  [18309] = 16692,
  [18310] = 16691,
  [18311] = 16692,
  [18312] = 16691,
  [18313] = 16708,
  [18314] = 17980,
  [18315] = 16699,
  [18316] = 16702,
  [18317] = 16708,
  [18318] = 16702,
  [18319] = 16699,
  [18320] = 17980,
  [18321] = 16692,
  [18322] = 16691,
  [18323] = 16692,
  [18324] = 16691,
  [18325] = 16708,
  [18326] = 17980,
  [18327] = 16699,
  [18328] = 18328,
  [18329] = 16702,
  [18330] = 16708,
  [18331] = 17842,
  [18332] = 17980,
  [18333] = 16702,
  [18334] = 18334,
  [18335] = 16699,
  [18336] = 18336,
  [18337] = 16699,
  [18338] = 17980,
  [18339] = 16692,
  [18340] = 16691,
  [18341] = 16692,
  [18342] = 17844,
  [18343] = 17980,
  [18344] = 16691,
  [18345] = 16708,
  [18346] = 16699,
  [18347] = 17758,
  [18348] = 17980,
  [18349] = 16702,
  [18350] = 16708,
  [18351] = 16708,
  [18352] = 16702,
  [18353] = 17980,
  [18354] = 16699,
  [18355] = 17694,
  [18356] = 16692,
  [18357] = 18357,
  [18358] = 17980,
  [18359] = 16691,
  [18360] = 17934,
  [18361] = 16692,
  [18362] = 16691,
  [18363] = 17980,
  [18364] = 16708,
  [18365] = 16699,
  [18366] = 16702,
  [18367] = 16708,
  [18368] = 17980,
  [18369] = 16702,
  [18370] = 16699,
  [18371] = 16692,
  [18372] = 16691,
  [18373] = 17980,
  [18374] = 16692,
  [18375] = 16693,
  [18376] = 16691,
  [18377] = 16702,
  [18378] = 17980,
  [18379] = 16708,
  [18380] = 16699,
  [18381] = 16702,
  [18382] = 16708,
  [18383] = 17980,
  [18384] = 16702,
  [18385] = 16699,
  [18386] = 16692,
  [18387] = 16691,
  [18388] = 17980,
  [18389] = 16692,
  [18390] = 16691,
  [18391] = 16708,
  [18392] = 16699,
  [18393] = 17980,
  [18394] = 16702,
  [18395] = 16708,
  [18396] = 16702,
  [18397] = 16699,
  [18398] = 17980,
  [18399] = 16692,
  [18400] = 16703,
  [18401] = 16691,
  [18402] = 16704,
  [18403] = 17980,
  [18404] = 16692,
  [18405] = 16746,
  [18406] = 16691,
  [18407] = 16762,
  [18408] = 17980,
  [18409] = 16699,
  [18410] = 17953,
  [18411] = 16699,
  [18412] = 16708,
  [18413] = 17980,
  [18414] = 17980,
  [18415] = 17980,
  [18416] = 17980,
  [18417] = 17980,
  [18418] = 17980,
  [18419] = 17980,
  [18420] = 17980,
  [18421] = 17980,
  [18422] = 17980,
  [18423] = 17980,
  [18424] = 17980,
  [18425] = 17980,
  [18426] = 17980,
  [18427] = 17980,
  [18428] = 17980,
  [18429] = 17980,
  [18430] = 17980,
  [18431] = 17980,
  [18432] = 17980,
  [18433] = 17980,
  [18434] = 17980,
  [18435] = 17980,
  [18436] = 17980,
  [18437] = 17980,
  [18438] = 17980,
  [18439] = 17980,
  [18440] = 17980,
  [18441] = 17980,
  [18442] = 17980,
  [18443] = 17980,
  [18444] = 17980,
  [18445] = 17980,
  [18446] = 17980,
  [18447] = 17980,
  [18448] = 17980,
  [18449] = 17980,
  [18450] = 17980,
  [18451] = 17980,
  [18452] = 17980,
  [18453] = 17980,
  [18454] = 17980,
  [18455] = 17980,
  [18456] = 17980,
  [18457] = 17980,
  [18458] = 17980,
  [18459] = 17980,
  [18460] = 17980,
  [18461] = 17980,
  [18462] = 17980,
  [18463] = 17980,
  [18464] = 17980,
  [18465] = 17980,
  [18466] = 17980,
  [18467] = 17980,
  [18468] = 17980,
  [18469] = 16702,
  [18470] = 17859,
  [18471] = 18471,
  [18472] = 18472,
  [18473] = 17952,
  [18474] = 17984,
  [18475] = 16705,
  [18476] = 16706,
  [18477] = 16707,
  [18478] = 5908,
  [18479] = 16699,
  [18480] = 16692,
  [18481] = 16691,
  [18482] = 16692,
  [18483] = 16691,
  [18484] = 16708,
  [18485] = 16699,
  [18486] = 16702,
  [18487] = 16702,
  [18488] = 18488,
  [18489] = 16708,
  [18490] = 16708,
  [18491] = 16699,
  [18492] = 16692,
  [18493] = 16691,
  [18494] = 16709,
  [18495] = 16691,
  [18496] = 16692,
  [18497] = 16691,
  [18498] = 18498,
  [18499] = 16708,
  [18500] = 16699,
  [18501] = 16702,
  [18502] = 16702,
  [18503] = 17967,
  [18504] = 18504,
  [18505] = 16699,
  [18506] = 16708,
  [18507] = 16692,
  [18508] = 16691,
  [18509] = 16708,
  [18510] = 18510,
  [18511] = 16691,
  [18512] = 17980,
  [18513] = 16692,
  [18514] = 17721,
  [18515] = 16699,
  [18516] = 18516,
  [18517] = 16702,
  [18518] = 16701,
  [18519] = 5861,
  [18520] = 16708,
  [18521] = 17943,
  [18522] = 16708,
  [18523] = 8390,
  [18524] = 16691,
  [18525] = 16710,
  [18526] = 16692,
  [18527] = 18527,
  [18528] = 16699,
  [18529] = 18529,
  [18530] = 16708,
  [18531] = 16700,
  [18532] = 16702,
  [18533] = 17973,
  [18534] = 18534,
  [18535] = 18535,
  [18536] = 18536,
  [18537] = 18537,
};

static inline bool sym__alpha_identifier_character_set_1(int32_t c) {
  return (c < 6823
    ? (c < 2990
      ? (c < 2384
        ? (c < 1519
          ? (c < 886
            ? (c < 216
              ? (c < 181
                ? (c < '_'
                  ? (c >= 'A' && c <= 'Z')
                  : (c <= 'z' || c == 170))
                : (c <= 181 || (c < 192
                  ? (c >= 186 && c <= 187)
                  : c <= 214)))
              : (c <= 246 || (c < 748
                ? (c < 710
                  ? (c >= 248 && c <= 705)
                  : (c <= 721 || (c >= 736 && c <= 740)))
                : (c <= 748 || (c < 880
                  ? c == 750
                  : c <= 884)))))
            : (c <= 887 || (c < 931
              ? (c < 904
                ? (c < 895
                  ? (c >= 890 && c <= 893)
                  : (c <= 895 || c == 902))
                : (c <= 906 || (c < 910
                  ? c == 908
                  : c <= 929)))
              : (c <= 1013 || (c < 1369
                ? (c < 1162
                  ? (c >= 1015 && c <= 1153)
                  : (c <= 1327 || (c >= 1329 && c <= 1366)))
                : (c <= 1369 || (c < 1488
                  ? (c >= 1376 && c <= 1416)
                  : c <= 1514)))))))
          : (c <= 1522 || (c < 2036
            ? (c < 1786
              ? (c < 1749
                ? (c < 1646
                  ? (c >= 1568 && c <= 1610)
                  : (c <= 1647 || (c >= 1649 && c <= 1747)))
                : (c <= 1749 || (c < 1774
                  ? (c >= 1765 && c <= 1766)
                  : c <= 1775)))
              : (c <= 1788 || (c < 1869
                ? (c < 1808
                  ? c == 1791
                  : (c <= 1808 || (c >= 1810 && c <= 1839)))
                : (c <= 1957 || (c < 1994
                  ? c == 1969
                  : c <= 2026)))))
            : (c <= 2037 || (c < 2144
              ? (c < 2084
                ? (c < 2048
                  ? c == 2042
                  : (c <= 2069 || c == 2074))
                : (c <= 2084 || (c < 2112
                  ? c == 2088
                  : c <= 2136)))
              : (c <= 2154 || (c < 2208
                ? (c < 2185
                  ? (c >= 2160 && c <= 2183)
                  : c <= 2190)
                : (c <= 2249 || (c < 2365
                  ? (c >= 2308 && c <= 2361)
                  : c <= 2365)))))))))
        : (c <= 2384 || (c < 2707
          ? (c < 2556
            ? (c < 2482
              ? (c < 2447
                ? (c < 2417
                  ? (c >= 2392 && c <= 2401)
                  : (c <= 2432 || (c >= 2437 && c <= 2444)))
                : (c <= 2448 || (c < 2474
                  ? (c >= 2451 && c <= 2472)
                  : c <= 2480)))
              : (c <= 2482 || (c < 2524
                ? (c < 2493
                  ? (c >= 2486 && c <= 2489)
                  : (c <= 2493 || c == 2510))
                : (c <= 2525 || (c < 2544
                  ? (c >= 2527 && c <= 2529)
                  : c <= 2545)))))
            : (c <= 2556 || (c < 2616
              ? (c < 2602
                ? (c < 2575
                  ? (c >= 2565 && c <= 2570)
                  : (c <= 2576 || (c >= 2579 && c <= 2600)))
                : (c <= 2608 || (c < 2613
                  ? (c >= 2610 && c <= 2611)
                  : c <= 2614)))
              : (c <= 2617 || (c < 2674
                ? (c < 2654
                  ? (c >= 2649 && c <= 2652)
                  : c <= 2654)
                : (c <= 2676 || (c < 2703
                  ? (c >= 2693 && c <= 2701)
                  : c <= 2705)))))))
          : (c <= 2728 || (c < 2877
            ? (c < 2809
              ? (c < 2749
                ? (c < 2738
                  ? (c >= 2730 && c <= 2736)
                  : (c <= 2739 || (c >= 2741 && c <= 2745)))
                : (c <= 2749 || (c < 2784
                  ? c == 2768
                  : c <= 2785)))
              : (c <= 2809 || (c < 2858
                ? (c < 2831
                  ? (c >= 2821 && c <= 2828)
                  : (c <= 2832 || (c >= 2835 && c <= 2856)))
                : (c <= 2864 || (c < 2869
                  ? (c >= 2866 && c <= 2867)
                  : c <= 2873)))))
            : (c <= 2877 || (c < 2962
              ? (c < 2947
                ? (c < 2911
                  ? (c >= 2908 && c <= 2909)
                  : (c <= 2913 || c == 2929))
                : (c <= 2947 || (c < 2958
                  ? (c >= 2949 && c <= 2954)
                  : c <= 2960)))
              : (c <= 2965 || (c < 2974
                ? (c < 2972
                  ? (c >= 2969 && c <= 2970)
                  : c <= 2972)
                : (c <= 2975 || (c < 2984
                  ? (c >= 2979 && c <= 2980)
                  : c <= 2986)))))))))))
      : (c <= 3001 || (c < 4186
        ? (c < 3450
          ? (c < 3242
            ? (c < 3160
              ? (c < 3090
                ? (c < 3077
                  ? c == 3024
                  : (c <= 3084 || (c >= 3086 && c <= 3088)))
                : (c <= 3112 || (c < 3133
                  ? (c >= 3114 && c <= 3129)
                  : c <= 3133)))
              : (c <= 3162 || (c < 3205
                ? (c < 3168
                  ? c == 3165
                  : (c <= 3169 || c == 3200))
                : (c <= 3212 || (c < 3218
                  ? (c >= 3214 && c <= 3216)
                  : c <= 3240)))))
            : (c <= 3251 || (c < 3342
              ? (c < 3296
                ? (c < 3261
                  ? (c >= 3253 && c <= 3257)
                  : (c <= 3261 || (c >= 3293 && c <= 3294)))
                : (c <= 3297 || (c < 3332
                  ? (c >= 3313 && c <= 3314)
                  : c <= 3340)))
              : (c <= 3344 || (c < 3406
                ? (c < 3389
                  ? (c >= 3346 && c <= 3386)
                  : c <= 3389)
                : (c <= 3406 || (c < 3423
                  ? (c >= 3412 && c <= 3414)
                  : c <= 3425)))))))
          : (c <= 3455 || (c < 3751
            ? (c < 3634
              ? (c < 3517
                ? (c < 3482
                  ? (c >= 3461 && c <= 3478)
                  : (c <= 3505 || (c >= 3507 && c <= 3515)))
                : (c <= 3517 || (c < 3585
                  ? (c >= 3520 && c <= 3526)
                  : c <= 3632)))
              : (c <= 3635 || (c < 3718
                ? (c < 3713
                  ? (c >= 3648 && c <= 3654)
                  : (c <= 3714 || c == 3716))
                : (c <= 3722 || (c < 3749
                  ? (c >= 3724 && c <= 3747)
                  : c <= 3749)))))
            : (c <= 3760 || (c < 3904
              ? (c < 3782
                ? (c < 3773
                  ? (c >= 3762 && c <= 3763)
                  : (c <= 3773 || (c >= 3776 && c <= 3780)))
                : (c <= 3782 || (c < 3840
                  ? (c >= 3804 && c <= 3807)
                  : c <= 3840)))
              : (c <= 3911 || (c < 4096
                ? (c < 3976
                  ? (c >= 3913 && c <= 3948)
                  : c <= 3980)
                : (c <= 4138 || (c < 4176
                  ? c == 4159
                  : c <= 4181)))))))))
        : (c <= 4189 || (c < 5024
          ? (c < 4698
            ? (c < 4295
              ? (c < 4213
                ? (c < 4197
                  ? c == 4193
                  : (c <= 4198 || (c >= 4206 && c <= 4208)))
                : (c <= 4225 || (c < 4256
                  ? c == 4238
                  : c <= 4293)))
              : (c <= 4295 || (c < 4682
                ? (c < 4304
                  ? c == 4301
                  : (c <= 4346 || (c >= 4348 && c <= 4680)))
                : (c <= 4685 || (c < 4696
                  ? (c >= 4688 && c <= 4694)
                  : c <= 4696)))))
            : (c <= 4701 || (c < 4802
              ? (c < 4786
                ? (c < 4746
                  ? (c >= 4704 && c <= 4744)
                  : (c <= 4749 || (c >= 4752 && c <= 4784)))
                : (c <= 4789 || (c < 4800
                  ? (c >= 4792 && c <= 4798)
                  : c <= 4800)))
              : (c <= 4805 || (c < 4882
                ? (c < 4824
                  ? (c >= 4808 && c <= 4822)
                  : c <= 4880)
                : (c <= 4885 || (c < 4992
                  ? (c >= 4888 && c <= 4954)
                  : c <= 5007)))))))
          : (c <= 5109 || (c < 6108
            ? (c < 5888
              ? (c < 5761
                ? (c < 5121
                  ? (c >= 5112 && c <= 5117)
                  : (c <= 5740 || (c >= 5743 && c <= 5759)))
                : (c <= 5786 || (c < 5870
                  ? (c >= 5792 && c <= 5866)
                  : c <= 5880)))
              : (c <= 5905 || (c < 5998
                ? (c < 5952
                  ? (c >= 5919 && c <= 5937)
                  : (c <= 5969 || (c >= 5984 && c <= 5996)))
                : (c <= 6000 || (c < 6103
                  ? (c >= 6016 && c <= 6067)
                  : c <= 6103)))))
            : (c <= 6108 || (c < 6480
              ? (c < 6314
                ? (c < 6272
                  ? (c >= 6176 && c <= 6264)
                  : (c <= 6276 || (c >= 6279 && c <= 6312)))
                : (c <= 6314 || (c < 6400
                  ? (c >= 6320 && c <= 6389)
                  : c <= 6430)))
              : (c <= 6509 || (c < 6576
                ? (c < 6528
                  ? (c >= 6512 && c <= 6516)
                  : c <= 6571)
                : (c <= 6601 || (c < 6688
                  ? (c >= 6656 && c <= 6678)
                  : c <= 6740)))))))))))))
    : (c <= 6823 || (c < 43261
      ? (c < 11499
        ? (c < 8118
          ? (c < 7413
            ? (c < 7245
              ? (c < 7086
                ? (c < 6981
                  ? (c >= 6917 && c <= 6963)
                  : (c <= 6988 || (c >= 7043 && c <= 7072)))
                : (c <= 7087 || (c < 7168
                  ? (c >= 7098 && c <= 7141)
                  : c <= 7203)))
              : (c <= 7247 || (c < 7357
                ? (c < 7296
                  ? (c >= 7258 && c <= 7293)
                  : (c <= 7304 || (c >= 7312 && c <= 7354)))
                : (c <= 7359 || (c < 7406
                  ? (c >= 7401 && c <= 7404)
                  : c <= 7411)))))
            : (c <= 7414 || (c < 8016
              ? (c < 7960
                ? (c < 7424
                  ? c == 7418
                  : (c <= 7615 || (c >= 7680 && c <= 7957)))
                : (c <= 7965 || (c < 8008
                  ? (c >= 7968 && c <= 8005)
                  : c <= 8013)))
              : (c <= 8023 || (c < 8029
                ? (c < 8027
                  ? c == 8025
                  : c <= 8027)
                : (c <= 8029 || (c < 8064
                  ? (c >= 8031 && c <= 8061)
                  : c <= 8116)))))))
          : (c <= 8124 || (c < 8458
            ? (c < 8178
              ? (c < 8144
                ? (c < 8130
                  ? c == 8126
                  : (c <= 8132 || (c >= 8134 && c <= 8140)))
                : (c <= 8147 || (c < 8160
                  ? (c >= 8150 && c <= 8155)
                  : c <= 8172)))
              : (c <= 8180 || (c < 8336
                ? (c < 8305
                  ? (c >= 8182 && c <= 8188)
                  : (c <= 8305 || c == 8319))
                : (c <= 8348 || (c < 8455
                  ? c == 8450
                  : c <= 8455)))))
            : (c <= 8467 || (c < 8495
              ? (c < 8486
                ? (c < 8473
                  ? c == 8469
                  : (c <= 8477 || c == 8484))
                : (c <= 8486 || (c < 8490
                  ? c == 8488
                  : c <= 8493)))
              : (c <= 8505 || (c < 8526
                ? (c < 8517
                  ? (c >= 8508 && c <= 8511)
                  : c <= 8521)
                : (c <= 8526 || (c < 11264
                  ? (c >= 8544 && c <= 8584)
                  : c <= 11492)))))))))
        : (c <= 11502 || (c < 12704
          ? (c < 11728
            ? (c < 11648
              ? (c < 11565
                ? (c < 11520
                  ? (c >= 11506 && c <= 11507)
                  : (c <= 11557 || c == 11559))
                : (c <= 11565 || (c < 11631
                  ? (c >= 11568 && c <= 11623)
                  : c <= 11631)))
              : (c <= 11670 || (c < 11704
                ? (c < 11688
                  ? (c >= 11680 && c <= 11686)
                  : (c <= 11694 || (c >= 11696 && c <= 11702)))
                : (c <= 11710 || (c < 11720
                  ? (c >= 11712 && c <= 11718)
                  : c <= 11726)))))
            : (c <= 11734 || (c < 12353
              ? (c < 12321
                ? (c < 11823
                  ? (c >= 11736 && c <= 11742)
                  : (c <= 11823 || (c >= 12293 && c <= 12295)))
                : (c <= 12329 || (c < 12344
                  ? (c >= 12337 && c <= 12341)
                  : c <= 12348)))
              : (c <= 12438 || (c < 12540
                ? (c < 12449
                  ? (c >= 12445 && c <= 12447)
                  : c <= 12538)
                : (c <= 12543 || (c < 12593
                  ? (c >= 12549 && c <= 12591)
                  : c <= 12686)))))))
          : (c <= 12735 || (c < 42786
            ? (c < 42240
              ? (c < 19968
                ? (c < 13312
                  ? (c >= 12784 && c <= 12799)
                  : (c <= 13312 || c == 19903))
                : (c <= 19968 || (c < 42192
                  ? (c >= 40959 && c <= 42124)
                  : c <= 42237)))
              : (c <= 42508 || (c < 42623
                ? (c < 42538
                  ? (c >= 42512 && c <= 42527)
                  : (c <= 42539 || (c >= 42560 && c <= 42606)))
                : (c <= 42653 || (c < 42775
                  ? (c >= 42656 && c <= 42735)
                  : c <= 42783)))))
            : (c <= 42888 || (c < 43015
              ? (c < 42965
                ? (c < 42960
                  ? (c >= 42891 && c <= 42954)
                  : (c <= 42961 || c == 42963))
                : (c <= 42969 || (c < 43011
                  ? (c >= 42994 && c <= 43009)
                  : c <= 43013)))
              : (c <= 43018 || (c < 43138
                ? (c < 43072
                  ? (c >= 43020 && c <= 43042)
                  : c <= 43123)
                : (c <= 43187 || (c < 43259
                  ? (c >= 43250 && c <= 43255)
                  : c <= 43259)))))))))))
      : (c <= 43262 || (c < 65345
        ? (c < 43816
          ? (c < 43646
            ? (c < 43494
              ? (c < 43396
                ? (c < 43312
                  ? (c >= 43274 && c <= 43301)
                  : (c <= 43334 || (c >= 43360 && c <= 43388)))
                : (c <= 43442 || (c < 43488
                  ? c == 43471
                  : c <= 43492)))
              : (c <= 43503 || (c < 43588
                ? (c < 43520
                  ? (c >= 43514 && c <= 43518)
                  : (c <= 43560 || (c >= 43584 && c <= 43586)))
                : (c <= 43595 || (c < 43642
                  ? (c >= 43616 && c <= 43638)
                  : c <= 43642)))))
            : (c <= 43695 || (c < 43744
              ? (c < 43712
                ? (c < 43701
                  ? c == 43697
                  : (c <= 43702 || (c >= 43705 && c <= 43709)))
                : (c <= 43712 || (c < 43739
                  ? c == 43714
                  : c <= 43741)))
              : (c <= 43754 || (c < 43785
                ? (c < 43777
                  ? (c >= 43762 && c <= 43764)
                  : c <= 43782)
                : (c <= 43790 || (c < 43808
                  ? (c >= 43793 && c <= 43798)
                  : c <= 43814)))))))
          : (c <= 43822 || (c < 64298
            ? (c < 55243
              ? (c < 44032
                ? (c < 43868
                  ? (c >= 43824 && c <= 43866)
                  : (c <= 43881 || (c >= 43888 && c <= 44002)))
                : (c <= 44032 || (c < 55216
                  ? c == 55203
                  : c <= 55238)))
              : (c <= 55291 || (c < 64275
                ? (c < 64112
                  ? (c >= 63744 && c <= 64109)
                  : (c <= 64217 || (c >= 64256 && c <= 64262)))
                : (c <= 64279 || (c < 64287
                  ? c == 64285
                  : c <= 64296)))))
            : (c <= 64310 || (c < 64848
              ? (c < 64323
                ? (c < 64318
                  ? (c >= 64312 && c <= 64316)
                  : (c <= 64318 || (c >= 64320 && c <= 64321)))
                : (c <= 64324 || (c < 64467
                  ? (c >= 64326 && c <= 64433)
                  : c <= 64829)))
              : (c <= 64911 || (c < 65136
                ? (c < 65008
                  ? (c >= 64914 && c <= 64967)
                  : c <= 65019)
                : (c <= 65140 || (c < 65313
                  ? (c >= 65142 && c <= 65276)
                  : c <= 65338)))))))))
        : (c <= 65370 || (c < 66864
          ? (c < 66176
            ? (c < 65549
              ? (c < 65490
                ? (c < 65474
                  ? (c >= 65382 && c <= 65470)
                  : (c <= 65479 || (c >= 65482 && c <= 65487)))
                : (c <= 65495 || (c < 65536
                  ? (c >= 65498 && c <= 65500)
                  : c <= 65547)))
              : (c <= 65574 || (c < 65616
                ? (c < 65596
                  ? (c >= 65576 && c <= 65594)
                  : (c <= 65597 || (c >= 65599 && c <= 65613)))
                : (c <= 65629 || (c < 65856
                  ? (c >= 65664 && c <= 65786)
                  : c <= 65908)))))
            : (c <= 66204 || (c < 66504
              ? (c < 66384
                ? (c < 66304
                  ? (c >= 66208 && c <= 66256)
                  : (c <= 66335 || (c >= 66349 && c <= 66378)))
                : (c <= 66421 || (c < 66464
                  ? (c >= 66432 && c <= 66461)
                  : c <= 66499)))
              : (c <= 66511 || (c < 66736
                ? (c < 66560
                  ? (c >= 66513 && c <= 66517)
                  : c <= 66717)
                : (c <= 66771 || (c < 66816
                  ? (c >= 66776 && c <= 66811)
                  : c <= 66855)))))))
          : (c <= 66915 || (c < 67506
            ? (c < 66995
              ? (c < 66964
                ? (c < 66940
                  ? (c >= 66928 && c <= 66938)
                  : (c <= 66954 || (c >= 66956 && c <= 66962)))
                : (c <= 66965 || (c < 66979
                  ? (c >= 66967 && c <= 66977)
                  : c <= 66993)))
              : (c <= 67001 || (c < 67424
                ? (c < 67072
                  ? (c >= 67003 && c <= 67004)
                  : (c <= 67382 || (c >= 67392 && c <= 67413)))
                : (c <= 67431 || (c < 67463
                  ? (c >= 67456 && c <= 67461)
                  : c <= 67504)))))
            : (c <= 67514 || (c < 67680
              ? (c < 67639
                ? (c < 67592
                  ? (c >= 67584 && c <= 67589)
                  : (c <= 67592 || (c >= 67594 && c <= 67637)))
                : (c <= 67640 || (c < 67647
                  ? c == 67644
                  : c <= 67669)))
              : (c <= 67702 || (c < 67828
                ? (c < 67808
                  ? (c >= 67712 && c <= 67742)
                  : c <= 67826)
                : (c <= 67829 || (c < 67872
                  ? (c >= 67840 && c <= 67861)
                  : c <= 67883)))))))))))))));
}

static inline bool sym__alpha_identifier_character_set_2(int32_t c) {
  return (c < 6400
    ? (c < 2979
      ? (c < 2392
        ? (c < 1568
          ? (c < 890
            ? (c < 710
              ? (c < 181
                ? (c < '_'
                  ? (c >= 'A' && c <= 'Z')
                  : (c <= 'z' || c == 170))
                : (c <= 181 || (c < 192
                  ? (c >= 186 && c <= 187)
                  : c <= 705)))
              : (c <= 721 || (c < 750
                ? (c < 748
                  ? (c >= 736 && c <= 740)
                  : c <= 748)
                : (c <= 750 || (c < 886
                  ? (c >= 880 && c <= 884)
                  : c <= 887)))))
            : (c <= 893 || (c < 1162
              ? (c < 908
                ? (c < 902
                  ? c == 895
                  : (c <= 902 || (c >= 904 && c <= 906)))
                : (c <= 908 || (c < 931
                  ? (c >= 910 && c <= 929)
                  : c <= 1153)))
              : (c <= 1327 || (c < 1376
                ? (c < 1369
                  ? (c >= 1329 && c <= 1366)
                  : c <= 1369)
                : (c <= 1416 || (c < 1519
                  ? (c >= 1488 && c <= 1514)
                  : c <= 1522)))))))
          : (c <= 1610 || (c < 2042
            ? (c < 1808
              ? (c < 1765
                ? (c < 1649
                  ? (c >= 1646 && c <= 1647)
                  : (c <= 1747 || c == 1749))
                : (c <= 1766 || (c < 1786
                  ? (c >= 1774 && c <= 1775)
                  : c <= 1791)))
              : (c <= 1808 || (c < 1969
                ? (c < 1869
                  ? (c >= 1810 && c <= 1839)
                  : c <= 1957)
                : (c <= 1969 || (c < 2036
                  ? (c >= 1994 && c <= 2026)
                  : c <= 2037)))))
            : (c <= 2042 || (c < 2160
              ? (c < 2088
                ? (c < 2074
                  ? (c >= 2048 && c <= 2069)
                  : (c <= 2074 || c == 2084))
                : (c <= 2088 || (c < 2144
                  ? (c >= 2112 && c <= 2136)
                  : c <= 2154)))
              : (c <= 2183 || (c < 2308
                ? (c < 2208
                  ? (c >= 2185 && c <= 2190)
                  : c <= 2249)
                : (c <= 2361 || (c < 2384
                  ? c == 2365
                  : c <= 2384)))))))))
        : (c <= 2401 || (c < 2707
          ? (c < 2556
            ? (c < 2486
              ? (c < 2451
                ? (c < 2437
                  ? (c >= 2417 && c <= 2432)
                  : (c <= 2444 || (c >= 2447 && c <= 2448)))
                : (c <= 2472 || (c < 2482
                  ? (c >= 2474 && c <= 2480)
                  : c <= 2482)))
              : (c <= 2489 || (c < 2524
                ? (c < 2510
                  ? c == 2493
                  : c <= 2510)
                : (c <= 2525 || (c < 2544
                  ? (c >= 2527 && c <= 2529)
                  : c <= 2545)))))
            : (c <= 2556 || (c < 2616
              ? (c < 2602
                ? (c < 2575
                  ? (c >= 2565 && c <= 2570)
                  : (c <= 2576 || (c >= 2579 && c <= 2600)))
                : (c <= 2608 || (c < 2613
                  ? (c >= 2610 && c <= 2611)
                  : c <= 2614)))
              : (c <= 2617 || (c < 2674
                ? (c < 2654
                  ? (c >= 2649 && c <= 2652)
                  : c <= 2654)
                : (c <= 2676 || (c < 2703
                  ? (c >= 2693 && c <= 2701)
                  : c <= 2705)))))))
          : (c <= 2728 || (c < 2869
            ? (c < 2809
              ? (c < 2749
                ? (c < 2738
                  ? (c >= 2730 && c <= 2736)
                  : (c <= 2739 || (c >= 2741 && c <= 2745)))
                : (c <= 2749 || (c < 2784
                  ? c == 2768
                  : c <= 2785)))
              : (c <= 2809 || (c < 2835
                ? (c < 2831
                  ? (c >= 2821 && c <= 2828)
                  : c <= 2832)
                : (c <= 2856 || (c < 2866
                  ? (c >= 2858 && c <= 2864)
                  : c <= 2867)))))
            : (c <= 2873 || (c < 2949
              ? (c < 2911
                ? (c < 2908
                  ? c == 2877
                  : c <= 2909)
                : (c <= 2913 || (c < 2947
                  ? c == 2929
                  : c <= 2947)))
              : (c <= 2954 || (c < 2969
                ? (c < 2962
                  ? (c >= 2958 && c <= 2960)
                  : c <= 2965)
                : (c <= 2970 || (c < 2974
                  ? c == 2972
                  : c <= 2975)))))))))))
      : (c <= 2980 || (c < 3976
        ? (c < 3406
          ? (c < 3205
            ? (c < 3114
              ? (c < 3077
                ? (c < 2990
                  ? (c >= 2984 && c <= 2986)
                  : (c <= 3001 || c == 3024))
                : (c <= 3084 || (c < 3090
                  ? (c >= 3086 && c <= 3088)
                  : c <= 3112)))
              : (c <= 3129 || (c < 3165
                ? (c < 3160
                  ? c == 3133
                  : c <= 3162)
                : (c <= 3165 || (c < 3200
                  ? (c >= 3168 && c <= 3169)
                  : c <= 3200)))))
            : (c <= 3212 || (c < 3296
              ? (c < 3253
                ? (c < 3218
                  ? (c >= 3214 && c <= 3216)
                  : (c <= 3240 || (c >= 3242 && c <= 3251)))
                : (c <= 3257 || (c < 3293
                  ? c == 3261
                  : c <= 3294)))
              : (c <= 3297 || (c < 3342
                ? (c < 3332
                  ? (c >= 3313 && c <= 3314)
                  : c <= 3340)
                : (c <= 3344 || (c < 3389
                  ? (c >= 3346 && c <= 3386)
                  : c <= 3389)))))))
          : (c <= 3406 || (c < 3716
            ? (c < 3517
              ? (c < 3461
                ? (c < 3423
                  ? (c >= 3412 && c <= 3414)
                  : (c <= 3425 || (c >= 3450 && c <= 3455)))
                : (c <= 3478 || (c < 3507
                  ? (c >= 3482 && c <= 3505)
                  : c <= 3515)))
              : (c <= 3517 || (c < 3634
                ? (c < 3585
                  ? (c >= 3520 && c <= 3526)
                  : c <= 3632)
                : (c <= 3635 || (c < 3713
                  ? (c >= 3648 && c <= 3654)
                  : c <= 3714)))))
            : (c <= 3716 || (c < 3776
              ? (c < 3751
                ? (c < 3724
                  ? (c >= 3718 && c <= 3722)
                  : (c <= 3747 || c == 3749))
                : (c <= 3760 || (c < 3773
                  ? (c >= 3762 && c <= 3763)
                  : c <= 3773)))
              : (c <= 3780 || (c < 3840
                ? (c < 3804
                  ? c == 3782
                  : c <= 3807)
                : (c <= 3840 || (c < 3913
                  ? (c >= 3904 && c <= 3911)
                  : c <= 3948)))))))))
        : (c <= 3980 || (c < 4808
          ? (c < 4304
            ? (c < 4206
              ? (c < 4186
                ? (c < 4159
                  ? (c >= 4096 && c <= 4138)
                  : (c <= 4159 || (c >= 4176 && c <= 4181)))
                : (c <= 4189 || (c < 4197
                  ? c == 4193
                  : c <= 4198)))
              : (c <= 4208 || (c < 4256
                ? (c < 4238
                  ? (c >= 4213 && c <= 4225)
                  : c <= 4238)
                : (c <= 4293 || (c < 4301
                  ? c == 4295
                  : c <= 4301)))))
            : (c <= 4346 || (c < 4746
              ? (c < 4696
                ? (c < 4682
                  ? (c >= 4348 && c <= 4680)
                  : (c <= 4685 || (c >= 4688 && c <= 4694)))
                : (c <= 4696 || (c < 4704
                  ? (c >= 4698 && c <= 4701)
                  : c <= 4744)))
              : (c <= 4749 || (c < 4792
                ? (c < 4786
                  ? (c >= 4752 && c <= 4784)
                  : c <= 4789)
                : (c <= 4798 || (c < 4802
                  ? c == 4800
                  : c <= 4805)))))))
          : (c <= 4822 || (c < 5919
            ? (c < 5121
              ? (c < 4992
                ? (c < 4882
                  ? (c >= 4824 && c <= 4880)
                  : (c <= 4885 || (c >= 4888 && c <= 4954)))
                : (c <= 5007 || (c < 5112
                  ? (c >= 5024 && c <= 5109)
                  : c <= 5117)))
              : (c <= 5740 || (c < 5792
                ? (c < 5761
                  ? (c >= 5743 && c <= 5759)
                  : c <= 5786)
                : (c <= 5866 || (c < 5888
                  ? (c >= 5870 && c <= 5880)
                  : c <= 5905)))))
            : (c <= 5937 || (c < 6108
              ? (c < 5998
                ? (c < 5984
                  ? (c >= 5952 && c <= 5969)
                  : c <= 5996)
                : (c <= 6000 || (c < 6103
                  ? (c >= 6016 && c <= 6067)
                  : c <= 6103)))
              : (c <= 6108 || (c < 6279
                ? (c < 6272
                  ? (c >= 6176 && c <= 6264)
                  : c <= 6276)
                : (c <= 6312 || (c < 6320
                  ? c == 6314
                  : c <= 6389)))))))))))))
    : (c <= 6430 || (c < 43360
      ? (c < 11565
        ? (c < 7968
          ? (c < 7168
            ? (c < 6823
              ? (c < 6576
                ? (c < 6512
                  ? (c >= 6480 && c <= 6509)
                  : (c <= 6516 || (c >= 6528 && c <= 6571)))
                : (c <= 6601 || (c < 6688
                  ? (c >= 6656 && c <= 6678)
                  : c <= 6740)))
              : (c <= 6823 || (c < 7043
                ? (c < 6981
                  ? (c >= 6917 && c <= 6963)
                  : c <= 6988)
                : (c <= 7072 || (c < 7098
                  ? (c >= 7086 && c <= 7087)
                  : c <= 7141)))))
            : (c <= 7203 || (c < 7406
              ? (c < 7312
                ? (c < 7258
                  ? (c >= 7245 && c <= 7247)
                  : (c <= 7293 || (c >= 7296 && c <= 7304)))
                : (c <= 7354 || (c < 7401
                  ? (c >= 7357 && c <= 7359)
                  : c <= 7404)))
              : (c <= 7411 || (c < 7424
                ? (c < 7418
                  ? (c >= 7413 && c <= 7414)
                  : c <= 7418)
                : (c <= 7615 || (c < 7960
                  ? (c >= 7680 && c <= 7957)
                  : c <= 7965)))))))
          : (c <= 8005 || (c < 8150
            ? (c < 8064
              ? (c < 8027
                ? (c < 8016
                  ? (c >= 8008 && c <= 8013)
                  : (c <= 8023 || c == 8025))
                : (c <= 8027 || (c < 8031
                  ? c == 8029
                  : c <= 8061)))
              : (c <= 8116 || (c < 8130
                ? (c < 8126
                  ? (c >= 8118 && c <= 8124)
                  : c <= 8126)
                : (c <= 8132 || (c < 8144
                  ? (c >= 8134 && c <= 8140)
                  : c <= 8147)))))
            : (c <= 8155 || (c < 8450
              ? (c < 8305
                ? (c < 8178
                  ? (c >= 8160 && c <= 8172)
                  : (c <= 8180 || (c >= 8182 && c <= 8188)))
                : (c <= 8305 || (c < 8336
                  ? c == 8319
                  : c <= 8348)))
              : (c <= 8526 || (c < 11506
                ? (c < 11264
                  ? (c >= 8544 && c <= 8584)
                  : c <= 11502)
                : (c <= 11507 || (c < 11559
                  ? (c >= 11520 && c <= 11557)
                  : c <= 11559)))))))))
        : (c <= 11565 || (c < 40959
          ? (c < 12293
            ? (c < 11704
              ? (c < 11680
                ? (c < 11631
                  ? (c >= 11568 && c <= 11623)
                  : (c <= 11631 || (c >= 11648 && c <= 11670)))
                : (c <= 11686 || (c < 11696
                  ? (c >= 11688 && c <= 11694)
                  : c <= 11702)))
              : (c <= 11710 || (c < 11728
                ? (c < 11720
                  ? (c >= 11712 && c <= 11718)
                  : c <= 11726)
                : (c <= 11734 || (c < 11823
                  ? (c >= 11736 && c <= 11742)
                  : c <= 11823)))))
            : (c <= 12295 || (c < 12549
              ? (c < 12445
                ? (c < 12337
                  ? (c >= 12321 && c <= 12329)
                  : (c <= 12348 || (c >= 12353 && c <= 12438)))
                : (c <= 12447 || (c < 12540
                  ? (c >= 12449 && c <= 12538)
                  : c <= 12543)))
              : (c <= 12591 || (c < 12784
                ? (c < 12704
                  ? (c >= 12593 && c <= 12686)
                  : c <= 12735)
                : (c <= 12799 || (c < 19903
                  ? c == 13312
                  : c <= 19968)))))))
          : (c <= 42124 || (c < 42965
            ? (c < 42656
              ? (c < 42538
                ? (c < 42240
                  ? (c >= 42192 && c <= 42237)
                  : (c <= 42508 || (c >= 42512 && c <= 42527)))
                : (c <= 42539 || (c < 42623
                  ? (c >= 42560 && c <= 42606)
                  : c <= 42653)))
              : (c <= 42735 || (c < 42891
                ? (c < 42786
                  ? (c >= 42775 && c <= 42783)
                  : c <= 42888)
                : (c <= 42954 || (c < 42963
                  ? (c >= 42960 && c <= 42961)
                  : c <= 42963)))))
            : (c <= 42969 || (c < 43138
              ? (c < 43015
                ? (c < 43011
                  ? (c >= 42994 && c <= 43009)
                  : c <= 43013)
                : (c <= 43018 || (c < 43072
                  ? (c >= 43020 && c <= 43042)
                  : c <= 43123)))
              : (c <= 43187 || (c < 43261
                ? (c < 43259
                  ? (c >= 43250 && c <= 43255)
                  : c <= 43259)
                : (c <= 43262 || (c < 43312
                  ? (c >= 43274 && c <= 43301)
                  : c <= 43334)))))))))))
      : (c <= 43388 || (c < 65482
        ? (c < 43888
          ? (c < 43705
            ? (c < 43584
              ? (c < 43494
                ? (c < 43471
                  ? (c >= 43396 && c <= 43442)
                  : (c <= 43471 || (c >= 43488 && c <= 43492)))
                : (c <= 43503 || (c < 43520
                  ? (c >= 43514 && c <= 43518)
                  : c <= 43560)))
              : (c <= 43586 || (c < 43646
                ? (c < 43616
                  ? (c >= 43588 && c <= 43595)
                  : c <= 43642)
                : (c <= 43695 || (c < 43701
                  ? c == 43697
                  : c <= 43702)))))
            : (c <= 43709 || (c < 43785
              ? (c < 43744
                ? (c < 43714
                  ? c == 43712
                  : (c <= 43714 || (c >= 43739 && c <= 43741)))
                : (c <= 43754 || (c < 43777
                  ? (c >= 43762 && c <= 43764)
                  : c <= 43782)))
              : (c <= 43790 || (c < 43816
                ? (c < 43808
                  ? (c >= 43793 && c <= 43798)
                  : c <= 43814)
                : (c <= 43822 || (c < 43868
                  ? (c >= 43824 && c <= 43866)
                  : c <= 43881)))))))
          : (c <= 44002 || (c < 64320
            ? (c < 64256
              ? (c < 55243
                ? (c < 55203
                  ? c == 44032
                  : (c <= 55203 || (c >= 55216 && c <= 55238)))
                : (c <= 55291 || (c < 64112
                  ? (c >= 63744 && c <= 64109)
                  : c <= 64217)))
              : (c <= 64262 || (c < 64287
                ? (c < 64285
                  ? (c >= 64275 && c <= 64279)
                  : c <= 64285)
                : (c <= 64310 || (c < 64318
                  ? (c >= 64312 && c <= 64316)
                  : c <= 64318)))))
            : (c <= 64321 || (c < 65136
              ? (c < 64848
                ? (c < 64326
                  ? (c >= 64323 && c <= 64324)
                  : (c <= 64433 || (c >= 64467 && c <= 64829)))
                : (c <= 64911 || (c < 65008
                  ? (c >= 64914 && c <= 64967)
                  : c <= 65019)))
              : (c <= 65140 || (c < 65345
                ? (c < 65313
                  ? (c >= 65142 && c <= 65276)
                  : c <= 65338)
                : (c <= 65370 || (c < 65474
                  ? (c >= 65382 && c <= 65470)
                  : c <= 65479)))))))))
        : (c <= 65487 || (c < 66940
          ? (c < 66304
            ? (c < 65599
              ? (c < 65549
                ? (c < 65498
                  ? (c >= 65490 && c <= 65495)
                  : (c <= 65500 || (c >= 65536 && c <= 65547)))
                : (c <= 65574 || (c < 65596
                  ? (c >= 65576 && c <= 65594)
                  : c <= 65597)))
              : (c <= 65613 || (c < 65856
                ? (c < 65664
                  ? (c >= 65616 && c <= 65629)
                  : c <= 65786)
                : (c <= 65908 || (c < 66208
                  ? (c >= 66176 && c <= 66204)
                  : c <= 66256)))))
            : (c <= 66335 || (c < 66560
              ? (c < 66464
                ? (c < 66384
                  ? (c >= 66349 && c <= 66378)
                  : (c <= 66421 || (c >= 66432 && c <= 66461)))
                : (c <= 66499 || (c < 66513
                  ? (c >= 66504 && c <= 66511)
                  : c <= 66517)))
              : (c <= 66717 || (c < 66816
                ? (c < 66776
                  ? (c >= 66736 && c <= 66771)
                  : c <= 66811)
                : (c <= 66855 || (c < 66928
                  ? (c >= 66864 && c <= 66915)
                  : c <= 66938)))))))
          : (c <= 66954 || (c < 67584
            ? (c < 67072
              ? (c < 66979
                ? (c < 66964
                  ? (c >= 66956 && c <= 66962)
                  : (c <= 66965 || (c >= 66967 && c <= 66977)))
                : (c <= 66993 || (c < 67003
                  ? (c >= 66995 && c <= 67001)
                  : c <= 67004)))
              : (c <= 67382 || (c < 67456
                ? (c < 67424
                  ? (c >= 67392 && c <= 67413)
                  : c <= 67431)
                : (c <= 67461 || (c < 67506
                  ? (c >= 67463 && c <= 67504)
                  : c <= 67514)))))
            : (c <= 67589 || (c < 67680
              ? (c < 67639
                ? (c < 67594
                  ? c == 67592
                  : c <= 67637)
                : (c <= 67640 || (c < 67647
                  ? c == 67644
                  : c <= 67669)))
              : (c <= 67702 || (c < 67828
                ? (c < 67808
                  ? (c >= 67712 && c <= 67742)
                  : c <= 67826)
                : (c <= 67829 || (c < 67872
                  ? (c >= 67840 && c <= 67861)
                  : c <= 67883)))))))))))))));
}

static inline bool sym__alpha_identifier_character_set_3(int32_t c) {
  return (c < 6400
    ? (c < 2979
      ? (c < 2384
        ? (c < 1519
          ? (c < 886
            ? (c < 192
              ? (c < 170
                ? (c < 'A'
                  ? c == '$'
                  : (c <= 'Z' || (c >= '_' && c <= 'z')))
                : (c <= 170 || (c < 186
                  ? c == 181
                  : c <= 187)))
              : (c <= 705 || (c < 748
                ? (c < 736
                  ? (c >= 710 && c <= 721)
                  : c <= 740)
                : (c <= 748 || (c < 880
                  ? c == 750
                  : c <= 884)))))
            : (c <= 887 || (c < 931
              ? (c < 904
                ? (c < 895
                  ? (c >= 890 && c <= 893)
                  : (c <= 895 || c == 902))
                : (c <= 906 || (c < 910
                  ? c == 908
                  : c <= 929)))
              : (c <= 1153 || (c < 1369
                ? (c < 1329
                  ? (c >= 1162 && c <= 1327)
                  : c <= 1366)
                : (c <= 1369 || (c < 1488
                  ? (c >= 1376 && c <= 1416)
                  : c <= 1514)))))))
          : (c <= 1522 || (c < 2036
            ? (c < 1786
              ? (c < 1749
                ? (c < 1646
                  ? (c >= 1568 && c <= 1610)
                  : (c <= 1647 || (c >= 1649 && c <= 1747)))
                : (c <= 1749 || (c < 1774
                  ? (c >= 1765 && c <= 1766)
                  : c <= 1775)))
              : (c <= 1791 || (c < 1869
                ? (c < 1810
                  ? c == 1808
                  : c <= 1839)
                : (c <= 1957 || (c < 1994
                  ? c == 1969
                  : c <= 2026)))))
            : (c <= 2037 || (c < 2144
              ? (c < 2084
                ? (c < 2048
                  ? c == 2042
                  : (c <= 2069 || c == 2074))
                : (c <= 2084 || (c < 2112
                  ? c == 2088
                  : c <= 2136)))
              : (c <= 2154 || (c < 2208
                ? (c < 2185
                  ? (c >= 2160 && c <= 2183)
                  : c <= 2190)
                : (c <= 2249 || (c < 2365
                  ? (c >= 2308 && c <= 2361)
                  : c <= 2365)))))))))
        : (c <= 2384 || (c < 2703
          ? (c < 2544
            ? (c < 2482
              ? (c < 2447
                ? (c < 2417
                  ? (c >= 2392 && c <= 2401)
                  : (c <= 2432 || (c >= 2437 && c <= 2444)))
                : (c <= 2448 || (c < 2474
                  ? (c >= 2451 && c <= 2472)
                  : c <= 2480)))
              : (c <= 2482 || (c < 2510
                ? (c < 2493
                  ? (c >= 2486 && c <= 2489)
                  : c <= 2493)
                : (c <= 2510 || (c < 2527
                  ? (c >= 2524 && c <= 2525)
                  : c <= 2529)))))
            : (c <= 2545 || (c < 2613
              ? (c < 2579
                ? (c < 2565
                  ? c == 2556
                  : (c <= 2570 || (c >= 2575 && c <= 2576)))
                : (c <= 2600 || (c < 2610
                  ? (c >= 2602 && c <= 2608)
                  : c <= 2611)))
              : (c <= 2614 || (c < 2654
                ? (c < 2649
                  ? (c >= 2616 && c <= 2617)
                  : c <= 2652)
                : (c <= 2654 || (c < 2693
                  ? (c >= 2674 && c <= 2676)
                  : c <= 2701)))))))
          : (c <= 2705 || (c < 2866
            ? (c < 2784
              ? (c < 2741
                ? (c < 2730
                  ? (c >= 2707 && c <= 2728)
                  : (c <= 2736 || (c >= 2738 && c <= 2739)))
                : (c <= 2745 || (c < 2768
                  ? c == 2749
                  : c <= 2768)))
              : (c <= 2785 || (c < 2831
                ? (c < 2821
                  ? c == 2809
                  : c <= 2828)
                : (c <= 2832 || (c < 2858
                  ? (c >= 2835 && c <= 2856)
                  : c <= 2864)))))
            : (c <= 2867 || (c < 2949
              ? (c < 2911
                ? (c < 2877
                  ? (c >= 2869 && c <= 2873)
                  : (c <= 2877 || (c >= 2908 && c <= 2909)))
                : (c <= 2913 || (c < 2947
                  ? c == 2929
                  : c <= 2947)))
              : (c <= 2954 || (c < 2969
                ? (c < 2962
                  ? (c >= 2958 && c <= 2960)
                  : c <= 2965)
                : (c <= 2970 || (c < 2974
                  ? c == 2972
                  : c <= 2975)))))))))))
      : (c <= 2980 || (c < 3976
        ? (c < 3406
          ? (c < 3205
            ? (c < 3114
              ? (c < 3077
                ? (c < 2990
                  ? (c >= 2984 && c <= 2986)
                  : (c <= 3001 || c == 3024))
                : (c <= 3084 || (c < 3090
                  ? (c >= 3086 && c <= 3088)
                  : c <= 3112)))
              : (c <= 3129 || (c < 3165
                ? (c < 3160
                  ? c == 3133
                  : c <= 3162)
                : (c <= 3165 || (c < 3200
                  ? (c >= 3168 && c <= 3169)
                  : c <= 3200)))))
            : (c <= 3212 || (c < 3296
              ? (c < 3253
                ? (c < 3218
                  ? (c >= 3214 && c <= 3216)
                  : (c <= 3240 || (c >= 3242 && c <= 3251)))
                : (c <= 3257 || (c < 3293
                  ? c == 3261
                  : c <= 3294)))
              : (c <= 3297 || (c < 3342
                ? (c < 3332
                  ? (c >= 3313 && c <= 3314)
                  : c <= 3340)
                : (c <= 3344 || (c < 3389
                  ? (c >= 3346 && c <= 3386)
                  : c <= 3389)))))))
          : (c <= 3406 || (c < 3716
            ? (c < 3517
              ? (c < 3461
                ? (c < 3423
                  ? (c >= 3412 && c <= 3414)
                  : (c <= 3425 || (c >= 3450 && c <= 3455)))
                : (c <= 3478 || (c < 3507
                  ? (c >= 3482 && c <= 3505)
                  : c <= 3515)))
              : (c <= 3517 || (c < 3634
                ? (c < 3585
                  ? (c >= 3520 && c <= 3526)
                  : c <= 3632)
                : (c <= 3635 || (c < 3713
                  ? (c >= 3648 && c <= 3654)
                  : c <= 3714)))))
            : (c <= 3716 || (c < 3776
              ? (c < 3751
                ? (c < 3724
                  ? (c >= 3718 && c <= 3722)
                  : (c <= 3747 || c == 3749))
                : (c <= 3760 || (c < 3773
                  ? (c >= 3762 && c <= 3763)
                  : c <= 3773)))
              : (c <= 3780 || (c < 3840
                ? (c < 3804
                  ? c == 3782
                  : c <= 3807)
                : (c <= 3840 || (c < 3913
                  ? (c >= 3904 && c <= 3911)
                  : c <= 3948)))))))))
        : (c <= 3980 || (c < 4808
          ? (c < 4304
            ? (c < 4206
              ? (c < 4186
                ? (c < 4159
                  ? (c >= 4096 && c <= 4138)
                  : (c <= 4159 || (c >= 4176 && c <= 4181)))
                : (c <= 4189 || (c < 4197
                  ? c == 4193
                  : c <= 4198)))
              : (c <= 4208 || (c < 4256
                ? (c < 4238
                  ? (c >= 4213 && c <= 4225)
                  : c <= 4238)
                : (c <= 4293 || (c < 4301
                  ? c == 4295
                  : c <= 4301)))))
            : (c <= 4346 || (c < 4746
              ? (c < 4696
                ? (c < 4682
                  ? (c >= 4348 && c <= 4680)
                  : (c <= 4685 || (c >= 4688 && c <= 4694)))
                : (c <= 4696 || (c < 4704
                  ? (c >= 4698 && c <= 4701)
                  : c <= 4744)))
              : (c <= 4749 || (c < 4792
                ? (c < 4786
                  ? (c >= 4752 && c <= 4784)
                  : c <= 4789)
                : (c <= 4798 || (c < 4802
                  ? c == 4800
                  : c <= 4805)))))))
          : (c <= 4822 || (c < 5919
            ? (c < 5121
              ? (c < 4992
                ? (c < 4882
                  ? (c >= 4824 && c <= 4880)
                  : (c <= 4885 || (c >= 4888 && c <= 4954)))
                : (c <= 5007 || (c < 5112
                  ? (c >= 5024 && c <= 5109)
                  : c <= 5117)))
              : (c <= 5740 || (c < 5792
                ? (c < 5761
                  ? (c >= 5743 && c <= 5759)
                  : c <= 5786)
                : (c <= 5866 || (c < 5888
                  ? (c >= 5870 && c <= 5880)
                  : c <= 5905)))))
            : (c <= 5937 || (c < 6108
              ? (c < 5998
                ? (c < 5984
                  ? (c >= 5952 && c <= 5969)
                  : c <= 5996)
                : (c <= 6000 || (c < 6103
                  ? (c >= 6016 && c <= 6067)
                  : c <= 6103)))
              : (c <= 6108 || (c < 6279
                ? (c < 6272
                  ? (c >= 6176 && c <= 6264)
                  : c <= 6276)
                : (c <= 6312 || (c < 6320
                  ? c == 6314
                  : c <= 6389)))))))))))))
    : (c <= 6430 || (c < 43360
      ? (c < 11565
        ? (c < 7968
          ? (c < 7168
            ? (c < 6823
              ? (c < 6576
                ? (c < 6512
                  ? (c >= 6480 && c <= 6509)
                  : (c <= 6516 || (c >= 6528 && c <= 6571)))
                : (c <= 6601 || (c < 6688
                  ? (c >= 6656 && c <= 6678)
                  : c <= 6740)))
              : (c <= 6823 || (c < 7043
                ? (c < 6981
                  ? (c >= 6917 && c <= 6963)
                  : c <= 6988)
                : (c <= 7072 || (c < 7098
                  ? (c >= 7086 && c <= 7087)
                  : c <= 7141)))))
            : (c <= 7203 || (c < 7406
              ? (c < 7312
                ? (c < 7258
                  ? (c >= 7245 && c <= 7247)
                  : (c <= 7293 || (c >= 7296 && c <= 7304)))
                : (c <= 7354 || (c < 7401
                  ? (c >= 7357 && c <= 7359)
                  : c <= 7404)))
              : (c <= 7411 || (c < 7424
                ? (c < 7418
                  ? (c >= 7413 && c <= 7414)
                  : c <= 7418)
                : (c <= 7615 || (c < 7960
                  ? (c >= 7680 && c <= 7957)
                  : c <= 7965)))))))
          : (c <= 8005 || (c < 8150
            ? (c < 8064
              ? (c < 8027
                ? (c < 8016
                  ? (c >= 8008 && c <= 8013)
                  : (c <= 8023 || c == 8025))
                : (c <= 8027 || (c < 8031
                  ? c == 8029
                  : c <= 8061)))
              : (c <= 8116 || (c < 8130
                ? (c < 8126
                  ? (c >= 8118 && c <= 8124)
                  : c <= 8126)
                : (c <= 8132 || (c < 8144
                  ? (c >= 8134 && c <= 8140)
                  : c <= 8147)))))
            : (c <= 8155 || (c < 8450
              ? (c < 8305
                ? (c < 8178
                  ? (c >= 8160 && c <= 8172)
                  : (c <= 8180 || (c >= 8182 && c <= 8188)))
                : (c <= 8305 || (c < 8336
                  ? c == 8319
                  : c <= 8348)))
              : (c <= 8526 || (c < 11506
                ? (c < 11264
                  ? (c >= 8544 && c <= 8584)
                  : c <= 11502)
                : (c <= 11507 || (c < 11559
                  ? (c >= 11520 && c <= 11557)
                  : c <= 11559)))))))))
        : (c <= 11565 || (c < 40959
          ? (c < 12293
            ? (c < 11704
              ? (c < 11680
                ? (c < 11631
                  ? (c >= 11568 && c <= 11623)
                  : (c <= 11631 || (c >= 11648 && c <= 11670)))
                : (c <= 11686 || (c < 11696
                  ? (c >= 11688 && c <= 11694)
                  : c <= 11702)))
              : (c <= 11710 || (c < 11728
                ? (c < 11720
                  ? (c >= 11712 && c <= 11718)
                  : c <= 11726)
                : (c <= 11734 || (c < 11823
                  ? (c >= 11736 && c <= 11742)
                  : c <= 11823)))))
            : (c <= 12295 || (c < 12549
              ? (c < 12445
                ? (c < 12337
                  ? (c >= 12321 && c <= 12329)
                  : (c <= 12348 || (c >= 12353 && c <= 12438)))
                : (c <= 12447 || (c < 12540
                  ? (c >= 12449 && c <= 12538)
                  : c <= 12543)))
              : (c <= 12591 || (c < 12784
                ? (c < 12704
                  ? (c >= 12593 && c <= 12686)
                  : c <= 12735)
                : (c <= 12799 || (c < 19903
                  ? c == 13312
                  : c <= 19968)))))))
          : (c <= 42124 || (c < 42965
            ? (c < 42656
              ? (c < 42538
                ? (c < 42240
                  ? (c >= 42192 && c <= 42237)
                  : (c <= 42508 || (c >= 42512 && c <= 42527)))
                : (c <= 42539 || (c < 42623
                  ? (c >= 42560 && c <= 42606)
                  : c <= 42653)))
              : (c <= 42735 || (c < 42891
                ? (c < 42786
                  ? (c >= 42775 && c <= 42783)
                  : c <= 42888)
                : (c <= 42954 || (c < 42963
                  ? (c >= 42960 && c <= 42961)
                  : c <= 42963)))))
            : (c <= 42969 || (c < 43138
              ? (c < 43015
                ? (c < 43011
                  ? (c >= 42994 && c <= 43009)
                  : c <= 43013)
                : (c <= 43018 || (c < 43072
                  ? (c >= 43020 && c <= 43042)
                  : c <= 43123)))
              : (c <= 43187 || (c < 43261
                ? (c < 43259
                  ? (c >= 43250 && c <= 43255)
                  : c <= 43259)
                : (c <= 43262 || (c < 43312
                  ? (c >= 43274 && c <= 43301)
                  : c <= 43334)))))))))))
      : (c <= 43388 || (c < 65482
        ? (c < 43888
          ? (c < 43705
            ? (c < 43584
              ? (c < 43494
                ? (c < 43471
                  ? (c >= 43396 && c <= 43442)
                  : (c <= 43471 || (c >= 43488 && c <= 43492)))
                : (c <= 43503 || (c < 43520
                  ? (c >= 43514 && c <= 43518)
                  : c <= 43560)))
              : (c <= 43586 || (c < 43646
                ? (c < 43616
                  ? (c >= 43588 && c <= 43595)
                  : c <= 43642)
                : (c <= 43695 || (c < 43701
                  ? c == 43697
                  : c <= 43702)))))
            : (c <= 43709 || (c < 43785
              ? (c < 43744
                ? (c < 43714
                  ? c == 43712
                  : (c <= 43714 || (c >= 43739 && c <= 43741)))
                : (c <= 43754 || (c < 43777
                  ? (c >= 43762 && c <= 43764)
                  : c <= 43782)))
              : (c <= 43790 || (c < 43816
                ? (c < 43808
                  ? (c >= 43793 && c <= 43798)
                  : c <= 43814)
                : (c <= 43822 || (c < 43868
                  ? (c >= 43824 && c <= 43866)
                  : c <= 43881)))))))
          : (c <= 44002 || (c < 64320
            ? (c < 64256
              ? (c < 55243
                ? (c < 55203
                  ? c == 44032
                  : (c <= 55203 || (c >= 55216 && c <= 55238)))
                : (c <= 55291 || (c < 64112
                  ? (c >= 63744 && c <= 64109)
                  : c <= 64217)))
              : (c <= 64262 || (c < 64287
                ? (c < 64285
                  ? (c >= 64275 && c <= 64279)
                  : c <= 64285)
                : (c <= 64310 || (c < 64318
                  ? (c >= 64312 && c <= 64316)
                  : c <= 64318)))))
            : (c <= 64321 || (c < 65136
              ? (c < 64848
                ? (c < 64326
                  ? (c >= 64323 && c <= 64324)
                  : (c <= 64433 || (c >= 64467 && c <= 64829)))
                : (c <= 64911 || (c < 65008
                  ? (c >= 64914 && c <= 64967)
                  : c <= 65019)))
              : (c <= 65140 || (c < 65345
                ? (c < 65313
                  ? (c >= 65142 && c <= 65276)
                  : c <= 65338)
                : (c <= 65370 || (c < 65474
                  ? (c >= 65382 && c <= 65470)
                  : c <= 65479)))))))))
        : (c <= 65487 || (c < 66940
          ? (c < 66304
            ? (c < 65599
              ? (c < 65549
                ? (c < 65498
                  ? (c >= 65490 && c <= 65495)
                  : (c <= 65500 || (c >= 65536 && c <= 65547)))
                : (c <= 65574 || (c < 65596
                  ? (c >= 65576 && c <= 65594)
                  : c <= 65597)))
              : (c <= 65613 || (c < 65856
                ? (c < 65664
                  ? (c >= 65616 && c <= 65629)
                  : c <= 65786)
                : (c <= 65908 || (c < 66208
                  ? (c >= 66176 && c <= 66204)
                  : c <= 66256)))))
            : (c <= 66335 || (c < 66560
              ? (c < 66464
                ? (c < 66384
                  ? (c >= 66349 && c <= 66378)
                  : (c <= 66421 || (c >= 66432 && c <= 66461)))
                : (c <= 66499 || (c < 66513
                  ? (c >= 66504 && c <= 66511)
                  : c <= 66517)))
              : (c <= 66717 || (c < 66816
                ? (c < 66776
                  ? (c >= 66736 && c <= 66771)
                  : c <= 66811)
                : (c <= 66855 || (c < 66928
                  ? (c >= 66864 && c <= 66915)
                  : c <= 66938)))))))
          : (c <= 66954 || (c < 67584
            ? (c < 67072
              ? (c < 66979
                ? (c < 66964
                  ? (c >= 66956 && c <= 66962)
                  : (c <= 66965 || (c >= 66967 && c <= 66977)))
                : (c <= 66993 || (c < 67003
                  ? (c >= 66995 && c <= 67001)
                  : c <= 67004)))
              : (c <= 67382 || (c < 67456
                ? (c < 67424
                  ? (c >= 67392 && c <= 67413)
                  : c <= 67431)
                : (c <= 67461 || (c < 67506
                  ? (c >= 67463 && c <= 67504)
                  : c <= 67514)))))
            : (c <= 67589 || (c < 67680
              ? (c < 67639
                ? (c < 67594
                  ? c == 67592
                  : c <= 67637)
                : (c <= 67640 || (c < 67647
                  ? c == 67644
                  : c <= 67669)))
              : (c <= 67702 || (c < 67828
                ? (c < 67808
                  ? (c >= 67712 && c <= 67742)
                  : c <= 67826)
                : (c <= 67829 || (c < 67872
                  ? (c >= 67840 && c <= 67861)
                  : c <= 67883)))))))))))))));
}

static inline bool sym__alpha_identifier_character_set_4(int32_t c) {
  return (c < 6400
    ? (c < 2979
      ? (c < 2392
        ? (c < 1568
          ? (c < 890
            ? (c < 710
              ? (c < 181
                ? (c < 'A'
                  ? c == '$'
                  : (c <= 'z' || c == 170))
                : (c <= 181 || (c < 192
                  ? (c >= 186 && c <= 187)
                  : c <= 705)))
              : (c <= 721 || (c < 750
                ? (c < 748
                  ? (c >= 736 && c <= 740)
                  : c <= 748)
                : (c <= 750 || (c < 886
                  ? (c >= 880 && c <= 884)
                  : c <= 887)))))
            : (c <= 893 || (c < 1162
              ? (c < 908
                ? (c < 902
                  ? c == 895
                  : (c <= 902 || (c >= 904 && c <= 906)))
                : (c <= 908 || (c < 931
                  ? (c >= 910 && c <= 929)
                  : c <= 1153)))
              : (c <= 1327 || (c < 1376
                ? (c < 1369
                  ? (c >= 1329 && c <= 1366)
                  : c <= 1369)
                : (c <= 1416 || (c < 1519
                  ? (c >= 1488 && c <= 1514)
                  : c <= 1522)))))))
          : (c <= 1610 || (c < 2042
            ? (c < 1808
              ? (c < 1765
                ? (c < 1649
                  ? (c >= 1646 && c <= 1647)
                  : (c <= 1747 || c == 1749))
                : (c <= 1766 || (c < 1786
                  ? (c >= 1774 && c <= 1775)
                  : c <= 1791)))
              : (c <= 1808 || (c < 1969
                ? (c < 1869
                  ? (c >= 1810 && c <= 1839)
                  : c <= 1957)
                : (c <= 1969 || (c < 2036
                  ? (c >= 1994 && c <= 2026)
                  : c <= 2037)))))
            : (c <= 2042 || (c < 2160
              ? (c < 2088
                ? (c < 2074
                  ? (c >= 2048 && c <= 2069)
                  : (c <= 2074 || c == 2084))
                : (c <= 2088 || (c < 2144
                  ? (c >= 2112 && c <= 2136)
                  : c <= 2154)))
              : (c <= 2183 || (c < 2308
                ? (c < 2208
                  ? (c >= 2185 && c <= 2190)
                  : c <= 2249)
                : (c <= 2361 || (c < 2384
                  ? c == 2365
                  : c <= 2384)))))))))
        : (c <= 2401 || (c < 2707
          ? (c < 2556
            ? (c < 2486
              ? (c < 2451
                ? (c < 2437
                  ? (c >= 2417 && c <= 2432)
                  : (c <= 2444 || (c >= 2447 && c <= 2448)))
                : (c <= 2472 || (c < 2482
                  ? (c >= 2474 && c <= 2480)
                  : c <= 2482)))
              : (c <= 2489 || (c < 2524
                ? (c < 2510
                  ? c == 2493
                  : c <= 2510)
                : (c <= 2525 || (c < 2544
                  ? (c >= 2527 && c <= 2529)
                  : c <= 2545)))))
            : (c <= 2556 || (c < 2616
              ? (c < 2602
                ? (c < 2575
                  ? (c >= 2565 && c <= 2570)
                  : (c <= 2576 || (c >= 2579 && c <= 2600)))
                : (c <= 2608 || (c < 2613
                  ? (c >= 2610 && c <= 2611)
                  : c <= 2614)))
              : (c <= 2617 || (c < 2674
                ? (c < 2654
                  ? (c >= 2649 && c <= 2652)
                  : c <= 2654)
                : (c <= 2676 || (c < 2703
                  ? (c >= 2693 && c <= 2701)
                  : c <= 2705)))))))
          : (c <= 2728 || (c < 2869
            ? (c < 2809
              ? (c < 2749
                ? (c < 2738
                  ? (c >= 2730 && c <= 2736)
                  : (c <= 2739 || (c >= 2741 && c <= 2745)))
                : (c <= 2749 || (c < 2784
                  ? c == 2768
                  : c <= 2785)))
              : (c <= 2809 || (c < 2835
                ? (c < 2831
                  ? (c >= 2821 && c <= 2828)
                  : c <= 2832)
                : (c <= 2856 || (c < 2866
                  ? (c >= 2858 && c <= 2864)
                  : c <= 2867)))))
            : (c <= 2873 || (c < 2949
              ? (c < 2911
                ? (c < 2908
                  ? c == 2877
                  : c <= 2909)
                : (c <= 2913 || (c < 2947
                  ? c == 2929
                  : c <= 2947)))
              : (c <= 2954 || (c < 2969
                ? (c < 2962
                  ? (c >= 2958 && c <= 2960)
                  : c <= 2965)
                : (c <= 2970 || (c < 2974
                  ? c == 2972
                  : c <= 2975)))))))))))
      : (c <= 2980 || (c < 3976
        ? (c < 3406
          ? (c < 3205
            ? (c < 3114
              ? (c < 3077
                ? (c < 2990
                  ? (c >= 2984 && c <= 2986)
                  : (c <= 3001 || c == 3024))
                : (c <= 3084 || (c < 3090
                  ? (c >= 3086 && c <= 3088)
                  : c <= 3112)))
              : (c <= 3129 || (c < 3165
                ? (c < 3160
                  ? c == 3133
                  : c <= 3162)
                : (c <= 3165 || (c < 3200
                  ? (c >= 3168 && c <= 3169)
                  : c <= 3200)))))
            : (c <= 3212 || (c < 3296
              ? (c < 3253
                ? (c < 3218
                  ? (c >= 3214 && c <= 3216)
                  : (c <= 3240 || (c >= 3242 && c <= 3251)))
                : (c <= 3257 || (c < 3293
                  ? c == 3261
                  : c <= 3294)))
              : (c <= 3297 || (c < 3342
                ? (c < 3332
                  ? (c >= 3313 && c <= 3314)
                  : c <= 3340)
                : (c <= 3344 || (c < 3389
                  ? (c >= 3346 && c <= 3386)
                  : c <= 3389)))))))
          : (c <= 3406 || (c < 3716
            ? (c < 3517
              ? (c < 3461
                ? (c < 3423
                  ? (c >= 3412 && c <= 3414)
                  : (c <= 3425 || (c >= 3450 && c <= 3455)))
                : (c <= 3478 || (c < 3507
                  ? (c >= 3482 && c <= 3505)
                  : c <= 3515)))
              : (c <= 3517 || (c < 3634
                ? (c < 3585
                  ? (c >= 3520 && c <= 3526)
                  : c <= 3632)
                : (c <= 3635 || (c < 3713
                  ? (c >= 3648 && c <= 3654)
                  : c <= 3714)))))
            : (c <= 3716 || (c < 3776
              ? (c < 3751
                ? (c < 3724
                  ? (c >= 3718 && c <= 3722)
                  : (c <= 3747 || c == 3749))
                : (c <= 3760 || (c < 3773
                  ? (c >= 3762 && c <= 3763)
                  : c <= 3773)))
              : (c <= 3780 || (c < 3840
                ? (c < 3804
                  ? c == 3782
                  : c <= 3807)
                : (c <= 3840 || (c < 3913
                  ? (c >= 3904 && c <= 3911)
                  : c <= 3948)))))))))
        : (c <= 3980 || (c < 4808
          ? (c < 4304
            ? (c < 4206
              ? (c < 4186
                ? (c < 4159
                  ? (c >= 4096 && c <= 4138)
                  : (c <= 4159 || (c >= 4176 && c <= 4181)))
                : (c <= 4189 || (c < 4197
                  ? c == 4193
                  : c <= 4198)))
              : (c <= 4208 || (c < 4256
                ? (c < 4238
                  ? (c >= 4213 && c <= 4225)
                  : c <= 4238)
                : (c <= 4293 || (c < 4301
                  ? c == 4295
                  : c <= 4301)))))
            : (c <= 4346 || (c < 4746
              ? (c < 4696
                ? (c < 4682
                  ? (c >= 4348 && c <= 4680)
                  : (c <= 4685 || (c >= 4688 && c <= 4694)))
                : (c <= 4696 || (c < 4704
                  ? (c >= 4698 && c <= 4701)
                  : c <= 4744)))
              : (c <= 4749 || (c < 4792
                ? (c < 4786
                  ? (c >= 4752 && c <= 4784)
                  : c <= 4789)
                : (c <= 4798 || (c < 4802
                  ? c == 4800
                  : c <= 4805)))))))
          : (c <= 4822 || (c < 5919
            ? (c < 5121
              ? (c < 4992
                ? (c < 4882
                  ? (c >= 4824 && c <= 4880)
                  : (c <= 4885 || (c >= 4888 && c <= 4954)))
                : (c <= 5007 || (c < 5112
                  ? (c >= 5024 && c <= 5109)
                  : c <= 5117)))
              : (c <= 5740 || (c < 5792
                ? (c < 5761
                  ? (c >= 5743 && c <= 5759)
                  : c <= 5786)
                : (c <= 5866 || (c < 5888
                  ? (c >= 5870 && c <= 5880)
                  : c <= 5905)))))
            : (c <= 5937 || (c < 6108
              ? (c < 5998
                ? (c < 5984
                  ? (c >= 5952 && c <= 5969)
                  : c <= 5996)
                : (c <= 6000 || (c < 6103
                  ? (c >= 6016 && c <= 6067)
                  : c <= 6103)))
              : (c <= 6108 || (c < 6279
                ? (c < 6272
                  ? (c >= 6176 && c <= 6264)
                  : c <= 6276)
                : (c <= 6312 || (c < 6320
                  ? c == 6314
                  : c <= 6389)))))))))))))
    : (c <= 6430 || (c < 43360
      ? (c < 11565
        ? (c < 7968
          ? (c < 7168
            ? (c < 6823
              ? (c < 6576
                ? (c < 6512
                  ? (c >= 6480 && c <= 6509)
                  : (c <= 6516 || (c >= 6528 && c <= 6571)))
                : (c <= 6601 || (c < 6688
                  ? (c >= 6656 && c <= 6678)
                  : c <= 6740)))
              : (c <= 6823 || (c < 7043
                ? (c < 6981
                  ? (c >= 6917 && c <= 6963)
                  : c <= 6988)
                : (c <= 7072 || (c < 7098
                  ? (c >= 7086 && c <= 7087)
                  : c <= 7141)))))
            : (c <= 7203 || (c < 7406
              ? (c < 7312
                ? (c < 7258
                  ? (c >= 7245 && c <= 7247)
                  : (c <= 7293 || (c >= 7296 && c <= 7304)))
                : (c <= 7354 || (c < 7401
                  ? (c >= 7357 && c <= 7359)
                  : c <= 7404)))
              : (c <= 7411 || (c < 7424
                ? (c < 7418
                  ? (c >= 7413 && c <= 7414)
                  : c <= 7418)
                : (c <= 7615 || (c < 7960
                  ? (c >= 7680 && c <= 7957)
                  : c <= 7965)))))))
          : (c <= 8005 || (c < 8150
            ? (c < 8064
              ? (c < 8027
                ? (c < 8016
                  ? (c >= 8008 && c <= 8013)
                  : (c <= 8023 || c == 8025))
                : (c <= 8027 || (c < 8031
                  ? c == 8029
                  : c <= 8061)))
              : (c <= 8116 || (c < 8130
                ? (c < 8126
                  ? (c >= 8118 && c <= 8124)
                  : c <= 8126)
                : (c <= 8132 || (c < 8144
                  ? (c >= 8134 && c <= 8140)
                  : c <= 8147)))))
            : (c <= 8155 || (c < 8450
              ? (c < 8305
                ? (c < 8178
                  ? (c >= 8160 && c <= 8172)
                  : (c <= 8180 || (c >= 8182 && c <= 8188)))
                : (c <= 8305 || (c < 8336
                  ? c == 8319
                  : c <= 8348)))
              : (c <= 8526 || (c < 11506
                ? (c < 11264
                  ? (c >= 8544 && c <= 8584)
                  : c <= 11502)
                : (c <= 11507 || (c < 11559
                  ? (c >= 11520 && c <= 11557)
                  : c <= 11559)))))))))
        : (c <= 11565 || (c < 40959
          ? (c < 12293
            ? (c < 11704
              ? (c < 11680
                ? (c < 11631
                  ? (c >= 11568 && c <= 11623)
                  : (c <= 11631 || (c >= 11648 && c <= 11670)))
                : (c <= 11686 || (c < 11696
                  ? (c >= 11688 && c <= 11694)
                  : c <= 11702)))
              : (c <= 11710 || (c < 11728
                ? (c < 11720
                  ? (c >= 11712 && c <= 11718)
                  : c <= 11726)
                : (c <= 11734 || (c < 11823
                  ? (c >= 11736 && c <= 11742)
                  : c <= 11823)))))
            : (c <= 12295 || (c < 12549
              ? (c < 12445
                ? (c < 12337
                  ? (c >= 12321 && c <= 12329)
                  : (c <= 12348 || (c >= 12353 && c <= 12438)))
                : (c <= 12447 || (c < 12540
                  ? (c >= 12449 && c <= 12538)
                  : c <= 12543)))
              : (c <= 12591 || (c < 12784
                ? (c < 12704
                  ? (c >= 12593 && c <= 12686)
                  : c <= 12735)
                : (c <= 12799 || (c < 19903
                  ? c == 13312
                  : c <= 19968)))))))
          : (c <= 42124 || (c < 42965
            ? (c < 42656
              ? (c < 42538
                ? (c < 42240
                  ? (c >= 42192 && c <= 42237)
                  : (c <= 42508 || (c >= 42512 && c <= 42527)))
                : (c <= 42539 || (c < 42623
                  ? (c >= 42560 && c <= 42606)
                  : c <= 42653)))
              : (c <= 42735 || (c < 42891
                ? (c < 42786
                  ? (c >= 42775 && c <= 42783)
                  : c <= 42888)
                : (c <= 42954 || (c < 42963
                  ? (c >= 42960 && c <= 42961)
                  : c <= 42963)))))
            : (c <= 42969 || (c < 43138
              ? (c < 43015
                ? (c < 43011
                  ? (c >= 42994 && c <= 43009)
                  : c <= 43013)
                : (c <= 43018 || (c < 43072
                  ? (c >= 43020 && c <= 43042)
                  : c <= 43123)))
              : (c <= 43187 || (c < 43261
                ? (c < 43259
                  ? (c >= 43250 && c <= 43255)
                  : c <= 43259)
                : (c <= 43262 || (c < 43312
                  ? (c >= 43274 && c <= 43301)
                  : c <= 43334)))))))))))
      : (c <= 43388 || (c < 65482
        ? (c < 43888
          ? (c < 43705
            ? (c < 43584
              ? (c < 43494
                ? (c < 43471
                  ? (c >= 43396 && c <= 43442)
                  : (c <= 43471 || (c >= 43488 && c <= 43492)))
                : (c <= 43503 || (c < 43520
                  ? (c >= 43514 && c <= 43518)
                  : c <= 43560)))
              : (c <= 43586 || (c < 43646
                ? (c < 43616
                  ? (c >= 43588 && c <= 43595)
                  : c <= 43642)
                : (c <= 43695 || (c < 43701
                  ? c == 43697
                  : c <= 43702)))))
            : (c <= 43709 || (c < 43785
              ? (c < 43744
                ? (c < 43714
                  ? c == 43712
                  : (c <= 43714 || (c >= 43739 && c <= 43741)))
                : (c <= 43754 || (c < 43777
                  ? (c >= 43762 && c <= 43764)
                  : c <= 43782)))
              : (c <= 43790 || (c < 43816
                ? (c < 43808
                  ? (c >= 43793 && c <= 43798)
                  : c <= 43814)
                : (c <= 43822 || (c < 43868
                  ? (c >= 43824 && c <= 43866)
                  : c <= 43881)))))))
          : (c <= 44002 || (c < 64320
            ? (c < 64256
              ? (c < 55243
                ? (c < 55203
                  ? c == 44032
                  : (c <= 55203 || (c >= 55216 && c <= 55238)))
                : (c <= 55291 || (c < 64112
                  ? (c >= 63744 && c <= 64109)
                  : c <= 64217)))
              : (c <= 64262 || (c < 64287
                ? (c < 64285
                  ? (c >= 64275 && c <= 64279)
                  : c <= 64285)
                : (c <= 64310 || (c < 64318
                  ? (c >= 64312 && c <= 64316)
                  : c <= 64318)))))
            : (c <= 64321 || (c < 65136
              ? (c < 64848
                ? (c < 64326
                  ? (c >= 64323 && c <= 64324)
                  : (c <= 64433 || (c >= 64467 && c <= 64829)))
                : (c <= 64911 || (c < 65008
                  ? (c >= 64914 && c <= 64967)
                  : c <= 65019)))
              : (c <= 65140 || (c < 65345
                ? (c < 65313
                  ? (c >= 65142 && c <= 65276)
                  : c <= 65338)
                : (c <= 65370 || (c < 65474
                  ? (c >= 65382 && c <= 65470)
                  : c <= 65479)))))))))
        : (c <= 65487 || (c < 66940
          ? (c < 66304
            ? (c < 65599
              ? (c < 65549
                ? (c < 65498
                  ? (c >= 65490 && c <= 65495)
                  : (c <= 65500 || (c >= 65536 && c <= 65547)))
                : (c <= 65574 || (c < 65596
                  ? (c >= 65576 && c <= 65594)
                  : c <= 65597)))
              : (c <= 65613 || (c < 65856
                ? (c < 65664
                  ? (c >= 65616 && c <= 65629)
                  : c <= 65786)
                : (c <= 65908 || (c < 66208
                  ? (c >= 66176 && c <= 66204)
                  : c <= 66256)))))
            : (c <= 66335 || (c < 66560
              ? (c < 66464
                ? (c < 66384
                  ? (c >= 66349 && c <= 66378)
                  : (c <= 66421 || (c >= 66432 && c <= 66461)))
                : (c <= 66499 || (c < 66513
                  ? (c >= 66504 && c <= 66511)
                  : c <= 66517)))
              : (c <= 66717 || (c < 66816
                ? (c < 66776
                  ? (c >= 66736 && c <= 66771)
                  : c <= 66811)
                : (c <= 66855 || (c < 66928
                  ? (c >= 66864 && c <= 66915)
                  : c <= 66938)))))))
          : (c <= 66954 || (c < 67584
            ? (c < 67072
              ? (c < 66979
                ? (c < 66964
                  ? (c >= 66956 && c <= 66962)
                  : (c <= 66965 || (c >= 66967 && c <= 66977)))
                : (c <= 66993 || (c < 67003
                  ? (c >= 66995 && c <= 67001)
                  : c <= 67004)))
              : (c <= 67382 || (c < 67456
                ? (c < 67424
                  ? (c >= 67392 && c <= 67413)
                  : c <= 67431)
                : (c <= 67461 || (c < 67506
                  ? (c >= 67463 && c <= 67504)
                  : c <= 67514)))))
            : (c <= 67589 || (c < 67680
              ? (c < 67639
                ? (c < 67594
                  ? c == 67592
                  : c <= 67637)
                : (c <= 67640 || (c < 67647
                  ? c == 67644
                  : c <= 67669)))
              : (c <= 67702 || (c < 67828
                ? (c < 67808
                  ? (c >= 67712 && c <= 67742)
                  : c <= 67826)
                : (c <= 67829 || (c < 67872
                  ? (c >= 67840 && c <= 67861)
                  : c <= 67883)))))))))))))));
}

static inline bool sym__alpha_identifier_character_set_5(int32_t c) {
  return (c < 6688
    ? (c < 2979
      ? (c < 2308
        ? (c < 1376
          ? (c < 750
            ? (c < 186
              ? (c < 'a'
                ? (c < 'A'
                  ? c == '$'
                  : (c <= 'Z' || c == '_'))
                : (c <= 'z' || (c < 181
                  ? c == 170
                  : c <= 181)))
              : (c <= 187 || (c < 710
                ? (c < 216
                  ? (c >= 192 && c <= 214)
                  : (c <= 246 || (c >= 248 && c <= 705)))
                : (c <= 721 || (c < 748
                  ? (c >= 736 && c <= 740)
                  : c <= 748)))))
            : (c <= 750 || (c < 908
              ? (c < 895
                ? (c < 886
                  ? (c >= 880 && c <= 884)
                  : (c <= 887 || (c >= 890 && c <= 893)))
                : (c <= 895 || (c < 904
                  ? c == 902
                  : c <= 906)))
              : (c <= 908 || (c < 1162
                ? (c < 931
                  ? (c >= 910 && c <= 929)
                  : (c <= 1013 || (c >= 1015 && c <= 1153)))
                : (c <= 1327 || (c < 1369
                  ? (c >= 1329 && c <= 1366)
                  : c <= 1369)))))))
          : (c <= 1416 || (c < 1969
            ? (c < 1765
              ? (c < 1646
                ? (c < 1519
                  ? (c >= 1488 && c <= 1514)
                  : (c <= 1522 || (c >= 1568 && c <= 1610)))
                : (c <= 1647 || (c < 1749
                  ? (c >= 1649 && c <= 1747)
                  : c <= 1749)))
              : (c <= 1766 || (c < 1808
                ? (c < 1786
                  ? (c >= 1774 && c <= 1775)
                  : (c <= 1788 || c == 1791))
                : (c <= 1808 || (c < 1869
                  ? (c >= 1810 && c <= 1839)
                  : c <= 1957)))))
            : (c <= 1969 || (c < 2088
              ? (c < 2048
                ? (c < 2036
                  ? (c >= 1994 && c <= 2026)
                  : (c <= 2037 || c == 2042))
                : (c <= 2069 || (c < 2084
                  ? c == 2074
                  : c <= 2084)))
              : (c <= 2088 || (c < 2160
                ? (c < 2144
                  ? (c >= 2112 && c <= 2136)
                  : c <= 2154)
                : (c <= 2183 || (c < 2208
                  ? (c >= 2185 && c <= 2190)
                  : c <= 2249)))))))))
        : (c <= 2361 || (c < 2693
          ? (c < 2527
            ? (c < 2451
              ? (c < 2417
                ? (c < 2384
                  ? c == 2365
                  : (c <= 2384 || (c >= 2392 && c <= 2401)))
                : (c <= 2432 || (c < 2447
                  ? (c >= 2437 && c <= 2444)
                  : c <= 2448)))
              : (c <= 2472 || (c < 2493
                ? (c < 2482
                  ? (c >= 2474 && c <= 2480)
                  : (c <= 2482 || (c >= 2486 && c <= 2489)))
                : (c <= 2493 || (c < 2524
                  ? c == 2510
                  : c <= 2525)))))
            : (c <= 2529 || (c < 2610
              ? (c < 2575
                ? (c < 2556
                  ? (c >= 2544 && c <= 2545)
                  : (c <= 2556 || (c >= 2565 && c <= 2570)))
                : (c <= 2576 || (c < 2602
                  ? (c >= 2579 && c <= 2600)
                  : c <= 2608)))
              : (c <= 2611 || (c < 2649
                ? (c < 2616
                  ? (c >= 2613 && c <= 2614)
                  : c <= 2617)
                : (c <= 2652 || (c < 2674
                  ? c == 2654
                  : c <= 2676)))))))
          : (c <= 2701 || (c < 2866
            ? (c < 2768
              ? (c < 2738
                ? (c < 2707
                  ? (c >= 2703 && c <= 2705)
                  : (c <= 2728 || (c >= 2730 && c <= 2736)))
                : (c <= 2739 || (c < 2749
                  ? (c >= 2741 && c <= 2745)
                  : c <= 2749)))
              : (c <= 2768 || (c < 2831
                ? (c < 2809
                  ? (c >= 2784 && c <= 2785)
                  : (c <= 2809 || (c >= 2821 && c <= 2828)))
                : (c <= 2832 || (c < 2858
                  ? (c >= 2835 && c <= 2856)
                  : c <= 2864)))))
            : (c <= 2867 || (c < 2949
              ? (c < 2911
                ? (c < 2877
                  ? (c >= 2869 && c <= 2873)
                  : (c <= 2877 || (c >= 2908 && c <= 2909)))
                : (c <= 2913 || (c < 2947
                  ? c == 2929
                  : c <= 2947)))
              : (c <= 2954 || (c < 2969
                ? (c < 2962
                  ? (c >= 2958 && c <= 2960)
                  : c <= 2965)
                : (c <= 2970 || (c < 2974
                  ? c == 2972
                  : c <= 2975)))))))))))
      : (c <= 2980 || (c < 4176
        ? (c < 3423
          ? (c < 3214
            ? (c < 3114
              ? (c < 3077
                ? (c < 2990
                  ? (c >= 2984 && c <= 2986)
                  : (c <= 3001 || c == 3024))
                : (c <= 3084 || (c < 3090
                  ? (c >= 3086 && c <= 3088)
                  : c <= 3112)))
              : (c <= 3129 || (c < 3168
                ? (c < 3160
                  ? c == 3133
                  : (c <= 3162 || c == 3165))
                : (c <= 3169 || (c < 3205
                  ? c == 3200
                  : c <= 3212)))))
            : (c <= 3216 || (c < 3313
              ? (c < 3261
                ? (c < 3242
                  ? (c >= 3218 && c <= 3240)
                  : (c <= 3251 || (c >= 3253 && c <= 3257)))
                : (c <= 3261 || (c < 3296
                  ? (c >= 3293 && c <= 3294)
                  : c <= 3297)))
              : (c <= 3314 || (c < 3389
                ? (c < 3342
                  ? (c >= 3332 && c <= 3340)
                  : (c <= 3344 || (c >= 3346 && c <= 3386)))
                : (c <= 3389 || (c < 3412
                  ? c == 3406
                  : c <= 3414)))))))
          : (c <= 3425 || (c < 3749
            ? (c < 3585
              ? (c < 3507
                ? (c < 3461
                  ? (c >= 3450 && c <= 3455)
                  : (c <= 3478 || (c >= 3482 && c <= 3505)))
                : (c <= 3515 || (c < 3520
                  ? c == 3517
                  : c <= 3526)))
              : (c <= 3632 || (c < 3716
                ? (c < 3648
                  ? (c >= 3634 && c <= 3635)
                  : (c <= 3654 || (c >= 3713 && c <= 3714)))
                : (c <= 3716 || (c < 3724
                  ? (c >= 3718 && c <= 3722)
                  : c <= 3747)))))
            : (c <= 3749 || (c < 3840
              ? (c < 3776
                ? (c < 3762
                  ? (c >= 3751 && c <= 3760)
                  : (c <= 3763 || c == 3773))
                : (c <= 3780 || (c < 3804
                  ? c == 3782
                  : c <= 3807)))
              : (c <= 3840 || (c < 3976
                ? (c < 3913
                  ? (c >= 3904 && c <= 3911)
                  : c <= 3948)
                : (c <= 3980 || (c < 4159
                  ? (c >= 4096 && c <= 4138)
                  : c <= 4159)))))))))
        : (c <= 4181 || (c < 4992
          ? (c < 4696
            ? (c < 4256
              ? (c < 4206
                ? (c < 4193
                  ? (c >= 4186 && c <= 4189)
                  : (c <= 4193 || (c >= 4197 && c <= 4198)))
                : (c <= 4208 || (c < 4238
                  ? (c >= 4213 && c <= 4225)
                  : c <= 4238)))
              : (c <= 4293 || (c < 4348
                ? (c < 4301
                  ? c == 4295
                  : (c <= 4301 || (c >= 4304 && c <= 4346)))
                : (c <= 4680 || (c < 4688
                  ? (c >= 4682 && c <= 4685)
                  : c <= 4694)))))
            : (c <= 4696 || (c < 4800
              ? (c < 4752
                ? (c < 4704
                  ? (c >= 4698 && c <= 4701)
                  : (c <= 4744 || (c >= 4746 && c <= 4749)))
                : (c <= 4784 || (c < 4792
                  ? (c >= 4786 && c <= 4789)
                  : c <= 4798)))
              : (c <= 4800 || (c < 4824
                ? (c < 4808
                  ? (c >= 4802 && c <= 4805)
                  : c <= 4822)
                : (c <= 4880 || (c < 4888
                  ? (c >= 4882 && c <= 4885)
                  : c <= 4954)))))))
          : (c <= 5007 || (c < 6103
            ? (c < 5870
              ? (c < 5743
                ? (c < 5112
                  ? (c >= 5024 && c <= 5109)
                  : (c <= 5117 || (c >= 5121 && c <= 5740)))
                : (c <= 5759 || (c < 5792
                  ? (c >= 5761 && c <= 5786)
                  : c <= 5866)))
              : (c <= 5880 || (c < 5984
                ? (c < 5919
                  ? (c >= 5888 && c <= 5905)
                  : (c <= 5937 || (c >= 5952 && c <= 5969)))
                : (c <= 5996 || (c < 6016
                  ? (c >= 5998 && c <= 6000)
                  : c <= 6067)))))
            : (c <= 6103 || (c < 6400
              ? (c < 6279
                ? (c < 6176
                  ? c == 6108
                  : (c <= 6264 || (c >= 6272 && c <= 6276)))
                : (c <= 6312 || (c < 6320
                  ? c == 6314
                  : c <= 6389)))
              : (c <= 6430 || (c < 6528
                ? (c < 6512
                  ? (c >= 6480 && c <= 6509)
                  : c <= 6516)
                : (c <= 6571 || (c < 6656
                  ? (c >= 6576 && c <= 6601)
                  : c <= 6678)))))))))))))
    : (c <= 6740 || (c < 43261
      ? (c < 11499
        ? (c < 8118
          ? (c < 7406
            ? (c < 7168
              ? (c < 7043
                ? (c < 6917
                  ? c == 6823
                  : (c <= 6963 || (c >= 6981 && c <= 6988)))
                : (c <= 7072 || (c < 7098
                  ? (c >= 7086 && c <= 7087)
                  : c <= 7141)))
              : (c <= 7203 || (c < 7312
                ? (c < 7258
                  ? (c >= 7245 && c <= 7247)
                  : (c <= 7293 || (c >= 7296 && c <= 7304)))
                : (c <= 7354 || (c < 7401
                  ? (c >= 7357 && c <= 7359)
                  : c <= 7404)))))
            : (c <= 7411 || (c < 8008
              ? (c < 7680
                ? (c < 7418
                  ? (c >= 7413 && c <= 7414)
                  : (c <= 7418 || (c >= 7424 && c <= 7615)))
                : (c <= 7957 || (c < 7968
                  ? (c >= 7960 && c <= 7965)
                  : c <= 8005)))
              : (c <= 8013 || (c < 8029
                ? (c < 8025
                  ? (c >= 8016 && c <= 8023)
                  : (c <= 8025 || c == 8027))
                : (c <= 8029 || (c < 8064
                  ? (c >= 8031 && c <= 8061)
                  : c <= 8116)))))))
          : (c <= 8124 || (c < 8458
            ? (c < 8178
              ? (c < 8144
                ? (c < 8130
                  ? c == 8126
                  : (c <= 8132 || (c >= 8134 && c <= 8140)))
                : (c <= 8147 || (c < 8160
                  ? (c >= 8150 && c <= 8155)
                  : c <= 8172)))
              : (c <= 8180 || (c < 8336
                ? (c < 8305
                  ? (c >= 8182 && c <= 8188)
                  : (c <= 8305 || c == 8319))
                : (c <= 8348 || (c < 8455
                  ? c == 8450
                  : c <= 8455)))))
            : (c <= 8467 || (c < 8495
              ? (c < 8486
                ? (c < 8473
                  ? c == 8469
                  : (c <= 8477 || c == 8484))
                : (c <= 8486 || (c < 8490
                  ? c == 8488
                  : c <= 8493)))
              : (c <= 8505 || (c < 8526
                ? (c < 8517
                  ? (c >= 8508 && c <= 8511)
                  : c <= 8521)
                : (c <= 8526 || (c < 11264
                  ? (c >= 8544 && c <= 8584)
                  : c <= 11492)))))))))
        : (c <= 11502 || (c < 12704
          ? (c < 11728
            ? (c < 11648
              ? (c < 11565
                ? (c < 11520
                  ? (c >= 11506 && c <= 11507)
                  : (c <= 11557 || c == 11559))
                : (c <= 11565 || (c < 11631
                  ? (c >= 11568 && c <= 11623)
                  : c <= 11631)))
              : (c <= 11670 || (c < 11704
                ? (c < 11688
                  ? (c >= 11680 && c <= 11686)
                  : (c <= 11694 || (c >= 11696 && c <= 11702)))
                : (c <= 11710 || (c < 11720
                  ? (c >= 11712 && c <= 11718)
                  : c <= 11726)))))
            : (c <= 11734 || (c < 12353
              ? (c < 12321
                ? (c < 11823
                  ? (c >= 11736 && c <= 11742)
                  : (c <= 11823 || (c >= 12293 && c <= 12295)))
                : (c <= 12329 || (c < 12344
                  ? (c >= 12337 && c <= 12341)
                  : c <= 12348)))
              : (c <= 12438 || (c < 12540
                ? (c < 12449
                  ? (c >= 12445 && c <= 12447)
                  : c <= 12538)
                : (c <= 12543 || (c < 12593
                  ? (c >= 12549 && c <= 12591)
                  : c <= 12686)))))))
          : (c <= 12735 || (c < 42786
            ? (c < 42240
              ? (c < 19968
                ? (c < 13312
                  ? (c >= 12784 && c <= 12799)
                  : (c <= 13312 || c == 19903))
                : (c <= 19968 || (c < 42192
                  ? (c >= 40959 && c <= 42124)
                  : c <= 42237)))
              : (c <= 42508 || (c < 42623
                ? (c < 42538
                  ? (c >= 42512 && c <= 42527)
                  : (c <= 42539 || (c >= 42560 && c <= 42606)))
                : (c <= 42653 || (c < 42775
                  ? (c >= 42656 && c <= 42735)
                  : c <= 42783)))))
            : (c <= 42888 || (c < 43015
              ? (c < 42965
                ? (c < 42960
                  ? (c >= 42891 && c <= 42954)
                  : (c <= 42961 || c == 42963))
                : (c <= 42969 || (c < 43011
                  ? (c >= 42994 && c <= 43009)
                  : c <= 43013)))
              : (c <= 43018 || (c < 43138
                ? (c < 43072
                  ? (c >= 43020 && c <= 43042)
                  : c <= 43123)
                : (c <= 43187 || (c < 43259
                  ? (c >= 43250 && c <= 43255)
                  : c <= 43259)))))))))))
      : (c <= 43262 || (c < 65345
        ? (c < 43816
          ? (c < 43646
            ? (c < 43494
              ? (c < 43396
                ? (c < 43312
                  ? (c >= 43274 && c <= 43301)
                  : (c <= 43334 || (c >= 43360 && c <= 43388)))
                : (c <= 43442 || (c < 43488
                  ? c == 43471
                  : c <= 43492)))
              : (c <= 43503 || (c < 43588
                ? (c < 43520
                  ? (c >= 43514 && c <= 43518)
                  : (c <= 43560 || (c >= 43584 && c <= 43586)))
                : (c <= 43595 || (c < 43642
                  ? (c >= 43616 && c <= 43638)
                  : c <= 43642)))))
            : (c <= 43695 || (c < 43744
              ? (c < 43712
                ? (c < 43701
                  ? c == 43697
                  : (c <= 43702 || (c >= 43705 && c <= 43709)))
                : (c <= 43712 || (c < 43739
                  ? c == 43714
                  : c <= 43741)))
              : (c <= 43754 || (c < 43785
                ? (c < 43777
                  ? (c >= 43762 && c <= 43764)
                  : c <= 43782)
                : (c <= 43790 || (c < 43808
                  ? (c >= 43793 && c <= 43798)
                  : c <= 43814)))))))
          : (c <= 43822 || (c < 64298
            ? (c < 55243
              ? (c < 44032
                ? (c < 43868
                  ? (c >= 43824 && c <= 43866)
                  : (c <= 43881 || (c >= 43888 && c <= 44002)))
                : (c <= 44032 || (c < 55216
                  ? c == 55203
                  : c <= 55238)))
              : (c <= 55291 || (c < 64275
                ? (c < 64112
                  ? (c >= 63744 && c <= 64109)
                  : (c <= 64217 || (c >= 64256 && c <= 64262)))
                : (c <= 64279 || (c < 64287
                  ? c == 64285
                  : c <= 64296)))))
            : (c <= 64310 || (c < 64848
              ? (c < 64323
                ? (c < 64318
                  ? (c >= 64312 && c <= 64316)
                  : (c <= 64318 || (c >= 64320 && c <= 64321)))
                : (c <= 64324 || (c < 64467
                  ? (c >= 64326 && c <= 64433)
                  : c <= 64829)))
              : (c <= 64911 || (c < 65136
                ? (c < 65008
                  ? (c >= 64914 && c <= 64967)
                  : c <= 65019)
                : (c <= 65140 || (c < 65313
                  ? (c >= 65142 && c <= 65276)
                  : c <= 65338)))))))))
        : (c <= 65370 || (c < 66864
          ? (c < 66176
            ? (c < 65549
              ? (c < 65490
                ? (c < 65474
                  ? (c >= 65382 && c <= 65470)
                  : (c <= 65479 || (c >= 65482 && c <= 65487)))
                : (c <= 65495 || (c < 65536
                  ? (c >= 65498 && c <= 65500)
                  : c <= 65547)))
              : (c <= 65574 || (c < 65616
                ? (c < 65596
                  ? (c >= 65576 && c <= 65594)
                  : (c <= 65597 || (c >= 65599 && c <= 65613)))
                : (c <= 65629 || (c < 65856
                  ? (c >= 65664 && c <= 65786)
                  : c <= 65908)))))
            : (c <= 66204 || (c < 66504
              ? (c < 66384
                ? (c < 66304
                  ? (c >= 66208 && c <= 66256)
                  : (c <= 66335 || (c >= 66349 && c <= 66378)))
                : (c <= 66421 || (c < 66464
                  ? (c >= 66432 && c <= 66461)
                  : c <= 66499)))
              : (c <= 66511 || (c < 66736
                ? (c < 66560
                  ? (c >= 66513 && c <= 66517)
                  : c <= 66717)
                : (c <= 66771 || (c < 66816
                  ? (c >= 66776 && c <= 66811)
                  : c <= 66855)))))))
          : (c <= 66915 || (c < 67506
            ? (c < 66995
              ? (c < 66964
                ? (c < 66940
                  ? (c >= 66928 && c <= 66938)
                  : (c <= 66954 || (c >= 66956 && c <= 66962)))
                : (c <= 66965 || (c < 66979
                  ? (c >= 66967 && c <= 66977)
                  : c <= 66993)))
              : (c <= 67001 || (c < 67424
                ? (c < 67072
                  ? (c >= 67003 && c <= 67004)
                  : (c <= 67382 || (c >= 67392 && c <= 67413)))
                : (c <= 67431 || (c < 67463
                  ? (c >= 67456 && c <= 67461)
                  : c <= 67504)))))
            : (c <= 67514 || (c < 67680
              ? (c < 67639
                ? (c < 67592
                  ? (c >= 67584 && c <= 67589)
                  : (c <= 67592 || (c >= 67594 && c <= 67637)))
                : (c <= 67640 || (c < 67647
                  ? c == 67644
                  : c <= 67669)))
              : (c <= 67702 || (c < 67828
                ? (c < 67808
                  ? (c >= 67712 && c <= 67742)
                  : c <= 67826)
                : (c <= 67829 || (c < 67872
                  ? (c >= 67840 && c <= 67861)
                  : c <= 67883)))))))))))))));
}

static inline bool sym__alpha_identifier_character_set_6(int32_t c) {
  return (c < 6400
    ? (c < 2979
      ? (c < 2392
        ? (c < 1568
          ? (c < 890
            ? (c < 710
              ? (c < 181
                ? (c < '_'
                  ? (c >= '$' && c <= 'Z')
                  : (c <= 'z' || c == 170))
                : (c <= 181 || (c < 192
                  ? (c >= 186 && c <= 187)
                  : c <= 705)))
              : (c <= 721 || (c < 750
                ? (c < 748
                  ? (c >= 736 && c <= 740)
                  : c <= 748)
                : (c <= 750 || (c < 886
                  ? (c >= 880 && c <= 884)
                  : c <= 887)))))
            : (c <= 893 || (c < 1162
              ? (c < 908
                ? (c < 902
                  ? c == 895
                  : (c <= 902 || (c >= 904 && c <= 906)))
                : (c <= 908 || (c < 931
                  ? (c >= 910 && c <= 929)
                  : c <= 1153)))
              : (c <= 1327 || (c < 1376
                ? (c < 1369
                  ? (c >= 1329 && c <= 1366)
                  : c <= 1369)
                : (c <= 1416 || (c < 1519
                  ? (c >= 1488 && c <= 1514)
                  : c <= 1522)))))))
          : (c <= 1610 || (c < 2042
            ? (c < 1808
              ? (c < 1765
                ? (c < 1649
                  ? (c >= 1646 && c <= 1647)
                  : (c <= 1747 || c == 1749))
                : (c <= 1766 || (c < 1786
                  ? (c >= 1774 && c <= 1775)
                  : c <= 1791)))
              : (c <= 1808 || (c < 1969
                ? (c < 1869
                  ? (c >= 1810 && c <= 1839)
                  : c <= 1957)
                : (c <= 1969 || (c < 2036
                  ? (c >= 1994 && c <= 2026)
                  : c <= 2037)))))
            : (c <= 2042 || (c < 2160
              ? (c < 2088
                ? (c < 2074
                  ? (c >= 2048 && c <= 2069)
                  : (c <= 2074 || c == 2084))
                : (c <= 2088 || (c < 2144
                  ? (c >= 2112 && c <= 2136)
                  : c <= 2154)))
              : (c <= 2183 || (c < 2308
                ? (c < 2208
                  ? (c >= 2185 && c <= 2190)
                  : c <= 2249)
                : (c <= 2361 || (c < 2384
                  ? c == 2365
                  : c <= 2384)))))))))
        : (c <= 2401 || (c < 2707
          ? (c < 2556
            ? (c < 2486
              ? (c < 2451
                ? (c < 2437
                  ? (c >= 2417 && c <= 2432)
                  : (c <= 2444 || (c >= 2447 && c <= 2448)))
                : (c <= 2472 || (c < 2482
                  ? (c >= 2474 && c <= 2480)
                  : c <= 2482)))
              : (c <= 2489 || (c < 2524
                ? (c < 2510
                  ? c == 2493
                  : c <= 2510)
                : (c <= 2525 || (c < 2544
                  ? (c >= 2527 && c <= 2529)
                  : c <= 2545)))))
            : (c <= 2556 || (c < 2616
              ? (c < 2602
                ? (c < 2575
                  ? (c >= 2565 && c <= 2570)
                  : (c <= 2576 || (c >= 2579 && c <= 2600)))
                : (c <= 2608 || (c < 2613
                  ? (c >= 2610 && c <= 2611)
                  : c <= 2614)))
              : (c <= 2617 || (c < 2674
                ? (c < 2654
                  ? (c >= 2649 && c <= 2652)
                  : c <= 2654)
                : (c <= 2676 || (c < 2703
                  ? (c >= 2693 && c <= 2701)
                  : c <= 2705)))))))
          : (c <= 2728 || (c < 2869
            ? (c < 2809
              ? (c < 2749
                ? (c < 2738
                  ? (c >= 2730 && c <= 2736)
                  : (c <= 2739 || (c >= 2741 && c <= 2745)))
                : (c <= 2749 || (c < 2784
                  ? c == 2768
                  : c <= 2785)))
              : (c <= 2809 || (c < 2835
                ? (c < 2831
                  ? (c >= 2821 && c <= 2828)
                  : c <= 2832)
                : (c <= 2856 || (c < 2866
                  ? (c >= 2858 && c <= 2864)
                  : c <= 2867)))))
            : (c <= 2873 || (c < 2949
              ? (c < 2911
                ? (c < 2908
                  ? c == 2877
                  : c <= 2909)
                : (c <= 2913 || (c < 2947
                  ? c == 2929
                  : c <= 2947)))
              : (c <= 2954 || (c < 2969
                ? (c < 2962
                  ? (c >= 2958 && c <= 2960)
                  : c <= 2965)
                : (c <= 2970 || (c < 2974
                  ? c == 2972
                  : c <= 2975)))))))))))
      : (c <= 2980 || (c < 3976
        ? (c < 3406
          ? (c < 3205
            ? (c < 3114
              ? (c < 3077
                ? (c < 2990
                  ? (c >= 2984 && c <= 2986)
                  : (c <= 3001 || c == 3024))
                : (c <= 3084 || (c < 3090
                  ? (c >= 3086 && c <= 3088)
                  : c <= 3112)))
              : (c <= 3129 || (c < 3165
                ? (c < 3160
                  ? c == 3133
                  : c <= 3162)
                : (c <= 3165 || (c < 3200
                  ? (c >= 3168 && c <= 3169)
                  : c <= 3200)))))
            : (c <= 3212 || (c < 3296
              ? (c < 3253
                ? (c < 3218
                  ? (c >= 3214 && c <= 3216)
                  : (c <= 3240 || (c >= 3242 && c <= 3251)))
                : (c <= 3257 || (c < 3293
                  ? c == 3261
                  : c <= 3294)))
              : (c <= 3297 || (c < 3342
                ? (c < 3332
                  ? (c >= 3313 && c <= 3314)
                  : c <= 3340)
                : (c <= 3344 || (c < 3389
                  ? (c >= 3346 && c <= 3386)
                  : c <= 3389)))))))
          : (c <= 3406 || (c < 3716
            ? (c < 3517
              ? (c < 3461
                ? (c < 3423
                  ? (c >= 3412 && c <= 3414)
                  : (c <= 3425 || (c >= 3450 && c <= 3455)))
                : (c <= 3478 || (c < 3507
                  ? (c >= 3482 && c <= 3505)
                  : c <= 3515)))
              : (c <= 3517 || (c < 3634
                ? (c < 3585
                  ? (c >= 3520 && c <= 3526)
                  : c <= 3632)
                : (c <= 3635 || (c < 3713
                  ? (c >= 3648 && c <= 3654)
                  : c <= 3714)))))
            : (c <= 3716 || (c < 3776
              ? (c < 3751
                ? (c < 3724
                  ? (c >= 3718 && c <= 3722)
                  : (c <= 3747 || c == 3749))
                : (c <= 3760 || (c < 3773
                  ? (c >= 3762 && c <= 3763)
                  : c <= 3773)))
              : (c <= 3780 || (c < 3840
                ? (c < 3804
                  ? c == 3782
                  : c <= 3807)
                : (c <= 3840 || (c < 3913
                  ? (c >= 3904 && c <= 3911)
                  : c <= 3948)))))))))
        : (c <= 3980 || (c < 4808
          ? (c < 4304
            ? (c < 4206
              ? (c < 4186
                ? (c < 4159
                  ? (c >= 4096 && c <= 4138)
                  : (c <= 4159 || (c >= 4176 && c <= 4181)))
                : (c <= 4189 || (c < 4197
                  ? c == 4193
                  : c <= 4198)))
              : (c <= 4208 || (c < 4256
                ? (c < 4238
                  ? (c >= 4213 && c <= 4225)
                  : c <= 4238)
                : (c <= 4293 || (c < 4301
                  ? c == 4295
                  : c <= 4301)))))
            : (c <= 4346 || (c < 4746
              ? (c < 4696
                ? (c < 4682
                  ? (c >= 4348 && c <= 4680)
                  : (c <= 4685 || (c >= 4688 && c <= 4694)))
                : (c <= 4696 || (c < 4704
                  ? (c >= 4698 && c <= 4701)
                  : c <= 4744)))
              : (c <= 4749 || (c < 4792
                ? (c < 4786
                  ? (c >= 4752 && c <= 4784)
                  : c <= 4789)
                : (c <= 4798 || (c < 4802
                  ? c == 4800
                  : c <= 4805)))))))
          : (c <= 4822 || (c < 5919
            ? (c < 5121
              ? (c < 4992
                ? (c < 4882
                  ? (c >= 4824 && c <= 4880)
                  : (c <= 4885 || (c >= 4888 && c <= 4954)))
                : (c <= 5007 || (c < 5112
                  ? (c >= 5024 && c <= 5109)
                  : c <= 5117)))
              : (c <= 5740 || (c < 5792
                ? (c < 5761
                  ? (c >= 5743 && c <= 5759)
                  : c <= 5786)
                : (c <= 5866 || (c < 5888
                  ? (c >= 5870 && c <= 5880)
                  : c <= 5905)))))
            : (c <= 5937 || (c < 6108
              ? (c < 5998
                ? (c < 5984
                  ? (c >= 5952 && c <= 5969)
                  : c <= 5996)
                : (c <= 6000 || (c < 6103
                  ? (c >= 6016 && c <= 6067)
                  : c <= 6103)))
              : (c <= 6108 || (c < 6279
                ? (c < 6272
                  ? (c >= 6176 && c <= 6264)
                  : c <= 6276)
                : (c <= 6312 || (c < 6320
                  ? c == 6314
                  : c <= 6389)))))))))))))
    : (c <= 6430 || (c < 43360
      ? (c < 11565
        ? (c < 7968
          ? (c < 7168
            ? (c < 6823
              ? (c < 6576
                ? (c < 6512
                  ? (c >= 6480 && c <= 6509)
                  : (c <= 6516 || (c >= 6528 && c <= 6571)))
                : (c <= 6601 || (c < 6688
                  ? (c >= 6656 && c <= 6678)
                  : c <= 6740)))
              : (c <= 6823 || (c < 7043
                ? (c < 6981
                  ? (c >= 6917 && c <= 6963)
                  : c <= 6988)
                : (c <= 7072 || (c < 7098
                  ? (c >= 7086 && c <= 7087)
                  : c <= 7141)))))
            : (c <= 7203 || (c < 7406
              ? (c < 7312
                ? (c < 7258
                  ? (c >= 7245 && c <= 7247)
                  : (c <= 7293 || (c >= 7296 && c <= 7304)))
                : (c <= 7354 || (c < 7401
                  ? (c >= 7357 && c <= 7359)
                  : c <= 7404)))
              : (c <= 7411 || (c < 7424
                ? (c < 7418
                  ? (c >= 7413 && c <= 7414)
                  : c <= 7418)
                : (c <= 7615 || (c < 7960
                  ? (c >= 7680 && c <= 7957)
                  : c <= 7965)))))))
          : (c <= 8005 || (c < 8150
            ? (c < 8064
              ? (c < 8027
                ? (c < 8016
                  ? (c >= 8008 && c <= 8013)
                  : (c <= 8023 || c == 8025))
                : (c <= 8027 || (c < 8031
                  ? c == 8029
                  : c <= 8061)))
              : (c <= 8116 || (c < 8130
                ? (c < 8126
                  ? (c >= 8118 && c <= 8124)
                  : c <= 8126)
                : (c <= 8132 || (c < 8144
                  ? (c >= 8134 && c <= 8140)
                  : c <= 8147)))))
            : (c <= 8155 || (c < 8450
              ? (c < 8305
                ? (c < 8178
                  ? (c >= 8160 && c <= 8172)
                  : (c <= 8180 || (c >= 8182 && c <= 8188)))
                : (c <= 8305 || (c < 8336
                  ? c == 8319
                  : c <= 8348)))
              : (c <= 8526 || (c < 11506
                ? (c < 11264
                  ? (c >= 8544 && c <= 8584)
                  : c <= 11502)
                : (c <= 11507 || (c < 11559
                  ? (c >= 11520 && c <= 11557)
                  : c <= 11559)))))))))
        : (c <= 11565 || (c < 40959
          ? (c < 12293
            ? (c < 11704
              ? (c < 11680
                ? (c < 11631
                  ? (c >= 11568 && c <= 11623)
                  : (c <= 11631 || (c >= 11648 && c <= 11670)))
                : (c <= 11686 || (c < 11696
                  ? (c >= 11688 && c <= 11694)
                  : c <= 11702)))
              : (c <= 11710 || (c < 11728
                ? (c < 11720
                  ? (c >= 11712 && c <= 11718)
                  : c <= 11726)
                : (c <= 11734 || (c < 11823
                  ? (c >= 11736 && c <= 11742)
                  : c <= 11823)))))
            : (c <= 12295 || (c < 12549
              ? (c < 12445
                ? (c < 12337
                  ? (c >= 12321 && c <= 12329)
                  : (c <= 12348 || (c >= 12353 && c <= 12438)))
                : (c <= 12447 || (c < 12540
                  ? (c >= 12449 && c <= 12538)
                  : c <= 12543)))
              : (c <= 12591 || (c < 12784
                ? (c < 12704
                  ? (c >= 12593 && c <= 12686)
                  : c <= 12735)
                : (c <= 12799 || (c < 19903
                  ? c == 13312
                  : c <= 19968)))))))
          : (c <= 42124 || (c < 42965
            ? (c < 42656
              ? (c < 42538
                ? (c < 42240
                  ? (c >= 42192 && c <= 42237)
                  : (c <= 42508 || (c >= 42512 && c <= 42527)))
                : (c <= 42539 || (c < 42623
                  ? (c >= 42560 && c <= 42606)
                  : c <= 42653)))
              : (c <= 42735 || (c < 42891
                ? (c < 42786
                  ? (c >= 42775 && c <= 42783)
                  : c <= 42888)
                : (c <= 42954 || (c < 42963
                  ? (c >= 42960 && c <= 42961)
                  : c <= 42963)))))
            : (c <= 42969 || (c < 43138
              ? (c < 43015
                ? (c < 43011
                  ? (c >= 42994 && c <= 43009)
                  : c <= 43013)
                : (c <= 43018 || (c < 43072
                  ? (c >= 43020 && c <= 43042)
                  : c <= 43123)))
              : (c <= 43187 || (c < 43261
                ? (c < 43259
                  ? (c >= 43250 && c <= 43255)
                  : c <= 43259)
                : (c <= 43262 || (c < 43312
                  ? (c >= 43274 && c <= 43301)
                  : c <= 43334)))))))))))
      : (c <= 43388 || (c < 65482
        ? (c < 43888
          ? (c < 43705
            ? (c < 43584
              ? (c < 43494
                ? (c < 43471
                  ? (c >= 43396 && c <= 43442)
                  : (c <= 43471 || (c >= 43488 && c <= 43492)))
                : (c <= 43503 || (c < 43520
                  ? (c >= 43514 && c <= 43518)
                  : c <= 43560)))
              : (c <= 43586 || (c < 43646
                ? (c < 43616
                  ? (c >= 43588 && c <= 43595)
                  : c <= 43642)
                : (c <= 43695 || (c < 43701
                  ? c == 43697
                  : c <= 43702)))))
            : (c <= 43709 || (c < 43785
              ? (c < 43744
                ? (c < 43714
                  ? c == 43712
                  : (c <= 43714 || (c >= 43739 && c <= 43741)))
                : (c <= 43754 || (c < 43777
                  ? (c >= 43762 && c <= 43764)
                  : c <= 43782)))
              : (c <= 43790 || (c < 43816
                ? (c < 43808
                  ? (c >= 43793 && c <= 43798)
                  : c <= 43814)
                : (c <= 43822 || (c < 43868
                  ? (c >= 43824 && c <= 43866)
                  : c <= 43881)))))))
          : (c <= 44002 || (c < 64320
            ? (c < 64256
              ? (c < 55243
                ? (c < 55203
                  ? c == 44032
                  : (c <= 55203 || (c >= 55216 && c <= 55238)))
                : (c <= 55291 || (c < 64112
                  ? (c >= 63744 && c <= 64109)
                  : c <= 64217)))
              : (c <= 64262 || (c < 64287
                ? (c < 64285
                  ? (c >= 64275 && c <= 64279)
                  : c <= 64285)
                : (c <= 64310 || (c < 64318
                  ? (c >= 64312 && c <= 64316)
                  : c <= 64318)))))
            : (c <= 64321 || (c < 65136
              ? (c < 64848
                ? (c < 64326
                  ? (c >= 64323 && c <= 64324)
                  : (c <= 64433 || (c >= 64467 && c <= 64829)))
                : (c <= 64911 || (c < 65008
                  ? (c >= 64914 && c <= 64967)
                  : c <= 65019)))
              : (c <= 65140 || (c < 65345
                ? (c < 65313
                  ? (c >= 65142 && c <= 65276)
                  : c <= 65338)
                : (c <= 65370 || (c < 65474
                  ? (c >= 65382 && c <= 65470)
                  : c <= 65479)))))))))
        : (c <= 65487 || (c < 66940
          ? (c < 66304
            ? (c < 65599
              ? (c < 65549
                ? (c < 65498
                  ? (c >= 65490 && c <= 65495)
                  : (c <= 65500 || (c >= 65536 && c <= 65547)))
                : (c <= 65574 || (c < 65596
                  ? (c >= 65576 && c <= 65594)
                  : c <= 65597)))
              : (c <= 65613 || (c < 65856
                ? (c < 65664
                  ? (c >= 65616 && c <= 65629)
                  : c <= 65786)
                : (c <= 65908 || (c < 66208
                  ? (c >= 66176 && c <= 66204)
                  : c <= 66256)))))
            : (c <= 66335 || (c < 66560
              ? (c < 66464
                ? (c < 66384
                  ? (c >= 66349 && c <= 66378)
                  : (c <= 66421 || (c >= 66432 && c <= 66461)))
                : (c <= 66499 || (c < 66513
                  ? (c >= 66504 && c <= 66511)
                  : c <= 66517)))
              : (c <= 66717 || (c < 66816
                ? (c < 66776
                  ? (c >= 66736 && c <= 66771)
                  : c <= 66811)
                : (c <= 66855 || (c < 66928
                  ? (c >= 66864 && c <= 66915)
                  : c <= 66938)))))))
          : (c <= 66954 || (c < 67584
            ? (c < 67072
              ? (c < 66979
                ? (c < 66964
                  ? (c >= 66956 && c <= 66962)
                  : (c <= 66965 || (c >= 66967 && c <= 66977)))
                : (c <= 66993 || (c < 67003
                  ? (c >= 66995 && c <= 67001)
                  : c <= 67004)))
              : (c <= 67382 || (c < 67456
                ? (c < 67424
                  ? (c >= 67392 && c <= 67413)
                  : c <= 67431)
                : (c <= 67461 || (c < 67506
                  ? (c >= 67463 && c <= 67504)
                  : c <= 67514)))))
            : (c <= 67589 || (c < 67680
              ? (c < 67639
                ? (c < 67594
                  ? c == 67592
                  : c <= 67637)
                : (c <= 67640 || (c < 67647
                  ? c == 67644
                  : c <= 67669)))
              : (c <= 67702 || (c < 67828
                ? (c < 67808
                  ? (c >= 67712 && c <= 67742)
                  : c <= 67826)
                : (c <= 67829 || (c < 67872
                  ? (c >= 67840 && c <= 67861)
                  : c <= 67883)))))))))))))));
}

static inline bool sym__alpha_identifier_character_set_7(int32_t c) {
  return (c < 6688
    ? (c < 2979
      ? (c < 2308
        ? (c < 1376
          ? (c < 750
            ? (c < 186
              ? (c < 'a'
                ? (c < '0'
                  ? c == '$'
                  : (c <= '9' || (c >= 'A' && c <= 'Z')))
                : (c <= 'z' || (c < 181
                  ? c == 170
                  : c <= 181)))
              : (c <= 187 || (c < 710
                ? (c < 216
                  ? (c >= 192 && c <= 214)
                  : (c <= 246 || (c >= 248 && c <= 705)))
                : (c <= 721 || (c < 748
                  ? (c >= 736 && c <= 740)
                  : c <= 748)))))
            : (c <= 750 || (c < 908
              ? (c < 895
                ? (c < 886
                  ? (c >= 880 && c <= 884)
                  : (c <= 887 || (c >= 890 && c <= 893)))
                : (c <= 895 || (c < 904
                  ? c == 902
                  : c <= 906)))
              : (c <= 908 || (c < 1162
                ? (c < 931
                  ? (c >= 910 && c <= 929)
                  : (c <= 1013 || (c >= 1015 && c <= 1153)))
                : (c <= 1327 || (c < 1369
                  ? (c >= 1329 && c <= 1366)
                  : c <= 1369)))))))
          : (c <= 1416 || (c < 1969
            ? (c < 1765
              ? (c < 1646
                ? (c < 1519
                  ? (c >= 1488 && c <= 1514)
                  : (c <= 1522 || (c >= 1568 && c <= 1610)))
                : (c <= 1647 || (c < 1749
                  ? (c >= 1649 && c <= 1747)
                  : c <= 1749)))
              : (c <= 1766 || (c < 1808
                ? (c < 1786
                  ? (c >= 1774 && c <= 1775)
                  : (c <= 1788 || c == 1791))
                : (c <= 1808 || (c < 1869
                  ? (c >= 1810 && c <= 1839)
                  : c <= 1957)))))
            : (c <= 1969 || (c < 2088
              ? (c < 2048
                ? (c < 2036
                  ? (c >= 1994 && c <= 2026)
                  : (c <= 2037 || c == 2042))
                : (c <= 2069 || (c < 2084
                  ? c == 2074
                  : c <= 2084)))
              : (c <= 2088 || (c < 2160
                ? (c < 2144
                  ? (c >= 2112 && c <= 2136)
                  : c <= 2154)
                : (c <= 2183 || (c < 2208
                  ? (c >= 2185 && c <= 2190)
                  : c <= 2249)))))))))
        : (c <= 2361 || (c < 2693
          ? (c < 2527
            ? (c < 2451
              ? (c < 2417
                ? (c < 2384
                  ? c == 2365
                  : (c <= 2384 || (c >= 2392 && c <= 2401)))
                : (c <= 2432 || (c < 2447
                  ? (c >= 2437 && c <= 2444)
                  : c <= 2448)))
              : (c <= 2472 || (c < 2493
                ? (c < 2482
                  ? (c >= 2474 && c <= 2480)
                  : (c <= 2482 || (c >= 2486 && c <= 2489)))
                : (c <= 2493 || (c < 2524
                  ? c == 2510
                  : c <= 2525)))))
            : (c <= 2529 || (c < 2610
              ? (c < 2575
                ? (c < 2556
                  ? (c >= 2544 && c <= 2545)
                  : (c <= 2556 || (c >= 2565 && c <= 2570)))
                : (c <= 2576 || (c < 2602
                  ? (c >= 2579 && c <= 2600)
                  : c <= 2608)))
              : (c <= 2611 || (c < 2649
                ? (c < 2616
                  ? (c >= 2613 && c <= 2614)
                  : c <= 2617)
                : (c <= 2652 || (c < 2674
                  ? c == 2654
                  : c <= 2676)))))))
          : (c <= 2701 || (c < 2866
            ? (c < 2768
              ? (c < 2738
                ? (c < 2707
                  ? (c >= 2703 && c <= 2705)
                  : (c <= 2728 || (c >= 2730 && c <= 2736)))
                : (c <= 2739 || (c < 2749
                  ? (c >= 2741 && c <= 2745)
                  : c <= 2749)))
              : (c <= 2768 || (c < 2831
                ? (c < 2809
                  ? (c >= 2784 && c <= 2785)
                  : (c <= 2809 || (c >= 2821 && c <= 2828)))
                : (c <= 2832 || (c < 2858
                  ? (c >= 2835 && c <= 2856)
                  : c <= 2864)))))
            : (c <= 2867 || (c < 2949
              ? (c < 2911
                ? (c < 2877
                  ? (c >= 2869 && c <= 2873)
                  : (c <= 2877 || (c >= 2908 && c <= 2909)))
                : (c <= 2913 || (c < 2947
                  ? c == 2929
                  : c <= 2947)))
              : (c <= 2954 || (c < 2969
                ? (c < 2962
                  ? (c >= 2958 && c <= 2960)
                  : c <= 2965)
                : (c <= 2970 || (c < 2974
                  ? c == 2972
                  : c <= 2975)))))))))))
      : (c <= 2980 || (c < 4176
        ? (c < 3423
          ? (c < 3214
            ? (c < 3114
              ? (c < 3077
                ? (c < 2990
                  ? (c >= 2984 && c <= 2986)
                  : (c <= 3001 || c == 3024))
                : (c <= 3084 || (c < 3090
                  ? (c >= 3086 && c <= 3088)
                  : c <= 3112)))
              : (c <= 3129 || (c < 3168
                ? (c < 3160
                  ? c == 3133
                  : (c <= 3162 || c == 3165))
                : (c <= 3169 || (c < 3205
                  ? c == 3200
                  : c <= 3212)))))
            : (c <= 3216 || (c < 3313
              ? (c < 3261
                ? (c < 3242
                  ? (c >= 3218 && c <= 3240)
                  : (c <= 3251 || (c >= 3253 && c <= 3257)))
                : (c <= 3261 || (c < 3296
                  ? (c >= 3293 && c <= 3294)
                  : c <= 3297)))
              : (c <= 3314 || (c < 3389
                ? (c < 3342
                  ? (c >= 3332 && c <= 3340)
                  : (c <= 3344 || (c >= 3346 && c <= 3386)))
                : (c <= 3389 || (c < 3412
                  ? c == 3406
                  : c <= 3414)))))))
          : (c <= 3425 || (c < 3749
            ? (c < 3585
              ? (c < 3507
                ? (c < 3461
                  ? (c >= 3450 && c <= 3455)
                  : (c <= 3478 || (c >= 3482 && c <= 3505)))
                : (c <= 3515 || (c < 3520
                  ? c == 3517
                  : c <= 3526)))
              : (c <= 3632 || (c < 3716
                ? (c < 3648
                  ? (c >= 3634 && c <= 3635)
                  : (c <= 3654 || (c >= 3713 && c <= 3714)))
                : (c <= 3716 || (c < 3724
                  ? (c >= 3718 && c <= 3722)
                  : c <= 3747)))))
            : (c <= 3749 || (c < 3840
              ? (c < 3776
                ? (c < 3762
                  ? (c >= 3751 && c <= 3760)
                  : (c <= 3763 || c == 3773))
                : (c <= 3780 || (c < 3804
                  ? c == 3782
                  : c <= 3807)))
              : (c <= 3840 || (c < 3976
                ? (c < 3913
                  ? (c >= 3904 && c <= 3911)
                  : c <= 3948)
                : (c <= 3980 || (c < 4159
                  ? (c >= 4096 && c <= 4138)
                  : c <= 4159)))))))))
        : (c <= 4181 || (c < 4992
          ? (c < 4696
            ? (c < 4256
              ? (c < 4206
                ? (c < 4193
                  ? (c >= 4186 && c <= 4189)
                  : (c <= 4193 || (c >= 4197 && c <= 4198)))
                : (c <= 4208 || (c < 4238
                  ? (c >= 4213 && c <= 4225)
                  : c <= 4238)))
              : (c <= 4293 || (c < 4348
                ? (c < 4301
                  ? c == 4295
                  : (c <= 4301 || (c >= 4304 && c <= 4346)))
                : (c <= 4680 || (c < 4688
                  ? (c >= 4682 && c <= 4685)
                  : c <= 4694)))))
            : (c <= 4696 || (c < 4800
              ? (c < 4752
                ? (c < 4704
                  ? (c >= 4698 && c <= 4701)
                  : (c <= 4744 || (c >= 4746 && c <= 4749)))
                : (c <= 4784 || (c < 4792
                  ? (c >= 4786 && c <= 4789)
                  : c <= 4798)))
              : (c <= 4800 || (c < 4824
                ? (c < 4808
                  ? (c >= 4802 && c <= 4805)
                  : c <= 4822)
                : (c <= 4880 || (c < 4888
                  ? (c >= 4882 && c <= 4885)
                  : c <= 4954)))))))
          : (c <= 5007 || (c < 6103
            ? (c < 5870
              ? (c < 5743
                ? (c < 5112
                  ? (c >= 5024 && c <= 5109)
                  : (c <= 5117 || (c >= 5121 && c <= 5740)))
                : (c <= 5759 || (c < 5792
                  ? (c >= 5761 && c <= 5786)
                  : c <= 5866)))
              : (c <= 5880 || (c < 5984
                ? (c < 5919
                  ? (c >= 5888 && c <= 5905)
                  : (c <= 5937 || (c >= 5952 && c <= 5969)))
                : (c <= 5996 || (c < 6016
                  ? (c >= 5998 && c <= 6000)
                  : c <= 6067)))))
            : (c <= 6103 || (c < 6400
              ? (c < 6279
                ? (c < 6176
                  ? c == 6108
                  : (c <= 6264 || (c >= 6272 && c <= 6276)))
                : (c <= 6312 || (c < 6320
                  ? c == 6314
                  : c <= 6389)))
              : (c <= 6430 || (c < 6528
                ? (c < 6512
                  ? (c >= 6480 && c <= 6509)
                  : c <= 6516)
                : (c <= 6571 || (c < 6656
                  ? (c >= 6576 && c <= 6601)
                  : c <= 6678)))))))))))))
    : (c <= 6740 || (c < 43261
      ? (c < 11499
        ? (c < 8118
          ? (c < 7406
            ? (c < 7168
              ? (c < 7043
                ? (c < 6917
                  ? c == 6823
                  : (c <= 6963 || (c >= 6981 && c <= 6988)))
                : (c <= 7072 || (c < 7098
                  ? (c >= 7086 && c <= 7087)
                  : c <= 7141)))
              : (c <= 7203 || (c < 7312
                ? (c < 7258
                  ? (c >= 7245 && c <= 7247)
                  : (c <= 7293 || (c >= 7296 && c <= 7304)))
                : (c <= 7354 || (c < 7401
                  ? (c >= 7357 && c <= 7359)
                  : c <= 7404)))))
            : (c <= 7411 || (c < 8008
              ? (c < 7680
                ? (c < 7418
                  ? (c >= 7413 && c <= 7414)
                  : (c <= 7418 || (c >= 7424 && c <= 7615)))
                : (c <= 7957 || (c < 7968
                  ? (c >= 7960 && c <= 7965)
                  : c <= 8005)))
              : (c <= 8013 || (c < 8029
                ? (c < 8025
                  ? (c >= 8016 && c <= 8023)
                  : (c <= 8025 || c == 8027))
                : (c <= 8029 || (c < 8064
                  ? (c >= 8031 && c <= 8061)
                  : c <= 8116)))))))
          : (c <= 8124 || (c < 8458
            ? (c < 8178
              ? (c < 8144
                ? (c < 8130
                  ? c == 8126
                  : (c <= 8132 || (c >= 8134 && c <= 8140)))
                : (c <= 8147 || (c < 8160
                  ? (c >= 8150 && c <= 8155)
                  : c <= 8172)))
              : (c <= 8180 || (c < 8336
                ? (c < 8305
                  ? (c >= 8182 && c <= 8188)
                  : (c <= 8305 || c == 8319))
                : (c <= 8348 || (c < 8455
                  ? c == 8450
                  : c <= 8455)))))
            : (c <= 8467 || (c < 8495
              ? (c < 8486
                ? (c < 8473
                  ? c == 8469
                  : (c <= 8477 || c == 8484))
                : (c <= 8486 || (c < 8490
                  ? c == 8488
                  : c <= 8493)))
              : (c <= 8505 || (c < 8526
                ? (c < 8517
                  ? (c >= 8508 && c <= 8511)
                  : c <= 8521)
                : (c <= 8526 || (c < 11264
                  ? (c >= 8544 && c <= 8584)
                  : c <= 11492)))))))))
        : (c <= 11502 || (c < 12704
          ? (c < 11728
            ? (c < 11648
              ? (c < 11565
                ? (c < 11520
                  ? (c >= 11506 && c <= 11507)
                  : (c <= 11557 || c == 11559))
                : (c <= 11565 || (c < 11631
                  ? (c >= 11568 && c <= 11623)
                  : c <= 11631)))
              : (c <= 11670 || (c < 11704
                ? (c < 11688
                  ? (c >= 11680 && c <= 11686)
                  : (c <= 11694 || (c >= 11696 && c <= 11702)))
                : (c <= 11710 || (c < 11720
                  ? (c >= 11712 && c <= 11718)
                  : c <= 11726)))))
            : (c <= 11734 || (c < 12353
              ? (c < 12321
                ? (c < 11823
                  ? (c >= 11736 && c <= 11742)
                  : (c <= 11823 || (c >= 12293 && c <= 12295)))
                : (c <= 12329 || (c < 12344
                  ? (c >= 12337 && c <= 12341)
                  : c <= 12348)))
              : (c <= 12438 || (c < 12540
                ? (c < 12449
                  ? (c >= 12445 && c <= 12447)
                  : c <= 12538)
                : (c <= 12543 || (c < 12593
                  ? (c >= 12549 && c <= 12591)
                  : c <= 12686)))))))
          : (c <= 12735 || (c < 42786
            ? (c < 42240
              ? (c < 19968
                ? (c < 13312
                  ? (c >= 12784 && c <= 12799)
                  : (c <= 13312 || c == 19903))
                : (c <= 19968 || (c < 42192
                  ? (c >= 40959 && c <= 42124)
                  : c <= 42237)))
              : (c <= 42508 || (c < 42623
                ? (c < 42538
                  ? (c >= 42512 && c <= 42527)
                  : (c <= 42539 || (c >= 42560 && c <= 42606)))
                : (c <= 42653 || (c < 42775
                  ? (c >= 42656 && c <= 42735)
                  : c <= 42783)))))
            : (c <= 42888 || (c < 43015
              ? (c < 42965
                ? (c < 42960
                  ? (c >= 42891 && c <= 42954)
                  : (c <= 42961 || c == 42963))
                : (c <= 42969 || (c < 43011
                  ? (c >= 42994 && c <= 43009)
                  : c <= 43013)))
              : (c <= 43018 || (c < 43138
                ? (c < 43072
                  ? (c >= 43020 && c <= 43042)
                  : c <= 43123)
                : (c <= 43187 || (c < 43259
                  ? (c >= 43250 && c <= 43255)
                  : c <= 43259)))))))))))
      : (c <= 43262 || (c < 65345
        ? (c < 43816
          ? (c < 43646
            ? (c < 43494
              ? (c < 43396
                ? (c < 43312
                  ? (c >= 43274 && c <= 43301)
                  : (c <= 43334 || (c >= 43360 && c <= 43388)))
                : (c <= 43442 || (c < 43488
                  ? c == 43471
                  : c <= 43492)))
              : (c <= 43503 || (c < 43588
                ? (c < 43520
                  ? (c >= 43514 && c <= 43518)
                  : (c <= 43560 || (c >= 43584 && c <= 43586)))
                : (c <= 43595 || (c < 43642
                  ? (c >= 43616 && c <= 43638)
                  : c <= 43642)))))
            : (c <= 43695 || (c < 43744
              ? (c < 43712
                ? (c < 43701
                  ? c == 43697
                  : (c <= 43702 || (c >= 43705 && c <= 43709)))
                : (c <= 43712 || (c < 43739
                  ? c == 43714
                  : c <= 43741)))
              : (c <= 43754 || (c < 43785
                ? (c < 43777
                  ? (c >= 43762 && c <= 43764)
                  : c <= 43782)
                : (c <= 43790 || (c < 43808
                  ? (c >= 43793 && c <= 43798)
                  : c <= 43814)))))))
          : (c <= 43822 || (c < 64298
            ? (c < 55243
              ? (c < 44032
                ? (c < 43868
                  ? (c >= 43824 && c <= 43866)
                  : (c <= 43881 || (c >= 43888 && c <= 44002)))
                : (c <= 44032 || (c < 55216
                  ? c == 55203
                  : c <= 55238)))
              : (c <= 55291 || (c < 64275
                ? (c < 64112
                  ? (c >= 63744 && c <= 64109)
                  : (c <= 64217 || (c >= 64256 && c <= 64262)))
                : (c <= 64279 || (c < 64287
                  ? c == 64285
                  : c <= 64296)))))
            : (c <= 64310 || (c < 64848
              ? (c < 64323
                ? (c < 64318
                  ? (c >= 64312 && c <= 64316)
                  : (c <= 64318 || (c >= 64320 && c <= 64321)))
                : (c <= 64324 || (c < 64467
                  ? (c >= 64326 && c <= 64433)
                  : c <= 64829)))
              : (c <= 64911 || (c < 65136
                ? (c < 65008
                  ? (c >= 64914 && c <= 64967)
                  : c <= 65019)
                : (c <= 65140 || (c < 65313
                  ? (c >= 65142 && c <= 65276)
                  : c <= 65338)))))))))
        : (c <= 65370 || (c < 66864
          ? (c < 66176
            ? (c < 65549
              ? (c < 65490
                ? (c < 65474
                  ? (c >= 65382 && c <= 65470)
                  : (c <= 65479 || (c >= 65482 && c <= 65487)))
                : (c <= 65495 || (c < 65536
                  ? (c >= 65498 && c <= 65500)
                  : c <= 65547)))
              : (c <= 65574 || (c < 65616
                ? (c < 65596
                  ? (c >= 65576 && c <= 65594)
                  : (c <= 65597 || (c >= 65599 && c <= 65613)))
                : (c <= 65629 || (c < 65856
                  ? (c >= 65664 && c <= 65786)
                  : c <= 65908)))))
            : (c <= 66204 || (c < 66504
              ? (c < 66384
                ? (c < 66304
                  ? (c >= 66208 && c <= 66256)
                  : (c <= 66335 || (c >= 66349 && c <= 66378)))
                : (c <= 66421 || (c < 66464
                  ? (c >= 66432 && c <= 66461)
                  : c <= 66499)))
              : (c <= 66511 || (c < 66736
                ? (c < 66560
                  ? (c >= 66513 && c <= 66517)
                  : c <= 66717)
                : (c <= 66771 || (c < 66816
                  ? (c >= 66776 && c <= 66811)
                  : c <= 66855)))))))
          : (c <= 66915 || (c < 67506
            ? (c < 66995
              ? (c < 66964
                ? (c < 66940
                  ? (c >= 66928 && c <= 66938)
                  : (c <= 66954 || (c >= 66956 && c <= 66962)))
                : (c <= 66965 || (c < 66979
                  ? (c >= 66967 && c <= 66977)
                  : c <= 66993)))
              : (c <= 67001 || (c < 67424
                ? (c < 67072
                  ? (c >= 67003 && c <= 67004)
                  : (c <= 67382 || (c >= 67392 && c <= 67413)))
                : (c <= 67431 || (c < 67463
                  ? (c >= 67456 && c <= 67461)
                  : c <= 67504)))))
            : (c <= 67514 || (c < 67680
              ? (c < 67639
                ? (c < 67592
                  ? (c >= 67584 && c <= 67589)
                  : (c <= 67592 || (c >= 67594 && c <= 67637)))
                : (c <= 67640 || (c < 67647
                  ? c == 67644
                  : c <= 67669)))
              : (c <= 67702 || (c < 67828
                ? (c < 67808
                  ? (c >= 67712 && c <= 67742)
                  : c <= 67826)
                : (c <= 67829 || (c < 67872
                  ? (c >= 67840 && c <= 67861)
                  : c <= 67883)))))))))))))));
}

static inline bool sym__alpha_identifier_character_set_8(int32_t c) {
  return (c < 6320
    ? (c < 2974
      ? (c < 2365
        ? (c < 1488
          ? (c < 880
            ? (c < 186
              ? (c < 'a'
                ? (c < '0'
                  ? c == '$'
                  : (c <= '9' || (c >= 'A' && c <= 'Z')))
                : (c <= 'z' || (c < 181
                  ? c == 170
                  : c <= 181)))
              : (c <= 187 || (c < 736
                ? (c < 710
                  ? (c >= 192 && c <= 705)
                  : c <= 721)
                : (c <= 740 || (c < 750
                  ? c == 748
                  : c <= 750)))))
            : (c <= 884 || (c < 910
              ? (c < 902
                ? (c < 890
                  ? (c >= 886 && c <= 887)
                  : (c <= 893 || c == 895))
                : (c <= 902 || (c < 908
                  ? (c >= 904 && c <= 906)
                  : c <= 908)))
              : (c <= 929 || (c < 1329
                ? (c < 1162
                  ? (c >= 931 && c <= 1153)
                  : c <= 1327)
                : (c <= 1366 || (c < 1376
                  ? c == 1369
                  : c <= 1416)))))))
          : (c <= 1514 || (c < 1994
            ? (c < 1774
              ? (c < 1649
                ? (c < 1568
                  ? (c >= 1519 && c <= 1522)
                  : (c <= 1610 || (c >= 1646 && c <= 1647)))
                : (c <= 1747 || (c < 1765
                  ? c == 1749
                  : c <= 1766)))
              : (c <= 1775 || (c < 1810
                ? (c < 1808
                  ? (c >= 1786 && c <= 1791)
                  : c <= 1808)
                : (c <= 1839 || (c < 1969
                  ? (c >= 1869 && c <= 1957)
                  : c <= 1969)))))
            : (c <= 2026 || (c < 2112
              ? (c < 2074
                ? (c < 2042
                  ? (c >= 2036 && c <= 2037)
                  : (c <= 2042 || (c >= 2048 && c <= 2069)))
                : (c <= 2074 || (c < 2088
                  ? c == 2084
                  : c <= 2088)))
              : (c <= 2136 || (c < 2185
                ? (c < 2160
                  ? (c >= 2144 && c <= 2154)
                  : c <= 2183)
                : (c <= 2190 || (c < 2308
                  ? (c >= 2208 && c <= 2249)
                  : c <= 2361)))))))))
        : (c <= 2365 || (c < 2693
          ? (c < 2527
            ? (c < 2474
              ? (c < 2437
                ? (c < 2392
                  ? c == 2384
                  : (c <= 2401 || (c >= 2417 && c <= 2432)))
                : (c <= 2444 || (c < 2451
                  ? (c >= 2447 && c <= 2448)
                  : c <= 2472)))
              : (c <= 2480 || (c < 2493
                ? (c < 2486
                  ? c == 2482
                  : c <= 2489)
                : (c <= 2493 || (c < 2524
                  ? c == 2510
                  : c <= 2525)))))
            : (c <= 2529 || (c < 2610
              ? (c < 2575
                ? (c < 2556
                  ? (c >= 2544 && c <= 2545)
                  : (c <= 2556 || (c >= 2565 && c <= 2570)))
                : (c <= 2576 || (c < 2602
                  ? (c >= 2579 && c <= 2600)
                  : c <= 2608)))
              : (c <= 2611 || (c < 2649
                ? (c < 2616
                  ? (c >= 2613 && c <= 2614)
                  : c <= 2617)
                : (c <= 2652 || (c < 2674
                  ? c == 2654
                  : c <= 2676)))))))
          : (c <= 2701 || (c < 2858
            ? (c < 2768
              ? (c < 2738
                ? (c < 2707
                  ? (c >= 2703 && c <= 2705)
                  : (c <= 2728 || (c >= 2730 && c <= 2736)))
                : (c <= 2739 || (c < 2749
                  ? (c >= 2741 && c <= 2745)
                  : c <= 2749)))
              : (c <= 2768 || (c < 2821
                ? (c < 2809
                  ? (c >= 2784 && c <= 2785)
                  : c <= 2809)
                : (c <= 2828 || (c < 2835
                  ? (c >= 2831 && c <= 2832)
                  : c <= 2856)))))
            : (c <= 2864 || (c < 2947
              ? (c < 2908
                ? (c < 2869
                  ? (c >= 2866 && c <= 2867)
                  : (c <= 2873 || c == 2877))
                : (c <= 2909 || (c < 2929
                  ? (c >= 2911 && c <= 2913)
                  : c <= 2929)))
              : (c <= 2947 || (c < 2962
                ? (c < 2958
                  ? (c >= 2949 && c <= 2954)
                  : c <= 2960)
                : (c <= 2965 || (c < 2972
                  ? (c >= 2969 && c <= 2970)
                  : c <= 2972)))))))))))
      : (c <= 2975 || (c < 3913
        ? (c < 3389
          ? (c < 3200
            ? (c < 3090
              ? (c < 3024
                ? (c < 2984
                  ? (c >= 2979 && c <= 2980)
                  : (c <= 2986 || (c >= 2990 && c <= 3001)))
                : (c <= 3024 || (c < 3086
                  ? (c >= 3077 && c <= 3084)
                  : c <= 3088)))
              : (c <= 3112 || (c < 3160
                ? (c < 3133
                  ? (c >= 3114 && c <= 3129)
                  : c <= 3133)
                : (c <= 3162 || (c < 3168
                  ? c == 3165
                  : c <= 3169)))))
            : (c <= 3200 || (c < 3293
              ? (c < 3242
                ? (c < 3214
                  ? (c >= 3205 && c <= 3212)
                  : (c <= 3216 || (c >= 3218 && c <= 3240)))
                : (c <= 3251 || (c < 3261
                  ? (c >= 3253 && c <= 3257)
                  : c <= 3261)))
              : (c <= 3294 || (c < 3332
                ? (c < 3313
                  ? (c >= 3296 && c <= 3297)
                  : c <= 3314)
                : (c <= 3340 || (c < 3346
                  ? (c >= 3342 && c <= 3344)
                  : c <= 3386)))))))
          : (c <= 3389 || (c < 3713
            ? (c < 3507
              ? (c < 3450
                ? (c < 3412
                  ? c == 3406
                  : (c <= 3414 || (c >= 3423 && c <= 3425)))
                : (c <= 3455 || (c < 3482
                  ? (c >= 3461 && c <= 3478)
                  : c <= 3505)))
              : (c <= 3515 || (c < 3585
                ? (c < 3520
                  ? c == 3517
                  : c <= 3526)
                : (c <= 3632 || (c < 3648
                  ? (c >= 3634 && c <= 3635)
                  : c <= 3654)))))
            : (c <= 3714 || (c < 3773
              ? (c < 3749
                ? (c < 3718
                  ? c == 3716
                  : (c <= 3722 || (c >= 3724 && c <= 3747)))
                : (c <= 3749 || (c < 3762
                  ? (c >= 3751 && c <= 3760)
                  : c <= 3763)))
              : (c <= 3773 || (c < 3804
                ? (c < 3782
                  ? (c >= 3776 && c <= 3780)
                  : c <= 3782)
                : (c <= 3807 || (c < 3904
                  ? c == 3840
                  : c <= 3911)))))))))
        : (c <= 3948 || (c < 4802
          ? (c < 4301
            ? (c < 4197
              ? (c < 4176
                ? (c < 4096
                  ? (c >= 3976 && c <= 3980)
                  : (c <= 4138 || c == 4159))
                : (c <= 4181 || (c < 4193
                  ? (c >= 4186 && c <= 4189)
                  : c <= 4193)))
              : (c <= 4198 || (c < 4238
                ? (c < 4213
                  ? (c >= 4206 && c <= 4208)
                  : c <= 4225)
                : (c <= 4238 || (c < 4295
                  ? (c >= 4256 && c <= 4293)
                  : c <= 4295)))))
            : (c <= 4301 || (c < 4704
              ? (c < 4688
                ? (c < 4348
                  ? (c >= 4304 && c <= 4346)
                  : (c <= 4680 || (c >= 4682 && c <= 4685)))
                : (c <= 4694 || (c < 4698
                  ? c == 4696
                  : c <= 4701)))
              : (c <= 4744 || (c < 4786
                ? (c < 4752
                  ? (c >= 4746 && c <= 4749)
                  : c <= 4784)
                : (c <= 4789 || (c < 4800
                  ? (c >= 4792 && c <= 4798)
                  : c <= 4800)))))))
          : (c <= 4805 || (c < 5888
            ? (c < 5112
              ? (c < 4888
                ? (c < 4824
                  ? (c >= 4808 && c <= 4822)
                  : (c <= 4880 || (c >= 4882 && c <= 4885)))
                : (c <= 4954 || (c < 5024
                  ? (c >= 4992 && c <= 5007)
                  : c <= 5109)))
              : (c <= 5117 || (c < 5761
                ? (c < 5743
                  ? (c >= 5121 && c <= 5740)
                  : c <= 5759)
                : (c <= 5786 || (c < 5870
                  ? (c >= 5792 && c <= 5866)
                  : c <= 5880)))))
            : (c <= 5905 || (c < 6103
              ? (c < 5984
                ? (c < 5952
                  ? (c >= 5919 && c <= 5937)
                  : c <= 5969)
                : (c <= 5996 || (c < 6016
                  ? (c >= 5998 && c <= 6000)
                  : c <= 6067)))
              : (c <= 6103 || (c < 6272
                ? (c < 6176
                  ? c == 6108
                  : c <= 6264)
                : (c <= 6276 || (c < 6314
                  ? (c >= 6279 && c <= 6312)
                  : c <= 6314)))))))))))))
    : (c <= 6389 || (c < 43360
      ? (c < 11559
        ? (c < 7960
          ? (c < 7098
            ? (c < 6688
              ? (c < 6528
                ? (c < 6480
                  ? (c >= 6400 && c <= 6430)
                  : (c <= 6509 || (c >= 6512 && c <= 6516)))
                : (c <= 6571 || (c < 6656
                  ? (c >= 6576 && c <= 6601)
                  : c <= 6678)))
              : (c <= 6740 || (c < 6981
                ? (c < 6917
                  ? c == 6823
                  : c <= 6963)
                : (c <= 6988 || (c < 7086
                  ? (c >= 7043 && c <= 7072)
                  : c <= 7087)))))
            : (c <= 7141 || (c < 7401
              ? (c < 7296
                ? (c < 7245
                  ? (c >= 7168 && c <= 7203)
                  : (c <= 7247 || (c >= 7258 && c <= 7293)))
                : (c <= 7304 || (c < 7357
                  ? (c >= 7312 && c <= 7354)
                  : c <= 7359)))
              : (c <= 7404 || (c < 7418
                ? (c < 7413
                  ? (c >= 7406 && c <= 7411)
                  : c <= 7414)
                : (c <= 7418 || (c < 7680
                  ? (c >= 7424 && c <= 7615)
                  : c <= 7957)))))))
          : (c <= 7965 || (c < 8144
            ? (c < 8031
              ? (c < 8025
                ? (c < 8008
                  ? (c >= 7968 && c <= 8005)
                  : (c <= 8013 || (c >= 8016 && c <= 8023)))
                : (c <= 8025 || (c < 8029
                  ? c == 8027
                  : c <= 8029)))
              : (c <= 8061 || (c < 8126
                ? (c < 8118
                  ? (c >= 8064 && c <= 8116)
                  : c <= 8124)
                : (c <= 8126 || (c < 8134
                  ? (c >= 8130 && c <= 8132)
                  : c <= 8140)))))
            : (c <= 8147 || (c < 8336
              ? (c < 8182
                ? (c < 8160
                  ? (c >= 8150 && c <= 8155)
                  : (c <= 8172 || (c >= 8178 && c <= 8180)))
                : (c <= 8188 || (c < 8319
                  ? c == 8305
                  : c <= 8319)))
              : (c <= 8348 || (c < 11264
                ? (c < 8544
                  ? (c >= 8450 && c <= 8526)
                  : c <= 8584)
                : (c <= 11502 || (c < 11520
                  ? (c >= 11506 && c <= 11507)
                  : c <= 11557)))))))))
        : (c <= 11559 || (c < 19903
          ? (c < 11823
            ? (c < 11696
              ? (c < 11648
                ? (c < 11568
                  ? c == 11565
                  : (c <= 11623 || c == 11631))
                : (c <= 11670 || (c < 11688
                  ? (c >= 11680 && c <= 11686)
                  : c <= 11694)))
              : (c <= 11702 || (c < 11720
                ? (c < 11712
                  ? (c >= 11704 && c <= 11710)
                  : c <= 11718)
                : (c <= 11726 || (c < 11736
                  ? (c >= 11728 && c <= 11734)
                  : c <= 11742)))))
            : (c <= 11823 || (c < 12540
              ? (c < 12353
                ? (c < 12321
                  ? (c >= 12293 && c <= 12295)
                  : (c <= 12329 || (c >= 12337 && c <= 12348)))
                : (c <= 12438 || (c < 12449
                  ? (c >= 12445 && c <= 12447)
                  : c <= 12538)))
              : (c <= 12543 || (c < 12704
                ? (c < 12593
                  ? (c >= 12549 && c <= 12591)
                  : c <= 12686)
                : (c <= 12735 || (c < 13312
                  ? (c >= 12784 && c <= 12799)
                  : c <= 13312)))))))
          : (c <= 19968 || (c < 42963
            ? (c < 42623
              ? (c < 42512
                ? (c < 42192
                  ? (c >= 40959 && c <= 42124)
                  : (c <= 42237 || (c >= 42240 && c <= 42508)))
                : (c <= 42527 || (c < 42560
                  ? (c >= 42538 && c <= 42539)
                  : c <= 42606)))
              : (c <= 42653 || (c < 42786
                ? (c < 42775
                  ? (c >= 42656 && c <= 42735)
                  : c <= 42783)
                : (c <= 42888 || (c < 42960
                  ? (c >= 42891 && c <= 42954)
                  : c <= 42961)))))
            : (c <= 42963 || (c < 43138
              ? (c < 43015
                ? (c < 42994
                  ? (c >= 42965 && c <= 42969)
                  : (c <= 43009 || (c >= 43011 && c <= 43013)))
                : (c <= 43018 || (c < 43072
                  ? (c >= 43020 && c <= 43042)
                  : c <= 43123)))
              : (c <= 43187 || (c < 43261
                ? (c < 43259
                  ? (c >= 43250 && c <= 43255)
                  : c <= 43259)
                : (c <= 43262 || (c < 43312
                  ? (c >= 43274 && c <= 43301)
                  : c <= 43334)))))))))))
      : (c <= 43388 || (c < 65482
        ? (c < 43888
          ? (c < 43705
            ? (c < 43584
              ? (c < 43494
                ? (c < 43471
                  ? (c >= 43396 && c <= 43442)
                  : (c <= 43471 || (c >= 43488 && c <= 43492)))
                : (c <= 43503 || (c < 43520
                  ? (c >= 43514 && c <= 43518)
                  : c <= 43560)))
              : (c <= 43586 || (c < 43646
                ? (c < 43616
                  ? (c >= 43588 && c <= 43595)
                  : c <= 43642)
                : (c <= 43695 || (c < 43701
                  ? c == 43697
                  : c <= 43702)))))
            : (c <= 43709 || (c < 43785
              ? (c < 43744
                ? (c < 43714
                  ? c == 43712
                  : (c <= 43714 || (c >= 43739 && c <= 43741)))
                : (c <= 43754 || (c < 43777
                  ? (c >= 43762 && c <= 43764)
                  : c <= 43782)))
              : (c <= 43790 || (c < 43816
                ? (c < 43808
                  ? (c >= 43793 && c <= 43798)
                  : c <= 43814)
                : (c <= 43822 || (c < 43868
                  ? (c >= 43824 && c <= 43866)
                  : c <= 43881)))))))
          : (c <= 44002 || (c < 64320
            ? (c < 64256
              ? (c < 55243
                ? (c < 55203
                  ? c == 44032
                  : (c <= 55203 || (c >= 55216 && c <= 55238)))
                : (c <= 55291 || (c < 64112
                  ? (c >= 63744 && c <= 64109)
                  : c <= 64217)))
              : (c <= 64262 || (c < 64287
                ? (c < 64285
                  ? (c >= 64275 && c <= 64279)
                  : c <= 64285)
                : (c <= 64310 || (c < 64318
                  ? (c >= 64312 && c <= 64316)
                  : c <= 64318)))))
            : (c <= 64321 || (c < 65136
              ? (c < 64848
                ? (c < 64326
                  ? (c >= 64323 && c <= 64324)
                  : (c <= 64433 || (c >= 64467 && c <= 64829)))
                : (c <= 64911 || (c < 65008
                  ? (c >= 64914 && c <= 64967)
                  : c <= 65019)))
              : (c <= 65140 || (c < 65345
                ? (c < 65313
                  ? (c >= 65142 && c <= 65276)
                  : c <= 65338)
                : (c <= 65370 || (c < 65474
                  ? (c >= 65382 && c <= 65470)
                  : c <= 65479)))))))))
        : (c <= 65487 || (c < 66940
          ? (c < 66304
            ? (c < 65599
              ? (c < 65549
                ? (c < 65498
                  ? (c >= 65490 && c <= 65495)
                  : (c <= 65500 || (c >= 65536 && c <= 65547)))
                : (c <= 65574 || (c < 65596
                  ? (c >= 65576 && c <= 65594)
                  : c <= 65597)))
              : (c <= 65613 || (c < 65856
                ? (c < 65664
                  ? (c >= 65616 && c <= 65629)
                  : c <= 65786)
                : (c <= 65908 || (c < 66208
                  ? (c >= 66176 && c <= 66204)
                  : c <= 66256)))))
            : (c <= 66335 || (c < 66560
              ? (c < 66464
                ? (c < 66384
                  ? (c >= 66349 && c <= 66378)
                  : (c <= 66421 || (c >= 66432 && c <= 66461)))
                : (c <= 66499 || (c < 66513
                  ? (c >= 66504 && c <= 66511)
                  : c <= 66517)))
              : (c <= 66717 || (c < 66816
                ? (c < 66776
                  ? (c >= 66736 && c <= 66771)
                  : c <= 66811)
                : (c <= 66855 || (c < 66928
                  ? (c >= 66864 && c <= 66915)
                  : c <= 66938)))))))
          : (c <= 66954 || (c < 67584
            ? (c < 67072
              ? (c < 66979
                ? (c < 66964
                  ? (c >= 66956 && c <= 66962)
                  : (c <= 66965 || (c >= 66967 && c <= 66977)))
                : (c <= 66993 || (c < 67003
                  ? (c >= 66995 && c <= 67001)
                  : c <= 67004)))
              : (c <= 67382 || (c < 67456
                ? (c < 67424
                  ? (c >= 67392 && c <= 67413)
                  : c <= 67431)
                : (c <= 67461 || (c < 67506
                  ? (c >= 67463 && c <= 67504)
                  : c <= 67514)))))
            : (c <= 67589 || (c < 67680
              ? (c < 67639
                ? (c < 67594
                  ? c == 67592
                  : c <= 67637)
                : (c <= 67640 || (c < 67647
                  ? c == 67644
                  : c <= 67669)))
              : (c <= 67702 || (c < 67828
                ? (c < 67808
                  ? (c >= 67712 && c <= 67742)
                  : c <= 67826)
                : (c <= 67829 || (c < 67872
                  ? (c >= 67840 && c <= 67861)
                  : c <= 67883)))))))))))))));
}

static inline bool sym__interpolation_identifier_character_set_1(int32_t c) {
  return (c < 6688
    ? (c < 2984
      ? (c < 2365
        ? (c < 1488
          ? (c < 880
            ? (c < 192
              ? (c < 170
                ? (c < '_'
                  ? (c >= 'A' && c <= 'Z')
                  : (c <= '_' || (c >= 'a' && c <= 'z')))
                : (c <= 170 || (c < 186
                  ? c == 181
                  : c <= 187)))
              : (c <= 214 || (c < 736
                ? (c < 248
                  ? (c >= 216 && c <= 246)
                  : (c <= 705 || (c >= 710 && c <= 721)))
                : (c <= 740 || (c < 750
                  ? c == 748
                  : c <= 750)))))
            : (c <= 884 || (c < 910
              ? (c < 902
                ? (c < 890
                  ? (c >= 886 && c <= 887)
                  : (c <= 893 || c == 895))
                : (c <= 902 || (c < 908
                  ? (c >= 904 && c <= 906)
                  : c <= 908)))
              : (c <= 929 || (c < 1329
                ? (c < 1015
                  ? (c >= 931 && c <= 1013)
                  : (c <= 1153 || (c >= 1162 && c <= 1327)))
                : (c <= 1366 || (c < 1376
                  ? c == 1369
                  : c <= 1416)))))))
          : (c <= 1514 || (c < 1994
            ? (c < 1774
              ? (c < 1649
                ? (c < 1568
                  ? (c >= 1519 && c <= 1522)
                  : (c <= 1610 || (c >= 1646 && c <= 1647)))
                : (c <= 1747 || (c < 1765
                  ? c == 1749
                  : c <= 1766)))
              : (c <= 1775 || (c < 1810
                ? (c < 1791
                  ? (c >= 1786 && c <= 1788)
                  : (c <= 1791 || c == 1808))
                : (c <= 1839 || (c < 1969
                  ? (c >= 1869 && c <= 1957)
                  : c <= 1969)))))
            : (c <= 2026 || (c < 2112
              ? (c < 2074
                ? (c < 2042
                  ? (c >= 2036 && c <= 2037)
                  : (c <= 2042 || (c >= 2048 && c <= 2069)))
                : (c <= 2074 || (c < 2088
                  ? c == 2084
                  : c <= 2088)))
              : (c <= 2136 || (c < 2185
                ? (c < 2160
                  ? (c >= 2144 && c <= 2154)
                  : c <= 2183)
                : (c <= 2190 || (c < 2308
                  ? (c >= 2208 && c <= 2249)
                  : c <= 2361)))))))))
        : (c <= 2365 || (c < 2703
          ? (c < 2544
            ? (c < 2474
              ? (c < 2437
                ? (c < 2392
                  ? c == 2384
                  : (c <= 2401 || (c >= 2417 && c <= 2432)))
                : (c <= 2444 || (c < 2451
                  ? (c >= 2447 && c <= 2448)
                  : c <= 2472)))
              : (c <= 2480 || (c < 2510
                ? (c < 2486
                  ? c == 2482
                  : (c <= 2489 || c == 2493))
                : (c <= 2510 || (c < 2527
                  ? (c >= 2524 && c <= 2525)
                  : c <= 2529)))))
            : (c <= 2545 || (c < 2613
              ? (c < 2579
                ? (c < 2565
                  ? c == 2556
                  : (c <= 2570 || (c >= 2575 && c <= 2576)))
                : (c <= 2600 || (c < 2610
                  ? (c >= 2602 && c <= 2608)
                  : c <= 2611)))
              : (c <= 2614 || (c < 2654
                ? (c < 2649
                  ? (c >= 2616 && c <= 2617)
                  : c <= 2652)
                : (c <= 2654 || (c < 2693
                  ? (c >= 2674 && c <= 2676)
                  : c <= 2701)))))))
          : (c <= 2705 || (c < 2869
            ? (c < 2784
              ? (c < 2741
                ? (c < 2730
                  ? (c >= 2707 && c <= 2728)
                  : (c <= 2736 || (c >= 2738 && c <= 2739)))
                : (c <= 2745 || (c < 2768
                  ? c == 2749
                  : c <= 2768)))
              : (c <= 2785 || (c < 2835
                ? (c < 2821
                  ? c == 2809
                  : (c <= 2828 || (c >= 2831 && c <= 2832)))
                : (c <= 2856 || (c < 2866
                  ? (c >= 2858 && c <= 2864)
                  : c <= 2867)))))
            : (c <= 2873 || (c < 2958
              ? (c < 2929
                ? (c < 2908
                  ? c == 2877
                  : (c <= 2909 || (c >= 2911 && c <= 2913)))
                : (c <= 2929 || (c < 2949
                  ? c == 2947
                  : c <= 2954)))
              : (c <= 2960 || (c < 2972
                ? (c < 2969
                  ? (c >= 2962 && c <= 2965)
                  : c <= 2970)
                : (c <= 2972 || (c < 2979
                  ? (c >= 2974 && c <= 2975)
                  : c <= 2980)))))))))))
      : (c <= 2986 || (c < 4176
        ? (c < 3423
          ? (c < 3218
            ? (c < 3133
              ? (c < 3086
                ? (c < 3024
                  ? (c >= 2990 && c <= 3001)
                  : (c <= 3024 || (c >= 3077 && c <= 3084)))
                : (c <= 3088 || (c < 3114
                  ? (c >= 3090 && c <= 3112)
                  : c <= 3129)))
              : (c <= 3133 || (c < 3200
                ? (c < 3165
                  ? (c >= 3160 && c <= 3162)
                  : (c <= 3165 || (c >= 3168 && c <= 3169)))
                : (c <= 3200 || (c < 3214
                  ? (c >= 3205 && c <= 3212)
                  : c <= 3216)))))
            : (c <= 3240 || (c < 3332
              ? (c < 3293
                ? (c < 3253
                  ? (c >= 3242 && c <= 3251)
                  : (c <= 3257 || c == 3261))
                : (c <= 3294 || (c < 3313
                  ? (c >= 3296 && c <= 3297)
                  : c <= 3314)))
              : (c <= 3340 || (c < 3389
                ? (c < 3346
                  ? (c >= 3342 && c <= 3344)
                  : c <= 3386)
                : (c <= 3389 || (c < 3412
                  ? c == 3406
                  : c <= 3414)))))))
          : (c <= 3425 || (c < 3749
            ? (c < 3585
              ? (c < 3507
                ? (c < 3461
                  ? (c >= 3450 && c <= 3455)
                  : (c <= 3478 || (c >= 3482 && c <= 3505)))
                : (c <= 3515 || (c < 3520
                  ? c == 3517
                  : c <= 3526)))
              : (c <= 3632 || (c < 3716
                ? (c < 3648
                  ? (c >= 3634 && c <= 3635)
                  : (c <= 3654 || (c >= 3713 && c <= 3714)))
                : (c <= 3716 || (c < 3724
                  ? (c >= 3718 && c <= 3722)
                  : c <= 3747)))))
            : (c <= 3749 || (c < 3840
              ? (c < 3776
                ? (c < 3762
                  ? (c >= 3751 && c <= 3760)
                  : (c <= 3763 || c == 3773))
                : (c <= 3780 || (c < 3804
                  ? c == 3782
                  : c <= 3807)))
              : (c <= 3840 || (c < 3976
                ? (c < 3913
                  ? (c >= 3904 && c <= 3911)
                  : c <= 3948)
                : (c <= 3980 || (c < 4159
                  ? (c >= 4096 && c <= 4138)
                  : c <= 4159)))))))))
        : (c <= 4181 || (c < 4992
          ? (c < 4696
            ? (c < 4256
              ? (c < 4206
                ? (c < 4193
                  ? (c >= 4186 && c <= 4189)
                  : (c <= 4193 || (c >= 4197 && c <= 4198)))
                : (c <= 4208 || (c < 4238
                  ? (c >= 4213 && c <= 4225)
                  : c <= 4238)))
              : (c <= 4293 || (c < 4348
                ? (c < 4301
                  ? c == 4295
                  : (c <= 4301 || (c >= 4304 && c <= 4346)))
                : (c <= 4680 || (c < 4688
                  ? (c >= 4682 && c <= 4685)
                  : c <= 4694)))))
            : (c <= 4696 || (c < 4800
              ? (c < 4752
                ? (c < 4704
                  ? (c >= 4698 && c <= 4701)
                  : (c <= 4744 || (c >= 4746 && c <= 4749)))
                : (c <= 4784 || (c < 4792
                  ? (c >= 4786 && c <= 4789)
                  : c <= 4798)))
              : (c <= 4800 || (c < 4824
                ? (c < 4808
                  ? (c >= 4802 && c <= 4805)
                  : c <= 4822)
                : (c <= 4880 || (c < 4888
                  ? (c >= 4882 && c <= 4885)
                  : c <= 4954)))))))
          : (c <= 5007 || (c < 6103
            ? (c < 5870
              ? (c < 5743
                ? (c < 5112
                  ? (c >= 5024 && c <= 5109)
                  : (c <= 5117 || (c >= 5121 && c <= 5740)))
                : (c <= 5759 || (c < 5792
                  ? (c >= 5761 && c <= 5786)
                  : c <= 5866)))
              : (c <= 5880 || (c < 5984
                ? (c < 5919
                  ? (c >= 5888 && c <= 5905)
                  : (c <= 5937 || (c >= 5952 && c <= 5969)))
                : (c <= 5996 || (c < 6016
                  ? (c >= 5998 && c <= 6000)
                  : c <= 6067)))))
            : (c <= 6103 || (c < 6400
              ? (c < 6279
                ? (c < 6176
                  ? c == 6108
                  : (c <= 6264 || (c >= 6272 && c <= 6276)))
                : (c <= 6312 || (c < 6320
                  ? c == 6314
                  : c <= 6389)))
              : (c <= 6430 || (c < 6528
                ? (c < 6512
                  ? (c >= 6480 && c <= 6509)
                  : c <= 6516)
                : (c <= 6571 || (c < 6656
                  ? (c >= 6576 && c <= 6601)
                  : c <= 6678)))))))))))))
    : (c <= 6740 || (c < 43261
      ? (c < 11499
        ? (c < 8118
          ? (c < 7406
            ? (c < 7168
              ? (c < 7043
                ? (c < 6917
                  ? c == 6823
                  : (c <= 6963 || (c >= 6981 && c <= 6988)))
                : (c <= 7072 || (c < 7098
                  ? (c >= 7086 && c <= 7087)
                  : c <= 7141)))
              : (c <= 7203 || (c < 7312
                ? (c < 7258
                  ? (c >= 7245 && c <= 7247)
                  : (c <= 7293 || (c >= 7296 && c <= 7304)))
                : (c <= 7354 || (c < 7401
                  ? (c >= 7357 && c <= 7359)
                  : c <= 7404)))))
            : (c <= 7411 || (c < 8008
              ? (c < 7680
                ? (c < 7418
                  ? (c >= 7413 && c <= 7414)
                  : (c <= 7418 || (c >= 7424 && c <= 7615)))
                : (c <= 7957 || (c < 7968
                  ? (c >= 7960 && c <= 7965)
                  : c <= 8005)))
              : (c <= 8013 || (c < 8029
                ? (c < 8025
                  ? (c >= 8016 && c <= 8023)
                  : (c <= 8025 || c == 8027))
                : (c <= 8029 || (c < 8064
                  ? (c >= 8031 && c <= 8061)
                  : c <= 8116)))))))
          : (c <= 8124 || (c < 8458
            ? (c < 8178
              ? (c < 8144
                ? (c < 8130
                  ? c == 8126
                  : (c <= 8132 || (c >= 8134 && c <= 8140)))
                : (c <= 8147 || (c < 8160
                  ? (c >= 8150 && c <= 8155)
                  : c <= 8172)))
              : (c <= 8180 || (c < 8336
                ? (c < 8305
                  ? (c >= 8182 && c <= 8188)
                  : (c <= 8305 || c == 8319))
                : (c <= 8348 || (c < 8455
                  ? c == 8450
                  : c <= 8455)))))
            : (c <= 8467 || (c < 8495
              ? (c < 8486
                ? (c < 8473
                  ? c == 8469
                  : (c <= 8477 || c == 8484))
                : (c <= 8486 || (c < 8490
                  ? c == 8488
                  : c <= 8493)))
              : (c <= 8505 || (c < 8526
                ? (c < 8517
                  ? (c >= 8508 && c <= 8511)
                  : c <= 8521)
                : (c <= 8526 || (c < 11264
                  ? (c >= 8544 && c <= 8584)
                  : c <= 11492)))))))))
        : (c <= 11502 || (c < 12704
          ? (c < 11728
            ? (c < 11648
              ? (c < 11565
                ? (c < 11520
                  ? (c >= 11506 && c <= 11507)
                  : (c <= 11557 || c == 11559))
                : (c <= 11565 || (c < 11631
                  ? (c >= 11568 && c <= 11623)
                  : c <= 11631)))
              : (c <= 11670 || (c < 11704
                ? (c < 11688
                  ? (c >= 11680 && c <= 11686)
                  : (c <= 11694 || (c >= 11696 && c <= 11702)))
                : (c <= 11710 || (c < 11720
                  ? (c >= 11712 && c <= 11718)
                  : c <= 11726)))))
            : (c <= 11734 || (c < 12353
              ? (c < 12321
                ? (c < 11823
                  ? (c >= 11736 && c <= 11742)
                  : (c <= 11823 || (c >= 12293 && c <= 12295)))
                : (c <= 12329 || (c < 12344
                  ? (c >= 12337 && c <= 12341)
                  : c <= 12348)))
              : (c <= 12438 || (c < 12540
                ? (c < 12449
                  ? (c >= 12445 && c <= 12447)
                  : c <= 12538)
                : (c <= 12543 || (c < 12593
                  ? (c >= 12549 && c <= 12591)
                  : c <= 12686)))))))
          : (c <= 12735 || (c < 42786
            ? (c < 42240
              ? (c < 19968
                ? (c < 13312
                  ? (c >= 12784 && c <= 12799)
                  : (c <= 13312 || c == 19903))
                : (c <= 19968 || (c < 42192
                  ? (c >= 40959 && c <= 42124)
                  : c <= 42237)))
              : (c <= 42508 || (c < 42623
                ? (c < 42538
                  ? (c >= 42512 && c <= 42527)
                  : (c <= 42539 || (c >= 42560 && c <= 42606)))
                : (c <= 42653 || (c < 42775
                  ? (c >= 42656 && c <= 42735)
                  : c <= 42783)))))
            : (c <= 42888 || (c < 43015
              ? (c < 42965
                ? (c < 42960
                  ? (c >= 42891 && c <= 42954)
                  : (c <= 42961 || c == 42963))
                : (c <= 42969 || (c < 43011
                  ? (c >= 42994 && c <= 43009)
                  : c <= 43013)))
              : (c <= 43018 || (c < 43138
                ? (c < 43072
                  ? (c >= 43020 && c <= 43042)
                  : c <= 43123)
                : (c <= 43187 || (c < 43259
                  ? (c >= 43250 && c <= 43255)
                  : c <= 43259)))))))))))
      : (c <= 43262 || (c < 65345
        ? (c < 43816
          ? (c < 43646
            ? (c < 43494
              ? (c < 43396
                ? (c < 43312
                  ? (c >= 43274 && c <= 43301)
                  : (c <= 43334 || (c >= 43360 && c <= 43388)))
                : (c <= 43442 || (c < 43488
                  ? c == 43471
                  : c <= 43492)))
              : (c <= 43503 || (c < 43588
                ? (c < 43520
                  ? (c >= 43514 && c <= 43518)
                  : (c <= 43560 || (c >= 43584 && c <= 43586)))
                : (c <= 43595 || (c < 43642
                  ? (c >= 43616 && c <= 43638)
                  : c <= 43642)))))
            : (c <= 43695 || (c < 43744
              ? (c < 43712
                ? (c < 43701
                  ? c == 43697
                  : (c <= 43702 || (c >= 43705 && c <= 43709)))
                : (c <= 43712 || (c < 43739
                  ? c == 43714
                  : c <= 43741)))
              : (c <= 43754 || (c < 43785
                ? (c < 43777
                  ? (c >= 43762 && c <= 43764)
                  : c <= 43782)
                : (c <= 43790 || (c < 43808
                  ? (c >= 43793 && c <= 43798)
                  : c <= 43814)))))))
          : (c <= 43822 || (c < 64298
            ? (c < 55243
              ? (c < 44032
                ? (c < 43868
                  ? (c >= 43824 && c <= 43866)
                  : (c <= 43881 || (c >= 43888 && c <= 44002)))
                : (c <= 44032 || (c < 55216
                  ? c == 55203
                  : c <= 55238)))
              : (c <= 55291 || (c < 64275
                ? (c < 64112
                  ? (c >= 63744 && c <= 64109)
                  : (c <= 64217 || (c >= 64256 && c <= 64262)))
                : (c <= 64279 || (c < 64287
                  ? c == 64285
                  : c <= 64296)))))
            : (c <= 64310 || (c < 64848
              ? (c < 64323
                ? (c < 64318
                  ? (c >= 64312 && c <= 64316)
                  : (c <= 64318 || (c >= 64320 && c <= 64321)))
                : (c <= 64324 || (c < 64467
                  ? (c >= 64326 && c <= 64433)
                  : c <= 64829)))
              : (c <= 64911 || (c < 65136
                ? (c < 65008
                  ? (c >= 64914 && c <= 64967)
                  : c <= 65019)
                : (c <= 65140 || (c < 65313
                  ? (c >= 65142 && c <= 65276)
                  : c <= 65338)))))))))
        : (c <= 65370 || (c < 66864
          ? (c < 66176
            ? (c < 65549
              ? (c < 65490
                ? (c < 65474
                  ? (c >= 65382 && c <= 65470)
                  : (c <= 65479 || (c >= 65482 && c <= 65487)))
                : (c <= 65495 || (c < 65536
                  ? (c >= 65498 && c <= 65500)
                  : c <= 65547)))
              : (c <= 65574 || (c < 65616
                ? (c < 65596
                  ? (c >= 65576 && c <= 65594)
                  : (c <= 65597 || (c >= 65599 && c <= 65613)))
                : (c <= 65629 || (c < 65856
                  ? (c >= 65664 && c <= 65786)
                  : c <= 65908)))))
            : (c <= 66204 || (c < 66504
              ? (c < 66384
                ? (c < 66304
                  ? (c >= 66208 && c <= 66256)
                  : (c <= 66335 || (c >= 66349 && c <= 66378)))
                : (c <= 66421 || (c < 66464
                  ? (c >= 66432 && c <= 66461)
                  : c <= 66499)))
              : (c <= 66511 || (c < 66736
                ? (c < 66560
                  ? (c >= 66513 && c <= 66517)
                  : c <= 66717)
                : (c <= 66771 || (c < 66816
                  ? (c >= 66776 && c <= 66811)
                  : c <= 66855)))))))
          : (c <= 66915 || (c < 67506
            ? (c < 66995
              ? (c < 66964
                ? (c < 66940
                  ? (c >= 66928 && c <= 66938)
                  : (c <= 66954 || (c >= 66956 && c <= 66962)))
                : (c <= 66965 || (c < 66979
                  ? (c >= 66967 && c <= 66977)
                  : c <= 66993)))
              : (c <= 67001 || (c < 67424
                ? (c < 67072
                  ? (c >= 67003 && c <= 67004)
                  : (c <= 67382 || (c >= 67392 && c <= 67413)))
                : (c <= 67431 || (c < 67463
                  ? (c >= 67456 && c <= 67461)
                  : c <= 67504)))))
            : (c <= 67514 || (c < 67680
              ? (c < 67639
                ? (c < 67592
                  ? (c >= 67584 && c <= 67589)
                  : (c <= 67592 || (c >= 67594 && c <= 67637)))
                : (c <= 67640 || (c < 67647
                  ? c == 67644
                  : c <= 67669)))
              : (c <= 67702 || (c < 67828
                ? (c < 67808
                  ? (c >= 67712 && c <= 67742)
                  : c <= 67826)
                : (c <= 67829 || (c < 67872
                  ? (c >= 67840 && c <= 67861)
                  : c <= 67883)))))))))))))));
}

static inline bool sym__interpolation_identifier_character_set_2(int32_t c) {
  return (c < 6688
    ? (c < 2979
      ? (c < 2308
        ? (c < 1376
          ? (c < 750
            ? (c < 186
              ? (c < 'a'
                ? (c < 'A'
                  ? (c >= '0' && c <= '9')
                  : (c <= 'Z' || c == '_'))
                : (c <= 'z' || (c < 181
                  ? c == 170
                  : c <= 181)))
              : (c <= 187 || (c < 710
                ? (c < 216
                  ? (c >= 192 && c <= 214)
                  : (c <= 246 || (c >= 248 && c <= 705)))
                : (c <= 721 || (c < 748
                  ? (c >= 736 && c <= 740)
                  : c <= 748)))))
            : (c <= 750 || (c < 908
              ? (c < 895
                ? (c < 886
                  ? (c >= 880 && c <= 884)
                  : (c <= 887 || (c >= 890 && c <= 893)))
                : (c <= 895 || (c < 904
                  ? c == 902
                  : c <= 906)))
              : (c <= 908 || (c < 1162
                ? (c < 931
                  ? (c >= 910 && c <= 929)
                  : (c <= 1013 || (c >= 1015 && c <= 1153)))
                : (c <= 1327 || (c < 1369
                  ? (c >= 1329 && c <= 1366)
                  : c <= 1369)))))))
          : (c <= 1416 || (c < 1969
            ? (c < 1765
              ? (c < 1646
                ? (c < 1519
                  ? (c >= 1488 && c <= 1514)
                  : (c <= 1522 || (c >= 1568 && c <= 1610)))
                : (c <= 1647 || (c < 1749
                  ? (c >= 1649 && c <= 1747)
                  : c <= 1749)))
              : (c <= 1766 || (c < 1808
                ? (c < 1786
                  ? (c >= 1774 && c <= 1775)
                  : (c <= 1788 || c == 1791))
                : (c <= 1808 || (c < 1869
                  ? (c >= 1810 && c <= 1839)
                  : c <= 1957)))))
            : (c <= 1969 || (c < 2088
              ? (c < 2048
                ? (c < 2036
                  ? (c >= 1994 && c <= 2026)
                  : (c <= 2037 || c == 2042))
                : (c <= 2069 || (c < 2084
                  ? c == 2074
                  : c <= 2084)))
              : (c <= 2088 || (c < 2160
                ? (c < 2144
                  ? (c >= 2112 && c <= 2136)
                  : c <= 2154)
                : (c <= 2183 || (c < 2208
                  ? (c >= 2185 && c <= 2190)
                  : c <= 2249)))))))))
        : (c <= 2361 || (c < 2693
          ? (c < 2527
            ? (c < 2451
              ? (c < 2417
                ? (c < 2384
                  ? c == 2365
                  : (c <= 2384 || (c >= 2392 && c <= 2401)))
                : (c <= 2432 || (c < 2447
                  ? (c >= 2437 && c <= 2444)
                  : c <= 2448)))
              : (c <= 2472 || (c < 2493
                ? (c < 2482
                  ? (c >= 2474 && c <= 2480)
                  : (c <= 2482 || (c >= 2486 && c <= 2489)))
                : (c <= 2493 || (c < 2524
                  ? c == 2510
                  : c <= 2525)))))
            : (c <= 2529 || (c < 2610
              ? (c < 2575
                ? (c < 2556
                  ? (c >= 2544 && c <= 2545)
                  : (c <= 2556 || (c >= 2565 && c <= 2570)))
                : (c <= 2576 || (c < 2602
                  ? (c >= 2579 && c <= 2600)
                  : c <= 2608)))
              : (c <= 2611 || (c < 2649
                ? (c < 2616
                  ? (c >= 2613 && c <= 2614)
                  : c <= 2617)
                : (c <= 2652 || (c < 2674
                  ? c == 2654
                  : c <= 2676)))))))
          : (c <= 2701 || (c < 2866
            ? (c < 2768
              ? (c < 2738
                ? (c < 2707
                  ? (c >= 2703 && c <= 2705)
                  : (c <= 2728 || (c >= 2730 && c <= 2736)))
                : (c <= 2739 || (c < 2749
                  ? (c >= 2741 && c <= 2745)
                  : c <= 2749)))
              : (c <= 2768 || (c < 2831
                ? (c < 2809
                  ? (c >= 2784 && c <= 2785)
                  : (c <= 2809 || (c >= 2821 && c <= 2828)))
                : (c <= 2832 || (c < 2858
                  ? (c >= 2835 && c <= 2856)
                  : c <= 2864)))))
            : (c <= 2867 || (c < 2949
              ? (c < 2911
                ? (c < 2877
                  ? (c >= 2869 && c <= 2873)
                  : (c <= 2877 || (c >= 2908 && c <= 2909)))
                : (c <= 2913 || (c < 2947
                  ? c == 2929
                  : c <= 2947)))
              : (c <= 2954 || (c < 2969
                ? (c < 2962
                  ? (c >= 2958 && c <= 2960)
                  : c <= 2965)
                : (c <= 2970 || (c < 2974
                  ? c == 2972
                  : c <= 2975)))))))))))
      : (c <= 2980 || (c < 4176
        ? (c < 3423
          ? (c < 3214
            ? (c < 3114
              ? (c < 3077
                ? (c < 2990
                  ? (c >= 2984 && c <= 2986)
                  : (c <= 3001 || c == 3024))
                : (c <= 3084 || (c < 3090
                  ? (c >= 3086 && c <= 3088)
                  : c <= 3112)))
              : (c <= 3129 || (c < 3168
                ? (c < 3160
                  ? c == 3133
                  : (c <= 3162 || c == 3165))
                : (c <= 3169 || (c < 3205
                  ? c == 3200
                  : c <= 3212)))))
            : (c <= 3216 || (c < 3313
              ? (c < 3261
                ? (c < 3242
                  ? (c >= 3218 && c <= 3240)
                  : (c <= 3251 || (c >= 3253 && c <= 3257)))
                : (c <= 3261 || (c < 3296
                  ? (c >= 3293 && c <= 3294)
                  : c <= 3297)))
              : (c <= 3314 || (c < 3389
                ? (c < 3342
                  ? (c >= 3332 && c <= 3340)
                  : (c <= 3344 || (c >= 3346 && c <= 3386)))
                : (c <= 3389 || (c < 3412
                  ? c == 3406
                  : c <= 3414)))))))
          : (c <= 3425 || (c < 3749
            ? (c < 3585
              ? (c < 3507
                ? (c < 3461
                  ? (c >= 3450 && c <= 3455)
                  : (c <= 3478 || (c >= 3482 && c <= 3505)))
                : (c <= 3515 || (c < 3520
                  ? c == 3517
                  : c <= 3526)))
              : (c <= 3632 || (c < 3716
                ? (c < 3648
                  ? (c >= 3634 && c <= 3635)
                  : (c <= 3654 || (c >= 3713 && c <= 3714)))
                : (c <= 3716 || (c < 3724
                  ? (c >= 3718 && c <= 3722)
                  : c <= 3747)))))
            : (c <= 3749 || (c < 3840
              ? (c < 3776
                ? (c < 3762
                  ? (c >= 3751 && c <= 3760)
                  : (c <= 3763 || c == 3773))
                : (c <= 3780 || (c < 3804
                  ? c == 3782
                  : c <= 3807)))
              : (c <= 3840 || (c < 3976
                ? (c < 3913
                  ? (c >= 3904 && c <= 3911)
                  : c <= 3948)
                : (c <= 3980 || (c < 4159
                  ? (c >= 4096 && c <= 4138)
                  : c <= 4159)))))))))
        : (c <= 4181 || (c < 4992
          ? (c < 4696
            ? (c < 4256
              ? (c < 4206
                ? (c < 4193
                  ? (c >= 4186 && c <= 4189)
                  : (c <= 4193 || (c >= 4197 && c <= 4198)))
                : (c <= 4208 || (c < 4238
                  ? (c >= 4213 && c <= 4225)
                  : c <= 4238)))
              : (c <= 4293 || (c < 4348
                ? (c < 4301
                  ? c == 4295
                  : (c <= 4301 || (c >= 4304 && c <= 4346)))
                : (c <= 4680 || (c < 4688
                  ? (c >= 4682 && c <= 4685)
                  : c <= 4694)))))
            : (c <= 4696 || (c < 4800
              ? (c < 4752
                ? (c < 4704
                  ? (c >= 4698 && c <= 4701)
                  : (c <= 4744 || (c >= 4746 && c <= 4749)))
                : (c <= 4784 || (c < 4792
                  ? (c >= 4786 && c <= 4789)
                  : c <= 4798)))
              : (c <= 4800 || (c < 4824
                ? (c < 4808
                  ? (c >= 4802 && c <= 4805)
                  : c <= 4822)
                : (c <= 4880 || (c < 4888
                  ? (c >= 4882 && c <= 4885)
                  : c <= 4954)))))))
          : (c <= 5007 || (c < 6103
            ? (c < 5870
              ? (c < 5743
                ? (c < 5112
                  ? (c >= 5024 && c <= 5109)
                  : (c <= 5117 || (c >= 5121 && c <= 5740)))
                : (c <= 5759 || (c < 5792
                  ? (c >= 5761 && c <= 5786)
                  : c <= 5866)))
              : (c <= 5880 || (c < 5984
                ? (c < 5919
                  ? (c >= 5888 && c <= 5905)
                  : (c <= 5937 || (c >= 5952 && c <= 5969)))
                : (c <= 5996 || (c < 6016
                  ? (c >= 5998 && c <= 6000)
                  : c <= 6067)))))
            : (c <= 6103 || (c < 6400
              ? (c < 6279
                ? (c < 6176
                  ? c == 6108
                  : (c <= 6264 || (c >= 6272 && c <= 6276)))
                : (c <= 6312 || (c < 6320
                  ? c == 6314
                  : c <= 6389)))
              : (c <= 6430 || (c < 6528
                ? (c < 6512
                  ? (c >= 6480 && c <= 6509)
                  : c <= 6516)
                : (c <= 6571 || (c < 6656
                  ? (c >= 6576 && c <= 6601)
                  : c <= 6678)))))))))))))
    : (c <= 6740 || (c < 43261
      ? (c < 11499
        ? (c < 8118
          ? (c < 7406
            ? (c < 7168
              ? (c < 7043
                ? (c < 6917
                  ? c == 6823
                  : (c <= 6963 || (c >= 6981 && c <= 6988)))
                : (c <= 7072 || (c < 7098
                  ? (c >= 7086 && c <= 7087)
                  : c <= 7141)))
              : (c <= 7203 || (c < 7312
                ? (c < 7258
                  ? (c >= 7245 && c <= 7247)
                  : (c <= 7293 || (c >= 7296 && c <= 7304)))
                : (c <= 7354 || (c < 7401
                  ? (c >= 7357 && c <= 7359)
                  : c <= 7404)))))
            : (c <= 7411 || (c < 8008
              ? (c < 7680
                ? (c < 7418
                  ? (c >= 7413 && c <= 7414)
                  : (c <= 7418 || (c >= 7424 && c <= 7615)))
                : (c <= 7957 || (c < 7968
                  ? (c >= 7960 && c <= 7965)
                  : c <= 8005)))
              : (c <= 8013 || (c < 8029
                ? (c < 8025
                  ? (c >= 8016 && c <= 8023)
                  : (c <= 8025 || c == 8027))
                : (c <= 8029 || (c < 8064
                  ? (c >= 8031 && c <= 8061)
                  : c <= 8116)))))))
          : (c <= 8124 || (c < 8458
            ? (c < 8178
              ? (c < 8144
                ? (c < 8130
                  ? c == 8126
                  : (c <= 8132 || (c >= 8134 && c <= 8140)))
                : (c <= 8147 || (c < 8160
                  ? (c >= 8150 && c <= 8155)
                  : c <= 8172)))
              : (c <= 8180 || (c < 8336
                ? (c < 8305
                  ? (c >= 8182 && c <= 8188)
                  : (c <= 8305 || c == 8319))
                : (c <= 8348 || (c < 8455
                  ? c == 8450
                  : c <= 8455)))))
            : (c <= 8467 || (c < 8495
              ? (c < 8486
                ? (c < 8473
                  ? c == 8469
                  : (c <= 8477 || c == 8484))
                : (c <= 8486 || (c < 8490
                  ? c == 8488
                  : c <= 8493)))
              : (c <= 8505 || (c < 8526
                ? (c < 8517
                  ? (c >= 8508 && c <= 8511)
                  : c <= 8521)
                : (c <= 8526 || (c < 11264
                  ? (c >= 8544 && c <= 8584)
                  : c <= 11492)))))))))
        : (c <= 11502 || (c < 12704
          ? (c < 11728
            ? (c < 11648
              ? (c < 11565
                ? (c < 11520
                  ? (c >= 11506 && c <= 11507)
                  : (c <= 11557 || c == 11559))
                : (c <= 11565 || (c < 11631
                  ? (c >= 11568 && c <= 11623)
                  : c <= 11631)))
              : (c <= 11670 || (c < 11704
                ? (c < 11688
                  ? (c >= 11680 && c <= 11686)
                  : (c <= 11694 || (c >= 11696 && c <= 11702)))
                : (c <= 11710 || (c < 11720
                  ? (c >= 11712 && c <= 11718)
                  : c <= 11726)))))
            : (c <= 11734 || (c < 12353
              ? (c < 12321
                ? (c < 11823
                  ? (c >= 11736 && c <= 11742)
                  : (c <= 11823 || (c >= 12293 && c <= 12295)))
                : (c <= 12329 || (c < 12344
                  ? (c >= 12337 && c <= 12341)
                  : c <= 12348)))
              : (c <= 12438 || (c < 12540
                ? (c < 12449
                  ? (c >= 12445 && c <= 12447)
                  : c <= 12538)
                : (c <= 12543 || (c < 12593
                  ? (c >= 12549 && c <= 12591)
                  : c <= 12686)))))))
          : (c <= 12735 || (c < 42786
            ? (c < 42240
              ? (c < 19968
                ? (c < 13312
                  ? (c >= 12784 && c <= 12799)
                  : (c <= 13312 || c == 19903))
                : (c <= 19968 || (c < 42192
                  ? (c >= 40959 && c <= 42124)
                  : c <= 42237)))
              : (c <= 42508 || (c < 42623
                ? (c < 42538
                  ? (c >= 42512 && c <= 42527)
                  : (c <= 42539 || (c >= 42560 && c <= 42606)))
                : (c <= 42653 || (c < 42775
                  ? (c >= 42656 && c <= 42735)
                  : c <= 42783)))))
            : (c <= 42888 || (c < 43015
              ? (c < 42965
                ? (c < 42960
                  ? (c >= 42891 && c <= 42954)
                  : (c <= 42961 || c == 42963))
                : (c <= 42969 || (c < 43011
                  ? (c >= 42994 && c <= 43009)
                  : c <= 43013)))
              : (c <= 43018 || (c < 43138
                ? (c < 43072
                  ? (c >= 43020 && c <= 43042)
                  : c <= 43123)
                : (c <= 43187 || (c < 43259
                  ? (c >= 43250 && c <= 43255)
                  : c <= 43259)))))))))))
      : (c <= 43262 || (c < 65345
        ? (c < 43816
          ? (c < 43646
            ? (c < 43494
              ? (c < 43396
                ? (c < 43312
                  ? (c >= 43274 && c <= 43301)
                  : (c <= 43334 || (c >= 43360 && c <= 43388)))
                : (c <= 43442 || (c < 43488
                  ? c == 43471
                  : c <= 43492)))
              : (c <= 43503 || (c < 43588
                ? (c < 43520
                  ? (c >= 43514 && c <= 43518)
                  : (c <= 43560 || (c >= 43584 && c <= 43586)))
                : (c <= 43595 || (c < 43642
                  ? (c >= 43616 && c <= 43638)
                  : c <= 43642)))))
            : (c <= 43695 || (c < 43744
              ? (c < 43712
                ? (c < 43701
                  ? c == 43697
                  : (c <= 43702 || (c >= 43705 && c <= 43709)))
                : (c <= 43712 || (c < 43739
                  ? c == 43714
                  : c <= 43741)))
              : (c <= 43754 || (c < 43785
                ? (c < 43777
                  ? (c >= 43762 && c <= 43764)
                  : c <= 43782)
                : (c <= 43790 || (c < 43808
                  ? (c >= 43793 && c <= 43798)
                  : c <= 43814)))))))
          : (c <= 43822 || (c < 64298
            ? (c < 55243
              ? (c < 44032
                ? (c < 43868
                  ? (c >= 43824 && c <= 43866)
                  : (c <= 43881 || (c >= 43888 && c <= 44002)))
                : (c <= 44032 || (c < 55216
                  ? c == 55203
                  : c <= 55238)))
              : (c <= 55291 || (c < 64275
                ? (c < 64112
                  ? (c >= 63744 && c <= 64109)
                  : (c <= 64217 || (c >= 64256 && c <= 64262)))
                : (c <= 64279 || (c < 64287
                  ? c == 64285
                  : c <= 64296)))))
            : (c <= 64310 || (c < 64848
              ? (c < 64323
                ? (c < 64318
                  ? (c >= 64312 && c <= 64316)
                  : (c <= 64318 || (c >= 64320 && c <= 64321)))
                : (c <= 64324 || (c < 64467
                  ? (c >= 64326 && c <= 64433)
                  : c <= 64829)))
              : (c <= 64911 || (c < 65136
                ? (c < 65008
                  ? (c >= 64914 && c <= 64967)
                  : c <= 65019)
                : (c <= 65140 || (c < 65313
                  ? (c >= 65142 && c <= 65276)
                  : c <= 65338)))))))))
        : (c <= 65370 || (c < 66864
          ? (c < 66176
            ? (c < 65549
              ? (c < 65490
                ? (c < 65474
                  ? (c >= 65382 && c <= 65470)
                  : (c <= 65479 || (c >= 65482 && c <= 65487)))
                : (c <= 65495 || (c < 65536
                  ? (c >= 65498 && c <= 65500)
                  : c <= 65547)))
              : (c <= 65574 || (c < 65616
                ? (c < 65596
                  ? (c >= 65576 && c <= 65594)
                  : (c <= 65597 || (c >= 65599 && c <= 65613)))
                : (c <= 65629 || (c < 65856
                  ? (c >= 65664 && c <= 65786)
                  : c <= 65908)))))
            : (c <= 66204 || (c < 66504
              ? (c < 66384
                ? (c < 66304
                  ? (c >= 66208 && c <= 66256)
                  : (c <= 66335 || (c >= 66349 && c <= 66378)))
                : (c <= 66421 || (c < 66464
                  ? (c >= 66432 && c <= 66461)
                  : c <= 66499)))
              : (c <= 66511 || (c < 66736
                ? (c < 66560
                  ? (c >= 66513 && c <= 66517)
                  : c <= 66717)
                : (c <= 66771 || (c < 66816
                  ? (c >= 66776 && c <= 66811)
                  : c <= 66855)))))))
          : (c <= 66915 || (c < 67506
            ? (c < 66995
              ? (c < 66964
                ? (c < 66940
                  ? (c >= 66928 && c <= 66938)
                  : (c <= 66954 || (c >= 66956 && c <= 66962)))
                : (c <= 66965 || (c < 66979
                  ? (c >= 66967 && c <= 66977)
                  : c <= 66993)))
              : (c <= 67001 || (c < 67424
                ? (c < 67072
                  ? (c >= 67003 && c <= 67004)
                  : (c <= 67382 || (c >= 67392 && c <= 67413)))
                : (c <= 67431 || (c < 67463
                  ? (c >= 67456 && c <= 67461)
                  : c <= 67504)))))
            : (c <= 67514 || (c < 67680
              ? (c < 67639
                ? (c < 67592
                  ? (c >= 67584 && c <= 67589)
                  : (c <= 67592 || (c >= 67594 && c <= 67637)))
                : (c <= 67640 || (c < 67647
                  ? c == 67644
                  : c <= 67669)))
              : (c <= 67702 || (c < 67828
                ? (c < 67808
                  ? (c >= 67712 && c <= 67742)
                  : c <= 67826)
                : (c <= 67829 || (c < 67872
                  ? (c >= 67840 && c <= 67861)
                  : c <= 67883)))))))))))))));
}

static inline bool sym_operator_identifier_character_set_1(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '\\'
            ? (c < '*'
              ? (c >= '#' && c <= '&')
              : (c <= '*' || (c >= '<' && c <= '@')))
            : (c <= '\\' || (c < '|'
              ? c == '^'
              : (c <= '|' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_2(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '\\'
            ? (c < '+'
              ? (c < '%'
                ? (c >= '!' && c <= '#')
                : c <= '&')
              : (c <= '-' || (c >= '>' && c <= '?')))
            : (c <= '\\' || (c < '~'
              ? c == '^'
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_3(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '\\'
            ? (c < '+'
              ? (c < '%'
                ? (c >= '!' && c <= '#')
                : c <= '&')
              : (c <= '-' || (c >= '<' && c <= '?')))
            : (c <= '\\' || (c < '~'
              ? c == '^'
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_4(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '<'
            ? (c < '+'
              ? (c < '%'
                ? (c >= '!' && c <= '#')
                : c <= '&')
              : (c <= '+' || c == '-'))
            : (c <= '?' || (c < '^'
              ? c == '\\'
              : (c <= '^' || c == '~'))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_5(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '\\'
            ? (c < '+'
              ? (c < '%'
                ? c == '!'
                : c <= '&')
              : (c <= '-' || c == '>'))
            : (c <= '\\' || (c < '~'
              ? c == '^'
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_6(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '\\'
            ? (c < '+'
              ? (c < '%'
                ? c == '!'
                : c <= '&')
              : (c <= '-' || (c >= '<' && c <= '>')))
            : (c <= '\\' || (c < '~'
              ? c == '^'
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_7(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '\\'
            ? (c < '+'
              ? (c < '%'
                ? c == '!'
                : c <= '&')
              : (c <= '-' || (c >= '<' && c <= '>')))
            : (c <= '\\' || (c < '|'
              ? c == '^'
              : (c <= '|' || c == '~'))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_8(int32_t c) {
  return (c < 8512
    ? (c < 3841
      ? (c < 1014
        ? (c < '~'
          ? (c < '<'
            ? (c < '*'
              ? (c < '%'
                ? c == '!'
                : c <= '&')
              : (c <= '*' || c == ':'))
            : (c <= '?' || (c < '^'
              ? c == '\\'
              : (c <= '^' || c == '|'))))
          : (c <= '~' || (c < 174
            ? (c < 169
              ? c == 166
              : (c <= 169 || c == 172))
            : (c <= 174 || (c < 215
              ? (c >= 176 && c <= 177)
              : (c <= 215 || c == 247))))))
        : (c <= 1014 || (c < 2038
          ? (c < 1550
            ? (c < 1421
              ? c == 1154
              : (c <= 1422 || (c >= 1542 && c <= 1544)))
            : (c <= 1551 || (c < 1769
              ? c == 1758
              : (c <= 1769 || (c >= 1789 && c <= 1790)))))
          : (c <= 2038 || (c < 3066
            ? (c < 2928
              ? c == 2554
              : (c <= 2928 || (c >= 3059 && c <= 3064)))
            : (c <= 3066 || (c < 3407
              ? c == 3199
              : (c <= 3407 || c == 3449))))))))
      : (c <= 3843 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c < 3861
                ? c == 3859
                : c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_9(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '\\'
            ? (c < '*'
              ? (c < '%'
                ? c == '!'
                : c <= '&')
              : (c <= '-' || c == '>'))
            : (c <= '^' || (c < '~'
              ? c == '|'
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_10(int32_t c) {
  return (c < 8512
    ? (c < 3841
      ? (c < 1014
        ? (c < '~'
          ? (c < '<'
            ? (c < '*'
              ? (c < '%'
                ? c == '!'
                : c <= '&')
              : (c <= '+' || c == '-'))
            : (c <= '?' || (c < '^'
              ? c == '\\'
              : (c <= '^' || c == '|'))))
          : (c <= '~' || (c < 174
            ? (c < 169
              ? c == 166
              : (c <= 169 || c == 172))
            : (c <= 174 || (c < 215
              ? (c >= 176 && c <= 177)
              : (c <= 215 || c == 247))))))
        : (c <= 1014 || (c < 2038
          ? (c < 1550
            ? (c < 1421
              ? c == 1154
              : (c <= 1422 || (c >= 1542 && c <= 1544)))
            : (c <= 1551 || (c < 1769
              ? c == 1758
              : (c <= 1769 || (c >= 1789 && c <= 1790)))))
          : (c <= 2038 || (c < 3066
            ? (c < 2928
              ? c == 2554
              : (c <= 2928 || (c >= 3059 && c <= 3064)))
            : (c <= 3066 || (c < 3407
              ? c == 3199
              : (c <= 3407 || c == 3449))))))))
      : (c <= 3843 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c < 3861
                ? c == 3859
                : c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_11(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 247
        ? (c < '|'
          ? (c < ':'
            ? (c < '*'
              ? (c < '%'
                ? c == '!'
                : c <= '&')
              : (c <= '+' || c == '-'))
            : (c <= ':' || (c < '\\'
              ? (c >= '<' && c <= '?')
              : (c <= '\\' || c == '^'))))
          : (c <= '|' || (c < 172
            ? (c < 166
              ? c == '~'
              : (c <= 166 || c == 169))
            : (c <= 172 || (c < 176
              ? c == 174
              : (c <= 177 || c == 215))))))
        : (c <= 247 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? c == 1014
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_12(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '<'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '+' || c == ':'))
            : (c <= '@' || (c < '^'
              ? c == '\\'
              : (c <= '^' || (c >= '|' && c <= '~')))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_13(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '<'
            ? (c < '#'
              ? c == '!'
              : (c <= '#' || (c >= '%' && c <= '+')))
            : (c <= '@' || (c < '|'
              ? (c >= '\\' && c <= '^')
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_14(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '\\'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '+' || (c >= '<' && c <= '@')))
            : (c <= '\\' || (c < '|'
              ? c == '^'
              : (c <= '|' || c == '~'))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_15(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '\\'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '+' || (c >= '<' && c <= '?')))
            : (c <= '\\' || (c < '|'
              ? c == '^'
              : (c <= '|' || c == '~'))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_16(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '>'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '+' && c <= '-')))
            : (c <= '@' || (c < '~'
              ? (c >= '\\' && c <= '^')
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_17(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '<'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '+' && c <= '-')))
            : (c <= '@' || (c < '^'
              ? c == '\\'
              : (c <= '^' || c == '~'))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_18(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '>'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '+' && c <= '-')))
            : (c <= '>' || (c < '^'
              ? c == '\\'
              : (c <= '^' || c == '~'))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_19(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '<'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '+' && c <= '-')))
            : (c <= '>' || (c < '^'
              ? c == '\\'
              : (c <= '^' || c == '~'))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_20(int32_t c) {
  return (c < 8512
    ? (c < 3841
      ? (c < 1014
        ? (c < '~'
          ? (c < '<'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '+' && c <= '-')))
            : (c <= '>' || (c < '^'
              ? c == '\\'
              : (c <= '^' || c == '|'))))
          : (c <= '~' || (c < 174
            ? (c < 169
              ? c == 166
              : (c <= 169 || c == 172))
            : (c <= 174 || (c < 215
              ? (c >= 176 && c <= 177)
              : (c <= 215 || c == 247))))))
        : (c <= 1014 || (c < 2038
          ? (c < 1550
            ? (c < 1421
              ? c == 1154
              : (c <= 1422 || (c >= 1542 && c <= 1544)))
            : (c <= 1551 || (c < 1769
              ? c == 1758
              : (c <= 1769 || (c >= 1789 && c <= 1790)))))
          : (c <= 2038 || (c < 3066
            ? (c < 2928
              ? c == 2554
              : (c <= 2928 || (c >= 3059 && c <= 3064)))
            : (c <= 3066 || (c < 3407
              ? c == 3199
              : (c <= 3407 || c == 3449))))))))
      : (c <= 3843 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c < 3861
                ? c == 3859
                : c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_21(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 215
        ? (c < '^'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '+')))
            : (c <= '-' || (c < '<'
              ? c == ':'
              : (c <= '?' || c == '\\'))))
          : (c <= '^' || (c < 169
            ? (c < '~'
              ? c == '|'
              : (c <= '~' || c == 166))
            : (c <= 169 || (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))))))
        : (c <= 215 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? (c < 1014
                ? c == 247
                : c <= 1014)
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_22(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 247
        ? (c < '|'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '+')))
            : (c <= '-' || (c < '<'
              ? c == ':'
              : (c <= '@' || (c >= '\\' && c <= '^')))))
          : (c <= '|' || (c < 172
            ? (c < 166
              ? c == '~'
              : (c <= 166 || c == 169))
            : (c <= 172 || (c < 176
              ? c == 174
              : (c <= 177 || c == 215))))))
        : (c <= 247 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? c == 1014
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_23(int32_t c) {
  return (c < 8512
    ? (c < 3841
      ? (c < 1014
        ? (c < '~'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || c == '+'))
            : (c <= '-' || (c < '\\'
              ? (c >= '<' && c <= '@')
              : (c <= '\\' || c == '^'))))
          : (c <= '~' || (c < 174
            ? (c < 169
              ? c == 166
              : (c <= 169 || c == 172))
            : (c <= 174 || (c < 215
              ? (c >= 176 && c <= 177)
              : (c <= 215 || c == 247))))))
        : (c <= 1014 || (c < 2038
          ? (c < 1550
            ? (c < 1421
              ? c == 1154
              : (c <= 1422 || (c >= 1542 && c <= 1544)))
            : (c <= 1551 || (c < 1769
              ? c == 1758
              : (c <= 1769 || (c >= 1789 && c <= 1790)))))
          : (c <= 2038 || (c < 3066
            ? (c < 2928
              ? c == 2554
              : (c <= 2928 || (c >= 3059 && c <= 3064)))
            : (c <= 3066 || (c < 3407
              ? c == 3199
              : (c <= 3407 || c == 3449))))))))
      : (c <= 3843 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c < 3861
                ? c == 3859
                : c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_24(int32_t c) {
  return (c < 8512
    ? (c < 3841
      ? (c < 1014
        ? (c < '~'
          ? (c < ':'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || c == '*'))
            : (c <= ':' || (c < '\\'
              ? (c >= '<' && c <= '?')
              : (c <= '^' || c == '|'))))
          : (c <= '~' || (c < 174
            ? (c < 169
              ? c == 166
              : (c <= 169 || c == 172))
            : (c <= 174 || (c < 215
              ? (c >= 176 && c <= 177)
              : (c <= 215 || c == 247))))))
        : (c <= 1014 || (c < 2038
          ? (c < 1550
            ? (c < 1421
              ? c == 1154
              : (c <= 1422 || (c >= 1542 && c <= 1544)))
            : (c <= 1551 || (c < 1769
              ? c == 1758
              : (c <= 1769 || (c >= 1789 && c <= 1790)))))
          : (c <= 2038 || (c < 3066
            ? (c < 2928
              ? c == 2554
              : (c <= 2928 || (c >= 3059 && c <= 3064)))
            : (c <= 3066 || (c < 3407
              ? c == 3199
              : (c <= 3407 || c == 3449))))))))
      : (c <= 3843 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c < 3861
                ? c == 3859
                : c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_25(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '>'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '-')))
            : (c <= '>' || (c < '|'
              ? (c >= '\\' && c <= '^')
              : (c <= '|' || c == '~'))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_26(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 247
        ? (c < '|'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '+')))
            : (c <= '-' || (c < '\\'
              ? (c >= '<' && c <= '?')
              : (c <= '\\' || c == '^'))))
          : (c <= '|' || (c < 172
            ? (c < 166
              ? c == '~'
              : (c <= 166 || c == 169))
            : (c <= 172 || (c < 176
              ? c == 174
              : (c <= 177 || c == 215))))))
        : (c <= 247 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? c == 1014
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_27(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 247
        ? (c < '|'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '+')))
            : (c <= '-' || (c < '\\'
              ? (c >= '<' && c <= '@')
              : (c <= '\\' || c == '^'))))
          : (c <= '|' || (c < 172
            ? (c < 166
              ? c == '~'
              : (c <= 166 || c == 169))
            : (c <= 172 || (c < 176
              ? c == 174
              : (c <= 177 || c == 215))))))
        : (c <= 247 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? c == 1014
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_28(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '>'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '+' && c <= '-')))
            : (c <= '@' || (c < '^'
              ? c == '\\'
              : (c <= '^' || c == '~'))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_29(int32_t c) {
  return (c < 8512
    ? (c < 3841
      ? (c < 1014
        ? (c < '~'
          ? (c < '<'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '+' && c <= '-')))
            : (c <= '@' || (c < '^'
              ? c == '\\'
              : (c <= '^' || c == '|'))))
          : (c <= '~' || (c < 174
            ? (c < 169
              ? c == 166
              : (c <= 169 || c == 172))
            : (c <= 174 || (c < 215
              ? (c >= 176 && c <= 177)
              : (c <= 215 || c == 247))))))
        : (c <= 1014 || (c < 2038
          ? (c < 1550
            ? (c < 1421
              ? c == 1154
              : (c <= 1422 || (c >= 1542 && c <= 1544)))
            : (c <= 1551 || (c < 1769
              ? c == 1758
              : (c <= 1769 || (c >= 1789 && c <= 1790)))))
          : (c <= 2038 || (c < 3066
            ? (c < 2928
              ? c == 2554
              : (c <= 2928 || (c >= 3059 && c <= 3064)))
            : (c <= 3066 || (c < 3407
              ? c == 3199
              : (c <= 3407 || c == 3449))))))))
      : (c <= 3843 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c < 3861
                ? c == 3859
                : c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_30(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 247
        ? (c < '|'
          ? (c < ':'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '+' && c <= '-')))
            : (c <= ':' || (c < '\\'
              ? (c >= '<' && c <= '@')
              : (c <= '\\' || c == '^'))))
          : (c <= '|' || (c < 172
            ? (c < 166
              ? c == '~'
              : (c <= 166 || c == 169))
            : (c <= 172 || (c < 176
              ? c == 174
              : (c <= 177 || c == 215))))))
        : (c <= 247 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? c == 1014
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_31(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 247
        ? (c < '^'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || c == '+'))
            : (c <= '-' || (c < '<'
              ? c == ':'
              : (c <= '@' || c == '\\'))))
          : (c <= '^' || (c < 172
            ? (c < 166
              ? (c >= '|' && c <= '~')
              : (c <= 166 || c == 169))
            : (c <= 172 || (c < 176
              ? c == 174
              : (c <= 177 || c == 215))))))
        : (c <= 247 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? c == 1014
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_32(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '>'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '-')))
            : (c <= '@' || (c < '|'
              ? (c >= '\\' && c <= '^')
              : (c <= '|' || c == '~'))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_33(int32_t c) {
  return (c < 8527
    ? (c < 3892
      ? (c < 1550
        ? (c < 174
          ? (c < '|'
            ? (c < '\\'
              ? (c >= '#' && c <= '@')
              : (c <= '\\' || c == '^'))
            : (c <= '|' || (c < 169
              ? c == 166
              : (c <= 169 || c == 172))))
          : (c <= 174 || (c < 1014
            ? (c < 215
              ? (c >= 176 && c <= 177)
              : (c <= 215 || c == 247))
            : (c <= 1014 || (c < 1421
              ? c == 1154
              : (c <= 1422 || (c >= 1542 && c <= 1544)))))))
        : (c <= 1551 || (c < 3066
          ? (c < 2038
            ? (c < 1769
              ? c == 1758
              : (c <= 1769 || (c >= 1789 && c <= 1790)))
            : (c <= 2038 || (c < 2928
              ? c == 2554
              : (c <= 2928 || (c >= 3059 && c <= 3064)))))
          : (c <= 3066 || (c < 3841
            ? (c < 3407
              ? c == 3199
              : (c <= 3407 || c == 3449))
            : (c <= 3843 || (c < 3861
              ? c == 3859
              : (c <= 3863 || (c >= 3866 && c <= 3871)))))))))
      : (c <= 3892 || (c < 8314
        ? (c < 5008
          ? (c < 4039
            ? (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))
            : (c <= 4044 || (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))))
          : (c <= 5017 || (c < 7009
            ? (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))
            : (c <= 7018 || (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))))))
        : (c <= 8316 || (c < 8485
          ? (c < 8456
            ? (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))
            : (c <= 8457 || (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))))
          : (c <= 8485 || (c < 8506
            ? (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))
            : (c <= 8507 || (c < 8522
              ? (c >= 8512 && c <= 8516)
              : c <= 8525)))))))))
    : (c <= 8527 || (c < 12880
      ? (c < 11493
        ? (c < 10132
          ? (c < 9003
            ? (c < 8592
              ? (c >= 8586 && c <= 8587)
              : (c <= 8967 || (c >= 8972 && c <= 9000)))
            : (c <= 9254 || (c < 9372
              ? (c >= 9280 && c <= 9290)
              : (c <= 9449 || (c >= 9472 && c <= 10087)))))
          : (c <= 10180 || (c < 10716
            ? (c < 10224
              ? (c >= 10183 && c <= 10213)
              : (c <= 10626 || (c >= 10649 && c <= 10711)))
            : (c <= 10747 || (c < 11126
              ? (c >= 10750 && c <= 11123)
              : (c <= 11157 || (c >= 11159 && c <= 11263)))))))
        : (c <= 11498 || (c < 12320
          ? (c < 12032
            ? (c < 11904
              ? (c >= 11856 && c <= 11857)
              : (c <= 11929 || (c >= 11931 && c <= 12019)))
            : (c <= 12245 || (c < 12292
              ? (c >= 12272 && c <= 12283)
              : (c <= 12292 || (c >= 12306 && c <= 12307)))))
          : (c <= 12320 || (c < 12694
            ? (c < 12350
              ? (c >= 12342 && c <= 12343)
              : (c <= 12351 || (c >= 12688 && c <= 12689)))
            : (c <= 12703 || (c < 12800
              ? (c >= 12736 && c <= 12771)
              : (c <= 12830 || (c >= 12842 && c <= 12871)))))))))
      : (c <= 12880 || (c < 65291
        ? (c < 43065
          ? (c < 19904
            ? (c < 12938
              ? (c >= 12896 && c <= 12927)
              : (c <= 12976 || (c >= 12992 && c <= 13311)))
            : (c <= 19967 || (c < 43048
              ? (c >= 42128 && c <= 42182)
              : (c <= 43051 || (c >= 43062 && c <= 43063)))))
          : (c <= 43065 || (c < 64975
            ? (c < 64297
              ? (c >= 43639 && c <= 43641)
              : (c <= 64297 || (c >= 64832 && c <= 64847)))
            : (c <= 64975 || (c < 65122
              ? (c >= 65021 && c <= 65023)
              : (c <= 65122 || (c >= 65124 && c <= 65126)))))))
        : (c <= 65291 || (c < 65847
          ? (c < 65506
            ? (c < 65372
              ? (c >= 65308 && c <= 65310)
              : (c <= 65372 || c == 65374))
            : (c <= 65506 || (c < 65512
              ? c == 65508
              : (c <= 65518 || (c >= 65532 && c <= 65533)))))
          : (c <= 65855 || (c < 65952
            ? (c < 65932
              ? (c >= 65913 && c <= 65929)
              : (c <= 65934 || (c >= 65936 && c <= 65948)))
            : (c <= 65952 || (c < 67703
              ? (c >= 66000 && c <= 66044)
              : c <= 67704)))))))))));
}

static inline bool sym_operator_identifier_character_set_34(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '\\'
            ? (c < ':'
              ? (c < '*'
                ? (c >= '%' && c <= '&')
                : c <= '*')
              : (c <= ':' || (c >= '<' && c <= '?')))
            : (c <= '\\' || (c < '|'
              ? c == '^'
              : (c <= '|' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_35(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '\\'
            ? (c < '*'
              ? (c >= '#' && c <= '&')
              : (c <= '*' || (c >= ':' && c <= '?')))
            : (c <= '\\' || (c < '|'
              ? c == '^'
              : (c <= '|' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_36(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '<'
            ? (c < '%'
              ? (c >= '!' && c <= '#')
              : (c <= '&' || (c >= '*' && c <= '-')))
            : (c <= '@' || (c < '|'
              ? (c >= '\\' && c <= '^')
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_37(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '\\'
            ? (c < '+'
              ? (c < '%'
                ? c == '!'
                : c <= '&')
              : (c <= '-' || (c >= '<' && c <= '>')))
            : (c <= '\\' || (c < '|'
              ? c == '^'
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_38(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '\\'
            ? (c < '*'
              ? (c < '%'
                ? c == '!'
                : c <= '&')
              : (c <= '-' || (c >= '<' && c <= '?')))
            : (c <= '\\' || (c < '|'
              ? c == '^'
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_39(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '<'
            ? (c < '%'
              ? c == '!'
              : (c <= '&' || (c >= '*' && c <= '-')))
            : (c <= '>' || (c < '|'
              ? (c >= '\\' && c <= '^')
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_40(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '\\'
            ? (c < '*'
              ? (c < '%'
                ? c == '!'
                : c <= '&')
              : (c <= '-' || (c >= '<' && c <= '>')))
            : (c <= '\\' || (c < '|'
              ? c == '^'
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_41(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '<'
            ? (c < '+'
              ? (c < '%'
                ? c == '!'
                : c <= '&')
              : (c <= '+' || c == '-'))
            : (c <= '>' || (c < '^'
              ? c == '\\'
              : (c <= '^' || c == '~'))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_42(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '>'
            ? (c < '*'
              ? (c < '%'
                ? c == '!'
                : c <= '&')
              : (c <= '+' || c == '-'))
            : (c <= '>' || (c < '^'
              ? c == '\\'
              : (c <= '^' || (c >= '|' && c <= '~')))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_43(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '\\'
            ? (c < '#'
              ? c == '!'
              : (c <= '#' || (c >= '%' && c <= '?')))
            : (c <= '\\' || (c < '|'
              ? c == '^'
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_44(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '<'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '+' && c <= '-')))
            : (c <= '>' || (c < '^'
              ? c == '\\'
              : (c <= '^' || (c >= '|' && c <= '~')))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_45(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '<'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '-')))
            : (c <= '?' || (c < '^'
              ? c == '\\'
              : (c <= '^' || (c >= '|' && c <= '~')))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_46(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '<'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '-')))
            : (c <= '@' || (c < '|'
              ? (c >= '\\' && c <= '^')
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_47(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < '<'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '-')))
            : (c <= '>' || (c < '|'
              ? (c >= '\\' && c <= '^')
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_48(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '<'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '-')))
            : (c <= '>' || (c < '^'
              ? c == '\\'
              : (c <= '^' || (c >= '|' && c <= '~')))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_49(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '<'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '-')))
            : (c <= '@' || (c < '^'
              ? c == '\\'
              : (c <= '^' || (c >= '|' && c <= '~')))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_50(int32_t c) {
  return (c < 8512
    ? (c < 3841
      ? (c < 1014
        ? (c < '~'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || c == '+'))
            : (c <= '-' || (c < '\\'
              ? (c >= '<' && c <= '>')
              : (c <= '\\' || c == '^'))))
          : (c <= '~' || (c < 174
            ? (c < 169
              ? c == 166
              : (c <= 169 || c == 172))
            : (c <= 174 || (c < 215
              ? (c >= 176 && c <= 177)
              : (c <= 215 || c == 247))))))
        : (c <= 1014 || (c < 2038
          ? (c < 1550
            ? (c < 1421
              ? c == 1154
              : (c <= 1422 || (c >= 1542 && c <= 1544)))
            : (c <= 1551 || (c < 1769
              ? c == 1758
              : (c <= 1769 || (c >= 1789 && c <= 1790)))))
          : (c <= 2038 || (c < 3066
            ? (c < 2928
              ? c == 2554
              : (c <= 2928 || (c >= 3059 && c <= 3064)))
            : (c <= 3066 || (c < 3407
              ? c == 3199
              : (c <= 3407 || c == 3449))))))))
      : (c <= 3843 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c < 3861
                ? c == 3859
                : c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_51(int32_t c) {
  return (c < 8512
    ? (c < 3841
      ? (c < 1014
        ? (c < '|'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '+')))
            : (c <= '-' || (c < '\\'
              ? c == '>'
              : (c <= '\\' || c == '^'))))
          : (c <= '~' || (c < 174
            ? (c < 169
              ? c == 166
              : (c <= 169 || c == 172))
            : (c <= 174 || (c < 215
              ? (c >= 176 && c <= 177)
              : (c <= 215 || c == 247))))))
        : (c <= 1014 || (c < 2038
          ? (c < 1550
            ? (c < 1421
              ? c == 1154
              : (c <= 1422 || (c >= 1542 && c <= 1544)))
            : (c <= 1551 || (c < 1769
              ? c == 1758
              : (c <= 1769 || (c >= 1789 && c <= 1790)))))
          : (c <= 2038 || (c < 3066
            ? (c < 2928
              ? c == 2554
              : (c <= 2928 || (c >= 3059 && c <= 3064)))
            : (c <= 3066 || (c < 3407
              ? c == 3199
              : (c <= 3407 || c == 3449))))))))
      : (c <= 3843 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c < 3861
                ? c == 3859
                : c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_52(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < '<'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '+' && c <= '-')))
            : (c <= '@' || (c < '^'
              ? c == '\\'
              : (c <= '^' || (c >= '|' && c <= '~')))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_53(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < ':'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '+' && c <= '-')))
            : (c <= '@' || (c < '^'
              ? c == '\\'
              : (c <= '^' || (c >= '|' && c <= '~')))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_54(int32_t c) {
  return (c < 8522
    ? (c < 3861
      ? (c < 1421
        ? (c < 169
          ? (c < ':'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '-')))
            : (c <= '@' || (c < '|'
              ? (c >= '\\' && c <= '^')
              : (c <= '~' || c == 166))))
          : (c <= 169 || (c < 215
            ? (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))
            : (c <= 215 || (c < 1014
              ? c == 247
              : (c <= 1014 || c == 1154))))))
        : (c <= 1422 || (c < 2928
          ? (c < 1769
            ? (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))
            : (c <= 1769 || (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))))
          : (c <= 2928 || (c < 3407
            ? (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))
            : (c <= 3407 || (c < 3841
              ? c == 3449
              : (c <= 3843 || c == 3859))))))))
      : (c <= 3863 || (c < 8260
        ? (c < 4053
          ? (c < 3896
            ? (c < 3892
              ? (c >= 3866 && c <= 3871)
              : (c <= 3892 || c == 3894))
            : (c <= 3896 || (c < 4039
              ? (c >= 4030 && c <= 4037)
              : (c <= 4044 || (c >= 4046 && c <= 4047)))))
          : (c <= 4056 || (c < 6464
            ? (c < 5008
              ? (c >= 4254 && c <= 4255)
              : (c <= 5017 || c == 5741))
            : (c <= 6464 || (c < 7009
              ? (c >= 6622 && c <= 6655)
              : (c <= 7018 || (c >= 7028 && c <= 7036)))))))
        : (c <= 8260 || (c < 8470
          ? (c < 8448
            ? (c < 8314
              ? c == 8274
              : (c <= 8316 || (c >= 8330 && c <= 8332)))
            : (c <= 8449 || (c < 8456
              ? (c >= 8451 && c <= 8454)
              : (c <= 8457 || c == 8468))))
          : (c <= 8472 || (c < 8489
            ? (c < 8485
              ? (c >= 8478 && c <= 8483)
              : (c <= 8485 || c == 8487))
            : (c <= 8489 || (c < 8506
              ? c == 8494
              : (c <= 8507 || (c >= 8512 && c <= 8516)))))))))))
    : (c <= 8525 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? c == 8527
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_55(int32_t c) {
  return (c < 8512
    ? (c < 3859
      ? (c < 1154
        ? (c < 166
          ? (c < ':'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '-')))
            : (c <= '@' || (c < '^'
              ? c == '\\'
              : (c <= '^' || (c >= '|' && c <= '~')))))
          : (c <= 166 || (c < 176
            ? (c < 172
              ? c == 169
              : (c <= 172 || c == 174))
            : (c <= 177 || (c < 247
              ? c == 215
              : (c <= 247 || c == 1014))))))
        : (c <= 1154 || (c < 2554
          ? (c < 1758
            ? (c < 1542
              ? (c >= 1421 && c <= 1422)
              : (c <= 1544 || (c >= 1550 && c <= 1551)))
            : (c <= 1758 || (c < 1789
              ? c == 1769
              : (c <= 1790 || c == 2038))))
          : (c <= 2554 || (c < 3199
            ? (c < 3059
              ? c == 2928
              : (c <= 3064 || c == 3066))
            : (c <= 3199 || (c < 3449
              ? c == 3407
              : (c <= 3449 || (c >= 3841 && c <= 3843)))))))))
      : (c <= 3859 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c >= 3861 && c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_56(int32_t c) {
  return (c < 8512
    ? (c < 3841
      ? (c < 1014
        ? (c < '|'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '+')))
            : (c <= '-' || (c < '\\'
              ? (c >= '>' && c <= '@')
              : (c <= '\\' || c == '^'))))
          : (c <= '~' || (c < 174
            ? (c < 169
              ? c == 166
              : (c <= 169 || c == 172))
            : (c <= 174 || (c < 215
              ? (c >= 176 && c <= 177)
              : (c <= 215 || c == 247))))))
        : (c <= 1014 || (c < 2038
          ? (c < 1550
            ? (c < 1421
              ? c == 1154
              : (c <= 1422 || (c >= 1542 && c <= 1544)))
            : (c <= 1551 || (c < 1769
              ? c == 1758
              : (c <= 1769 || (c >= 1789 && c <= 1790)))))
          : (c <= 2038 || (c < 3066
            ? (c < 2928
              ? c == 2554
              : (c <= 2928 || (c >= 3059 && c <= 3064)))
            : (c <= 3066 || (c < 3407
              ? c == 3199
              : (c <= 3407 || c == 3449))))))))
      : (c <= 3843 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c < 3861
                ? c == 3859
                : c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_57(int32_t c) {
  return (c < 8512
    ? (c < 3841
      ? (c < 1014
        ? (c < '|'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '+')))
            : (c <= '-' || (c < '\\'
              ? (c >= ':' && c <= '@')
              : (c <= '\\' || c == '^'))))
          : (c <= '~' || (c < 174
            ? (c < 169
              ? c == 166
              : (c <= 169 || c == 172))
            : (c <= 174 || (c < 215
              ? (c >= 176 && c <= 177)
              : (c <= 215 || c == 247))))))
        : (c <= 1014 || (c < 2038
          ? (c < 1550
            ? (c < 1421
              ? c == 1154
              : (c <= 1422 || (c >= 1542 && c <= 1544)))
            : (c <= 1551 || (c < 1769
              ? c == 1758
              : (c <= 1769 || (c >= 1789 && c <= 1790)))))
          : (c <= 2038 || (c < 3066
            ? (c < 2928
              ? c == 2554
              : (c <= 2928 || (c >= 3059 && c <= 3064)))
            : (c <= 3066 || (c < 3407
              ? c == 3199
              : (c <= 3407 || c == 3449))))))))
      : (c <= 3843 || (c < 7028
        ? (c < 4046
          ? (c < 3894
            ? (c < 3866
              ? (c < 3861
                ? c == 3859
                : c <= 3863)
              : (c <= 3871 || c == 3892))
            : (c <= 3894 || (c < 4030
              ? c == 3896
              : (c <= 4037 || (c >= 4039 && c <= 4044)))))
          : (c <= 4047 || (c < 5741
            ? (c < 4254
              ? (c >= 4053 && c <= 4056)
              : (c <= 4255 || (c >= 5008 && c <= 5017)))
            : (c <= 5741 || (c < 6622
              ? c == 6464
              : (c <= 6655 || (c >= 7009 && c <= 7018)))))))
        : (c <= 7036 || (c < 8468
          ? (c < 8330
            ? (c < 8274
              ? c == 8260
              : (c <= 8274 || (c >= 8314 && c <= 8316)))
            : (c <= 8332 || (c < 8451
              ? (c >= 8448 && c <= 8449)
              : (c <= 8454 || (c >= 8456 && c <= 8457)))))
          : (c <= 8468 || (c < 8487
            ? (c < 8478
              ? (c >= 8470 && c <= 8472)
              : (c <= 8483 || c == 8485))
            : (c <= 8487 || (c < 8494
              ? c == 8489
              : (c <= 8494 || (c >= 8506 && c <= 8507)))))))))))
    : (c <= 8516 || (c < 12842
      ? (c < 11159
        ? (c < 9472
          ? (c < 8972
            ? (c < 8586
              ? (c < 8527
                ? (c >= 8522 && c <= 8525)
                : c <= 8527)
              : (c <= 8587 || (c >= 8592 && c <= 8967)))
            : (c <= 9000 || (c < 9280
              ? (c >= 9003 && c <= 9254)
              : (c <= 9290 || (c >= 9372 && c <= 9449)))))
          : (c <= 10087 || (c < 10649
            ? (c < 10183
              ? (c >= 10132 && c <= 10180)
              : (c <= 10213 || (c >= 10224 && c <= 10626)))
            : (c <= 10711 || (c < 10750
              ? (c >= 10716 && c <= 10747)
              : (c <= 11123 || (c >= 11126 && c <= 11157)))))))
        : (c <= 11263 || (c < 12306
          ? (c < 11931
            ? (c < 11856
              ? (c >= 11493 && c <= 11498)
              : (c <= 11857 || (c >= 11904 && c <= 11929)))
            : (c <= 12019 || (c < 12272
              ? (c >= 12032 && c <= 12245)
              : (c <= 12283 || c == 12292))))
          : (c <= 12307 || (c < 12688
            ? (c < 12342
              ? c == 12320
              : (c <= 12343 || (c >= 12350 && c <= 12351)))
            : (c <= 12689 || (c < 12736
              ? (c >= 12694 && c <= 12703)
              : (c <= 12771 || (c >= 12800 && c <= 12830)))))))))
      : (c <= 12871 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? c == 12880
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_58(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 215
        ? (c < '^'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || c == '+'))
            : (c <= '-' || (c < '<'
              ? c == ':'
              : (c <= '@' || c == '\\'))))
          : (c <= '^' || (c < 169
            ? (c < '~'
              ? c == '|'
              : (c <= '~' || c == 166))
            : (c <= 169 || (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))))))
        : (c <= 215 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? (c < 1014
                ? c == 247
                : c <= 1014)
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_59(int32_t c) {
  return (c < 8494
    ? (c < 3407
      ? (c < 176
        ? (c < '\\'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || (c >= '*' && c <= '+')))
            : (c <= '-' || (c < ':'
              ? c == '/'
              : (c <= ':' || (c >= '<' && c <= '@')))))
          : (c <= '\\' || (c < 166
            ? (c < '|'
              ? c == '^'
              : (c <= '|' || c == '~'))
            : (c <= 166 || (c < 172
              ? c == 169
              : (c <= 172 || c == 174))))))
        : (c <= 177 || (c < 1769
          ? (c < 1421
            ? (c < 1014
              ? (c < 247
                ? c == 215
                : c <= 247)
              : (c <= 1014 || c == 1154))
            : (c <= 1422 || (c < 1550
              ? (c >= 1542 && c <= 1544)
              : (c <= 1551 || c == 1758))))
          : (c <= 1769 || (c < 2928
            ? (c < 2038
              ? (c >= 1789 && c <= 1790)
              : (c <= 2038 || c == 2554))
            : (c <= 2928 || (c < 3066
              ? (c >= 3059 && c <= 3064)
              : (c <= 3066 || c == 3199))))))))
      : (c <= 3407 || (c < 6622
        ? (c < 4030
          ? (c < 3866
            ? (c < 3859
              ? (c < 3841
                ? c == 3449
                : c <= 3843)
              : (c <= 3859 || (c >= 3861 && c <= 3863)))
            : (c <= 3871 || (c < 3894
              ? c == 3892
              : (c <= 3894 || c == 3896))))
          : (c <= 4037 || (c < 4254
            ? (c < 4046
              ? (c >= 4039 && c <= 4044)
              : (c <= 4047 || (c >= 4053 && c <= 4056)))
            : (c <= 4255 || (c < 5741
              ? (c >= 5008 && c <= 5017)
              : (c <= 5741 || c == 6464))))))
        : (c <= 6655 || (c < 8451
          ? (c < 8274
            ? (c < 7028
              ? (c >= 7009 && c <= 7018)
              : (c <= 7036 || c == 8260))
            : (c <= 8274 || (c < 8330
              ? (c >= 8314 && c <= 8316)
              : (c <= 8332 || (c >= 8448 && c <= 8449)))))
          : (c <= 8454 || (c < 8478
            ? (c < 8468
              ? (c >= 8456 && c <= 8457)
              : (c <= 8468 || (c >= 8470 && c <= 8472)))
            : (c <= 8483 || (c < 8487
              ? c == 8485
              : (c <= 8487 || c == 8489))))))))))
    : (c <= 8494 || (c < 12800
      ? (c < 10750
        ? (c < 9280
          ? (c < 8586
            ? (c < 8522
              ? (c < 8512
                ? (c >= 8506 && c <= 8507)
                : c <= 8516)
              : (c <= 8525 || c == 8527))
            : (c <= 8587 || (c < 8972
              ? (c >= 8592 && c <= 8967)
              : (c <= 9000 || (c >= 9003 && c <= 9254)))))
          : (c <= 9290 || (c < 10183
            ? (c < 9472
              ? (c >= 9372 && c <= 9449)
              : (c <= 10087 || (c >= 10132 && c <= 10180)))
            : (c <= 10213 || (c < 10649
              ? (c >= 10224 && c <= 10626)
              : (c <= 10711 || (c >= 10716 && c <= 10747)))))))
        : (c <= 11123 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c < 11159
                ? (c >= 11126 && c <= 11157)
                : c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_60(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 247
        ? (c < '|'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || c == '+'))
            : (c <= ':' || (c < '\\'
              ? (c >= '<' && c <= '@')
              : (c <= '\\' || c == '^'))))
          : (c <= '|' || (c < 172
            ? (c < 166
              ? c == '~'
              : (c <= 166 || c == 169))
            : (c <= 172 || (c < 176
              ? c == 174
              : (c <= 177 || c == 215))))))
        : (c <= 247 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? c == 1014
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_61(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 247
        ? (c < '|'
          ? (c < ':'
            ? (c < '+'
              ? (c < '%'
                ? c == '#'
                : c <= '&')
              : (c <= '+' || c == '-'))
            : (c <= ':' || (c < '\\'
              ? (c >= '<' && c <= '@')
              : (c <= '\\' || c == '^'))))
          : (c <= '|' || (c < 172
            ? (c < 166
              ? c == '~'
              : (c <= 166 || c == 169))
            : (c <= 172 || (c < 176
              ? c == 174
              : (c <= 177 || c == 215))))))
        : (c <= 247 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? c == 1014
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_62(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 247
        ? (c < '|'
          ? (c < '-'
            ? (c < '&'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || c == '+'))
            : (c <= '-' || (c < '\\'
              ? (c >= '<' && c <= '@')
              : (c <= '\\' || c == '^'))))
          : (c <= '|' || (c < 172
            ? (c < 166
              ? c == '~'
              : (c <= 166 || c == 169))
            : (c <= 172 || (c < 176
              ? c == 174
              : (c <= 177 || c == 215))))))
        : (c <= 247 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? c == 1014
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_63(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 215
        ? (c < '^'
          ? (c < '-'
            ? (c < '&'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || c == '+'))
            : (c <= '-' || (c < '<'
              ? c == ':'
              : (c <= '@' || c == '\\'))))
          : (c <= '^' || (c < 169
            ? (c < '~'
              ? c == '|'
              : (c <= '~' || c == 166))
            : (c <= 169 || (c < 174
              ? c == 172
              : (c <= 174 || (c >= 176 && c <= 177)))))))
        : (c <= 215 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? (c < 1014
                ? c == 247
                : c <= 1014)
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_64(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 247
        ? (c < '|'
          ? (c < ':'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || c == '+'))
            : (c <= ':' || (c < '\\'
              ? (c >= '<' && c <= '@')
              : (c <= '\\' || c == '^'))))
          : (c <= '|' || (c < 172
            ? (c < 166
              ? c == '~'
              : (c <= 166 || c == 169))
            : (c <= 172 || (c < 176
              ? c == 174
              : (c <= 177 || c == 215))))))
        : (c <= 247 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? c == 1014
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static inline bool sym_operator_identifier_character_set_65(int32_t c) {
  return (c < 8506
    ? (c < 3449
      ? (c < 247
        ? (c < '|'
          ? (c < '-'
            ? (c < '%'
              ? (c < '#'
                ? c == '!'
                : c <= '#')
              : (c <= '&' || c == '+'))
            : (c <= '-' || (c < '\\'
              ? (c >= '<' && c <= '@')
              : (c <= '\\' || c == '^'))))
          : (c <= '|' || (c < 172
            ? (c < 166
              ? c == '~'
              : (c <= 166 || c == 169))
            : (c <= 172 || (c < 176
              ? c == 174
              : (c <= 177 || c == 215))))))
        : (c <= 247 || (c < 1789
          ? (c < 1542
            ? (c < 1154
              ? c == 1014
              : (c <= 1154 || (c >= 1421 && c <= 1422)))
            : (c <= 1544 || (c < 1758
              ? (c >= 1550 && c <= 1551)
              : (c <= 1758 || c == 1769))))
          : (c <= 1790 || (c < 3059
            ? (c < 2554
              ? c == 2038
              : (c <= 2554 || c == 2928))
            : (c <= 3064 || (c < 3199
              ? c == 3066
              : (c <= 3199 || c == 3407))))))))
      : (c <= 3449 || (c < 7009
        ? (c < 4039
          ? (c < 3892
            ? (c < 3861
              ? (c < 3859
                ? (c >= 3841 && c <= 3843)
                : c <= 3859)
              : (c <= 3863 || (c >= 3866 && c <= 3871)))
            : (c <= 3892 || (c < 3896
              ? c == 3894
              : (c <= 3896 || (c >= 4030 && c <= 4037)))))
          : (c <= 4044 || (c < 5008
            ? (c < 4053
              ? (c >= 4046 && c <= 4047)
              : (c <= 4056 || (c >= 4254 && c <= 4255)))
            : (c <= 5017 || (c < 6464
              ? c == 5741
              : (c <= 6464 || (c >= 6622 && c <= 6655)))))))
        : (c <= 7018 || (c < 8456
          ? (c < 8314
            ? (c < 8260
              ? (c >= 7028 && c <= 7036)
              : (c <= 8260 || c == 8274))
            : (c <= 8316 || (c < 8448
              ? (c >= 8330 && c <= 8332)
              : (c <= 8449 || (c >= 8451 && c <= 8454)))))
          : (c <= 8457 || (c < 8485
            ? (c < 8470
              ? c == 8468
              : (c <= 8472 || (c >= 8478 && c <= 8483)))
            : (c <= 8485 || (c < 8489
              ? c == 8487
              : (c <= 8489 || c == 8494))))))))))
    : (c <= 8507 || (c < 12800
      ? (c < 11126
        ? (c < 9372
          ? (c < 8592
            ? (c < 8527
              ? (c < 8522
                ? (c >= 8512 && c <= 8516)
                : c <= 8525)
              : (c <= 8527 || (c >= 8586 && c <= 8587)))
            : (c <= 8967 || (c < 9003
              ? (c >= 8972 && c <= 9000)
              : (c <= 9254 || (c >= 9280 && c <= 9290)))))
          : (c <= 9449 || (c < 10224
            ? (c < 10132
              ? (c >= 9472 && c <= 10087)
              : (c <= 10180 || (c >= 10183 && c <= 10213)))
            : (c <= 10626 || (c < 10716
              ? (c >= 10649 && c <= 10711)
              : (c <= 10747 || (c >= 10750 && c <= 11123)))))))
        : (c <= 11157 || (c < 12292
          ? (c < 11904
            ? (c < 11493
              ? (c >= 11159 && c <= 11263)
              : (c <= 11498 || (c >= 11856 && c <= 11857)))
            : (c <= 11929 || (c < 12032
              ? (c >= 11931 && c <= 12019)
              : (c <= 12245 || (c >= 12272 && c <= 12283)))))
          : (c <= 12292 || (c < 12350
            ? (c < 12320
              ? (c >= 12306 && c <= 12307)
              : (c <= 12320 || (c >= 12342 && c <= 12343)))
            : (c <= 12351 || (c < 12694
              ? (c >= 12688 && c <= 12689)
              : (c <= 12703 || (c >= 12736 && c <= 12771)))))))))
      : (c <= 12830 || (c < 65124
        ? (c < 43062
          ? (c < 12992
            ? (c < 12896
              ? (c < 12880
                ? (c >= 12842 && c <= 12871)
                : c <= 12880)
              : (c <= 12927 || (c >= 12938 && c <= 12976)))
            : (c <= 13311 || (c < 42128
              ? (c >= 19904 && c <= 19967)
              : (c <= 42182 || (c >= 43048 && c <= 43051)))))
          : (c <= 43063 || (c < 64832
            ? (c < 43639
              ? c == 43065
              : (c <= 43641 || c == 64297))
            : (c <= 64847 || (c < 65021
              ? c == 64975
              : (c <= 65023 || c == 65122))))))
        : (c <= 65126 || (c < 65532
          ? (c < 65374
            ? (c < 65308
              ? c == 65291
              : (c <= 65310 || c == 65372))
            : (c <= 65374 || (c < 65508
              ? c == 65506
              : (c <= 65508 || (c >= 65512 && c <= 65518)))))
          : (c <= 65533 || (c < 65936
            ? (c < 65913
              ? (c >= 65847 && c <= 65855)
              : (c <= 65929 || (c >= 65932 && c <= 65934)))
            : (c <= 65948 || (c < 66000
              ? c == 65952
              : (c <= 66044 || (c >= 67703 && c <= 67704)))))))))))));
}

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(102);
      if (lookahead == '!') ADVANCE(142);
      if (lookahead == '"') ADVANCE(177);
      if (lookahead == '#') ADVANCE(135);
      if (lookahead == '$') ADVANCE(147);
      if (lookahead == '\'') ADVANCE(148);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(110);
      if (lookahead == '+') ADVANCE(116);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '-') ADVANCE(119);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == '/') ADVANCE(43);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == ':') ADVANCE(103);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '<') ADVANCE(18);
      if (lookahead == '=') ADVANCE(129);
      if (lookahead == '>') ADVANCE(189);
      if (lookahead == '?') ADVANCE(50);
      if (lookahead == '@') ADVANCE(126);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '|') ADVANCE(140);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '~') ADVANCE(144);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(69)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym__alpha_identifier_character_set_1(lookahead)) ADVANCE(150);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(1)
      if (lookahead == '*') ADVANCE(201);
      if (lookahead == '/') ADVANCE(199);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(200);
      if (lookahead != 0) ADVANCE(198);
      END_STATE();
    case 2:
      if (lookahead == '!') ADVANCE(143);
      if (lookahead == '$') ADVANCE(147);
      if (lookahead == '\'') ADVANCE(148);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '+') ADVANCE(117);
      if (lookahead == '-') ADVANCE(118);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(131);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '~') ADVANCE(145);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(2)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_1(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_2(lookahead)) ADVANCE(150);
      END_STATE();
    case 3:
      if (lookahead == '!') ADVANCE(143);
      if (lookahead == '$') ADVANCE(147);
      if (lookahead == '\'') ADVANCE(148);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '+') ADVANCE(117);
      if (lookahead == '-') ADVANCE(118);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '~') ADVANCE(145);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(3)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_1(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_2(lookahead)) ADVANCE(150);
      END_STATE();
    case 4:
      if (lookahead == '"') ADVANCE(177);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '<') ADVANCE(158);
      if (lookahead == '=') ADVANCE(131);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(4)
      if (sym_operator_identifier_character_set_2(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 5:
      if (lookahead == '"') ADVANCE(177);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(5)
      if (sym_operator_identifier_character_set_3(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 6:
      if (lookahead == '"') ADVANCE(177);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(131);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(6)
      if (sym_operator_identifier_character_set_3(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 7:
      if (lookahead == '"') ADVANCE(177);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(7)
      if (sym_operator_identifier_character_set_4(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 8:
      if (lookahead == '"') ADVANCE(178);
      END_STATE();
    case 9:
      if (lookahead == '"') ADVANCE(176);
      if (lookahead == '$') ADVANCE(146);
      if (lookahead == '/') ADVANCE(43);
      if (lookahead == '=') ADVANCE(54);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(9)
      if (sym__interpolation_identifier_character_set_1(lookahead)) ADVANCE(152);
      END_STATE();
    case 10:
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '<') ADVANCE(158);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(10)
      if (sym_operator_identifier_character_set_5(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 11:
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(11)
      if (sym_operator_identifier_character_set_6(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 12:
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(12)
      if (sym_operator_identifier_character_set_7(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 13:
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '+') ADVANCE(117);
      if (lookahead == '-') ADVANCE(120);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(13)
      if (sym_operator_identifier_character_set_8(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 14:
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '<') ADVANCE(155);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(14)
      if (sym_operator_identifier_character_set_9(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_4(lookahead)) ADVANCE(150);
      END_STATE();
    case 15:
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '<') ADVANCE(156);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(15)
      if (sym_operator_identifier_character_set_9(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_4(lookahead)) ADVANCE(150);
      END_STATE();
    case 16:
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(16)
      if (sym_operator_identifier_character_set_10(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 17:
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(17)
      if (sym_operator_identifier_character_set_11(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 18:
      if (lookahead == '%') ADVANCE(124);
      if (lookahead == '-') ADVANCE(179);
      if (lookahead == ':') ADVANCE(121);
      END_STATE();
    case 19:
      if (lookahead == '%') ADVANCE(124);
      if (lookahead == ':') ADVANCE(121);
      END_STATE();
    case 20:
      if (lookahead == '\'') ADVANCE(148);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '-') ADVANCE(159);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(20)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_12(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 21:
      if (lookahead == '\'') ADVANCE(175);
      END_STATE();
    case 22:
      if (lookahead == '\'') ADVANCE(175);
      if (lookahead == '\\') ADVANCE(56);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(21);
      END_STATE();
    case 23:
      if (lookahead == '\'') ADVANCE(22);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '-') ADVANCE(159);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(23)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_13(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_4(lookahead)) ADVANCE(150);
      END_STATE();
    case 24:
      if (lookahead == '\'') ADVANCE(22);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '-') ADVANCE(159);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(24)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_14(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 25:
      if (lookahead == '\'') ADVANCE(22);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '-') ADVANCE(159);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(25)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_15(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 26:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '<') ADVANCE(158);
      if (lookahead == '=') ADVANCE(131);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(26)
      if (sym_operator_identifier_character_set_16(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_4(lookahead)) ADVANCE(150);
      END_STATE();
    case 27:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(27)
      if (sym_operator_identifier_character_set_17(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 28:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '<') ADVANCE(158);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(28)
      if (sym_operator_identifier_character_set_18(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 29:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(29)
      if (sym_operator_identifier_character_set_19(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 30:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(30)
      if (sym_operator_identifier_character_set_20(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 31:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(31)
      if (sym_operator_identifier_character_set_21(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 32:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(32)
      if (sym_operator_identifier_character_set_22(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_4(lookahead)) ADVANCE(150);
      END_STATE();
    case 33:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(33)
      if (sym_operator_identifier_character_set_23(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 34:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '+') ADVANCE(117);
      if (lookahead == '-') ADVANCE(120);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(34)
      if (sym_operator_identifier_character_set_24(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_4(lookahead)) ADVANCE(150);
      END_STATE();
    case 35:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '<') ADVANCE(155);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(35)
      if (sym_operator_identifier_character_set_25(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 36:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '<') ADVANCE(156);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(36)
      if (sym_operator_identifier_character_set_25(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 37:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(37)
      if (sym_operator_identifier_character_set_26(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 38:
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(38)
      if (sym_operator_identifier_character_set_27(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 39:
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '<') ADVANCE(158);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(39)
      if (sym_operator_identifier_character_set_28(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 40:
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(40)
      if (sym_operator_identifier_character_set_17(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 41:
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(41)
      if (sym_operator_identifier_character_set_29(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 42:
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(42)
      if (sym_operator_identifier_character_set_30(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 43:
      if (lookahead == '*') ADVANCE(195);
      if (lookahead == '/') ADVANCE(182);
      END_STATE();
    case 44:
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(44)
      if (sym_operator_identifier_character_set_31(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 45:
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '<') ADVANCE(155);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(45)
      if (sym_operator_identifier_character_set_32(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 46:
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '<') ADVANCE(156);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(46)
      if (sym_operator_identifier_character_set_32(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 47:
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(47)
      if (sym_operator_identifier_character_set_27(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 48:
      if (lookahead == '/') ADVANCE(190);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(48)
      if (lookahead != 0) ADVANCE(191);
      END_STATE();
    case 49:
      if (lookahead == ':') ADVANCE(123);
      END_STATE();
    case 50:
      if (lookahead == '=') ADVANCE(52);
      END_STATE();
    case 51:
      if (lookahead == '>') ADVANCE(112);
      END_STATE();
    case 52:
      if (lookahead == '>') ADVANCE(137);
      END_STATE();
    case 53:
      if (lookahead == '>') ADVANCE(139);
      END_STATE();
    case 54:
      if (lookahead == '>') ADVANCE(53);
      END_STATE();
    case 55:
      if (lookahead == '`') ADVANCE(153);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(55);
      END_STATE();
    case 56:
      if (lookahead == 'u') ADVANCE(57);
      if (lookahead == 'x') ADVANCE(67);
      if (lookahead != 0) ADVANCE(21);
      END_STATE();
    case 57:
      if (lookahead == '{') ADVANCE(65);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(66);
      END_STATE();
    case 58:
      if (lookahead == '}') ADVANCE(21);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(58);
      END_STATE();
    case 59:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(62);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(174);
      END_STATE();
    case 60:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(173);
      END_STATE();
    case 61:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(171);
      END_STATE();
    case 62:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(174);
      END_STATE();
    case 63:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(21);
      END_STATE();
    case 64:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(170);
      END_STATE();
    case 65:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(58);
      END_STATE();
    case 66:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(67);
      END_STATE();
    case 67:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(63);
      END_STATE();
    case 68:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(55);
      END_STATE();
    case 69:
      if (eof) ADVANCE(102);
      if (lookahead == '!') ADVANCE(142);
      if (lookahead == '"') ADVANCE(177);
      if (lookahead == '#') ADVANCE(135);
      if (lookahead == '$') ADVANCE(147);
      if (lookahead == '\'') ADVANCE(148);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(110);
      if (lookahead == '+') ADVANCE(116);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '-') ADVANCE(119);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == '/') ADVANCE(43);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == ':') ADVANCE(103);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '<') ADVANCE(18);
      if (lookahead == '=') ADVANCE(129);
      if (lookahead == '>') ADVANCE(49);
      if (lookahead == '?') ADVANCE(50);
      if (lookahead == '@') ADVANCE(126);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '|') ADVANCE(140);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '~') ADVANCE(144);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(69)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym__alpha_identifier_character_set_1(lookahead)) ADVANCE(150);
      END_STATE();
    case 70:
      if (eof) ADVANCE(102);
      if (lookahead == '!') ADVANCE(143);
      if (lookahead == '"') ADVANCE(177);
      if (lookahead == '$') ADVANCE(147);
      if (lookahead == '\'') ADVANCE(148);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '+') ADVANCE(117);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '-') ADVANCE(118);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '~') ADVANCE(145);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(70)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_33(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_2(lookahead)) ADVANCE(150);
      END_STATE();
    case 71:
      if (eof) ADVANCE(102);
      if (lookahead == '!') ADVANCE(143);
      if (lookahead == '#') ADVANCE(154);
      if (lookahead == '$') ADVANCE(147);
      if (lookahead == '\'') ADVANCE(148);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '+') ADVANCE(117);
      if (lookahead == '-') ADVANCE(118);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '~') ADVANCE(145);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(71)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_34(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_2(lookahead)) ADVANCE(150);
      END_STATE();
    case 72:
      if (eof) ADVANCE(102);
      if (lookahead == '!') ADVANCE(143);
      if (lookahead == '$') ADVANCE(147);
      if (lookahead == '\'') ADVANCE(148);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '+') ADVANCE(117);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '-') ADVANCE(118);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '~') ADVANCE(145);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(72)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_33(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_2(lookahead)) ADVANCE(150);
      END_STATE();
    case 73:
      if (eof) ADVANCE(102);
      if (lookahead == '!') ADVANCE(143);
      if (lookahead == '$') ADVANCE(147);
      if (lookahead == '\'') ADVANCE(148);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '+') ADVANCE(117);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '-') ADVANCE(118);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '~') ADVANCE(145);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(73)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_33(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_2(lookahead)) ADVANCE(150);
      END_STATE();
    case 74:
      if (eof) ADVANCE(102);
      if (lookahead == '!') ADVANCE(143);
      if (lookahead == '$') ADVANCE(147);
      if (lookahead == '\'') ADVANCE(148);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '+') ADVANCE(117);
      if (lookahead == '-') ADVANCE(118);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '~') ADVANCE(145);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(74)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_35(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_2(lookahead)) ADVANCE(150);
      END_STATE();
    case 75:
      if (eof) ADVANCE(102);
      if (lookahead == '"') ADVANCE(177);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(75)
      if (sym_operator_identifier_character_set_36(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_4(lookahead)) ADVANCE(150);
      END_STATE();
    case 76:
      if (eof) ADVANCE(102);
      if (lookahead == '#') ADVANCE(135);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(110);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(43);
      if (lookahead == ':') ADVANCE(103);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '<') ADVANCE(19);
      if (lookahead == '=') ADVANCE(128);
      if (lookahead == '>') ADVANCE(49);
      if (lookahead == '@') ADVANCE(126);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(76)
      if (sym__alpha_identifier_character_set_5(lookahead)) ADVANCE(150);
      END_STATE();
    case 77:
      if (eof) ADVANCE(102);
      if (lookahead == '#') ADVANCE(135);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(110);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(43);
      if (lookahead == ':') ADVANCE(103);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '<') ADVANCE(19);
      if (lookahead == '=') ADVANCE(51);
      if (lookahead == '>') ADVANCE(49);
      if (lookahead == '?') ADVANCE(50);
      if (lookahead == '@') ADVANCE(126);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(77)
      if (sym__alpha_identifier_character_set_5(lookahead)) ADVANCE(150);
      END_STATE();
    case 78:
      if (eof) ADVANCE(102);
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(78)
      if (sym_operator_identifier_character_set_37(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 79:
      if (eof) ADVANCE(102);
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(131);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(79)
      if (sym_operator_identifier_character_set_38(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 80:
      if (eof) ADVANCE(102);
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(80)
      if (sym_operator_identifier_character_set_39(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_4(lookahead)) ADVANCE(150);
      END_STATE();
    case 81:
      if (eof) ADVANCE(102);
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(81)
      if (sym_operator_identifier_character_set_40(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 82:
      if (eof) ADVANCE(102);
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(82)
      if (sym_operator_identifier_character_set_41(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 83:
      if (eof) ADVANCE(102);
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '<') ADVANCE(160);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(83)
      if (sym_operator_identifier_character_set_42(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 84:
      if (eof) ADVANCE(102);
      if (lookahead == '\'') ADVANCE(22);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '-') ADVANCE(159);
      if (lookahead == '.') ADVANCE(109);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(84)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_43(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_6(lookahead)) ADVANCE(150);
      END_STATE();
    case 85:
      if (eof) ADVANCE(102);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(85)
      if (sym_operator_identifier_character_set_44(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 86:
      if (eof) ADVANCE(102);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(131);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(86)
      if (sym_operator_identifier_character_set_45(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 87:
      if (eof) ADVANCE(102);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(131);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(87)
      if (sym_operator_identifier_character_set_46(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_4(lookahead)) ADVANCE(150);
      END_STATE();
    case 88:
      if (eof) ADVANCE(102);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(88)
      if (sym_operator_identifier_character_set_47(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_4(lookahead)) ADVANCE(150);
      END_STATE();
    case 89:
      if (eof) ADVANCE(102);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(89)
      if (sym_operator_identifier_character_set_48(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 90:
      if (eof) ADVANCE(102);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(90)
      if (sym_operator_identifier_character_set_49(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 91:
      if (eof) ADVANCE(102);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == '.') ADVANCE(108);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(131);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(91)
      if (sym_operator_identifier_character_set_23(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 92:
      if (eof) ADVANCE(102);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(92)
      if (sym_operator_identifier_character_set_50(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 93:
      if (eof) ADVANCE(102);
      if (lookahead == '(') ADVANCE(132);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '<') ADVANCE(160);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '@') ADVANCE(127);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(93)
      if (sym_operator_identifier_character_set_51(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 94:
      if (eof) ADVANCE(102);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(94)
      if (sym_operator_identifier_character_set_52(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 95:
      if (eof) ADVANCE(102);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(95)
      if (sym_operator_identifier_character_set_53(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 96:
      if (eof) ADVANCE(102);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(96)
      if (sym_operator_identifier_character_set_46(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_4(lookahead)) ADVANCE(150);
      END_STATE();
    case 97:
      if (eof) ADVANCE(102);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(162);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '[') ADVANCE(114);
      if (lookahead == ']') ADVANCE(115);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(97)
      if (sym_operator_identifier_character_set_54(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_4(lookahead)) ADVANCE(150);
      END_STATE();
    case 98:
      if (eof) ADVANCE(102);
      if (lookahead == ')') ADVANCE(133);
      if (lookahead == ',') ADVANCE(107);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(98)
      if (sym_operator_identifier_character_set_55(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 99:
      if (eof) ADVANCE(102);
      if (lookahead == '*') ADVANCE(111);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '|') ADVANCE(141);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(99)
      if (sym_operator_identifier_character_set_23(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 100:
      if (eof) ADVANCE(102);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ':') ADVANCE(104);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '<') ADVANCE(160);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '{') ADVANCE(105);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(100)
      if (sym_operator_identifier_character_set_56(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 101:
      if (eof) ADVANCE(102);
      if (lookahead == '/') ADVANCE(157);
      if (lookahead == ';') ADVANCE(134);
      if (lookahead == '<') ADVANCE(160);
      if (lookahead == '=') ADVANCE(130);
      if (lookahead == '?') ADVANCE(161);
      if (lookahead == '`') ADVANCE(68);
      if (lookahead == '}') ADVANCE(106);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(101)
      if (sym_operator_identifier_character_set_57(lookahead)) ADVANCE(164);
      if (sym__alpha_identifier_character_set_3(lookahead)) ADVANCE(150);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(173);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      if (sym_operator_identifier_character_set_59(lookahead)) ADVANCE(165);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_60(lookahead)) ADVANCE(165);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '0') ADVANCE(168);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_LT_COLON);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_LT_COLON);
      if (sym_operator_identifier_character_set_59(lookahead)) ADVANCE(165);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_GT_COLON);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_LT_PERCENT);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_LT_PERCENT);
      if (sym_operator_identifier_character_set_59(lookahead)) ADVANCE(165);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '>') ADVANCE(112);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '>') ADVANCE(113);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_QMARK_EQ_GT);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_QMARK_EQ_GT);
      if (sym_operator_identifier_character_set_59(lookahead)) ADVANCE(165);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_EQ_GT_GT);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == '_') ADVANCE(149);
      if (sym__alpha_identifier_character_set_7(lookahead)) ADVANCE(150);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      if (lookahead == '\'') ADVANCE(175);
      if (lookahead == '\\') ADVANCE(56);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(21);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(sym__alpha_identifier);
      if (lookahead == '_') ADVANCE(149);
      if (sym_operator_identifier_character_set_59(lookahead)) ADVANCE(151);
      if (sym__alpha_identifier_character_set_8(lookahead)) ADVANCE(150);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(sym__alpha_identifier);
      if (lookahead == '_') ADVANCE(149);
      if (sym__alpha_identifier_character_set_7(lookahead)) ADVANCE(150);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(sym__alpha_identifier);
      if (sym_operator_identifier_character_set_59(lookahead)) ADVANCE(151);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(sym__interpolation_identifier);
      if (sym__interpolation_identifier_character_set_2(lookahead)) ADVANCE(152);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(sym__backquoted_id);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '!') ADVANCE(166);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_61(lookahead)) ADVANCE(165);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '%') ADVANCE(125);
      if (lookahead == ':') ADVANCE(122);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_62(lookahead)) ADVANCE(165);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '%') ADVANCE(125);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_63(lookahead)) ADVANCE(165);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '*') ADVANCE(195);
      if (lookahead == '/') ADVANCE(182);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '-') ADVANCE(180);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_64(lookahead)) ADVANCE(165);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '0') ADVANCE(168);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (sym_operator_identifier_character_set_60(lookahead)) ADVANCE(165);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == ':') ADVANCE(122);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_65(lookahead)) ADVANCE(165);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '=') ADVANCE(163);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '>') ADVANCE(113);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '>') ADVANCE(138);
      if (sym_operator_identifier_character_set_59(lookahead)) ADVANCE(165);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (lookahead == '*' ||
          lookahead == '/') ADVANCE(165);
      if (sym_operator_identifier_character_set_58(lookahead)) ADVANCE(165);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (sym_operator_identifier_character_set_59(lookahead)) ADVANCE(165);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(sym_operator_identifier);
      if (sym_operator_identifier_character_set_59(lookahead)) ADVANCE(166);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(181);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(sym_integer_literal);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '_') ADVANCE(61);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(59);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(167);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(64);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(172);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(169);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '_') ADVANCE(61);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(59);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(167);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(172);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(169);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '_') ADVANCE(64);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(167);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(170);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '_') ADVANCE(61);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(167);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(171);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(sym_floating_point_literal);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(sym_floating_point_literal);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(59);
      if (('D' <= lookahead && lookahead <= 'F') ||
          ('d' <= lookahead && lookahead <= 'f')) ADVANCE(172);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(173);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(sym_floating_point_literal);
      if (lookahead == 'D' ||
          lookahead == 'F' ||
          lookahead == 'd' ||
          lookahead == 'f') ADVANCE(172);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(174);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(sym_character_literal);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      if (lookahead == '"') ADVANCE(8);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(sym__interpolated_multiline_string_start);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      if (sym_operator_identifier_character_set_59(lookahead)) ADVANCE(165);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(aux_sym__shebang_token1);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(181);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != ' ') ADVANCE(191);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(194);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(sym__comment_text);
      if (lookahead == '*') ADVANCE(188);
      if (lookahead == '/') ADVANCE(188);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(188);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(sym__comment_text);
      if (lookahead == '/') ADVANCE(185);
      if (lookahead == '>') ADVANCE(189);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(187);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(188);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(sym__comment_text);
      if (lookahead == '/') ADVANCE(185);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(187);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(188);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(sym__comment_text);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(188);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(sym_using_directive_key);
      if (lookahead == '*') ADVANCE(196);
      if (lookahead == '/') ADVANCE(183);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != ' ') ADVANCE(191);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(sym_using_directive_key);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != ' ') ADVANCE(191);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(sym_using_directive_value);
      if (lookahead == '*') ADVANCE(197);
      if (lookahead == '/') ADVANCE(184);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(194);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(sym_using_directive_value);
      if (lookahead == '/') ADVANCE(192);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(193);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(194);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(sym_using_directive_value);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(194);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_SLASH_STAR);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_SLASH_STAR);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != ' ') ADVANCE(191);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_SLASH_STAR);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(194);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(aux_sym_block_comment_token1);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(aux_sym_block_comment_token1);
      if (lookahead == '*') ADVANCE(195);
      if (lookahead == '/') ADVANCE(182);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(aux_sym_block_comment_token1);
      if (lookahead == '*') ADVANCE(201);
      if (lookahead == '/') ADVANCE(199);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(200);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(198);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(aux_sym_block_comment_token1);
      if (lookahead == '/') ADVANCE(202);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_STAR_SLASH);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (lookahead == '_') ADVANCE(1);
      if (lookahead == 'a') ADVANCE(2);
      if (lookahead == 'c') ADVANCE(3);
      if (lookahead == 'd') ADVANCE(4);
      if (lookahead == 'e') ADVANCE(5);
      if (lookahead == 'f') ADVANCE(6);
      if (lookahead == 'g') ADVANCE(7);
      if (lookahead == 'i') ADVANCE(8);
      if (lookahead == 'l') ADVANCE(9);
      if (lookahead == 'm') ADVANCE(10);
      if (lookahead == 'n') ADVANCE(11);
      if (lookahead == 'o') ADVANCE(12);
      if (lookahead == 'p') ADVANCE(13);
      if (lookahead == 'r') ADVANCE(14);
      if (lookahead == 's') ADVANCE(15);
      if (lookahead == 't') ADVANCE(16);
      if (lookahead == 'u') ADVANCE(17);
      if (lookahead == 'v') ADVANCE(18);
      if (lookahead == 'w') ADVANCE(19);
      if (lookahead == 'y') ADVANCE(20);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(0)
      END_STATE();
    case 1:
      ACCEPT_TOKEN(anon_sym__);
      if (lookahead == '_') ADVANCE(21);
      END_STATE();
    case 2:
      if (lookahead == 'b') ADVANCE(22);
      if (lookahead == 's') ADVANCE(23);
      END_STATE();
    case 3:
      if (lookahead == 'a') ADVANCE(24);
      if (lookahead == 'l') ADVANCE(25);
      END_STATE();
    case 4:
      if (lookahead == 'e') ADVANCE(26);
      if (lookahead == 'o') ADVANCE(27);
      END_STATE();
    case 5:
      if (lookahead == 'l') ADVANCE(28);
      if (lookahead == 'n') ADVANCE(29);
      if (lookahead == 'x') ADVANCE(30);
      END_STATE();
    case 6:
      if (lookahead == 'a') ADVANCE(31);
      if (lookahead == 'i') ADVANCE(32);
      if (lookahead == 'o') ADVANCE(33);
      END_STATE();
    case 7:
      if (lookahead == 'i') ADVANCE(34);
      END_STATE();
    case 8:
      if (lookahead == 'f') ADVANCE(35);
      if (lookahead == 'm') ADVANCE(36);
      if (lookahead == 'n') ADVANCE(37);
      END_STATE();
    case 9:
      if (lookahead == 'a') ADVANCE(38);
      END_STATE();
    case 10:
      if (lookahead == 'a') ADVANCE(39);
      END_STATE();
    case 11:
      if (lookahead == 'e') ADVANCE(40);
      if (lookahead == 'u') ADVANCE(41);
      END_STATE();
    case 12:
      if (lookahead == 'b') ADVANCE(42);
      if (lookahead == 'p') ADVANCE(43);
      if (lookahead == 'v') ADVANCE(44);
      END_STATE();
    case 13:
      if (lookahead == 'a') ADVANCE(45);
      if (lookahead == 'r') ADVANCE(46);
      END_STATE();
    case 14:
      if (lookahead == 'e') ADVANCE(47);
      END_STATE();
    case 15:
      if (lookahead == 'e') ADVANCE(48);
      END_STATE();
    case 16:
      if (lookahead == 'h') ADVANCE(49);
      if (lookahead == 'r') ADVANCE(50);
      if (lookahead == 'y') ADVANCE(51);
      END_STATE();
    case 17:
      if (lookahead == 's') ADVANCE(52);
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(53);
      END_STATE();
    case 19:
      if (lookahead == 'h') ADVANCE(54);
      if (lookahead == 'i') ADVANCE(55);
      END_STATE();
    case 20:
      if (lookahead == 'i') ADVANCE(56);
      END_STATE();
    case 21:
      if (lookahead == 'n') ADVANCE(57);
      END_STATE();
    case 22:
      if (lookahead == 's') ADVANCE(58);
      END_STATE();
    case 23:
      ACCEPT_TOKEN(anon_sym_as);
      END_STATE();
    case 24:
      if (lookahead == 's') ADVANCE(59);
      if (lookahead == 't') ADVANCE(60);
      END_STATE();
    case 25:
      if (lookahead == 'a') ADVANCE(61);
      END_STATE();
    case 26:
      if (lookahead == 'f') ADVANCE(62);
      if (lookahead == 'r') ADVANCE(63);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 28:
      if (lookahead == 's') ADVANCE(64);
      END_STATE();
    case 29:
      if (lookahead == 'd') ADVANCE(65);
      if (lookahead == 'u') ADVANCE(66);
      END_STATE();
    case 30:
      if (lookahead == 'p') ADVANCE(67);
      if (lookahead == 't') ADVANCE(68);
      END_STATE();
    case 31:
      if (lookahead == 'l') ADVANCE(69);
      END_STATE();
    case 32:
      if (lookahead == 'n') ADVANCE(70);
      END_STATE();
    case 33:
      if (lookahead == 'r') ADVANCE(71);
      END_STATE();
    case 34:
      if (lookahead == 'v') ADVANCE(72);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 36:
      if (lookahead == 'p') ADVANCE(73);
      END_STATE();
    case 37:
      if (lookahead == 'f') ADVANCE(74);
      if (lookahead == 'l') ADVANCE(75);
      END_STATE();
    case 38:
      if (lookahead == 'z') ADVANCE(76);
      END_STATE();
    case 39:
      if (lookahead == 'c') ADVANCE(77);
      if (lookahead == 't') ADVANCE(78);
      END_STATE();
    case 40:
      if (lookahead == 'w') ADVANCE(79);
      END_STATE();
    case 41:
      if (lookahead == 'l') ADVANCE(80);
      END_STATE();
    case 42:
      if (lookahead == 'j') ADVANCE(81);
      END_STATE();
    case 43:
      if (lookahead == 'a') ADVANCE(82);
      if (lookahead == 'e') ADVANCE(83);
      END_STATE();
    case 44:
      if (lookahead == 'e') ADVANCE(84);
      END_STATE();
    case 45:
      if (lookahead == 'c') ADVANCE(85);
      END_STATE();
    case 46:
      if (lookahead == 'i') ADVANCE(86);
      if (lookahead == 'o') ADVANCE(87);
      END_STATE();
    case 47:
      if (lookahead == 't') ADVANCE(88);
      END_STATE();
    case 48:
      if (lookahead == 'a') ADVANCE(89);
      END_STATE();
    case 49:
      if (lookahead == 'e') ADVANCE(90);
      if (lookahead == 'i') ADVANCE(91);
      if (lookahead == 'r') ADVANCE(92);
      END_STATE();
    case 50:
      if (lookahead == 'a') ADVANCE(93);
      if (lookahead == 'u') ADVANCE(94);
      if (lookahead == 'y') ADVANCE(95);
      END_STATE();
    case 51:
      if (lookahead == 'p') ADVANCE(96);
      END_STATE();
    case 52:
      if (lookahead == 'i') ADVANCE(97);
      END_STATE();
    case 53:
      if (lookahead == 'l') ADVANCE(98);
      if (lookahead == 'r') ADVANCE(99);
      END_STATE();
    case 54:
      if (lookahead == 'i') ADVANCE(100);
      END_STATE();
    case 55:
      if (lookahead == 't') ADVANCE(101);
      END_STATE();
    case 56:
      if (lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 57:
      if (lookahead == 'o') ADVANCE(103);
      END_STATE();
    case 58:
      if (lookahead == 't') ADVANCE(104);
      END_STATE();
    case 59:
      if (lookahead == 'e') ADVANCE(105);
      END_STATE();
    case 60:
      if (lookahead == 'c') ADVANCE(106);
      END_STATE();
    case 61:
      if (lookahead == 's') ADVANCE(107);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_def);
      END_STATE();
    case 63:
      if (lookahead == 'i') ADVANCE(108);
      END_STATE();
    case 64:
      if (lookahead == 'e') ADVANCE(109);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(anon_sym_end);
      END_STATE();
    case 66:
      if (lookahead == 'm') ADVANCE(110);
      END_STATE();
    case 67:
      if (lookahead == 'o') ADVANCE(111);
      END_STATE();
    case 68:
      if (lookahead == 'e') ADVANCE(112);
      END_STATE();
    case 69:
      if (lookahead == 's') ADVANCE(113);
      END_STATE();
    case 70:
      if (lookahead == 'a') ADVANCE(114);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 72:
      if (lookahead == 'e') ADVANCE(115);
      END_STATE();
    case 73:
      if (lookahead == 'l') ADVANCE(116);
      if (lookahead == 'o') ADVANCE(117);
      END_STATE();
    case 74:
      if (lookahead == 'i') ADVANCE(118);
      END_STATE();
    case 75:
      if (lookahead == 'i') ADVANCE(119);
      END_STATE();
    case 76:
      if (lookahead == 'y') ADVANCE(120);
      END_STATE();
    case 77:
      if (lookahead == 'r') ADVANCE(121);
      END_STATE();
    case 78:
      if (lookahead == 'c') ADVANCE(122);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 80:
      if (lookahead == 'l') ADVANCE(123);
      END_STATE();
    case 81:
      if (lookahead == 'e') ADVANCE(124);
      END_STATE();
    case 82:
      if (lookahead == 'q') ADVANCE(125);
      END_STATE();
    case 83:
      if (lookahead == 'n') ADVANCE(126);
      END_STATE();
    case 84:
      if (lookahead == 'r') ADVANCE(127);
      END_STATE();
    case 85:
      if (lookahead == 'k') ADVANCE(128);
      END_STATE();
    case 86:
      if (lookahead == 'v') ADVANCE(129);
      END_STATE();
    case 87:
      if (lookahead == 't') ADVANCE(130);
      END_STATE();
    case 88:
      if (lookahead == 'u') ADVANCE(131);
      END_STATE();
    case 89:
      if (lookahead == 'l') ADVANCE(132);
      END_STATE();
    case 90:
      if (lookahead == 'n') ADVANCE(133);
      END_STATE();
    case 91:
      if (lookahead == 's') ADVANCE(134);
      END_STATE();
    case 92:
      if (lookahead == 'o') ADVANCE(135);
      END_STATE();
    case 93:
      if (lookahead == 'i') ADVANCE(136);
      if (lookahead == 'n') ADVANCE(137);
      END_STATE();
    case 94:
      if (lookahead == 'e') ADVANCE(138);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 96:
      if (lookahead == 'e') ADVANCE(139);
      END_STATE();
    case 97:
      if (lookahead == 'n') ADVANCE(140);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_val);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_var);
      END_STATE();
    case 100:
      if (lookahead == 'l') ADVANCE(141);
      END_STATE();
    case 101:
      if (lookahead == 'h') ADVANCE(142);
      END_STATE();
    case 102:
      if (lookahead == 'l') ADVANCE(143);
      END_STATE();
    case 103:
      if (lookahead == '_') ADVANCE(144);
      END_STATE();
    case 104:
      if (lookahead == 'r') ADVANCE(145);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 106:
      if (lookahead == 'h') ADVANCE(146);
      END_STATE();
    case 107:
      if (lookahead == 's') ADVANCE(147);
      END_STATE();
    case 108:
      if (lookahead == 'v') ADVANCE(148);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 111:
      if (lookahead == 'r') ADVANCE(149);
      END_STATE();
    case 112:
      if (lookahead == 'n') ADVANCE(150);
      END_STATE();
    case 113:
      if (lookahead == 'e') ADVANCE(151);
      END_STATE();
    case 114:
      if (lookahead == 'l') ADVANCE(152);
      END_STATE();
    case 115:
      if (lookahead == 'n') ADVANCE(153);
      END_STATE();
    case 116:
      if (lookahead == 'i') ADVANCE(154);
      END_STATE();
    case 117:
      if (lookahead == 'r') ADVANCE(155);
      END_STATE();
    case 118:
      if (lookahead == 'x') ADVANCE(156);
      END_STATE();
    case 119:
      if (lookahead == 'n') ADVANCE(157);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_lazy);
      END_STATE();
    case 121:
      if (lookahead == 'o') ADVANCE(158);
      END_STATE();
    case 122:
      if (lookahead == 'h') ADVANCE(159);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(sym_null_literal);
      END_STATE();
    case 124:
      if (lookahead == 'c') ADVANCE(160);
      END_STATE();
    case 125:
      if (lookahead == 'u') ADVANCE(161);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_open);
      END_STATE();
    case 127:
      if (lookahead == 'r') ADVANCE(162);
      END_STATE();
    case 128:
      if (lookahead == 'a') ADVANCE(163);
      END_STATE();
    case 129:
      if (lookahead == 'a') ADVANCE(164);
      END_STATE();
    case 130:
      if (lookahead == 'e') ADVANCE(165);
      END_STATE();
    case 131:
      if (lookahead == 'r') ADVANCE(166);
      END_STATE();
    case 132:
      if (lookahead == 'e') ADVANCE(167);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_then);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_this);
      END_STATE();
    case 135:
      if (lookahead == 'w') ADVANCE(168);
      END_STATE();
    case 136:
      if (lookahead == 't') ADVANCE(169);
      END_STATE();
    case 137:
      if (lookahead == 's') ADVANCE(170);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 140:
      if (lookahead == 'g') ADVANCE(171);
      END_STATE();
    case 141:
      if (lookahead == 'e') ADVANCE(172);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_with);
      END_STATE();
    case 143:
      if (lookahead == 'd') ADVANCE(173);
      END_STATE();
    case 144:
      if (lookahead == 'l') ADVANCE(174);
      END_STATE();
    case 145:
      if (lookahead == 'a') ADVANCE(175);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 148:
      if (lookahead == 'e') ADVANCE(176);
      END_STATE();
    case 149:
      if (lookahead == 't') ADVANCE(177);
      END_STATE();
    case 150:
      if (lookahead == 'd') ADVANCE(178);
      if (lookahead == 's') ADVANCE(179);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_final);
      if (lookahead == 'l') ADVANCE(180);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_given);
      END_STATE();
    case 154:
      if (lookahead == 'c') ADVANCE(181);
      END_STATE();
    case 155:
      if (lookahead == 't') ADVANCE(182);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_infix);
      END_STATE();
    case 157:
      if (lookahead == 'e') ADVANCE(183);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_macro);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_match);
      END_STATE();
    case 160:
      if (lookahead == 't') ADVANCE(184);
      END_STATE();
    case 161:
      if (lookahead == 'e') ADVANCE(185);
      END_STATE();
    case 162:
      if (lookahead == 'i') ADVANCE(186);
      END_STATE();
    case 163:
      if (lookahead == 'g') ADVANCE(187);
      END_STATE();
    case 164:
      if (lookahead == 't') ADVANCE(188);
      END_STATE();
    case 165:
      if (lookahead == 'c') ADVANCE(189);
      END_STATE();
    case 166:
      if (lookahead == 'n') ADVANCE(190);
      END_STATE();
    case 167:
      if (lookahead == 'd') ADVANCE(191);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_throw);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_trait);
      END_STATE();
    case 170:
      if (lookahead == 'p') ADVANCE(192);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_using);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(anon_sym_yield);
      END_STATE();
    case 174:
      if (lookahead == 'o') ADVANCE(193);
      END_STATE();
    case 175:
      if (lookahead == 'c') ADVANCE(194);
      END_STATE();
    case 176:
      if (lookahead == 's') ADVANCE(195);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(anon_sym_export);
      END_STATE();
    case 178:
      if (lookahead == 's') ADVANCE(196);
      END_STATE();
    case 179:
      if (lookahead == 'i') ADVANCE(197);
      END_STATE();
    case 180:
      if (lookahead == 'y') ADVANCE(198);
      END_STATE();
    case 181:
      if (lookahead == 'i') ADVANCE(199);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(anon_sym_inline);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_object);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_opaque);
      END_STATE();
    case 186:
      if (lookahead == 'd') ADVANCE(200);
      END_STATE();
    case 187:
      if (lookahead == 'e') ADVANCE(201);
      END_STATE();
    case 188:
      if (lookahead == 'e') ADVANCE(202);
      END_STATE();
    case 189:
      if (lookahead == 't') ADVANCE(203);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_sealed);
      END_STATE();
    case 192:
      if (lookahead == 'a') ADVANCE(204);
      END_STATE();
    case 193:
      if (lookahead == 'n') ADVANCE(205);
      END_STATE();
    case 194:
      if (lookahead == 't') ADVANCE(206);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_derives);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_extends);
      END_STATE();
    case 197:
      if (lookahead == 'o') ADVANCE(207);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_finally);
      END_STATE();
    case 199:
      if (lookahead == 't') ADVANCE(208);
      END_STATE();
    case 200:
      if (lookahead == 'e') ADVANCE(209);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(anon_sym_package);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 203:
      if (lookahead == 'e') ADVANCE(210);
      END_STATE();
    case 204:
      if (lookahead == 'r') ADVANCE(211);
      END_STATE();
    case 205:
      if (lookahead == 'g') ADVANCE(212);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(anon_sym_abstract);
      END_STATE();
    case 207:
      if (lookahead == 'n') ADVANCE(213);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(anon_sym_implicit);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(anon_sym_override);
      END_STATE();
    case 210:
      if (lookahead == 'd') ADVANCE(214);
      END_STATE();
    case 211:
      if (lookahead == 'e') ADVANCE(215);
      END_STATE();
    case 212:
      if (lookahead == 'e') ADVANCE(216);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(anon_sym_extension);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(anon_sym_protected);
      END_STATE();
    case 215:
      if (lookahead == 'n') ADVANCE(217);
      END_STATE();
    case 216:
      if (lookahead == 'r') ADVANCE(218);
      END_STATE();
    case 217:
      if (lookahead == 't') ADVANCE(219);
      END_STATE();
    case 218:
      if (lookahead == '_') ADVANCE(220);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(anon_sym_transparent);
      END_STATE();
    case 220:
      if (lookahead == 'u') ADVANCE(221);
      END_STATE();
    case 221:
      if (lookahead == 's') ADVANCE(222);
      END_STATE();
    case 222:
      if (lookahead == 'e') ADVANCE(223);
      END_STATE();
    case 223:
      if (lookahead == 'd') ADVANCE(224);
      END_STATE();
    case 224:
      if (lookahead == '_') ADVANCE(225);
      END_STATE();
    case 225:
      if (lookahead == 's') ADVANCE(226);
      END_STATE();
    case 226:
      if (lookahead == 'y') ADVANCE(227);
      END_STATE();
    case 227:
      if (lookahead == 'm') ADVANCE(228);
      END_STATE();
    case 228:
      if (lookahead == 'b') ADVANCE(229);
      END_STATE();
    case 229:
      if (lookahead == 'o') ADVANCE(230);
      END_STATE();
    case 230:
      if (lookahead == 'l') ADVANCE(231);
      END_STATE();
    case 231:
      if (lookahead == '_') ADVANCE(232);
      END_STATE();
    case 232:
      if (lookahead == 'l') ADVANCE(233);
      END_STATE();
    case 233:
      if (lookahead == 'i') ADVANCE(234);
      END_STATE();
    case 234:
      if (lookahead == 't') ADVANCE(235);
      END_STATE();
    case 235:
      if (lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 236:
      if (lookahead == 'r') ADVANCE(237);
      END_STATE();
    case 237:
      if (lookahead == 'a') ADVANCE(238);
      END_STATE();
    case 238:
      if (lookahead == 'l') ADVANCE(239);
      END_STATE();
    case 239:
      if (lookahead == '_') ADVANCE(240);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(sym_symbol_literal);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 71, .external_lex_state = 2},
  [2] = {.lex_state = 74, .external_lex_state = 3},
  [3] = {.lex_state = 74, .external_lex_state = 3},
  [4] = {.lex_state = 74, .external_lex_state = 3},
  [5] = {.lex_state = 74, .external_lex_state = 3},
  [6] = {.lex_state = 74, .external_lex_state = 3},
  [7] = {.lex_state = 74, .external_lex_state = 3},
  [8] = {.lex_state = 74, .external_lex_state = 3},
  [9] = {.lex_state = 74, .external_lex_state = 3},
  [10] = {.lex_state = 74, .external_lex_state = 3},
  [11] = {.lex_state = 74, .external_lex_state = 3},
  [12] = {.lex_state = 74, .external_lex_state = 3},
  [13] = {.lex_state = 74, .external_lex_state = 3},
  [14] = {.lex_state = 74, .external_lex_state = 3},
  [15] = {.lex_state = 74, .external_lex_state = 3},
  [16] = {.lex_state = 74, .external_lex_state = 3},
  [17] = {.lex_state = 74, .external_lex_state = 3},
  [18] = {.lex_state = 74, .external_lex_state = 3},
  [19] = {.lex_state = 74, .external_lex_state = 3},
  [20] = {.lex_state = 74, .external_lex_state = 3},
  [21] = {.lex_state = 74, .external_lex_state = 3},
  [22] = {.lex_state = 74, .external_lex_state = 3},
  [23] = {.lex_state = 74, .external_lex_state = 3},
  [24] = {.lex_state = 74, .external_lex_state = 3},
  [25] = {.lex_state = 74, .external_lex_state = 3},
  [26] = {.lex_state = 74, .external_lex_state = 3},
  [27] = {.lex_state = 74, .external_lex_state = 3},
  [28] = {.lex_state = 74, .external_lex_state = 3},
  [29] = {.lex_state = 74, .external_lex_state = 3},
  [30] = {.lex_state = 74, .external_lex_state = 3},
  [31] = {.lex_state = 74, .external_lex_state = 3},
  [32] = {.lex_state = 74, .external_lex_state = 3},
  [33] = {.lex_state = 74, .external_lex_state = 3},
  [34] = {.lex_state = 74, .external_lex_state = 3},
  [35] = {.lex_state = 74, .external_lex_state = 3},
  [36] = {.lex_state = 74, .external_lex_state = 3},
  [37] = {.lex_state = 74, .external_lex_state = 3},
  [38] = {.lex_state = 74, .external_lex_state = 3},
  [39] = {.lex_state = 74, .external_lex_state = 3},
  [40] = {.lex_state = 74, .external_lex_state = 3},
  [41] = {.lex_state = 74, .external_lex_state = 3},
  [42] = {.lex_state = 74, .external_lex_state = 3},
  [43] = {.lex_state = 74, .external_lex_state = 3},
  [44] = {.lex_state = 74, .external_lex_state = 3},
  [45] = {.lex_state = 74, .external_lex_state = 3},
  [46] = {.lex_state = 74, .external_lex_state = 3},
  [47] = {.lex_state = 74, .external_lex_state = 3},
  [48] = {.lex_state = 74, .external_lex_state = 3},
  [49] = {.lex_state = 74, .external_lex_state = 3},
  [50] = {.lex_state = 74, .external_lex_state = 3},
  [51] = {.lex_state = 74, .external_lex_state = 3},
  [52] = {.lex_state = 74, .external_lex_state = 3},
  [53] = {.lex_state = 74, .external_lex_state = 3},
  [54] = {.lex_state = 74, .external_lex_state = 3},
  [55] = {.lex_state = 74, .external_lex_state = 3},
  [56] = {.lex_state = 74, .external_lex_state = 3},
  [57] = {.lex_state = 74, .external_lex_state = 3},
  [58] = {.lex_state = 74, .external_lex_state = 3},
  [59] = {.lex_state = 74, .external_lex_state = 3},
  [60] = {.lex_state = 74, .external_lex_state = 3},
  [61] = {.lex_state = 74, .external_lex_state = 3},
  [62] = {.lex_state = 74, .external_lex_state = 3},
  [63] = {.lex_state = 74, .external_lex_state = 3},
  [64] = {.lex_state = 74, .external_lex_state = 3},
  [65] = {.lex_state = 74, .external_lex_state = 3},
  [66] = {.lex_state = 74, .external_lex_state = 3},
  [67] = {.lex_state = 74, .external_lex_state = 3},
  [68] = {.lex_state = 74, .external_lex_state = 3},
  [69] = {.lex_state = 74, .external_lex_state = 3},
  [70] = {.lex_state = 74, .external_lex_state = 3},
  [71] = {.lex_state = 74, .external_lex_state = 3},
  [72] = {.lex_state = 74, .external_lex_state = 3},
  [73] = {.lex_state = 74, .external_lex_state = 3},
  [74] = {.lex_state = 74, .external_lex_state = 3},
  [75] = {.lex_state = 74, .external_lex_state = 3},
  [76] = {.lex_state = 74, .external_lex_state = 3},
  [77] = {.lex_state = 74, .external_lex_state = 3},
  [78] = {.lex_state = 74, .external_lex_state = 3},
  [79] = {.lex_state = 74, .external_lex_state = 3},
  [80] = {.lex_state = 74, .external_lex_state = 3},
  [81] = {.lex_state = 74, .external_lex_state = 3},
  [82] = {.lex_state = 74, .external_lex_state = 3},
  [83] = {.lex_state = 74, .external_lex_state = 3},
  [84] = {.lex_state = 74, .external_lex_state = 3},
  [85] = {.lex_state = 74, .external_lex_state = 3},
  [86] = {.lex_state = 74, .external_lex_state = 3},
  [87] = {.lex_state = 74, .external_lex_state = 3},
  [88] = {.lex_state = 74, .external_lex_state = 3},
  [89] = {.lex_state = 74, .external_lex_state = 3},
  [90] = {.lex_state = 74, .external_lex_state = 3},
  [91] = {.lex_state = 74, .external_lex_state = 3},
  [92] = {.lex_state = 74, .external_lex_state = 3},
  [93] = {.lex_state = 74, .external_lex_state = 3},
  [94] = {.lex_state = 74, .external_lex_state = 3},
  [95] = {.lex_state = 74, .external_lex_state = 3},
  [96] = {.lex_state = 74, .external_lex_state = 3},
  [97] = {.lex_state = 74, .external_lex_state = 3},
  [98] = {.lex_state = 74, .external_lex_state = 3},
  [99] = {.lex_state = 74, .external_lex_state = 3},
  [100] = {.lex_state = 74, .external_lex_state = 3},
  [101] = {.lex_state = 74, .external_lex_state = 3},
  [102] = {.lex_state = 74, .external_lex_state = 3},
  [103] = {.lex_state = 74, .external_lex_state = 3},
  [104] = {.lex_state = 74, .external_lex_state = 3},
  [105] = {.lex_state = 74, .external_lex_state = 3},
  [106] = {.lex_state = 74, .external_lex_state = 3},
  [107] = {.lex_state = 74, .external_lex_state = 3},
  [108] = {.lex_state = 74, .external_lex_state = 3},
  [109] = {.lex_state = 74, .external_lex_state = 3},
  [110] = {.lex_state = 74, .external_lex_state = 3},
  [111] = {.lex_state = 74, .external_lex_state = 3},
  [112] = {.lex_state = 74, .external_lex_state = 3},
  [113] = {.lex_state = 74, .external_lex_state = 3},
  [114] = {.lex_state = 74, .external_lex_state = 3},
  [115] = {.lex_state = 74, .external_lex_state = 3},
  [116] = {.lex_state = 74, .external_lex_state = 3},
  [117] = {.lex_state = 74, .external_lex_state = 3},
  [118] = {.lex_state = 74, .external_lex_state = 3},
  [119] = {.lex_state = 74, .external_lex_state = 3},
  [120] = {.lex_state = 74, .external_lex_state = 3},
  [121] = {.lex_state = 74, .external_lex_state = 3},
  [122] = {.lex_state = 74, .external_lex_state = 3},
  [123] = {.lex_state = 74, .external_lex_state = 3},
  [124] = {.lex_state = 74, .external_lex_state = 3},
  [125] = {.lex_state = 74, .external_lex_state = 3},
  [126] = {.lex_state = 74, .external_lex_state = 3},
  [127] = {.lex_state = 74, .external_lex_state = 3},
  [128] = {.lex_state = 74, .external_lex_state = 2},
  [129] = {.lex_state = 74, .external_lex_state = 2},
  [130] = {.lex_state = 74, .external_lex_state = 2},
  [131] = {.lex_state = 74, .external_lex_state = 2},
  [132] = {.lex_state = 74, .external_lex_state = 2},
  [133] = {.lex_state = 74, .external_lex_state = 2},
  [134] = {.lex_state = 74, .external_lex_state = 2},
  [135] = {.lex_state = 74, .external_lex_state = 2},
  [136] = {.lex_state = 74, .external_lex_state = 2},
  [137] = {.lex_state = 74, .external_lex_state = 2},
  [138] = {.lex_state = 74, .external_lex_state = 2},
  [139] = {.lex_state = 74, .external_lex_state = 2},
  [140] = {.lex_state = 74, .external_lex_state = 2},
  [141] = {.lex_state = 74, .external_lex_state = 2},
  [142] = {.lex_state = 74, .external_lex_state = 2},
  [143] = {.lex_state = 74, .external_lex_state = 2},
  [144] = {.lex_state = 74, .external_lex_state = 2},
  [145] = {.lex_state = 74, .external_lex_state = 2},
  [146] = {.lex_state = 74, .external_lex_state = 2},
  [147] = {.lex_state = 74, .external_lex_state = 2},
  [148] = {.lex_state = 74, .external_lex_state = 2},
  [149] = {.lex_state = 74, .external_lex_state = 2},
  [150] = {.lex_state = 74, .external_lex_state = 2},
  [151] = {.lex_state = 74, .external_lex_state = 2},
  [152] = {.lex_state = 74, .external_lex_state = 2},
  [153] = {.lex_state = 74, .external_lex_state = 2},
  [154] = {.lex_state = 74, .external_lex_state = 2},
  [155] = {.lex_state = 74, .external_lex_state = 2},
  [156] = {.lex_state = 74, .external_lex_state = 2},
  [157] = {.lex_state = 74, .external_lex_state = 2},
  [158] = {.lex_state = 74, .external_lex_state = 2},
  [159] = {.lex_state = 74, .external_lex_state = 2},
  [160] = {.lex_state = 74, .external_lex_state = 2},
  [161] = {.lex_state = 74, .external_lex_state = 2},
  [162] = {.lex_state = 74, .external_lex_state = 2},
  [163] = {.lex_state = 74, .external_lex_state = 2},
  [164] = {.lex_state = 74, .external_lex_state = 2},
  [165] = {.lex_state = 74, .external_lex_state = 2},
  [166] = {.lex_state = 74, .external_lex_state = 2},
  [167] = {.lex_state = 74, .external_lex_state = 2},
  [168] = {.lex_state = 74, .external_lex_state = 2},
  [169] = {.lex_state = 74, .external_lex_state = 2},
  [170] = {.lex_state = 74, .external_lex_state = 2},
  [171] = {.lex_state = 74, .external_lex_state = 2},
  [172] = {.lex_state = 74, .external_lex_state = 2},
  [173] = {.lex_state = 74, .external_lex_state = 2},
  [174] = {.lex_state = 74, .external_lex_state = 2},
  [175] = {.lex_state = 74, .external_lex_state = 2},
  [176] = {.lex_state = 74, .external_lex_state = 2},
  [177] = {.lex_state = 74, .external_lex_state = 2},
  [178] = {.lex_state = 74, .external_lex_state = 2},
  [179] = {.lex_state = 74, .external_lex_state = 2},
  [180] = {.lex_state = 74, .external_lex_state = 2},
  [181] = {.lex_state = 74, .external_lex_state = 2},
  [182] = {.lex_state = 74, .external_lex_state = 2},
  [183] = {.lex_state = 74, .external_lex_state = 2},
  [184] = {.lex_state = 74, .external_lex_state = 2},
  [185] = {.lex_state = 74, .external_lex_state = 2},
  [186] = {.lex_state = 74, .external_lex_state = 2},
  [187] = {.lex_state = 74, .external_lex_state = 2},
  [188] = {.lex_state = 74, .external_lex_state = 2},
  [189] = {.lex_state = 74, .external_lex_state = 2},
  [190] = {.lex_state = 74, .external_lex_state = 2},
  [191] = {.lex_state = 74, .external_lex_state = 2},
  [192] = {.lex_state = 74, .external_lex_state = 2},
  [193] = {.lex_state = 74, .external_lex_state = 2},
  [194] = {.lex_state = 74, .external_lex_state = 2},
  [195] = {.lex_state = 74, .external_lex_state = 2},
  [196] = {.lex_state = 74, .external_lex_state = 2},
  [197] = {.lex_state = 74, .external_lex_state = 4},
  [198] = {.lex_state = 74, .external_lex_state = 2},
  [199] = {.lex_state = 74, .external_lex_state = 2},
  [200] = {.lex_state = 74, .external_lex_state = 2},
  [201] = {.lex_state = 74, .external_lex_state = 2},
  [202] = {.lex_state = 74, .external_lex_state = 2},
  [203] = {.lex_state = 74, .external_lex_state = 2},
  [204] = {.lex_state = 74, .external_lex_state = 2},
  [205] = {.lex_state = 74, .external_lex_state = 2},
  [206] = {.lex_state = 74, .external_lex_state = 2},
  [207] = {.lex_state = 74, .external_lex_state = 2},
  [208] = {.lex_state = 74, .external_lex_state = 2},
  [209] = {.lex_state = 74, .external_lex_state = 2},
  [210] = {.lex_state = 74, .external_lex_state = 2},
  [211] = {.lex_state = 74, .external_lex_state = 2},
  [212] = {.lex_state = 74, .external_lex_state = 2},
  [213] = {.lex_state = 74, .external_lex_state = 2},
  [214] = {.lex_state = 74, .external_lex_state = 2},
  [215] = {.lex_state = 74, .external_lex_state = 2},
  [216] = {.lex_state = 74, .external_lex_state = 2},
  [217] = {.lex_state = 74, .external_lex_state = 2},
  [218] = {.lex_state = 74, .external_lex_state = 2},
  [219] = {.lex_state = 74, .external_lex_state = 2},
  [220] = {.lex_state = 74, .external_lex_state = 2},
  [221] = {.lex_state = 74, .external_lex_state = 2},
  [222] = {.lex_state = 74, .external_lex_state = 2},
  [223] = {.lex_state = 74, .external_lex_state = 2},
  [224] = {.lex_state = 74, .external_lex_state = 2},
  [225] = {.lex_state = 74, .external_lex_state = 2},
  [226] = {.lex_state = 74, .external_lex_state = 2},
  [227] = {.lex_state = 74, .external_lex_state = 2},
  [228] = {.lex_state = 74, .external_lex_state = 2},
  [229] = {.lex_state = 74, .external_lex_state = 2},
  [230] = {.lex_state = 74, .external_lex_state = 2},
  [231] = {.lex_state = 74, .external_lex_state = 2},
  [232] = {.lex_state = 74, .external_lex_state = 2},
  [233] = {.lex_state = 74, .external_lex_state = 2},
  [234] = {.lex_state = 74, .external_lex_state = 2},
  [235] = {.lex_state = 74, .external_lex_state = 2},
  [236] = {.lex_state = 74, .external_lex_state = 2},
  [237] = {.lex_state = 74, .external_lex_state = 2},
  [238] = {.lex_state = 74, .external_lex_state = 2},
  [239] = {.lex_state = 74, .external_lex_state = 2},
  [240] = {.lex_state = 74, .external_lex_state = 2},
  [241] = {.lex_state = 74, .external_lex_state = 2},
  [242] = {.lex_state = 74, .external_lex_state = 2},
  [243] = {.lex_state = 74, .external_lex_state = 2},
  [244] = {.lex_state = 74, .external_lex_state = 2},
  [245] = {.lex_state = 74, .external_lex_state = 2},
  [246] = {.lex_state = 74, .external_lex_state = 2},
  [247] = {.lex_state = 74, .external_lex_state = 2},
  [248] = {.lex_state = 74, .external_lex_state = 2},
  [249] = {.lex_state = 74, .external_lex_state = 2},
  [250] = {.lex_state = 74, .external_lex_state = 2},
  [251] = {.lex_state = 74, .external_lex_state = 2},
  [252] = {.lex_state = 74, .external_lex_state = 2},
  [253] = {.lex_state = 74, .external_lex_state = 2},
  [254] = {.lex_state = 74, .external_lex_state = 2},
  [255] = {.lex_state = 74, .external_lex_state = 2},
  [256] = {.lex_state = 74, .external_lex_state = 2},
  [257] = {.lex_state = 74, .external_lex_state = 2},
  [258] = {.lex_state = 74, .external_lex_state = 2},
  [259] = {.lex_state = 74, .external_lex_state = 2},
  [260] = {.lex_state = 74, .external_lex_state = 2},
  [261] = {.lex_state = 74, .external_lex_state = 2},
  [262] = {.lex_state = 74, .external_lex_state = 2},
  [263] = {.lex_state = 74, .external_lex_state = 2},
  [264] = {.lex_state = 74, .external_lex_state = 2},
  [265] = {.lex_state = 74, .external_lex_state = 2},
  [266] = {.lex_state = 74, .external_lex_state = 2},
  [267] = {.lex_state = 74, .external_lex_state = 2},
  [268] = {.lex_state = 74, .external_lex_state = 2},
  [269] = {.lex_state = 74, .external_lex_state = 2},
  [270] = {.lex_state = 74, .external_lex_state = 2},
  [271] = {.lex_state = 74, .external_lex_state = 2},
  [272] = {.lex_state = 74, .external_lex_state = 2},
  [273] = {.lex_state = 74, .external_lex_state = 2},
  [274] = {.lex_state = 74, .external_lex_state = 2},
  [275] = {.lex_state = 74, .external_lex_state = 2},
  [276] = {.lex_state = 74, .external_lex_state = 2},
  [277] = {.lex_state = 74, .external_lex_state = 2},
  [278] = {.lex_state = 74, .external_lex_state = 2},
  [279] = {.lex_state = 74, .external_lex_state = 2},
  [280] = {.lex_state = 74, .external_lex_state = 2},
  [281] = {.lex_state = 74, .external_lex_state = 2},
  [282] = {.lex_state = 74, .external_lex_state = 2},
  [283] = {.lex_state = 74, .external_lex_state = 2},
  [284] = {.lex_state = 74, .external_lex_state = 2},
  [285] = {.lex_state = 74, .external_lex_state = 2},
  [286] = {.lex_state = 74, .external_lex_state = 2},
  [287] = {.lex_state = 74, .external_lex_state = 2},
  [288] = {.lex_state = 74, .external_lex_state = 2},
  [289] = {.lex_state = 74, .external_lex_state = 2},
  [290] = {.lex_state = 74, .external_lex_state = 2},
  [291] = {.lex_state = 74, .external_lex_state = 2},
  [292] = {.lex_state = 74, .external_lex_state = 2},
  [293] = {.lex_state = 74, .external_lex_state = 2},
  [294] = {.lex_state = 74, .external_lex_state = 2},
  [295] = {.lex_state = 74, .external_lex_state = 2},
  [296] = {.lex_state = 74, .external_lex_state = 2},
  [297] = {.lex_state = 74, .external_lex_state = 2},
  [298] = {.lex_state = 74, .external_lex_state = 2},
  [299] = {.lex_state = 74, .external_lex_state = 2},
  [300] = {.lex_state = 74, .external_lex_state = 3},
  [301] = {.lex_state = 74, .external_lex_state = 2},
  [302] = {.lex_state = 74, .external_lex_state = 2},
  [303] = {.lex_state = 74, .external_lex_state = 2},
  [304] = {.lex_state = 74, .external_lex_state = 2},
  [305] = {.lex_state = 74, .external_lex_state = 2},
  [306] = {.lex_state = 74, .external_lex_state = 2},
  [307] = {.lex_state = 74, .external_lex_state = 2},
  [308] = {.lex_state = 74, .external_lex_state = 2},
  [309] = {.lex_state = 74, .external_lex_state = 2},
  [310] = {.lex_state = 74, .external_lex_state = 2},
  [311] = {.lex_state = 74, .external_lex_state = 2},
  [312] = {.lex_state = 74, .external_lex_state = 2},
  [313] = {.lex_state = 74, .external_lex_state = 2},
  [314] = {.lex_state = 74, .external_lex_state = 2},
  [315] = {.lex_state = 74, .external_lex_state = 2},
  [316] = {.lex_state = 74, .external_lex_state = 2},
  [317] = {.lex_state = 74, .external_lex_state = 2},
  [318] = {.lex_state = 74, .external_lex_state = 2},
  [319] = {.lex_state = 74, .external_lex_state = 2},
  [320] = {.lex_state = 74, .external_lex_state = 2},
  [321] = {.lex_state = 74, .external_lex_state = 2},
  [322] = {.lex_state = 74, .external_lex_state = 2},
  [323] = {.lex_state = 74, .external_lex_state = 2},
  [324] = {.lex_state = 74, .external_lex_state = 2},
  [325] = {.lex_state = 74, .external_lex_state = 2},
  [326] = {.lex_state = 74, .external_lex_state = 2},
  [327] = {.lex_state = 74, .external_lex_state = 2},
  [328] = {.lex_state = 74, .external_lex_state = 2},
  [329] = {.lex_state = 74, .external_lex_state = 2},
  [330] = {.lex_state = 74, .external_lex_state = 2},
  [331] = {.lex_state = 74, .external_lex_state = 2},
  [332] = {.lex_state = 74, .external_lex_state = 2},
  [333] = {.lex_state = 74, .external_lex_state = 4},
  [334] = {.lex_state = 74, .external_lex_state = 2},
  [335] = {.lex_state = 74, .external_lex_state = 2},
  [336] = {.lex_state = 74, .external_lex_state = 2},
  [337] = {.lex_state = 74, .external_lex_state = 2},
  [338] = {.lex_state = 74, .external_lex_state = 2},
  [339] = {.lex_state = 74, .external_lex_state = 2},
  [340] = {.lex_state = 74, .external_lex_state = 4},
  [341] = {.lex_state = 74, .external_lex_state = 2},
  [342] = {.lex_state = 74, .external_lex_state = 2},
  [343] = {.lex_state = 74, .external_lex_state = 2},
  [344] = {.lex_state = 74, .external_lex_state = 2},
  [345] = {.lex_state = 74, .external_lex_state = 2},
  [346] = {.lex_state = 74, .external_lex_state = 2},
  [347] = {.lex_state = 74, .external_lex_state = 2},
  [348] = {.lex_state = 74, .external_lex_state = 2},
  [349] = {.lex_state = 74, .external_lex_state = 2},
  [350] = {.lex_state = 74, .external_lex_state = 2},
  [351] = {.lex_state = 74, .external_lex_state = 2},
  [352] = {.lex_state = 74, .external_lex_state = 2},
  [353] = {.lex_state = 74, .external_lex_state = 2},
  [354] = {.lex_state = 74, .external_lex_state = 2},
  [355] = {.lex_state = 74, .external_lex_state = 2},
  [356] = {.lex_state = 74, .external_lex_state = 2},
  [357] = {.lex_state = 74, .external_lex_state = 2},
  [358] = {.lex_state = 74, .external_lex_state = 2},
  [359] = {.lex_state = 74, .external_lex_state = 2},
  [360] = {.lex_state = 74, .external_lex_state = 2},
  [361] = {.lex_state = 74, .external_lex_state = 2},
  [362] = {.lex_state = 74, .external_lex_state = 2},
  [363] = {.lex_state = 74, .external_lex_state = 2},
  [364] = {.lex_state = 74, .external_lex_state = 2},
  [365] = {.lex_state = 74, .external_lex_state = 2},
  [366] = {.lex_state = 74, .external_lex_state = 2},
  [367] = {.lex_state = 74, .external_lex_state = 2},
  [368] = {.lex_state = 74, .external_lex_state = 2},
  [369] = {.lex_state = 74, .external_lex_state = 2},
  [370] = {.lex_state = 74, .external_lex_state = 2},
  [371] = {.lex_state = 74, .external_lex_state = 2},
  [372] = {.lex_state = 74, .external_lex_state = 2},
  [373] = {.lex_state = 74, .external_lex_state = 2},
  [374] = {.lex_state = 74, .external_lex_state = 2},
  [375] = {.lex_state = 74, .external_lex_state = 2},
  [376] = {.lex_state = 74, .external_lex_state = 2},
  [377] = {.lex_state = 74, .external_lex_state = 2},
  [378] = {.lex_state = 74, .external_lex_state = 2},
  [379] = {.lex_state = 74, .external_lex_state = 2},
  [380] = {.lex_state = 74, .external_lex_state = 2},
  [381] = {.lex_state = 74, .external_lex_state = 2},
  [382] = {.lex_state = 74, .external_lex_state = 2},
  [383] = {.lex_state = 74, .external_lex_state = 2},
  [384] = {.lex_state = 74, .external_lex_state = 2},
  [385] = {.lex_state = 74, .external_lex_state = 2},
  [386] = {.lex_state = 74, .external_lex_state = 2},
  [387] = {.lex_state = 74, .external_lex_state = 2},
  [388] = {.lex_state = 74, .external_lex_state = 2},
  [389] = {.lex_state = 74, .external_lex_state = 2},
  [390] = {.lex_state = 74, .external_lex_state = 2},
  [391] = {.lex_state = 74, .external_lex_state = 2},
  [392] = {.lex_state = 74, .external_lex_state = 2},
  [393] = {.lex_state = 74, .external_lex_state = 2},
  [394] = {.lex_state = 74, .external_lex_state = 2},
  [395] = {.lex_state = 74, .external_lex_state = 2},
  [396] = {.lex_state = 74, .external_lex_state = 2},
  [397] = {.lex_state = 74, .external_lex_state = 2},
  [398] = {.lex_state = 74, .external_lex_state = 4},
  [399] = {.lex_state = 74, .external_lex_state = 2},
  [400] = {.lex_state = 74, .external_lex_state = 2},
  [401] = {.lex_state = 74, .external_lex_state = 2},
  [402] = {.lex_state = 74, .external_lex_state = 2},
  [403] = {.lex_state = 74, .external_lex_state = 2},
  [404] = {.lex_state = 74, .external_lex_state = 2},
  [405] = {.lex_state = 74, .external_lex_state = 2},
  [406] = {.lex_state = 74, .external_lex_state = 2},
  [407] = {.lex_state = 74, .external_lex_state = 2},
  [408] = {.lex_state = 74, .external_lex_state = 2},
  [409] = {.lex_state = 74, .external_lex_state = 2},
  [410] = {.lex_state = 74, .external_lex_state = 2},
  [411] = {.lex_state = 74, .external_lex_state = 2},
  [412] = {.lex_state = 74, .external_lex_state = 2},
  [413] = {.lex_state = 74, .external_lex_state = 2},
  [414] = {.lex_state = 74, .external_lex_state = 2},
  [415] = {.lex_state = 74, .external_lex_state = 2},
  [416] = {.lex_state = 74, .external_lex_state = 2},
  [417] = {.lex_state = 74, .external_lex_state = 2},
  [418] = {.lex_state = 74, .external_lex_state = 2},
  [419] = {.lex_state = 74, .external_lex_state = 2},
  [420] = {.lex_state = 74, .external_lex_state = 2},
  [421] = {.lex_state = 74, .external_lex_state = 2},
  [422] = {.lex_state = 74, .external_lex_state = 2},
  [423] = {.lex_state = 74, .external_lex_state = 2},
  [424] = {.lex_state = 74, .external_lex_state = 2},
  [425] = {.lex_state = 74, .external_lex_state = 2},
  [426] = {.lex_state = 74, .external_lex_state = 2},
  [427] = {.lex_state = 74, .external_lex_state = 4},
  [428] = {.lex_state = 74, .external_lex_state = 2},
  [429] = {.lex_state = 74, .external_lex_state = 2},
  [430] = {.lex_state = 74, .external_lex_state = 2},
  [431] = {.lex_state = 74, .external_lex_state = 2},
  [432] = {.lex_state = 74, .external_lex_state = 2},
  [433] = {.lex_state = 74, .external_lex_state = 2},
  [434] = {.lex_state = 74, .external_lex_state = 2},
  [435] = {.lex_state = 74, .external_lex_state = 2},
  [436] = {.lex_state = 74, .external_lex_state = 2},
  [437] = {.lex_state = 74, .external_lex_state = 2},
  [438] = {.lex_state = 74, .external_lex_state = 2},
  [439] = {.lex_state = 74, .external_lex_state = 2},
  [440] = {.lex_state = 74, .external_lex_state = 2},
  [441] = {.lex_state = 74, .external_lex_state = 2},
  [442] = {.lex_state = 74, .external_lex_state = 2},
  [443] = {.lex_state = 74, .external_lex_state = 2},
  [444] = {.lex_state = 74, .external_lex_state = 2},
  [445] = {.lex_state = 74, .external_lex_state = 2},
  [446] = {.lex_state = 74, .external_lex_state = 2},
  [447] = {.lex_state = 74, .external_lex_state = 2},
  [448] = {.lex_state = 74, .external_lex_state = 2},
  [449] = {.lex_state = 74, .external_lex_state = 2},
  [450] = {.lex_state = 74, .external_lex_state = 2},
  [451] = {.lex_state = 74, .external_lex_state = 2},
  [452] = {.lex_state = 74, .external_lex_state = 2},
  [453] = {.lex_state = 74, .external_lex_state = 2},
  [454] = {.lex_state = 74, .external_lex_state = 2},
  [455] = {.lex_state = 74, .external_lex_state = 2},
  [456] = {.lex_state = 74, .external_lex_state = 2},
  [457] = {.lex_state = 74, .external_lex_state = 2},
  [458] = {.lex_state = 74, .external_lex_state = 2},
  [459] = {.lex_state = 74, .external_lex_state = 2},
  [460] = {.lex_state = 74, .external_lex_state = 2},
  [461] = {.lex_state = 74, .external_lex_state = 2},
  [462] = {.lex_state = 74, .external_lex_state = 2},
  [463] = {.lex_state = 74, .external_lex_state = 2},
  [464] = {.lex_state = 74, .external_lex_state = 2},
  [465] = {.lex_state = 74, .external_lex_state = 2},
  [466] = {.lex_state = 74, .external_lex_state = 2},
  [467] = {.lex_state = 74, .external_lex_state = 2},
  [468] = {.lex_state = 74, .external_lex_state = 2},
  [469] = {.lex_state = 74, .external_lex_state = 2},
  [470] = {.lex_state = 74, .external_lex_state = 2},
  [471] = {.lex_state = 74, .external_lex_state = 2},
  [472] = {.lex_state = 74, .external_lex_state = 2},
  [473] = {.lex_state = 74, .external_lex_state = 2},
  [474] = {.lex_state = 74, .external_lex_state = 4},
  [475] = {.lex_state = 74, .external_lex_state = 2},
  [476] = {.lex_state = 74, .external_lex_state = 2},
  [477] = {.lex_state = 74, .external_lex_state = 2},
  [478] = {.lex_state = 74, .external_lex_state = 2},
  [479] = {.lex_state = 74, .external_lex_state = 2},
  [480] = {.lex_state = 74, .external_lex_state = 2},
  [481] = {.lex_state = 74, .external_lex_state = 2},
  [482] = {.lex_state = 74, .external_lex_state = 2},
  [483] = {.lex_state = 74, .external_lex_state = 2},
  [484] = {.lex_state = 74, .external_lex_state = 2},
  [485] = {.lex_state = 74, .external_lex_state = 2},
  [486] = {.lex_state = 74, .external_lex_state = 2},
  [487] = {.lex_state = 74, .external_lex_state = 2},
  [488] = {.lex_state = 74, .external_lex_state = 2},
  [489] = {.lex_state = 74, .external_lex_state = 2},
  [490] = {.lex_state = 74, .external_lex_state = 2},
  [491] = {.lex_state = 74, .external_lex_state = 2},
  [492] = {.lex_state = 74, .external_lex_state = 2},
  [493] = {.lex_state = 74, .external_lex_state = 2},
  [494] = {.lex_state = 74, .external_lex_state = 2},
  [495] = {.lex_state = 74, .external_lex_state = 2},
  [496] = {.lex_state = 74, .external_lex_state = 2},
  [497] = {.lex_state = 74, .external_lex_state = 2},
  [498] = {.lex_state = 74, .external_lex_state = 2},
  [499] = {.lex_state = 74, .external_lex_state = 2},
  [500] = {.lex_state = 74, .external_lex_state = 2},
  [501] = {.lex_state = 74, .external_lex_state = 2},
  [502] = {.lex_state = 74, .external_lex_state = 2},
  [503] = {.lex_state = 74, .external_lex_state = 2},
  [504] = {.lex_state = 74, .external_lex_state = 2},
  [505] = {.lex_state = 74, .external_lex_state = 2},
  [506] = {.lex_state = 74, .external_lex_state = 2},
  [507] = {.lex_state = 74, .external_lex_state = 2},
  [508] = {.lex_state = 74, .external_lex_state = 2},
  [509] = {.lex_state = 74, .external_lex_state = 2},
  [510] = {.lex_state = 74, .external_lex_state = 2},
  [511] = {.lex_state = 74, .external_lex_state = 2},
  [512] = {.lex_state = 74, .external_lex_state = 2},
  [513] = {.lex_state = 74, .external_lex_state = 2},
  [514] = {.lex_state = 74, .external_lex_state = 2},
  [515] = {.lex_state = 74, .external_lex_state = 2},
  [516] = {.lex_state = 74, .external_lex_state = 2},
  [517] = {.lex_state = 74, .external_lex_state = 2},
  [518] = {.lex_state = 74, .external_lex_state = 2},
  [519] = {.lex_state = 74, .external_lex_state = 4},
  [520] = {.lex_state = 74, .external_lex_state = 2},
  [521] = {.lex_state = 74, .external_lex_state = 2},
  [522] = {.lex_state = 74, .external_lex_state = 2},
  [523] = {.lex_state = 74, .external_lex_state = 2},
  [524] = {.lex_state = 74, .external_lex_state = 2},
  [525] = {.lex_state = 74, .external_lex_state = 2},
  [526] = {.lex_state = 74, .external_lex_state = 2},
  [527] = {.lex_state = 74, .external_lex_state = 2},
  [528] = {.lex_state = 74, .external_lex_state = 2},
  [529] = {.lex_state = 74, .external_lex_state = 2},
  [530] = {.lex_state = 74, .external_lex_state = 2},
  [531] = {.lex_state = 74, .external_lex_state = 2},
  [532] = {.lex_state = 74, .external_lex_state = 2},
  [533] = {.lex_state = 74, .external_lex_state = 2},
  [534] = {.lex_state = 74, .external_lex_state = 2},
  [535] = {.lex_state = 74, .external_lex_state = 2},
  [536] = {.lex_state = 74, .external_lex_state = 2},
  [537] = {.lex_state = 74, .external_lex_state = 2},
  [538] = {.lex_state = 74, .external_lex_state = 2},
  [539] = {.lex_state = 74, .external_lex_state = 2},
  [540] = {.lex_state = 74, .external_lex_state = 2},
  [541] = {.lex_state = 74, .external_lex_state = 2},
  [542] = {.lex_state = 74, .external_lex_state = 2},
  [543] = {.lex_state = 74, .external_lex_state = 2},
  [544] = {.lex_state = 74, .external_lex_state = 2},
  [545] = {.lex_state = 74, .external_lex_state = 2},
  [546] = {.lex_state = 74, .external_lex_state = 2},
  [547] = {.lex_state = 74, .external_lex_state = 2},
  [548] = {.lex_state = 74, .external_lex_state = 2},
  [549] = {.lex_state = 74, .external_lex_state = 2},
  [550] = {.lex_state = 74, .external_lex_state = 2},
  [551] = {.lex_state = 74, .external_lex_state = 2},
  [552] = {.lex_state = 74, .external_lex_state = 2},
  [553] = {.lex_state = 74, .external_lex_state = 2},
  [554] = {.lex_state = 74, .external_lex_state = 2},
  [555] = {.lex_state = 74, .external_lex_state = 2},
  [556] = {.lex_state = 74, .external_lex_state = 2},
  [557] = {.lex_state = 74, .external_lex_state = 2},
  [558] = {.lex_state = 74, .external_lex_state = 2},
  [559] = {.lex_state = 74, .external_lex_state = 2},
  [560] = {.lex_state = 74, .external_lex_state = 4},
  [561] = {.lex_state = 74, .external_lex_state = 2},
  [562] = {.lex_state = 74, .external_lex_state = 2},
  [563] = {.lex_state = 74, .external_lex_state = 2},
  [564] = {.lex_state = 74, .external_lex_state = 2},
  [565] = {.lex_state = 74, .external_lex_state = 4},
  [566] = {.lex_state = 74, .external_lex_state = 2},
  [567] = {.lex_state = 74, .external_lex_state = 2},
  [568] = {.lex_state = 74, .external_lex_state = 2},
  [569] = {.lex_state = 74, .external_lex_state = 2},
  [570] = {.lex_state = 74, .external_lex_state = 2},
  [571] = {.lex_state = 74, .external_lex_state = 5},
  [572] = {.lex_state = 74, .external_lex_state = 3},
  [573] = {.lex_state = 74, .external_lex_state = 3},
  [574] = {.lex_state = 73, .external_lex_state = 2},
  [575] = {.lex_state = 73, .external_lex_state = 2},
  [576] = {.lex_state = 73, .external_lex_state = 2},
  [577] = {.lex_state = 73, .external_lex_state = 2},
  [578] = {.lex_state = 73, .external_lex_state = 2},
  [579] = {.lex_state = 72, .external_lex_state = 6},
  [580] = {.lex_state = 72, .external_lex_state = 7},
  [581] = {.lex_state = 72, .external_lex_state = 8},
  [582] = {.lex_state = 72, .external_lex_state = 9},
  [583] = {.lex_state = 72, .external_lex_state = 10},
  [584] = {.lex_state = 72, .external_lex_state = 11},
  [585] = {.lex_state = 72, .external_lex_state = 12},
  [586] = {.lex_state = 72, .external_lex_state = 13},
  [587] = {.lex_state = 73, .external_lex_state = 12},
  [588] = {.lex_state = 72, .external_lex_state = 14},
  [589] = {.lex_state = 73, .external_lex_state = 11},
  [590] = {.lex_state = 72, .external_lex_state = 6},
  [591] = {.lex_state = 73, .external_lex_state = 6},
  [592] = {.lex_state = 72, .external_lex_state = 15},
  [593] = {.lex_state = 73, .external_lex_state = 6},
  [594] = {.lex_state = 73, .external_lex_state = 8},
  [595] = {.lex_state = 73, .external_lex_state = 14},
  [596] = {.lex_state = 72, .external_lex_state = 16},
  [597] = {.lex_state = 73, .external_lex_state = 7},
  [598] = {.lex_state = 73, .external_lex_state = 6},
  [599] = {.lex_state = 73, .external_lex_state = 6},
  [600] = {.lex_state = 72, .external_lex_state = 7},
  [601] = {.lex_state = 73, .external_lex_state = 13},
  [602] = {.lex_state = 72, .external_lex_state = 17},
  [603] = {.lex_state = 73, .external_lex_state = 7},
  [604] = {.lex_state = 73, .external_lex_state = 15},
  [605] = {.lex_state = 72, .external_lex_state = 8},
  [606] = {.lex_state = 72, .external_lex_state = 18},
  [607] = {.lex_state = 73, .external_lex_state = 12},
  [608] = {.lex_state = 72, .external_lex_state = 19},
  [609] = {.lex_state = 73, .external_lex_state = 8},
  [610] = {.lex_state = 72, .external_lex_state = 20},
  [611] = {.lex_state = 73, .external_lex_state = 17},
  [612] = {.lex_state = 73, .external_lex_state = 15},
  [613] = {.lex_state = 72, .external_lex_state = 10},
  [614] = {.lex_state = 73, .external_lex_state = 7},
  [615] = {.lex_state = 73, .external_lex_state = 9},
  [616] = {.lex_state = 73, .external_lex_state = 20},
  [617] = {.lex_state = 73, .external_lex_state = 16},
  [618] = {.lex_state = 73, .external_lex_state = 10},
  [619] = {.lex_state = 73, .external_lex_state = 9},
  [620] = {.lex_state = 73, .external_lex_state = 8},
  [621] = {.lex_state = 72, .external_lex_state = 19},
  [622] = {.lex_state = 72, .external_lex_state = 21},
  [623] = {.lex_state = 73, .external_lex_state = 8},
  [624] = {.lex_state = 73, .external_lex_state = 10},
  [625] = {.lex_state = 73, .external_lex_state = 7},
  [626] = {.lex_state = 72, .external_lex_state = 22},
  [627] = {.lex_state = 73, .external_lex_state = 14},
  [628] = {.lex_state = 72, .external_lex_state = 9},
  [629] = {.lex_state = 73, .external_lex_state = 18},
  [630] = {.lex_state = 73, .external_lex_state = 21},
  [631] = {.lex_state = 73, .external_lex_state = 3},
  [632] = {.lex_state = 73, .external_lex_state = 3},
  [633] = {.lex_state = 73, .external_lex_state = 3},
  [634] = {.lex_state = 73, .external_lex_state = 3},
  [635] = {.lex_state = 73, .external_lex_state = 11},
  [636] = {.lex_state = 73, .external_lex_state = 3},
  [637] = {.lex_state = 73, .external_lex_state = 20},
  [638] = {.lex_state = 73, .external_lex_state = 3},
  [639] = {.lex_state = 73, .external_lex_state = 10},
  [640] = {.lex_state = 73, .external_lex_state = 3},
  [641] = {.lex_state = 73, .external_lex_state = 3},
  [642] = {.lex_state = 73, .external_lex_state = 3},
  [643] = {.lex_state = 73, .external_lex_state = 3},
  [644] = {.lex_state = 73, .external_lex_state = 3},
  [645] = {.lex_state = 72, .external_lex_state = 19},
  [646] = {.lex_state = 72, .external_lex_state = 22},
  [647] = {.lex_state = 73, .external_lex_state = 3},
  [648] = {.lex_state = 73, .external_lex_state = 3},
  [649] = {.lex_state = 73, .external_lex_state = 3},
  [650] = {.lex_state = 73, .external_lex_state = 19},
  [651] = {.lex_state = 73, .external_lex_state = 9},
  [652] = {.lex_state = 73, .external_lex_state = 18},
  [653] = {.lex_state = 73, .external_lex_state = 10},
  [654] = {.lex_state = 73, .external_lex_state = 19},
  [655] = {.lex_state = 73, .external_lex_state = 3},
  [656] = {.lex_state = 73, .external_lex_state = 3},
  [657] = {.lex_state = 73, .external_lex_state = 3},
  [658] = {.lex_state = 73, .external_lex_state = 3},
  [659] = {.lex_state = 73, .external_lex_state = 3},
  [660] = {.lex_state = 73, .external_lex_state = 3},
  [661] = {.lex_state = 73, .external_lex_state = 3},
  [662] = {.lex_state = 73, .external_lex_state = 3},
  [663] = {.lex_state = 73, .external_lex_state = 3},
  [664] = {.lex_state = 73, .external_lex_state = 3},
  [665] = {.lex_state = 73, .external_lex_state = 3},
  [666] = {.lex_state = 73, .external_lex_state = 3},
  [667] = {.lex_state = 73, .external_lex_state = 3},
  [668] = {.lex_state = 73, .external_lex_state = 3},
  [669] = {.lex_state = 73, .external_lex_state = 11},
  [670] = {.lex_state = 73, .external_lex_state = 3},
  [671] = {.lex_state = 73, .external_lex_state = 3},
  [672] = {.lex_state = 73, .external_lex_state = 22},
  [673] = {.lex_state = 73, .external_lex_state = 3},
  [674] = {.lex_state = 73, .external_lex_state = 3},
  [675] = {.lex_state = 72, .external_lex_state = 2},
  [676] = {.lex_state = 73, .external_lex_state = 3},
  [677] = {.lex_state = 73, .external_lex_state = 3},
  [678] = {.lex_state = 73, .external_lex_state = 9},
  [679] = {.lex_state = 73, .external_lex_state = 3},
  [680] = {.lex_state = 73, .external_lex_state = 3},
  [681] = {.lex_state = 73, .external_lex_state = 3},
  [682] = {.lex_state = 73, .external_lex_state = 19},
  [683] = {.lex_state = 73, .external_lex_state = 3},
  [684] = {.lex_state = 2, .external_lex_state = 2},
  [685] = {.lex_state = 73, .external_lex_state = 3},
  [686] = {.lex_state = 73, .external_lex_state = 3},
  [687] = {.lex_state = 2, .external_lex_state = 2},
  [688] = {.lex_state = 73, .external_lex_state = 3},
  [689] = {.lex_state = 73, .external_lex_state = 3},
  [690] = {.lex_state = 2, .external_lex_state = 2},
  [691] = {.lex_state = 2, .external_lex_state = 2},
  [692] = {.lex_state = 2, .external_lex_state = 2},
  [693] = {.lex_state = 73, .external_lex_state = 3},
  [694] = {.lex_state = 73, .external_lex_state = 3},
  [695] = {.lex_state = 73, .external_lex_state = 3},
  [696] = {.lex_state = 73, .external_lex_state = 3},
  [697] = {.lex_state = 2, .external_lex_state = 2},
  [698] = {.lex_state = 73, .external_lex_state = 3},
  [699] = {.lex_state = 73, .external_lex_state = 3},
  [700] = {.lex_state = 73, .external_lex_state = 3},
  [701] = {.lex_state = 73, .external_lex_state = 3},
  [702] = {.lex_state = 73, .external_lex_state = 3},
  [703] = {.lex_state = 2, .external_lex_state = 2},
  [704] = {.lex_state = 73, .external_lex_state = 3},
  [705] = {.lex_state = 73, .external_lex_state = 19},
  [706] = {.lex_state = 73, .external_lex_state = 3},
  [707] = {.lex_state = 2, .external_lex_state = 2},
  [708] = {.lex_state = 73, .external_lex_state = 3},
  [709] = {.lex_state = 2, .external_lex_state = 2},
  [710] = {.lex_state = 2, .external_lex_state = 2},
  [711] = {.lex_state = 73, .external_lex_state = 2},
  [712] = {.lex_state = 2, .external_lex_state = 2},
  [713] = {.lex_state = 2, .external_lex_state = 2},
  [714] = {.lex_state = 2, .external_lex_state = 2},
  [715] = {.lex_state = 2, .external_lex_state = 2},
  [716] = {.lex_state = 73, .external_lex_state = 13},
  [717] = {.lex_state = 73, .external_lex_state = 3},
  [718] = {.lex_state = 73, .external_lex_state = 3},
  [719] = {.lex_state = 2, .external_lex_state = 2},
  [720] = {.lex_state = 2, .external_lex_state = 2},
  [721] = {.lex_state = 73, .external_lex_state = 3},
  [722] = {.lex_state = 73, .external_lex_state = 3},
  [723] = {.lex_state = 2, .external_lex_state = 2},
  [724] = {.lex_state = 73, .external_lex_state = 3},
  [725] = {.lex_state = 73, .external_lex_state = 3},
  [726] = {.lex_state = 2, .external_lex_state = 2},
  [727] = {.lex_state = 73, .external_lex_state = 19},
  [728] = {.lex_state = 73, .external_lex_state = 22},
  [729] = {.lex_state = 73, .external_lex_state = 3},
  [730] = {.lex_state = 73, .external_lex_state = 3},
  [731] = {.lex_state = 73, .external_lex_state = 3},
  [732] = {.lex_state = 73, .external_lex_state = 3},
  [733] = {.lex_state = 2, .external_lex_state = 2},
  [734] = {.lex_state = 73, .external_lex_state = 3},
  [735] = {.lex_state = 2, .external_lex_state = 2},
  [736] = {.lex_state = 73, .external_lex_state = 3},
  [737] = {.lex_state = 73, .external_lex_state = 3},
  [738] = {.lex_state = 73, .external_lex_state = 3},
  [739] = {.lex_state = 73, .external_lex_state = 3},
  [740] = {.lex_state = 73, .external_lex_state = 3},
  [741] = {.lex_state = 73, .external_lex_state = 3},
  [742] = {.lex_state = 2, .external_lex_state = 2},
  [743] = {.lex_state = 2, .external_lex_state = 2},
  [744] = {.lex_state = 2, .external_lex_state = 2},
  [745] = {.lex_state = 73, .external_lex_state = 3},
  [746] = {.lex_state = 2, .external_lex_state = 2},
  [747] = {.lex_state = 73, .external_lex_state = 3},
  [748] = {.lex_state = 2, .external_lex_state = 2},
  [749] = {.lex_state = 2, .external_lex_state = 2},
  [750] = {.lex_state = 73, .external_lex_state = 3},
  [751] = {.lex_state = 73, .external_lex_state = 3},
  [752] = {.lex_state = 73, .external_lex_state = 3},
  [753] = {.lex_state = 73, .external_lex_state = 3},
  [754] = {.lex_state = 2, .external_lex_state = 2},
  [755] = {.lex_state = 73, .external_lex_state = 3},
  [756] = {.lex_state = 73, .external_lex_state = 3},
  [757] = {.lex_state = 73, .external_lex_state = 3},
  [758] = {.lex_state = 73, .external_lex_state = 3},
  [759] = {.lex_state = 73, .external_lex_state = 3},
  [760] = {.lex_state = 2, .external_lex_state = 2},
  [761] = {.lex_state = 73, .external_lex_state = 3},
  [762] = {.lex_state = 2, .external_lex_state = 2},
  [763] = {.lex_state = 73, .external_lex_state = 3},
  [764] = {.lex_state = 2, .external_lex_state = 2},
  [765] = {.lex_state = 73, .external_lex_state = 3},
  [766] = {.lex_state = 2, .external_lex_state = 2},
  [767] = {.lex_state = 73, .external_lex_state = 3},
  [768] = {.lex_state = 73, .external_lex_state = 3},
  [769] = {.lex_state = 73, .external_lex_state = 3},
  [770] = {.lex_state = 73, .external_lex_state = 3},
  [771] = {.lex_state = 73, .external_lex_state = 3},
  [772] = {.lex_state = 73, .external_lex_state = 3},
  [773] = {.lex_state = 73, .external_lex_state = 3},
  [774] = {.lex_state = 2, .external_lex_state = 2},
  [775] = {.lex_state = 2, .external_lex_state = 2},
  [776] = {.lex_state = 73, .external_lex_state = 3},
  [777] = {.lex_state = 2, .external_lex_state = 2},
  [778] = {.lex_state = 73, .external_lex_state = 3},
  [779] = {.lex_state = 2, .external_lex_state = 2},
  [780] = {.lex_state = 2, .external_lex_state = 2},
  [781] = {.lex_state = 73, .external_lex_state = 3},
  [782] = {.lex_state = 73, .external_lex_state = 3},
  [783] = {.lex_state = 73, .external_lex_state = 3},
  [784] = {.lex_state = 2, .external_lex_state = 2},
  [785] = {.lex_state = 73, .external_lex_state = 3},
  [786] = {.lex_state = 2, .external_lex_state = 2},
  [787] = {.lex_state = 73, .external_lex_state = 3},
  [788] = {.lex_state = 73, .external_lex_state = 3},
  [789] = {.lex_state = 73, .external_lex_state = 3},
  [790] = {.lex_state = 73, .external_lex_state = 3},
  [791] = {.lex_state = 73, .external_lex_state = 13},
  [792] = {.lex_state = 73, .external_lex_state = 3},
  [793] = {.lex_state = 2, .external_lex_state = 2},
  [794] = {.lex_state = 73, .external_lex_state = 3},
  [795] = {.lex_state = 73, .external_lex_state = 3},
  [796] = {.lex_state = 2, .external_lex_state = 2},
  [797] = {.lex_state = 73, .external_lex_state = 3},
  [798] = {.lex_state = 2, .external_lex_state = 2},
  [799] = {.lex_state = 73, .external_lex_state = 3},
  [800] = {.lex_state = 73, .external_lex_state = 3},
  [801] = {.lex_state = 73, .external_lex_state = 3},
  [802] = {.lex_state = 2, .external_lex_state = 2},
  [803] = {.lex_state = 73, .external_lex_state = 3},
  [804] = {.lex_state = 73, .external_lex_state = 3},
  [805] = {.lex_state = 73, .external_lex_state = 3},
  [806] = {.lex_state = 73, .external_lex_state = 3},
  [807] = {.lex_state = 73, .external_lex_state = 3},
  [808] = {.lex_state = 73, .external_lex_state = 3},
  [809] = {.lex_state = 73, .external_lex_state = 3},
  [810] = {.lex_state = 2, .external_lex_state = 2},
  [811] = {.lex_state = 73, .external_lex_state = 3},
  [812] = {.lex_state = 2, .external_lex_state = 2},
  [813] = {.lex_state = 2, .external_lex_state = 2},
  [814] = {.lex_state = 73, .external_lex_state = 3},
  [815] = {.lex_state = 73, .external_lex_state = 3},
  [816] = {.lex_state = 73, .external_lex_state = 3},
  [817] = {.lex_state = 2, .external_lex_state = 2},
  [818] = {.lex_state = 73, .external_lex_state = 3},
  [819] = {.lex_state = 73, .external_lex_state = 3},
  [820] = {.lex_state = 73, .external_lex_state = 3},
  [821] = {.lex_state = 73, .external_lex_state = 3},
  [822] = {.lex_state = 2, .external_lex_state = 2},
  [823] = {.lex_state = 73, .external_lex_state = 3},
  [824] = {.lex_state = 2, .external_lex_state = 2},
  [825] = {.lex_state = 73, .external_lex_state = 3},
  [826] = {.lex_state = 2, .external_lex_state = 2},
  [827] = {.lex_state = 2, .external_lex_state = 2},
  [828] = {.lex_state = 73, .external_lex_state = 3},
  [829] = {.lex_state = 73, .external_lex_state = 3},
  [830] = {.lex_state = 73, .external_lex_state = 3},
  [831] = {.lex_state = 73, .external_lex_state = 3},
  [832] = {.lex_state = 73, .external_lex_state = 22},
  [833] = {.lex_state = 73, .external_lex_state = 3},
  [834] = {.lex_state = 73, .external_lex_state = 3},
  [835] = {.lex_state = 73, .external_lex_state = 3},
  [836] = {.lex_state = 73, .external_lex_state = 3},
  [837] = {.lex_state = 73, .external_lex_state = 3},
  [838] = {.lex_state = 2, .external_lex_state = 2},
  [839] = {.lex_state = 73, .external_lex_state = 3},
  [840] = {.lex_state = 73, .external_lex_state = 3},
  [841] = {.lex_state = 2, .external_lex_state = 2},
  [842] = {.lex_state = 2, .external_lex_state = 2},
  [843] = {.lex_state = 73, .external_lex_state = 3},
  [844] = {.lex_state = 73, .external_lex_state = 3},
  [845] = {.lex_state = 2, .external_lex_state = 2},
  [846] = {.lex_state = 2, .external_lex_state = 2},
  [847] = {.lex_state = 73, .external_lex_state = 3},
  [848] = {.lex_state = 73, .external_lex_state = 3},
  [849] = {.lex_state = 73, .external_lex_state = 3},
  [850] = {.lex_state = 73, .external_lex_state = 3},
  [851] = {.lex_state = 73, .external_lex_state = 3},
  [852] = {.lex_state = 73, .external_lex_state = 3},
  [853] = {.lex_state = 2, .external_lex_state = 2},
  [854] = {.lex_state = 73, .external_lex_state = 3},
  [855] = {.lex_state = 73, .external_lex_state = 3},
  [856] = {.lex_state = 73, .external_lex_state = 3},
  [857] = {.lex_state = 73, .external_lex_state = 3},
  [858] = {.lex_state = 73, .external_lex_state = 3},
  [859] = {.lex_state = 73, .external_lex_state = 3},
  [860] = {.lex_state = 73, .external_lex_state = 3},
  [861] = {.lex_state = 73, .external_lex_state = 3},
  [862] = {.lex_state = 73, .external_lex_state = 3},
  [863] = {.lex_state = 73, .external_lex_state = 3},
  [864] = {.lex_state = 73, .external_lex_state = 3},
  [865] = {.lex_state = 73, .external_lex_state = 3},
  [866] = {.lex_state = 73, .external_lex_state = 3},
  [867] = {.lex_state = 73, .external_lex_state = 3},
  [868] = {.lex_state = 73, .external_lex_state = 3},
  [869] = {.lex_state = 73, .external_lex_state = 3},
  [870] = {.lex_state = 73, .external_lex_state = 3},
  [871] = {.lex_state = 73, .external_lex_state = 3},
  [872] = {.lex_state = 73, .external_lex_state = 3},
  [873] = {.lex_state = 73, .external_lex_state = 3},
  [874] = {.lex_state = 73, .external_lex_state = 3},
  [875] = {.lex_state = 73, .external_lex_state = 3},
  [876] = {.lex_state = 73, .external_lex_state = 3},
  [877] = {.lex_state = 73, .external_lex_state = 3},
  [878] = {.lex_state = 73, .external_lex_state = 3},
  [879] = {.lex_state = 73, .external_lex_state = 3},
  [880] = {.lex_state = 73, .external_lex_state = 3},
  [881] = {.lex_state = 73, .external_lex_state = 3},
  [882] = {.lex_state = 73, .external_lex_state = 3},
  [883] = {.lex_state = 73, .external_lex_state = 3},
  [884] = {.lex_state = 73, .external_lex_state = 3},
  [885] = {.lex_state = 73, .external_lex_state = 3},
  [886] = {.lex_state = 73, .external_lex_state = 3},
  [887] = {.lex_state = 73, .external_lex_state = 3},
  [888] = {.lex_state = 73, .external_lex_state = 3},
  [889] = {.lex_state = 73, .external_lex_state = 3},
  [890] = {.lex_state = 73, .external_lex_state = 3},
  [891] = {.lex_state = 73, .external_lex_state = 3},
  [892] = {.lex_state = 73, .external_lex_state = 3},
  [893] = {.lex_state = 73, .external_lex_state = 3},
  [894] = {.lex_state = 73, .external_lex_state = 3},
  [895] = {.lex_state = 73, .external_lex_state = 3},
  [896] = {.lex_state = 73, .external_lex_state = 3},
  [897] = {.lex_state = 73, .external_lex_state = 3},
  [898] = {.lex_state = 73, .external_lex_state = 3},
  [899] = {.lex_state = 73, .external_lex_state = 3},
  [900] = {.lex_state = 73, .external_lex_state = 3},
  [901] = {.lex_state = 73, .external_lex_state = 3},
  [902] = {.lex_state = 73, .external_lex_state = 3},
  [903] = {.lex_state = 73, .external_lex_state = 3},
  [904] = {.lex_state = 73, .external_lex_state = 3},
  [905] = {.lex_state = 73, .external_lex_state = 3},
  [906] = {.lex_state = 73, .external_lex_state = 3},
  [907] = {.lex_state = 73, .external_lex_state = 3},
  [908] = {.lex_state = 73, .external_lex_state = 3},
  [909] = {.lex_state = 73, .external_lex_state = 3},
  [910] = {.lex_state = 73, .external_lex_state = 3},
  [911] = {.lex_state = 73, .external_lex_state = 3},
  [912] = {.lex_state = 73, .external_lex_state = 3},
  [913] = {.lex_state = 73, .external_lex_state = 3},
  [914] = {.lex_state = 73, .external_lex_state = 3},
  [915] = {.lex_state = 73, .external_lex_state = 3},
  [916] = {.lex_state = 73, .external_lex_state = 3},
  [917] = {.lex_state = 73, .external_lex_state = 3},
  [918] = {.lex_state = 73, .external_lex_state = 3},
  [919] = {.lex_state = 73, .external_lex_state = 3},
  [920] = {.lex_state = 73, .external_lex_state = 3},
  [921] = {.lex_state = 73, .external_lex_state = 3},
  [922] = {.lex_state = 73, .external_lex_state = 3},
  [923] = {.lex_state = 73, .external_lex_state = 3},
  [924] = {.lex_state = 73, .external_lex_state = 3},
  [925] = {.lex_state = 73, .external_lex_state = 3},
  [926] = {.lex_state = 73, .external_lex_state = 3},
  [927] = {.lex_state = 73, .external_lex_state = 3},
  [928] = {.lex_state = 73, .external_lex_state = 3},
  [929] = {.lex_state = 73, .external_lex_state = 3},
  [930] = {.lex_state = 73, .external_lex_state = 3},
  [931] = {.lex_state = 73, .external_lex_state = 3},
  [932] = {.lex_state = 73, .external_lex_state = 3},
  [933] = {.lex_state = 73, .external_lex_state = 3},
  [934] = {.lex_state = 73, .external_lex_state = 3},
  [935] = {.lex_state = 73, .external_lex_state = 3},
  [936] = {.lex_state = 73, .external_lex_state = 3},
  [937] = {.lex_state = 73, .external_lex_state = 3},
  [938] = {.lex_state = 73, .external_lex_state = 3},
  [939] = {.lex_state = 73, .external_lex_state = 3},
  [940] = {.lex_state = 73, .external_lex_state = 3},
  [941] = {.lex_state = 73, .external_lex_state = 3},
  [942] = {.lex_state = 73, .external_lex_state = 3},
  [943] = {.lex_state = 73, .external_lex_state = 3},
  [944] = {.lex_state = 73, .external_lex_state = 3},
  [945] = {.lex_state = 73, .external_lex_state = 3},
  [946] = {.lex_state = 73, .external_lex_state = 3},
  [947] = {.lex_state = 73, .external_lex_state = 3},
  [948] = {.lex_state = 73, .external_lex_state = 3},
  [949] = {.lex_state = 73, .external_lex_state = 3},
  [950] = {.lex_state = 73, .external_lex_state = 3},
  [951] = {.lex_state = 73, .external_lex_state = 3},
  [952] = {.lex_state = 73, .external_lex_state = 3},
  [953] = {.lex_state = 73, .external_lex_state = 3},
  [954] = {.lex_state = 73, .external_lex_state = 3},
  [955] = {.lex_state = 73, .external_lex_state = 3},
  [956] = {.lex_state = 73, .external_lex_state = 3},
  [957] = {.lex_state = 73, .external_lex_state = 3},
  [958] = {.lex_state = 73, .external_lex_state = 3},
  [959] = {.lex_state = 73, .external_lex_state = 3},
  [960] = {.lex_state = 73, .external_lex_state = 3},
  [961] = {.lex_state = 73, .external_lex_state = 3},
  [962] = {.lex_state = 73, .external_lex_state = 3},
  [963] = {.lex_state = 73, .external_lex_state = 3},
  [964] = {.lex_state = 73, .external_lex_state = 3},
  [965] = {.lex_state = 73, .external_lex_state = 3},
  [966] = {.lex_state = 73, .external_lex_state = 3},
  [967] = {.lex_state = 73, .external_lex_state = 3},
  [968] = {.lex_state = 73, .external_lex_state = 3},
  [969] = {.lex_state = 73, .external_lex_state = 3},
  [970] = {.lex_state = 73, .external_lex_state = 3},
  [971] = {.lex_state = 73, .external_lex_state = 3},
  [972] = {.lex_state = 73, .external_lex_state = 3},
  [973] = {.lex_state = 73, .external_lex_state = 3},
  [974] = {.lex_state = 73, .external_lex_state = 3},
  [975] = {.lex_state = 73, .external_lex_state = 3},
  [976] = {.lex_state = 73, .external_lex_state = 3},
  [977] = {.lex_state = 73, .external_lex_state = 3},
  [978] = {.lex_state = 73, .external_lex_state = 17},
  [979] = {.lex_state = 73, .external_lex_state = 3},
  [980] = {.lex_state = 73, .external_lex_state = 3},
  [981] = {.lex_state = 73, .external_lex_state = 3},
  [982] = {.lex_state = 73, .external_lex_state = 3},
  [983] = {.lex_state = 73, .external_lex_state = 3},
  [984] = {.lex_state = 73, .external_lex_state = 3},
  [985] = {.lex_state = 73, .external_lex_state = 3},
  [986] = {.lex_state = 73, .external_lex_state = 3},
  [987] = {.lex_state = 73, .external_lex_state = 3},
  [988] = {.lex_state = 73, .external_lex_state = 3},
  [989] = {.lex_state = 73, .external_lex_state = 3},
  [990] = {.lex_state = 73, .external_lex_state = 3},
  [991] = {.lex_state = 73, .external_lex_state = 3},
  [992] = {.lex_state = 73, .external_lex_state = 3},
  [993] = {.lex_state = 73, .external_lex_state = 3},
  [994] = {.lex_state = 73, .external_lex_state = 3},
  [995] = {.lex_state = 73, .external_lex_state = 3},
  [996] = {.lex_state = 73, .external_lex_state = 3},
  [997] = {.lex_state = 73, .external_lex_state = 3},
  [998] = {.lex_state = 73, .external_lex_state = 3},
  [999] = {.lex_state = 73, .external_lex_state = 3},
  [1000] = {.lex_state = 73, .external_lex_state = 3},
  [1001] = {.lex_state = 73, .external_lex_state = 3},
  [1002] = {.lex_state = 73, .external_lex_state = 3},
  [1003] = {.lex_state = 73, .external_lex_state = 3},
  [1004] = {.lex_state = 73, .external_lex_state = 3},
  [1005] = {.lex_state = 73, .external_lex_state = 3},
  [1006] = {.lex_state = 73, .external_lex_state = 3},
  [1007] = {.lex_state = 73, .external_lex_state = 3},
  [1008] = {.lex_state = 73, .external_lex_state = 3},
  [1009] = {.lex_state = 73, .external_lex_state = 3},
  [1010] = {.lex_state = 73, .external_lex_state = 3},
  [1011] = {.lex_state = 73, .external_lex_state = 3},
  [1012] = {.lex_state = 73, .external_lex_state = 3},
  [1013] = {.lex_state = 73, .external_lex_state = 3},
  [1014] = {.lex_state = 73, .external_lex_state = 3},
  [1015] = {.lex_state = 73, .external_lex_state = 3},
  [1016] = {.lex_state = 73, .external_lex_state = 3},
  [1017] = {.lex_state = 73, .external_lex_state = 3},
  [1018] = {.lex_state = 73, .external_lex_state = 3},
  [1019] = {.lex_state = 73, .external_lex_state = 3},
  [1020] = {.lex_state = 73, .external_lex_state = 3},
  [1021] = {.lex_state = 73, .external_lex_state = 3},
  [1022] = {.lex_state = 73, .external_lex_state = 3},
  [1023] = {.lex_state = 73, .external_lex_state = 3},
  [1024] = {.lex_state = 73, .external_lex_state = 3},
  [1025] = {.lex_state = 73, .external_lex_state = 3},
  [1026] = {.lex_state = 73, .external_lex_state = 3},
  [1027] = {.lex_state = 73, .external_lex_state = 3},
  [1028] = {.lex_state = 73, .external_lex_state = 3},
  [1029] = {.lex_state = 73, .external_lex_state = 3},
  [1030] = {.lex_state = 73, .external_lex_state = 3},
  [1031] = {.lex_state = 73, .external_lex_state = 3},
  [1032] = {.lex_state = 73, .external_lex_state = 3},
  [1033] = {.lex_state = 73, .external_lex_state = 3},
  [1034] = {.lex_state = 73, .external_lex_state = 3},
  [1035] = {.lex_state = 73, .external_lex_state = 3},
  [1036] = {.lex_state = 73, .external_lex_state = 3},
  [1037] = {.lex_state = 73, .external_lex_state = 3},
  [1038] = {.lex_state = 73, .external_lex_state = 3},
  [1039] = {.lex_state = 73, .external_lex_state = 3},
  [1040] = {.lex_state = 73, .external_lex_state = 3},
  [1041] = {.lex_state = 73, .external_lex_state = 3},
  [1042] = {.lex_state = 73, .external_lex_state = 3},
  [1043] = {.lex_state = 73, .external_lex_state = 3},
  [1044] = {.lex_state = 73, .external_lex_state = 3},
  [1045] = {.lex_state = 73, .external_lex_state = 3},
  [1046] = {.lex_state = 73, .external_lex_state = 3},
  [1047] = {.lex_state = 73, .external_lex_state = 3},
  [1048] = {.lex_state = 73, .external_lex_state = 3},
  [1049] = {.lex_state = 73, .external_lex_state = 3},
  [1050] = {.lex_state = 73, .external_lex_state = 3},
  [1051] = {.lex_state = 73, .external_lex_state = 3},
  [1052] = {.lex_state = 73, .external_lex_state = 3},
  [1053] = {.lex_state = 73, .external_lex_state = 3},
  [1054] = {.lex_state = 73, .external_lex_state = 3},
  [1055] = {.lex_state = 73, .external_lex_state = 17},
  [1056] = {.lex_state = 73, .external_lex_state = 3},
  [1057] = {.lex_state = 73, .external_lex_state = 3},
  [1058] = {.lex_state = 73, .external_lex_state = 3},
  [1059] = {.lex_state = 73, .external_lex_state = 3},
  [1060] = {.lex_state = 73, .external_lex_state = 3},
  [1061] = {.lex_state = 73, .external_lex_state = 3},
  [1062] = {.lex_state = 73, .external_lex_state = 3},
  [1063] = {.lex_state = 73, .external_lex_state = 3},
  [1064] = {.lex_state = 73, .external_lex_state = 3},
  [1065] = {.lex_state = 73, .external_lex_state = 3},
  [1066] = {.lex_state = 73, .external_lex_state = 3},
  [1067] = {.lex_state = 73, .external_lex_state = 3},
  [1068] = {.lex_state = 73, .external_lex_state = 3},
  [1069] = {.lex_state = 73, .external_lex_state = 3},
  [1070] = {.lex_state = 73, .external_lex_state = 3},
  [1071] = {.lex_state = 73, .external_lex_state = 3},
  [1072] = {.lex_state = 73, .external_lex_state = 3},
  [1073] = {.lex_state = 73, .external_lex_state = 3},
  [1074] = {.lex_state = 73, .external_lex_state = 3},
  [1075] = {.lex_state = 73, .external_lex_state = 3},
  [1076] = {.lex_state = 3, .external_lex_state = 2},
  [1077] = {.lex_state = 73, .external_lex_state = 3},
  [1078] = {.lex_state = 73, .external_lex_state = 3},
  [1079] = {.lex_state = 73, .external_lex_state = 3},
  [1080] = {.lex_state = 73, .external_lex_state = 3},
  [1081] = {.lex_state = 73, .external_lex_state = 3},
  [1082] = {.lex_state = 73, .external_lex_state = 3},
  [1083] = {.lex_state = 73, .external_lex_state = 3},
  [1084] = {.lex_state = 73, .external_lex_state = 3},
  [1085] = {.lex_state = 73, .external_lex_state = 3},
  [1086] = {.lex_state = 73, .external_lex_state = 3},
  [1087] = {.lex_state = 73, .external_lex_state = 3},
  [1088] = {.lex_state = 73, .external_lex_state = 3},
  [1089] = {.lex_state = 73, .external_lex_state = 3},
  [1090] = {.lex_state = 73, .external_lex_state = 3},
  [1091] = {.lex_state = 73, .external_lex_state = 3},
  [1092] = {.lex_state = 73, .external_lex_state = 3},
  [1093] = {.lex_state = 73, .external_lex_state = 3},
  [1094] = {.lex_state = 73, .external_lex_state = 3},
  [1095] = {.lex_state = 73, .external_lex_state = 3},
  [1096] = {.lex_state = 73, .external_lex_state = 3},
  [1097] = {.lex_state = 73, .external_lex_state = 3},
  [1098] = {.lex_state = 73, .external_lex_state = 3},
  [1099] = {.lex_state = 73, .external_lex_state = 3},
  [1100] = {.lex_state = 73, .external_lex_state = 3},
  [1101] = {.lex_state = 73, .external_lex_state = 3},
  [1102] = {.lex_state = 73, .external_lex_state = 3},
  [1103] = {.lex_state = 73, .external_lex_state = 3},
  [1104] = {.lex_state = 73, .external_lex_state = 3},
  [1105] = {.lex_state = 73, .external_lex_state = 16},
  [1106] = {.lex_state = 73, .external_lex_state = 3},
  [1107] = {.lex_state = 73, .external_lex_state = 3},
  [1108] = {.lex_state = 73, .external_lex_state = 3},
  [1109] = {.lex_state = 73, .external_lex_state = 3},
  [1110] = {.lex_state = 73, .external_lex_state = 3},
  [1111] = {.lex_state = 73, .external_lex_state = 3},
  [1112] = {.lex_state = 73, .external_lex_state = 3},
  [1113] = {.lex_state = 73, .external_lex_state = 3},
  [1114] = {.lex_state = 73, .external_lex_state = 3},
  [1115] = {.lex_state = 73, .external_lex_state = 3},
  [1116] = {.lex_state = 73, .external_lex_state = 3},
  [1117] = {.lex_state = 73, .external_lex_state = 3},
  [1118] = {.lex_state = 73, .external_lex_state = 3},
  [1119] = {.lex_state = 73, .external_lex_state = 3},
  [1120] = {.lex_state = 73, .external_lex_state = 3},
  [1121] = {.lex_state = 73, .external_lex_state = 3},
  [1122] = {.lex_state = 73, .external_lex_state = 3},
  [1123] = {.lex_state = 73, .external_lex_state = 3},
  [1124] = {.lex_state = 73, .external_lex_state = 3},
  [1125] = {.lex_state = 73, .external_lex_state = 3},
  [1126] = {.lex_state = 73, .external_lex_state = 3},
  [1127] = {.lex_state = 73, .external_lex_state = 3},
  [1128] = {.lex_state = 73, .external_lex_state = 3},
  [1129] = {.lex_state = 73, .external_lex_state = 3},
  [1130] = {.lex_state = 73, .external_lex_state = 3},
  [1131] = {.lex_state = 73, .external_lex_state = 3},
  [1132] = {.lex_state = 73, .external_lex_state = 3},
  [1133] = {.lex_state = 73, .external_lex_state = 3},
  [1134] = {.lex_state = 73, .external_lex_state = 3},
  [1135] = {.lex_state = 73, .external_lex_state = 3},
  [1136] = {.lex_state = 73, .external_lex_state = 3},
  [1137] = {.lex_state = 73, .external_lex_state = 3},
  [1138] = {.lex_state = 73, .external_lex_state = 3},
  [1139] = {.lex_state = 73, .external_lex_state = 3},
  [1140] = {.lex_state = 73, .external_lex_state = 3},
  [1141] = {.lex_state = 73, .external_lex_state = 3},
  [1142] = {.lex_state = 73, .external_lex_state = 3},
  [1143] = {.lex_state = 73, .external_lex_state = 3},
  [1144] = {.lex_state = 73, .external_lex_state = 3},
  [1145] = {.lex_state = 73, .external_lex_state = 3},
  [1146] = {.lex_state = 73, .external_lex_state = 3},
  [1147] = {.lex_state = 73, .external_lex_state = 3},
  [1148] = {.lex_state = 73, .external_lex_state = 3},
  [1149] = {.lex_state = 73, .external_lex_state = 3},
  [1150] = {.lex_state = 73, .external_lex_state = 3},
  [1151] = {.lex_state = 73, .external_lex_state = 3},
  [1152] = {.lex_state = 73, .external_lex_state = 3},
  [1153] = {.lex_state = 73, .external_lex_state = 3},
  [1154] = {.lex_state = 73, .external_lex_state = 3},
  [1155] = {.lex_state = 73, .external_lex_state = 3},
  [1156] = {.lex_state = 73, .external_lex_state = 3},
  [1157] = {.lex_state = 73, .external_lex_state = 3},
  [1158] = {.lex_state = 73, .external_lex_state = 3},
  [1159] = {.lex_state = 73, .external_lex_state = 3},
  [1160] = {.lex_state = 73, .external_lex_state = 3},
  [1161] = {.lex_state = 73, .external_lex_state = 3},
  [1162] = {.lex_state = 73, .external_lex_state = 3},
  [1163] = {.lex_state = 73, .external_lex_state = 3},
  [1164] = {.lex_state = 73, .external_lex_state = 3},
  [1165] = {.lex_state = 73, .external_lex_state = 3},
  [1166] = {.lex_state = 73, .external_lex_state = 3},
  [1167] = {.lex_state = 73, .external_lex_state = 3},
  [1168] = {.lex_state = 73, .external_lex_state = 3},
  [1169] = {.lex_state = 73, .external_lex_state = 3},
  [1170] = {.lex_state = 73, .external_lex_state = 3},
  [1171] = {.lex_state = 73, .external_lex_state = 3},
  [1172] = {.lex_state = 73, .external_lex_state = 3},
  [1173] = {.lex_state = 73, .external_lex_state = 3},
  [1174] = {.lex_state = 73, .external_lex_state = 3},
  [1175] = {.lex_state = 73, .external_lex_state = 3},
  [1176] = {.lex_state = 73, .external_lex_state = 3},
  [1177] = {.lex_state = 73, .external_lex_state = 3},
  [1178] = {.lex_state = 73, .external_lex_state = 3},
  [1179] = {.lex_state = 73, .external_lex_state = 3},
  [1180] = {.lex_state = 73, .external_lex_state = 3},
  [1181] = {.lex_state = 73, .external_lex_state = 3},
  [1182] = {.lex_state = 73, .external_lex_state = 3},
  [1183] = {.lex_state = 73, .external_lex_state = 3},
  [1184] = {.lex_state = 73, .external_lex_state = 3},
  [1185] = {.lex_state = 73, .external_lex_state = 3},
  [1186] = {.lex_state = 73, .external_lex_state = 3},
  [1187] = {.lex_state = 73, .external_lex_state = 16},
  [1188] = {.lex_state = 73, .external_lex_state = 3},
  [1189] = {.lex_state = 73, .external_lex_state = 3},
  [1190] = {.lex_state = 73, .external_lex_state = 3},
  [1191] = {.lex_state = 73, .external_lex_state = 3},
  [1192] = {.lex_state = 73, .external_lex_state = 3},
  [1193] = {.lex_state = 73, .external_lex_state = 3},
  [1194] = {.lex_state = 73, .external_lex_state = 3},
  [1195] = {.lex_state = 73, .external_lex_state = 3},
  [1196] = {.lex_state = 73, .external_lex_state = 3},
  [1197] = {.lex_state = 73, .external_lex_state = 3},
  [1198] = {.lex_state = 73, .external_lex_state = 3},
  [1199] = {.lex_state = 73, .external_lex_state = 3},
  [1200] = {.lex_state = 73, .external_lex_state = 3},
  [1201] = {.lex_state = 73, .external_lex_state = 3},
  [1202] = {.lex_state = 73, .external_lex_state = 3},
  [1203] = {.lex_state = 73, .external_lex_state = 3},
  [1204] = {.lex_state = 73, .external_lex_state = 3},
  [1205] = {.lex_state = 73, .external_lex_state = 3},
  [1206] = {.lex_state = 73, .external_lex_state = 3},
  [1207] = {.lex_state = 73, .external_lex_state = 3},
  [1208] = {.lex_state = 73, .external_lex_state = 3},
  [1209] = {.lex_state = 73, .external_lex_state = 3},
  [1210] = {.lex_state = 73, .external_lex_state = 3},
  [1211] = {.lex_state = 73, .external_lex_state = 3},
  [1212] = {.lex_state = 73, .external_lex_state = 3},
  [1213] = {.lex_state = 73, .external_lex_state = 3},
  [1214] = {.lex_state = 73, .external_lex_state = 3},
  [1215] = {.lex_state = 73, .external_lex_state = 3},
  [1216] = {.lex_state = 73, .external_lex_state = 3},
  [1217] = {.lex_state = 73, .external_lex_state = 3},
  [1218] = {.lex_state = 73, .external_lex_state = 3},
  [1219] = {.lex_state = 73, .external_lex_state = 3},
  [1220] = {.lex_state = 73, .external_lex_state = 3},
  [1221] = {.lex_state = 73, .external_lex_state = 3},
  [1222] = {.lex_state = 73, .external_lex_state = 3},
  [1223] = {.lex_state = 73, .external_lex_state = 3},
  [1224] = {.lex_state = 73, .external_lex_state = 3},
  [1225] = {.lex_state = 73, .external_lex_state = 3},
  [1226] = {.lex_state = 73, .external_lex_state = 3},
  [1227] = {.lex_state = 73, .external_lex_state = 3},
  [1228] = {.lex_state = 73, .external_lex_state = 3},
  [1229] = {.lex_state = 73, .external_lex_state = 3},
  [1230] = {.lex_state = 73, .external_lex_state = 3},
  [1231] = {.lex_state = 73, .external_lex_state = 3},
  [1232] = {.lex_state = 73, .external_lex_state = 3},
  [1233] = {.lex_state = 73, .external_lex_state = 3},
  [1234] = {.lex_state = 73, .external_lex_state = 3},
  [1235] = {.lex_state = 73, .external_lex_state = 3},
  [1236] = {.lex_state = 73, .external_lex_state = 3},
  [1237] = {.lex_state = 73, .external_lex_state = 3},
  [1238] = {.lex_state = 73, .external_lex_state = 3},
  [1239] = {.lex_state = 73, .external_lex_state = 3},
  [1240] = {.lex_state = 73, .external_lex_state = 3},
  [1241] = {.lex_state = 73, .external_lex_state = 3},
  [1242] = {.lex_state = 73, .external_lex_state = 3},
  [1243] = {.lex_state = 73, .external_lex_state = 3},
  [1244] = {.lex_state = 73, .external_lex_state = 3},
  [1245] = {.lex_state = 73, .external_lex_state = 3},
  [1246] = {.lex_state = 73, .external_lex_state = 3},
  [1247] = {.lex_state = 73, .external_lex_state = 3},
  [1248] = {.lex_state = 73, .external_lex_state = 3},
  [1249] = {.lex_state = 73, .external_lex_state = 3},
  [1250] = {.lex_state = 73, .external_lex_state = 3},
  [1251] = {.lex_state = 73, .external_lex_state = 3},
  [1252] = {.lex_state = 73, .external_lex_state = 3},
  [1253] = {.lex_state = 73, .external_lex_state = 3},
  [1254] = {.lex_state = 73, .external_lex_state = 3},
  [1255] = {.lex_state = 73, .external_lex_state = 3},
  [1256] = {.lex_state = 73, .external_lex_state = 3},
  [1257] = {.lex_state = 73, .external_lex_state = 3},
  [1258] = {.lex_state = 73, .external_lex_state = 3},
  [1259] = {.lex_state = 73, .external_lex_state = 3},
  [1260] = {.lex_state = 73, .external_lex_state = 3},
  [1261] = {.lex_state = 73, .external_lex_state = 3},
  [1262] = {.lex_state = 73, .external_lex_state = 3},
  [1263] = {.lex_state = 73, .external_lex_state = 3},
  [1264] = {.lex_state = 73, .external_lex_state = 3},
  [1265] = {.lex_state = 73, .external_lex_state = 3},
  [1266] = {.lex_state = 73, .external_lex_state = 3},
  [1267] = {.lex_state = 73, .external_lex_state = 3},
  [1268] = {.lex_state = 73, .external_lex_state = 3},
  [1269] = {.lex_state = 73, .external_lex_state = 3},
  [1270] = {.lex_state = 73, .external_lex_state = 3},
  [1271] = {.lex_state = 73, .external_lex_state = 3},
  [1272] = {.lex_state = 73, .external_lex_state = 3},
  [1273] = {.lex_state = 73, .external_lex_state = 3},
  [1274] = {.lex_state = 73, .external_lex_state = 3},
  [1275] = {.lex_state = 73, .external_lex_state = 3},
  [1276] = {.lex_state = 73, .external_lex_state = 3},
  [1277] = {.lex_state = 73, .external_lex_state = 3},
  [1278] = {.lex_state = 73, .external_lex_state = 3},
  [1279] = {.lex_state = 73, .external_lex_state = 3},
  [1280] = {.lex_state = 73, .external_lex_state = 3},
  [1281] = {.lex_state = 73, .external_lex_state = 3},
  [1282] = {.lex_state = 73, .external_lex_state = 3},
  [1283] = {.lex_state = 73, .external_lex_state = 3},
  [1284] = {.lex_state = 73, .external_lex_state = 3},
  [1285] = {.lex_state = 73, .external_lex_state = 3},
  [1286] = {.lex_state = 73, .external_lex_state = 3},
  [1287] = {.lex_state = 73, .external_lex_state = 3},
  [1288] = {.lex_state = 73, .external_lex_state = 3},
  [1289] = {.lex_state = 73, .external_lex_state = 3},
  [1290] = {.lex_state = 73, .external_lex_state = 3},
  [1291] = {.lex_state = 73, .external_lex_state = 3},
  [1292] = {.lex_state = 73, .external_lex_state = 3},
  [1293] = {.lex_state = 73, .external_lex_state = 3},
  [1294] = {.lex_state = 73, .external_lex_state = 3},
  [1295] = {.lex_state = 73, .external_lex_state = 3},
  [1296] = {.lex_state = 73, .external_lex_state = 3},
  [1297] = {.lex_state = 73, .external_lex_state = 3},
  [1298] = {.lex_state = 73, .external_lex_state = 3},
  [1299] = {.lex_state = 73, .external_lex_state = 3},
  [1300] = {.lex_state = 73, .external_lex_state = 3},
  [1301] = {.lex_state = 73, .external_lex_state = 3},
  [1302] = {.lex_state = 73, .external_lex_state = 3},
  [1303] = {.lex_state = 73, .external_lex_state = 3},
  [1304] = {.lex_state = 73, .external_lex_state = 3},
  [1305] = {.lex_state = 73, .external_lex_state = 3},
  [1306] = {.lex_state = 73, .external_lex_state = 3},
  [1307] = {.lex_state = 73, .external_lex_state = 3},
  [1308] = {.lex_state = 73, .external_lex_state = 3},
  [1309] = {.lex_state = 73, .external_lex_state = 3},
  [1310] = {.lex_state = 73, .external_lex_state = 3},
  [1311] = {.lex_state = 73, .external_lex_state = 3},
  [1312] = {.lex_state = 73, .external_lex_state = 3},
  [1313] = {.lex_state = 73, .external_lex_state = 3},
  [1314] = {.lex_state = 73, .external_lex_state = 3},
  [1315] = {.lex_state = 73, .external_lex_state = 3},
  [1316] = {.lex_state = 73, .external_lex_state = 3},
  [1317] = {.lex_state = 73, .external_lex_state = 3},
  [1318] = {.lex_state = 73, .external_lex_state = 3},
  [1319] = {.lex_state = 73, .external_lex_state = 3},
  [1320] = {.lex_state = 73, .external_lex_state = 3},
  [1321] = {.lex_state = 73, .external_lex_state = 3},
  [1322] = {.lex_state = 73, .external_lex_state = 3},
  [1323] = {.lex_state = 73, .external_lex_state = 3},
  [1324] = {.lex_state = 73, .external_lex_state = 3},
  [1325] = {.lex_state = 73, .external_lex_state = 3},
  [1326] = {.lex_state = 73, .external_lex_state = 3},
  [1327] = {.lex_state = 73, .external_lex_state = 3},
  [1328] = {.lex_state = 73, .external_lex_state = 3},
  [1329] = {.lex_state = 73, .external_lex_state = 3},
  [1330] = {.lex_state = 73, .external_lex_state = 3},
  [1331] = {.lex_state = 73, .external_lex_state = 3},
  [1332] = {.lex_state = 73, .external_lex_state = 3},
  [1333] = {.lex_state = 73, .external_lex_state = 3},
  [1334] = {.lex_state = 73, .external_lex_state = 3},
  [1335] = {.lex_state = 73, .external_lex_state = 3},
  [1336] = {.lex_state = 73, .external_lex_state = 3},
  [1337] = {.lex_state = 73, .external_lex_state = 3},
  [1338] = {.lex_state = 73, .external_lex_state = 3},
  [1339] = {.lex_state = 73, .external_lex_state = 3},
  [1340] = {.lex_state = 73, .external_lex_state = 3},
  [1341] = {.lex_state = 73, .external_lex_state = 3},
  [1342] = {.lex_state = 73, .external_lex_state = 3},
  [1343] = {.lex_state = 73, .external_lex_state = 3},
  [1344] = {.lex_state = 73, .external_lex_state = 3},
  [1345] = {.lex_state = 73, .external_lex_state = 3},
  [1346] = {.lex_state = 73, .external_lex_state = 3},
  [1347] = {.lex_state = 73, .external_lex_state = 3},
  [1348] = {.lex_state = 73, .external_lex_state = 3},
  [1349] = {.lex_state = 73, .external_lex_state = 3},
  [1350] = {.lex_state = 73, .external_lex_state = 3},
  [1351] = {.lex_state = 73, .external_lex_state = 3},
  [1352] = {.lex_state = 73, .external_lex_state = 3},
  [1353] = {.lex_state = 73, .external_lex_state = 3},
  [1354] = {.lex_state = 73, .external_lex_state = 3},
  [1355] = {.lex_state = 73, .external_lex_state = 3},
  [1356] = {.lex_state = 73, .external_lex_state = 3},
  [1357] = {.lex_state = 73, .external_lex_state = 3},
  [1358] = {.lex_state = 73, .external_lex_state = 3},
  [1359] = {.lex_state = 73, .external_lex_state = 3},
  [1360] = {.lex_state = 73, .external_lex_state = 3},
  [1361] = {.lex_state = 73, .external_lex_state = 3},
  [1362] = {.lex_state = 73, .external_lex_state = 3},
  [1363] = {.lex_state = 73, .external_lex_state = 3},
  [1364] = {.lex_state = 73, .external_lex_state = 3},
  [1365] = {.lex_state = 73, .external_lex_state = 3},
  [1366] = {.lex_state = 73, .external_lex_state = 3},
  [1367] = {.lex_state = 73, .external_lex_state = 3},
  [1368] = {.lex_state = 73, .external_lex_state = 3},
  [1369] = {.lex_state = 73, .external_lex_state = 3},
  [1370] = {.lex_state = 73, .external_lex_state = 3},
  [1371] = {.lex_state = 73, .external_lex_state = 3},
  [1372] = {.lex_state = 73, .external_lex_state = 3},
  [1373] = {.lex_state = 73, .external_lex_state = 3},
  [1374] = {.lex_state = 73, .external_lex_state = 3},
  [1375] = {.lex_state = 73, .external_lex_state = 3},
  [1376] = {.lex_state = 73, .external_lex_state = 3},
  [1377] = {.lex_state = 73, .external_lex_state = 3},
  [1378] = {.lex_state = 73, .external_lex_state = 3},
  [1379] = {.lex_state = 73, .external_lex_state = 3},
  [1380] = {.lex_state = 73, .external_lex_state = 3},
  [1381] = {.lex_state = 73, .external_lex_state = 3},
  [1382] = {.lex_state = 73, .external_lex_state = 3},
  [1383] = {.lex_state = 73, .external_lex_state = 3},
  [1384] = {.lex_state = 73, .external_lex_state = 3},
  [1385] = {.lex_state = 73, .external_lex_state = 3},
  [1386] = {.lex_state = 73, .external_lex_state = 3},
  [1387] = {.lex_state = 73, .external_lex_state = 3},
  [1388] = {.lex_state = 73, .external_lex_state = 3},
  [1389] = {.lex_state = 73, .external_lex_state = 3},
  [1390] = {.lex_state = 73, .external_lex_state = 3},
  [1391] = {.lex_state = 73, .external_lex_state = 3},
  [1392] = {.lex_state = 73, .external_lex_state = 3},
  [1393] = {.lex_state = 73, .external_lex_state = 3},
  [1394] = {.lex_state = 73, .external_lex_state = 3},
  [1395] = {.lex_state = 73, .external_lex_state = 3},
  [1396] = {.lex_state = 73, .external_lex_state = 3},
  [1397] = {.lex_state = 73, .external_lex_state = 3},
  [1398] = {.lex_state = 73, .external_lex_state = 3},
  [1399] = {.lex_state = 73, .external_lex_state = 3},
  [1400] = {.lex_state = 73, .external_lex_state = 3},
  [1401] = {.lex_state = 73, .external_lex_state = 3},
  [1402] = {.lex_state = 73, .external_lex_state = 3},
  [1403] = {.lex_state = 73, .external_lex_state = 3},
  [1404] = {.lex_state = 73, .external_lex_state = 3},
  [1405] = {.lex_state = 73, .external_lex_state = 3},
  [1406] = {.lex_state = 73, .external_lex_state = 3},
  [1407] = {.lex_state = 73, .external_lex_state = 3},
  [1408] = {.lex_state = 73, .external_lex_state = 3},
  [1409] = {.lex_state = 73, .external_lex_state = 3},
  [1410] = {.lex_state = 73, .external_lex_state = 3},
  [1411] = {.lex_state = 73, .external_lex_state = 3},
  [1412] = {.lex_state = 73, .external_lex_state = 3},
  [1413] = {.lex_state = 73, .external_lex_state = 3},
  [1414] = {.lex_state = 73, .external_lex_state = 3},
  [1415] = {.lex_state = 73, .external_lex_state = 3},
  [1416] = {.lex_state = 73, .external_lex_state = 3},
  [1417] = {.lex_state = 73, .external_lex_state = 3},
  [1418] = {.lex_state = 73, .external_lex_state = 3},
  [1419] = {.lex_state = 73, .external_lex_state = 3},
  [1420] = {.lex_state = 73, .external_lex_state = 3},
  [1421] = {.lex_state = 73, .external_lex_state = 3},
  [1422] = {.lex_state = 73, .external_lex_state = 3},
  [1423] = {.lex_state = 73, .external_lex_state = 3},
  [1424] = {.lex_state = 73, .external_lex_state = 3},
  [1425] = {.lex_state = 73, .external_lex_state = 3},
  [1426] = {.lex_state = 73, .external_lex_state = 3},
  [1427] = {.lex_state = 73, .external_lex_state = 3},
  [1428] = {.lex_state = 73, .external_lex_state = 3},
  [1429] = {.lex_state = 73, .external_lex_state = 3},
  [1430] = {.lex_state = 73, .external_lex_state = 3},
  [1431] = {.lex_state = 73, .external_lex_state = 3},
  [1432] = {.lex_state = 73, .external_lex_state = 3},
  [1433] = {.lex_state = 73, .external_lex_state = 3},
  [1434] = {.lex_state = 73, .external_lex_state = 3},
  [1435] = {.lex_state = 73, .external_lex_state = 3},
  [1436] = {.lex_state = 73, .external_lex_state = 3},
  [1437] = {.lex_state = 73, .external_lex_state = 3},
  [1438] = {.lex_state = 73, .external_lex_state = 3},
  [1439] = {.lex_state = 73, .external_lex_state = 3},
  [1440] = {.lex_state = 73, .external_lex_state = 3},
  [1441] = {.lex_state = 73, .external_lex_state = 3},
  [1442] = {.lex_state = 73, .external_lex_state = 3},
  [1443] = {.lex_state = 73, .external_lex_state = 3},
  [1444] = {.lex_state = 73, .external_lex_state = 3},
  [1445] = {.lex_state = 73, .external_lex_state = 3},
  [1446] = {.lex_state = 73, .external_lex_state = 3},
  [1447] = {.lex_state = 73, .external_lex_state = 3},
  [1448] = {.lex_state = 73, .external_lex_state = 3},
  [1449] = {.lex_state = 73, .external_lex_state = 3},
  [1450] = {.lex_state = 73, .external_lex_state = 3},
  [1451] = {.lex_state = 73, .external_lex_state = 3},
  [1452] = {.lex_state = 73, .external_lex_state = 3},
  [1453] = {.lex_state = 73, .external_lex_state = 3},
  [1454] = {.lex_state = 73, .external_lex_state = 3},
  [1455] = {.lex_state = 73, .external_lex_state = 3},
  [1456] = {.lex_state = 73, .external_lex_state = 3},
  [1457] = {.lex_state = 73, .external_lex_state = 3},
  [1458] = {.lex_state = 73, .external_lex_state = 3},
  [1459] = {.lex_state = 73, .external_lex_state = 3},
  [1460] = {.lex_state = 73, .external_lex_state = 3},
  [1461] = {.lex_state = 73, .external_lex_state = 3},
  [1462] = {.lex_state = 73, .external_lex_state = 3},
  [1463] = {.lex_state = 73, .external_lex_state = 3},
  [1464] = {.lex_state = 73, .external_lex_state = 3},
  [1465] = {.lex_state = 73, .external_lex_state = 3},
  [1466] = {.lex_state = 73, .external_lex_state = 3},
  [1467] = {.lex_state = 73, .external_lex_state = 3},
  [1468] = {.lex_state = 73, .external_lex_state = 3},
  [1469] = {.lex_state = 73, .external_lex_state = 3},
  [1470] = {.lex_state = 73, .external_lex_state = 3},
  [1471] = {.lex_state = 73, .external_lex_state = 3},
  [1472] = {.lex_state = 73, .external_lex_state = 3},
  [1473] = {.lex_state = 73, .external_lex_state = 3},
  [1474] = {.lex_state = 73, .external_lex_state = 3},
  [1475] = {.lex_state = 73, .external_lex_state = 3},
  [1476] = {.lex_state = 73, .external_lex_state = 3},
  [1477] = {.lex_state = 73, .external_lex_state = 3},
  [1478] = {.lex_state = 73, .external_lex_state = 3},
  [1479] = {.lex_state = 73, .external_lex_state = 3},
  [1480] = {.lex_state = 73, .external_lex_state = 3},
  [1481] = {.lex_state = 73, .external_lex_state = 3},
  [1482] = {.lex_state = 73, .external_lex_state = 3},
  [1483] = {.lex_state = 73, .external_lex_state = 3},
  [1484] = {.lex_state = 73, .external_lex_state = 3},
  [1485] = {.lex_state = 73, .external_lex_state = 3},
  [1486] = {.lex_state = 73, .external_lex_state = 3},
  [1487] = {.lex_state = 73, .external_lex_state = 3},
  [1488] = {.lex_state = 73, .external_lex_state = 3},
  [1489] = {.lex_state = 73, .external_lex_state = 3},
  [1490] = {.lex_state = 73, .external_lex_state = 3},
  [1491] = {.lex_state = 73, .external_lex_state = 3},
  [1492] = {.lex_state = 73, .external_lex_state = 3},
  [1493] = {.lex_state = 73, .external_lex_state = 3},
  [1494] = {.lex_state = 73, .external_lex_state = 3},
  [1495] = {.lex_state = 73, .external_lex_state = 3},
  [1496] = {.lex_state = 73, .external_lex_state = 3},
  [1497] = {.lex_state = 73, .external_lex_state = 3},
  [1498] = {.lex_state = 73, .external_lex_state = 3},
  [1499] = {.lex_state = 73, .external_lex_state = 3},
  [1500] = {.lex_state = 73, .external_lex_state = 3},
  [1501] = {.lex_state = 73, .external_lex_state = 3},
  [1502] = {.lex_state = 73, .external_lex_state = 3},
  [1503] = {.lex_state = 73, .external_lex_state = 3},
  [1504] = {.lex_state = 73, .external_lex_state = 3},
  [1505] = {.lex_state = 73, .external_lex_state = 3},
  [1506] = {.lex_state = 73, .external_lex_state = 3},
  [1507] = {.lex_state = 73, .external_lex_state = 3},
  [1508] = {.lex_state = 73, .external_lex_state = 3},
  [1509] = {.lex_state = 73, .external_lex_state = 3},
  [1510] = {.lex_state = 73, .external_lex_state = 3},
  [1511] = {.lex_state = 73, .external_lex_state = 3},
  [1512] = {.lex_state = 73, .external_lex_state = 3},
  [1513] = {.lex_state = 73, .external_lex_state = 3},
  [1514] = {.lex_state = 73, .external_lex_state = 3},
  [1515] = {.lex_state = 73, .external_lex_state = 3},
  [1516] = {.lex_state = 73, .external_lex_state = 3},
  [1517] = {.lex_state = 73, .external_lex_state = 3},
  [1518] = {.lex_state = 73, .external_lex_state = 3},
  [1519] = {.lex_state = 73, .external_lex_state = 3},
  [1520] = {.lex_state = 73, .external_lex_state = 3},
  [1521] = {.lex_state = 73, .external_lex_state = 3},
  [1522] = {.lex_state = 73, .external_lex_state = 3},
  [1523] = {.lex_state = 73, .external_lex_state = 3},
  [1524] = {.lex_state = 73, .external_lex_state = 3},
  [1525] = {.lex_state = 73, .external_lex_state = 3},
  [1526] = {.lex_state = 73, .external_lex_state = 3},
  [1527] = {.lex_state = 73, .external_lex_state = 3},
  [1528] = {.lex_state = 73, .external_lex_state = 3},
  [1529] = {.lex_state = 73, .external_lex_state = 3},
  [1530] = {.lex_state = 73, .external_lex_state = 3},
  [1531] = {.lex_state = 73, .external_lex_state = 3},
  [1532] = {.lex_state = 73, .external_lex_state = 3},
  [1533] = {.lex_state = 73, .external_lex_state = 3},
  [1534] = {.lex_state = 73, .external_lex_state = 3},
  [1535] = {.lex_state = 73, .external_lex_state = 3},
  [1536] = {.lex_state = 73, .external_lex_state = 3},
  [1537] = {.lex_state = 73, .external_lex_state = 3},
  [1538] = {.lex_state = 73, .external_lex_state = 3},
  [1539] = {.lex_state = 73, .external_lex_state = 3},
  [1540] = {.lex_state = 73, .external_lex_state = 3},
  [1541] = {.lex_state = 73, .external_lex_state = 3},
  [1542] = {.lex_state = 73, .external_lex_state = 3},
  [1543] = {.lex_state = 73, .external_lex_state = 3},
  [1544] = {.lex_state = 73, .external_lex_state = 3},
  [1545] = {.lex_state = 73, .external_lex_state = 3},
  [1546] = {.lex_state = 73, .external_lex_state = 3},
  [1547] = {.lex_state = 73, .external_lex_state = 3},
  [1548] = {.lex_state = 73, .external_lex_state = 3},
  [1549] = {.lex_state = 73, .external_lex_state = 3},
  [1550] = {.lex_state = 73, .external_lex_state = 3},
  [1551] = {.lex_state = 73, .external_lex_state = 3},
  [1552] = {.lex_state = 73, .external_lex_state = 3},
  [1553] = {.lex_state = 73, .external_lex_state = 3},
  [1554] = {.lex_state = 73, .external_lex_state = 3},
  [1555] = {.lex_state = 73, .external_lex_state = 3},
  [1556] = {.lex_state = 73, .external_lex_state = 3},
  [1557] = {.lex_state = 73, .external_lex_state = 3},
  [1558] = {.lex_state = 73, .external_lex_state = 3},
  [1559] = {.lex_state = 73, .external_lex_state = 3},
  [1560] = {.lex_state = 73, .external_lex_state = 3},
  [1561] = {.lex_state = 73, .external_lex_state = 3},
  [1562] = {.lex_state = 73, .external_lex_state = 3},
  [1563] = {.lex_state = 73, .external_lex_state = 3},
  [1564] = {.lex_state = 73, .external_lex_state = 3},
  [1565] = {.lex_state = 73, .external_lex_state = 3},
  [1566] = {.lex_state = 73, .external_lex_state = 3},
  [1567] = {.lex_state = 73, .external_lex_state = 3},
  [1568] = {.lex_state = 73, .external_lex_state = 3},
  [1569] = {.lex_state = 73, .external_lex_state = 3},
  [1570] = {.lex_state = 73, .external_lex_state = 3},
  [1571] = {.lex_state = 73, .external_lex_state = 3},
  [1572] = {.lex_state = 73, .external_lex_state = 3},
  [1573] = {.lex_state = 73, .external_lex_state = 3},
  [1574] = {.lex_state = 73, .external_lex_state = 3},
  [1575] = {.lex_state = 73, .external_lex_state = 3},
  [1576] = {.lex_state = 73, .external_lex_state = 3},
  [1577] = {.lex_state = 73, .external_lex_state = 3},
  [1578] = {.lex_state = 73, .external_lex_state = 3},
  [1579] = {.lex_state = 73, .external_lex_state = 3},
  [1580] = {.lex_state = 73, .external_lex_state = 3},
  [1581] = {.lex_state = 73, .external_lex_state = 3},
  [1582] = {.lex_state = 73, .external_lex_state = 3},
  [1583] = {.lex_state = 73, .external_lex_state = 3},
  [1584] = {.lex_state = 73, .external_lex_state = 3},
  [1585] = {.lex_state = 73, .external_lex_state = 3},
  [1586] = {.lex_state = 73, .external_lex_state = 3},
  [1587] = {.lex_state = 73, .external_lex_state = 3},
  [1588] = {.lex_state = 73, .external_lex_state = 3},
  [1589] = {.lex_state = 73, .external_lex_state = 3},
  [1590] = {.lex_state = 73, .external_lex_state = 3},
  [1591] = {.lex_state = 73, .external_lex_state = 3},
  [1592] = {.lex_state = 73, .external_lex_state = 3},
  [1593] = {.lex_state = 73, .external_lex_state = 3},
  [1594] = {.lex_state = 73, .external_lex_state = 3},
  [1595] = {.lex_state = 73, .external_lex_state = 3},
  [1596] = {.lex_state = 73, .external_lex_state = 3},
  [1597] = {.lex_state = 73, .external_lex_state = 3},
  [1598] = {.lex_state = 73, .external_lex_state = 3},
  [1599] = {.lex_state = 73, .external_lex_state = 3},
  [1600] = {.lex_state = 73, .external_lex_state = 3},
  [1601] = {.lex_state = 73, .external_lex_state = 3},
  [1602] = {.lex_state = 73, .external_lex_state = 3},
  [1603] = {.lex_state = 73, .external_lex_state = 3},
  [1604] = {.lex_state = 73, .external_lex_state = 3},
  [1605] = {.lex_state = 73, .external_lex_state = 3},
  [1606] = {.lex_state = 73, .external_lex_state = 3},
  [1607] = {.lex_state = 73, .external_lex_state = 3},
  [1608] = {.lex_state = 73, .external_lex_state = 3},
  [1609] = {.lex_state = 73, .external_lex_state = 3},
  [1610] = {.lex_state = 73, .external_lex_state = 3},
  [1611] = {.lex_state = 73, .external_lex_state = 3},
  [1612] = {.lex_state = 73, .external_lex_state = 3},
  [1613] = {.lex_state = 73, .external_lex_state = 3},
  [1614] = {.lex_state = 73, .external_lex_state = 3},
  [1615] = {.lex_state = 73, .external_lex_state = 3},
  [1616] = {.lex_state = 73, .external_lex_state = 3},
  [1617] = {.lex_state = 73, .external_lex_state = 3},
  [1618] = {.lex_state = 73, .external_lex_state = 3},
  [1619] = {.lex_state = 73, .external_lex_state = 3},
  [1620] = {.lex_state = 73, .external_lex_state = 3},
  [1621] = {.lex_state = 73, .external_lex_state = 3},
  [1622] = {.lex_state = 73, .external_lex_state = 3},
  [1623] = {.lex_state = 73, .external_lex_state = 3},
  [1624] = {.lex_state = 73, .external_lex_state = 3},
  [1625] = {.lex_state = 73, .external_lex_state = 3},
  [1626] = {.lex_state = 73, .external_lex_state = 3},
  [1627] = {.lex_state = 73, .external_lex_state = 3},
  [1628] = {.lex_state = 73, .external_lex_state = 3},
  [1629] = {.lex_state = 73, .external_lex_state = 3},
  [1630] = {.lex_state = 73, .external_lex_state = 3},
  [1631] = {.lex_state = 73, .external_lex_state = 3},
  [1632] = {.lex_state = 73, .external_lex_state = 3},
  [1633] = {.lex_state = 73, .external_lex_state = 3},
  [1634] = {.lex_state = 73, .external_lex_state = 3},
  [1635] = {.lex_state = 73, .external_lex_state = 3},
  [1636] = {.lex_state = 73, .external_lex_state = 3},
  [1637] = {.lex_state = 73, .external_lex_state = 3},
  [1638] = {.lex_state = 73, .external_lex_state = 3},
  [1639] = {.lex_state = 73, .external_lex_state = 3},
  [1640] = {.lex_state = 73, .external_lex_state = 3},
  [1641] = {.lex_state = 73, .external_lex_state = 3},
  [1642] = {.lex_state = 73, .external_lex_state = 3},
  [1643] = {.lex_state = 73, .external_lex_state = 3},
  [1644] = {.lex_state = 73, .external_lex_state = 3},
  [1645] = {.lex_state = 73, .external_lex_state = 3},
  [1646] = {.lex_state = 73, .external_lex_state = 3},
  [1647] = {.lex_state = 73, .external_lex_state = 3},
  [1648] = {.lex_state = 73, .external_lex_state = 3},
  [1649] = {.lex_state = 73, .external_lex_state = 3},
  [1650] = {.lex_state = 73, .external_lex_state = 3},
  [1651] = {.lex_state = 73, .external_lex_state = 3},
  [1652] = {.lex_state = 73, .external_lex_state = 3},
  [1653] = {.lex_state = 73, .external_lex_state = 3},
  [1654] = {.lex_state = 73, .external_lex_state = 3},
  [1655] = {.lex_state = 73, .external_lex_state = 3},
  [1656] = {.lex_state = 73, .external_lex_state = 3},
  [1657] = {.lex_state = 73, .external_lex_state = 3},
  [1658] = {.lex_state = 73, .external_lex_state = 3},
  [1659] = {.lex_state = 73, .external_lex_state = 3},
  [1660] = {.lex_state = 73, .external_lex_state = 3},
  [1661] = {.lex_state = 73, .external_lex_state = 3},
  [1662] = {.lex_state = 73, .external_lex_state = 3},
  [1663] = {.lex_state = 73, .external_lex_state = 3},
  [1664] = {.lex_state = 73, .external_lex_state = 3},
  [1665] = {.lex_state = 73, .external_lex_state = 3},
  [1666] = {.lex_state = 73, .external_lex_state = 3},
  [1667] = {.lex_state = 73, .external_lex_state = 3},
  [1668] = {.lex_state = 73, .external_lex_state = 3},
  [1669] = {.lex_state = 73, .external_lex_state = 3},
  [1670] = {.lex_state = 73, .external_lex_state = 3},
  [1671] = {.lex_state = 73, .external_lex_state = 3},
  [1672] = {.lex_state = 73, .external_lex_state = 3},
  [1673] = {.lex_state = 73, .external_lex_state = 3},
  [1674] = {.lex_state = 73, .external_lex_state = 3},
  [1675] = {.lex_state = 73, .external_lex_state = 3},
  [1676] = {.lex_state = 73, .external_lex_state = 3},
  [1677] = {.lex_state = 73, .external_lex_state = 3},
  [1678] = {.lex_state = 73, .external_lex_state = 3},
  [1679] = {.lex_state = 73, .external_lex_state = 3},
  [1680] = {.lex_state = 73, .external_lex_state = 3},
  [1681] = {.lex_state = 73, .external_lex_state = 3},
  [1682] = {.lex_state = 73, .external_lex_state = 3},
  [1683] = {.lex_state = 73, .external_lex_state = 3},
  [1684] = {.lex_state = 73, .external_lex_state = 3},
  [1685] = {.lex_state = 73, .external_lex_state = 3},
  [1686] = {.lex_state = 73, .external_lex_state = 3},
  [1687] = {.lex_state = 73, .external_lex_state = 3},
  [1688] = {.lex_state = 73, .external_lex_state = 3},
  [1689] = {.lex_state = 73, .external_lex_state = 3},
  [1690] = {.lex_state = 73, .external_lex_state = 3},
  [1691] = {.lex_state = 73, .external_lex_state = 3},
  [1692] = {.lex_state = 73, .external_lex_state = 3},
  [1693] = {.lex_state = 73, .external_lex_state = 3},
  [1694] = {.lex_state = 73, .external_lex_state = 3},
  [1695] = {.lex_state = 73, .external_lex_state = 3},
  [1696] = {.lex_state = 73, .external_lex_state = 3},
  [1697] = {.lex_state = 73, .external_lex_state = 3},
  [1698] = {.lex_state = 73, .external_lex_state = 3},
  [1699] = {.lex_state = 73, .external_lex_state = 3},
  [1700] = {.lex_state = 73, .external_lex_state = 3},
  [1701] = {.lex_state = 72, .external_lex_state = 2},
  [1702] = {.lex_state = 72, .external_lex_state = 2},
  [1703] = {.lex_state = 73, .external_lex_state = 2},
  [1704] = {.lex_state = 73, .external_lex_state = 2},
  [1705] = {.lex_state = 73, .external_lex_state = 2},
  [1706] = {.lex_state = 73, .external_lex_state = 2},
  [1707] = {.lex_state = 72, .external_lex_state = 2},
  [1708] = {.lex_state = 73, .external_lex_state = 2},
  [1709] = {.lex_state = 72, .external_lex_state = 2},
  [1710] = {.lex_state = 73, .external_lex_state = 2},
  [1711] = {.lex_state = 73, .external_lex_state = 2},
  [1712] = {.lex_state = 73, .external_lex_state = 2},
  [1713] = {.lex_state = 73, .external_lex_state = 2},
  [1714] = {.lex_state = 73, .external_lex_state = 2},
  [1715] = {.lex_state = 73, .external_lex_state = 2},
  [1716] = {.lex_state = 73, .external_lex_state = 2},
  [1717] = {.lex_state = 73, .external_lex_state = 2},
  [1718] = {.lex_state = 73, .external_lex_state = 2},
  [1719] = {.lex_state = 72, .external_lex_state = 2},
  [1720] = {.lex_state = 73, .external_lex_state = 2},
  [1721] = {.lex_state = 73, .external_lex_state = 2},
  [1722] = {.lex_state = 72, .external_lex_state = 2},
  [1723] = {.lex_state = 73, .external_lex_state = 2},
  [1724] = {.lex_state = 73, .external_lex_state = 2},
  [1725] = {.lex_state = 73, .external_lex_state = 2},
  [1726] = {.lex_state = 73, .external_lex_state = 2},
  [1727] = {.lex_state = 73, .external_lex_state = 2},
  [1728] = {.lex_state = 72, .external_lex_state = 2},
  [1729] = {.lex_state = 72, .external_lex_state = 2},
  [1730] = {.lex_state = 73, .external_lex_state = 2},
  [1731] = {.lex_state = 73, .external_lex_state = 2},
  [1732] = {.lex_state = 73, .external_lex_state = 2},
  [1733] = {.lex_state = 73, .external_lex_state = 2},
  [1734] = {.lex_state = 73, .external_lex_state = 2},
  [1735] = {.lex_state = 73, .external_lex_state = 2},
  [1736] = {.lex_state = 73, .external_lex_state = 2},
  [1737] = {.lex_state = 73, .external_lex_state = 2},
  [1738] = {.lex_state = 73, .external_lex_state = 2},
  [1739] = {.lex_state = 73, .external_lex_state = 2},
  [1740] = {.lex_state = 72, .external_lex_state = 2},
  [1741] = {.lex_state = 73, .external_lex_state = 2},
  [1742] = {.lex_state = 72, .external_lex_state = 2},
  [1743] = {.lex_state = 73, .external_lex_state = 2},
  [1744] = {.lex_state = 73, .external_lex_state = 2},
  [1745] = {.lex_state = 72, .external_lex_state = 2},
  [1746] = {.lex_state = 73, .external_lex_state = 2},
  [1747] = {.lex_state = 73, .external_lex_state = 2},
  [1748] = {.lex_state = 73, .external_lex_state = 2},
  [1749] = {.lex_state = 73, .external_lex_state = 2},
  [1750] = {.lex_state = 73, .external_lex_state = 2},
  [1751] = {.lex_state = 73, .external_lex_state = 2},
  [1752] = {.lex_state = 72, .external_lex_state = 2},
  [1753] = {.lex_state = 73, .external_lex_state = 2},
  [1754] = {.lex_state = 73, .external_lex_state = 2},
  [1755] = {.lex_state = 73, .external_lex_state = 2},
  [1756] = {.lex_state = 72, .external_lex_state = 2},
  [1757] = {.lex_state = 73, .external_lex_state = 2},
  [1758] = {.lex_state = 73, .external_lex_state = 2},
  [1759] = {.lex_state = 73, .external_lex_state = 2},
  [1760] = {.lex_state = 73, .external_lex_state = 2},
  [1761] = {.lex_state = 73, .external_lex_state = 2},
  [1762] = {.lex_state = 73, .external_lex_state = 2},
  [1763] = {.lex_state = 73, .external_lex_state = 2},
  [1764] = {.lex_state = 73, .external_lex_state = 2},
  [1765] = {.lex_state = 73, .external_lex_state = 2},
  [1766] = {.lex_state = 73, .external_lex_state = 2},
  [1767] = {.lex_state = 73, .external_lex_state = 2},
  [1768] = {.lex_state = 73, .external_lex_state = 2},
  [1769] = {.lex_state = 73, .external_lex_state = 2},
  [1770] = {.lex_state = 73, .external_lex_state = 2},
  [1771] = {.lex_state = 72, .external_lex_state = 2},
  [1772] = {.lex_state = 73, .external_lex_state = 2},
  [1773] = {.lex_state = 73, .external_lex_state = 2},
  [1774] = {.lex_state = 73, .external_lex_state = 2},
  [1775] = {.lex_state = 73, .external_lex_state = 2},
  [1776] = {.lex_state = 73, .external_lex_state = 2},
  [1777] = {.lex_state = 73, .external_lex_state = 2},
  [1778] = {.lex_state = 73, .external_lex_state = 2},
  [1779] = {.lex_state = 73, .external_lex_state = 2},
  [1780] = {.lex_state = 73, .external_lex_state = 2},
  [1781] = {.lex_state = 73, .external_lex_state = 2},
  [1782] = {.lex_state = 72, .external_lex_state = 2},
  [1783] = {.lex_state = 73, .external_lex_state = 2},
  [1784] = {.lex_state = 73, .external_lex_state = 2},
  [1785] = {.lex_state = 73, .external_lex_state = 2},
  [1786] = {.lex_state = 72, .external_lex_state = 2},
  [1787] = {.lex_state = 73, .external_lex_state = 2},
  [1788] = {.lex_state = 73, .external_lex_state = 2},
  [1789] = {.lex_state = 73, .external_lex_state = 2},
  [1790] = {.lex_state = 72, .external_lex_state = 2},
  [1791] = {.lex_state = 73, .external_lex_state = 21},
  [1792] = {.lex_state = 73, .external_lex_state = 2},
  [1793] = {.lex_state = 73, .external_lex_state = 2},
  [1794] = {.lex_state = 73, .external_lex_state = 2},
  [1795] = {.lex_state = 73, .external_lex_state = 2},
  [1796] = {.lex_state = 73, .external_lex_state = 2},
  [1797] = {.lex_state = 73, .external_lex_state = 2},
  [1798] = {.lex_state = 73, .external_lex_state = 2},
  [1799] = {.lex_state = 72, .external_lex_state = 2},
  [1800] = {.lex_state = 73, .external_lex_state = 2},
  [1801] = {.lex_state = 73, .external_lex_state = 2},
  [1802] = {.lex_state = 73, .external_lex_state = 2},
  [1803] = {.lex_state = 72, .external_lex_state = 2},
  [1804] = {.lex_state = 73, .external_lex_state = 2},
  [1805] = {.lex_state = 73, .external_lex_state = 2},
  [1806] = {.lex_state = 73, .external_lex_state = 2},
  [1807] = {.lex_state = 73, .external_lex_state = 2},
  [1808] = {.lex_state = 73, .external_lex_state = 2},
  [1809] = {.lex_state = 73, .external_lex_state = 2},
  [1810] = {.lex_state = 73, .external_lex_state = 2},
  [1811] = {.lex_state = 73, .external_lex_state = 2},
  [1812] = {.lex_state = 73, .external_lex_state = 2},
  [1813] = {.lex_state = 72, .external_lex_state = 2},
  [1814] = {.lex_state = 73, .external_lex_state = 2},
  [1815] = {.lex_state = 73, .external_lex_state = 2},
  [1816] = {.lex_state = 73, .external_lex_state = 2},
  [1817] = {.lex_state = 73, .external_lex_state = 2},
  [1818] = {.lex_state = 73, .external_lex_state = 2},
  [1819] = {.lex_state = 72, .external_lex_state = 2},
  [1820] = {.lex_state = 73, .external_lex_state = 2},
  [1821] = {.lex_state = 73, .external_lex_state = 2},
  [1822] = {.lex_state = 73, .external_lex_state = 2},
  [1823] = {.lex_state = 73, .external_lex_state = 2},
  [1824] = {.lex_state = 73, .external_lex_state = 2},
  [1825] = {.lex_state = 73, .external_lex_state = 2},
  [1826] = {.lex_state = 73, .external_lex_state = 2},
  [1827] = {.lex_state = 73, .external_lex_state = 2},
  [1828] = {.lex_state = 72, .external_lex_state = 2},
  [1829] = {.lex_state = 73, .external_lex_state = 2},
  [1830] = {.lex_state = 73, .external_lex_state = 2},
  [1831] = {.lex_state = 73, .external_lex_state = 2},
  [1832] = {.lex_state = 73, .external_lex_state = 2},
  [1833] = {.lex_state = 73, .external_lex_state = 2},
  [1834] = {.lex_state = 73, .external_lex_state = 2},
  [1835] = {.lex_state = 72, .external_lex_state = 2},
  [1836] = {.lex_state = 73, .external_lex_state = 2},
  [1837] = {.lex_state = 73, .external_lex_state = 2},
  [1838] = {.lex_state = 73, .external_lex_state = 2},
  [1839] = {.lex_state = 73, .external_lex_state = 2},
  [1840] = {.lex_state = 73, .external_lex_state = 21},
  [1841] = {.lex_state = 73, .external_lex_state = 2},
  [1842] = {.lex_state = 73, .external_lex_state = 2},
  [1843] = {.lex_state = 73, .external_lex_state = 2},
  [1844] = {.lex_state = 73, .external_lex_state = 2},
  [1845] = {.lex_state = 73, .external_lex_state = 2},
  [1846] = {.lex_state = 73, .external_lex_state = 2},
  [1847] = {.lex_state = 72, .external_lex_state = 2},
  [1848] = {.lex_state = 73, .external_lex_state = 2},
  [1849] = {.lex_state = 73, .external_lex_state = 2},
  [1850] = {.lex_state = 73, .external_lex_state = 2},
  [1851] = {.lex_state = 73, .external_lex_state = 2},
  [1852] = {.lex_state = 72, .external_lex_state = 2},
  [1853] = {.lex_state = 73, .external_lex_state = 2},
  [1854] = {.lex_state = 73, .external_lex_state = 2},
  [1855] = {.lex_state = 73, .external_lex_state = 2},
  [1856] = {.lex_state = 73, .external_lex_state = 2},
  [1857] = {.lex_state = 73, .external_lex_state = 2},
  [1858] = {.lex_state = 73, .external_lex_state = 2},
  [1859] = {.lex_state = 73, .external_lex_state = 2},
  [1860] = {.lex_state = 73, .external_lex_state = 2},
  [1861] = {.lex_state = 73, .external_lex_state = 2},
  [1862] = {.lex_state = 73, .external_lex_state = 2},
  [1863] = {.lex_state = 73, .external_lex_state = 2},
  [1864] = {.lex_state = 73, .external_lex_state = 2},
  [1865] = {.lex_state = 73, .external_lex_state = 2},
  [1866] = {.lex_state = 73, .external_lex_state = 2},
  [1867] = {.lex_state = 73, .external_lex_state = 2},
  [1868] = {.lex_state = 73, .external_lex_state = 2},
  [1869] = {.lex_state = 73, .external_lex_state = 2},
  [1870] = {.lex_state = 73, .external_lex_state = 2},
  [1871] = {.lex_state = 73, .external_lex_state = 2},
  [1872] = {.lex_state = 73, .external_lex_state = 2},
  [1873] = {.lex_state = 73, .external_lex_state = 2},
  [1874] = {.lex_state = 73, .external_lex_state = 2},
  [1875] = {.lex_state = 73, .external_lex_state = 2},
  [1876] = {.lex_state = 73, .external_lex_state = 2},
  [1877] = {.lex_state = 73, .external_lex_state = 2},
  [1878] = {.lex_state = 73, .external_lex_state = 2},
  [1879] = {.lex_state = 73, .external_lex_state = 2},
  [1880] = {.lex_state = 73, .external_lex_state = 2},
  [1881] = {.lex_state = 73, .external_lex_state = 2},
  [1882] = {.lex_state = 73, .external_lex_state = 2},
  [1883] = {.lex_state = 73, .external_lex_state = 2},
  [1884] = {.lex_state = 73, .external_lex_state = 2},
  [1885] = {.lex_state = 73, .external_lex_state = 2},
  [1886] = {.lex_state = 73, .external_lex_state = 2},
  [1887] = {.lex_state = 73, .external_lex_state = 2},
  [1888] = {.lex_state = 73, .external_lex_state = 2},
  [1889] = {.lex_state = 73, .external_lex_state = 2},
  [1890] = {.lex_state = 73, .external_lex_state = 2},
  [1891] = {.lex_state = 73, .external_lex_state = 2},
  [1892] = {.lex_state = 73, .external_lex_state = 2},
  [1893] = {.lex_state = 73, .external_lex_state = 2},
  [1894] = {.lex_state = 73, .external_lex_state = 2},
  [1895] = {.lex_state = 73, .external_lex_state = 2},
  [1896] = {.lex_state = 73, .external_lex_state = 2},
  [1897] = {.lex_state = 73, .external_lex_state = 2},
  [1898] = {.lex_state = 73, .external_lex_state = 2},
  [1899] = {.lex_state = 73, .external_lex_state = 2},
  [1900] = {.lex_state = 73, .external_lex_state = 2},
  [1901] = {.lex_state = 73, .external_lex_state = 2},
  [1902] = {.lex_state = 73, .external_lex_state = 2},
  [1903] = {.lex_state = 73, .external_lex_state = 2},
  [1904] = {.lex_state = 73, .external_lex_state = 2},
  [1905] = {.lex_state = 73, .external_lex_state = 2},
  [1906] = {.lex_state = 73, .external_lex_state = 2},
  [1907] = {.lex_state = 73, .external_lex_state = 2},
  [1908] = {.lex_state = 73, .external_lex_state = 2},
  [1909] = {.lex_state = 73, .external_lex_state = 2},
  [1910] = {.lex_state = 73, .external_lex_state = 2},
  [1911] = {.lex_state = 73, .external_lex_state = 2},
  [1912] = {.lex_state = 73, .external_lex_state = 2},
  [1913] = {.lex_state = 73, .external_lex_state = 2},
  [1914] = {.lex_state = 73, .external_lex_state = 2},
  [1915] = {.lex_state = 73, .external_lex_state = 2},
  [1916] = {.lex_state = 73, .external_lex_state = 2},
  [1917] = {.lex_state = 73, .external_lex_state = 2},
  [1918] = {.lex_state = 73, .external_lex_state = 2},
  [1919] = {.lex_state = 73, .external_lex_state = 2},
  [1920] = {.lex_state = 73, .external_lex_state = 2},
  [1921] = {.lex_state = 73, .external_lex_state = 2},
  [1922] = {.lex_state = 73, .external_lex_state = 2},
  [1923] = {.lex_state = 73, .external_lex_state = 2},
  [1924] = {.lex_state = 73, .external_lex_state = 2},
  [1925] = {.lex_state = 73, .external_lex_state = 2},
  [1926] = {.lex_state = 73, .external_lex_state = 2},
  [1927] = {.lex_state = 73, .external_lex_state = 2},
  [1928] = {.lex_state = 73, .external_lex_state = 2},
  [1929] = {.lex_state = 73, .external_lex_state = 2},
  [1930] = {.lex_state = 73, .external_lex_state = 2},
  [1931] = {.lex_state = 73, .external_lex_state = 2},
  [1932] = {.lex_state = 73, .external_lex_state = 2},
  [1933] = {.lex_state = 73, .external_lex_state = 2},
  [1934] = {.lex_state = 73, .external_lex_state = 2},
  [1935] = {.lex_state = 73, .external_lex_state = 2},
  [1936] = {.lex_state = 73, .external_lex_state = 2},
  [1937] = {.lex_state = 73, .external_lex_state = 2},
  [1938] = {.lex_state = 73, .external_lex_state = 2},
  [1939] = {.lex_state = 73, .external_lex_state = 2},
  [1940] = {.lex_state = 73, .external_lex_state = 2},
  [1941] = {.lex_state = 73, .external_lex_state = 2},
  [1942] = {.lex_state = 73, .external_lex_state = 2},
  [1943] = {.lex_state = 73, .external_lex_state = 2},
  [1944] = {.lex_state = 73, .external_lex_state = 2},
  [1945] = {.lex_state = 73, .external_lex_state = 2},
  [1946] = {.lex_state = 73, .external_lex_state = 2},
  [1947] = {.lex_state = 73, .external_lex_state = 2},
  [1948] = {.lex_state = 73, .external_lex_state = 2},
  [1949] = {.lex_state = 73, .external_lex_state = 2},
  [1950] = {.lex_state = 73, .external_lex_state = 2},
  [1951] = {.lex_state = 73, .external_lex_state = 2},
  [1952] = {.lex_state = 73, .external_lex_state = 2},
  [1953] = {.lex_state = 73, .external_lex_state = 2},
  [1954] = {.lex_state = 73, .external_lex_state = 2},
  [1955] = {.lex_state = 73, .external_lex_state = 2},
  [1956] = {.lex_state = 73, .external_lex_state = 2},
  [1957] = {.lex_state = 73, .external_lex_state = 2},
  [1958] = {.lex_state = 73, .external_lex_state = 2},
  [1959] = {.lex_state = 73, .external_lex_state = 2},
  [1960] = {.lex_state = 73, .external_lex_state = 2},
  [1961] = {.lex_state = 73, .external_lex_state = 2},
  [1962] = {.lex_state = 73, .external_lex_state = 2},
  [1963] = {.lex_state = 73, .external_lex_state = 2},
  [1964] = {.lex_state = 73, .external_lex_state = 2},
  [1965] = {.lex_state = 73, .external_lex_state = 2},
  [1966] = {.lex_state = 73, .external_lex_state = 2},
  [1967] = {.lex_state = 73, .external_lex_state = 2},
  [1968] = {.lex_state = 73, .external_lex_state = 2},
  [1969] = {.lex_state = 73, .external_lex_state = 2},
  [1970] = {.lex_state = 73, .external_lex_state = 2},
  [1971] = {.lex_state = 73, .external_lex_state = 2},
  [1972] = {.lex_state = 73, .external_lex_state = 2},
  [1973] = {.lex_state = 73, .external_lex_state = 2},
  [1974] = {.lex_state = 73, .external_lex_state = 2},
  [1975] = {.lex_state = 73, .external_lex_state = 2},
  [1976] = {.lex_state = 73, .external_lex_state = 2},
  [1977] = {.lex_state = 73, .external_lex_state = 2},
  [1978] = {.lex_state = 73, .external_lex_state = 2},
  [1979] = {.lex_state = 73, .external_lex_state = 2},
  [1980] = {.lex_state = 73, .external_lex_state = 2},
  [1981] = {.lex_state = 73, .external_lex_state = 2},
  [1982] = {.lex_state = 73, .external_lex_state = 2},
  [1983] = {.lex_state = 73, .external_lex_state = 2},
  [1984] = {.lex_state = 73, .external_lex_state = 2},
  [1985] = {.lex_state = 73, .external_lex_state = 2},
  [1986] = {.lex_state = 73, .external_lex_state = 2},
  [1987] = {.lex_state = 73, .external_lex_state = 2},
  [1988] = {.lex_state = 73, .external_lex_state = 2},
  [1989] = {.lex_state = 73, .external_lex_state = 2},
  [1990] = {.lex_state = 73, .external_lex_state = 2},
  [1991] = {.lex_state = 73, .external_lex_state = 2},
  [1992] = {.lex_state = 73, .external_lex_state = 2},
  [1993] = {.lex_state = 73, .external_lex_state = 2},
  [1994] = {.lex_state = 73, .external_lex_state = 2},
  [1995] = {.lex_state = 73, .external_lex_state = 2},
  [1996] = {.lex_state = 73, .external_lex_state = 2},
  [1997] = {.lex_state = 73, .external_lex_state = 2},
  [1998] = {.lex_state = 73, .external_lex_state = 2},
  [1999] = {.lex_state = 73, .external_lex_state = 2},
  [2000] = {.lex_state = 73, .external_lex_state = 2},
  [2001] = {.lex_state = 73, .external_lex_state = 2},
  [2002] = {.lex_state = 73, .external_lex_state = 2},
  [2003] = {.lex_state = 73, .external_lex_state = 2},
  [2004] = {.lex_state = 73, .external_lex_state = 2},
  [2005] = {.lex_state = 73, .external_lex_state = 2},
  [2006] = {.lex_state = 73, .external_lex_state = 2},
  [2007] = {.lex_state = 73, .external_lex_state = 2},
  [2008] = {.lex_state = 73, .external_lex_state = 2},
  [2009] = {.lex_state = 73, .external_lex_state = 2},
  [2010] = {.lex_state = 73, .external_lex_state = 2},
  [2011] = {.lex_state = 73, .external_lex_state = 2},
  [2012] = {.lex_state = 73, .external_lex_state = 2},
  [2013] = {.lex_state = 73, .external_lex_state = 2},
  [2014] = {.lex_state = 73, .external_lex_state = 2},
  [2015] = {.lex_state = 73, .external_lex_state = 2},
  [2016] = {.lex_state = 73, .external_lex_state = 2},
  [2017] = {.lex_state = 73, .external_lex_state = 2},
  [2018] = {.lex_state = 73, .external_lex_state = 2},
  [2019] = {.lex_state = 73, .external_lex_state = 2},
  [2020] = {.lex_state = 73, .external_lex_state = 2},
  [2021] = {.lex_state = 73, .external_lex_state = 2},
  [2022] = {.lex_state = 73, .external_lex_state = 2},
  [2023] = {.lex_state = 73, .external_lex_state = 2},
  [2024] = {.lex_state = 73, .external_lex_state = 2},
  [2025] = {.lex_state = 73, .external_lex_state = 2},
  [2026] = {.lex_state = 73, .external_lex_state = 2},
  [2027] = {.lex_state = 73, .external_lex_state = 2},
  [2028] = {.lex_state = 73, .external_lex_state = 2},
  [2029] = {.lex_state = 73, .external_lex_state = 2},
  [2030] = {.lex_state = 73, .external_lex_state = 2},
  [2031] = {.lex_state = 73, .external_lex_state = 2},
  [2032] = {.lex_state = 73, .external_lex_state = 2},
  [2033] = {.lex_state = 73, .external_lex_state = 2},
  [2034] = {.lex_state = 73, .external_lex_state = 2},
  [2035] = {.lex_state = 73, .external_lex_state = 2},
  [2036] = {.lex_state = 73, .external_lex_state = 2},
  [2037] = {.lex_state = 73, .external_lex_state = 2},
  [2038] = {.lex_state = 73, .external_lex_state = 2},
  [2039] = {.lex_state = 73, .external_lex_state = 2},
  [2040] = {.lex_state = 73, .external_lex_state = 2},
  [2041] = {.lex_state = 73, .external_lex_state = 2},
  [2042] = {.lex_state = 73, .external_lex_state = 2},
  [2043] = {.lex_state = 73, .external_lex_state = 2},
  [2044] = {.lex_state = 73, .external_lex_state = 2},
  [2045] = {.lex_state = 73, .external_lex_state = 2},
  [2046] = {.lex_state = 73, .external_lex_state = 2},
  [2047] = {.lex_state = 73, .external_lex_state = 2},
  [2048] = {.lex_state = 73, .external_lex_state = 2},
  [2049] = {.lex_state = 73, .external_lex_state = 2},
  [2050] = {.lex_state = 73, .external_lex_state = 2},
  [2051] = {.lex_state = 73, .external_lex_state = 2},
  [2052] = {.lex_state = 73, .external_lex_state = 2},
  [2053] = {.lex_state = 73, .external_lex_state = 2},
  [2054] = {.lex_state = 73, .external_lex_state = 2},
  [2055] = {.lex_state = 73, .external_lex_state = 2},
  [2056] = {.lex_state = 73, .external_lex_state = 2},
  [2057] = {.lex_state = 73, .external_lex_state = 2},
  [2058] = {.lex_state = 73, .external_lex_state = 2},
  [2059] = {.lex_state = 73, .external_lex_state = 2},
  [2060] = {.lex_state = 73, .external_lex_state = 2},
  [2061] = {.lex_state = 73, .external_lex_state = 2},
  [2062] = {.lex_state = 73, .external_lex_state = 2},
  [2063] = {.lex_state = 73, .external_lex_state = 2},
  [2064] = {.lex_state = 73, .external_lex_state = 2},
  [2065] = {.lex_state = 73, .external_lex_state = 2},
  [2066] = {.lex_state = 73, .external_lex_state = 2},
  [2067] = {.lex_state = 73, .external_lex_state = 2},
  [2068] = {.lex_state = 73, .external_lex_state = 2},
  [2069] = {.lex_state = 73, .external_lex_state = 2},
  [2070] = {.lex_state = 73, .external_lex_state = 2},
  [2071] = {.lex_state = 73, .external_lex_state = 2},
  [2072] = {.lex_state = 73, .external_lex_state = 2},
  [2073] = {.lex_state = 73, .external_lex_state = 2},
  [2074] = {.lex_state = 73, .external_lex_state = 2},
  [2075] = {.lex_state = 73, .external_lex_state = 2},
  [2076] = {.lex_state = 73, .external_lex_state = 2},
  [2077] = {.lex_state = 73, .external_lex_state = 2},
  [2078] = {.lex_state = 73, .external_lex_state = 2},
  [2079] = {.lex_state = 73, .external_lex_state = 2},
  [2080] = {.lex_state = 73, .external_lex_state = 2},
  [2081] = {.lex_state = 73, .external_lex_state = 2},
  [2082] = {.lex_state = 73, .external_lex_state = 2},
  [2083] = {.lex_state = 73, .external_lex_state = 2},
  [2084] = {.lex_state = 73, .external_lex_state = 2},
  [2085] = {.lex_state = 73, .external_lex_state = 2},
  [2086] = {.lex_state = 73, .external_lex_state = 2},
  [2087] = {.lex_state = 73, .external_lex_state = 2},
  [2088] = {.lex_state = 73, .external_lex_state = 2},
  [2089] = {.lex_state = 73, .external_lex_state = 2},
  [2090] = {.lex_state = 73, .external_lex_state = 2},
  [2091] = {.lex_state = 73, .external_lex_state = 2},
  [2092] = {.lex_state = 73, .external_lex_state = 2},
  [2093] = {.lex_state = 73, .external_lex_state = 2},
  [2094] = {.lex_state = 73, .external_lex_state = 2},
  [2095] = {.lex_state = 73, .external_lex_state = 2},
  [2096] = {.lex_state = 73, .external_lex_state = 2},
  [2097] = {.lex_state = 73, .external_lex_state = 2},
  [2098] = {.lex_state = 73, .external_lex_state = 2},
  [2099] = {.lex_state = 73, .external_lex_state = 2},
  [2100] = {.lex_state = 73, .external_lex_state = 2},
  [2101] = {.lex_state = 73, .external_lex_state = 2},
  [2102] = {.lex_state = 73, .external_lex_state = 2},
  [2103] = {.lex_state = 73, .external_lex_state = 2},
  [2104] = {.lex_state = 73, .external_lex_state = 2},
  [2105] = {.lex_state = 73, .external_lex_state = 2},
  [2106] = {.lex_state = 73, .external_lex_state = 2},
  [2107] = {.lex_state = 73, .external_lex_state = 2},
  [2108] = {.lex_state = 73, .external_lex_state = 2},
  [2109] = {.lex_state = 73, .external_lex_state = 2},
  [2110] = {.lex_state = 73, .external_lex_state = 2},
  [2111] = {.lex_state = 73, .external_lex_state = 2},
  [2112] = {.lex_state = 73, .external_lex_state = 2},
  [2113] = {.lex_state = 73, .external_lex_state = 2},
  [2114] = {.lex_state = 73, .external_lex_state = 2},
  [2115] = {.lex_state = 73, .external_lex_state = 2},
  [2116] = {.lex_state = 73, .external_lex_state = 2},
  [2117] = {.lex_state = 73, .external_lex_state = 2},
  [2118] = {.lex_state = 73, .external_lex_state = 2},
  [2119] = {.lex_state = 73, .external_lex_state = 2},
  [2120] = {.lex_state = 73, .external_lex_state = 2},
  [2121] = {.lex_state = 73, .external_lex_state = 2},
  [2122] = {.lex_state = 73, .external_lex_state = 2},
  [2123] = {.lex_state = 73, .external_lex_state = 2},
  [2124] = {.lex_state = 73, .external_lex_state = 2},
  [2125] = {.lex_state = 73, .external_lex_state = 2},
  [2126] = {.lex_state = 73, .external_lex_state = 2},
  [2127] = {.lex_state = 73, .external_lex_state = 2},
  [2128] = {.lex_state = 73, .external_lex_state = 2},
  [2129] = {.lex_state = 73, .external_lex_state = 2},
  [2130] = {.lex_state = 73, .external_lex_state = 2},
  [2131] = {.lex_state = 73, .external_lex_state = 2},
  [2132] = {.lex_state = 73, .external_lex_state = 2},
  [2133] = {.lex_state = 73, .external_lex_state = 2},
  [2134] = {.lex_state = 73, .external_lex_state = 2},
  [2135] = {.lex_state = 73, .external_lex_state = 2},
  [2136] = {.lex_state = 73, .external_lex_state = 2},
  [2137] = {.lex_state = 73, .external_lex_state = 2},
  [2138] = {.lex_state = 73, .external_lex_state = 2},
  [2139] = {.lex_state = 73, .external_lex_state = 2},
  [2140] = {.lex_state = 73, .external_lex_state = 2},
  [2141] = {.lex_state = 73, .external_lex_state = 2},
  [2142] = {.lex_state = 73, .external_lex_state = 2},
  [2143] = {.lex_state = 73, .external_lex_state = 2},
  [2144] = {.lex_state = 73, .external_lex_state = 2},
  [2145] = {.lex_state = 73, .external_lex_state = 2},
  [2146] = {.lex_state = 73, .external_lex_state = 2},
  [2147] = {.lex_state = 73, .external_lex_state = 2},
  [2148] = {.lex_state = 73, .external_lex_state = 2},
  [2149] = {.lex_state = 73, .external_lex_state = 2},
  [2150] = {.lex_state = 73, .external_lex_state = 2},
  [2151] = {.lex_state = 73, .external_lex_state = 2},
  [2152] = {.lex_state = 73, .external_lex_state = 2},
  [2153] = {.lex_state = 73, .external_lex_state = 2},
  [2154] = {.lex_state = 73, .external_lex_state = 2},
  [2155] = {.lex_state = 73, .external_lex_state = 2},
  [2156] = {.lex_state = 73, .external_lex_state = 2},
  [2157] = {.lex_state = 73, .external_lex_state = 2},
  [2158] = {.lex_state = 73, .external_lex_state = 2},
  [2159] = {.lex_state = 73, .external_lex_state = 2},
  [2160] = {.lex_state = 73, .external_lex_state = 2},
  [2161] = {.lex_state = 73, .external_lex_state = 2},
  [2162] = {.lex_state = 73, .external_lex_state = 2},
  [2163] = {.lex_state = 73, .external_lex_state = 2},
  [2164] = {.lex_state = 73, .external_lex_state = 2},
  [2165] = {.lex_state = 73, .external_lex_state = 2},
  [2166] = {.lex_state = 73, .external_lex_state = 2},
  [2167] = {.lex_state = 73, .external_lex_state = 2},
  [2168] = {.lex_state = 73, .external_lex_state = 2},
  [2169] = {.lex_state = 73, .external_lex_state = 2},
  [2170] = {.lex_state = 73, .external_lex_state = 2},
  [2171] = {.lex_state = 73, .external_lex_state = 2},
  [2172] = {.lex_state = 73, .external_lex_state = 2},
  [2173] = {.lex_state = 73, .external_lex_state = 2},
  [2174] = {.lex_state = 73, .external_lex_state = 2},
  [2175] = {.lex_state = 73, .external_lex_state = 2},
  [2176] = {.lex_state = 73, .external_lex_state = 2},
  [2177] = {.lex_state = 73, .external_lex_state = 2},
  [2178] = {.lex_state = 73, .external_lex_state = 2},
  [2179] = {.lex_state = 73, .external_lex_state = 2},
  [2180] = {.lex_state = 73, .external_lex_state = 2},
  [2181] = {.lex_state = 73, .external_lex_state = 2},
  [2182] = {.lex_state = 73, .external_lex_state = 2},
  [2183] = {.lex_state = 73, .external_lex_state = 2},
  [2184] = {.lex_state = 73, .external_lex_state = 2},
  [2185] = {.lex_state = 73, .external_lex_state = 2},
  [2186] = {.lex_state = 73, .external_lex_state = 2},
  [2187] = {.lex_state = 73, .external_lex_state = 2},
  [2188] = {.lex_state = 73, .external_lex_state = 2},
  [2189] = {.lex_state = 73, .external_lex_state = 2},
  [2190] = {.lex_state = 73, .external_lex_state = 2},
  [2191] = {.lex_state = 73, .external_lex_state = 2},
  [2192] = {.lex_state = 73, .external_lex_state = 2},
  [2193] = {.lex_state = 73, .external_lex_state = 2},
  [2194] = {.lex_state = 73, .external_lex_state = 2},
  [2195] = {.lex_state = 73, .external_lex_state = 2},
  [2196] = {.lex_state = 73, .external_lex_state = 2},
  [2197] = {.lex_state = 73, .external_lex_state = 2},
  [2198] = {.lex_state = 73, .external_lex_state = 2},
  [2199] = {.lex_state = 73, .external_lex_state = 2},
  [2200] = {.lex_state = 73, .external_lex_state = 2},
  [2201] = {.lex_state = 73, .external_lex_state = 2},
  [2202] = {.lex_state = 73, .external_lex_state = 2},
  [2203] = {.lex_state = 73, .external_lex_state = 2},
  [2204] = {.lex_state = 73, .external_lex_state = 2},
  [2205] = {.lex_state = 73, .external_lex_state = 2},
  [2206] = {.lex_state = 73, .external_lex_state = 2},
  [2207] = {.lex_state = 73, .external_lex_state = 2},
  [2208] = {.lex_state = 73, .external_lex_state = 2},
  [2209] = {.lex_state = 73, .external_lex_state = 2},
  [2210] = {.lex_state = 73, .external_lex_state = 2},
  [2211] = {.lex_state = 73, .external_lex_state = 2},
  [2212] = {.lex_state = 73, .external_lex_state = 2},
  [2213] = {.lex_state = 73, .external_lex_state = 2},
  [2214] = {.lex_state = 73, .external_lex_state = 2},
  [2215] = {.lex_state = 73, .external_lex_state = 2},
  [2216] = {.lex_state = 73, .external_lex_state = 2},
  [2217] = {.lex_state = 73, .external_lex_state = 2},
  [2218] = {.lex_state = 73, .external_lex_state = 2},
  [2219] = {.lex_state = 73, .external_lex_state = 2},
  [2220] = {.lex_state = 73, .external_lex_state = 2},
  [2221] = {.lex_state = 73, .external_lex_state = 2},
  [2222] = {.lex_state = 73, .external_lex_state = 2},
  [2223] = {.lex_state = 73, .external_lex_state = 2},
  [2224] = {.lex_state = 73, .external_lex_state = 2},
  [2225] = {.lex_state = 73, .external_lex_state = 2},
  [2226] = {.lex_state = 73, .external_lex_state = 2},
  [2227] = {.lex_state = 73, .external_lex_state = 2},
  [2228] = {.lex_state = 73, .external_lex_state = 2},
  [2229] = {.lex_state = 73, .external_lex_state = 2},
  [2230] = {.lex_state = 73, .external_lex_state = 2},
  [2231] = {.lex_state = 73, .external_lex_state = 2},
  [2232] = {.lex_state = 73, .external_lex_state = 2},
  [2233] = {.lex_state = 73, .external_lex_state = 2},
  [2234] = {.lex_state = 73, .external_lex_state = 2},
  [2235] = {.lex_state = 73, .external_lex_state = 2},
  [2236] = {.lex_state = 73, .external_lex_state = 2},
  [2237] = {.lex_state = 73, .external_lex_state = 2},
  [2238] = {.lex_state = 73, .external_lex_state = 2},
  [2239] = {.lex_state = 73, .external_lex_state = 2},
  [2240] = {.lex_state = 73, .external_lex_state = 2},
  [2241] = {.lex_state = 73, .external_lex_state = 2},
  [2242] = {.lex_state = 73, .external_lex_state = 2},
  [2243] = {.lex_state = 73, .external_lex_state = 2},
  [2244] = {.lex_state = 73, .external_lex_state = 2},
  [2245] = {.lex_state = 73, .external_lex_state = 2},
  [2246] = {.lex_state = 73, .external_lex_state = 2},
  [2247] = {.lex_state = 73, .external_lex_state = 2},
  [2248] = {.lex_state = 73, .external_lex_state = 2},
  [2249] = {.lex_state = 73, .external_lex_state = 2},
  [2250] = {.lex_state = 73, .external_lex_state = 2},
  [2251] = {.lex_state = 73, .external_lex_state = 2},
  [2252] = {.lex_state = 73, .external_lex_state = 2},
  [2253] = {.lex_state = 73, .external_lex_state = 2},
  [2254] = {.lex_state = 73, .external_lex_state = 2},
  [2255] = {.lex_state = 73, .external_lex_state = 2},
  [2256] = {.lex_state = 73, .external_lex_state = 2},
  [2257] = {.lex_state = 73, .external_lex_state = 2},
  [2258] = {.lex_state = 73, .external_lex_state = 2},
  [2259] = {.lex_state = 73, .external_lex_state = 2},
  [2260] = {.lex_state = 73, .external_lex_state = 2},
  [2261] = {.lex_state = 73, .external_lex_state = 2},
  [2262] = {.lex_state = 73, .external_lex_state = 2},
  [2263] = {.lex_state = 73, .external_lex_state = 2},
  [2264] = {.lex_state = 73, .external_lex_state = 2},
  [2265] = {.lex_state = 73, .external_lex_state = 2},
  [2266] = {.lex_state = 73, .external_lex_state = 2},
  [2267] = {.lex_state = 73, .external_lex_state = 2},
  [2268] = {.lex_state = 73, .external_lex_state = 2},
  [2269] = {.lex_state = 73, .external_lex_state = 2},
  [2270] = {.lex_state = 73, .external_lex_state = 2},
  [2271] = {.lex_state = 73, .external_lex_state = 2},
  [2272] = {.lex_state = 73, .external_lex_state = 2},
  [2273] = {.lex_state = 73, .external_lex_state = 2},
  [2274] = {.lex_state = 73, .external_lex_state = 2},
  [2275] = {.lex_state = 73, .external_lex_state = 2},
  [2276] = {.lex_state = 73, .external_lex_state = 2},
  [2277] = {.lex_state = 73, .external_lex_state = 2},
  [2278] = {.lex_state = 73, .external_lex_state = 2},
  [2279] = {.lex_state = 73, .external_lex_state = 2},
  [2280] = {.lex_state = 73, .external_lex_state = 2},
  [2281] = {.lex_state = 73, .external_lex_state = 2},
  [2282] = {.lex_state = 73, .external_lex_state = 2},
  [2283] = {.lex_state = 73, .external_lex_state = 2},
  [2284] = {.lex_state = 73, .external_lex_state = 2},
  [2285] = {.lex_state = 73, .external_lex_state = 2},
  [2286] = {.lex_state = 73, .external_lex_state = 2},
  [2287] = {.lex_state = 73, .external_lex_state = 2},
  [2288] = {.lex_state = 73, .external_lex_state = 2},
  [2289] = {.lex_state = 73, .external_lex_state = 2},
  [2290] = {.lex_state = 73, .external_lex_state = 2},
  [2291] = {.lex_state = 73, .external_lex_state = 2},
  [2292] = {.lex_state = 73, .external_lex_state = 2},
  [2293] = {.lex_state = 73, .external_lex_state = 2},
  [2294] = {.lex_state = 73, .external_lex_state = 2},
  [2295] = {.lex_state = 73, .external_lex_state = 2},
  [2296] = {.lex_state = 73, .external_lex_state = 2},
  [2297] = {.lex_state = 73, .external_lex_state = 2},
  [2298] = {.lex_state = 73, .external_lex_state = 2},
  [2299] = {.lex_state = 73, .external_lex_state = 2},
  [2300] = {.lex_state = 73, .external_lex_state = 2},
  [2301] = {.lex_state = 73, .external_lex_state = 2},
  [2302] = {.lex_state = 73, .external_lex_state = 2},
  [2303] = {.lex_state = 73, .external_lex_state = 2},
  [2304] = {.lex_state = 73, .external_lex_state = 2},
  [2305] = {.lex_state = 73, .external_lex_state = 2},
  [2306] = {.lex_state = 73, .external_lex_state = 2},
  [2307] = {.lex_state = 73, .external_lex_state = 2},
  [2308] = {.lex_state = 73, .external_lex_state = 2},
  [2309] = {.lex_state = 73, .external_lex_state = 2},
  [2310] = {.lex_state = 73, .external_lex_state = 2},
  [2311] = {.lex_state = 73, .external_lex_state = 2},
  [2312] = {.lex_state = 73, .external_lex_state = 2},
  [2313] = {.lex_state = 73, .external_lex_state = 2},
  [2314] = {.lex_state = 73, .external_lex_state = 2},
  [2315] = {.lex_state = 73, .external_lex_state = 2},
  [2316] = {.lex_state = 73, .external_lex_state = 2},
  [2317] = {.lex_state = 73, .external_lex_state = 2},
  [2318] = {.lex_state = 73, .external_lex_state = 2},
  [2319] = {.lex_state = 73, .external_lex_state = 2},
  [2320] = {.lex_state = 73, .external_lex_state = 2},
  [2321] = {.lex_state = 73, .external_lex_state = 2},
  [2322] = {.lex_state = 73, .external_lex_state = 2},
  [2323] = {.lex_state = 73, .external_lex_state = 2},
  [2324] = {.lex_state = 73, .external_lex_state = 2},
  [2325] = {.lex_state = 73, .external_lex_state = 2},
  [2326] = {.lex_state = 73, .external_lex_state = 2},
  [2327] = {.lex_state = 73, .external_lex_state = 2},
  [2328] = {.lex_state = 73, .external_lex_state = 2},
  [2329] = {.lex_state = 73, .external_lex_state = 2},
  [2330] = {.lex_state = 73, .external_lex_state = 2},
  [2331] = {.lex_state = 73, .external_lex_state = 2},
  [2332] = {.lex_state = 73, .external_lex_state = 2},
  [2333] = {.lex_state = 73, .external_lex_state = 2},
  [2334] = {.lex_state = 73, .external_lex_state = 2},
  [2335] = {.lex_state = 73, .external_lex_state = 2},
  [2336] = {.lex_state = 73, .external_lex_state = 2},
  [2337] = {.lex_state = 73, .external_lex_state = 2},
  [2338] = {.lex_state = 73, .external_lex_state = 2},
  [2339] = {.lex_state = 73, .external_lex_state = 2},
  [2340] = {.lex_state = 73, .external_lex_state = 2},
  [2341] = {.lex_state = 73, .external_lex_state = 2},
  [2342] = {.lex_state = 73, .external_lex_state = 2},
  [2343] = {.lex_state = 73, .external_lex_state = 2},
  [2344] = {.lex_state = 73, .external_lex_state = 2},
  [2345] = {.lex_state = 73, .external_lex_state = 2},
  [2346] = {.lex_state = 73, .external_lex_state = 2},
  [2347] = {.lex_state = 73, .external_lex_state = 2},
  [2348] = {.lex_state = 73, .external_lex_state = 2},
  [2349] = {.lex_state = 73, .external_lex_state = 2},
  [2350] = {.lex_state = 73, .external_lex_state = 2},
  [2351] = {.lex_state = 73, .external_lex_state = 2},
  [2352] = {.lex_state = 73, .external_lex_state = 2},
  [2353] = {.lex_state = 73, .external_lex_state = 2},
  [2354] = {.lex_state = 73, .external_lex_state = 2},
  [2355] = {.lex_state = 73, .external_lex_state = 2},
  [2356] = {.lex_state = 73, .external_lex_state = 2},
  [2357] = {.lex_state = 73, .external_lex_state = 2},
  [2358] = {.lex_state = 73, .external_lex_state = 2},
  [2359] = {.lex_state = 73, .external_lex_state = 2},
  [2360] = {.lex_state = 73, .external_lex_state = 2},
  [2361] = {.lex_state = 73, .external_lex_state = 2},
  [2362] = {.lex_state = 73, .external_lex_state = 2},
  [2363] = {.lex_state = 73, .external_lex_state = 2},
  [2364] = {.lex_state = 73, .external_lex_state = 2},
  [2365] = {.lex_state = 73, .external_lex_state = 2},
  [2366] = {.lex_state = 73, .external_lex_state = 2},
  [2367] = {.lex_state = 73, .external_lex_state = 2},
  [2368] = {.lex_state = 73, .external_lex_state = 2},
  [2369] = {.lex_state = 73, .external_lex_state = 2},
  [2370] = {.lex_state = 73, .external_lex_state = 2},
  [2371] = {.lex_state = 73, .external_lex_state = 2},
  [2372] = {.lex_state = 73, .external_lex_state = 2},
  [2373] = {.lex_state = 73, .external_lex_state = 2},
  [2374] = {.lex_state = 73, .external_lex_state = 2},
  [2375] = {.lex_state = 73, .external_lex_state = 2},
  [2376] = {.lex_state = 73, .external_lex_state = 2},
  [2377] = {.lex_state = 73, .external_lex_state = 2},
  [2378] = {.lex_state = 73, .external_lex_state = 2},
  [2379] = {.lex_state = 73, .external_lex_state = 2},
  [2380] = {.lex_state = 73, .external_lex_state = 2},
  [2381] = {.lex_state = 73, .external_lex_state = 2},
  [2382] = {.lex_state = 73, .external_lex_state = 2},
  [2383] = {.lex_state = 73, .external_lex_state = 2},
  [2384] = {.lex_state = 73, .external_lex_state = 2},
  [2385] = {.lex_state = 73, .external_lex_state = 2},
  [2386] = {.lex_state = 73, .external_lex_state = 2},
  [2387] = {.lex_state = 73, .external_lex_state = 2},
  [2388] = {.lex_state = 73, .external_lex_state = 2},
  [2389] = {.lex_state = 73, .external_lex_state = 2},
  [2390] = {.lex_state = 73, .external_lex_state = 2},
  [2391] = {.lex_state = 73, .external_lex_state = 2},
  [2392] = {.lex_state = 73, .external_lex_state = 2},
  [2393] = {.lex_state = 73, .external_lex_state = 2},
  [2394] = {.lex_state = 73, .external_lex_state = 2},
  [2395] = {.lex_state = 73, .external_lex_state = 2},
  [2396] = {.lex_state = 73, .external_lex_state = 2},
  [2397] = {.lex_state = 73, .external_lex_state = 2},
  [2398] = {.lex_state = 73, .external_lex_state = 2},
  [2399] = {.lex_state = 73, .external_lex_state = 2},
  [2400] = {.lex_state = 73, .external_lex_state = 2},
  [2401] = {.lex_state = 73, .external_lex_state = 2},
  [2402] = {.lex_state = 73, .external_lex_state = 2},
  [2403] = {.lex_state = 73, .external_lex_state = 2},
  [2404] = {.lex_state = 73, .external_lex_state = 2},
  [2405] = {.lex_state = 73, .external_lex_state = 2},
  [2406] = {.lex_state = 73, .external_lex_state = 2},
  [2407] = {.lex_state = 73, .external_lex_state = 2},
  [2408] = {.lex_state = 73, .external_lex_state = 2},
  [2409] = {.lex_state = 73, .external_lex_state = 2},
  [2410] = {.lex_state = 73, .external_lex_state = 2},
  [2411] = {.lex_state = 73, .external_lex_state = 2},
  [2412] = {.lex_state = 70, .external_lex_state = 19},
  [2413] = {.lex_state = 70, .external_lex_state = 22},
  [2414] = {.lex_state = 70, .external_lex_state = 19},
  [2415] = {.lex_state = 84, .external_lex_state = 3},
  [2416] = {.lex_state = 84, .external_lex_state = 3},
  [2417] = {.lex_state = 84, .external_lex_state = 3},
  [2418] = {.lex_state = 84, .external_lex_state = 3},
  [2419] = {.lex_state = 84, .external_lex_state = 3},
  [2420] = {.lex_state = 84, .external_lex_state = 3},
  [2421] = {.lex_state = 84, .external_lex_state = 3},
  [2422] = {.lex_state = 84, .external_lex_state = 3},
  [2423] = {.lex_state = 84, .external_lex_state = 3},
  [2424] = {.lex_state = 84, .external_lex_state = 3},
  [2425] = {.lex_state = 84, .external_lex_state = 3},
  [2426] = {.lex_state = 84, .external_lex_state = 3},
  [2427] = {.lex_state = 84, .external_lex_state = 3},
  [2428] = {.lex_state = 84, .external_lex_state = 3},
  [2429] = {.lex_state = 84, .external_lex_state = 3},
  [2430] = {.lex_state = 84, .external_lex_state = 3},
  [2431] = {.lex_state = 84, .external_lex_state = 3},
  [2432] = {.lex_state = 84, .external_lex_state = 3},
  [2433] = {.lex_state = 84, .external_lex_state = 3},
  [2434] = {.lex_state = 84, .external_lex_state = 3},
  [2435] = {.lex_state = 84, .external_lex_state = 3},
  [2436] = {.lex_state = 84, .external_lex_state = 3},
  [2437] = {.lex_state = 84, .external_lex_state = 3},
  [2438] = {.lex_state = 84, .external_lex_state = 3},
  [2439] = {.lex_state = 84, .external_lex_state = 3},
  [2440] = {.lex_state = 84, .external_lex_state = 3},
  [2441] = {.lex_state = 84, .external_lex_state = 3},
  [2442] = {.lex_state = 84, .external_lex_state = 3},
  [2443] = {.lex_state = 84, .external_lex_state = 3},
  [2444] = {.lex_state = 84, .external_lex_state = 3},
  [2445] = {.lex_state = 84, .external_lex_state = 3},
  [2446] = {.lex_state = 84, .external_lex_state = 3},
  [2447] = {.lex_state = 84, .external_lex_state = 3},
  [2448] = {.lex_state = 84, .external_lex_state = 3},
  [2449] = {.lex_state = 84, .external_lex_state = 3},
  [2450] = {.lex_state = 84, .external_lex_state = 3},
  [2451] = {.lex_state = 84, .external_lex_state = 3},
  [2452] = {.lex_state = 84, .external_lex_state = 3},
  [2453] = {.lex_state = 84, .external_lex_state = 3},
  [2454] = {.lex_state = 84, .external_lex_state = 3},
  [2455] = {.lex_state = 84, .external_lex_state = 3},
  [2456] = {.lex_state = 84, .external_lex_state = 3},
  [2457] = {.lex_state = 84, .external_lex_state = 3},
  [2458] = {.lex_state = 84, .external_lex_state = 3},
  [2459] = {.lex_state = 84, .external_lex_state = 3},
  [2460] = {.lex_state = 84, .external_lex_state = 3},
  [2461] = {.lex_state = 84, .external_lex_state = 3},
  [2462] = {.lex_state = 84, .external_lex_state = 3},
  [2463] = {.lex_state = 74, .external_lex_state = 2},
  [2464] = {.lex_state = 74, .external_lex_state = 4},
  [2465] = {.lex_state = 74, .external_lex_state = 2},
  [2466] = {.lex_state = 74, .external_lex_state = 2},
  [2467] = {.lex_state = 74, .external_lex_state = 3},
  [2468] = {.lex_state = 74, .external_lex_state = 4},
  [2469] = {.lex_state = 74, .external_lex_state = 4},
  [2470] = {.lex_state = 84, .external_lex_state = 2},
  [2471] = {.lex_state = 84, .external_lex_state = 2},
  [2472] = {.lex_state = 25, .external_lex_state = 2},
  [2473] = {.lex_state = 74, .external_lex_state = 2},
  [2474] = {.lex_state = 84, .external_lex_state = 2},
  [2475] = {.lex_state = 24, .external_lex_state = 2},
  [2476] = {.lex_state = 24, .external_lex_state = 2},
  [2477] = {.lex_state = 24, .external_lex_state = 2},
  [2478] = {.lex_state = 24, .external_lex_state = 2},
  [2479] = {.lex_state = 24, .external_lex_state = 2},
  [2480] = {.lex_state = 24, .external_lex_state = 2},
  [2481] = {.lex_state = 24, .external_lex_state = 2},
  [2482] = {.lex_state = 24, .external_lex_state = 2},
  [2483] = {.lex_state = 24, .external_lex_state = 2},
  [2484] = {.lex_state = 24, .external_lex_state = 2},
  [2485] = {.lex_state = 24, .external_lex_state = 2},
  [2486] = {.lex_state = 24, .external_lex_state = 2},
  [2487] = {.lex_state = 24, .external_lex_state = 2},
  [2488] = {.lex_state = 24, .external_lex_state = 2},
  [2489] = {.lex_state = 24, .external_lex_state = 2},
  [2490] = {.lex_state = 24, .external_lex_state = 2},
  [2491] = {.lex_state = 24, .external_lex_state = 2},
  [2492] = {.lex_state = 24, .external_lex_state = 2},
  [2493] = {.lex_state = 24, .external_lex_state = 2},
  [2494] = {.lex_state = 24, .external_lex_state = 2},
  [2495] = {.lex_state = 24, .external_lex_state = 2},
  [2496] = {.lex_state = 24, .external_lex_state = 2},
  [2497] = {.lex_state = 24, .external_lex_state = 2},
  [2498] = {.lex_state = 24, .external_lex_state = 2},
  [2499] = {.lex_state = 24, .external_lex_state = 2},
  [2500] = {.lex_state = 24, .external_lex_state = 2},
  [2501] = {.lex_state = 24, .external_lex_state = 2},
  [2502] = {.lex_state = 24, .external_lex_state = 2},
  [2503] = {.lex_state = 24, .external_lex_state = 2},
  [2504] = {.lex_state = 24, .external_lex_state = 2},
  [2505] = {.lex_state = 24, .external_lex_state = 2},
  [2506] = {.lex_state = 24, .external_lex_state = 2},
  [2507] = {.lex_state = 24, .external_lex_state = 2},
  [2508] = {.lex_state = 24, .external_lex_state = 2},
  [2509] = {.lex_state = 24, .external_lex_state = 2},
  [2510] = {.lex_state = 24, .external_lex_state = 2},
  [2511] = {.lex_state = 24, .external_lex_state = 2},
  [2512] = {.lex_state = 24, .external_lex_state = 2},
  [2513] = {.lex_state = 24, .external_lex_state = 2},
  [2514] = {.lex_state = 24, .external_lex_state = 2},
  [2515] = {.lex_state = 24, .external_lex_state = 2},
  [2516] = {.lex_state = 24, .external_lex_state = 2},
  [2517] = {.lex_state = 24, .external_lex_state = 2},
  [2518] = {.lex_state = 24, .external_lex_state = 2},
  [2519] = {.lex_state = 24, .external_lex_state = 2},
  [2520] = {.lex_state = 24, .external_lex_state = 2},
  [2521] = {.lex_state = 24, .external_lex_state = 2},
  [2522] = {.lex_state = 24, .external_lex_state = 2},
  [2523] = {.lex_state = 24, .external_lex_state = 2},
  [2524] = {.lex_state = 24, .external_lex_state = 2},
  [2525] = {.lex_state = 24, .external_lex_state = 2},
  [2526] = {.lex_state = 24, .external_lex_state = 2},
  [2527] = {.lex_state = 24, .external_lex_state = 2},
  [2528] = {.lex_state = 24, .external_lex_state = 2},
  [2529] = {.lex_state = 24, .external_lex_state = 2},
  [2530] = {.lex_state = 24, .external_lex_state = 2},
  [2531] = {.lex_state = 24, .external_lex_state = 2},
  [2532] = {.lex_state = 24, .external_lex_state = 2},
  [2533] = {.lex_state = 24, .external_lex_state = 2},
  [2534] = {.lex_state = 24, .external_lex_state = 2},
  [2535] = {.lex_state = 24, .external_lex_state = 2},
  [2536] = {.lex_state = 24, .external_lex_state = 2},
  [2537] = {.lex_state = 24, .external_lex_state = 2},
  [2538] = {.lex_state = 24, .external_lex_state = 2},
  [2539] = {.lex_state = 24, .external_lex_state = 2},
  [2540] = {.lex_state = 24, .external_lex_state = 2},
  [2541] = {.lex_state = 24, .external_lex_state = 2},
  [2542] = {.lex_state = 24, .external_lex_state = 2},
  [2543] = {.lex_state = 24, .external_lex_state = 2},
  [2544] = {.lex_state = 24, .external_lex_state = 2},
  [2545] = {.lex_state = 24, .external_lex_state = 2},
  [2546] = {.lex_state = 24, .external_lex_state = 2},
  [2547] = {.lex_state = 24, .external_lex_state = 2},
  [2548] = {.lex_state = 24, .external_lex_state = 2},
  [2549] = {.lex_state = 24, .external_lex_state = 2},
  [2550] = {.lex_state = 24, .external_lex_state = 2},
  [2551] = {.lex_state = 24, .external_lex_state = 2},
  [2552] = {.lex_state = 24, .external_lex_state = 2},
  [2553] = {.lex_state = 24, .external_lex_state = 2},
  [2554] = {.lex_state = 24, .external_lex_state = 2},
  [2555] = {.lex_state = 24, .external_lex_state = 2},
  [2556] = {.lex_state = 24, .external_lex_state = 2},
  [2557] = {.lex_state = 24, .external_lex_state = 2},
  [2558] = {.lex_state = 24, .external_lex_state = 2},
  [2559] = {.lex_state = 24, .external_lex_state = 2},
  [2560] = {.lex_state = 24, .external_lex_state = 2},
  [2561] = {.lex_state = 24, .external_lex_state = 2},
  [2562] = {.lex_state = 24, .external_lex_state = 2},
  [2563] = {.lex_state = 24, .external_lex_state = 2},
  [2564] = {.lex_state = 24, .external_lex_state = 2},
  [2565] = {.lex_state = 24, .external_lex_state = 2},
  [2566] = {.lex_state = 24, .external_lex_state = 2},
  [2567] = {.lex_state = 24, .external_lex_state = 2},
  [2568] = {.lex_state = 24, .external_lex_state = 2},
  [2569] = {.lex_state = 24, .external_lex_state = 2},
  [2570] = {.lex_state = 24, .external_lex_state = 2},
  [2571] = {.lex_state = 24, .external_lex_state = 2},
  [2572] = {.lex_state = 24, .external_lex_state = 2},
  [2573] = {.lex_state = 24, .external_lex_state = 2},
  [2574] = {.lex_state = 24, .external_lex_state = 2},
  [2575] = {.lex_state = 24, .external_lex_state = 2},
  [2576] = {.lex_state = 24, .external_lex_state = 2},
  [2577] = {.lex_state = 24, .external_lex_state = 2},
  [2578] = {.lex_state = 24, .external_lex_state = 2},
  [2579] = {.lex_state = 24, .external_lex_state = 2},
  [2580] = {.lex_state = 24, .external_lex_state = 2},
  [2581] = {.lex_state = 24, .external_lex_state = 2},
  [2582] = {.lex_state = 24, .external_lex_state = 2},
  [2583] = {.lex_state = 24, .external_lex_state = 2},
  [2584] = {.lex_state = 24, .external_lex_state = 2},
  [2585] = {.lex_state = 24, .external_lex_state = 2},
  [2586] = {.lex_state = 24, .external_lex_state = 2},
  [2587] = {.lex_state = 24, .external_lex_state = 2},
  [2588] = {.lex_state = 24, .external_lex_state = 2},
  [2589] = {.lex_state = 24, .external_lex_state = 2},
  [2590] = {.lex_state = 24, .external_lex_state = 2},
  [2591] = {.lex_state = 24, .external_lex_state = 2},
  [2592] = {.lex_state = 70, .external_lex_state = 6},
  [2593] = {.lex_state = 24, .external_lex_state = 2},
  [2594] = {.lex_state = 24, .external_lex_state = 2},
  [2595] = {.lex_state = 24, .external_lex_state = 2},
  [2596] = {.lex_state = 24, .external_lex_state = 2},
  [2597] = {.lex_state = 24, .external_lex_state = 2},
  [2598] = {.lex_state = 24, .external_lex_state = 2},
  [2599] = {.lex_state = 24, .external_lex_state = 2},
  [2600] = {.lex_state = 24, .external_lex_state = 2},
  [2601] = {.lex_state = 24, .external_lex_state = 2},
  [2602] = {.lex_state = 24, .external_lex_state = 2},
  [2603] = {.lex_state = 24, .external_lex_state = 2},
  [2604] = {.lex_state = 24, .external_lex_state = 2},
  [2605] = {.lex_state = 24, .external_lex_state = 2},
  [2606] = {.lex_state = 24, .external_lex_state = 2},
  [2607] = {.lex_state = 24, .external_lex_state = 2},
  [2608] = {.lex_state = 24, .external_lex_state = 2},
  [2609] = {.lex_state = 24, .external_lex_state = 2},
  [2610] = {.lex_state = 24, .external_lex_state = 2},
  [2611] = {.lex_state = 24, .external_lex_state = 2},
  [2612] = {.lex_state = 24, .external_lex_state = 2},
  [2613] = {.lex_state = 24, .external_lex_state = 2},
  [2614] = {.lex_state = 24, .external_lex_state = 2},
  [2615] = {.lex_state = 24, .external_lex_state = 2},
  [2616] = {.lex_state = 24, .external_lex_state = 2},
  [2617] = {.lex_state = 24, .external_lex_state = 2},
  [2618] = {.lex_state = 24, .external_lex_state = 2},
  [2619] = {.lex_state = 24, .external_lex_state = 2},
  [2620] = {.lex_state = 24, .external_lex_state = 2},
  [2621] = {.lex_state = 24, .external_lex_state = 2},
  [2622] = {.lex_state = 24, .external_lex_state = 2},
  [2623] = {.lex_state = 24, .external_lex_state = 2},
  [2624] = {.lex_state = 24, .external_lex_state = 2},
  [2625] = {.lex_state = 24, .external_lex_state = 2},
  [2626] = {.lex_state = 24, .external_lex_state = 2},
  [2627] = {.lex_state = 24, .external_lex_state = 2},
  [2628] = {.lex_state = 24, .external_lex_state = 2},
  [2629] = {.lex_state = 24, .external_lex_state = 2},
  [2630] = {.lex_state = 24, .external_lex_state = 2},
  [2631] = {.lex_state = 24, .external_lex_state = 2},
  [2632] = {.lex_state = 24, .external_lex_state = 2},
  [2633] = {.lex_state = 24, .external_lex_state = 2},
  [2634] = {.lex_state = 24, .external_lex_state = 2},
  [2635] = {.lex_state = 24, .external_lex_state = 2},
  [2636] = {.lex_state = 24, .external_lex_state = 2},
  [2637] = {.lex_state = 24, .external_lex_state = 2},
  [2638] = {.lex_state = 24, .external_lex_state = 2},
  [2639] = {.lex_state = 24, .external_lex_state = 2},
  [2640] = {.lex_state = 70, .external_lex_state = 8},
  [2641] = {.lex_state = 24, .external_lex_state = 2},
  [2642] = {.lex_state = 24, .external_lex_state = 2},
  [2643] = {.lex_state = 24, .external_lex_state = 2},
  [2644] = {.lex_state = 24, .external_lex_state = 2},
  [2645] = {.lex_state = 24, .external_lex_state = 2},
  [2646] = {.lex_state = 24, .external_lex_state = 2},
  [2647] = {.lex_state = 70, .external_lex_state = 7},
  [2648] = {.lex_state = 24, .external_lex_state = 2},
  [2649] = {.lex_state = 24, .external_lex_state = 2},
  [2650] = {.lex_state = 70, .external_lex_state = 12},
  [2651] = {.lex_state = 23, .external_lex_state = 2},
  [2652] = {.lex_state = 70, .external_lex_state = 9},
  [2653] = {.lex_state = 70, .external_lex_state = 11},
  [2654] = {.lex_state = 70, .external_lex_state = 10},
  [2655] = {.lex_state = 23, .external_lex_state = 2},
  [2656] = {.lex_state = 23, .external_lex_state = 2},
  [2657] = {.lex_state = 23, .external_lex_state = 2},
  [2658] = {.lex_state = 23, .external_lex_state = 2},
  [2659] = {.lex_state = 23, .external_lex_state = 2},
  [2660] = {.lex_state = 23, .external_lex_state = 2},
  [2661] = {.lex_state = 23, .external_lex_state = 2},
  [2662] = {.lex_state = 23, .external_lex_state = 2},
  [2663] = {.lex_state = 23, .external_lex_state = 2},
  [2664] = {.lex_state = 23, .external_lex_state = 2},
  [2665] = {.lex_state = 23, .external_lex_state = 2},
  [2666] = {.lex_state = 23, .external_lex_state = 2},
  [2667] = {.lex_state = 23, .external_lex_state = 2},
  [2668] = {.lex_state = 23, .external_lex_state = 2},
  [2669] = {.lex_state = 23, .external_lex_state = 2},
  [2670] = {.lex_state = 23, .external_lex_state = 2},
  [2671] = {.lex_state = 23, .external_lex_state = 2},
  [2672] = {.lex_state = 23, .external_lex_state = 2},
  [2673] = {.lex_state = 23, .external_lex_state = 2},
  [2674] = {.lex_state = 23, .external_lex_state = 2},
  [2675] = {.lex_state = 23, .external_lex_state = 2},
  [2676] = {.lex_state = 23, .external_lex_state = 2},
  [2677] = {.lex_state = 23, .external_lex_state = 2},
  [2678] = {.lex_state = 23, .external_lex_state = 2},
  [2679] = {.lex_state = 23, .external_lex_state = 2},
  [2680] = {.lex_state = 23, .external_lex_state = 2},
  [2681] = {.lex_state = 23, .external_lex_state = 2},
  [2682] = {.lex_state = 23, .external_lex_state = 2},
  [2683] = {.lex_state = 23, .external_lex_state = 2},
  [2684] = {.lex_state = 23, .external_lex_state = 2},
  [2685] = {.lex_state = 23, .external_lex_state = 2},
  [2686] = {.lex_state = 23, .external_lex_state = 2},
  [2687] = {.lex_state = 23, .external_lex_state = 2},
  [2688] = {.lex_state = 70, .external_lex_state = 6},
  [2689] = {.lex_state = 23, .external_lex_state = 2},
  [2690] = {.lex_state = 23, .external_lex_state = 2},
  [2691] = {.lex_state = 23, .external_lex_state = 2},
  [2692] = {.lex_state = 23, .external_lex_state = 2},
  [2693] = {.lex_state = 23, .external_lex_state = 2},
  [2694] = {.lex_state = 23, .external_lex_state = 2},
  [2695] = {.lex_state = 23, .external_lex_state = 2},
  [2696] = {.lex_state = 23, .external_lex_state = 2},
  [2697] = {.lex_state = 23, .external_lex_state = 2},
  [2698] = {.lex_state = 23, .external_lex_state = 2},
  [2699] = {.lex_state = 23, .external_lex_state = 2},
  [2700] = {.lex_state = 23, .external_lex_state = 2},
  [2701] = {.lex_state = 23, .external_lex_state = 2},
  [2702] = {.lex_state = 23, .external_lex_state = 2},
  [2703] = {.lex_state = 23, .external_lex_state = 2},
  [2704] = {.lex_state = 23, .external_lex_state = 2},
  [2705] = {.lex_state = 23, .external_lex_state = 2},
  [2706] = {.lex_state = 23, .external_lex_state = 2},
  [2707] = {.lex_state = 23, .external_lex_state = 2},
  [2708] = {.lex_state = 23, .external_lex_state = 2},
  [2709] = {.lex_state = 23, .external_lex_state = 2},
  [2710] = {.lex_state = 23, .external_lex_state = 2},
  [2711] = {.lex_state = 23, .external_lex_state = 2},
  [2712] = {.lex_state = 23, .external_lex_state = 2},
  [2713] = {.lex_state = 23, .external_lex_state = 2},
  [2714] = {.lex_state = 23, .external_lex_state = 2},
  [2715] = {.lex_state = 23, .external_lex_state = 2},
  [2716] = {.lex_state = 23, .external_lex_state = 2},
  [2717] = {.lex_state = 23, .external_lex_state = 2},
  [2718] = {.lex_state = 23, .external_lex_state = 2},
  [2719] = {.lex_state = 23, .external_lex_state = 2},
  [2720] = {.lex_state = 23, .external_lex_state = 2},
  [2721] = {.lex_state = 23, .external_lex_state = 2},
  [2722] = {.lex_state = 23, .external_lex_state = 2},
  [2723] = {.lex_state = 23, .external_lex_state = 2},
  [2724] = {.lex_state = 23, .external_lex_state = 2},
  [2725] = {.lex_state = 23, .external_lex_state = 2},
  [2726] = {.lex_state = 23, .external_lex_state = 2},
  [2727] = {.lex_state = 23, .external_lex_state = 2},
  [2728] = {.lex_state = 23, .external_lex_state = 2},
  [2729] = {.lex_state = 23, .external_lex_state = 2},
  [2730] = {.lex_state = 23, .external_lex_state = 2},
  [2731] = {.lex_state = 23, .external_lex_state = 2},
  [2732] = {.lex_state = 23, .external_lex_state = 2},
  [2733] = {.lex_state = 23, .external_lex_state = 2},
  [2734] = {.lex_state = 23, .external_lex_state = 2},
  [2735] = {.lex_state = 23, .external_lex_state = 2},
  [2736] = {.lex_state = 23, .external_lex_state = 2},
  [2737] = {.lex_state = 23, .external_lex_state = 2},
  [2738] = {.lex_state = 23, .external_lex_state = 2},
  [2739] = {.lex_state = 23, .external_lex_state = 2},
  [2740] = {.lex_state = 23, .external_lex_state = 2},
  [2741] = {.lex_state = 23, .external_lex_state = 2},
  [2742] = {.lex_state = 23, .external_lex_state = 2},
  [2743] = {.lex_state = 23, .external_lex_state = 2},
  [2744] = {.lex_state = 23, .external_lex_state = 2},
  [2745] = {.lex_state = 23, .external_lex_state = 2},
  [2746] = {.lex_state = 23, .external_lex_state = 2},
  [2747] = {.lex_state = 23, .external_lex_state = 2},
  [2748] = {.lex_state = 23, .external_lex_state = 2},
  [2749] = {.lex_state = 23, .external_lex_state = 2},
  [2750] = {.lex_state = 23, .external_lex_state = 2},
  [2751] = {.lex_state = 23, .external_lex_state = 2},
  [2752] = {.lex_state = 23, .external_lex_state = 2},
  [2753] = {.lex_state = 23, .external_lex_state = 2},
  [2754] = {.lex_state = 23, .external_lex_state = 2},
  [2755] = {.lex_state = 23, .external_lex_state = 2},
  [2756] = {.lex_state = 23, .external_lex_state = 2},
  [2757] = {.lex_state = 23, .external_lex_state = 2},
  [2758] = {.lex_state = 23, .external_lex_state = 2},
  [2759] = {.lex_state = 23, .external_lex_state = 2},
  [2760] = {.lex_state = 23, .external_lex_state = 2},
  [2761] = {.lex_state = 23, .external_lex_state = 2},
  [2762] = {.lex_state = 23, .external_lex_state = 2},
  [2763] = {.lex_state = 23, .external_lex_state = 2},
  [2764] = {.lex_state = 23, .external_lex_state = 2},
  [2765] = {.lex_state = 23, .external_lex_state = 2},
  [2766] = {.lex_state = 23, .external_lex_state = 2},
  [2767] = {.lex_state = 23, .external_lex_state = 2},
  [2768] = {.lex_state = 23, .external_lex_state = 2},
  [2769] = {.lex_state = 23, .external_lex_state = 2},
  [2770] = {.lex_state = 70, .external_lex_state = 14},
  [2771] = {.lex_state = 23, .external_lex_state = 2},
  [2772] = {.lex_state = 23, .external_lex_state = 2},
  [2773] = {.lex_state = 23, .external_lex_state = 2},
  [2774] = {.lex_state = 23, .external_lex_state = 2},
  [2775] = {.lex_state = 23, .external_lex_state = 2},
  [2776] = {.lex_state = 23, .external_lex_state = 2},
  [2777] = {.lex_state = 23, .external_lex_state = 2},
  [2778] = {.lex_state = 23, .external_lex_state = 2},
  [2779] = {.lex_state = 23, .external_lex_state = 2},
  [2780] = {.lex_state = 23, .external_lex_state = 2},
  [2781] = {.lex_state = 23, .external_lex_state = 2},
  [2782] = {.lex_state = 23, .external_lex_state = 2},
  [2783] = {.lex_state = 23, .external_lex_state = 2},
  [2784] = {.lex_state = 23, .external_lex_state = 2},
  [2785] = {.lex_state = 23, .external_lex_state = 2},
  [2786] = {.lex_state = 23, .external_lex_state = 2},
  [2787] = {.lex_state = 23, .external_lex_state = 2},
  [2788] = {.lex_state = 23, .external_lex_state = 2},
  [2789] = {.lex_state = 23, .external_lex_state = 2},
  [2790] = {.lex_state = 23, .external_lex_state = 2},
  [2791] = {.lex_state = 23, .external_lex_state = 2},
  [2792] = {.lex_state = 23, .external_lex_state = 2},
  [2793] = {.lex_state = 23, .external_lex_state = 2},
  [2794] = {.lex_state = 23, .external_lex_state = 2},
  [2795] = {.lex_state = 23, .external_lex_state = 2},
  [2796] = {.lex_state = 23, .external_lex_state = 2},
  [2797] = {.lex_state = 23, .external_lex_state = 2},
  [2798] = {.lex_state = 23, .external_lex_state = 2},
  [2799] = {.lex_state = 23, .external_lex_state = 2},
  [2800] = {.lex_state = 23, .external_lex_state = 2},
  [2801] = {.lex_state = 23, .external_lex_state = 2},
  [2802] = {.lex_state = 23, .external_lex_state = 2},
  [2803] = {.lex_state = 23, .external_lex_state = 2},
  [2804] = {.lex_state = 23, .external_lex_state = 2},
  [2805] = {.lex_state = 23, .external_lex_state = 2},
  [2806] = {.lex_state = 23, .external_lex_state = 2},
  [2807] = {.lex_state = 23, .external_lex_state = 2},
  [2808] = {.lex_state = 23, .external_lex_state = 2},
  [2809] = {.lex_state = 23, .external_lex_state = 2},
  [2810] = {.lex_state = 23, .external_lex_state = 2},
  [2811] = {.lex_state = 23, .external_lex_state = 2},
  [2812] = {.lex_state = 23, .external_lex_state = 2},
  [2813] = {.lex_state = 23, .external_lex_state = 2},
  [2814] = {.lex_state = 23, .external_lex_state = 2},
  [2815] = {.lex_state = 23, .external_lex_state = 2},
  [2816] = {.lex_state = 23, .external_lex_state = 2},
  [2817] = {.lex_state = 23, .external_lex_state = 2},
  [2818] = {.lex_state = 23, .external_lex_state = 2},
  [2819] = {.lex_state = 23, .external_lex_state = 2},
  [2820] = {.lex_state = 23, .external_lex_state = 2},
  [2821] = {.lex_state = 23, .external_lex_state = 2},
  [2822] = {.lex_state = 23, .external_lex_state = 2},
  [2823] = {.lex_state = 23, .external_lex_state = 2},
  [2824] = {.lex_state = 23, .external_lex_state = 2},
  [2825] = {.lex_state = 23, .external_lex_state = 2},
  [2826] = {.lex_state = 23, .external_lex_state = 2},
  [2827] = {.lex_state = 23, .external_lex_state = 2},
  [2828] = {.lex_state = 23, .external_lex_state = 2},
  [2829] = {.lex_state = 23, .external_lex_state = 2},
  [2830] = {.lex_state = 23, .external_lex_state = 2},
  [2831] = {.lex_state = 23, .external_lex_state = 2},
  [2832] = {.lex_state = 23, .external_lex_state = 2},
  [2833] = {.lex_state = 23, .external_lex_state = 2},
  [2834] = {.lex_state = 23, .external_lex_state = 2},
  [2835] = {.lex_state = 23, .external_lex_state = 2},
  [2836] = {.lex_state = 23, .external_lex_state = 2},
  [2837] = {.lex_state = 23, .external_lex_state = 2},
  [2838] = {.lex_state = 23, .external_lex_state = 2},
  [2839] = {.lex_state = 23, .external_lex_state = 2},
  [2840] = {.lex_state = 23, .external_lex_state = 2},
  [2841] = {.lex_state = 23, .external_lex_state = 2},
  [2842] = {.lex_state = 23, .external_lex_state = 2},
  [2843] = {.lex_state = 23, .external_lex_state = 2},
  [2844] = {.lex_state = 23, .external_lex_state = 2},
  [2845] = {.lex_state = 23, .external_lex_state = 2},
  [2846] = {.lex_state = 23, .external_lex_state = 2},
  [2847] = {.lex_state = 23, .external_lex_state = 2},
  [2848] = {.lex_state = 23, .external_lex_state = 2},
  [2849] = {.lex_state = 23, .external_lex_state = 2},
  [2850] = {.lex_state = 23, .external_lex_state = 2},
  [2851] = {.lex_state = 23, .external_lex_state = 2},
  [2852] = {.lex_state = 23, .external_lex_state = 2},
  [2853] = {.lex_state = 23, .external_lex_state = 2},
  [2854] = {.lex_state = 23, .external_lex_state = 2},
  [2855] = {.lex_state = 23, .external_lex_state = 2},
  [2856] = {.lex_state = 23, .external_lex_state = 2},
  [2857] = {.lex_state = 23, .external_lex_state = 2},
  [2858] = {.lex_state = 23, .external_lex_state = 2},
  [2859] = {.lex_state = 23, .external_lex_state = 2},
  [2860] = {.lex_state = 23, .external_lex_state = 2},
  [2861] = {.lex_state = 23, .external_lex_state = 2},
  [2862] = {.lex_state = 23, .external_lex_state = 2},
  [2863] = {.lex_state = 23, .external_lex_state = 2},
  [2864] = {.lex_state = 23, .external_lex_state = 2},
  [2865] = {.lex_state = 23, .external_lex_state = 2},
  [2866] = {.lex_state = 23, .external_lex_state = 2},
  [2867] = {.lex_state = 23, .external_lex_state = 2},
  [2868] = {.lex_state = 23, .external_lex_state = 2},
  [2869] = {.lex_state = 23, .external_lex_state = 2},
  [2870] = {.lex_state = 23, .external_lex_state = 2},
  [2871] = {.lex_state = 23, .external_lex_state = 2},
  [2872] = {.lex_state = 23, .external_lex_state = 2},
  [2873] = {.lex_state = 23, .external_lex_state = 2},
  [2874] = {.lex_state = 23, .external_lex_state = 2},
  [2875] = {.lex_state = 70, .external_lex_state = 15},
  [2876] = {.lex_state = 23, .external_lex_state = 2},
  [2877] = {.lex_state = 23, .external_lex_state = 2},
  [2878] = {.lex_state = 23, .external_lex_state = 2},
  [2879] = {.lex_state = 23, .external_lex_state = 2},
  [2880] = {.lex_state = 23, .external_lex_state = 2},
  [2881] = {.lex_state = 23, .external_lex_state = 2},
  [2882] = {.lex_state = 23, .external_lex_state = 2},
  [2883] = {.lex_state = 23, .external_lex_state = 2},
  [2884] = {.lex_state = 23, .external_lex_state = 2},
  [2885] = {.lex_state = 23, .external_lex_state = 2},
  [2886] = {.lex_state = 23, .external_lex_state = 2},
  [2887] = {.lex_state = 23, .external_lex_state = 2},
  [2888] = {.lex_state = 23, .external_lex_state = 2},
  [2889] = {.lex_state = 23, .external_lex_state = 2},
  [2890] = {.lex_state = 23, .external_lex_state = 2},
  [2891] = {.lex_state = 23, .external_lex_state = 2},
  [2892] = {.lex_state = 23, .external_lex_state = 2},
  [2893] = {.lex_state = 23, .external_lex_state = 2},
  [2894] = {.lex_state = 23, .external_lex_state = 2},
  [2895] = {.lex_state = 23, .external_lex_state = 2},
  [2896] = {.lex_state = 23, .external_lex_state = 2},
  [2897] = {.lex_state = 23, .external_lex_state = 2},
  [2898] = {.lex_state = 23, .external_lex_state = 2},
  [2899] = {.lex_state = 23, .external_lex_state = 2},
  [2900] = {.lex_state = 23, .external_lex_state = 2},
  [2901] = {.lex_state = 23, .external_lex_state = 2},
  [2902] = {.lex_state = 23, .external_lex_state = 2},
  [2903] = {.lex_state = 23, .external_lex_state = 2},
  [2904] = {.lex_state = 70, .external_lex_state = 13},
  [2905] = {.lex_state = 23, .external_lex_state = 2},
  [2906] = {.lex_state = 23, .external_lex_state = 2},
  [2907] = {.lex_state = 23, .external_lex_state = 2},
  [2908] = {.lex_state = 23, .external_lex_state = 2},
  [2909] = {.lex_state = 23, .external_lex_state = 2},
  [2910] = {.lex_state = 23, .external_lex_state = 2},
  [2911] = {.lex_state = 23, .external_lex_state = 2},
  [2912] = {.lex_state = 23, .external_lex_state = 2},
  [2913] = {.lex_state = 23, .external_lex_state = 2},
  [2914] = {.lex_state = 23, .external_lex_state = 2},
  [2915] = {.lex_state = 23, .external_lex_state = 2},
  [2916] = {.lex_state = 23, .external_lex_state = 2},
  [2917] = {.lex_state = 23, .external_lex_state = 2},
  [2918] = {.lex_state = 23, .external_lex_state = 2},
  [2919] = {.lex_state = 23, .external_lex_state = 2},
  [2920] = {.lex_state = 23, .external_lex_state = 2},
  [2921] = {.lex_state = 23, .external_lex_state = 2},
  [2922] = {.lex_state = 23, .external_lex_state = 2},
  [2923] = {.lex_state = 23, .external_lex_state = 2},
  [2924] = {.lex_state = 23, .external_lex_state = 2},
  [2925] = {.lex_state = 23, .external_lex_state = 2},
  [2926] = {.lex_state = 23, .external_lex_state = 2},
  [2927] = {.lex_state = 23, .external_lex_state = 2},
  [2928] = {.lex_state = 23, .external_lex_state = 2},
  [2929] = {.lex_state = 23, .external_lex_state = 2},
  [2930] = {.lex_state = 23, .external_lex_state = 2},
  [2931] = {.lex_state = 23, .external_lex_state = 2},
  [2932] = {.lex_state = 23, .external_lex_state = 2},
  [2933] = {.lex_state = 23, .external_lex_state = 2},
  [2934] = {.lex_state = 23, .external_lex_state = 2},
  [2935] = {.lex_state = 23, .external_lex_state = 2},
  [2936] = {.lex_state = 23, .external_lex_state = 2},
  [2937] = {.lex_state = 23, .external_lex_state = 2},
  [2938] = {.lex_state = 23, .external_lex_state = 2},
  [2939] = {.lex_state = 23, .external_lex_state = 2},
  [2940] = {.lex_state = 23, .external_lex_state = 2},
  [2941] = {.lex_state = 23, .external_lex_state = 2},
  [2942] = {.lex_state = 23, .external_lex_state = 2},
  [2943] = {.lex_state = 23, .external_lex_state = 2},
  [2944] = {.lex_state = 23, .external_lex_state = 2},
  [2945] = {.lex_state = 23, .external_lex_state = 2},
  [2946] = {.lex_state = 23, .external_lex_state = 2},
  [2947] = {.lex_state = 23, .external_lex_state = 2},
  [2948] = {.lex_state = 23, .external_lex_state = 2},
  [2949] = {.lex_state = 23, .external_lex_state = 2},
  [2950] = {.lex_state = 23, .external_lex_state = 2},
  [2951] = {.lex_state = 23, .external_lex_state = 2},
  [2952] = {.lex_state = 23, .external_lex_state = 2},
  [2953] = {.lex_state = 23, .external_lex_state = 2},
  [2954] = {.lex_state = 23, .external_lex_state = 2},
  [2955] = {.lex_state = 23, .external_lex_state = 2},
  [2956] = {.lex_state = 23, .external_lex_state = 2},
  [2957] = {.lex_state = 23, .external_lex_state = 2},
  [2958] = {.lex_state = 23, .external_lex_state = 2},
  [2959] = {.lex_state = 23, .external_lex_state = 2},
  [2960] = {.lex_state = 23, .external_lex_state = 2},
  [2961] = {.lex_state = 23, .external_lex_state = 2},
  [2962] = {.lex_state = 23, .external_lex_state = 2},
  [2963] = {.lex_state = 23, .external_lex_state = 2},
  [2964] = {.lex_state = 23, .external_lex_state = 2},
  [2965] = {.lex_state = 23, .external_lex_state = 2},
  [2966] = {.lex_state = 23, .external_lex_state = 2},
  [2967] = {.lex_state = 23, .external_lex_state = 2},
  [2968] = {.lex_state = 23, .external_lex_state = 2},
  [2969] = {.lex_state = 23, .external_lex_state = 2},
  [2970] = {.lex_state = 23, .external_lex_state = 2},
  [2971] = {.lex_state = 23, .external_lex_state = 2},
  [2972] = {.lex_state = 23, .external_lex_state = 2},
  [2973] = {.lex_state = 23, .external_lex_state = 2},
  [2974] = {.lex_state = 23, .external_lex_state = 2},
  [2975] = {.lex_state = 23, .external_lex_state = 2},
  [2976] = {.lex_state = 23, .external_lex_state = 2},
  [2977] = {.lex_state = 23, .external_lex_state = 2},
  [2978] = {.lex_state = 23, .external_lex_state = 2},
  [2979] = {.lex_state = 23, .external_lex_state = 2},
  [2980] = {.lex_state = 23, .external_lex_state = 2},
  [2981] = {.lex_state = 23, .external_lex_state = 2},
  [2982] = {.lex_state = 23, .external_lex_state = 2},
  [2983] = {.lex_state = 23, .external_lex_state = 2},
  [2984] = {.lex_state = 23, .external_lex_state = 2},
  [2985] = {.lex_state = 23, .external_lex_state = 2},
  [2986] = {.lex_state = 23, .external_lex_state = 2},
  [2987] = {.lex_state = 23, .external_lex_state = 2},
  [2988] = {.lex_state = 23, .external_lex_state = 2},
  [2989] = {.lex_state = 23, .external_lex_state = 2},
  [2990] = {.lex_state = 23, .external_lex_state = 2},
  [2991] = {.lex_state = 23, .external_lex_state = 2},
  [2992] = {.lex_state = 23, .external_lex_state = 2},
  [2993] = {.lex_state = 23, .external_lex_state = 2},
  [2994] = {.lex_state = 23, .external_lex_state = 2},
  [2995] = {.lex_state = 23, .external_lex_state = 2},
  [2996] = {.lex_state = 23, .external_lex_state = 2},
  [2997] = {.lex_state = 23, .external_lex_state = 2},
  [2998] = {.lex_state = 23, .external_lex_state = 2},
  [2999] = {.lex_state = 23, .external_lex_state = 2},
  [3000] = {.lex_state = 23, .external_lex_state = 2},
  [3001] = {.lex_state = 23, .external_lex_state = 2},
  [3002] = {.lex_state = 23, .external_lex_state = 2},
  [3003] = {.lex_state = 23, .external_lex_state = 2},
  [3004] = {.lex_state = 23, .external_lex_state = 2},
  [3005] = {.lex_state = 23, .external_lex_state = 2},
  [3006] = {.lex_state = 23, .external_lex_state = 2},
  [3007] = {.lex_state = 23, .external_lex_state = 2},
  [3008] = {.lex_state = 23, .external_lex_state = 2},
  [3009] = {.lex_state = 23, .external_lex_state = 2},
  [3010] = {.lex_state = 23, .external_lex_state = 2},
  [3011] = {.lex_state = 23, .external_lex_state = 2},
  [3012] = {.lex_state = 23, .external_lex_state = 2},
  [3013] = {.lex_state = 23, .external_lex_state = 2},
  [3014] = {.lex_state = 23, .external_lex_state = 2},
  [3015] = {.lex_state = 23, .external_lex_state = 2},
  [3016] = {.lex_state = 23, .external_lex_state = 2},
  [3017] = {.lex_state = 23, .external_lex_state = 2},
  [3018] = {.lex_state = 23, .external_lex_state = 2},
  [3019] = {.lex_state = 23, .external_lex_state = 2},
  [3020] = {.lex_state = 23, .external_lex_state = 2},
  [3021] = {.lex_state = 23, .external_lex_state = 2},
  [3022] = {.lex_state = 23, .external_lex_state = 2},
  [3023] = {.lex_state = 23, .external_lex_state = 2},
  [3024] = {.lex_state = 23, .external_lex_state = 2},
  [3025] = {.lex_state = 23, .external_lex_state = 2},
  [3026] = {.lex_state = 23, .external_lex_state = 2},
  [3027] = {.lex_state = 23, .external_lex_state = 2},
  [3028] = {.lex_state = 23, .external_lex_state = 2},
  [3029] = {.lex_state = 23, .external_lex_state = 2},
  [3030] = {.lex_state = 23, .external_lex_state = 2},
  [3031] = {.lex_state = 23, .external_lex_state = 2},
  [3032] = {.lex_state = 23, .external_lex_state = 2},
  [3033] = {.lex_state = 23, .external_lex_state = 2},
  [3034] = {.lex_state = 23, .external_lex_state = 2},
  [3035] = {.lex_state = 23, .external_lex_state = 2},
  [3036] = {.lex_state = 23, .external_lex_state = 2},
  [3037] = {.lex_state = 23, .external_lex_state = 2},
  [3038] = {.lex_state = 23, .external_lex_state = 2},
  [3039] = {.lex_state = 23, .external_lex_state = 2},
  [3040] = {.lex_state = 23, .external_lex_state = 2},
  [3041] = {.lex_state = 23, .external_lex_state = 2},
  [3042] = {.lex_state = 23, .external_lex_state = 2},
  [3043] = {.lex_state = 23, .external_lex_state = 2},
  [3044] = {.lex_state = 23, .external_lex_state = 2},
  [3045] = {.lex_state = 23, .external_lex_state = 2},
  [3046] = {.lex_state = 23, .external_lex_state = 2},
  [3047] = {.lex_state = 23, .external_lex_state = 2},
  [3048] = {.lex_state = 23, .external_lex_state = 2},
  [3049] = {.lex_state = 23, .external_lex_state = 2},
  [3050] = {.lex_state = 23, .external_lex_state = 2},
  [3051] = {.lex_state = 23, .external_lex_state = 2},
  [3052] = {.lex_state = 23, .external_lex_state = 2},
  [3053] = {.lex_state = 23, .external_lex_state = 2},
  [3054] = {.lex_state = 23, .external_lex_state = 2},
  [3055] = {.lex_state = 23, .external_lex_state = 2},
  [3056] = {.lex_state = 23, .external_lex_state = 2},
  [3057] = {.lex_state = 23, .external_lex_state = 2},
  [3058] = {.lex_state = 23, .external_lex_state = 2},
  [3059] = {.lex_state = 23, .external_lex_state = 2},
  [3060] = {.lex_state = 23, .external_lex_state = 2},
  [3061] = {.lex_state = 23, .external_lex_state = 2},
  [3062] = {.lex_state = 23, .external_lex_state = 2},
  [3063] = {.lex_state = 23, .external_lex_state = 2},
  [3064] = {.lex_state = 23, .external_lex_state = 2},
  [3065] = {.lex_state = 23, .external_lex_state = 2},
  [3066] = {.lex_state = 23, .external_lex_state = 2},
  [3067] = {.lex_state = 23, .external_lex_state = 2},
  [3068] = {.lex_state = 23, .external_lex_state = 2},
  [3069] = {.lex_state = 23, .external_lex_state = 2},
  [3070] = {.lex_state = 23, .external_lex_state = 2},
  [3071] = {.lex_state = 23, .external_lex_state = 2},
  [3072] = {.lex_state = 23, .external_lex_state = 2},
  [3073] = {.lex_state = 23, .external_lex_state = 2},
  [3074] = {.lex_state = 23, .external_lex_state = 2},
  [3075] = {.lex_state = 23, .external_lex_state = 2},
  [3076] = {.lex_state = 23, .external_lex_state = 2},
  [3077] = {.lex_state = 23, .external_lex_state = 2},
  [3078] = {.lex_state = 23, .external_lex_state = 2},
  [3079] = {.lex_state = 23, .external_lex_state = 2},
  [3080] = {.lex_state = 23, .external_lex_state = 2},
  [3081] = {.lex_state = 23, .external_lex_state = 2},
  [3082] = {.lex_state = 23, .external_lex_state = 2},
  [3083] = {.lex_state = 23, .external_lex_state = 2},
  [3084] = {.lex_state = 23, .external_lex_state = 2},
  [3085] = {.lex_state = 23, .external_lex_state = 2},
  [3086] = {.lex_state = 23, .external_lex_state = 2},
  [3087] = {.lex_state = 23, .external_lex_state = 2},
  [3088] = {.lex_state = 23, .external_lex_state = 2},
  [3089] = {.lex_state = 23, .external_lex_state = 2},
  [3090] = {.lex_state = 23, .external_lex_state = 2},
  [3091] = {.lex_state = 23, .external_lex_state = 2},
  [3092] = {.lex_state = 23, .external_lex_state = 2},
  [3093] = {.lex_state = 23, .external_lex_state = 2},
  [3094] = {.lex_state = 23, .external_lex_state = 2},
  [3095] = {.lex_state = 23, .external_lex_state = 2},
  [3096] = {.lex_state = 23, .external_lex_state = 2},
  [3097] = {.lex_state = 23, .external_lex_state = 2},
  [3098] = {.lex_state = 23, .external_lex_state = 2},
  [3099] = {.lex_state = 23, .external_lex_state = 2},
  [3100] = {.lex_state = 23, .external_lex_state = 2},
  [3101] = {.lex_state = 23, .external_lex_state = 2},
  [3102] = {.lex_state = 23, .external_lex_state = 2},
  [3103] = {.lex_state = 23, .external_lex_state = 2},
  [3104] = {.lex_state = 23, .external_lex_state = 2},
  [3105] = {.lex_state = 23, .external_lex_state = 2},
  [3106] = {.lex_state = 23, .external_lex_state = 2},
  [3107] = {.lex_state = 23, .external_lex_state = 2},
  [3108] = {.lex_state = 23, .external_lex_state = 2},
  [3109] = {.lex_state = 23, .external_lex_state = 2},
  [3110] = {.lex_state = 23, .external_lex_state = 2},
  [3111] = {.lex_state = 23, .external_lex_state = 2},
  [3112] = {.lex_state = 23, .external_lex_state = 2},
  [3113] = {.lex_state = 23, .external_lex_state = 2},
  [3114] = {.lex_state = 23, .external_lex_state = 2},
  [3115] = {.lex_state = 23, .external_lex_state = 2},
  [3116] = {.lex_state = 23, .external_lex_state = 2},
  [3117] = {.lex_state = 23, .external_lex_state = 2},
  [3118] = {.lex_state = 23, .external_lex_state = 2},
  [3119] = {.lex_state = 23, .external_lex_state = 2},
  [3120] = {.lex_state = 23, .external_lex_state = 2},
  [3121] = {.lex_state = 23, .external_lex_state = 2},
  [3122] = {.lex_state = 23, .external_lex_state = 2},
  [3123] = {.lex_state = 23, .external_lex_state = 2},
  [3124] = {.lex_state = 23, .external_lex_state = 2},
  [3125] = {.lex_state = 23, .external_lex_state = 2},
  [3126] = {.lex_state = 23, .external_lex_state = 2},
  [3127] = {.lex_state = 23, .external_lex_state = 2},
  [3128] = {.lex_state = 23, .external_lex_state = 2},
  [3129] = {.lex_state = 23, .external_lex_state = 2},
  [3130] = {.lex_state = 23, .external_lex_state = 2},
  [3131] = {.lex_state = 23, .external_lex_state = 2},
  [3132] = {.lex_state = 23, .external_lex_state = 2},
  [3133] = {.lex_state = 23, .external_lex_state = 2},
  [3134] = {.lex_state = 23, .external_lex_state = 2},
  [3135] = {.lex_state = 23, .external_lex_state = 2},
  [3136] = {.lex_state = 23, .external_lex_state = 2},
  [3137] = {.lex_state = 23, .external_lex_state = 2},
  [3138] = {.lex_state = 23, .external_lex_state = 2},
  [3139] = {.lex_state = 23, .external_lex_state = 2},
  [3140] = {.lex_state = 23, .external_lex_state = 2},
  [3141] = {.lex_state = 23, .external_lex_state = 2},
  [3142] = {.lex_state = 23, .external_lex_state = 2},
  [3143] = {.lex_state = 23, .external_lex_state = 2},
  [3144] = {.lex_state = 23, .external_lex_state = 2},
  [3145] = {.lex_state = 23, .external_lex_state = 2},
  [3146] = {.lex_state = 23, .external_lex_state = 2},
  [3147] = {.lex_state = 23, .external_lex_state = 2},
  [3148] = {.lex_state = 23, .external_lex_state = 2},
  [3149] = {.lex_state = 23, .external_lex_state = 2},
  [3150] = {.lex_state = 23, .external_lex_state = 2},
  [3151] = {.lex_state = 23, .external_lex_state = 2},
  [3152] = {.lex_state = 23, .external_lex_state = 2},
  [3153] = {.lex_state = 23, .external_lex_state = 2},
  [3154] = {.lex_state = 23, .external_lex_state = 2},
  [3155] = {.lex_state = 23, .external_lex_state = 2},
  [3156] = {.lex_state = 23, .external_lex_state = 2},
  [3157] = {.lex_state = 23, .external_lex_state = 2},
  [3158] = {.lex_state = 23, .external_lex_state = 2},
  [3159] = {.lex_state = 23, .external_lex_state = 2},
  [3160] = {.lex_state = 23, .external_lex_state = 2},
  [3161] = {.lex_state = 23, .external_lex_state = 2},
  [3162] = {.lex_state = 23, .external_lex_state = 2},
  [3163] = {.lex_state = 23, .external_lex_state = 2},
  [3164] = {.lex_state = 23, .external_lex_state = 2},
  [3165] = {.lex_state = 23, .external_lex_state = 2},
  [3166] = {.lex_state = 23, .external_lex_state = 2},
  [3167] = {.lex_state = 23, .external_lex_state = 2},
  [3168] = {.lex_state = 23, .external_lex_state = 2},
  [3169] = {.lex_state = 23, .external_lex_state = 2},
  [3170] = {.lex_state = 23, .external_lex_state = 2},
  [3171] = {.lex_state = 23, .external_lex_state = 2},
  [3172] = {.lex_state = 23, .external_lex_state = 2},
  [3173] = {.lex_state = 23, .external_lex_state = 2},
  [3174] = {.lex_state = 23, .external_lex_state = 2},
  [3175] = {.lex_state = 23, .external_lex_state = 2},
  [3176] = {.lex_state = 23, .external_lex_state = 2},
  [3177] = {.lex_state = 23, .external_lex_state = 2},
  [3178] = {.lex_state = 23, .external_lex_state = 2},
  [3179] = {.lex_state = 23, .external_lex_state = 2},
  [3180] = {.lex_state = 23, .external_lex_state = 2},
  [3181] = {.lex_state = 23, .external_lex_state = 2},
  [3182] = {.lex_state = 23, .external_lex_state = 2},
  [3183] = {.lex_state = 23, .external_lex_state = 2},
  [3184] = {.lex_state = 23, .external_lex_state = 2},
  [3185] = {.lex_state = 23, .external_lex_state = 2},
  [3186] = {.lex_state = 23, .external_lex_state = 2},
  [3187] = {.lex_state = 23, .external_lex_state = 2},
  [3188] = {.lex_state = 23, .external_lex_state = 2},
  [3189] = {.lex_state = 23, .external_lex_state = 2},
  [3190] = {.lex_state = 23, .external_lex_state = 2},
  [3191] = {.lex_state = 23, .external_lex_state = 2},
  [3192] = {.lex_state = 23, .external_lex_state = 2},
  [3193] = {.lex_state = 23, .external_lex_state = 2},
  [3194] = {.lex_state = 23, .external_lex_state = 2},
  [3195] = {.lex_state = 23, .external_lex_state = 2},
  [3196] = {.lex_state = 23, .external_lex_state = 2},
  [3197] = {.lex_state = 70, .external_lex_state = 18},
  [3198] = {.lex_state = 23, .external_lex_state = 2},
  [3199] = {.lex_state = 23, .external_lex_state = 2},
  [3200] = {.lex_state = 23, .external_lex_state = 2},
  [3201] = {.lex_state = 23, .external_lex_state = 2},
  [3202] = {.lex_state = 23, .external_lex_state = 2},
  [3203] = {.lex_state = 23, .external_lex_state = 2},
  [3204] = {.lex_state = 23, .external_lex_state = 2},
  [3205] = {.lex_state = 23, .external_lex_state = 2},
  [3206] = {.lex_state = 23, .external_lex_state = 2},
  [3207] = {.lex_state = 23, .external_lex_state = 2},
  [3208] = {.lex_state = 23, .external_lex_state = 2},
  [3209] = {.lex_state = 23, .external_lex_state = 2},
  [3210] = {.lex_state = 23, .external_lex_state = 2},
  [3211] = {.lex_state = 23, .external_lex_state = 2},
  [3212] = {.lex_state = 23, .external_lex_state = 2},
  [3213] = {.lex_state = 23, .external_lex_state = 2},
  [3214] = {.lex_state = 23, .external_lex_state = 2},
  [3215] = {.lex_state = 23, .external_lex_state = 2},
  [3216] = {.lex_state = 23, .external_lex_state = 2},
  [3217] = {.lex_state = 23, .external_lex_state = 2},
  [3218] = {.lex_state = 23, .external_lex_state = 2},
  [3219] = {.lex_state = 23, .external_lex_state = 2},
  [3220] = {.lex_state = 23, .external_lex_state = 2},
  [3221] = {.lex_state = 23, .external_lex_state = 2},
  [3222] = {.lex_state = 23, .external_lex_state = 2},
  [3223] = {.lex_state = 23, .external_lex_state = 2},
  [3224] = {.lex_state = 23, .external_lex_state = 2},
  [3225] = {.lex_state = 23, .external_lex_state = 2},
  [3226] = {.lex_state = 23, .external_lex_state = 2},
  [3227] = {.lex_state = 23, .external_lex_state = 2},
  [3228] = {.lex_state = 23, .external_lex_state = 2},
  [3229] = {.lex_state = 23, .external_lex_state = 2},
  [3230] = {.lex_state = 23, .external_lex_state = 2},
  [3231] = {.lex_state = 23, .external_lex_state = 2},
  [3232] = {.lex_state = 23, .external_lex_state = 2},
  [3233] = {.lex_state = 23, .external_lex_state = 2},
  [3234] = {.lex_state = 23, .external_lex_state = 2},
  [3235] = {.lex_state = 23, .external_lex_state = 2},
  [3236] = {.lex_state = 23, .external_lex_state = 2},
  [3237] = {.lex_state = 23, .external_lex_state = 2},
  [3238] = {.lex_state = 23, .external_lex_state = 2},
  [3239] = {.lex_state = 23, .external_lex_state = 2},
  [3240] = {.lex_state = 23, .external_lex_state = 2},
  [3241] = {.lex_state = 23, .external_lex_state = 2},
  [3242] = {.lex_state = 23, .external_lex_state = 2},
  [3243] = {.lex_state = 23, .external_lex_state = 2},
  [3244] = {.lex_state = 23, .external_lex_state = 2},
  [3245] = {.lex_state = 23, .external_lex_state = 2},
  [3246] = {.lex_state = 23, .external_lex_state = 2},
  [3247] = {.lex_state = 23, .external_lex_state = 2},
  [3248] = {.lex_state = 23, .external_lex_state = 2},
  [3249] = {.lex_state = 23, .external_lex_state = 2},
  [3250] = {.lex_state = 23, .external_lex_state = 2},
  [3251] = {.lex_state = 23, .external_lex_state = 2},
  [3252] = {.lex_state = 23, .external_lex_state = 2},
  [3253] = {.lex_state = 23, .external_lex_state = 2},
  [3254] = {.lex_state = 23, .external_lex_state = 2},
  [3255] = {.lex_state = 23, .external_lex_state = 2},
  [3256] = {.lex_state = 23, .external_lex_state = 2},
  [3257] = {.lex_state = 23, .external_lex_state = 2},
  [3258] = {.lex_state = 23, .external_lex_state = 2},
  [3259] = {.lex_state = 23, .external_lex_state = 2},
  [3260] = {.lex_state = 23, .external_lex_state = 2},
  [3261] = {.lex_state = 23, .external_lex_state = 2},
  [3262] = {.lex_state = 23, .external_lex_state = 2},
  [3263] = {.lex_state = 23, .external_lex_state = 2},
  [3264] = {.lex_state = 23, .external_lex_state = 2},
  [3265] = {.lex_state = 23, .external_lex_state = 2},
  [3266] = {.lex_state = 23, .external_lex_state = 2},
  [3267] = {.lex_state = 23, .external_lex_state = 2},
  [3268] = {.lex_state = 23, .external_lex_state = 2},
  [3269] = {.lex_state = 23, .external_lex_state = 2},
  [3270] = {.lex_state = 23, .external_lex_state = 2},
  [3271] = {.lex_state = 23, .external_lex_state = 2},
  [3272] = {.lex_state = 23, .external_lex_state = 2},
  [3273] = {.lex_state = 23, .external_lex_state = 2},
  [3274] = {.lex_state = 23, .external_lex_state = 2},
  [3275] = {.lex_state = 23, .external_lex_state = 2},
  [3276] = {.lex_state = 23, .external_lex_state = 2},
  [3277] = {.lex_state = 23, .external_lex_state = 2},
  [3278] = {.lex_state = 23, .external_lex_state = 2},
  [3279] = {.lex_state = 23, .external_lex_state = 2},
  [3280] = {.lex_state = 23, .external_lex_state = 2},
  [3281] = {.lex_state = 23, .external_lex_state = 2},
  [3282] = {.lex_state = 23, .external_lex_state = 2},
  [3283] = {.lex_state = 23, .external_lex_state = 2},
  [3284] = {.lex_state = 23, .external_lex_state = 2},
  [3285] = {.lex_state = 23, .external_lex_state = 2},
  [3286] = {.lex_state = 23, .external_lex_state = 2},
  [3287] = {.lex_state = 23, .external_lex_state = 2},
  [3288] = {.lex_state = 23, .external_lex_state = 2},
  [3289] = {.lex_state = 23, .external_lex_state = 2},
  [3290] = {.lex_state = 23, .external_lex_state = 2},
  [3291] = {.lex_state = 23, .external_lex_state = 2},
  [3292] = {.lex_state = 23, .external_lex_state = 2},
  [3293] = {.lex_state = 23, .external_lex_state = 2},
  [3294] = {.lex_state = 23, .external_lex_state = 2},
  [3295] = {.lex_state = 23, .external_lex_state = 2},
  [3296] = {.lex_state = 23, .external_lex_state = 2},
  [3297] = {.lex_state = 23, .external_lex_state = 2},
  [3298] = {.lex_state = 23, .external_lex_state = 2},
  [3299] = {.lex_state = 23, .external_lex_state = 2},
  [3300] = {.lex_state = 23, .external_lex_state = 2},
  [3301] = {.lex_state = 23, .external_lex_state = 2},
  [3302] = {.lex_state = 23, .external_lex_state = 2},
  [3303] = {.lex_state = 23, .external_lex_state = 2},
  [3304] = {.lex_state = 23, .external_lex_state = 2},
  [3305] = {.lex_state = 23, .external_lex_state = 2},
  [3306] = {.lex_state = 23, .external_lex_state = 2},
  [3307] = {.lex_state = 23, .external_lex_state = 2},
  [3308] = {.lex_state = 23, .external_lex_state = 2},
  [3309] = {.lex_state = 23, .external_lex_state = 2},
  [3310] = {.lex_state = 23, .external_lex_state = 2},
  [3311] = {.lex_state = 23, .external_lex_state = 2},
  [3312] = {.lex_state = 23, .external_lex_state = 2},
  [3313] = {.lex_state = 23, .external_lex_state = 2},
  [3314] = {.lex_state = 23, .external_lex_state = 2},
  [3315] = {.lex_state = 23, .external_lex_state = 2},
  [3316] = {.lex_state = 23, .external_lex_state = 2},
  [3317] = {.lex_state = 23, .external_lex_state = 2},
  [3318] = {.lex_state = 23, .external_lex_state = 2},
  [3319] = {.lex_state = 23, .external_lex_state = 2},
  [3320] = {.lex_state = 23, .external_lex_state = 2},
  [3321] = {.lex_state = 23, .external_lex_state = 2},
  [3322] = {.lex_state = 23, .external_lex_state = 2},
  [3323] = {.lex_state = 23, .external_lex_state = 2},
  [3324] = {.lex_state = 70, .external_lex_state = 20},
  [3325] = {.lex_state = 23, .external_lex_state = 2},
  [3326] = {.lex_state = 23, .external_lex_state = 2},
  [3327] = {.lex_state = 23, .external_lex_state = 2},
  [3328] = {.lex_state = 23, .external_lex_state = 2},
  [3329] = {.lex_state = 23, .external_lex_state = 2},
  [3330] = {.lex_state = 23, .external_lex_state = 2},
  [3331] = {.lex_state = 23, .external_lex_state = 2},
  [3332] = {.lex_state = 23, .external_lex_state = 2},
  [3333] = {.lex_state = 23, .external_lex_state = 2},
  [3334] = {.lex_state = 23, .external_lex_state = 2},
  [3335] = {.lex_state = 23, .external_lex_state = 2},
  [3336] = {.lex_state = 23, .external_lex_state = 2},
  [3337] = {.lex_state = 23, .external_lex_state = 2},
  [3338] = {.lex_state = 23, .external_lex_state = 2},
  [3339] = {.lex_state = 23, .external_lex_state = 2},
  [3340] = {.lex_state = 23, .external_lex_state = 2},
  [3341] = {.lex_state = 23, .external_lex_state = 2},
  [3342] = {.lex_state = 23, .external_lex_state = 2},
  [3343] = {.lex_state = 23, .external_lex_state = 2},
  [3344] = {.lex_state = 23, .external_lex_state = 2},
  [3345] = {.lex_state = 23, .external_lex_state = 2},
  [3346] = {.lex_state = 23, .external_lex_state = 2},
  [3347] = {.lex_state = 23, .external_lex_state = 2},
  [3348] = {.lex_state = 23, .external_lex_state = 2},
  [3349] = {.lex_state = 23, .external_lex_state = 2},
  [3350] = {.lex_state = 23, .external_lex_state = 2},
  [3351] = {.lex_state = 23, .external_lex_state = 2},
  [3352] = {.lex_state = 23, .external_lex_state = 2},
  [3353] = {.lex_state = 23, .external_lex_state = 2},
  [3354] = {.lex_state = 23, .external_lex_state = 2},
  [3355] = {.lex_state = 23, .external_lex_state = 2},
  [3356] = {.lex_state = 23, .external_lex_state = 2},
  [3357] = {.lex_state = 23, .external_lex_state = 2},
  [3358] = {.lex_state = 23, .external_lex_state = 2},
  [3359] = {.lex_state = 23, .external_lex_state = 2},
  [3360] = {.lex_state = 23, .external_lex_state = 2},
  [3361] = {.lex_state = 23, .external_lex_state = 2},
  [3362] = {.lex_state = 23, .external_lex_state = 2},
  [3363] = {.lex_state = 23, .external_lex_state = 2},
  [3364] = {.lex_state = 23, .external_lex_state = 2},
  [3365] = {.lex_state = 23, .external_lex_state = 2},
  [3366] = {.lex_state = 23, .external_lex_state = 2},
  [3367] = {.lex_state = 23, .external_lex_state = 2},
  [3368] = {.lex_state = 23, .external_lex_state = 2},
  [3369] = {.lex_state = 23, .external_lex_state = 2},
  [3370] = {.lex_state = 23, .external_lex_state = 2},
  [3371] = {.lex_state = 23, .external_lex_state = 2},
  [3372] = {.lex_state = 23, .external_lex_state = 2},
  [3373] = {.lex_state = 23, .external_lex_state = 2},
  [3374] = {.lex_state = 23, .external_lex_state = 2},
  [3375] = {.lex_state = 23, .external_lex_state = 2},
  [3376] = {.lex_state = 23, .external_lex_state = 2},
  [3377] = {.lex_state = 23, .external_lex_state = 2},
  [3378] = {.lex_state = 23, .external_lex_state = 2},
  [3379] = {.lex_state = 23, .external_lex_state = 2},
  [3380] = {.lex_state = 23, .external_lex_state = 2},
  [3381] = {.lex_state = 23, .external_lex_state = 2},
  [3382] = {.lex_state = 23, .external_lex_state = 2},
  [3383] = {.lex_state = 23, .external_lex_state = 2},
  [3384] = {.lex_state = 70, .external_lex_state = 7},
  [3385] = {.lex_state = 23, .external_lex_state = 2},
  [3386] = {.lex_state = 23, .external_lex_state = 2},
  [3387] = {.lex_state = 23, .external_lex_state = 2},
  [3388] = {.lex_state = 23, .external_lex_state = 2},
  [3389] = {.lex_state = 23, .external_lex_state = 2},
  [3390] = {.lex_state = 23, .external_lex_state = 2},
  [3391] = {.lex_state = 23, .external_lex_state = 2},
  [3392] = {.lex_state = 23, .external_lex_state = 2},
  [3393] = {.lex_state = 23, .external_lex_state = 2},
  [3394] = {.lex_state = 23, .external_lex_state = 2},
  [3395] = {.lex_state = 23, .external_lex_state = 2},
  [3396] = {.lex_state = 23, .external_lex_state = 2},
  [3397] = {.lex_state = 70, .external_lex_state = 16},
  [3398] = {.lex_state = 23, .external_lex_state = 2},
  [3399] = {.lex_state = 23, .external_lex_state = 2},
  [3400] = {.lex_state = 23, .external_lex_state = 2},
  [3401] = {.lex_state = 23, .external_lex_state = 2},
  [3402] = {.lex_state = 23, .external_lex_state = 2},
  [3403] = {.lex_state = 23, .external_lex_state = 2},
  [3404] = {.lex_state = 23, .external_lex_state = 2},
  [3405] = {.lex_state = 23, .external_lex_state = 2},
  [3406] = {.lex_state = 23, .external_lex_state = 2},
  [3407] = {.lex_state = 23, .external_lex_state = 2},
  [3408] = {.lex_state = 23, .external_lex_state = 2},
  [3409] = {.lex_state = 23, .external_lex_state = 2},
  [3410] = {.lex_state = 23, .external_lex_state = 2},
  [3411] = {.lex_state = 23, .external_lex_state = 2},
  [3412] = {.lex_state = 23, .external_lex_state = 2},
  [3413] = {.lex_state = 23, .external_lex_state = 2},
  [3414] = {.lex_state = 23, .external_lex_state = 2},
  [3415] = {.lex_state = 23, .external_lex_state = 2},
  [3416] = {.lex_state = 23, .external_lex_state = 2},
  [3417] = {.lex_state = 23, .external_lex_state = 2},
  [3418] = {.lex_state = 23, .external_lex_state = 2},
  [3419] = {.lex_state = 23, .external_lex_state = 2},
  [3420] = {.lex_state = 23, .external_lex_state = 2},
  [3421] = {.lex_state = 23, .external_lex_state = 2},
  [3422] = {.lex_state = 23, .external_lex_state = 2},
  [3423] = {.lex_state = 23, .external_lex_state = 2},
  [3424] = {.lex_state = 23, .external_lex_state = 2},
  [3425] = {.lex_state = 23, .external_lex_state = 2},
  [3426] = {.lex_state = 23, .external_lex_state = 2},
  [3427] = {.lex_state = 23, .external_lex_state = 2},
  [3428] = {.lex_state = 23, .external_lex_state = 2},
  [3429] = {.lex_state = 23, .external_lex_state = 2},
  [3430] = {.lex_state = 23, .external_lex_state = 2},
  [3431] = {.lex_state = 23, .external_lex_state = 2},
  [3432] = {.lex_state = 23, .external_lex_state = 2},
  [3433] = {.lex_state = 23, .external_lex_state = 2},
  [3434] = {.lex_state = 23, .external_lex_state = 2},
  [3435] = {.lex_state = 23, .external_lex_state = 2},
  [3436] = {.lex_state = 23, .external_lex_state = 2},
  [3437] = {.lex_state = 23, .external_lex_state = 2},
  [3438] = {.lex_state = 23, .external_lex_state = 2},
  [3439] = {.lex_state = 23, .external_lex_state = 2},
  [3440] = {.lex_state = 23, .external_lex_state = 2},
  [3441] = {.lex_state = 23, .external_lex_state = 2},
  [3442] = {.lex_state = 23, .external_lex_state = 2},
  [3443] = {.lex_state = 23, .external_lex_state = 2},
  [3444] = {.lex_state = 23, .external_lex_state = 2},
  [3445] = {.lex_state = 23, .external_lex_state = 2},
  [3446] = {.lex_state = 23, .external_lex_state = 2},
  [3447] = {.lex_state = 23, .external_lex_state = 2},
  [3448] = {.lex_state = 23, .external_lex_state = 2},
  [3449] = {.lex_state = 23, .external_lex_state = 2},
  [3450] = {.lex_state = 23, .external_lex_state = 2},
  [3451] = {.lex_state = 23, .external_lex_state = 2},
  [3452] = {.lex_state = 23, .external_lex_state = 2},
  [3453] = {.lex_state = 23, .external_lex_state = 2},
  [3454] = {.lex_state = 23, .external_lex_state = 2},
  [3455] = {.lex_state = 23, .external_lex_state = 2},
  [3456] = {.lex_state = 23, .external_lex_state = 2},
  [3457] = {.lex_state = 23, .external_lex_state = 2},
  [3458] = {.lex_state = 23, .external_lex_state = 2},
  [3459] = {.lex_state = 23, .external_lex_state = 2},
  [3460] = {.lex_state = 23, .external_lex_state = 2},
  [3461] = {.lex_state = 23, .external_lex_state = 2},
  [3462] = {.lex_state = 23, .external_lex_state = 2},
  [3463] = {.lex_state = 23, .external_lex_state = 2},
  [3464] = {.lex_state = 23, .external_lex_state = 2},
  [3465] = {.lex_state = 23, .external_lex_state = 2},
  [3466] = {.lex_state = 23, .external_lex_state = 2},
  [3467] = {.lex_state = 23, .external_lex_state = 2},
  [3468] = {.lex_state = 23, .external_lex_state = 2},
  [3469] = {.lex_state = 23, .external_lex_state = 2},
  [3470] = {.lex_state = 23, .external_lex_state = 2},
  [3471] = {.lex_state = 23, .external_lex_state = 2},
  [3472] = {.lex_state = 23, .external_lex_state = 2},
  [3473] = {.lex_state = 23, .external_lex_state = 2},
  [3474] = {.lex_state = 23, .external_lex_state = 2},
  [3475] = {.lex_state = 23, .external_lex_state = 2},
  [3476] = {.lex_state = 23, .external_lex_state = 2},
  [3477] = {.lex_state = 23, .external_lex_state = 2},
  [3478] = {.lex_state = 23, .external_lex_state = 2},
  [3479] = {.lex_state = 23, .external_lex_state = 2},
  [3480] = {.lex_state = 23, .external_lex_state = 2},
  [3481] = {.lex_state = 23, .external_lex_state = 2},
  [3482] = {.lex_state = 23, .external_lex_state = 2},
  [3483] = {.lex_state = 23, .external_lex_state = 2},
  [3484] = {.lex_state = 23, .external_lex_state = 2},
  [3485] = {.lex_state = 23, .external_lex_state = 2},
  [3486] = {.lex_state = 23, .external_lex_state = 2},
  [3487] = {.lex_state = 23, .external_lex_state = 2},
  [3488] = {.lex_state = 23, .external_lex_state = 2},
  [3489] = {.lex_state = 23, .external_lex_state = 2},
  [3490] = {.lex_state = 23, .external_lex_state = 2},
  [3491] = {.lex_state = 23, .external_lex_state = 2},
  [3492] = {.lex_state = 23, .external_lex_state = 2},
  [3493] = {.lex_state = 23, .external_lex_state = 2},
  [3494] = {.lex_state = 23, .external_lex_state = 2},
  [3495] = {.lex_state = 23, .external_lex_state = 2},
  [3496] = {.lex_state = 23, .external_lex_state = 2},
  [3497] = {.lex_state = 23, .external_lex_state = 2},
  [3498] = {.lex_state = 23, .external_lex_state = 2},
  [3499] = {.lex_state = 23, .external_lex_state = 2},
  [3500] = {.lex_state = 23, .external_lex_state = 2},
  [3501] = {.lex_state = 23, .external_lex_state = 2},
  [3502] = {.lex_state = 23, .external_lex_state = 2},
  [3503] = {.lex_state = 23, .external_lex_state = 2},
  [3504] = {.lex_state = 23, .external_lex_state = 2},
  [3505] = {.lex_state = 23, .external_lex_state = 2},
  [3506] = {.lex_state = 23, .external_lex_state = 2},
  [3507] = {.lex_state = 23, .external_lex_state = 2},
  [3508] = {.lex_state = 23, .external_lex_state = 2},
  [3509] = {.lex_state = 23, .external_lex_state = 2},
  [3510] = {.lex_state = 23, .external_lex_state = 2},
  [3511] = {.lex_state = 23, .external_lex_state = 2},
  [3512] = {.lex_state = 23, .external_lex_state = 2},
  [3513] = {.lex_state = 23, .external_lex_state = 2},
  [3514] = {.lex_state = 23, .external_lex_state = 2},
  [3515] = {.lex_state = 23, .external_lex_state = 2},
  [3516] = {.lex_state = 23, .external_lex_state = 2},
  [3517] = {.lex_state = 23, .external_lex_state = 2},
  [3518] = {.lex_state = 23, .external_lex_state = 2},
  [3519] = {.lex_state = 23, .external_lex_state = 2},
  [3520] = {.lex_state = 23, .external_lex_state = 2},
  [3521] = {.lex_state = 23, .external_lex_state = 2},
  [3522] = {.lex_state = 23, .external_lex_state = 2},
  [3523] = {.lex_state = 23, .external_lex_state = 2},
  [3524] = {.lex_state = 23, .external_lex_state = 2},
  [3525] = {.lex_state = 23, .external_lex_state = 2},
  [3526] = {.lex_state = 23, .external_lex_state = 2},
  [3527] = {.lex_state = 23, .external_lex_state = 2},
  [3528] = {.lex_state = 23, .external_lex_state = 2},
  [3529] = {.lex_state = 23, .external_lex_state = 2},
  [3530] = {.lex_state = 23, .external_lex_state = 2},
  [3531] = {.lex_state = 23, .external_lex_state = 2},
  [3532] = {.lex_state = 23, .external_lex_state = 2},
  [3533] = {.lex_state = 23, .external_lex_state = 2},
  [3534] = {.lex_state = 23, .external_lex_state = 2},
  [3535] = {.lex_state = 23, .external_lex_state = 2},
  [3536] = {.lex_state = 23, .external_lex_state = 2},
  [3537] = {.lex_state = 23, .external_lex_state = 2},
  [3538] = {.lex_state = 23, .external_lex_state = 2},
  [3539] = {.lex_state = 23, .external_lex_state = 2},
  [3540] = {.lex_state = 23, .external_lex_state = 2},
  [3541] = {.lex_state = 23, .external_lex_state = 2},
  [3542] = {.lex_state = 23, .external_lex_state = 2},
  [3543] = {.lex_state = 23, .external_lex_state = 2},
  [3544] = {.lex_state = 23, .external_lex_state = 2},
  [3545] = {.lex_state = 23, .external_lex_state = 2},
  [3546] = {.lex_state = 23, .external_lex_state = 2},
  [3547] = {.lex_state = 23, .external_lex_state = 2},
  [3548] = {.lex_state = 23, .external_lex_state = 2},
  [3549] = {.lex_state = 23, .external_lex_state = 2},
  [3550] = {.lex_state = 23, .external_lex_state = 2},
  [3551] = {.lex_state = 23, .external_lex_state = 2},
  [3552] = {.lex_state = 23, .external_lex_state = 2},
  [3553] = {.lex_state = 23, .external_lex_state = 2},
  [3554] = {.lex_state = 23, .external_lex_state = 2},
  [3555] = {.lex_state = 23, .external_lex_state = 2},
  [3556] = {.lex_state = 23, .external_lex_state = 2},
  [3557] = {.lex_state = 23, .external_lex_state = 2},
  [3558] = {.lex_state = 23, .external_lex_state = 2},
  [3559] = {.lex_state = 23, .external_lex_state = 2},
  [3560] = {.lex_state = 23, .external_lex_state = 2},
  [3561] = {.lex_state = 23, .external_lex_state = 2},
  [3562] = {.lex_state = 23, .external_lex_state = 2},
  [3563] = {.lex_state = 23, .external_lex_state = 2},
  [3564] = {.lex_state = 23, .external_lex_state = 2},
  [3565] = {.lex_state = 23, .external_lex_state = 2},
  [3566] = {.lex_state = 23, .external_lex_state = 2},
  [3567] = {.lex_state = 23, .external_lex_state = 2},
  [3568] = {.lex_state = 23, .external_lex_state = 2},
  [3569] = {.lex_state = 23, .external_lex_state = 2},
  [3570] = {.lex_state = 23, .external_lex_state = 2},
  [3571] = {.lex_state = 23, .external_lex_state = 2},
  [3572] = {.lex_state = 23, .external_lex_state = 2},
  [3573] = {.lex_state = 23, .external_lex_state = 2},
  [3574] = {.lex_state = 23, .external_lex_state = 2},
  [3575] = {.lex_state = 23, .external_lex_state = 2},
  [3576] = {.lex_state = 23, .external_lex_state = 2},
  [3577] = {.lex_state = 23, .external_lex_state = 2},
  [3578] = {.lex_state = 23, .external_lex_state = 2},
  [3579] = {.lex_state = 23, .external_lex_state = 2},
  [3580] = {.lex_state = 23, .external_lex_state = 2},
  [3581] = {.lex_state = 23, .external_lex_state = 2},
  [3582] = {.lex_state = 23, .external_lex_state = 2},
  [3583] = {.lex_state = 23, .external_lex_state = 2},
  [3584] = {.lex_state = 23, .external_lex_state = 2},
  [3585] = {.lex_state = 23, .external_lex_state = 2},
  [3586] = {.lex_state = 23, .external_lex_state = 2},
  [3587] = {.lex_state = 23, .external_lex_state = 2},
  [3588] = {.lex_state = 23, .external_lex_state = 2},
  [3589] = {.lex_state = 23, .external_lex_state = 2},
  [3590] = {.lex_state = 23, .external_lex_state = 2},
  [3591] = {.lex_state = 23, .external_lex_state = 2},
  [3592] = {.lex_state = 23, .external_lex_state = 2},
  [3593] = {.lex_state = 23, .external_lex_state = 2},
  [3594] = {.lex_state = 23, .external_lex_state = 2},
  [3595] = {.lex_state = 70, .external_lex_state = 17},
  [3596] = {.lex_state = 23, .external_lex_state = 2},
  [3597] = {.lex_state = 23, .external_lex_state = 2},
  [3598] = {.lex_state = 23, .external_lex_state = 2},
  [3599] = {.lex_state = 23, .external_lex_state = 2},
  [3600] = {.lex_state = 23, .external_lex_state = 2},
  [3601] = {.lex_state = 23, .external_lex_state = 2},
  [3602] = {.lex_state = 23, .external_lex_state = 2},
  [3603] = {.lex_state = 23, .external_lex_state = 2},
  [3604] = {.lex_state = 23, .external_lex_state = 2},
  [3605] = {.lex_state = 23, .external_lex_state = 2},
  [3606] = {.lex_state = 23, .external_lex_state = 2},
  [3607] = {.lex_state = 23, .external_lex_state = 2},
  [3608] = {.lex_state = 23, .external_lex_state = 2},
  [3609] = {.lex_state = 23, .external_lex_state = 2},
  [3610] = {.lex_state = 23, .external_lex_state = 2},
  [3611] = {.lex_state = 23, .external_lex_state = 2},
  [3612] = {.lex_state = 23, .external_lex_state = 2},
  [3613] = {.lex_state = 23, .external_lex_state = 2},
  [3614] = {.lex_state = 23, .external_lex_state = 2},
  [3615] = {.lex_state = 23, .external_lex_state = 2},
  [3616] = {.lex_state = 23, .external_lex_state = 2},
  [3617] = {.lex_state = 23, .external_lex_state = 2},
  [3618] = {.lex_state = 23, .external_lex_state = 2},
  [3619] = {.lex_state = 23, .external_lex_state = 2},
  [3620] = {.lex_state = 23, .external_lex_state = 2},
  [3621] = {.lex_state = 23, .external_lex_state = 2},
  [3622] = {.lex_state = 23, .external_lex_state = 2},
  [3623] = {.lex_state = 23, .external_lex_state = 2},
  [3624] = {.lex_state = 23, .external_lex_state = 2},
  [3625] = {.lex_state = 23, .external_lex_state = 2},
  [3626] = {.lex_state = 23, .external_lex_state = 2},
  [3627] = {.lex_state = 23, .external_lex_state = 2},
  [3628] = {.lex_state = 23, .external_lex_state = 2},
  [3629] = {.lex_state = 23, .external_lex_state = 2},
  [3630] = {.lex_state = 23, .external_lex_state = 2},
  [3631] = {.lex_state = 23, .external_lex_state = 2},
  [3632] = {.lex_state = 23, .external_lex_state = 2},
  [3633] = {.lex_state = 23, .external_lex_state = 2},
  [3634] = {.lex_state = 23, .external_lex_state = 2},
  [3635] = {.lex_state = 23, .external_lex_state = 2},
  [3636] = {.lex_state = 23, .external_lex_state = 2},
  [3637] = {.lex_state = 23, .external_lex_state = 2},
  [3638] = {.lex_state = 23, .external_lex_state = 2},
  [3639] = {.lex_state = 23, .external_lex_state = 2},
  [3640] = {.lex_state = 23, .external_lex_state = 2},
  [3641] = {.lex_state = 23, .external_lex_state = 2},
  [3642] = {.lex_state = 23, .external_lex_state = 2},
  [3643] = {.lex_state = 23, .external_lex_state = 2},
  [3644] = {.lex_state = 23, .external_lex_state = 2},
  [3645] = {.lex_state = 23, .external_lex_state = 2},
  [3646] = {.lex_state = 23, .external_lex_state = 2},
  [3647] = {.lex_state = 23, .external_lex_state = 2},
  [3648] = {.lex_state = 23, .external_lex_state = 2},
  [3649] = {.lex_state = 23, .external_lex_state = 2},
  [3650] = {.lex_state = 23, .external_lex_state = 2},
  [3651] = {.lex_state = 23, .external_lex_state = 2},
  [3652] = {.lex_state = 23, .external_lex_state = 2},
  [3653] = {.lex_state = 23, .external_lex_state = 2},
  [3654] = {.lex_state = 23, .external_lex_state = 2},
  [3655] = {.lex_state = 23, .external_lex_state = 2},
  [3656] = {.lex_state = 23, .external_lex_state = 2},
  [3657] = {.lex_state = 23, .external_lex_state = 2},
  [3658] = {.lex_state = 23, .external_lex_state = 2},
  [3659] = {.lex_state = 23, .external_lex_state = 2},
  [3660] = {.lex_state = 23, .external_lex_state = 2},
  [3661] = {.lex_state = 23, .external_lex_state = 2},
  [3662] = {.lex_state = 23, .external_lex_state = 2},
  [3663] = {.lex_state = 23, .external_lex_state = 2},
  [3664] = {.lex_state = 23, .external_lex_state = 2},
  [3665] = {.lex_state = 23, .external_lex_state = 2},
  [3666] = {.lex_state = 23, .external_lex_state = 2},
  [3667] = {.lex_state = 23, .external_lex_state = 2},
  [3668] = {.lex_state = 23, .external_lex_state = 2},
  [3669] = {.lex_state = 23, .external_lex_state = 2},
  [3670] = {.lex_state = 23, .external_lex_state = 2},
  [3671] = {.lex_state = 23, .external_lex_state = 2},
  [3672] = {.lex_state = 23, .external_lex_state = 2},
  [3673] = {.lex_state = 23, .external_lex_state = 2},
  [3674] = {.lex_state = 23, .external_lex_state = 2},
  [3675] = {.lex_state = 23, .external_lex_state = 2},
  [3676] = {.lex_state = 23, .external_lex_state = 2},
  [3677] = {.lex_state = 23, .external_lex_state = 2},
  [3678] = {.lex_state = 23, .external_lex_state = 2},
  [3679] = {.lex_state = 23, .external_lex_state = 2},
  [3680] = {.lex_state = 23, .external_lex_state = 2},
  [3681] = {.lex_state = 23, .external_lex_state = 2},
  [3682] = {.lex_state = 23, .external_lex_state = 2},
  [3683] = {.lex_state = 23, .external_lex_state = 2},
  [3684] = {.lex_state = 23, .external_lex_state = 2},
  [3685] = {.lex_state = 23, .external_lex_state = 2},
  [3686] = {.lex_state = 23, .external_lex_state = 2},
  [3687] = {.lex_state = 23, .external_lex_state = 2},
  [3688] = {.lex_state = 23, .external_lex_state = 2},
  [3689] = {.lex_state = 23, .external_lex_state = 2},
  [3690] = {.lex_state = 23, .external_lex_state = 2},
  [3691] = {.lex_state = 23, .external_lex_state = 2},
  [3692] = {.lex_state = 23, .external_lex_state = 2},
  [3693] = {.lex_state = 23, .external_lex_state = 2},
  [3694] = {.lex_state = 23, .external_lex_state = 2},
  [3695] = {.lex_state = 23, .external_lex_state = 2},
  [3696] = {.lex_state = 23, .external_lex_state = 2},
  [3697] = {.lex_state = 23, .external_lex_state = 2},
  [3698] = {.lex_state = 23, .external_lex_state = 2},
  [3699] = {.lex_state = 23, .external_lex_state = 2},
  [3700] = {.lex_state = 23, .external_lex_state = 2},
  [3701] = {.lex_state = 23, .external_lex_state = 2},
  [3702] = {.lex_state = 23, .external_lex_state = 2},
  [3703] = {.lex_state = 23, .external_lex_state = 2},
  [3704] = {.lex_state = 23, .external_lex_state = 2},
  [3705] = {.lex_state = 23, .external_lex_state = 2},
  [3706] = {.lex_state = 23, .external_lex_state = 2},
  [3707] = {.lex_state = 23, .external_lex_state = 2},
  [3708] = {.lex_state = 23, .external_lex_state = 2},
  [3709] = {.lex_state = 23, .external_lex_state = 2},
  [3710] = {.lex_state = 23, .external_lex_state = 2},
  [3711] = {.lex_state = 23, .external_lex_state = 2},
  [3712] = {.lex_state = 23, .external_lex_state = 2},
  [3713] = {.lex_state = 23, .external_lex_state = 2},
  [3714] = {.lex_state = 23, .external_lex_state = 2},
  [3715] = {.lex_state = 23, .external_lex_state = 2},
  [3716] = {.lex_state = 23, .external_lex_state = 2},
  [3717] = {.lex_state = 23, .external_lex_state = 2},
  [3718] = {.lex_state = 23, .external_lex_state = 2},
  [3719] = {.lex_state = 23, .external_lex_state = 2},
  [3720] = {.lex_state = 23, .external_lex_state = 2},
  [3721] = {.lex_state = 23, .external_lex_state = 2},
  [3722] = {.lex_state = 23, .external_lex_state = 2},
  [3723] = {.lex_state = 23, .external_lex_state = 2},
  [3724] = {.lex_state = 23, .external_lex_state = 2},
  [3725] = {.lex_state = 23, .external_lex_state = 2},
  [3726] = {.lex_state = 23, .external_lex_state = 2},
  [3727] = {.lex_state = 23, .external_lex_state = 2},
  [3728] = {.lex_state = 23, .external_lex_state = 2},
  [3729] = {.lex_state = 23, .external_lex_state = 2},
  [3730] = {.lex_state = 23, .external_lex_state = 2},
  [3731] = {.lex_state = 23, .external_lex_state = 2},
  [3732] = {.lex_state = 23, .external_lex_state = 2},
  [3733] = {.lex_state = 23, .external_lex_state = 2},
  [3734] = {.lex_state = 23, .external_lex_state = 2},
  [3735] = {.lex_state = 23, .external_lex_state = 2},
  [3736] = {.lex_state = 23, .external_lex_state = 2},
  [3737] = {.lex_state = 23, .external_lex_state = 2},
  [3738] = {.lex_state = 23, .external_lex_state = 2},
  [3739] = {.lex_state = 23, .external_lex_state = 2},
  [3740] = {.lex_state = 23, .external_lex_state = 2},
  [3741] = {.lex_state = 23, .external_lex_state = 2},
  [3742] = {.lex_state = 23, .external_lex_state = 2},
  [3743] = {.lex_state = 23, .external_lex_state = 2},
  [3744] = {.lex_state = 23, .external_lex_state = 2},
  [3745] = {.lex_state = 23, .external_lex_state = 2},
  [3746] = {.lex_state = 23, .external_lex_state = 2},
  [3747] = {.lex_state = 23, .external_lex_state = 2},
  [3748] = {.lex_state = 23, .external_lex_state = 2},
  [3749] = {.lex_state = 23, .external_lex_state = 2},
  [3750] = {.lex_state = 23, .external_lex_state = 2},
  [3751] = {.lex_state = 23, .external_lex_state = 2},
  [3752] = {.lex_state = 23, .external_lex_state = 2},
  [3753] = {.lex_state = 23, .external_lex_state = 2},
  [3754] = {.lex_state = 23, .external_lex_state = 2},
  [3755] = {.lex_state = 23, .external_lex_state = 2},
  [3756] = {.lex_state = 23, .external_lex_state = 2},
  [3757] = {.lex_state = 23, .external_lex_state = 2},
  [3758] = {.lex_state = 23, .external_lex_state = 2},
  [3759] = {.lex_state = 23, .external_lex_state = 2},
  [3760] = {.lex_state = 23, .external_lex_state = 2},
  [3761] = {.lex_state = 23, .external_lex_state = 2},
  [3762] = {.lex_state = 23, .external_lex_state = 2},
  [3763] = {.lex_state = 23, .external_lex_state = 2},
  [3764] = {.lex_state = 23, .external_lex_state = 2},
  [3765] = {.lex_state = 23, .external_lex_state = 2},
  [3766] = {.lex_state = 23, .external_lex_state = 2},
  [3767] = {.lex_state = 23, .external_lex_state = 2},
  [3768] = {.lex_state = 23, .external_lex_state = 2},
  [3769] = {.lex_state = 23, .external_lex_state = 2},
  [3770] = {.lex_state = 23, .external_lex_state = 2},
  [3771] = {.lex_state = 23, .external_lex_state = 2},
  [3772] = {.lex_state = 23, .external_lex_state = 2},
  [3773] = {.lex_state = 23, .external_lex_state = 2},
  [3774] = {.lex_state = 23, .external_lex_state = 2},
  [3775] = {.lex_state = 23, .external_lex_state = 2},
  [3776] = {.lex_state = 23, .external_lex_state = 2},
  [3777] = {.lex_state = 23, .external_lex_state = 2},
  [3778] = {.lex_state = 23, .external_lex_state = 2},
  [3779] = {.lex_state = 23, .external_lex_state = 2},
  [3780] = {.lex_state = 23, .external_lex_state = 2},
  [3781] = {.lex_state = 23, .external_lex_state = 2},
  [3782] = {.lex_state = 23, .external_lex_state = 2},
  [3783] = {.lex_state = 23, .external_lex_state = 2},
  [3784] = {.lex_state = 23, .external_lex_state = 2},
  [3785] = {.lex_state = 23, .external_lex_state = 2},
  [3786] = {.lex_state = 23, .external_lex_state = 2},
  [3787] = {.lex_state = 23, .external_lex_state = 2},
  [3788] = {.lex_state = 23, .external_lex_state = 2},
  [3789] = {.lex_state = 23, .external_lex_state = 2},
  [3790] = {.lex_state = 23, .external_lex_state = 2},
  [3791] = {.lex_state = 23, .external_lex_state = 2},
  [3792] = {.lex_state = 23, .external_lex_state = 2},
  [3793] = {.lex_state = 23, .external_lex_state = 2},
  [3794] = {.lex_state = 23, .external_lex_state = 2},
  [3795] = {.lex_state = 23, .external_lex_state = 2},
  [3796] = {.lex_state = 23, .external_lex_state = 2},
  [3797] = {.lex_state = 23, .external_lex_state = 2},
  [3798] = {.lex_state = 23, .external_lex_state = 2},
  [3799] = {.lex_state = 23, .external_lex_state = 2},
  [3800] = {.lex_state = 23, .external_lex_state = 2},
  [3801] = {.lex_state = 23, .external_lex_state = 2},
  [3802] = {.lex_state = 23, .external_lex_state = 2},
  [3803] = {.lex_state = 23, .external_lex_state = 2},
  [3804] = {.lex_state = 23, .external_lex_state = 2},
  [3805] = {.lex_state = 23, .external_lex_state = 2},
  [3806] = {.lex_state = 23, .external_lex_state = 2},
  [3807] = {.lex_state = 23, .external_lex_state = 2},
  [3808] = {.lex_state = 23, .external_lex_state = 2},
  [3809] = {.lex_state = 23, .external_lex_state = 2},
  [3810] = {.lex_state = 23, .external_lex_state = 2},
  [3811] = {.lex_state = 23, .external_lex_state = 2},
  [3812] = {.lex_state = 23, .external_lex_state = 2},
  [3813] = {.lex_state = 23, .external_lex_state = 2},
  [3814] = {.lex_state = 23, .external_lex_state = 2},
  [3815] = {.lex_state = 23, .external_lex_state = 2},
  [3816] = {.lex_state = 23, .external_lex_state = 2},
  [3817] = {.lex_state = 23, .external_lex_state = 2},
  [3818] = {.lex_state = 23, .external_lex_state = 2},
  [3819] = {.lex_state = 23, .external_lex_state = 2},
  [3820] = {.lex_state = 23, .external_lex_state = 2},
  [3821] = {.lex_state = 23, .external_lex_state = 2},
  [3822] = {.lex_state = 23, .external_lex_state = 2},
  [3823] = {.lex_state = 23, .external_lex_state = 2},
  [3824] = {.lex_state = 23, .external_lex_state = 2},
  [3825] = {.lex_state = 23, .external_lex_state = 2},
  [3826] = {.lex_state = 23, .external_lex_state = 2},
  [3827] = {.lex_state = 23, .external_lex_state = 2},
  [3828] = {.lex_state = 23, .external_lex_state = 2},
  [3829] = {.lex_state = 23, .external_lex_state = 2},
  [3830] = {.lex_state = 23, .external_lex_state = 2},
  [3831] = {.lex_state = 23, .external_lex_state = 2},
  [3832] = {.lex_state = 23, .external_lex_state = 2},
  [3833] = {.lex_state = 23, .external_lex_state = 2},
  [3834] = {.lex_state = 23, .external_lex_state = 2},
  [3835] = {.lex_state = 23, .external_lex_state = 2},
  [3836] = {.lex_state = 23, .external_lex_state = 2},
  [3837] = {.lex_state = 23, .external_lex_state = 2},
  [3838] = {.lex_state = 23, .external_lex_state = 2},
  [3839] = {.lex_state = 23, .external_lex_state = 2},
  [3840] = {.lex_state = 23, .external_lex_state = 2},
  [3841] = {.lex_state = 23, .external_lex_state = 2},
  [3842] = {.lex_state = 23, .external_lex_state = 2},
  [3843] = {.lex_state = 23, .external_lex_state = 2},
  [3844] = {.lex_state = 23, .external_lex_state = 2},
  [3845] = {.lex_state = 23, .external_lex_state = 2},
  [3846] = {.lex_state = 23, .external_lex_state = 2},
  [3847] = {.lex_state = 23, .external_lex_state = 2},
  [3848] = {.lex_state = 23, .external_lex_state = 2},
  [3849] = {.lex_state = 23, .external_lex_state = 2},
  [3850] = {.lex_state = 23, .external_lex_state = 2},
  [3851] = {.lex_state = 23, .external_lex_state = 2},
  [3852] = {.lex_state = 23, .external_lex_state = 2},
  [3853] = {.lex_state = 23, .external_lex_state = 2},
  [3854] = {.lex_state = 23, .external_lex_state = 2},
  [3855] = {.lex_state = 23, .external_lex_state = 2},
  [3856] = {.lex_state = 23, .external_lex_state = 2},
  [3857] = {.lex_state = 23, .external_lex_state = 2},
  [3858] = {.lex_state = 23, .external_lex_state = 2},
  [3859] = {.lex_state = 23, .external_lex_state = 2},
  [3860] = {.lex_state = 23, .external_lex_state = 2},
  [3861] = {.lex_state = 23, .external_lex_state = 2},
  [3862] = {.lex_state = 23, .external_lex_state = 2},
  [3863] = {.lex_state = 23, .external_lex_state = 2},
  [3864] = {.lex_state = 23, .external_lex_state = 2},
  [3865] = {.lex_state = 23, .external_lex_state = 2},
  [3866] = {.lex_state = 23, .external_lex_state = 2},
  [3867] = {.lex_state = 23, .external_lex_state = 2},
  [3868] = {.lex_state = 23, .external_lex_state = 2},
  [3869] = {.lex_state = 23, .external_lex_state = 2},
  [3870] = {.lex_state = 23, .external_lex_state = 2},
  [3871] = {.lex_state = 23, .external_lex_state = 2},
  [3872] = {.lex_state = 23, .external_lex_state = 2},
  [3873] = {.lex_state = 23, .external_lex_state = 2},
  [3874] = {.lex_state = 23, .external_lex_state = 2},
  [3875] = {.lex_state = 23, .external_lex_state = 2},
  [3876] = {.lex_state = 23, .external_lex_state = 2},
  [3877] = {.lex_state = 23, .external_lex_state = 2},
  [3878] = {.lex_state = 23, .external_lex_state = 2},
  [3879] = {.lex_state = 23, .external_lex_state = 2},
  [3880] = {.lex_state = 23, .external_lex_state = 2},
  [3881] = {.lex_state = 23, .external_lex_state = 2},
  [3882] = {.lex_state = 23, .external_lex_state = 2},
  [3883] = {.lex_state = 23, .external_lex_state = 2},
  [3884] = {.lex_state = 23, .external_lex_state = 2},
  [3885] = {.lex_state = 23, .external_lex_state = 2},
  [3886] = {.lex_state = 23, .external_lex_state = 2},
  [3887] = {.lex_state = 23, .external_lex_state = 2},
  [3888] = {.lex_state = 23, .external_lex_state = 2},
  [3889] = {.lex_state = 23, .external_lex_state = 2},
  [3890] = {.lex_state = 23, .external_lex_state = 2},
  [3891] = {.lex_state = 23, .external_lex_state = 2},
  [3892] = {.lex_state = 23, .external_lex_state = 2},
  [3893] = {.lex_state = 23, .external_lex_state = 2},
  [3894] = {.lex_state = 23, .external_lex_state = 2},
  [3895] = {.lex_state = 23, .external_lex_state = 2},
  [3896] = {.lex_state = 23, .external_lex_state = 2},
  [3897] = {.lex_state = 23, .external_lex_state = 2},
  [3898] = {.lex_state = 23, .external_lex_state = 2},
  [3899] = {.lex_state = 23, .external_lex_state = 2},
  [3900] = {.lex_state = 23, .external_lex_state = 2},
  [3901] = {.lex_state = 23, .external_lex_state = 2},
  [3902] = {.lex_state = 23, .external_lex_state = 2},
  [3903] = {.lex_state = 23, .external_lex_state = 2},
  [3904] = {.lex_state = 23, .external_lex_state = 2},
  [3905] = {.lex_state = 23, .external_lex_state = 2},
  [3906] = {.lex_state = 23, .external_lex_state = 2},
  [3907] = {.lex_state = 23, .external_lex_state = 2},
  [3908] = {.lex_state = 23, .external_lex_state = 2},
  [3909] = {.lex_state = 23, .external_lex_state = 2},
  [3910] = {.lex_state = 23, .external_lex_state = 2},
  [3911] = {.lex_state = 23, .external_lex_state = 2},
  [3912] = {.lex_state = 23, .external_lex_state = 2},
  [3913] = {.lex_state = 23, .external_lex_state = 2},
  [3914] = {.lex_state = 23, .external_lex_state = 2},
  [3915] = {.lex_state = 23, .external_lex_state = 2},
  [3916] = {.lex_state = 23, .external_lex_state = 2},
  [3917] = {.lex_state = 23, .external_lex_state = 2},
  [3918] = {.lex_state = 23, .external_lex_state = 2},
  [3919] = {.lex_state = 23, .external_lex_state = 2},
  [3920] = {.lex_state = 23, .external_lex_state = 2},
  [3921] = {.lex_state = 23, .external_lex_state = 2},
  [3922] = {.lex_state = 23, .external_lex_state = 2},
  [3923] = {.lex_state = 23, .external_lex_state = 2},
  [3924] = {.lex_state = 23, .external_lex_state = 2},
  [3925] = {.lex_state = 23, .external_lex_state = 2},
  [3926] = {.lex_state = 23, .external_lex_state = 2},
  [3927] = {.lex_state = 23, .external_lex_state = 2},
  [3928] = {.lex_state = 23, .external_lex_state = 2},
  [3929] = {.lex_state = 23, .external_lex_state = 2},
  [3930] = {.lex_state = 23, .external_lex_state = 2},
  [3931] = {.lex_state = 23, .external_lex_state = 2},
  [3932] = {.lex_state = 23, .external_lex_state = 2},
  [3933] = {.lex_state = 23, .external_lex_state = 2},
  [3934] = {.lex_state = 23, .external_lex_state = 2},
  [3935] = {.lex_state = 23, .external_lex_state = 2},
  [3936] = {.lex_state = 23, .external_lex_state = 2},
  [3937] = {.lex_state = 23, .external_lex_state = 2},
  [3938] = {.lex_state = 23, .external_lex_state = 2},
  [3939] = {.lex_state = 23, .external_lex_state = 2},
  [3940] = {.lex_state = 23, .external_lex_state = 2},
  [3941] = {.lex_state = 23, .external_lex_state = 2},
  [3942] = {.lex_state = 23, .external_lex_state = 2},
  [3943] = {.lex_state = 23, .external_lex_state = 2},
  [3944] = {.lex_state = 23, .external_lex_state = 2},
  [3945] = {.lex_state = 23, .external_lex_state = 2},
  [3946] = {.lex_state = 23, .external_lex_state = 2},
  [3947] = {.lex_state = 23, .external_lex_state = 2},
  [3948] = {.lex_state = 23, .external_lex_state = 2},
  [3949] = {.lex_state = 23, .external_lex_state = 2},
  [3950] = {.lex_state = 23, .external_lex_state = 2},
  [3951] = {.lex_state = 23, .external_lex_state = 2},
  [3952] = {.lex_state = 23, .external_lex_state = 2},
  [3953] = {.lex_state = 23, .external_lex_state = 2},
  [3954] = {.lex_state = 23, .external_lex_state = 2},
  [3955] = {.lex_state = 23, .external_lex_state = 2},
  [3956] = {.lex_state = 23, .external_lex_state = 2},
  [3957] = {.lex_state = 23, .external_lex_state = 2},
  [3958] = {.lex_state = 23, .external_lex_state = 2},
  [3959] = {.lex_state = 23, .external_lex_state = 2},
  [3960] = {.lex_state = 23, .external_lex_state = 2},
  [3961] = {.lex_state = 23, .external_lex_state = 2},
  [3962] = {.lex_state = 70, .external_lex_state = 8},
  [3963] = {.lex_state = 23, .external_lex_state = 2},
  [3964] = {.lex_state = 23, .external_lex_state = 2},
  [3965] = {.lex_state = 23, .external_lex_state = 2},
  [3966] = {.lex_state = 23, .external_lex_state = 2},
  [3967] = {.lex_state = 23, .external_lex_state = 2},
  [3968] = {.lex_state = 23, .external_lex_state = 2},
  [3969] = {.lex_state = 23, .external_lex_state = 2},
  [3970] = {.lex_state = 23, .external_lex_state = 2},
  [3971] = {.lex_state = 23, .external_lex_state = 2},
  [3972] = {.lex_state = 23, .external_lex_state = 2},
  [3973] = {.lex_state = 70, .external_lex_state = 9},
  [3974] = {.lex_state = 70, .external_lex_state = 10},
  [3975] = {.lex_state = 70, .external_lex_state = 19},
  [3976] = {.lex_state = 70, .external_lex_state = 21},
  [3977] = {.lex_state = 70, .external_lex_state = 22},
  [3978] = {.lex_state = 20, .external_lex_state = 3},
  [3979] = {.lex_state = 20, .external_lex_state = 3},
  [3980] = {.lex_state = 20, .external_lex_state = 3},
  [3981] = {.lex_state = 20, .external_lex_state = 3},
  [3982] = {.lex_state = 20, .external_lex_state = 3},
  [3983] = {.lex_state = 70, .external_lex_state = 2},
  [3984] = {.lex_state = 20, .external_lex_state = 3},
  [3985] = {.lex_state = 72, .external_lex_state = 6},
  [3986] = {.lex_state = 20, .external_lex_state = 3},
  [3987] = {.lex_state = 72, .external_lex_state = 6},
  [3988] = {.lex_state = 20, .external_lex_state = 3},
  [3989] = {.lex_state = 20, .external_lex_state = 3},
  [3990] = {.lex_state = 20, .external_lex_state = 3},
  [3991] = {.lex_state = 20, .external_lex_state = 3},
  [3992] = {.lex_state = 20, .external_lex_state = 3},
  [3993] = {.lex_state = 20, .external_lex_state = 3},
  [3994] = {.lex_state = 20, .external_lex_state = 3},
  [3995] = {.lex_state = 20, .external_lex_state = 3},
  [3996] = {.lex_state = 20, .external_lex_state = 3},
  [3997] = {.lex_state = 20, .external_lex_state = 3},
  [3998] = {.lex_state = 20, .external_lex_state = 3},
  [3999] = {.lex_state = 20, .external_lex_state = 3},
  [4000] = {.lex_state = 20, .external_lex_state = 3},
  [4001] = {.lex_state = 20, .external_lex_state = 3},
  [4002] = {.lex_state = 20, .external_lex_state = 3},
  [4003] = {.lex_state = 20, .external_lex_state = 3},
  [4004] = {.lex_state = 20, .external_lex_state = 3},
  [4005] = {.lex_state = 20, .external_lex_state = 3},
  [4006] = {.lex_state = 20, .external_lex_state = 3},
  [4007] = {.lex_state = 20, .external_lex_state = 3},
  [4008] = {.lex_state = 20, .external_lex_state = 3},
  [4009] = {.lex_state = 20, .external_lex_state = 3},
  [4010] = {.lex_state = 20, .external_lex_state = 3},
  [4011] = {.lex_state = 20, .external_lex_state = 3},
  [4012] = {.lex_state = 20, .external_lex_state = 3},
  [4013] = {.lex_state = 20, .external_lex_state = 3},
  [4014] = {.lex_state = 20, .external_lex_state = 3},
  [4015] = {.lex_state = 20, .external_lex_state = 3},
  [4016] = {.lex_state = 20, .external_lex_state = 3},
  [4017] = {.lex_state = 20, .external_lex_state = 3},
  [4018] = {.lex_state = 20, .external_lex_state = 3},
  [4019] = {.lex_state = 20, .external_lex_state = 3},
  [4020] = {.lex_state = 20, .external_lex_state = 3},
  [4021] = {.lex_state = 20, .external_lex_state = 3},
  [4022] = {.lex_state = 20, .external_lex_state = 3},
  [4023] = {.lex_state = 20, .external_lex_state = 3},
  [4024] = {.lex_state = 20, .external_lex_state = 3},
  [4025] = {.lex_state = 20, .external_lex_state = 3},
  [4026] = {.lex_state = 20, .external_lex_state = 3},
  [4027] = {.lex_state = 20, .external_lex_state = 3},
  [4028] = {.lex_state = 20, .external_lex_state = 3},
  [4029] = {.lex_state = 20, .external_lex_state = 3},
  [4030] = {.lex_state = 20, .external_lex_state = 3},
  [4031] = {.lex_state = 20, .external_lex_state = 3},
  [4032] = {.lex_state = 20, .external_lex_state = 3},
  [4033] = {.lex_state = 20, .external_lex_state = 3},
  [4034] = {.lex_state = 20, .external_lex_state = 3},
  [4035] = {.lex_state = 20, .external_lex_state = 3},
  [4036] = {.lex_state = 20, .external_lex_state = 3},
  [4037] = {.lex_state = 20, .external_lex_state = 3},
  [4038] = {.lex_state = 20, .external_lex_state = 3},
  [4039] = {.lex_state = 20, .external_lex_state = 3},
  [4040] = {.lex_state = 20, .external_lex_state = 3},
  [4041] = {.lex_state = 20, .external_lex_state = 3},
  [4042] = {.lex_state = 20, .external_lex_state = 3},
  [4043] = {.lex_state = 20, .external_lex_state = 3},
  [4044] = {.lex_state = 20, .external_lex_state = 3},
  [4045] = {.lex_state = 20, .external_lex_state = 3},
  [4046] = {.lex_state = 20, .external_lex_state = 3},
  [4047] = {.lex_state = 20, .external_lex_state = 3},
  [4048] = {.lex_state = 20, .external_lex_state = 2},
  [4049] = {.lex_state = 20, .external_lex_state = 3},
  [4050] = {.lex_state = 72, .external_lex_state = 7},
  [4051] = {.lex_state = 20, .external_lex_state = 3},
  [4052] = {.lex_state = 20, .external_lex_state = 3},
  [4053] = {.lex_state = 20, .external_lex_state = 3},
  [4054] = {.lex_state = 20, .external_lex_state = 3},
  [4055] = {.lex_state = 20, .external_lex_state = 3},
  [4056] = {.lex_state = 20, .external_lex_state = 3},
  [4057] = {.lex_state = 20, .external_lex_state = 3},
  [4058] = {.lex_state = 20, .external_lex_state = 3},
  [4059] = {.lex_state = 20, .external_lex_state = 3},
  [4060] = {.lex_state = 20, .external_lex_state = 3},
  [4061] = {.lex_state = 20, .external_lex_state = 3},
  [4062] = {.lex_state = 72, .external_lex_state = 7},
  [4063] = {.lex_state = 20, .external_lex_state = 3},
  [4064] = {.lex_state = 20, .external_lex_state = 3},
  [4065] = {.lex_state = 20, .external_lex_state = 3},
  [4066] = {.lex_state = 20, .external_lex_state = 3},
  [4067] = {.lex_state = 20, .external_lex_state = 3},
  [4068] = {.lex_state = 20, .external_lex_state = 3},
  [4069] = {.lex_state = 20, .external_lex_state = 3},
  [4070] = {.lex_state = 20, .external_lex_state = 3},
  [4071] = {.lex_state = 20, .external_lex_state = 3},
  [4072] = {.lex_state = 20, .external_lex_state = 3},
  [4073] = {.lex_state = 20, .external_lex_state = 3},
  [4074] = {.lex_state = 20, .external_lex_state = 3},
  [4075] = {.lex_state = 20, .external_lex_state = 3},
  [4076] = {.lex_state = 20, .external_lex_state = 3},
  [4077] = {.lex_state = 20, .external_lex_state = 3},
  [4078] = {.lex_state = 20, .external_lex_state = 3},
  [4079] = {.lex_state = 20, .external_lex_state = 3},
  [4080] = {.lex_state = 72, .external_lex_state = 8},
  [4081] = {.lex_state = 20, .external_lex_state = 3},
  [4082] = {.lex_state = 20, .external_lex_state = 3},
  [4083] = {.lex_state = 20, .external_lex_state = 3},
  [4084] = {.lex_state = 20, .external_lex_state = 3},
  [4085] = {.lex_state = 20, .external_lex_state = 3},
  [4086] = {.lex_state = 20, .external_lex_state = 3},
  [4087] = {.lex_state = 20, .external_lex_state = 3},
  [4088] = {.lex_state = 20, .external_lex_state = 3},
  [4089] = {.lex_state = 20, .external_lex_state = 3},
  [4090] = {.lex_state = 20, .external_lex_state = 3},
  [4091] = {.lex_state = 20, .external_lex_state = 3},
  [4092] = {.lex_state = 20, .external_lex_state = 3},
  [4093] = {.lex_state = 20, .external_lex_state = 3},
  [4094] = {.lex_state = 20, .external_lex_state = 3},
  [4095] = {.lex_state = 20, .external_lex_state = 3},
  [4096] = {.lex_state = 20, .external_lex_state = 3},
  [4097] = {.lex_state = 20, .external_lex_state = 3},
  [4098] = {.lex_state = 20, .external_lex_state = 3},
  [4099] = {.lex_state = 20, .external_lex_state = 3},
  [4100] = {.lex_state = 20, .external_lex_state = 3},
  [4101] = {.lex_state = 20, .external_lex_state = 3},
  [4102] = {.lex_state = 20, .external_lex_state = 2},
  [4103] = {.lex_state = 20, .external_lex_state = 3},
  [4104] = {.lex_state = 20, .external_lex_state = 3},
  [4105] = {.lex_state = 20, .external_lex_state = 3},
  [4106] = {.lex_state = 20, .external_lex_state = 2},
  [4107] = {.lex_state = 20, .external_lex_state = 3},
  [4108] = {.lex_state = 20, .external_lex_state = 3},
  [4109] = {.lex_state = 20, .external_lex_state = 3},
  [4110] = {.lex_state = 20, .external_lex_state = 3},
  [4111] = {.lex_state = 20, .external_lex_state = 3},
  [4112] = {.lex_state = 20, .external_lex_state = 3},
  [4113] = {.lex_state = 20, .external_lex_state = 3},
  [4114] = {.lex_state = 20, .external_lex_state = 3},
  [4115] = {.lex_state = 20, .external_lex_state = 3},
  [4116] = {.lex_state = 20, .external_lex_state = 3},
  [4117] = {.lex_state = 20, .external_lex_state = 3},
  [4118] = {.lex_state = 20, .external_lex_state = 3},
  [4119] = {.lex_state = 20, .external_lex_state = 3},
  [4120] = {.lex_state = 20, .external_lex_state = 3},
  [4121] = {.lex_state = 20, .external_lex_state = 3},
  [4122] = {.lex_state = 20, .external_lex_state = 3},
  [4123] = {.lex_state = 20, .external_lex_state = 3},
  [4124] = {.lex_state = 20, .external_lex_state = 3},
  [4125] = {.lex_state = 20, .external_lex_state = 3},
  [4126] = {.lex_state = 20, .external_lex_state = 3},
  [4127] = {.lex_state = 20, .external_lex_state = 3},
  [4128] = {.lex_state = 20, .external_lex_state = 3},
  [4129] = {.lex_state = 20, .external_lex_state = 3},
  [4130] = {.lex_state = 20, .external_lex_state = 3},
  [4131] = {.lex_state = 20, .external_lex_state = 3},
  [4132] = {.lex_state = 20, .external_lex_state = 3},
  [4133] = {.lex_state = 20, .external_lex_state = 3},
  [4134] = {.lex_state = 20, .external_lex_state = 3},
  [4135] = {.lex_state = 20, .external_lex_state = 3},
  [4136] = {.lex_state = 20, .external_lex_state = 2},
  [4137] = {.lex_state = 20, .external_lex_state = 3},
  [4138] = {.lex_state = 20, .external_lex_state = 3},
  [4139] = {.lex_state = 20, .external_lex_state = 3},
  [4140] = {.lex_state = 20, .external_lex_state = 3},
  [4141] = {.lex_state = 20, .external_lex_state = 3},
  [4142] = {.lex_state = 20, .external_lex_state = 3},
  [4143] = {.lex_state = 20, .external_lex_state = 3},
  [4144] = {.lex_state = 72, .external_lex_state = 8},
  [4145] = {.lex_state = 20, .external_lex_state = 3},
  [4146] = {.lex_state = 20, .external_lex_state = 3},
  [4147] = {.lex_state = 20, .external_lex_state = 3},
  [4148] = {.lex_state = 20, .external_lex_state = 3},
  [4149] = {.lex_state = 20, .external_lex_state = 3},
  [4150] = {.lex_state = 20, .external_lex_state = 3},
  [4151] = {.lex_state = 20, .external_lex_state = 3},
  [4152] = {.lex_state = 20, .external_lex_state = 3},
  [4153] = {.lex_state = 20, .external_lex_state = 3},
  [4154] = {.lex_state = 20, .external_lex_state = 3},
  [4155] = {.lex_state = 20, .external_lex_state = 3},
  [4156] = {.lex_state = 20, .external_lex_state = 3},
  [4157] = {.lex_state = 72, .external_lex_state = 12},
  [4158] = {.lex_state = 72, .external_lex_state = 10},
  [4159] = {.lex_state = 72, .external_lex_state = 9},
  [4160] = {.lex_state = 72, .external_lex_state = 11},
  [4161] = {.lex_state = 20, .external_lex_state = 4},
  [4162] = {.lex_state = 72, .external_lex_state = 9},
  [4163] = {.lex_state = 72, .external_lex_state = 10},
  [4164] = {.lex_state = 20, .external_lex_state = 4},
  [4165] = {.lex_state = 72, .external_lex_state = 12},
  [4166] = {.lex_state = 72, .external_lex_state = 11},
  [4167] = {.lex_state = 72, .external_lex_state = 15},
  [4168] = {.lex_state = 72, .external_lex_state = 14},
  [4169] = {.lex_state = 20, .external_lex_state = 2},
  [4170] = {.lex_state = 72, .external_lex_state = 19},
  [4171] = {.lex_state = 20, .external_lex_state = 2},
  [4172] = {.lex_state = 72, .external_lex_state = 6},
  [4173] = {.lex_state = 72, .external_lex_state = 15},
  [4174] = {.lex_state = 20, .external_lex_state = 2},
  [4175] = {.lex_state = 20, .external_lex_state = 2},
  [4176] = {.lex_state = 72, .external_lex_state = 6},
  [4177] = {.lex_state = 72, .external_lex_state = 13},
  [4178] = {.lex_state = 72, .external_lex_state = 19},
  [4179] = {.lex_state = 72, .external_lex_state = 14},
  [4180] = {.lex_state = 72, .external_lex_state = 13},
  [4181] = {.lex_state = 77},
  [4182] = {.lex_state = 72, .external_lex_state = 16},
  [4183] = {.lex_state = 77},
  [4184] = {.lex_state = 72, .external_lex_state = 17},
  [4185] = {.lex_state = 72, .external_lex_state = 20},
  [4186] = {.lex_state = 72, .external_lex_state = 8},
  [4187] = {.lex_state = 72, .external_lex_state = 8},
  [4188] = {.lex_state = 72, .external_lex_state = 18},
  [4189] = {.lex_state = 72, .external_lex_state = 18},
  [4190] = {.lex_state = 72, .external_lex_state = 16},
  [4191] = {.lex_state = 72, .external_lex_state = 17},
  [4192] = {.lex_state = 72, .external_lex_state = 7},
  [4193] = {.lex_state = 72, .external_lex_state = 20},
  [4194] = {.lex_state = 72, .external_lex_state = 7},
  [4195] = {.lex_state = 20, .external_lex_state = 2},
  [4196] = {.lex_state = 72, .external_lex_state = 9},
  [4197] = {.lex_state = 72, .external_lex_state = 10},
  [4198] = {.lex_state = 72, .external_lex_state = 22},
  [4199] = {.lex_state = 72, .external_lex_state = 10},
  [4200] = {.lex_state = 72, .external_lex_state = 22},
  [4201] = {.lex_state = 20, .external_lex_state = 2},
  [4202] = {.lex_state = 72, .external_lex_state = 9},
  [4203] = {.lex_state = 2, .external_lex_state = 3},
  [4204] = {.lex_state = 72, .external_lex_state = 21},
  [4205] = {.lex_state = 72, .external_lex_state = 21},
  [4206] = {.lex_state = 2, .external_lex_state = 3},
  [4207] = {.lex_state = 72, .external_lex_state = 2},
  [4208] = {.lex_state = 72, .external_lex_state = 19},
  [4209] = {.lex_state = 72, .external_lex_state = 19},
  [4210] = {.lex_state = 72, .external_lex_state = 2},
  [4211] = {.lex_state = 20, .external_lex_state = 2},
  [4212] = {.lex_state = 20, .external_lex_state = 2},
  [4213] = {.lex_state = 20, .external_lex_state = 2},
  [4214] = {.lex_state = 20, .external_lex_state = 2},
  [4215] = {.lex_state = 20, .external_lex_state = 2},
  [4216] = {.lex_state = 20, .external_lex_state = 2},
  [4217] = {.lex_state = 20, .external_lex_state = 2},
  [4218] = {.lex_state = 20, .external_lex_state = 2},
  [4219] = {.lex_state = 20, .external_lex_state = 2},
  [4220] = {.lex_state = 20, .external_lex_state = 2},
  [4221] = {.lex_state = 20, .external_lex_state = 2},
  [4222] = {.lex_state = 20, .external_lex_state = 2},
  [4223] = {.lex_state = 20, .external_lex_state = 2},
  [4224] = {.lex_state = 2, .external_lex_state = 2},
  [4225] = {.lex_state = 20, .external_lex_state = 2},
  [4226] = {.lex_state = 20, .external_lex_state = 2},
  [4227] = {.lex_state = 20, .external_lex_state = 2},
  [4228] = {.lex_state = 20, .external_lex_state = 2},
  [4229] = {.lex_state = 20, .external_lex_state = 2},
  [4230] = {.lex_state = 20, .external_lex_state = 2},
  [4231] = {.lex_state = 20, .external_lex_state = 2},
  [4232] = {.lex_state = 20, .external_lex_state = 2},
  [4233] = {.lex_state = 20, .external_lex_state = 2},
  [4234] = {.lex_state = 20, .external_lex_state = 2},
  [4235] = {.lex_state = 20, .external_lex_state = 2},
  [4236] = {.lex_state = 20, .external_lex_state = 2},
  [4237] = {.lex_state = 20, .external_lex_state = 2},
  [4238] = {.lex_state = 20, .external_lex_state = 2},
  [4239] = {.lex_state = 20, .external_lex_state = 2},
  [4240] = {.lex_state = 20, .external_lex_state = 2},
  [4241] = {.lex_state = 20, .external_lex_state = 2},
  [4242] = {.lex_state = 20, .external_lex_state = 2},
  [4243] = {.lex_state = 20, .external_lex_state = 2},
  [4244] = {.lex_state = 20, .external_lex_state = 2},
  [4245] = {.lex_state = 20, .external_lex_state = 2},
  [4246] = {.lex_state = 20, .external_lex_state = 2},
  [4247] = {.lex_state = 20, .external_lex_state = 2},
  [4248] = {.lex_state = 20, .external_lex_state = 2},
  [4249] = {.lex_state = 20, .external_lex_state = 2},
  [4250] = {.lex_state = 20, .external_lex_state = 2},
  [4251] = {.lex_state = 20, .external_lex_state = 2},
  [4252] = {.lex_state = 20, .external_lex_state = 2},
  [4253] = {.lex_state = 20, .external_lex_state = 2},
  [4254] = {.lex_state = 20, .external_lex_state = 2},
  [4255] = {.lex_state = 20, .external_lex_state = 2},
  [4256] = {.lex_state = 20, .external_lex_state = 2},
  [4257] = {.lex_state = 20, .external_lex_state = 2},
  [4258] = {.lex_state = 20, .external_lex_state = 2},
  [4259] = {.lex_state = 20, .external_lex_state = 2},
  [4260] = {.lex_state = 20, .external_lex_state = 2},
  [4261] = {.lex_state = 20, .external_lex_state = 2},
  [4262] = {.lex_state = 20, .external_lex_state = 2},
  [4263] = {.lex_state = 20, .external_lex_state = 2},
  [4264] = {.lex_state = 20, .external_lex_state = 2},
  [4265] = {.lex_state = 20, .external_lex_state = 2},
  [4266] = {.lex_state = 20, .external_lex_state = 2},
  [4267] = {.lex_state = 20, .external_lex_state = 2},
  [4268] = {.lex_state = 20, .external_lex_state = 2},
  [4269] = {.lex_state = 20, .external_lex_state = 2},
  [4270] = {.lex_state = 20, .external_lex_state = 2},
  [4271] = {.lex_state = 20, .external_lex_state = 2},
  [4272] = {.lex_state = 20, .external_lex_state = 2},
  [4273] = {.lex_state = 90, .external_lex_state = 23},
  [4274] = {.lex_state = 75, .external_lex_state = 23},
  [4275] = {.lex_state = 90, .external_lex_state = 23},
  [4276] = {.lex_state = 20, .external_lex_state = 2},
  [4277] = {.lex_state = 20, .external_lex_state = 2},
  [4278] = {.lex_state = 90, .external_lex_state = 23},
  [4279] = {.lex_state = 20, .external_lex_state = 2},
  [4280] = {.lex_state = 20, .external_lex_state = 2},
  [4281] = {.lex_state = 20, .external_lex_state = 2},
  [4282] = {.lex_state = 20, .external_lex_state = 2},
  [4283] = {.lex_state = 90, .external_lex_state = 23},
  [4284] = {.lex_state = 3, .external_lex_state = 2},
  [4285] = {.lex_state = 90, .external_lex_state = 23},
  [4286] = {.lex_state = 20, .external_lex_state = 2},
  [4287] = {.lex_state = 20, .external_lex_state = 2},
  [4288] = {.lex_state = 75, .external_lex_state = 23},
  [4289] = {.lex_state = 75, .external_lex_state = 24},
  [4290] = {.lex_state = 20, .external_lex_state = 2},
  [4291] = {.lex_state = 75, .external_lex_state = 24},
  [4292] = {.lex_state = 90, .external_lex_state = 23},
  [4293] = {.lex_state = 20, .external_lex_state = 2},
  [4294] = {.lex_state = 20, .external_lex_state = 2},
  [4295] = {.lex_state = 90, .external_lex_state = 23},
  [4296] = {.lex_state = 20, .external_lex_state = 2},
  [4297] = {.lex_state = 90, .external_lex_state = 23},
  [4298] = {.lex_state = 20, .external_lex_state = 2},
  [4299] = {.lex_state = 20, .external_lex_state = 2},
  [4300] = {.lex_state = 90, .external_lex_state = 23},
  [4301] = {.lex_state = 90, .external_lex_state = 23},
  [4302] = {.lex_state = 20, .external_lex_state = 2},
  [4303] = {.lex_state = 20, .external_lex_state = 2},
  [4304] = {.lex_state = 75, .external_lex_state = 24},
  [4305] = {.lex_state = 90, .external_lex_state = 23},
  [4306] = {.lex_state = 90, .external_lex_state = 23},
  [4307] = {.lex_state = 75, .external_lex_state = 23},
  [4308] = {.lex_state = 75, .external_lex_state = 23},
  [4309] = {.lex_state = 75, .external_lex_state = 23},
  [4310] = {.lex_state = 90, .external_lex_state = 23},
  [4311] = {.lex_state = 90, .external_lex_state = 23},
  [4312] = {.lex_state = 20, .external_lex_state = 2},
  [4313] = {.lex_state = 20, .external_lex_state = 2},
  [4314] = {.lex_state = 90, .external_lex_state = 23},
  [4315] = {.lex_state = 75, .external_lex_state = 23},
  [4316] = {.lex_state = 3, .external_lex_state = 2},
  [4317] = {.lex_state = 20, .external_lex_state = 2},
  [4318] = {.lex_state = 77},
  [4319] = {.lex_state = 73, .external_lex_state = 3},
  [4320] = {.lex_state = 73, .external_lex_state = 2},
  [4321] = {.lex_state = 77},
  [4322] = {.lex_state = 73, .external_lex_state = 2},
  [4323] = {.lex_state = 75, .external_lex_state = 24},
  [4324] = {.lex_state = 75, .external_lex_state = 23},
  [4325] = {.lex_state = 77},
  [4326] = {.lex_state = 75, .external_lex_state = 23},
  [4327] = {.lex_state = 31},
  [4328] = {.lex_state = 77, .external_lex_state = 25},
  [4329] = {.lex_state = 77, .external_lex_state = 25},
  [4330] = {.lex_state = 77, .external_lex_state = 25},
  [4331] = {.lex_state = 31},
  [4332] = {.lex_state = 31},
  [4333] = {.lex_state = 77},
  [4334] = {.lex_state = 31},
  [4335] = {.lex_state = 31},
  [4336] = {.lex_state = 78, .external_lex_state = 26},
  [4337] = {.lex_state = 31},
  [4338] = {.lex_state = 77, .external_lex_state = 25},
  [4339] = {.lex_state = 77, .external_lex_state = 25},
  [4340] = {.lex_state = 79, .external_lex_state = 26},
  [4341] = {.lex_state = 31},
  [4342] = {.lex_state = 31},
  [4343] = {.lex_state = 77},
  [4344] = {.lex_state = 77},
  [4345] = {.lex_state = 77},
  [4346] = {.lex_state = 31},
  [4347] = {.lex_state = 77},
  [4348] = {.lex_state = 87, .external_lex_state = 26},
  [4349] = {.lex_state = 77},
  [4350] = {.lex_state = 31},
  [4351] = {.lex_state = 77},
  [4352] = {.lex_state = 77},
  [4353] = {.lex_state = 79, .external_lex_state = 26},
  [4354] = {.lex_state = 94, .external_lex_state = 26},
  [4355] = {.lex_state = 94, .external_lex_state = 26},
  [4356] = {.lex_state = 90},
  [4357] = {.lex_state = 90},
  [4358] = {.lex_state = 90},
  [4359] = {.lex_state = 90},
  [4360] = {.lex_state = 31},
  [4361] = {.lex_state = 31},
  [4362] = {.lex_state = 77},
  [4363] = {.lex_state = 31},
  [4364] = {.lex_state = 31},
  [4365] = {.lex_state = 31},
  [4366] = {.lex_state = 77},
  [4367] = {.lex_state = 31},
  [4368] = {.lex_state = 31},
  [4369] = {.lex_state = 90},
  [4370] = {.lex_state = 78, .external_lex_state = 27},
  [4371] = {.lex_state = 31},
  [4372] = {.lex_state = 77},
  [4373] = {.lex_state = 90},
  [4374] = {.lex_state = 31},
  [4375] = {.lex_state = 31},
  [4376] = {.lex_state = 31},
  [4377] = {.lex_state = 31},
  [4378] = {.lex_state = 31},
  [4379] = {.lex_state = 31},
  [4380] = {.lex_state = 31},
  [4381] = {.lex_state = 77},
  [4382] = {.lex_state = 31},
  [4383] = {.lex_state = 31},
  [4384] = {.lex_state = 31},
  [4385] = {.lex_state = 79, .external_lex_state = 28},
  [4386] = {.lex_state = 77},
  [4387] = {.lex_state = 77},
  [4388] = {.lex_state = 31},
  [4389] = {.lex_state = 31},
  [4390] = {.lex_state = 90},
  [4391] = {.lex_state = 90},
  [4392] = {.lex_state = 31},
  [4393] = {.lex_state = 31},
  [4394] = {.lex_state = 31},
  [4395] = {.lex_state = 77},
  [4396] = {.lex_state = 79, .external_lex_state = 27},
  [4397] = {.lex_state = 94, .external_lex_state = 26},
  [4398] = {.lex_state = 31},
  [4399] = {.lex_state = 31},
  [4400] = {.lex_state = 31},
  [4401] = {.lex_state = 31},
  [4402] = {.lex_state = 77},
  [4403] = {.lex_state = 31},
  [4404] = {.lex_state = 90},
  [4405] = {.lex_state = 31},
  [4406] = {.lex_state = 31},
  [4407] = {.lex_state = 90},
  [4408] = {.lex_state = 31},
  [4409] = {.lex_state = 77},
  [4410] = {.lex_state = 87, .external_lex_state = 27},
  [4411] = {.lex_state = 31},
  [4412] = {.lex_state = 80, .external_lex_state = 26},
  [4413] = {.lex_state = 31},
  [4414] = {.lex_state = 31},
  [4415] = {.lex_state = 90},
  [4416] = {.lex_state = 90},
  [4417] = {.lex_state = 77},
  [4418] = {.lex_state = 31},
  [4419] = {.lex_state = 90},
  [4420] = {.lex_state = 87, .external_lex_state = 26},
  [4421] = {.lex_state = 79, .external_lex_state = 26},
  [4422] = {.lex_state = 90},
  [4423] = {.lex_state = 78, .external_lex_state = 28},
  [4424] = {.lex_state = 31},
  [4425] = {.lex_state = 90},
  [4426] = {.lex_state = 31},
  [4427] = {.lex_state = 90},
  [4428] = {.lex_state = 31},
  [4429] = {.lex_state = 90},
  [4430] = {.lex_state = 90},
  [4431] = {.lex_state = 31},
  [4432] = {.lex_state = 90},
  [4433] = {.lex_state = 90},
  [4434] = {.lex_state = 75, .external_lex_state = 29},
  [4435] = {.lex_state = 90},
  [4436] = {.lex_state = 87, .external_lex_state = 28},
  [4437] = {.lex_state = 78, .external_lex_state = 26},
  [4438] = {.lex_state = 90},
  [4439] = {.lex_state = 77},
  [4440] = {.lex_state = 31},
  [4441] = {.lex_state = 31},
  [4442] = {.lex_state = 31},
  [4443] = {.lex_state = 77, .external_lex_state = 25},
  [4444] = {.lex_state = 90},
  [4445] = {.lex_state = 78, .external_lex_state = 26},
  [4446] = {.lex_state = 78, .external_lex_state = 27},
  [4447] = {.lex_state = 79, .external_lex_state = 28},
  [4448] = {.lex_state = 77, .external_lex_state = 25},
  [4449] = {.lex_state = 78, .external_lex_state = 26},
  [4450] = {.lex_state = 94, .external_lex_state = 28},
  [4451] = {.lex_state = 79, .external_lex_state = 28},
  [4452] = {.lex_state = 90},
  [4453] = {.lex_state = 90},
  [4454] = {.lex_state = 90},
  [4455] = {.lex_state = 90},
  [4456] = {.lex_state = 90},
  [4457] = {.lex_state = 90},
  [4458] = {.lex_state = 77, .external_lex_state = 25},
  [4459] = {.lex_state = 78, .external_lex_state = 26},
  [4460] = {.lex_state = 75, .external_lex_state = 30},
  [4461] = {.lex_state = 94, .external_lex_state = 27},
  [4462] = {.lex_state = 96, .external_lex_state = 26},
  [4463] = {.lex_state = 90},
  [4464] = {.lex_state = 87, .external_lex_state = 28},
  [4465] = {.lex_state = 90},
  [4466] = {.lex_state = 90},
  [4467] = {.lex_state = 78, .external_lex_state = 31},
  [4468] = {.lex_state = 78, .external_lex_state = 32},
  [4469] = {.lex_state = 94, .external_lex_state = 27},
  [4470] = {.lex_state = 78, .external_lex_state = 28},
  [4471] = {.lex_state = 87, .external_lex_state = 33},
  [4472] = {.lex_state = 85, .external_lex_state = 26},
  [4473] = {.lex_state = 87, .external_lex_state = 32},
  [4474] = {.lex_state = 85, .external_lex_state = 26},
  [4475] = {.lex_state = 94, .external_lex_state = 27},
  [4476] = {.lex_state = 31},
  [4477] = {.lex_state = 90},
  [4478] = {.lex_state = 78, .external_lex_state = 26},
  [4479] = {.lex_state = 75, .external_lex_state = 34},
  [4480] = {.lex_state = 90},
  [4481] = {.lex_state = 90},
  [4482] = {.lex_state = 87, .external_lex_state = 29},
  [4483] = {.lex_state = 77, .external_lex_state = 25},
  [4484] = {.lex_state = 90},
  [4485] = {.lex_state = 87, .external_lex_state = 29},
  [4486] = {.lex_state = 90},
  [4487] = {.lex_state = 90},
  [4488] = {.lex_state = 77, .external_lex_state = 25},
  [4489] = {.lex_state = 90},
  [4490] = {.lex_state = 90},
  [4491] = {.lex_state = 77, .external_lex_state = 25},
  [4492] = {.lex_state = 79, .external_lex_state = 32},
  [4493] = {.lex_state = 90},
  [4494] = {.lex_state = 32},
  [4495] = {.lex_state = 90},
  [4496] = {.lex_state = 80, .external_lex_state = 26},
  [4497] = {.lex_state = 90},
  [4498] = {.lex_state = 77, .external_lex_state = 25},
  [4499] = {.lex_state = 96, .external_lex_state = 26},
  [4500] = {.lex_state = 90},
  [4501] = {.lex_state = 77, .external_lex_state = 25},
  [4502] = {.lex_state = 90},
  [4503] = {.lex_state = 77, .external_lex_state = 25},
  [4504] = {.lex_state = 87, .external_lex_state = 29},
  [4505] = {.lex_state = 77, .external_lex_state = 25},
  [4506] = {.lex_state = 79, .external_lex_state = 27},
  [4507] = {.lex_state = 87, .external_lex_state = 31},
  [4508] = {.lex_state = 90},
  [4509] = {.lex_state = 94, .external_lex_state = 28},
  [4510] = {.lex_state = 77, .external_lex_state = 25},
  [4511] = {.lex_state = 90},
  [4512] = {.lex_state = 79, .external_lex_state = 27},
  [4513] = {.lex_state = 80, .external_lex_state = 28},
  [4514] = {.lex_state = 94, .external_lex_state = 28},
  [4515] = {.lex_state = 90},
  [4516] = {.lex_state = 90},
  [4517] = {.lex_state = 79, .external_lex_state = 33},
  [4518] = {.lex_state = 90},
  [4519] = {.lex_state = 77, .external_lex_state = 25},
  [4520] = {.lex_state = 90},
  [4521] = {.lex_state = 80, .external_lex_state = 27},
  [4522] = {.lex_state = 75, .external_lex_state = 29},
  [4523] = {.lex_state = 90},
  [4524] = {.lex_state = 78, .external_lex_state = 33},
  [4525] = {.lex_state = 90},
  [4526] = {.lex_state = 75, .external_lex_state = 29},
  [4527] = {.lex_state = 90},
  [4528] = {.lex_state = 77, .external_lex_state = 25},
  [4529] = {.lex_state = 77},
  [4530] = {.lex_state = 90},
  [4531] = {.lex_state = 90},
  [4532] = {.lex_state = 79, .external_lex_state = 31},
  [4533] = {.lex_state = 87, .external_lex_state = 27},
  [4534] = {.lex_state = 90},
  [4535] = {.lex_state = 77, .external_lex_state = 25},
  [4536] = {.lex_state = 77, .external_lex_state = 25},
  [4537] = {.lex_state = 96, .external_lex_state = 26},
  [4538] = {.lex_state = 86, .external_lex_state = 26},
  [4539] = {.lex_state = 96, .external_lex_state = 27},
  [4540] = {.lex_state = 78, .external_lex_state = 35},
  [4541] = {.lex_state = 78, .external_lex_state = 26},
  [4542] = {.lex_state = 78, .external_lex_state = 26},
  [4543] = {.lex_state = 94, .external_lex_state = 32},
  [4544] = {.lex_state = 75, .external_lex_state = 29},
  [4545] = {.lex_state = 79, .external_lex_state = 36},
  [4546] = {.lex_state = 78, .external_lex_state = 28},
  [4547] = {.lex_state = 78, .external_lex_state = 28},
  [4548] = {.lex_state = 78, .external_lex_state = 26},
  [4549] = {.lex_state = 80, .external_lex_state = 28},
  [4550] = {.lex_state = 87, .external_lex_state = 34},
  [4551] = {.lex_state = 87, .external_lex_state = 32},
  [4552] = {.lex_state = 79, .external_lex_state = 33},
  [4553] = {.lex_state = 75, .external_lex_state = 34},
  [4554] = {.lex_state = 78, .external_lex_state = 26},
  [4555] = {.lex_state = 78, .external_lex_state = 26},
  [4556] = {.lex_state = 78, .external_lex_state = 26},
  [4557] = {.lex_state = 78, .external_lex_state = 26},
  [4558] = {.lex_state = 79, .external_lex_state = 37},
  [4559] = {.lex_state = 78, .external_lex_state = 26},
  [4560] = {.lex_state = 78, .external_lex_state = 31},
  [4561] = {.lex_state = 79, .external_lex_state = 31},
  [4562] = {.lex_state = 78, .external_lex_state = 27},
  [4563] = {.lex_state = 94, .external_lex_state = 33},
  [4564] = {.lex_state = 96, .external_lex_state = 28},
  [4565] = {.lex_state = 31},
  [4566] = {.lex_state = 94, .external_lex_state = 31},
  [4567] = {.lex_state = 75, .external_lex_state = 29},
  [4568] = {.lex_state = 75, .external_lex_state = 38},
  [4569] = {.lex_state = 87, .external_lex_state = 30},
  [4570] = {.lex_state = 85, .external_lex_state = 28},
  [4571] = {.lex_state = 78, .external_lex_state = 28},
  [4572] = {.lex_state = 94, .external_lex_state = 32},
  [4573] = {.lex_state = 85, .external_lex_state = 28},
  [4574] = {.lex_state = 75, .external_lex_state = 30},
  [4575] = {.lex_state = 85, .external_lex_state = 27},
  [4576] = {.lex_state = 87, .external_lex_state = 35},
  [4577] = {.lex_state = 87, .external_lex_state = 36},
  [4578] = {.lex_state = 79, .external_lex_state = 33},
  [4579] = {.lex_state = 80, .external_lex_state = 26},
  [4580] = {.lex_state = 78, .external_lex_state = 26},
  [4581] = {.lex_state = 75, .external_lex_state = 34},
  [4582] = {.lex_state = 78, .external_lex_state = 26},
  [4583] = {.lex_state = 87, .external_lex_state = 31},
  [4584] = {.lex_state = 78, .external_lex_state = 26},
  [4585] = {.lex_state = 96, .external_lex_state = 28},
  [4586] = {.lex_state = 78, .external_lex_state = 37},
  [4587] = {.lex_state = 78, .external_lex_state = 36},
  [4588] = {.lex_state = 94, .external_lex_state = 31},
  [4589] = {.lex_state = 96, .external_lex_state = 28},
  [4590] = {.lex_state = 79, .external_lex_state = 32},
  [4591] = {.lex_state = 86, .external_lex_state = 26},
  [4592] = {.lex_state = 96, .external_lex_state = 27},
  [4593] = {.lex_state = 87, .external_lex_state = 30},
  [4594] = {.lex_state = 78, .external_lex_state = 27},
  [4595] = {.lex_state = 78, .external_lex_state = 26},
  [4596] = {.lex_state = 75, .external_lex_state = 30},
  [4597] = {.lex_state = 80, .external_lex_state = 31},
  [4598] = {.lex_state = 75, .external_lex_state = 39},
  [4599] = {.lex_state = 87, .external_lex_state = 34},
  [4600] = {.lex_state = 94, .external_lex_state = 33},
  [4601] = {.lex_state = 78, .external_lex_state = 27},
  [4602] = {.lex_state = 86, .external_lex_state = 26},
  [4603] = {.lex_state = 86, .external_lex_state = 26},
  [4604] = {.lex_state = 96, .external_lex_state = 27},
  [4605] = {.lex_state = 78, .external_lex_state = 33},
  [4606] = {.lex_state = 80, .external_lex_state = 26},
  [4607] = {.lex_state = 75, .external_lex_state = 40},
  [4608] = {.lex_state = 75, .external_lex_state = 23},
  [4609] = {.lex_state = 87, .external_lex_state = 30},
  [4610] = {.lex_state = 85, .external_lex_state = 26},
  [4611] = {.lex_state = 80, .external_lex_state = 33},
  [4612] = {.lex_state = 80, .external_lex_state = 27},
  [4613] = {.lex_state = 78, .external_lex_state = 26},
  [4614] = {.lex_state = 78, .external_lex_state = 32},
  [4615] = {.lex_state = 94, .external_lex_state = 32},
  [4616] = {.lex_state = 80, .external_lex_state = 26},
  [4617] = {.lex_state = 79, .external_lex_state = 32},
  [4618] = {.lex_state = 87, .external_lex_state = 34},
  [4619] = {.lex_state = 94, .external_lex_state = 31},
  [4620] = {.lex_state = 78, .external_lex_state = 27},
  [4621] = {.lex_state = 78, .external_lex_state = 28},
  [4622] = {.lex_state = 94, .external_lex_state = 33},
  [4623] = {.lex_state = 87, .external_lex_state = 37},
  [4624] = {.lex_state = 85, .external_lex_state = 27},
  [4625] = {.lex_state = 79, .external_lex_state = 31},
  [4626] = {.lex_state = 79, .external_lex_state = 35},
  [4627] = {.lex_state = 78, .external_lex_state = 26},
  [4628] = {.lex_state = 88, .external_lex_state = 26},
  [4629] = {.lex_state = 88, .external_lex_state = 26},
  [4630] = {.lex_state = 87, .external_lex_state = 33},
  [4631] = {.lex_state = 85, .external_lex_state = 26},
  [4632] = {.lex_state = 80, .external_lex_state = 26},
  [4633] = {.lex_state = 80, .external_lex_state = 32},
  [4634] = {.lex_state = 75, .external_lex_state = 34},
  [4635] = {.lex_state = 78, .external_lex_state = 32},
  [4636] = {.lex_state = 94, .external_lex_state = 36},
  [4637] = {.lex_state = 80, .external_lex_state = 27},
  [4638] = {.lex_state = 79, .external_lex_state = 26},
  [4639] = {.lex_state = 78, .external_lex_state = 33},
  [4640] = {.lex_state = 77},
  [4641] = {.lex_state = 80, .external_lex_state = 26},
  [4642] = {.lex_state = 85, .external_lex_state = 26},
  [4643] = {.lex_state = 88, .external_lex_state = 27},
  [4644] = {.lex_state = 88, .external_lex_state = 27},
  [4645] = {.lex_state = 80, .external_lex_state = 26},
  [4646] = {.lex_state = 87, .external_lex_state = 35},
  [4647] = {.lex_state = 85, .external_lex_state = 26},
  [4648] = {.lex_state = 80, .external_lex_state = 26},
  [4649] = {.lex_state = 78, .external_lex_state = 28},
  [4650] = {.lex_state = 88, .external_lex_state = 28},
  [4651] = {.lex_state = 79, .external_lex_state = 26},
  [4652] = {.lex_state = 78, .external_lex_state = 28},
  [4653] = {.lex_state = 78, .external_lex_state = 35},
  [4654] = {.lex_state = 78, .external_lex_state = 28},
  [4655] = {.lex_state = 88, .external_lex_state = 28},
  [4656] = {.lex_state = 85, .external_lex_state = 26},
  [4657] = {.lex_state = 78, .external_lex_state = 31},
  [4658] = {.lex_state = 75, .external_lex_state = 38},
  [4659] = {.lex_state = 80, .external_lex_state = 27},
  [4660] = {.lex_state = 94, .external_lex_state = 35},
  [4661] = {.lex_state = 78, .external_lex_state = 31},
  [4662] = {.lex_state = 79, .external_lex_state = 37},
  [4663] = {.lex_state = 85, .external_lex_state = 27},
  [4664] = {.lex_state = 79, .external_lex_state = 41},
  [4665] = {.lex_state = 85, .external_lex_state = 31},
  [4666] = {.lex_state = 85, .external_lex_state = 31},
  [4667] = {.lex_state = 78, .external_lex_state = 42},
  [4668] = {.lex_state = 78, .external_lex_state = 36},
  [4669] = {.lex_state = 94, .external_lex_state = 36},
  [4670] = {.lex_state = 78, .external_lex_state = 33},
  [4671] = {.lex_state = 75, .external_lex_state = 38},
  [4672] = {.lex_state = 78, .external_lex_state = 28},
  [4673] = {.lex_state = 96, .external_lex_state = 32},
  [4674] = {.lex_state = 80, .external_lex_state = 36},
  [4675] = {.lex_state = 85, .external_lex_state = 32},
  [4676] = {.lex_state = 85, .external_lex_state = 32},
  [4677] = {.lex_state = 79, .external_lex_state = 26},
  [4678] = {.lex_state = 96, .external_lex_state = 32},
  [4679] = {.lex_state = 79, .external_lex_state = 36},
  [4680] = {.lex_state = 75, .external_lex_state = 40},
  [4681] = {.lex_state = 94, .external_lex_state = 37},
  [4682] = {.lex_state = 78, .external_lex_state = 26},
  [4683] = {.lex_state = 94, .external_lex_state = 35},
  [4684] = {.lex_state = 87, .external_lex_state = 43},
  [4685] = {.lex_state = 80, .external_lex_state = 26},
  [4686] = {.lex_state = 88, .external_lex_state = 26},
  [4687] = {.lex_state = 80, .external_lex_state = 26},
  [4688] = {.lex_state = 79, .external_lex_state = 26},
  [4689] = {.lex_state = 85, .external_lex_state = 33},
  [4690] = {.lex_state = 94, .external_lex_state = 36},
  [4691] = {.lex_state = 85, .external_lex_state = 33},
  [4692] = {.lex_state = 78, .external_lex_state = 31},
  [4693] = {.lex_state = 85, .external_lex_state = 26},
  [4694] = {.lex_state = 78, .external_lex_state = 31},
  [4695] = {.lex_state = 86, .external_lex_state = 28},
  [4696] = {.lex_state = 78, .external_lex_state = 33},
  [4697] = {.lex_state = 75, .external_lex_state = 29},
  [4698] = {.lex_state = 78, .external_lex_state = 32},
  [4699] = {.lex_state = 86, .external_lex_state = 28},
  [4700] = {.lex_state = 94, .external_lex_state = 37},
  [4701] = {.lex_state = 87, .external_lex_state = 42},
  [4702] = {.lex_state = 75, .external_lex_state = 34},
  [4703] = {.lex_state = 78, .external_lex_state = 32},
  [4704] = {.lex_state = 78, .external_lex_state = 27},
  [4705] = {.lex_state = 88, .external_lex_state = 26},
  [4706] = {.lex_state = 79, .external_lex_state = 26},
  [4707] = {.lex_state = 78, .external_lex_state = 27},
  [4708] = {.lex_state = 96, .external_lex_state = 31},
  [4709] = {.lex_state = 78, .external_lex_state = 26},
  [4710] = {.lex_state = 86, .external_lex_state = 28},
  [4711] = {.lex_state = 86, .external_lex_state = 28},
  [4712] = {.lex_state = 80, .external_lex_state = 37},
  [4713] = {.lex_state = 94, .external_lex_state = 35},
  [4714] = {.lex_state = 80, .external_lex_state = 27},
  [4715] = {.lex_state = 86, .external_lex_state = 27},
  [4716] = {.lex_state = 78, .external_lex_state = 44},
  [4717] = {.lex_state = 78, .external_lex_state = 27},
  [4718] = {.lex_state = 78, .external_lex_state = 43},
  [4719] = {.lex_state = 78, .external_lex_state = 33},
  [4720] = {.lex_state = 87, .external_lex_state = 36},
  [4721] = {.lex_state = 78, .external_lex_state = 26},
  [4722] = {.lex_state = 85, .external_lex_state = 28},
  [4723] = {.lex_state = 78, .external_lex_state = 27},
  [4724] = {.lex_state = 78, .external_lex_state = 28},
  [4725] = {.lex_state = 79, .external_lex_state = 37},
  [4726] = {.lex_state = 79, .external_lex_state = 35},
  [4727] = {.lex_state = 78, .external_lex_state = 27},
  [4728] = {.lex_state = 96, .external_lex_state = 33},
  [4729] = {.lex_state = 78, .external_lex_state = 27},
  [4730] = {.lex_state = 75, .external_lex_state = 29},
  [4731] = {.lex_state = 78, .external_lex_state = 27},
  [4732] = {.lex_state = 78, .external_lex_state = 32},
  [4733] = {.lex_state = 87, .external_lex_state = 37},
  [4734] = {.lex_state = 79, .external_lex_state = 26},
  [4735] = {.lex_state = 87, .external_lex_state = 39},
  [4736] = {.lex_state = 75, .external_lex_state = 23},
  [4737] = {.lex_state = 78, .external_lex_state = 37},
  [4738] = {.lex_state = 87, .external_lex_state = 44},
  [4739] = {.lex_state = 78, .external_lex_state = 28},
  [4740] = {.lex_state = 79, .external_lex_state = 26},
  [4741] = {.lex_state = 79, .external_lex_state = 44},
  [4742] = {.lex_state = 78, .external_lex_state = 27},
  [4743] = {.lex_state = 79, .external_lex_state = 26},
  [4744] = {.lex_state = 75, .external_lex_state = 45},
  [4745] = {.lex_state = 78, .external_lex_state = 28},
  [4746] = {.lex_state = 87, .external_lex_state = 38},
  [4747] = {.lex_state = 78, .external_lex_state = 28},
  [4748] = {.lex_state = 80, .external_lex_state = 32},
  [4749] = {.lex_state = 87, .external_lex_state = 40},
  [4750] = {.lex_state = 75, .external_lex_state = 46},
  [4751] = {.lex_state = 78, .external_lex_state = 28},
  [4752] = {.lex_state = 80, .external_lex_state = 28},
  [4753] = {.lex_state = 80, .external_lex_state = 28},
  [4754] = {.lex_state = 80, .external_lex_state = 27},
  [4755] = {.lex_state = 79, .external_lex_state = 26},
  [4756] = {.lex_state = 78, .external_lex_state = 28},
  [4757] = {.lex_state = 78, .external_lex_state = 27},
  [4758] = {.lex_state = 96, .external_lex_state = 33},
  [4759] = {.lex_state = 87, .external_lex_state = 41},
  [4760] = {.lex_state = 79, .external_lex_state = 43},
  [4761] = {.lex_state = 96, .external_lex_state = 32},
  [4762] = {.lex_state = 85, .external_lex_state = 27},
  [4763] = {.lex_state = 96, .external_lex_state = 31},
  [4764] = {.lex_state = 78, .external_lex_state = 28},
  [4765] = {.lex_state = 85, .external_lex_state = 28},
  [4766] = {.lex_state = 80, .external_lex_state = 26},
  [4767] = {.lex_state = 87, .external_lex_state = 38},
  [4768] = {.lex_state = 78, .external_lex_state = 28},
  [4769] = {.lex_state = 80, .external_lex_state = 26},
  [4770] = {.lex_state = 79, .external_lex_state = 26},
  [4771] = {.lex_state = 75, .external_lex_state = 30},
  [4772] = {.lex_state = 79, .external_lex_state = 42},
  [4773] = {.lex_state = 78, .external_lex_state = 28},
  [4774] = {.lex_state = 79, .external_lex_state = 35},
  [4775] = {.lex_state = 79, .external_lex_state = 26},
  [4776] = {.lex_state = 87, .external_lex_state = 40},
  [4777] = {.lex_state = 78, .external_lex_state = 27},
  [4778] = {.lex_state = 79, .external_lex_state = 26},
  [4779] = {.lex_state = 87, .external_lex_state = 39},
  [4780] = {.lex_state = 94, .external_lex_state = 37},
  [4781] = {.lex_state = 75, .external_lex_state = 30},
  [4782] = {.lex_state = 86, .external_lex_state = 27},
  [4783] = {.lex_state = 78, .external_lex_state = 27},
  [4784] = {.lex_state = 79, .external_lex_state = 26},
  [4785] = {.lex_state = 78, .external_lex_state = 27},
  [4786] = {.lex_state = 78, .external_lex_state = 28},
  [4787] = {.lex_state = 96, .external_lex_state = 31},
  [4788] = {.lex_state = 80, .external_lex_state = 28},
  [4789] = {.lex_state = 79, .external_lex_state = 26},
  [4790] = {.lex_state = 80, .external_lex_state = 28},
  [4791] = {.lex_state = 78, .external_lex_state = 41},
  [4792] = {.lex_state = 78, .external_lex_state = 27},
  [4793] = {.lex_state = 79, .external_lex_state = 26},
  [4794] = {.lex_state = 80, .external_lex_state = 31},
  [4795] = {.lex_state = 96, .external_lex_state = 33},
  [4796] = {.lex_state = 80, .external_lex_state = 33},
  [4797] = {.lex_state = 75, .external_lex_state = 40},
  [4798] = {.lex_state = 87, .external_lex_state = 29},
  [4799] = {.lex_state = 80, .external_lex_state = 26},
  [4800] = {.lex_state = 78, .external_lex_state = 27},
  [4801] = {.lex_state = 87, .external_lex_state = 39},
  [4802] = {.lex_state = 80, .external_lex_state = 26},
  [4803] = {.lex_state = 80, .external_lex_state = 26},
  [4804] = {.lex_state = 87, .external_lex_state = 38},
  [4805] = {.lex_state = 80, .external_lex_state = 35},
  [4806] = {.lex_state = 87, .external_lex_state = 40},
  [4807] = {.lex_state = 79, .external_lex_state = 26},
  [4808] = {.lex_state = 86, .external_lex_state = 27},
  [4809] = {.lex_state = 79, .external_lex_state = 26},
  [4810] = {.lex_state = 80, .external_lex_state = 26},
  [4811] = {.lex_state = 86, .external_lex_state = 27},
  [4812] = {.lex_state = 80, .external_lex_state = 26},
  [4813] = {.lex_state = 79, .external_lex_state = 36},
  [4814] = {.lex_state = 80, .external_lex_state = 26},
  [4815] = {.lex_state = 80, .external_lex_state = 28},
  [4816] = {.lex_state = 87, .external_lex_state = 42},
  [4817] = {.lex_state = 94, .external_lex_state = 43},
  [4818] = {.lex_state = 87, .external_lex_state = 47},
  [4819] = {.lex_state = 78, .external_lex_state = 48},
  [4820] = {.lex_state = 75, .external_lex_state = 29},
  [4821] = {.lex_state = 79, .external_lex_state = 27},
  [4822] = {.lex_state = 86, .external_lex_state = 31},
  [4823] = {.lex_state = 80, .external_lex_state = 27},
  [4824] = {.lex_state = 80, .external_lex_state = 27},
  [4825] = {.lex_state = 80, .external_lex_state = 27},
  [4826] = {.lex_state = 78, .external_lex_state = 33},
  [4827] = {.lex_state = 75, .external_lex_state = 29},
  [4828] = {.lex_state = 78, .external_lex_state = 33},
  [4829] = {.lex_state = 80, .external_lex_state = 27},
  [4830] = {.lex_state = 79, .external_lex_state = 44},
  [4831] = {.lex_state = 94, .external_lex_state = 43},
  [4832] = {.lex_state = 80, .external_lex_state = 27},
  [4833] = {.lex_state = 96, .external_lex_state = 36},
  [4834] = {.lex_state = 78, .external_lex_state = 32},
  [4835] = {.lex_state = 79, .external_lex_state = 26},
  [4836] = {.lex_state = 78, .external_lex_state = 33},
  [4837] = {.lex_state = 78, .external_lex_state = 33},
  [4838] = {.lex_state = 78, .external_lex_state = 32},
  [4839] = {.lex_state = 96, .external_lex_state = 36},
  [4840] = {.lex_state = 80, .external_lex_state = 32},
  [4841] = {.lex_state = 78, .external_lex_state = 33},
  [4842] = {.lex_state = 78, .external_lex_state = 33},
  [4843] = {.lex_state = 78, .external_lex_state = 28},
  [4844] = {.lex_state = 96, .external_lex_state = 35},
  [4845] = {.lex_state = 86, .external_lex_state = 32},
  [4846] = {.lex_state = 80, .external_lex_state = 49},
  [4847] = {.lex_state = 96, .external_lex_state = 36},
  [4848] = {.lex_state = 79, .external_lex_state = 27},
  [4849] = {.lex_state = 85, .external_lex_state = 37},
  [4850] = {.lex_state = 78, .external_lex_state = 27},
  [4851] = {.lex_state = 85, .external_lex_state = 28},
  [4852] = {.lex_state = 79, .external_lex_state = 28},
  [4853] = {.lex_state = 87, .external_lex_state = 30},
  [4854] = {.lex_state = 85, .external_lex_state = 37},
  [4855] = {.lex_state = 85, .external_lex_state = 33},
  [4856] = {.lex_state = 78, .external_lex_state = 31},
  [4857] = {.lex_state = 85, .external_lex_state = 27},
  [4858] = {.lex_state = 87, .external_lex_state = 26},
  [4859] = {.lex_state = 79, .external_lex_state = 27},
  [4860] = {.lex_state = 78, .external_lex_state = 27},
  [4861] = {.lex_state = 85, .external_lex_state = 28},
  [4862] = {.lex_state = 85, .external_lex_state = 28},
  [4863] = {.lex_state = 85, .external_lex_state = 28},
  [4864] = {.lex_state = 80, .external_lex_state = 28},
  [4865] = {.lex_state = 80, .external_lex_state = 27},
  [4866] = {.lex_state = 85, .external_lex_state = 31},
  [4867] = {.lex_state = 79, .external_lex_state = 41},
  [4868] = {.lex_state = 75, .external_lex_state = 29},
  [4869] = {.lex_state = 78, .external_lex_state = 32},
  [4870] = {.lex_state = 78, .external_lex_state = 33},
  [4871] = {.lex_state = 82, .external_lex_state = 50},
  [4872] = {.lex_state = 78, .external_lex_state = 32},
  [4873] = {.lex_state = 85, .external_lex_state = 36},
  [4874] = {.lex_state = 79, .external_lex_state = 27},
  [4875] = {.lex_state = 78, .external_lex_state = 32},
  [4876] = {.lex_state = 79, .external_lex_state = 28},
  [4877] = {.lex_state = 78, .external_lex_state = 32},
  [4878] = {.lex_state = 78, .external_lex_state = 32},
  [4879] = {.lex_state = 78, .external_lex_state = 36},
  [4880] = {.lex_state = 78, .external_lex_state = 37},
  [4881] = {.lex_state = 78, .external_lex_state = 32},
  [4882] = {.lex_state = 78, .external_lex_state = 32},
  [4883] = {.lex_state = 87, .external_lex_state = 23},
  [4884] = {.lex_state = 75, .external_lex_state = 38},
  [4885] = {.lex_state = 78, .external_lex_state = 31},
  [4886] = {.lex_state = 78, .external_lex_state = 26},
  [4887] = {.lex_state = 78, .external_lex_state = 31},
  [4888] = {.lex_state = 78, .external_lex_state = 31},
  [4889] = {.lex_state = 85, .external_lex_state = 36},
  [4890] = {.lex_state = 78, .external_lex_state = 31},
  [4891] = {.lex_state = 78, .external_lex_state = 31},
  [4892] = {.lex_state = 78, .external_lex_state = 31},
  [4893] = {.lex_state = 75, .external_lex_state = 34},
  [4894] = {.lex_state = 88, .external_lex_state = 31},
  [4895] = {.lex_state = 79, .external_lex_state = 27},
  [4896] = {.lex_state = 88, .external_lex_state = 27},
  [4897] = {.lex_state = 78, .external_lex_state = 31},
  [4898] = {.lex_state = 96, .external_lex_state = 35},
  [4899] = {.lex_state = 78, .external_lex_state = 31},
  [4900] = {.lex_state = 78, .external_lex_state = 33},
  [4901] = {.lex_state = 79, .external_lex_state = 43},
  [4902] = {.lex_state = 87, .external_lex_state = 29},
  [4903] = {.lex_state = 79, .external_lex_state = 27},
  [4904] = {.lex_state = 86, .external_lex_state = 33},
  [4905] = {.lex_state = 85, .external_lex_state = 32},
  [4906] = {.lex_state = 78, .external_lex_state = 37},
  [4907] = {.lex_state = 75, .external_lex_state = 51},
  [4908] = {.lex_state = 88, .external_lex_state = 31},
  [4909] = {.lex_state = 80, .external_lex_state = 28},
  [4910] = {.lex_state = 78, .external_lex_state = 35},
  [4911] = {.lex_state = 96, .external_lex_state = 37},
  [4912] = {.lex_state = 80, .external_lex_state = 28},
  [4913] = {.lex_state = 79, .external_lex_state = 52},
  [4914] = {.lex_state = 78, .external_lex_state = 35},
  [4915] = {.lex_state = 75, .external_lex_state = 30},
  [4916] = {.lex_state = 80, .external_lex_state = 26},
  [4917] = {.lex_state = 80, .external_lex_state = 44},
  [4918] = {.lex_state = 75, .external_lex_state = 38},
  [4919] = {.lex_state = 75, .external_lex_state = 30},
  [4920] = {.lex_state = 87, .external_lex_state = 23},
  [4921] = {.lex_state = 75, .external_lex_state = 53},
  [4922] = {.lex_state = 80, .external_lex_state = 26},
  [4923] = {.lex_state = 87, .external_lex_state = 34},
  [4924] = {.lex_state = 86, .external_lex_state = 26},
  [4925] = {.lex_state = 86, .external_lex_state = 26},
  [4926] = {.lex_state = 80, .external_lex_state = 33},
  [4927] = {.lex_state = 87, .external_lex_state = 29},
  [4928] = {.lex_state = 87, .external_lex_state = 45},
  [4929] = {.lex_state = 86, .external_lex_state = 26},
  [4930] = {.lex_state = 79, .external_lex_state = 28},
  [4931] = {.lex_state = 80, .external_lex_state = 28},
  [4932] = {.lex_state = 79, .external_lex_state = 27},
  [4933] = {.lex_state = 86, .external_lex_state = 26},
  [4934] = {.lex_state = 85, .external_lex_state = 31},
  [4935] = {.lex_state = 85, .external_lex_state = 35},
  [4936] = {.lex_state = 80, .external_lex_state = 28},
  [4937] = {.lex_state = 79, .external_lex_state = 44},
  [4938] = {.lex_state = 94, .external_lex_state = 44},
  [4939] = {.lex_state = 79, .external_lex_state = 27},
  [4940] = {.lex_state = 87, .external_lex_state = 48},
  [4941] = {.lex_state = 80, .external_lex_state = 28},
  [4942] = {.lex_state = 94, .external_lex_state = 44},
  [4943] = {.lex_state = 79, .external_lex_state = 28},
  [4944] = {.lex_state = 80, .external_lex_state = 28},
  [4945] = {.lex_state = 78, .external_lex_state = 32},
  [4946] = {.lex_state = 78, .external_lex_state = 31},
  [4947] = {.lex_state = 88, .external_lex_state = 26},
  [4948] = {.lex_state = 78, .external_lex_state = 31},
  [4949] = {.lex_state = 88, .external_lex_state = 26},
  [4950] = {.lex_state = 78, .external_lex_state = 31},
  [4951] = {.lex_state = 75, .external_lex_state = 54},
  [4952] = {.lex_state = 80, .external_lex_state = 28},
  [4953] = {.lex_state = 85, .external_lex_state = 26},
  [4954] = {.lex_state = 94, .external_lex_state = 43},
  [4955] = {.lex_state = 96, .external_lex_state = 37},
  [4956] = {.lex_state = 80, .external_lex_state = 28},
  [4957] = {.lex_state = 88, .external_lex_state = 26},
  [4958] = {.lex_state = 79, .external_lex_state = 27},
  [4959] = {.lex_state = 88, .external_lex_state = 33},
  [4960] = {.lex_state = 80, .external_lex_state = 28},
  [4961] = {.lex_state = 75, .external_lex_state = 46},
  [4962] = {.lex_state = 96, .external_lex_state = 37},
  [4963] = {.lex_state = 88, .external_lex_state = 33},
  [4964] = {.lex_state = 78, .external_lex_state = 33},
  [4965] = {.lex_state = 87, .external_lex_state = 26},
  [4966] = {.lex_state = 80, .external_lex_state = 28},
  [4967] = {.lex_state = 94, .external_lex_state = 42},
  [4968] = {.lex_state = 85, .external_lex_state = 32},
  [4969] = {.lex_state = 79, .external_lex_state = 27},
  [4970] = {.lex_state = 94, .external_lex_state = 42},
  [4971] = {.lex_state = 75, .external_lex_state = 34},
  [4972] = {.lex_state = 96, .external_lex_state = 35},
  [4973] = {.lex_state = 86, .external_lex_state = 32},
  [4974] = {.lex_state = 80, .external_lex_state = 27},
  [4975] = {.lex_state = 79, .external_lex_state = 42},
  [4976] = {.lex_state = 80, .external_lex_state = 27},
  [4977] = {.lex_state = 80, .external_lex_state = 33},
  [4978] = {.lex_state = 78, .external_lex_state = 35},
  [4979] = {.lex_state = 88, .external_lex_state = 32},
  [4980] = {.lex_state = 85, .external_lex_state = 27},
  [4981] = {.lex_state = 80, .external_lex_state = 31},
  [4982] = {.lex_state = 94, .external_lex_state = 26},
  [4983] = {.lex_state = 79, .external_lex_state = 28},
  [4984] = {.lex_state = 80, .external_lex_state = 32},
  [4985] = {.lex_state = 80, .external_lex_state = 42},
  [4986] = {.lex_state = 88, .external_lex_state = 32},
  [4987] = {.lex_state = 79, .external_lex_state = 47},
  [4988] = {.lex_state = 87, .external_lex_state = 46},
  [4989] = {.lex_state = 75, .external_lex_state = 39},
  [4990] = {.lex_state = 79, .external_lex_state = 27},
  [4991] = {.lex_state = 78, .external_lex_state = 47},
  [4992] = {.lex_state = 87, .external_lex_state = 43},
  [4993] = {.lex_state = 88, .external_lex_state = 27},
  [4994] = {.lex_state = 80, .external_lex_state = 37},
  [4995] = {.lex_state = 85, .external_lex_state = 27},
  [4996] = {.lex_state = 79, .external_lex_state = 28},
  [4997] = {.lex_state = 79, .external_lex_state = 28},
  [4998] = {.lex_state = 80, .external_lex_state = 32},
  [4999] = {.lex_state = 75, .external_lex_state = 29},
  [5000] = {.lex_state = 78, .external_lex_state = 32},
  [5001] = {.lex_state = 78, .external_lex_state = 32},
  [5002] = {.lex_state = 78, .external_lex_state = 32},
  [5003] = {.lex_state = 78, .external_lex_state = 36},
  [5004] = {.lex_state = 85, .external_lex_state = 27},
  [5005] = {.lex_state = 79, .external_lex_state = 48},
  [5006] = {.lex_state = 86, .external_lex_state = 31},
  [5007] = {.lex_state = 79, .external_lex_state = 27},
  [5008] = {.lex_state = 80, .external_lex_state = 28},
  [5009] = {.lex_state = 86, .external_lex_state = 31},
  [5010] = {.lex_state = 80, .external_lex_state = 31},
  [5011] = {.lex_state = 80, .external_lex_state = 31},
  [5012] = {.lex_state = 80, .external_lex_state = 35},
  [5013] = {.lex_state = 80, .external_lex_state = 31},
  [5014] = {.lex_state = 79, .external_lex_state = 27},
  [5015] = {.lex_state = 88, .external_lex_state = 26},
  [5016] = {.lex_state = 78, .external_lex_state = 42},
  [5017] = {.lex_state = 86, .external_lex_state = 32},
  [5018] = {.lex_state = 80, .external_lex_state = 27},
  [5019] = {.lex_state = 80, .external_lex_state = 27},
  [5020] = {.lex_state = 86, .external_lex_state = 32},
  [5021] = {.lex_state = 80, .external_lex_state = 27},
  [5022] = {.lex_state = 94, .external_lex_state = 41},
  [5023] = {.lex_state = 94, .external_lex_state = 41},
  [5024] = {.lex_state = 94, .external_lex_state = 42},
  [5025] = {.lex_state = 79, .external_lex_state = 41},
  [5026] = {.lex_state = 75, .external_lex_state = 39},
  [5027] = {.lex_state = 80, .external_lex_state = 32},
  [5028] = {.lex_state = 80, .external_lex_state = 27},
  [5029] = {.lex_state = 78, .external_lex_state = 33},
  [5030] = {.lex_state = 86, .external_lex_state = 26},
  [5031] = {.lex_state = 78, .external_lex_state = 35},
  [5032] = {.lex_state = 79, .external_lex_state = 28},
  [5033] = {.lex_state = 94, .external_lex_state = 41},
  [5034] = {.lex_state = 75, .external_lex_state = 39},
  [5035] = {.lex_state = 94, .external_lex_state = 44},
  [5036] = {.lex_state = 88, .external_lex_state = 28},
  [5037] = {.lex_state = 82, .external_lex_state = 35},
  [5038] = {.lex_state = 75, .external_lex_state = 40},
  [5039] = {.lex_state = 78, .external_lex_state = 28},
  [5040] = {.lex_state = 78, .external_lex_state = 28},
  [5041] = {.lex_state = 79, .external_lex_state = 27},
  [5042] = {.lex_state = 87, .external_lex_state = 46},
  [5043] = {.lex_state = 75, .external_lex_state = 46},
  [5044] = {.lex_state = 87, .external_lex_state = 45},
  [5045] = {.lex_state = 78, .external_lex_state = 27},
  [5046] = {.lex_state = 78, .external_lex_state = 37},
  [5047] = {.lex_state = 87, .external_lex_state = 44},
  [5048] = {.lex_state = 78, .external_lex_state = 52},
  [5049] = {.lex_state = 78, .external_lex_state = 33},
  [5050] = {.lex_state = 78, .external_lex_state = 32},
  [5051] = {.lex_state = 87, .external_lex_state = 52},
  [5052] = {.lex_state = 85, .external_lex_state = 35},
  [5053] = {.lex_state = 79, .external_lex_state = 43},
  [5054] = {.lex_state = 86, .external_lex_state = 33},
  [5055] = {.lex_state = 78, .external_lex_state = 31},
  [5056] = {.lex_state = 80, .external_lex_state = 27},
  [5057] = {.lex_state = 79, .external_lex_state = 42},
  [5058] = {.lex_state = 79, .external_lex_state = 28},
  [5059] = {.lex_state = 79, .external_lex_state = 27},
  [5060] = {.lex_state = 78, .external_lex_state = 31},
  [5061] = {.lex_state = 78, .external_lex_state = 44},
  [5062] = {.lex_state = 79, .external_lex_state = 27},
  [5063] = {.lex_state = 75, .external_lex_state = 40},
  [5064] = {.lex_state = 80, .external_lex_state = 33},
  [5065] = {.lex_state = 86, .external_lex_state = 33},
  [5066] = {.lex_state = 79, .external_lex_state = 28},
  [5067] = {.lex_state = 79, .external_lex_state = 28},
  [5068] = {.lex_state = 79, .external_lex_state = 27},
  [5069] = {.lex_state = 80, .external_lex_state = 41},
  [5070] = {.lex_state = 79, .external_lex_state = 28},
  [5071] = {.lex_state = 78, .external_lex_state = 43},
  [5072] = {.lex_state = 80, .external_lex_state = 33},
  [5073] = {.lex_state = 75, .external_lex_state = 55},
  [5074] = {.lex_state = 80, .external_lex_state = 43},
  [5075] = {.lex_state = 79, .external_lex_state = 28},
  [5076] = {.lex_state = 78, .external_lex_state = 33},
  [5077] = {.lex_state = 79, .external_lex_state = 28},
  [5078] = {.lex_state = 79, .external_lex_state = 28},
  [5079] = {.lex_state = 79, .external_lex_state = 28},
  [5080] = {.lex_state = 79, .external_lex_state = 28},
  [5081] = {.lex_state = 86, .external_lex_state = 31},
  [5082] = {.lex_state = 78, .external_lex_state = 33},
  [5083] = {.lex_state = 86, .external_lex_state = 33},
  [5084] = {.lex_state = 78, .external_lex_state = 33},
  [5085] = {.lex_state = 80, .external_lex_state = 36},
  [5086] = {.lex_state = 85, .external_lex_state = 33},
  [5087] = {.lex_state = 78, .external_lex_state = 36},
  [5088] = {.lex_state = 78, .external_lex_state = 36},
  [5089] = {.lex_state = 87, .external_lex_state = 41},
  [5090] = {.lex_state = 78, .external_lex_state = 41},
  [5091] = {.lex_state = 88, .external_lex_state = 28},
  [5092] = {.lex_state = 87, .external_lex_state = 45},
  [5093] = {.lex_state = 87, .external_lex_state = 46},
  [5094] = {.lex_state = 78, .external_lex_state = 37},
  [5095] = {.lex_state = 96, .external_lex_state = 44},
  [5096] = {.lex_state = 80, .external_lex_state = 35},
  [5097] = {.lex_state = 85, .external_lex_state = 35},
  [5098] = {.lex_state = 78, .external_lex_state = 31},
  [5099] = {.lex_state = 82, .external_lex_state = 50},
  [5100] = {.lex_state = 78, .external_lex_state = 44},
  [5101] = {.lex_state = 87, .external_lex_state = 38},
  [5102] = {.lex_state = 79, .external_lex_state = 32},
  [5103] = {.lex_state = 87, .external_lex_state = 34},
  [5104] = {.lex_state = 79, .external_lex_state = 49},
  [5105] = {.lex_state = 78, .external_lex_state = 35},
  [5106] = {.lex_state = 75, .external_lex_state = 53},
  [5107] = {.lex_state = 78, .external_lex_state = 35},
  [5108] = {.lex_state = 80, .external_lex_state = 26},
  [5109] = {.lex_state = 87, .external_lex_state = 27},
  [5110] = {.lex_state = 32},
  [5111] = {.lex_state = 32},
  [5112] = {.lex_state = 75, .external_lex_state = 53},
  [5113] = {.lex_state = 78, .external_lex_state = 26},
  [5114] = {.lex_state = 80, .external_lex_state = 32},
  [5115] = {.lex_state = 80, .external_lex_state = 32},
  [5116] = {.lex_state = 80, .external_lex_state = 32},
  [5117] = {.lex_state = 80, .external_lex_state = 31},
  [5118] = {.lex_state = 87, .external_lex_state = 34},
  [5119] = {.lex_state = 80, .external_lex_state = 32},
  [5120] = {.lex_state = 80, .external_lex_state = 32},
  [5121] = {.lex_state = 94, .external_lex_state = 48},
  [5122] = {.lex_state = 78, .external_lex_state = 35},
  [5123] = {.lex_state = 87, .external_lex_state = 26},
  [5124] = {.lex_state = 80, .external_lex_state = 32},
  [5125] = {.lex_state = 78, .external_lex_state = 41},
  [5126] = {.lex_state = 80, .external_lex_state = 32},
  [5127] = {.lex_state = 75, .external_lex_state = 38},
  [5128] = {.lex_state = 79, .external_lex_state = 33},
  [5129] = {.lex_state = 87, .external_lex_state = 46},
  [5130] = {.lex_state = 96, .external_lex_state = 49},
  [5131] = {.lex_state = 79, .external_lex_state = 33},
  [5132] = {.lex_state = 79, .external_lex_state = 33},
  [5133] = {.lex_state = 87, .external_lex_state = 30},
  [5134] = {.lex_state = 78, .external_lex_state = 35},
  [5135] = {.lex_state = 75, .external_lex_state = 54},
  [5136] = {.lex_state = 75, .external_lex_state = 40},
  [5137] = {.lex_state = 85, .external_lex_state = 36},
  [5138] = {.lex_state = 87, .external_lex_state = 30},
  [5139] = {.lex_state = 87, .external_lex_state = 26},
  [5140] = {.lex_state = 75, .external_lex_state = 40},
  [5141] = {.lex_state = 78, .external_lex_state = 35},
  [5142] = {.lex_state = 75, .external_lex_state = 30},
  [5143] = {.lex_state = 75, .external_lex_state = 34},
  [5144] = {.lex_state = 87, .external_lex_state = 29},
  [5145] = {.lex_state = 78, .external_lex_state = 44},
  [5146] = {.lex_state = 75, .external_lex_state = 30},
  [5147] = {.lex_state = 78, .external_lex_state = 35},
  [5148] = {.lex_state = 75, .external_lex_state = 29},
  [5149] = {.lex_state = 87, .external_lex_state = 23},
  [5150] = {.lex_state = 75, .external_lex_state = 38},
  [5151] = {.lex_state = 78, .external_lex_state = 35},
  [5152] = {.lex_state = 84},
  [5153] = {.lex_state = 80, .external_lex_state = 32},
  [5154] = {.lex_state = 85, .external_lex_state = 44},
  [5155] = {.lex_state = 78, .external_lex_state = 35},
  [5156] = {.lex_state = 85, .external_lex_state = 44},
  [5157] = {.lex_state = 78, .external_lex_state = 32},
  [5158] = {.lex_state = 87, .external_lex_state = 39},
  [5159] = {.lex_state = 78, .external_lex_state = 35},
  [5160] = {.lex_state = 79, .external_lex_state = 31},
  [5161] = {.lex_state = 94, .external_lex_state = 26},
  [5162] = {.lex_state = 96, .external_lex_state = 49},
  [5163] = {.lex_state = 78, .external_lex_state = 35},
  [5164] = {.lex_state = 79, .external_lex_state = 33},
  [5165] = {.lex_state = 78, .external_lex_state = 31},
  [5166] = {.lex_state = 96, .external_lex_state = 42},
  [5167] = {.lex_state = 78, .external_lex_state = 35},
  [5168] = {.lex_state = 80, .external_lex_state = 31},
  [5169] = {.lex_state = 75, .external_lex_state = 54},
  [5170] = {.lex_state = 80, .external_lex_state = 31},
  [5171] = {.lex_state = 87, .external_lex_state = 53},
  [5172] = {.lex_state = 80, .external_lex_state = 31},
  [5173] = {.lex_state = 86, .external_lex_state = 27},
  [5174] = {.lex_state = 79, .external_lex_state = 33},
  [5175] = {.lex_state = 80, .external_lex_state = 31},
  [5176] = {.lex_state = 78, .external_lex_state = 31},
  [5177] = {.lex_state = 75, .external_lex_state = 30},
  [5178] = {.lex_state = 79, .external_lex_state = 27},
  [5179] = {.lex_state = 32},
  [5180] = {.lex_state = 75, .external_lex_state = 30},
  [5181] = {.lex_state = 87, .external_lex_state = 26},
  [5182] = {.lex_state = 87, .external_lex_state = 29},
  [5183] = {.lex_state = 80, .external_lex_state = 31},
  [5184] = {.lex_state = 87, .external_lex_state = 29},
  [5185] = {.lex_state = 87, .external_lex_state = 29},
  [5186] = {.lex_state = 94, .external_lex_state = 47},
  [5187] = {.lex_state = 80, .external_lex_state = 31},
  [5188] = {.lex_state = 87, .external_lex_state = 29},
  [5189] = {.lex_state = 75, .external_lex_state = 56},
  [5190] = {.lex_state = 78, .external_lex_state = 32},
  [5191] = {.lex_state = 78, .external_lex_state = 50},
  [5192] = {.lex_state = 78, .external_lex_state = 44},
  [5193] = {.lex_state = 94, .external_lex_state = 26},
  [5194] = {.lex_state = 85, .external_lex_state = 28},
  [5195] = {.lex_state = 78, .external_lex_state = 32},
  [5196] = {.lex_state = 86, .external_lex_state = 35},
  [5197] = {.lex_state = 75, .external_lex_state = 23},
  [5198] = {.lex_state = 96, .external_lex_state = 42},
  [5199] = {.lex_state = 85, .external_lex_state = 35},
  [5200] = {.lex_state = 80, .external_lex_state = 31},
  [5201] = {.lex_state = 79, .external_lex_state = 32},
  [5202] = {.lex_state = 86, .external_lex_state = 27},
  [5203] = {.lex_state = 85, .external_lex_state = 36},
  [5204] = {.lex_state = 87, .external_lex_state = 53},
  [5205] = {.lex_state = 32},
  [5206] = {.lex_state = 94, .external_lex_state = 52},
  [5207] = {.lex_state = 32},
  [5208] = {.lex_state = 78, .external_lex_state = 43},
  [5209] = {.lex_state = 78, .external_lex_state = 43},
  [5210] = {.lex_state = 79, .external_lex_state = 48},
  [5211] = {.lex_state = 80, .external_lex_state = 36},
  [5212] = {.lex_state = 80, .external_lex_state = 36},
  [5213] = {.lex_state = 87, .external_lex_state = 29},
  [5214] = {.lex_state = 79, .external_lex_state = 26},
  [5215] = {.lex_state = 80, .external_lex_state = 37},
  [5216] = {.lex_state = 87, .external_lex_state = 53},
  [5217] = {.lex_state = 85, .external_lex_state = 31},
  [5218] = {.lex_state = 85, .external_lex_state = 31},
  [5219] = {.lex_state = 80, .external_lex_state = 37},
  [5220] = {.lex_state = 94, .external_lex_state = 47},
  [5221] = {.lex_state = 87, .external_lex_state = 49},
  [5222] = {.lex_state = 85, .external_lex_state = 31},
  [5223] = {.lex_state = 83, .external_lex_state = 35},
  [5224] = {.lex_state = 75, .external_lex_state = 45},
  [5225] = {.lex_state = 96, .external_lex_state = 41},
  [5226] = {.lex_state = 87, .external_lex_state = 39},
  [5227] = {.lex_state = 79, .external_lex_state = 32},
  [5228] = {.lex_state = 87, .external_lex_state = 29},
  [5229] = {.lex_state = 94, .external_lex_state = 52},
  [5230] = {.lex_state = 79, .external_lex_state = 32},
  [5231] = {.lex_state = 78, .external_lex_state = 42},
  [5232] = {.lex_state = 87, .external_lex_state = 55},
  [5233] = {.lex_state = 79, .external_lex_state = 32},
  [5234] = {.lex_state = 79, .external_lex_state = 31},
  [5235] = {.lex_state = 79, .external_lex_state = 32},
  [5236] = {.lex_state = 87, .external_lex_state = 55},
  [5237] = {.lex_state = 85, .external_lex_state = 32},
  [5238] = {.lex_state = 80, .external_lex_state = 44},
  [5239] = {.lex_state = 85, .external_lex_state = 32},
  [5240] = {.lex_state = 79, .external_lex_state = 32},
  [5241] = {.lex_state = 75, .external_lex_state = 23},
  [5242] = {.lex_state = 94, .external_lex_state = 28},
  [5243] = {.lex_state = 86, .external_lex_state = 35},
  [5244] = {.lex_state = 79, .external_lex_state = 32},
  [5245] = {.lex_state = 75, .external_lex_state = 34},
  [5246] = {.lex_state = 80, .external_lex_state = 33},
  [5247] = {.lex_state = 75, .external_lex_state = 45},
  [5248] = {.lex_state = 85, .external_lex_state = 32},
  [5249] = {.lex_state = 80, .external_lex_state = 43},
  [5250] = {.lex_state = 75, .external_lex_state = 45},
  [5251] = {.lex_state = 79, .external_lex_state = 32},
  [5252] = {.lex_state = 86, .external_lex_state = 28},
  [5253] = {.lex_state = 96, .external_lex_state = 41},
  [5254] = {.lex_state = 87, .external_lex_state = 55},
  [5255] = {.lex_state = 88, .external_lex_state = 35},
  [5256] = {.lex_state = 87, .external_lex_state = 27},
  [5257] = {.lex_state = 78, .external_lex_state = 37},
  [5258] = {.lex_state = 88, .external_lex_state = 35},
  [5259] = {.lex_state = 79, .external_lex_state = 31},
  [5260] = {.lex_state = 96, .external_lex_state = 49},
  [5261] = {.lex_state = 86, .external_lex_state = 37},
  [5262] = {.lex_state = 78, .external_lex_state = 37},
  [5263] = {.lex_state = 80, .external_lex_state = 33},
  [5264] = {.lex_state = 78, .external_lex_state = 41},
  [5265] = {.lex_state = 86, .external_lex_state = 37},
  [5266] = {.lex_state = 80, .external_lex_state = 49},
  [5267] = {.lex_state = 80, .external_lex_state = 33},
  [5268] = {.lex_state = 79, .external_lex_state = 48},
  [5269] = {.lex_state = 85, .external_lex_state = 37},
  [5270] = {.lex_state = 79, .external_lex_state = 31},
  [5271] = {.lex_state = 79, .external_lex_state = 31},
  [5272] = {.lex_state = 80, .external_lex_state = 33},
  [5273] = {.lex_state = 75, .external_lex_state = 34},
  [5274] = {.lex_state = 79, .external_lex_state = 31},
  [5275] = {.lex_state = 79, .external_lex_state = 31},
  [5276] = {.lex_state = 79, .external_lex_state = 31},
  [5277] = {.lex_state = 78, .external_lex_state = 41},
  [5278] = {.lex_state = 78, .external_lex_state = 36},
  [5279] = {.lex_state = 79, .external_lex_state = 31},
  [5280] = {.lex_state = 78, .external_lex_state = 36},
  [5281] = {.lex_state = 80, .external_lex_state = 35},
  [5282] = {.lex_state = 78, .external_lex_state = 36},
  [5283] = {.lex_state = 75, .external_lex_state = 46},
  [5284] = {.lex_state = 87, .external_lex_state = 29},
  [5285] = {.lex_state = 75, .external_lex_state = 46},
  [5286] = {.lex_state = 78, .external_lex_state = 37},
  [5287] = {.lex_state = 78, .external_lex_state = 37},
  [5288] = {.lex_state = 78, .external_lex_state = 37},
  [5289] = {.lex_state = 78, .external_lex_state = 37},
  [5290] = {.lex_state = 78, .external_lex_state = 36},
  [5291] = {.lex_state = 80, .external_lex_state = 31},
  [5292] = {.lex_state = 78, .external_lex_state = 43},
  [5293] = {.lex_state = 78, .external_lex_state = 37},
  [5294] = {.lex_state = 78, .external_lex_state = 37},
  [5295] = {.lex_state = 87, .external_lex_state = 29},
  [5296] = {.lex_state = 80, .external_lex_state = 42},
  [5297] = {.lex_state = 87, .external_lex_state = 47},
  [5298] = {.lex_state = 78, .external_lex_state = 37},
  [5299] = {.lex_state = 78, .external_lex_state = 42},
  [5300] = {.lex_state = 87, .external_lex_state = 51},
  [5301] = {.lex_state = 79, .external_lex_state = 32},
  [5302] = {.lex_state = 80, .external_lex_state = 32},
  [5303] = {.lex_state = 80, .external_lex_state = 31},
  [5304] = {.lex_state = 80, .external_lex_state = 31},
  [5305] = {.lex_state = 80, .external_lex_state = 31},
  [5306] = {.lex_state = 80, .external_lex_state = 36},
  [5307] = {.lex_state = 78, .external_lex_state = 43},
  [5308] = {.lex_state = 88, .external_lex_state = 31},
  [5309] = {.lex_state = 79, .external_lex_state = 31},
  [5310] = {.lex_state = 96, .external_lex_state = 44},
  [5311] = {.lex_state = 78, .external_lex_state = 47},
  [5312] = {.lex_state = 87, .external_lex_state = 29},
  [5313] = {.lex_state = 85, .external_lex_state = 43},
  [5314] = {.lex_state = 85, .external_lex_state = 43},
  [5315] = {.lex_state = 80, .external_lex_state = 32},
  [5316] = {.lex_state = 86, .external_lex_state = 28},
  [5317] = {.lex_state = 78, .external_lex_state = 37},
  [5318] = {.lex_state = 78, .external_lex_state = 37},
  [5319] = {.lex_state = 78, .external_lex_state = 52},
  [5320] = {.lex_state = 79, .external_lex_state = 31},
  [5321] = {.lex_state = 80, .external_lex_state = 32},
  [5322] = {.lex_state = 86, .external_lex_state = 28},
  [5323] = {.lex_state = 79, .external_lex_state = 33},
  [5324] = {.lex_state = 80, .external_lex_state = 32},
  [5325] = {.lex_state = 88, .external_lex_state = 36},
  [5326] = {.lex_state = 87, .external_lex_state = 52},
  [5327] = {.lex_state = 85, .external_lex_state = 33},
  [5328] = {.lex_state = 78, .external_lex_state = 42},
  [5329] = {.lex_state = 78, .external_lex_state = 37},
  [5330] = {.lex_state = 85, .external_lex_state = 31},
  [5331] = {.lex_state = 85, .external_lex_state = 37},
  [5332] = {.lex_state = 78, .external_lex_state = 42},
  [5333] = {.lex_state = 86, .external_lex_state = 28},
  [5334] = {.lex_state = 88, .external_lex_state = 36},
  [5335] = {.lex_state = 86, .external_lex_state = 36},
  [5336] = {.lex_state = 94, .external_lex_state = 27},
  [5337] = {.lex_state = 80, .external_lex_state = 41},
  [5338] = {.lex_state = 75, .external_lex_state = 57},
  [5339] = {.lex_state = 78, .external_lex_state = 37},
  [5340] = {.lex_state = 80, .external_lex_state = 33},
  [5341] = {.lex_state = 87, .external_lex_state = 29},
  [5342] = {.lex_state = 86, .external_lex_state = 35},
  [5343] = {.lex_state = 94, .external_lex_state = 48},
  [5344] = {.lex_state = 79, .external_lex_state = 31},
  [5345] = {.lex_state = 79, .external_lex_state = 26},
  [5346] = {.lex_state = 86, .external_lex_state = 27},
  [5347] = {.lex_state = 88, .external_lex_state = 27},
  [5348] = {.lex_state = 78, .external_lex_state = 33},
  [5349] = {.lex_state = 88, .external_lex_state = 28},
  [5350] = {.lex_state = 96, .external_lex_state = 44},
  [5351] = {.lex_state = 88, .external_lex_state = 28},
  [5352] = {.lex_state = 85, .external_lex_state = 32},
  [5353] = {.lex_state = 88, .external_lex_state = 32},
  [5354] = {.lex_state = 86, .external_lex_state = 27},
  [5355] = {.lex_state = 78, .external_lex_state = 36},
  [5356] = {.lex_state = 94, .external_lex_state = 48},
  [5357] = {.lex_state = 79, .external_lex_state = 31},
  [5358] = {.lex_state = 86, .external_lex_state = 27},
  [5359] = {.lex_state = 88, .external_lex_state = 28},
  [5360] = {.lex_state = 88, .external_lex_state = 28},
  [5361] = {.lex_state = 94, .external_lex_state = 26},
  [5362] = {.lex_state = 86, .external_lex_state = 35},
  [5363] = {.lex_state = 78, .external_lex_state = 33},
  [5364] = {.lex_state = 82, .external_lex_state = 35},
  [5365] = {.lex_state = 94, .external_lex_state = 26},
  [5366] = {.lex_state = 80, .external_lex_state = 28},
  [5367] = {.lex_state = 80, .external_lex_state = 28},
  [5368] = {.lex_state = 75, .external_lex_state = 58},
  [5369] = {.lex_state = 88, .external_lex_state = 33},
  [5370] = {.lex_state = 85, .external_lex_state = 42},
  [5371] = {.lex_state = 85, .external_lex_state = 42},
  [5372] = {.lex_state = 78, .external_lex_state = 49},
  [5373] = {.lex_state = 86, .external_lex_state = 36},
  [5374] = {.lex_state = 79, .external_lex_state = 47},
  [5375] = {.lex_state = 79, .external_lex_state = 32},
  [5376] = {.lex_state = 88, .external_lex_state = 31},
  [5377] = {.lex_state = 32},
  [5378] = {.lex_state = 82, .external_lex_state = 35},
  [5379] = {.lex_state = 80, .external_lex_state = 48},
  [5380] = {.lex_state = 94, .external_lex_state = 26},
  [5381] = {.lex_state = 88, .external_lex_state = 37},
  [5382] = {.lex_state = 88, .external_lex_state = 37},
  [5383] = {.lex_state = 87, .external_lex_state = 29},
  [5384] = {.lex_state = 88, .external_lex_state = 33},
  [5385] = {.lex_state = 79, .external_lex_state = 32},
  [5386] = {.lex_state = 86, .external_lex_state = 36},
  [5387] = {.lex_state = 80, .external_lex_state = 37},
  [5388] = {.lex_state = 85, .external_lex_state = 33},
  [5389] = {.lex_state = 78, .external_lex_state = 41},
  [5390] = {.lex_state = 79, .external_lex_state = 28},
  [5391] = {.lex_state = 88, .external_lex_state = 26},
  [5392] = {.lex_state = 87, .external_lex_state = 23},
  [5393] = {.lex_state = 85, .external_lex_state = 33},
  [5394] = {.lex_state = 85, .external_lex_state = 33},
  [5395] = {.lex_state = 78, .external_lex_state = 44},
  [5396] = {.lex_state = 87, .external_lex_state = 29},
  [5397] = {.lex_state = 79, .external_lex_state = 33},
  [5398] = {.lex_state = 78, .external_lex_state = 36},
  [5399] = {.lex_state = 78, .external_lex_state = 35},
  [5400] = {.lex_state = 87, .external_lex_state = 29},
  [5401] = {.lex_state = 80, .external_lex_state = 36},
  [5402] = {.lex_state = 87, .external_lex_state = 51},
  [5403] = {.lex_state = 79, .external_lex_state = 52},
  [5404] = {.lex_state = 87, .external_lex_state = 29},
  [5405] = {.lex_state = 79, .external_lex_state = 33},
  [5406] = {.lex_state = 86, .external_lex_state = 37},
  [5407] = {.lex_state = 88, .external_lex_state = 27},
  [5408] = {.lex_state = 87, .external_lex_state = 40},
  [5409] = {.lex_state = 80, .external_lex_state = 32},
  [5410] = {.lex_state = 87, .external_lex_state = 50},
  [5411] = {.lex_state = 88, .external_lex_state = 27},
  [5412] = {.lex_state = 79, .external_lex_state = 33},
  [5413] = {.lex_state = 86, .external_lex_state = 36},
  [5414] = {.lex_state = 88, .external_lex_state = 27},
  [5415] = {.lex_state = 87, .external_lex_state = 46},
  [5416] = {.lex_state = 79, .external_lex_state = 33},
  [5417] = {.lex_state = 10, .external_lex_state = 49},
  [5418] = {.lex_state = 79, .external_lex_state = 33},
  [5419] = {.lex_state = 79, .external_lex_state = 33},
  [5420] = {.lex_state = 79, .external_lex_state = 32},
  [5421] = {.lex_state = 79, .external_lex_state = 33},
  [5422] = {.lex_state = 87, .external_lex_state = 29},
  [5423] = {.lex_state = 87, .external_lex_state = 54},
  [5424] = {.lex_state = 96, .external_lex_state = 43},
  [5425] = {.lex_state = 78, .external_lex_state = 28},
  [5426] = {.lex_state = 87, .external_lex_state = 29},
  [5427] = {.lex_state = 85, .external_lex_state = 41},
  [5428] = {.lex_state = 78, .external_lex_state = 36},
  [5429] = {.lex_state = 78, .external_lex_state = 36},
  [5430] = {.lex_state = 79, .external_lex_state = 33},
  [5431] = {.lex_state = 86, .external_lex_state = 28},
  [5432] = {.lex_state = 80, .external_lex_state = 35},
  [5433] = {.lex_state = 87, .external_lex_state = 51},
  [5434] = {.lex_state = 85, .external_lex_state = 41},
  [5435] = {.lex_state = 79, .external_lex_state = 32},
  [5436] = {.lex_state = 96, .external_lex_state = 43},
  [5437] = {.lex_state = 79, .external_lex_state = 32},
  [5438] = {.lex_state = 78, .external_lex_state = 36},
  [5439] = {.lex_state = 79, .external_lex_state = 32},
  [5440] = {.lex_state = 78, .external_lex_state = 36},
  [5441] = {.lex_state = 88, .external_lex_state = 32},
  [5442] = {.lex_state = 86, .external_lex_state = 37},
  [5443] = {.lex_state = 79, .external_lex_state = 50},
  [5444] = {.lex_state = 78, .external_lex_state = 36},
  [5445] = {.lex_state = 96, .external_lex_state = 41},
  [5446] = {.lex_state = 78, .external_lex_state = 36},
  [5447] = {.lex_state = 79, .external_lex_state = 47},
  [5448] = {.lex_state = 78, .external_lex_state = 36},
  [5449] = {.lex_state = 80, .external_lex_state = 33},
  [5450] = {.lex_state = 79, .external_lex_state = 33},
  [5451] = {.lex_state = 80, .external_lex_state = 27},
  [5452] = {.lex_state = 87, .external_lex_state = 54},
  [5453] = {.lex_state = 78, .external_lex_state = 33},
  [5454] = {.lex_state = 96, .external_lex_state = 43},
  [5455] = {.lex_state = 78, .external_lex_state = 37},
  [5456] = {.lex_state = 79, .external_lex_state = 31},
  [5457] = {.lex_state = 79, .external_lex_state = 31},
  [5458] = {.lex_state = 96, .external_lex_state = 26},
  [5459] = {.lex_state = 80, .external_lex_state = 52},
  [5460] = {.lex_state = 79, .external_lex_state = 31},
  [5461] = {.lex_state = 79, .external_lex_state = 32},
  [5462] = {.lex_state = 78, .external_lex_state = 36},
  [5463] = {.lex_state = 80, .external_lex_state = 33},
  [5464] = {.lex_state = 83, .external_lex_state = 50},
  [5465] = {.lex_state = 75, .external_lex_state = 34},
  [5466] = {.lex_state = 80, .external_lex_state = 27},
  [5467] = {.lex_state = 80, .external_lex_state = 33},
  [5468] = {.lex_state = 96, .external_lex_state = 42},
  [5469] = {.lex_state = 87, .external_lex_state = 29},
  [5470] = {.lex_state = 87, .external_lex_state = 48},
  [5471] = {.lex_state = 78, .external_lex_state = 48},
  [5472] = {.lex_state = 80, .external_lex_state = 33},
  [5473] = {.lex_state = 78, .external_lex_state = 27},
  [5474] = {.lex_state = 80, .external_lex_state = 33},
  [5475] = {.lex_state = 80, .external_lex_state = 35},
  [5476] = {.lex_state = 78, .external_lex_state = 35},
  [5477] = {.lex_state = 80, .external_lex_state = 33},
  [5478] = {.lex_state = 80, .external_lex_state = 33},
  [5479] = {.lex_state = 85, .external_lex_state = 27},
  [5480] = {.lex_state = 80, .external_lex_state = 33},
  [5481] = {.lex_state = 79, .external_lex_state = 33},
  [5482] = {.lex_state = 80, .external_lex_state = 37},
  [5483] = {.lex_state = 94, .external_lex_state = 47},
  [5484] = {.lex_state = 80, .external_lex_state = 31},
  [5485] = {.lex_state = 75, .external_lex_state = 29},
  [5486] = {.lex_state = 87, .external_lex_state = 28},
  [5487] = {.lex_state = 79, .external_lex_state = 31},
  [5488] = {.lex_state = 87, .external_lex_state = 29},
  [5489] = {.lex_state = 80, .external_lex_state = 47},
  [5490] = {.lex_state = 79, .external_lex_state = 52},
  [5491] = {.lex_state = 79, .external_lex_state = 33},
  [5492] = {.lex_state = 87, .external_lex_state = 54},
  [5493] = {.lex_state = 94, .external_lex_state = 52},
  [5494] = {.lex_state = 78, .external_lex_state = 35},
  [5495] = {.lex_state = 87, .external_lex_state = 28},
  [5496] = {.lex_state = 87, .external_lex_state = 29},
  [5497] = {.lex_state = 75},
  [5498] = {.lex_state = 75, .external_lex_state = 54},
  [5499] = {.lex_state = 32},
  [5500] = {.lex_state = 86, .external_lex_state = 42},
  [5501] = {.lex_state = 87, .external_lex_state = 28},
  [5502] = {.lex_state = 75, .external_lex_state = 38},
  [5503] = {.lex_state = 32},
  [5504] = {.lex_state = 87, .external_lex_state = 34},
  [5505] = {.lex_state = 79, .external_lex_state = 36},
  [5506] = {.lex_state = 75, .external_lex_state = 30},
  [5507] = {.lex_state = 94, .external_lex_state = 33},
  [5508] = {.lex_state = 94, .external_lex_state = 50},
  [5509] = {.lex_state = 32},
  [5510] = {.lex_state = 78, .external_lex_state = 42},
  [5511] = {.lex_state = 78, .external_lex_state = 43},
  [5512] = {.lex_state = 94, .external_lex_state = 28},
  [5513] = {.lex_state = 32},
  [5514] = {.lex_state = 87, .external_lex_state = 29},
  [5515] = {.lex_state = 86, .external_lex_state = 42},
  [5516] = {.lex_state = 87, .external_lex_state = 29},
  [5517] = {.lex_state = 87, .external_lex_state = 29},
  [5518] = {.lex_state = 75, .external_lex_state = 24},
  [5519] = {.lex_state = 79, .external_lex_state = 35},
  [5520] = {.lex_state = 79, .external_lex_state = 32},
  [5521] = {.lex_state = 79, .external_lex_state = 35},
  [5522] = {.lex_state = 85, .external_lex_state = 26},
  [5523] = {.lex_state = 80, .external_lex_state = 52},
  [5524] = {.lex_state = 87, .external_lex_state = 29},
  [5525] = {.lex_state = 79, .external_lex_state = 35},
  [5526] = {.lex_state = 87, .external_lex_state = 30},
  [5527] = {.lex_state = 79, .external_lex_state = 35},
  [5528] = {.lex_state = 85, .external_lex_state = 26},
  [5529] = {.lex_state = 87, .external_lex_state = 29},
  [5530] = {.lex_state = 88, .external_lex_state = 37},
  [5531] = {.lex_state = 87, .external_lex_state = 29},
  [5532] = {.lex_state = 87, .external_lex_state = 30},
  [5533] = {.lex_state = 32},
  [5534] = {.lex_state = 79, .external_lex_state = 36},
  [5535] = {.lex_state = 87, .external_lex_state = 29},
  [5536] = {.lex_state = 78, .external_lex_state = 26},
  [5537] = {.lex_state = 79, .external_lex_state = 36},
  [5538] = {.lex_state = 32},
  [5539] = {.lex_state = 87, .external_lex_state = 29},
  [5540] = {.lex_state = 87, .external_lex_state = 29},
  [5541] = {.lex_state = 88, .external_lex_state = 31},
  [5542] = {.lex_state = 87, .external_lex_state = 28},
  [5543] = {.lex_state = 75, .external_lex_state = 56},
  [5544] = {.lex_state = 87, .external_lex_state = 53},
  [5545] = {.lex_state = 75, .external_lex_state = 57},
  [5546] = {.lex_state = 86, .external_lex_state = 43},
  [5547] = {.lex_state = 75, .external_lex_state = 39},
  [5548] = {.lex_state = 87, .external_lex_state = 29},
  [5549] = {.lex_state = 87, .external_lex_state = 32},
  [5550] = {.lex_state = 79, .external_lex_state = 36},
  [5551] = {.lex_state = 86, .external_lex_state = 33},
  [5552] = {.lex_state = 32},
  [5553] = {.lex_state = 32},
  [5554] = {.lex_state = 87, .external_lex_state = 29},
  [5555] = {.lex_state = 87, .external_lex_state = 30},
  [5556] = {.lex_state = 87, .external_lex_state = 38},
  [5557] = {.lex_state = 88, .external_lex_state = 31},
  [5558] = {.lex_state = 79, .external_lex_state = 35},
  [5559] = {.lex_state = 32},
  [5560] = {.lex_state = 83, .external_lex_state = 50},
  [5561] = {.lex_state = 88, .external_lex_state = 31},
  [5562] = {.lex_state = 96, .external_lex_state = 52},
  [5563] = {.lex_state = 32},
  [5564] = {.lex_state = 88, .external_lex_state = 28},
  [5565] = {.lex_state = 79, .external_lex_state = 35},
  [5566] = {.lex_state = 87, .external_lex_state = 54},
  [5567] = {.lex_state = 78, .external_lex_state = 42},
  [5568] = {.lex_state = 96, .external_lex_state = 28},
  [5569] = {.lex_state = 87, .external_lex_state = 40},
  [5570] = {.lex_state = 88, .external_lex_state = 49},
  [5571] = {.lex_state = 78, .external_lex_state = 52},
  [5572] = {.lex_state = 32},
  [5573] = {.lex_state = 79, .external_lex_state = 28},
  [5574] = {.lex_state = 78, .external_lex_state = 42},
  [5575] = {.lex_state = 78, .external_lex_state = 35},
  [5576] = {.lex_state = 87, .external_lex_state = 29},
  [5577] = {.lex_state = 87, .external_lex_state = 29},
  [5578] = {.lex_state = 87, .external_lex_state = 40},
  [5579] = {.lex_state = 78, .external_lex_state = 42},
  [5580] = {.lex_state = 87, .external_lex_state = 38},
  [5581] = {.lex_state = 86, .external_lex_state = 44},
  [5582] = {.lex_state = 87, .external_lex_state = 30},
  [5583] = {.lex_state = 79, .external_lex_state = 35},
  [5584] = {.lex_state = 32},
  [5585] = {.lex_state = 79, .external_lex_state = 36},
  [5586] = {.lex_state = 78, .external_lex_state = 42},
  [5587] = {.lex_state = 79, .external_lex_state = 35},
  [5588] = {.lex_state = 88, .external_lex_state = 41},
  [5589] = {.lex_state = 96, .external_lex_state = 26},
  [5590] = {.lex_state = 78, .external_lex_state = 32},
  [5591] = {.lex_state = 87, .external_lex_state = 29},
  [5592] = {.lex_state = 85, .external_lex_state = 37},
  [5593] = {.lex_state = 87, .external_lex_state = 34},
  [5594] = {.lex_state = 79, .external_lex_state = 35},
  [5595] = {.lex_state = 86, .external_lex_state = 44},
  [5596] = {.lex_state = 79, .external_lex_state = 36},
  [5597] = {.lex_state = 79, .external_lex_state = 27},
  [5598] = {.lex_state = 79, .external_lex_state = 35},
  [5599] = {.lex_state = 88, .external_lex_state = 32},
  [5600] = {.lex_state = 78, .external_lex_state = 41},
  [5601] = {.lex_state = 79, .external_lex_state = 37},
  [5602] = {.lex_state = 87, .external_lex_state = 34},
  [5603] = {.lex_state = 96, .external_lex_state = 27},
  [5604] = {.lex_state = 96, .external_lex_state = 26},
  [5605] = {.lex_state = 79, .external_lex_state = 37},
  [5606] = {.lex_state = 79, .external_lex_state = 37},
  [5607] = {.lex_state = 79, .external_lex_state = 37},
  [5608] = {.lex_state = 94, .external_lex_state = 49},
  [5609] = {.lex_state = 87, .external_lex_state = 34},
  [5610] = {.lex_state = 32},
  [5611] = {.lex_state = 87, .external_lex_state = 29},
  [5612] = {.lex_state = 88, .external_lex_state = 32},
  [5613] = {.lex_state = 11, .external_lex_state = 49},
  [5614] = {.lex_state = 75, .external_lex_state = 40},
  [5615] = {.lex_state = 32},
  [5616] = {.lex_state = 85, .external_lex_state = 33},
  [5617] = {.lex_state = 85, .external_lex_state = 37},
  [5618] = {.lex_state = 32},
  [5619] = {.lex_state = 86, .external_lex_state = 44},
  [5620] = {.lex_state = 87, .external_lex_state = 34},
  [5621] = {.lex_state = 88, .external_lex_state = 41},
  [5622] = {.lex_state = 80, .external_lex_state = 47},
  [5623] = {.lex_state = 75, .external_lex_state = 39},
  [5624] = {.lex_state = 79, .external_lex_state = 35},
  [5625] = {.lex_state = 87, .external_lex_state = 58},
  [5626] = {.lex_state = 32},
  [5627] = {.lex_state = 75, .external_lex_state = 39},
  [5628] = {.lex_state = 87, .external_lex_state = 29},
  [5629] = {.lex_state = 80, .external_lex_state = 37},
  [5630] = {.lex_state = 81, .external_lex_state = 50},
  [5631] = {.lex_state = 79, .external_lex_state = 36},
  [5632] = {.lex_state = 32},
  [5633] = {.lex_state = 88, .external_lex_state = 37},
  [5634] = {.lex_state = 78, .external_lex_state = 41},
  [5635] = {.lex_state = 87, .external_lex_state = 29},
  [5636] = {.lex_state = 85, .external_lex_state = 37},
  [5637] = {.lex_state = 79, .external_lex_state = 36},
  [5638] = {.lex_state = 87, .external_lex_state = 50},
  [5639] = {.lex_state = 32},
  [5640] = {.lex_state = 85, .external_lex_state = 37},
  [5641] = {.lex_state = 87, .external_lex_state = 29},
  [5642] = {.lex_state = 32},
  [5643] = {.lex_state = 78, .external_lex_state = 26},
  [5644] = {.lex_state = 79, .external_lex_state = 36},
  [5645] = {.lex_state = 79, .external_lex_state = 35},
  [5646] = {.lex_state = 87, .external_lex_state = 29},
  [5647] = {.lex_state = 87, .external_lex_state = 29},
  [5648] = {.lex_state = 78, .external_lex_state = 28},
  [5649] = {.lex_state = 86, .external_lex_state = 41},
  [5650] = {.lex_state = 87, .external_lex_state = 29},
  [5651] = {.lex_state = 80, .external_lex_state = 50},
  [5652] = {.lex_state = 85, .external_lex_state = 48},
  [5653] = {.lex_state = 87, .external_lex_state = 34},
  [5654] = {.lex_state = 87, .external_lex_state = 29},
  [5655] = {.lex_state = 75, .external_lex_state = 34},
  [5656] = {.lex_state = 78, .external_lex_state = 48},
  [5657] = {.lex_state = 87, .external_lex_state = 29},
  [5658] = {.lex_state = 80, .external_lex_state = 37},
  [5659] = {.lex_state = 32},
  [5660] = {.lex_state = 32},
  [5661] = {.lex_state = 87, .external_lex_state = 31},
  [5662] = {.lex_state = 87, .external_lex_state = 32},
  [5663] = {.lex_state = 86, .external_lex_state = 41},
  [5664] = {.lex_state = 87, .external_lex_state = 29},
  [5665] = {.lex_state = 87, .external_lex_state = 29},
  [5666] = {.lex_state = 85, .external_lex_state = 48},
  [5667] = {.lex_state = 87, .external_lex_state = 30},
  [5668] = {.lex_state = 87, .external_lex_state = 30},
  [5669] = {.lex_state = 87, .external_lex_state = 30},
  [5670] = {.lex_state = 82, .external_lex_state = 50},
  [5671] = {.lex_state = 87, .external_lex_state = 30},
  [5672] = {.lex_state = 88, .external_lex_state = 36},
  [5673] = {.lex_state = 75},
  [5674] = {.lex_state = 79, .external_lex_state = 37},
  [5675] = {.lex_state = 86, .external_lex_state = 32},
  [5676] = {.lex_state = 87, .external_lex_state = 30},
  [5677] = {.lex_state = 79, .external_lex_state = 50},
  [5678] = {.lex_state = 79, .external_lex_state = 37},
  [5679] = {.lex_state = 87, .external_lex_state = 29},
  [5680] = {.lex_state = 88, .external_lex_state = 35},
  [5681] = {.lex_state = 32},
  [5682] = {.lex_state = 32},
  [5683] = {.lex_state = 85, .external_lex_state = 42},
  [5684] = {.lex_state = 32},
  [5685] = {.lex_state = 32},
  [5686] = {.lex_state = 32},
  [5687] = {.lex_state = 75, .external_lex_state = 23},
  [5688] = {.lex_state = 99, .external_lex_state = 50},
  [5689] = {.lex_state = 79, .external_lex_state = 37},
  [5690] = {.lex_state = 80, .external_lex_state = 35},
  [5691] = {.lex_state = 32},
  [5692] = {.lex_state = 88, .external_lex_state = 49},
  [5693] = {.lex_state = 32},
  [5694] = {.lex_state = 87, .external_lex_state = 29},
  [5695] = {.lex_state = 80, .external_lex_state = 41},
  [5696] = {.lex_state = 78, .external_lex_state = 44},
  [5697] = {.lex_state = 87, .external_lex_state = 29},
  [5698] = {.lex_state = 86, .external_lex_state = 43},
  [5699] = {.lex_state = 86, .external_lex_state = 31},
  [5700] = {.lex_state = 80, .external_lex_state = 35},
  [5701] = {.lex_state = 87, .external_lex_state = 30},
  [5702] = {.lex_state = 32},
  [5703] = {.lex_state = 80, .external_lex_state = 35},
  [5704] = {.lex_state = 80, .external_lex_state = 35},
  [5705] = {.lex_state = 86, .external_lex_state = 31},
  [5706] = {.lex_state = 32},
  [5707] = {.lex_state = 75, .external_lex_state = 38},
  [5708] = {.lex_state = 88, .external_lex_state = 35},
  [5709] = {.lex_state = 32},
  [5710] = {.lex_state = 86, .external_lex_state = 31},
  [5711] = {.lex_state = 78, .external_lex_state = 27},
  [5712] = {.lex_state = 87, .external_lex_state = 49},
  [5713] = {.lex_state = 78, .external_lex_state = 44},
  [5714] = {.lex_state = 88, .external_lex_state = 27},
  [5715] = {.lex_state = 75, .external_lex_state = 51},
  [5716] = {.lex_state = 87, .external_lex_state = 58},
  [5717] = {.lex_state = 80, .external_lex_state = 44},
  [5718] = {.lex_state = 78, .external_lex_state = 44},
  [5719] = {.lex_state = 87, .external_lex_state = 57},
  [5720] = {.lex_state = 75, .external_lex_state = 38},
  [5721] = {.lex_state = 32},
  [5722] = {.lex_state = 78, .external_lex_state = 44},
  [5723] = {.lex_state = 75, .external_lex_state = 24},
  [5724] = {.lex_state = 75, .external_lex_state = 23},
  [5725] = {.lex_state = 75, .external_lex_state = 40},
  [5726] = {.lex_state = 32},
  [5727] = {.lex_state = 87, .external_lex_state = 34},
  [5728] = {.lex_state = 87, .external_lex_state = 28},
  [5729] = {.lex_state = 78, .external_lex_state = 44},
  [5730] = {.lex_state = 32},
  [5731] = {.lex_state = 79, .external_lex_state = 37},
  [5732] = {.lex_state = 32},
  [5733] = {.lex_state = 80, .external_lex_state = 35},
  [5734] = {.lex_state = 87, .external_lex_state = 30},
  [5735] = {.lex_state = 87, .external_lex_state = 34},
  [5736] = {.lex_state = 78, .external_lex_state = 44},
  [5737] = {.lex_state = 75, .external_lex_state = 38},
  [5738] = {.lex_state = 94, .external_lex_state = 50},
  [5739] = {.lex_state = 87, .external_lex_state = 30},
  [5740] = {.lex_state = 79, .external_lex_state = 50},
  [5741] = {.lex_state = 79, .external_lex_state = 49},
  [5742] = {.lex_state = 32},
  [5743] = {.lex_state = 80, .external_lex_state = 37},
  [5744] = {.lex_state = 80, .external_lex_state = 37},
  [5745] = {.lex_state = 80, .external_lex_state = 37},
  [5746] = {.lex_state = 87, .external_lex_state = 34},
  [5747] = {.lex_state = 79, .external_lex_state = 37},
  [5748] = {.lex_state = 80, .external_lex_state = 37},
  [5749] = {.lex_state = 87, .external_lex_state = 34},
  [5750] = {.lex_state = 32},
  [5751] = {.lex_state = 80, .external_lex_state = 37},
  [5752] = {.lex_state = 32},
  [5753] = {.lex_state = 88, .external_lex_state = 32},
  [5754] = {.lex_state = 80, .external_lex_state = 37},
  [5755] = {.lex_state = 82, .external_lex_state = 35},
  [5756] = {.lex_state = 80, .external_lex_state = 32},
  [5757] = {.lex_state = 32},
  [5758] = {.lex_state = 32},
  [5759] = {.lex_state = 78, .external_lex_state = 44},
  [5760] = {.lex_state = 32},
  [5761] = {.lex_state = 87, .external_lex_state = 58},
  [5762] = {.lex_state = 80, .external_lex_state = 36},
  [5763] = {.lex_state = 96, .external_lex_state = 47},
  [5764] = {.lex_state = 87, .external_lex_state = 34},
  [5765] = {.lex_state = 87, .external_lex_state = 34},
  [5766] = {.lex_state = 87, .external_lex_state = 33},
  [5767] = {.lex_state = 79, .external_lex_state = 37},
  [5768] = {.lex_state = 87, .external_lex_state = 34},
  [5769] = {.lex_state = 32},
  [5770] = {.lex_state = 87, .external_lex_state = 30},
  [5771] = {.lex_state = 87, .external_lex_state = 29},
  [5772] = {.lex_state = 85, .external_lex_state = 31},
  [5773] = {.lex_state = 87, .external_lex_state = 29},
  [5774] = {.lex_state = 79, .external_lex_state = 49},
  [5775] = {.lex_state = 85, .external_lex_state = 36},
  [5776] = {.lex_state = 80, .external_lex_state = 33},
  [5777] = {.lex_state = 86, .external_lex_state = 32},
  [5778] = {.lex_state = 80, .external_lex_state = 32},
  [5779] = {.lex_state = 75, .external_lex_state = 30},
  [5780] = {.lex_state = 80, .external_lex_state = 43},
  [5781] = {.lex_state = 86, .external_lex_state = 32},
  [5782] = {.lex_state = 80, .external_lex_state = 43},
  [5783] = {.lex_state = 75, .external_lex_state = 51},
  [5784] = {.lex_state = 95, .external_lex_state = 29},
  [5785] = {.lex_state = 99, .external_lex_state = 50},
  [5786] = {.lex_state = 86, .external_lex_state = 32},
  [5787] = {.lex_state = 80, .external_lex_state = 33},
  [5788] = {.lex_state = 86, .external_lex_state = 31},
  [5789] = {.lex_state = 87, .external_lex_state = 29},
  [5790] = {.lex_state = 87, .external_lex_state = 34},
  [5791] = {.lex_state = 86, .external_lex_state = 43},
  [5792] = {.lex_state = 96, .external_lex_state = 48},
  [5793] = {.lex_state = 87, .external_lex_state = 30},
  [5794] = {.lex_state = 85, .external_lex_state = 36},
  [5795] = {.lex_state = 82, .external_lex_state = 35},
  [5796] = {.lex_state = 85, .external_lex_state = 52},
  [5797] = {.lex_state = 87, .external_lex_state = 30},
  [5798] = {.lex_state = 32},
  [5799] = {.lex_state = 85, .external_lex_state = 32},
  [5800] = {.lex_state = 78, .external_lex_state = 48},
  [5801] = {.lex_state = 86, .external_lex_state = 43},
  [5802] = {.lex_state = 79, .external_lex_state = 37},
  [5803] = {.lex_state = 82, .external_lex_state = 35},
  [5804] = {.lex_state = 96, .external_lex_state = 48},
  [5805] = {.lex_state = 79, .external_lex_state = 37},
  [5806] = {.lex_state = 85, .external_lex_state = 36},
  [5807] = {.lex_state = 85, .external_lex_state = 36},
  [5808] = {.lex_state = 88, .external_lex_state = 44},
  [5809] = {.lex_state = 79, .external_lex_state = 37},
  [5810] = {.lex_state = 82, .external_lex_state = 35},
  [5811] = {.lex_state = 88, .external_lex_state = 44},
  [5812] = {.lex_state = 78, .external_lex_state = 48},
  [5813] = {.lex_state = 87, .external_lex_state = 29},
  [5814] = {.lex_state = 32},
  [5815] = {.lex_state = 86, .external_lex_state = 41},
  [5816] = {.lex_state = 85, .external_lex_state = 52},
  [5817] = {.lex_state = 87, .external_lex_state = 45},
  [5818] = {.lex_state = 78, .external_lex_state = 48},
  [5819] = {.lex_state = 75, .external_lex_state = 39},
  [5820] = {.lex_state = 86, .external_lex_state = 33},
  [5821] = {.lex_state = 87, .external_lex_state = 56},
  [5822] = {.lex_state = 87, .external_lex_state = 30},
  [5823] = {.lex_state = 87, .external_lex_state = 30},
  [5824] = {.lex_state = 75, .external_lex_state = 53},
  [5825] = {.lex_state = 75, .external_lex_state = 53},
  [5826] = {.lex_state = 87, .external_lex_state = 30},
  [5827] = {.lex_state = 86, .external_lex_state = 33},
  [5828] = {.lex_state = 87, .external_lex_state = 29},
  [5829] = {.lex_state = 96, .external_lex_state = 48},
  [5830] = {.lex_state = 80, .external_lex_state = 31},
  [5831] = {.lex_state = 79, .external_lex_state = 36},
  [5832] = {.lex_state = 80, .external_lex_state = 35},
  [5833] = {.lex_state = 79, .external_lex_state = 28},
  [5834] = {.lex_state = 94, .external_lex_state = 31},
  [5835] = {.lex_state = 94, .external_lex_state = 27},
  [5836] = {.lex_state = 79, .external_lex_state = 36},
  [5837] = {.lex_state = 32},
  [5838] = {.lex_state = 83, .external_lex_state = 35},
  [5839] = {.lex_state = 80, .external_lex_state = 49},
  [5840] = {.lex_state = 86, .external_lex_state = 33},
  [5841] = {.lex_state = 80, .external_lex_state = 37},
  [5842] = {.lex_state = 32},
  [5843] = {.lex_state = 80, .external_lex_state = 31},
  [5844] = {.lex_state = 87, .external_lex_state = 29},
  [5845] = {.lex_state = 80, .external_lex_state = 36},
  [5846] = {.lex_state = 32},
  [5847] = {.lex_state = 87, .external_lex_state = 53},
  [5848] = {.lex_state = 80, .external_lex_state = 35},
  [5849] = {.lex_state = 75},
  [5850] = {.lex_state = 32},
  [5851] = {.lex_state = 99, .external_lex_state = 35},
  [5852] = {.lex_state = 80, .external_lex_state = 35},
  [5853] = {.lex_state = 80, .external_lex_state = 49},
  [5854] = {.lex_state = 87, .external_lex_state = 33},
  [5855] = {.lex_state = 75, .external_lex_state = 55},
  [5856] = {.lex_state = 85, .external_lex_state = 42},
  [5857] = {.lex_state = 32},
  [5858] = {.lex_state = 85, .external_lex_state = 43},
  [5859] = {.lex_state = 80, .external_lex_state = 42},
  [5860] = {.lex_state = 99, .external_lex_state = 35},
  [5861] = {.lex_state = 87, .external_lex_state = 29},
  [5862] = {.lex_state = 80, .external_lex_state = 41},
  [5863] = {.lex_state = 87, .external_lex_state = 29},
  [5864] = {.lex_state = 78, .external_lex_state = 44},
  [5865] = {.lex_state = 80, .external_lex_state = 35},
  [5866] = {.lex_state = 87, .external_lex_state = 57},
  [5867] = {.lex_state = 80, .external_lex_state = 41},
  [5868] = {.lex_state = 78, .external_lex_state = 52},
  [5869] = {.lex_state = 96, .external_lex_state = 26},
  [5870] = {.lex_state = 79, .external_lex_state = 35},
  [5871] = {.lex_state = 80, .external_lex_state = 35},
  [5872] = {.lex_state = 78, .external_lex_state = 52},
  [5873] = {.lex_state = 94, .external_lex_state = 32},
  [5874] = {.lex_state = 32},
  [5875] = {.lex_state = 79, .external_lex_state = 37},
  [5876] = {.lex_state = 87, .external_lex_state = 29},
  [5877] = {.lex_state = 96, .external_lex_state = 26},
  [5878] = {.lex_state = 85, .external_lex_state = 44},
  [5879] = {.lex_state = 87, .external_lex_state = 29},
  [5880] = {.lex_state = 79, .external_lex_state = 35},
  [5881] = {.lex_state = 80, .external_lex_state = 35},
  [5882] = {.lex_state = 78, .external_lex_state = 47},
  [5883] = {.lex_state = 99, .external_lex_state = 50},
  [5884] = {.lex_state = 87, .external_lex_state = 29},
  [5885] = {.lex_state = 32},
  [5886] = {.lex_state = 79, .external_lex_state = 37},
  [5887] = {.lex_state = 87, .external_lex_state = 29},
  [5888] = {.lex_state = 81, .external_lex_state = 35},
  [5889] = {.lex_state = 94, .external_lex_state = 28},
  [5890] = {.lex_state = 80, .external_lex_state = 28},
  [5891] = {.lex_state = 78, .external_lex_state = 47},
  [5892] = {.lex_state = 87, .external_lex_state = 29},
  [5893] = {.lex_state = 79, .external_lex_state = 35},
  [5894] = {.lex_state = 80, .external_lex_state = 35},
  [5895] = {.lex_state = 80, .external_lex_state = 42},
  [5896] = {.lex_state = 80, .external_lex_state = 41},
  [5897] = {.lex_state = 88, .external_lex_state = 33},
  [5898] = {.lex_state = 87, .external_lex_state = 29},
  [5899] = {.lex_state = 88, .external_lex_state = 31},
  [5900] = {.lex_state = 86, .external_lex_state = 44},
  [5901] = {.lex_state = 80, .external_lex_state = 42},
  [5902] = {.lex_state = 80, .external_lex_state = 36},
  [5903] = {.lex_state = 32},
  [5904] = {.lex_state = 80, .external_lex_state = 48},
  [5905] = {.lex_state = 80, .external_lex_state = 36},
  [5906] = {.lex_state = 80, .external_lex_state = 42},
  [5907] = {.lex_state = 80, .external_lex_state = 36},
  [5908] = {.lex_state = 87, .external_lex_state = 29},
  [5909] = {.lex_state = 87, .external_lex_state = 54},
  [5910] = {.lex_state = 78, .external_lex_state = 33},
  [5911] = {.lex_state = 94, .external_lex_state = 27},
  [5912] = {.lex_state = 32},
  [5913] = {.lex_state = 87, .external_lex_state = 34},
  [5914] = {.lex_state = 77},
  [5915] = {.lex_state = 87, .external_lex_state = 34},
  [5916] = {.lex_state = 87, .external_lex_state = 56},
  [5917] = {.lex_state = 94, .external_lex_state = 28},
  [5918] = {.lex_state = 78, .external_lex_state = 43},
  [5919] = {.lex_state = 85, .external_lex_state = 35},
  [5920] = {.lex_state = 80, .external_lex_state = 35},
  [5921] = {.lex_state = 32},
  [5922] = {.lex_state = 78, .external_lex_state = 43},
  [5923] = {.lex_state = 80, .external_lex_state = 36},
  [5924] = {.lex_state = 94, .external_lex_state = 28},
  [5925] = {.lex_state = 78, .external_lex_state = 41},
  [5926] = {.lex_state = 80, .external_lex_state = 36},
  [5927] = {.lex_state = 80, .external_lex_state = 36},
  [5928] = {.lex_state = 32},
  [5929] = {.lex_state = 75, .external_lex_state = 55},
  [5930] = {.lex_state = 78, .external_lex_state = 41},
  [5931] = {.lex_state = 87, .external_lex_state = 57},
  [5932] = {.lex_state = 78, .external_lex_state = 41},
  [5933] = {.lex_state = 75, .external_lex_state = 51},
  [5934] = {.lex_state = 78, .external_lex_state = 41},
  [5935] = {.lex_state = 78, .external_lex_state = 44},
  [5936] = {.lex_state = 79, .external_lex_state = 35},
  [5937] = {.lex_state = 32},
  [5938] = {.lex_state = 78, .external_lex_state = 41},
  [5939] = {.lex_state = 75, .external_lex_state = 55},
  [5940] = {.lex_state = 86, .external_lex_state = 31},
  [5941] = {.lex_state = 88, .external_lex_state = 33},
  [5942] = {.lex_state = 78, .external_lex_state = 42},
  [5943] = {.lex_state = 78, .external_lex_state = 41},
  [5944] = {.lex_state = 80, .external_lex_state = 26},
  [5945] = {.lex_state = 10, .external_lex_state = 49},
  [5946] = {.lex_state = 80, .external_lex_state = 36},
  [5947] = {.lex_state = 78, .external_lex_state = 37},
  [5948] = {.lex_state = 78, .external_lex_state = 37},
  [5949] = {.lex_state = 87, .external_lex_state = 29},
  [5950] = {.lex_state = 78, .external_lex_state = 43},
  [5951] = {.lex_state = 78, .external_lex_state = 41},
  [5952] = {.lex_state = 87, .external_lex_state = 27},
  [5953] = {.lex_state = 78, .external_lex_state = 44},
  [5954] = {.lex_state = 78, .external_lex_state = 37},
  [5955] = {.lex_state = 80, .external_lex_state = 49},
  [5956] = {.lex_state = 78, .external_lex_state = 43},
  [5957] = {.lex_state = 78, .external_lex_state = 43},
  [5958] = {.lex_state = 94, .external_lex_state = 28},
  [5959] = {.lex_state = 80, .external_lex_state = 36},
  [5960] = {.lex_state = 80, .external_lex_state = 36},
  [5961] = {.lex_state = 80, .external_lex_state = 36},
  [5962] = {.lex_state = 87, .external_lex_state = 34},
  [5963] = {.lex_state = 94, .external_lex_state = 50},
  [5964] = {.lex_state = 78, .external_lex_state = 41},
  [5965] = {.lex_state = 80, .external_lex_state = 44},
  [5966] = {.lex_state = 87, .external_lex_state = 29},
  [5967] = {.lex_state = 78, .external_lex_state = 26},
  [5968] = {.lex_state = 78, .external_lex_state = 35},
  [5969] = {.lex_state = 79, .external_lex_state = 27},
  [5970] = {.lex_state = 88, .external_lex_state = 33},
  [5971] = {.lex_state = 78, .external_lex_state = 36},
  [5972] = {.lex_state = 86, .external_lex_state = 42},
  [5973] = {.lex_state = 87, .external_lex_state = 29},
  [5974] = {.lex_state = 96, .external_lex_state = 52},
  [5975] = {.lex_state = 82, .external_lex_state = 35},
  [5976] = {.lex_state = 78, .external_lex_state = 43},
  [5977] = {.lex_state = 78, .external_lex_state = 26},
  [5978] = {.lex_state = 87, .external_lex_state = 29},
  [5979] = {.lex_state = 82, .external_lex_state = 50},
  [5980] = {.lex_state = 82, .external_lex_state = 50},
  [5981] = {.lex_state = 80, .external_lex_state = 37},
  [5982] = {.lex_state = 80, .external_lex_state = 43},
  [5983] = {.lex_state = 88, .external_lex_state = 33},
  [5984] = {.lex_state = 78, .external_lex_state = 43},
  [5985] = {.lex_state = 96, .external_lex_state = 26},
  [5986] = {.lex_state = 86, .external_lex_state = 32},
  [5987] = {.lex_state = 78, .external_lex_state = 47},
  [5988] = {.lex_state = 78, .external_lex_state = 43},
  [5989] = {.lex_state = 75, .external_lex_state = 34},
  [5990] = {.lex_state = 78, .external_lex_state = 43},
  [5991] = {.lex_state = 75, .external_lex_state = 40},
  [5992] = {.lex_state = 99, .external_lex_state = 35},
  [5993] = {.lex_state = 87, .external_lex_state = 34},
  [5994] = {.lex_state = 78, .external_lex_state = 44},
  [5995] = {.lex_state = 78, .external_lex_state = 36},
  [5996] = {.lex_state = 87, .external_lex_state = 34},
  [5997] = {.lex_state = 87, .external_lex_state = 23},
  [5998] = {.lex_state = 78, .external_lex_state = 44},
  [5999] = {.lex_state = 32},
  [6000] = {.lex_state = 96, .external_lex_state = 52},
  [6001] = {.lex_state = 78, .external_lex_state = 36},
  [6002] = {.lex_state = 32},
  [6003] = {.lex_state = 32},
  [6004] = {.lex_state = 85, .external_lex_state = 41},
  [6005] = {.lex_state = 87, .external_lex_state = 34},
  [6006] = {.lex_state = 78, .external_lex_state = 44},
  [6007] = {.lex_state = 78, .external_lex_state = 35},
  [6008] = {.lex_state = 32},
  [6009] = {.lex_state = 80, .external_lex_state = 36},
  [6010] = {.lex_state = 94, .external_lex_state = 27},
  [6011] = {.lex_state = 79, .external_lex_state = 37},
  [6012] = {.lex_state = 32},
  [6013] = {.lex_state = 88, .external_lex_state = 36},
  [6014] = {.lex_state = 87, .external_lex_state = 27},
  [6015] = {.lex_state = 86, .external_lex_state = 42},
  [6016] = {.lex_state = 78, .external_lex_state = 43},
  [6017] = {.lex_state = 94, .external_lex_state = 27},
  [6018] = {.lex_state = 32},
  [6019] = {.lex_state = 80, .external_lex_state = 37},
  [6020] = {.lex_state = 80, .external_lex_state = 37},
  [6021] = {.lex_state = 78, .external_lex_state = 47},
  [6022] = {.lex_state = 80, .external_lex_state = 37},
  [6023] = {.lex_state = 85, .external_lex_state = 35},
  [6024] = {.lex_state = 96, .external_lex_state = 47},
  [6025] = {.lex_state = 87, .external_lex_state = 30},
  [6026] = {.lex_state = 32},
  [6027] = {.lex_state = 75, .external_lex_state = 39},
  [6028] = {.lex_state = 75, .external_lex_state = 24},
  [6029] = {.lex_state = 78, .external_lex_state = 42},
  [6030] = {.lex_state = 78, .external_lex_state = 43},
  [6031] = {.lex_state = 87, .external_lex_state = 45},
  [6032] = {.lex_state = 78, .external_lex_state = 41},
  [6033] = {.lex_state = 78, .external_lex_state = 44},
  [6034] = {.lex_state = 78, .external_lex_state = 41},
  [6035] = {.lex_state = 79, .external_lex_state = 36},
  [6036] = {.lex_state = 75, .external_lex_state = 57},
  [6037] = {.lex_state = 78, .external_lex_state = 43},
  [6038] = {.lex_state = 78, .external_lex_state = 42},
  [6039] = {.lex_state = 87, .external_lex_state = 29},
  [6040] = {.lex_state = 85, .external_lex_state = 35},
  [6041] = {.lex_state = 75, .external_lex_state = 40},
  [6042] = {.lex_state = 85, .external_lex_state = 47},
  [6043] = {.lex_state = 82, .external_lex_state = 50},
  [6044] = {.lex_state = 94, .external_lex_state = 49},
  [6045] = {.lex_state = 78, .external_lex_state = 49},
  [6046] = {.lex_state = 32},
  [6047] = {.lex_state = 87, .external_lex_state = 27},
  [6048] = {.lex_state = 86, .external_lex_state = 41},
  [6049] = {.lex_state = 32},
  [6050] = {.lex_state = 32},
  [6051] = {.lex_state = 78, .external_lex_state = 42},
  [6052] = {.lex_state = 85, .external_lex_state = 35},
  [6053] = {.lex_state = 94, .external_lex_state = 27},
  [6054] = {.lex_state = 78, .external_lex_state = 42},
  [6055] = {.lex_state = 87, .external_lex_state = 29},
  [6056] = {.lex_state = 78, .external_lex_state = 41},
  [6057] = {.lex_state = 80, .external_lex_state = 49},
  [6058] = {.lex_state = 87, .external_lex_state = 30},
  [6059] = {.lex_state = 96, .external_lex_state = 47},
  [6060] = {.lex_state = 80, .external_lex_state = 44},
  [6061] = {.lex_state = 32},
  [6062] = {.lex_state = 78, .external_lex_state = 52},
  [6063] = {.lex_state = 78, .external_lex_state = 42},
  [6064] = {.lex_state = 32},
  [6065] = {.lex_state = 78, .external_lex_state = 43},
  [6066] = {.lex_state = 85, .external_lex_state = 47},
  [6067] = {.lex_state = 75, .external_lex_state = 56},
  [6068] = {.lex_state = 78, .external_lex_state = 42},
  [6069] = {.lex_state = 80, .external_lex_state = 44},
  [6070] = {.lex_state = 79, .external_lex_state = 35},
  [6071] = {.lex_state = 80, .external_lex_state = 43},
  [6072] = {.lex_state = 75, .external_lex_state = 54},
  [6073] = {.lex_state = 87, .external_lex_state = 29},
  [6074] = {.lex_state = 87, .external_lex_state = 46},
  [6075] = {.lex_state = 87, .external_lex_state = 29},
  [6076] = {.lex_state = 77},
  [6077] = {.lex_state = 80, .external_lex_state = 27},
  [6078] = {.lex_state = 78, .external_lex_state = 42},
  [6079] = {.lex_state = 79, .external_lex_state = 36},
  [6080] = {.lex_state = 79, .external_lex_state = 33},
  [6081] = {.lex_state = 85, .external_lex_state = 43},
  [6082] = {.lex_state = 79, .external_lex_state = 36},
  [6083] = {.lex_state = 87, .external_lex_state = 56},
  [6084] = {.lex_state = 78, .external_lex_state = 41},
  [6085] = {.lex_state = 79, .external_lex_state = 36},
  [6086] = {.lex_state = 78, .external_lex_state = 42},
  [6087] = {.lex_state = 85, .external_lex_state = 41},
  [6088] = {.lex_state = 79, .external_lex_state = 36},
  [6089] = {.lex_state = 94, .external_lex_state = 49},
  [6090] = {.lex_state = 88, .external_lex_state = 42},
  [6091] = {.lex_state = 32},
  [6092] = {.lex_state = 79, .external_lex_state = 37},
  [6093] = {.lex_state = 85, .external_lex_state = 44},
  [6094] = {.lex_state = 88, .external_lex_state = 42},
  [6095] = {.lex_state = 32},
  [6096] = {.lex_state = 88, .external_lex_state = 32},
  [6097] = {.lex_state = 88, .external_lex_state = 43},
  [6098] = {.lex_state = 86, .external_lex_state = 33},
  [6099] = {.lex_state = 79, .external_lex_state = 36},
  [6100] = {.lex_state = 78, .external_lex_state = 50},
  [6101] = {.lex_state = 88, .external_lex_state = 43},
  [6102] = {.lex_state = 83, .external_lex_state = 35},
  [6103] = {.lex_state = 32},
  [6104] = {.lex_state = 80, .external_lex_state = 41},
  [6105] = {.lex_state = 94, .external_lex_state = 32},
  [6106] = {.lex_state = 87, .external_lex_state = 30},
  [6107] = {.lex_state = 80, .external_lex_state = 43},
  [6108] = {.lex_state = 87, .external_lex_state = 30},
  [6109] = {.lex_state = 87, .external_lex_state = 38},
  [6110] = {.lex_state = 80, .external_lex_state = 44},
  [6111] = {.lex_state = 82, .external_lex_state = 35},
  [6112] = {.lex_state = 87, .external_lex_state = 34},
  [6113] = {.lex_state = 87, .external_lex_state = 30},
  [6114] = {.lex_state = 80, .external_lex_state = 43},
  [6115] = {.lex_state = 79, .external_lex_state = 44},
  [6116] = {.lex_state = 82, .external_lex_state = 35},
  [6117] = {.lex_state = 83, .external_lex_state = 50},
  [6118] = {.lex_state = 87, .external_lex_state = 40},
  [6119] = {.lex_state = 85, .external_lex_state = 43},
  [6120] = {.lex_state = 87, .external_lex_state = 30},
  [6121] = {.lex_state = 82, .external_lex_state = 35},
  [6122] = {.lex_state = 96, .external_lex_state = 50},
  [6123] = {.lex_state = 87, .external_lex_state = 30},
  [6124] = {.lex_state = 88, .external_lex_state = 31},
  [6125] = {.lex_state = 87, .external_lex_state = 40},
  [6126] = {.lex_state = 87, .external_lex_state = 23},
  [6127] = {.lex_state = 80, .external_lex_state = 41},
  [6128] = {.lex_state = 75, .external_lex_state = 46},
  [6129] = {.lex_state = 80, .external_lex_state = 43},
  [6130] = {.lex_state = 86, .external_lex_state = 52},
  [6131] = {.lex_state = 39, .external_lex_state = 49},
  [6132] = {.lex_state = 85, .external_lex_state = 43},
  [6133] = {.lex_state = 80, .external_lex_state = 44},
  [6134] = {.lex_state = 82, .external_lex_state = 35},
  [6135] = {.lex_state = 87, .external_lex_state = 34},
  [6136] = {.lex_state = 79, .external_lex_state = 42},
  [6137] = {.lex_state = 87, .external_lex_state = 30},
  [6138] = {.lex_state = 80, .external_lex_state = 42},
  [6139] = {.lex_state = 87, .external_lex_state = 30},
  [6140] = {.lex_state = 82, .external_lex_state = 35},
  [6141] = {.lex_state = 87, .external_lex_state = 30},
  [6142] = {.lex_state = 87, .external_lex_state = 38},
  [6143] = {.lex_state = 80, .external_lex_state = 44},
  [6144] = {.lex_state = 80, .external_lex_state = 43},
  [6145] = {.lex_state = 80, .external_lex_state = 43},
  [6146] = {.lex_state = 80, .external_lex_state = 44},
  [6147] = {.lex_state = 79, .external_lex_state = 44},
  [6148] = {.lex_state = 78, .external_lex_state = 48},
  [6149] = {.lex_state = 75, .external_lex_state = 40},
  [6150] = {.lex_state = 87, .external_lex_state = 24},
  [6151] = {.lex_state = 87, .external_lex_state = 38},
  [6152] = {.lex_state = 87, .external_lex_state = 30},
  [6153] = {.lex_state = 87, .external_lex_state = 30},
  [6154] = {.lex_state = 86, .external_lex_state = 36},
  [6155] = {.lex_state = 79, .external_lex_state = 41},
  [6156] = {.lex_state = 79, .external_lex_state = 42},
  [6157] = {.lex_state = 82, .external_lex_state = 35},
  [6158] = {.lex_state = 85, .external_lex_state = 43},
  [6159] = {.lex_state = 87, .external_lex_state = 30},
  [6160] = {.lex_state = 80, .external_lex_state = 44},
  [6161] = {.lex_state = 85, .external_lex_state = 43},
  [6162] = {.lex_state = 79, .external_lex_state = 42},
  [6163] = {.lex_state = 80, .external_lex_state = 43},
  [6164] = {.lex_state = 78, .external_lex_state = 48},
  [6165] = {.lex_state = 80, .external_lex_state = 44},
  [6166] = {.lex_state = 78, .external_lex_state = 48},
  [6167] = {.lex_state = 80, .external_lex_state = 44},
  [6168] = {.lex_state = 79, .external_lex_state = 41},
  [6169] = {.lex_state = 78, .external_lex_state = 48},
  [6170] = {.lex_state = 80, .external_lex_state = 43},
  [6171] = {.lex_state = 87, .external_lex_state = 30},
  [6172] = {.lex_state = 79, .external_lex_state = 42},
  [6173] = {.lex_state = 79, .external_lex_state = 44},
  [6174] = {.lex_state = 80, .external_lex_state = 43},
  [6175] = {.lex_state = 87, .external_lex_state = 40},
  [6176] = {.lex_state = 80, .external_lex_state = 44},
  [6177] = {.lex_state = 78, .external_lex_state = 48},
  [6178] = {.lex_state = 79, .external_lex_state = 44},
  [6179] = {.lex_state = 80, .external_lex_state = 41},
  [6180] = {.lex_state = 75, .external_lex_state = 56},
  [6181] = {.lex_state = 10, .external_lex_state = 49},
  [6182] = {.lex_state = 88, .external_lex_state = 49},
  [6183] = {.lex_state = 87, .external_lex_state = 30},
  [6184] = {.lex_state = 88, .external_lex_state = 36},
  [6185] = {.lex_state = 87, .external_lex_state = 40},
  [6186] = {.lex_state = 87, .external_lex_state = 23},
  [6187] = {.lex_state = 95, .external_lex_state = 34},
  [6188] = {.lex_state = 80, .external_lex_state = 41},
  [6189] = {.lex_state = 80, .external_lex_state = 49},
  [6190] = {.lex_state = 85, .external_lex_state = 37},
  [6191] = {.lex_state = 78, .external_lex_state = 26},
  [6192] = {.lex_state = 79, .external_lex_state = 43},
  [6193] = {.lex_state = 79, .external_lex_state = 43},
  [6194] = {.lex_state = 82, .external_lex_state = 35},
  [6195] = {.lex_state = 79, .external_lex_state = 43},
  [6196] = {.lex_state = 88, .external_lex_state = 36},
  [6197] = {.lex_state = 87, .external_lex_state = 24},
  [6198] = {.lex_state = 87, .external_lex_state = 30},
  [6199] = {.lex_state = 94, .external_lex_state = 37},
  [6200] = {.lex_state = 75, .external_lex_state = 56},
  [6201] = {.lex_state = 78, .external_lex_state = 42},
  [6202] = {.lex_state = 87, .external_lex_state = 40},
  [6203] = {.lex_state = 80, .external_lex_state = 41},
  [6204] = {.lex_state = 87, .external_lex_state = 40},
  [6205] = {.lex_state = 85, .external_lex_state = 26},
  [6206] = {.lex_state = 87, .external_lex_state = 30},
  [6207] = {.lex_state = 79, .external_lex_state = 42},
  [6208] = {.lex_state = 78, .external_lex_state = 26},
  [6209] = {.lex_state = 85, .external_lex_state = 48},
  [6210] = {.lex_state = 85, .external_lex_state = 44},
  [6211] = {.lex_state = 80, .external_lex_state = 43},
  [6212] = {.lex_state = 88, .external_lex_state = 36},
  [6213] = {.lex_state = 80, .external_lex_state = 41},
  [6214] = {.lex_state = 85, .external_lex_state = 44},
  [6215] = {.lex_state = 87, .external_lex_state = 23},
  [6216] = {.lex_state = 79, .external_lex_state = 44},
  [6217] = {.lex_state = 86, .external_lex_state = 35},
  [6218] = {.lex_state = 85, .external_lex_state = 44},
  [6219] = {.lex_state = 79, .external_lex_state = 42},
  [6220] = {.lex_state = 88, .external_lex_state = 36},
  [6221] = {.lex_state = 87, .external_lex_state = 30},
  [6222] = {.lex_state = 86, .external_lex_state = 37},
  [6223] = {.lex_state = 87, .external_lex_state = 40},
  [6224] = {.lex_state = 79, .external_lex_state = 43},
  [6225] = {.lex_state = 80, .external_lex_state = 41},
  [6226] = {.lex_state = 88, .external_lex_state = 44},
  [6227] = {.lex_state = 83, .external_lex_state = 50},
  [6228] = {.lex_state = 87, .external_lex_state = 30},
  [6229] = {.lex_state = 80, .external_lex_state = 37},
  [6230] = {.lex_state = 86, .external_lex_state = 36},
  [6231] = {.lex_state = 79, .external_lex_state = 32},
  [6232] = {.lex_state = 83, .external_lex_state = 50},
  [6233] = {.lex_state = 79, .external_lex_state = 44},
  [6234] = {.lex_state = 80, .external_lex_state = 37},
  [6235] = {.lex_state = 87, .external_lex_state = 30},
  [6236] = {.lex_state = 75, .external_lex_state = 46},
  [6237] = {.lex_state = 96, .external_lex_state = 50},
  [6238] = {.lex_state = 82, .external_lex_state = 50},
  [6239] = {.lex_state = 96, .external_lex_state = 50},
  [6240] = {.lex_state = 87, .external_lex_state = 30},
  [6241] = {.lex_state = 87, .external_lex_state = 34},
  [6242] = {.lex_state = 79, .external_lex_state = 44},
  [6243] = {.lex_state = 87, .external_lex_state = 30},
  [6244] = {.lex_state = 80, .external_lex_state = 41},
  [6245] = {.lex_state = 79, .external_lex_state = 41},
  [6246] = {.lex_state = 75, .external_lex_state = 24},
  [6247] = {.lex_state = 79, .external_lex_state = 44},
  [6248] = {.lex_state = 79, .external_lex_state = 41},
  [6249] = {.lex_state = 87, .external_lex_state = 30},
  [6250] = {.lex_state = 79, .external_lex_state = 41},
  [6251] = {.lex_state = 88, .external_lex_state = 35},
  [6252] = {.lex_state = 87, .external_lex_state = 38},
  [6253] = {.lex_state = 79, .external_lex_state = 42},
  [6254] = {.lex_state = 88, .external_lex_state = 35},
  [6255] = {.lex_state = 78, .external_lex_state = 27},
  [6256] = {.lex_state = 75, .external_lex_state = 23},
  [6257] = {.lex_state = 80, .external_lex_state = 43},
  [6258] = {.lex_state = 82, .external_lex_state = 35},
  [6259] = {.lex_state = 87, .external_lex_state = 34},
  [6260] = {.lex_state = 79, .external_lex_state = 42},
  [6261] = {.lex_state = 88, .external_lex_state = 35},
  [6262] = {.lex_state = 87, .external_lex_state = 30},
  [6263] = {.lex_state = 78, .external_lex_state = 44},
  [6264] = {.lex_state = 39, .external_lex_state = 49},
  [6265] = {.lex_state = 88, .external_lex_state = 32},
  [6266] = {.lex_state = 87, .external_lex_state = 40},
  [6267] = {.lex_state = 79, .external_lex_state = 44},
  [6268] = {.lex_state = 83, .external_lex_state = 35},
  [6269] = {.lex_state = 87, .external_lex_state = 51},
  [6270] = {.lex_state = 82, .external_lex_state = 35},
  [6271] = {.lex_state = 88, .external_lex_state = 35},
  [6272] = {.lex_state = 78, .external_lex_state = 52},
  [6273] = {.lex_state = 87, .external_lex_state = 34},
  [6274] = {.lex_state = 87, .external_lex_state = 57},
  [6275] = {.lex_state = 100, .external_lex_state = 50},
  [6276] = {.lex_state = 78, .external_lex_state = 52},
  [6277] = {.lex_state = 86, .external_lex_state = 52},
  [6278] = {.lex_state = 80, .external_lex_state = 43},
  [6279] = {.lex_state = 80, .external_lex_state = 43},
  [6280] = {.lex_state = 88, .external_lex_state = 43},
  [6281] = {.lex_state = 87, .external_lex_state = 34},
  [6282] = {.lex_state = 79, .external_lex_state = 32},
  [6283] = {.lex_state = 100, .external_lex_state = 50},
  [6284] = {.lex_state = 86, .external_lex_state = 47},
  [6285] = {.lex_state = 78, .external_lex_state = 52},
  [6286] = {.lex_state = 96, .external_lex_state = 31},
  [6287] = {.lex_state = 80, .external_lex_state = 41},
  [6288] = {.lex_state = 39, .external_lex_state = 49},
  [6289] = {.lex_state = 10, .external_lex_state = 49},
  [6290] = {.lex_state = 79, .external_lex_state = 41},
  [6291] = {.lex_state = 78, .external_lex_state = 27},
  [6292] = {.lex_state = 80, .external_lex_state = 43},
  [6293] = {.lex_state = 87, .external_lex_state = 30},
  [6294] = {.lex_state = 81, .external_lex_state = 35},
  [6295] = {.lex_state = 100, .external_lex_state = 35},
  [6296] = {.lex_state = 88, .external_lex_state = 43},
  [6297] = {.lex_state = 78, .external_lex_state = 52},
  [6298] = {.lex_state = 85, .external_lex_state = 42},
  [6299] = {.lex_state = 87, .external_lex_state = 34},
  [6300] = {.lex_state = 82, .external_lex_state = 35},
  [6301] = {.lex_state = 96, .external_lex_state = 33},
  [6302] = {.lex_state = 80, .external_lex_state = 36},
  [6303] = {.lex_state = 87, .external_lex_state = 30},
  [6304] = {.lex_state = 82, .external_lex_state = 35},
  [6305] = {.lex_state = 87, .external_lex_state = 40},
  [6306] = {.lex_state = 80, .external_lex_state = 36},
  [6307] = {.lex_state = 94, .external_lex_state = 32},
  [6308] = {.lex_state = 87, .external_lex_state = 30},
  [6309] = {.lex_state = 87, .external_lex_state = 30},
  [6310] = {.lex_state = 87, .external_lex_state = 38},
  [6311] = {.lex_state = 87, .external_lex_state = 34},
  [6312] = {.lex_state = 78, .external_lex_state = 52},
  [6313] = {.lex_state = 86, .external_lex_state = 47},
  [6314] = {.lex_state = 82, .external_lex_state = 50},
  [6315] = {.lex_state = 82, .external_lex_state = 50},
  [6316] = {.lex_state = 94, .external_lex_state = 32},
  [6317] = {.lex_state = 88, .external_lex_state = 48},
  [6318] = {.lex_state = 82, .external_lex_state = 35},
  [6319] = {.lex_state = 80, .external_lex_state = 48},
  [6320] = {.lex_state = 86, .external_lex_state = 47},
  [6321] = {.lex_state = 82, .external_lex_state = 50},
  [6322] = {.lex_state = 86, .external_lex_state = 26},
  [6323] = {.lex_state = 78, .external_lex_state = 43},
  [6324] = {.lex_state = 78, .external_lex_state = 43},
  [6325] = {.lex_state = 87, .external_lex_state = 55},
  [6326] = {.lex_state = 82, .external_lex_state = 50},
  [6327] = {.lex_state = 79, .external_lex_state = 42},
  [6328] = {.lex_state = 78, .external_lex_state = 50},
  [6329] = {.lex_state = 10, .external_lex_state = 49},
  [6330] = {.lex_state = 78, .external_lex_state = 27},
  [6331] = {.lex_state = 82, .external_lex_state = 35},
  [6332] = {.lex_state = 87, .external_lex_state = 40},
  [6333] = {.lex_state = 87, .external_lex_state = 40},
  [6334] = {.lex_state = 80, .external_lex_state = 41},
  [6335] = {.lex_state = 83, .external_lex_state = 35},
  [6336] = {.lex_state = 88, .external_lex_state = 48},
  [6337] = {.lex_state = 82, .external_lex_state = 35},
  [6338] = {.lex_state = 94, .external_lex_state = 31},
  [6339] = {.lex_state = 82, .external_lex_state = 50},
  [6340] = {.lex_state = 87, .external_lex_state = 34},
  [6341] = {.lex_state = 87, .external_lex_state = 30},
  [6342] = {.lex_state = 87, .external_lex_state = 30},
  [6343] = {.lex_state = 78, .external_lex_state = 28},
  [6344] = {.lex_state = 80, .external_lex_state = 26},
  [6345] = {.lex_state = 87, .external_lex_state = 55},
  [6346] = {.lex_state = 77},
  [6347] = {.lex_state = 80, .external_lex_state = 26},
  [6348] = {.lex_state = 86, .external_lex_state = 35},
  [6349] = {.lex_state = 88, .external_lex_state = 37},
  [6350] = {.lex_state = 85, .external_lex_state = 48},
  [6351] = {.lex_state = 87, .external_lex_state = 34},
  [6352] = {.lex_state = 82, .external_lex_state = 50},
  [6353] = {.lex_state = 79, .external_lex_state = 44},
  [6354] = {.lex_state = 88, .external_lex_state = 37},
  [6355] = {.lex_state = 96, .external_lex_state = 28},
  [6356] = {.lex_state = 87, .external_lex_state = 33},
  [6357] = {.lex_state = 87, .external_lex_state = 34},
  [6358] = {.lex_state = 87, .external_lex_state = 40},
  [6359] = {.lex_state = 87, .external_lex_state = 38},
  [6360] = {.lex_state = 82, .external_lex_state = 50},
  [6361] = {.lex_state = 87, .external_lex_state = 30},
  [6362] = {.lex_state = 87, .external_lex_state = 38},
  [6363] = {.lex_state = 88, .external_lex_state = 37},
  [6364] = {.lex_state = 78, .external_lex_state = 26},
  [6365] = {.lex_state = 87, .external_lex_state = 38},
  [6366] = {.lex_state = 94, .external_lex_state = 31},
  [6367] = {.lex_state = 82, .external_lex_state = 50},
  [6368] = {.lex_state = 85, .external_lex_state = 49},
  [6369] = {.lex_state = 82, .external_lex_state = 50},
  [6370] = {.lex_state = 87, .external_lex_state = 54},
  [6371] = {.lex_state = 86, .external_lex_state = 26},
  [6372] = {.lex_state = 80, .external_lex_state = 49},
  [6373] = {.lex_state = 80, .external_lex_state = 47},
  [6374] = {.lex_state = 82, .external_lex_state = 50},
  [6375] = {.lex_state = 87, .external_lex_state = 38},
  [6376] = {.lex_state = 80, .external_lex_state = 47},
  [6377] = {.lex_state = 87},
  [6378] = {.lex_state = 88, .external_lex_state = 37},
  [6379] = {.lex_state = 79, .external_lex_state = 42},
  [6380] = {.lex_state = 88, .external_lex_state = 33},
  [6381] = {.lex_state = 80, .external_lex_state = 52},
  [6382] = {.lex_state = 78, .external_lex_state = 52},
  [6383] = {.lex_state = 82, .external_lex_state = 50},
  [6384] = {.lex_state = 78, .external_lex_state = 48},
  [6385] = {.lex_state = 80, .external_lex_state = 52},
  [6386] = {.lex_state = 80, .external_lex_state = 49},
  [6387] = {.lex_state = 87, .external_lex_state = 30},
  [6388] = {.lex_state = 79, .external_lex_state = 43},
  [6389] = {.lex_state = 78, .external_lex_state = 52},
  [6390] = {.lex_state = 86, .external_lex_state = 26},
  [6391] = {.lex_state = 100, .external_lex_state = 50},
  [6392] = {.lex_state = 88, .external_lex_state = 42},
  [6393] = {.lex_state = 78, .external_lex_state = 28},
  [6394] = {.lex_state = 11, .external_lex_state = 49},
  [6395] = {.lex_state = 96, .external_lex_state = 28},
  [6396] = {.lex_state = 79, .external_lex_state = 43},
  [6397] = {.lex_state = 79, .external_lex_state = 42},
  [6398] = {.lex_state = 88, .external_lex_state = 44},
  [6399] = {.lex_state = 78, .external_lex_state = 28},
  [6400] = {.lex_state = 80, .external_lex_state = 49},
  [6401] = {.lex_state = 78, .external_lex_state = 26},
  [6402] = {.lex_state = 100, .external_lex_state = 35},
  [6403] = {.lex_state = 79, .external_lex_state = 43},
  [6404] = {.lex_state = 79, .external_lex_state = 43},
  [6405] = {.lex_state = 87},
  [6406] = {.lex_state = 87, .external_lex_state = 40},
  [6407] = {.lex_state = 75, .external_lex_state = 45},
  [6408] = {.lex_state = 87, .external_lex_state = 34},
  [6409] = {.lex_state = 78, .external_lex_state = 26},
  [6410] = {.lex_state = 79, .external_lex_state = 42},
  [6411] = {.lex_state = 79, .external_lex_state = 33},
  [6412] = {.lex_state = 79, .external_lex_state = 41},
  [6413] = {.lex_state = 87, .external_lex_state = 23},
  [6414] = {.lex_state = 80, .external_lex_state = 48},
  [6415] = {.lex_state = 94, .external_lex_state = 32},
  [6416] = {.lex_state = 79, .external_lex_state = 42},
  [6417] = {.lex_state = 75, .external_lex_state = 58},
  [6418] = {.lex_state = 80, .external_lex_state = 48},
  [6419] = {.lex_state = 87, .external_lex_state = 30},
  [6420] = {.lex_state = 87, .external_lex_state = 30},
  [6421] = {.lex_state = 87, .external_lex_state = 34},
  [6422] = {.lex_state = 79, .external_lex_state = 44},
  [6423] = {.lex_state = 78, .external_lex_state = 26},
  [6424] = {.lex_state = 80, .external_lex_state = 49},
  [6425] = {.lex_state = 85, .external_lex_state = 47},
  [6426] = {.lex_state = 79, .external_lex_state = 42},
  [6427] = {.lex_state = 78, .external_lex_state = 26},
  [6428] = {.lex_state = 80, .external_lex_state = 47},
  [6429] = {.lex_state = 85, .external_lex_state = 49},
  [6430] = {.lex_state = 87, .external_lex_state = 36},
  [6431] = {.lex_state = 80, .external_lex_state = 49},
  [6432] = {.lex_state = 80, .external_lex_state = 49},
  [6433] = {.lex_state = 80, .external_lex_state = 28},
  [6434] = {.lex_state = 78, .external_lex_state = 26},
  [6435] = {.lex_state = 80, .external_lex_state = 49},
  [6436] = {.lex_state = 78, .external_lex_state = 26},
  [6437] = {.lex_state = 87, .external_lex_state = 34},
  [6438] = {.lex_state = 78, .external_lex_state = 26},
  [6439] = {.lex_state = 79, .external_lex_state = 42},
  [6440] = {.lex_state = 4},
  [6441] = {.lex_state = 82, .external_lex_state = 35},
  [6442] = {.lex_state = 85, .external_lex_state = 26},
  [6443] = {.lex_state = 82, .external_lex_state = 35},
  [6444] = {.lex_state = 87, .external_lex_state = 34},
  [6445] = {.lex_state = 75, .external_lex_state = 46},
  [6446] = {.lex_state = 87, .external_lex_state = 34},
  [6447] = {.lex_state = 87, .external_lex_state = 34},
  [6448] = {.lex_state = 80, .external_lex_state = 49},
  [6449] = {.lex_state = 96, .external_lex_state = 28},
  [6450] = {.lex_state = 78, .external_lex_state = 52},
  [6451] = {.lex_state = 87, .external_lex_state = 30},
  [6452] = {.lex_state = 87, .external_lex_state = 23},
  [6453] = {.lex_state = 87, .external_lex_state = 30},
  [6454] = {.lex_state = 97, .external_lex_state = 29},
  [6455] = {.lex_state = 87, .external_lex_state = 34},
  [6456] = {.lex_state = 87, .external_lex_state = 40},
  [6457] = {.lex_state = 10, .external_lex_state = 49},
  [6458] = {.lex_state = 81, .external_lex_state = 35},
  [6459] = {.lex_state = 75, .external_lex_state = 23},
  [6460] = {.lex_state = 86, .external_lex_state = 52},
  [6461] = {.lex_state = 79, .external_lex_state = 42},
  [6462] = {.lex_state = 87, .external_lex_state = 38},
  [6463] = {.lex_state = 87, .external_lex_state = 34},
  [6464] = {.lex_state = 32},
  [6465] = {.lex_state = 87, .external_lex_state = 34},
  [6466] = {.lex_state = 85, .external_lex_state = 50},
  [6467] = {.lex_state = 87, .external_lex_state = 37},
  [6468] = {.lex_state = 80, .external_lex_state = 47},
  [6469] = {.lex_state = 86, .external_lex_state = 52},
  [6470] = {.lex_state = 83, .external_lex_state = 35},
  [6471] = {.lex_state = 86, .external_lex_state = 48},
  [6472] = {.lex_state = 78, .external_lex_state = 52},
  [6473] = {.lex_state = 87, .external_lex_state = 34},
  [6474] = {.lex_state = 87, .external_lex_state = 33},
  [6475] = {.lex_state = 87, .external_lex_state = 30},
  [6476] = {.lex_state = 80, .external_lex_state = 41},
  [6477] = {.lex_state = 87, .external_lex_state = 34},
  [6478] = {.lex_state = 79, .external_lex_state = 44},
  [6479] = {.lex_state = 87, .external_lex_state = 34},
  [6480] = {.lex_state = 92, .external_lex_state = 35},
  [6481] = {.lex_state = 79, .external_lex_state = 44},
  [6482] = {.lex_state = 78, .external_lex_state = 41},
  [6483] = {.lex_state = 85, .external_lex_state = 50},
  [6484] = {.lex_state = 94, .external_lex_state = 35},
  [6485] = {.lex_state = 87, .external_lex_state = 30},
  [6486] = {.lex_state = 79, .external_lex_state = 43},
  [6487] = {.lex_state = 99, .external_lex_state = 35},
  [6488] = {.lex_state = 86, .external_lex_state = 47},
  [6489] = {.lex_state = 79, .external_lex_state = 44},
  [6490] = {.lex_state = 87, .external_lex_state = 34},
  [6491] = {.lex_state = 80, .external_lex_state = 41},
  [6492] = {.lex_state = 79, .external_lex_state = 43},
  [6493] = {.lex_state = 94, .external_lex_state = 36},
  [6494] = {.lex_state = 86, .external_lex_state = 48},
  [6495] = {.lex_state = 88, .external_lex_state = 42},
  [6496] = {.lex_state = 82, .external_lex_state = 50},
  [6497] = {.lex_state = 92, .external_lex_state = 35},
  [6498] = {.lex_state = 80, .external_lex_state = 41},
  [6499] = {.lex_state = 79, .external_lex_state = 44},
  [6500] = {.lex_state = 87, .external_lex_state = 29},
  [6501] = {.lex_state = 87, .external_lex_state = 34},
  [6502] = {.lex_state = 87, .external_lex_state = 34},
  [6503] = {.lex_state = 87, .external_lex_state = 40},
  [6504] = {.lex_state = 87, .external_lex_state = 38},
  [6505] = {.lex_state = 78, .external_lex_state = 41},
  [6506] = {.lex_state = 32},
  [6507] = {.lex_state = 32},
  [6508] = {.lex_state = 32},
  [6509] = {.lex_state = 32},
  [6510] = {.lex_state = 85, .external_lex_state = 28},
  [6511] = {.lex_state = 79, .external_lex_state = 43},
  [6512] = {.lex_state = 79, .external_lex_state = 44},
  [6513] = {.lex_state = 80, .external_lex_state = 49},
  [6514] = {.lex_state = 87, .external_lex_state = 34},
  [6515] = {.lex_state = 85, .external_lex_state = 52},
  [6516] = {.lex_state = 87, .external_lex_state = 35},
  [6517] = {.lex_state = 78, .external_lex_state = 28},
  [6518] = {.lex_state = 79, .external_lex_state = 43},
  [6519] = {.lex_state = 83, .external_lex_state = 50},
  [6520] = {.lex_state = 99, .external_lex_state = 35},
  [6521] = {.lex_state = 87, .external_lex_state = 39},
  [6522] = {.lex_state = 78, .external_lex_state = 48},
  [6523] = {.lex_state = 75, .external_lex_state = 38},
  [6524] = {.lex_state = 87, .external_lex_state = 29},
  [6525] = {.lex_state = 87, .external_lex_state = 51},
  [6526] = {.lex_state = 87, .external_lex_state = 38},
  [6527] = {.lex_state = 87, .external_lex_state = 40},
  [6528] = {.lex_state = 87, .external_lex_state = 30},
  [6529] = {.lex_state = 85, .external_lex_state = 28},
  [6530] = {.lex_state = 87, .external_lex_state = 30},
  [6531] = {.lex_state = 79, .external_lex_state = 41},
  [6532] = {.lex_state = 87, .external_lex_state = 30},
  [6533] = {.lex_state = 87, .external_lex_state = 34},
  [6534] = {.lex_state = 87, .external_lex_state = 30},
  [6535] = {.lex_state = 80, .external_lex_state = 42},
  [6536] = {.lex_state = 87, .external_lex_state = 38},
  [6537] = {.lex_state = 82, .external_lex_state = 35},
  [6538] = {.lex_state = 87, .external_lex_state = 30},
  [6539] = {.lex_state = 80, .external_lex_state = 26},
  [6540] = {.lex_state = 87, .external_lex_state = 30},
  [6541] = {.lex_state = 86, .external_lex_state = 26},
  [6542] = {.lex_state = 85, .external_lex_state = 47},
  [6543] = {.lex_state = 100, .external_lex_state = 35},
  [6544] = {.lex_state = 80, .external_lex_state = 50},
  [6545] = {.lex_state = 87, .external_lex_state = 23},
  [6546] = {.lex_state = 87, .external_lex_state = 34},
  [6547] = {.lex_state = 32},
  [6548] = {.lex_state = 78, .external_lex_state = 26},
  [6549] = {.lex_state = 79, .external_lex_state = 41},
  [6550] = {.lex_state = 79, .external_lex_state = 43},
  [6551] = {.lex_state = 78, .external_lex_state = 26},
  [6552] = {.lex_state = 87, .external_lex_state = 23},
  [6553] = {.lex_state = 87, .external_lex_state = 34},
  [6554] = {.lex_state = 78, .external_lex_state = 26},
  [6555] = {.lex_state = 79, .external_lex_state = 43},
  [6556] = {.lex_state = 95, .external_lex_state = 30},
  [6557] = {.lex_state = 87, .external_lex_state = 30},
  [6558] = {.lex_state = 86, .external_lex_state = 48},
  [6559] = {.lex_state = 80, .external_lex_state = 27},
  [6560] = {.lex_state = 96, .external_lex_state = 27},
  [6561] = {.lex_state = 78, .external_lex_state = 32},
  [6562] = {.lex_state = 79, .external_lex_state = 41},
  [6563] = {.lex_state = 87, .external_lex_state = 23},
  [6564] = {.lex_state = 85, .external_lex_state = 41},
  [6565] = {.lex_state = 80, .external_lex_state = 49},
  [6566] = {.lex_state = 79, .external_lex_state = 44},
  [6567] = {.lex_state = 79, .external_lex_state = 43},
  [6568] = {.lex_state = 79, .external_lex_state = 41},
  [6569] = {.lex_state = 87, .external_lex_state = 38},
  [6570] = {.lex_state = 87},
  [6571] = {.lex_state = 86, .external_lex_state = 35},
  [6572] = {.lex_state = 87, .external_lex_state = 30},
  [6573] = {.lex_state = 85, .external_lex_state = 42},
  [6574] = {.lex_state = 83, .external_lex_state = 35},
  [6575] = {.lex_state = 75, .external_lex_state = 58},
  [6576] = {.lex_state = 78, .external_lex_state = 49},
  [6577] = {.lex_state = 87, .external_lex_state = 53},
  [6578] = {.lex_state = 79, .external_lex_state = 41},
  [6579] = {.lex_state = 75, .external_lex_state = 57},
  [6580] = {.lex_state = 83, .external_lex_state = 35},
  [6581] = {.lex_state = 87, .external_lex_state = 34},
  [6582] = {.lex_state = 80, .external_lex_state = 52},
  [6583] = {.lex_state = 87, .external_lex_state = 30},
  [6584] = {.lex_state = 78, .external_lex_state = 47},
  [6585] = {.lex_state = 87, .external_lex_state = 30},
  [6586] = {.lex_state = 78, .external_lex_state = 47},
  [6587] = {.lex_state = 78, .external_lex_state = 47},
  [6588] = {.lex_state = 80, .external_lex_state = 32},
  [6589] = {.lex_state = 78, .external_lex_state = 50},
  [6590] = {.lex_state = 87, .external_lex_state = 33},
  [6591] = {.lex_state = 79, .external_lex_state = 41},
  [6592] = {.lex_state = 87, .external_lex_state = 38},
  [6593] = {.lex_state = 85, .external_lex_state = 42},
  [6594] = {.lex_state = 96, .external_lex_state = 32},
  [6595] = {.lex_state = 78, .external_lex_state = 52},
  [6596] = {.lex_state = 87, .external_lex_state = 30},
  [6597] = {.lex_state = 78, .external_lex_state = 47},
  [6598] = {.lex_state = 78, .external_lex_state = 41},
  [6599] = {.lex_state = 87, .external_lex_state = 31},
  [6600] = {.lex_state = 85, .external_lex_state = 42},
  [6601] = {.lex_state = 78, .external_lex_state = 35},
  [6602] = {.lex_state = 78, .external_lex_state = 47},
  [6603] = {.lex_state = 78, .external_lex_state = 47},
  [6604] = {.lex_state = 86, .external_lex_state = 37},
  [6605] = {.lex_state = 80, .external_lex_state = 42},
  [6606] = {.lex_state = 87, .external_lex_state = 34},
  [6607] = {.lex_state = 86, .external_lex_state = 35},
  [6608] = {.lex_state = 87, .external_lex_state = 34},
  [6609] = {.lex_state = 88, .external_lex_state = 41},
  [6610] = {.lex_state = 78, .external_lex_state = 47},
  [6611] = {.lex_state = 78, .external_lex_state = 52},
  [6612] = {.lex_state = 14, .external_lex_state = 49},
  [6613] = {.lex_state = 79, .external_lex_state = 41},
  [6614] = {.lex_state = 87, .external_lex_state = 34},
  [6615] = {.lex_state = 78, .external_lex_state = 47},
  [6616] = {.lex_state = 78, .external_lex_state = 52},
  [6617] = {.lex_state = 78, .external_lex_state = 52},
  [6618] = {.lex_state = 78, .external_lex_state = 47},
  [6619] = {.lex_state = 78, .external_lex_state = 50},
  [6620] = {.lex_state = 81, .external_lex_state = 50},
  [6621] = {.lex_state = 87, .external_lex_state = 35},
  [6622] = {.lex_state = 87, .external_lex_state = 38},
  [6623] = {.lex_state = 85, .external_lex_state = 27},
  [6624] = {.lex_state = 94, .external_lex_state = 33},
  [6625] = {.lex_state = 87, .external_lex_state = 34},
  [6626] = {.lex_state = 75, .external_lex_state = 58},
  [6627] = {.lex_state = 87, .external_lex_state = 34},
  [6628] = {.lex_state = 87, .external_lex_state = 40},
  [6629] = {.lex_state = 85, .external_lex_state = 52},
  [6630] = {.lex_state = 87, .external_lex_state = 34},
  [6631] = {.lex_state = 87, .external_lex_state = 31},
  [6632] = {.lex_state = 78, .external_lex_state = 49},
  [6633] = {.lex_state = 79, .external_lex_state = 43},
  [6634] = {.lex_state = 80, .external_lex_state = 44},
  [6635] = {.lex_state = 87, .external_lex_state = 34},
  [6636] = {.lex_state = 88, .external_lex_state = 52},
  [6637] = {.lex_state = 87, .external_lex_state = 38},
  [6638] = {.lex_state = 87, .external_lex_state = 34},
  [6639] = {.lex_state = 86, .external_lex_state = 37},
  [6640] = {.lex_state = 87, .external_lex_state = 40},
  [6641] = {.lex_state = 85, .external_lex_state = 27},
  [6642] = {.lex_state = 78, .external_lex_state = 49},
  [6643] = {.lex_state = 80, .external_lex_state = 48},
  [6644] = {.lex_state = 75, .external_lex_state = 45},
  [6645] = {.lex_state = 78, .external_lex_state = 47},
  [6646] = {.lex_state = 75, .external_lex_state = 23},
  [6647] = {.lex_state = 75, .external_lex_state = 24},
  [6648] = {.lex_state = 80, .external_lex_state = 42},
  [6649] = {.lex_state = 80, .external_lex_state = 49},
  [6650] = {.lex_state = 86, .external_lex_state = 35},
  [6651] = {.lex_state = 87, .external_lex_state = 34},
  [6652] = {.lex_state = 96, .external_lex_state = 27},
  [6653] = {.lex_state = 78, .external_lex_state = 50},
  [6654] = {.lex_state = 86, .external_lex_state = 48},
  [6655] = {.lex_state = 87, .external_lex_state = 34},
  [6656] = {.lex_state = 94, .external_lex_state = 33},
  [6657] = {.lex_state = 85, .external_lex_state = 44},
  [6658] = {.lex_state = 87, .external_lex_state = 40},
  [6659] = {.lex_state = 87, .external_lex_state = 34},
  [6660] = {.lex_state = 99, .external_lex_state = 35},
  [6661] = {.lex_state = 88, .external_lex_state = 26},
  [6662] = {.lex_state = 80, .external_lex_state = 52},
  [6663] = {.lex_state = 80, .external_lex_state = 42},
  [6664] = {.lex_state = 87, .external_lex_state = 34},
  [6665] = {.lex_state = 87, .external_lex_state = 34},
  [6666] = {.lex_state = 86, .external_lex_state = 37},
  [6667] = {.lex_state = 79, .external_lex_state = 33},
  [6668] = {.lex_state = 75, .external_lex_state = 45},
  [6669] = {.lex_state = 75, .external_lex_state = 29},
  [6670] = {.lex_state = 87, .external_lex_state = 34},
  [6671] = {.lex_state = 87, .external_lex_state = 34},
  [6672] = {.lex_state = 86, .external_lex_state = 37},
  [6673] = {.lex_state = 85, .external_lex_state = 36},
  [6674] = {.lex_state = 87, .external_lex_state = 34},
  [6675] = {.lex_state = 87, .external_lex_state = 39},
  [6676] = {.lex_state = 87, .external_lex_state = 30},
  [6677] = {.lex_state = 78, .external_lex_state = 48},
  [6678] = {.lex_state = 79, .external_lex_state = 41},
  [6679] = {.lex_state = 87, .external_lex_state = 38},
  [6680] = {.lex_state = 75, .external_lex_state = 24},
  [6681] = {.lex_state = 87, .external_lex_state = 34},
  [6682] = {.lex_state = 75, .external_lex_state = 23},
  [6683] = {.lex_state = 80, .external_lex_state = 42},
  [6684] = {.lex_state = 96, .external_lex_state = 27},
  [6685] = {.lex_state = 75, .external_lex_state = 38},
  [6686] = {.lex_state = 80, .external_lex_state = 42},
  [6687] = {.lex_state = 75, .external_lex_state = 24},
  [6688] = {.lex_state = 12, .external_lex_state = 49},
  [6689] = {.lex_state = 87, .external_lex_state = 34},
  [6690] = {.lex_state = 94, .external_lex_state = 33},
  [6691] = {.lex_state = 78, .external_lex_state = 44},
  [6692] = {.lex_state = 78, .external_lex_state = 48},
  [6693] = {.lex_state = 80, .external_lex_state = 42},
  [6694] = {.lex_state = 78, .external_lex_state = 47},
  [6695] = {.lex_state = 80, .external_lex_state = 49},
  [6696] = {.lex_state = 80, .external_lex_state = 26},
  [6697] = {.lex_state = 88, .external_lex_state = 49},
  [6698] = {.lex_state = 78, .external_lex_state = 42},
  [6699] = {.lex_state = 78, .external_lex_state = 47},
  [6700] = {.lex_state = 87, .external_lex_state = 32},
  [6701] = {.lex_state = 87, .external_lex_state = 38},
  [6702] = {.lex_state = 88, .external_lex_state = 41},
  [6703] = {.lex_state = 87, .external_lex_state = 39},
  [6704] = {.lex_state = 75, .external_lex_state = 29},
  [6705] = {.lex_state = 78, .external_lex_state = 47},
  [6706] = {.lex_state = 87, .external_lex_state = 57},
  [6707] = {.lex_state = 79, .external_lex_state = 43},
  [6708] = {.lex_state = 88, .external_lex_state = 52},
  [6709] = {.lex_state = 78, .external_lex_state = 26},
  [6710] = {.lex_state = 87, .external_lex_state = 56},
  [6711] = {.lex_state = 75, .external_lex_state = 23},
  [6712] = {.lex_state = 92, .external_lex_state = 50},
  [6713] = {.lex_state = 96, .external_lex_state = 27},
  [6714] = {.lex_state = 87, .external_lex_state = 32},
  [6715] = {.lex_state = 79, .external_lex_state = 42},
  [6716] = {.lex_state = 79, .external_lex_state = 41},
  [6717] = {.lex_state = 75, .external_lex_state = 57},
  [6718] = {.lex_state = 87, .external_lex_state = 30},
  [6719] = {.lex_state = 88, .external_lex_state = 47},
  [6720] = {.lex_state = 78, .external_lex_state = 42},
  [6721] = {.lex_state = 87, .external_lex_state = 39},
  [6722] = {.lex_state = 87, .external_lex_state = 23},
  [6723] = {.lex_state = 80, .external_lex_state = 42},
  [6724] = {.lex_state = 87, .external_lex_state = 38},
  [6725] = {.lex_state = 92, .external_lex_state = 50},
  [6726] = {.lex_state = 75, .external_lex_state = 45},
  [6727] = {.lex_state = 78, .external_lex_state = 47},
  [6728] = {.lex_state = 96, .external_lex_state = 28},
  [6729] = {.lex_state = 87, .external_lex_state = 40},
  [6730] = {.lex_state = 79, .external_lex_state = 41},
  [6731] = {.lex_state = 78, .external_lex_state = 44},
  [6732] = {.lex_state = 96, .external_lex_state = 28},
  [6733] = {.lex_state = 17},
  [6734] = {.lex_state = 78, .external_lex_state = 49},
  [6735] = {.lex_state = 32},
  [6736] = {.lex_state = 88, .external_lex_state = 47},
  [6737] = {.lex_state = 80, .external_lex_state = 35},
  [6738] = {.lex_state = 79, .external_lex_state = 35},
  [6739] = {.lex_state = 80, .external_lex_state = 42},
  [6740] = {.lex_state = 87, .external_lex_state = 32},
  [6741] = {.lex_state = 78, .external_lex_state = 48},
  [6742] = {.lex_state = 78, .external_lex_state = 48},
  [6743] = {.lex_state = 86, .external_lex_state = 36},
  [6744] = {.lex_state = 80, .external_lex_state = 35},
  [6745] = {.lex_state = 80, .external_lex_state = 42},
  [6746] = {.lex_state = 78, .external_lex_state = 27},
  [6747] = {.lex_state = 78, .external_lex_state = 48},
  [6748] = {.lex_state = 85, .external_lex_state = 41},
  [6749] = {.lex_state = 75, .external_lex_state = 45},
  [6750] = {.lex_state = 85, .external_lex_state = 35},
  [6751] = {.lex_state = 75, .external_lex_state = 40},
  [6752] = {.lex_state = 80, .external_lex_state = 44},
  [6753] = {.lex_state = 87, .external_lex_state = 30},
  [6754] = {.lex_state = 86, .external_lex_state = 36},
  [6755] = {.lex_state = 80, .external_lex_state = 44},
  [6756] = {.lex_state = 85, .external_lex_state = 41},
  [6757] = {.lex_state = 78, .external_lex_state = 48},
  [6758] = {.lex_state = 94, .external_lex_state = 33},
  [6759] = {.lex_state = 80, .external_lex_state = 44},
  [6760] = {.lex_state = 78, .external_lex_state = 43},
  [6761] = {.lex_state = 85, .external_lex_state = 41},
  [6762] = {.lex_state = 87, .external_lex_state = 34},
  [6763] = {.lex_state = 80, .external_lex_state = 44},
  [6764] = {.lex_state = 78, .external_lex_state = 33},
  [6765] = {.lex_state = 87, .external_lex_state = 56},
  [6766] = {.lex_state = 78, .external_lex_state = 48},
  [6767] = {.lex_state = 87, .external_lex_state = 30},
  [6768] = {.lex_state = 86, .external_lex_state = 36},
  [6769] = {.lex_state = 94, .external_lex_state = 33},
  [6770] = {.lex_state = 88, .external_lex_state = 26},
  [6771] = {.lex_state = 94, .external_lex_state = 32},
  [6772] = {.lex_state = 87, .external_lex_state = 34},
  [6773] = {.lex_state = 87, .external_lex_state = 23},
  [6774] = {.lex_state = 80, .external_lex_state = 42},
  [6775] = {.lex_state = 80, .external_lex_state = 42},
  [6776] = {.lex_state = 96, .external_lex_state = 27},
  [6777] = {.lex_state = 80, .external_lex_state = 33},
  [6778] = {.lex_state = 78, .external_lex_state = 52},
  [6779] = {.lex_state = 79, .external_lex_state = 47},
  [6780] = {.lex_state = 78, .external_lex_state = 28},
  [6781] = {.lex_state = 75, .external_lex_state = 34},
  [6782] = {.lex_state = 87, .external_lex_state = 45},
  [6783] = {.lex_state = 80, .external_lex_state = 35},
  [6784] = {.lex_state = 80, .external_lex_state = 44},
  [6785] = {.lex_state = 86, .external_lex_state = 42},
  [6786] = {.lex_state = 88, .external_lex_state = 35},
  [6787] = {.lex_state = 80, .external_lex_state = 44},
  [6788] = {.lex_state = 88, .external_lex_state = 50},
  [6789] = {.lex_state = 88, .external_lex_state = 50},
  [6790] = {.lex_state = 86, .external_lex_state = 28},
  [6791] = {.lex_state = 87, .external_lex_state = 23},
  [6792] = {.lex_state = 88, .external_lex_state = 44},
  [6793] = {.lex_state = 88, .external_lex_state = 44},
  [6794] = {.lex_state = 85, .external_lex_state = 49},
  [6795] = {.lex_state = 79, .external_lex_state = 48},
  [6796] = {.lex_state = 88, .external_lex_state = 44},
  [6797] = {.lex_state = 87, .external_lex_state = 35},
  [6798] = {.lex_state = 32},
  [6799] = {.lex_state = 79, .external_lex_state = 26},
  [6800] = {.lex_state = 87, .external_lex_state = 40},
  [6801] = {.lex_state = 75, .external_lex_state = 51},
  [6802] = {.lex_state = 87, .external_lex_state = 40},
  [6803] = {.lex_state = 75, .external_lex_state = 35},
  [6804] = {.lex_state = 88, .external_lex_state = 26},
  [6805] = {.lex_state = 78, .external_lex_state = 52},
  [6806] = {.lex_state = 75, .external_lex_state = 23},
  [6807] = {.lex_state = 93, .external_lex_state = 50},
  [6808] = {.lex_state = 82, .external_lex_state = 35},
  [6809] = {.lex_state = 81, .external_lex_state = 35},
  [6810] = {.lex_state = 93, .external_lex_state = 50},
  [6811] = {.lex_state = 95, .external_lex_state = 29},
  [6812] = {.lex_state = 87, .external_lex_state = 37},
  [6813] = {.lex_state = 81, .external_lex_state = 50},
  [6814] = {.lex_state = 87, .external_lex_state = 24},
  [6815] = {.lex_state = 78, .external_lex_state = 49},
  [6816] = {.lex_state = 95, .external_lex_state = 29},
  [6817] = {.lex_state = 87, .external_lex_state = 39},
  [6818] = {.lex_state = 78, .external_lex_state = 52},
  [6819] = {.lex_state = 78, .external_lex_state = 49},
  [6820] = {.lex_state = 82, .external_lex_state = 35},
  [6821] = {.lex_state = 75, .external_lex_state = 55},
  [6822] = {.lex_state = 97, .external_lex_state = 30},
  [6823] = {.lex_state = 95, .external_lex_state = 29},
  [6824] = {.lex_state = 78, .external_lex_state = 32},
  [6825] = {.lex_state = 75, .external_lex_state = 23},
  [6826] = {.lex_state = 75, .external_lex_state = 30},
  [6827] = {.lex_state = 87, .external_lex_state = 38},
  [6828] = {.lex_state = 79, .external_lex_state = 47},
  [6829] = {.lex_state = 79, .external_lex_state = 26},
  [6830] = {.lex_state = 10, .external_lex_state = 49},
  [6831] = {.lex_state = 78, .external_lex_state = 47},
  [6832] = {.lex_state = 87, .external_lex_state = 37},
  [6833] = {.lex_state = 75, .external_lex_state = 35},
  [6834] = {.lex_state = 34},
  [6835] = {.lex_state = 87, .external_lex_state = 40},
  [6836] = {.lex_state = 10, .external_lex_state = 49},
  [6837] = {.lex_state = 95, .external_lex_state = 29},
  [6838] = {.lex_state = 83, .external_lex_state = 35},
  [6839] = {.lex_state = 10, .external_lex_state = 49},
  [6840] = {.lex_state = 87, .external_lex_state = 39},
  [6841] = {.lex_state = 79, .external_lex_state = 47},
  [6842] = {.lex_state = 34},
  [6843] = {.lex_state = 95, .external_lex_state = 29},
  [6844] = {.lex_state = 34},
  [6845] = {.lex_state = 87, .external_lex_state = 38},
  [6846] = {.lex_state = 87, .external_lex_state = 38},
  [6847] = {.lex_state = 87, .external_lex_state = 40},
  [6848] = {.lex_state = 79, .external_lex_state = 26},
  [6849] = {.lex_state = 78, .external_lex_state = 49},
  [6850] = {.lex_state = 78, .external_lex_state = 47},
  [6851] = {.lex_state = 79, .external_lex_state = 47},
  [6852] = {.lex_state = 87, .external_lex_state = 40},
  [6853] = {.lex_state = 86, .external_lex_state = 28},
  [6854] = {.lex_state = 83, .external_lex_state = 35},
  [6855] = {.lex_state = 87, .external_lex_state = 38},
  [6856] = {.lex_state = 85, .external_lex_state = 26},
  [6857] = {.lex_state = 80, .external_lex_state = 50},
  [6858] = {.lex_state = 87, .external_lex_state = 38},
  [6859] = {.lex_state = 87, .external_lex_state = 23},
  [6860] = {.lex_state = 87, .external_lex_state = 23},
  [6861] = {.lex_state = 79, .external_lex_state = 26},
  [6862] = {.lex_state = 87, .external_lex_state = 40},
  [6863] = {.lex_state = 87, .external_lex_state = 38},
  [6864] = {.lex_state = 34},
  [6865] = {.lex_state = 82, .external_lex_state = 35},
  [6866] = {.lex_state = 87, .external_lex_state = 38},
  [6867] = {.lex_state = 87, .external_lex_state = 38},
  [6868] = {.lex_state = 87, .external_lex_state = 38},
  [6869] = {.lex_state = 87, .external_lex_state = 40},
  [6870] = {.lex_state = 79, .external_lex_state = 26},
  [6871] = {.lex_state = 87, .external_lex_state = 39},
  [6872] = {.lex_state = 78, .external_lex_state = 33},
  [6873] = {.lex_state = 88, .external_lex_state = 26},
  [6874] = {.lex_state = 87, .external_lex_state = 38},
  [6875] = {.lex_state = 79, .external_lex_state = 47},
  [6876] = {.lex_state = 85, .external_lex_state = 32},
  [6877] = {.lex_state = 82, .external_lex_state = 35},
  [6878] = {.lex_state = 87, .external_lex_state = 38},
  [6879] = {.lex_state = 90, .external_lex_state = 29},
  [6880] = {.lex_state = 85, .external_lex_state = 32},
  [6881] = {.lex_state = 80, .external_lex_state = 41},
  [6882] = {.lex_state = 82, .external_lex_state = 49},
  [6883] = {.lex_state = 87, .external_lex_state = 38},
  [6884] = {.lex_state = 87, .external_lex_state = 40},
  [6885] = {.lex_state = 87, .external_lex_state = 39},
  [6886] = {.lex_state = 87, .external_lex_state = 39},
  [6887] = {.lex_state = 34},
  [6888] = {.lex_state = 95, .external_lex_state = 40},
  [6889] = {.lex_state = 79, .external_lex_state = 26},
  [6890] = {.lex_state = 81, .external_lex_state = 35},
  [6891] = {.lex_state = 96, .external_lex_state = 32},
  [6892] = {.lex_state = 82, .external_lex_state = 35},
  [6893] = {.lex_state = 82, .external_lex_state = 35},
  [6894] = {.lex_state = 80, .external_lex_state = 41},
  [6895] = {.lex_state = 87, .external_lex_state = 44},
  [6896] = {.lex_state = 96, .external_lex_state = 35},
  [6897] = {.lex_state = 87, .external_lex_state = 24},
  [6898] = {.lex_state = 96, .external_lex_state = 32},
  [6899] = {.lex_state = 87, .external_lex_state = 40},
  [6900] = {.lex_state = 87, .external_lex_state = 40},
  [6901] = {.lex_state = 75, .external_lex_state = 53},
  [6902] = {.lex_state = 82, .external_lex_state = 35},
  [6903] = {.lex_state = 88, .external_lex_state = 44},
  [6904] = {.lex_state = 96, .external_lex_state = 33},
  [6905] = {.lex_state = 34},
  [6906] = {.lex_state = 80, .external_lex_state = 49},
  [6907] = {.lex_state = 78, .external_lex_state = 50},
  [6908] = {.lex_state = 96, .external_lex_state = 33},
  [6909] = {.lex_state = 87, .external_lex_state = 36},
  [6910] = {.lex_state = 75, .external_lex_state = 55},
  [6911] = {.lex_state = 82, .external_lex_state = 35},
  [6912] = {.lex_state = 87, .external_lex_state = 40},
  [6913] = {.lex_state = 78, .external_lex_state = 49},
  [6914] = {.lex_state = 79, .external_lex_state = 48},
  [6915] = {.lex_state = 79, .external_lex_state = 26},
  [6916] = {.lex_state = 87, .external_lex_state = 40},
  [6917] = {.lex_state = 87, .external_lex_state = 38},
  [6918] = {.lex_state = 87, .external_lex_state = 38},
  [6919] = {.lex_state = 87, .external_lex_state = 36},
  [6920] = {.lex_state = 87, .external_lex_state = 39},
  [6921] = {.lex_state = 83, .external_lex_state = 35},
  [6922] = {.lex_state = 75, .external_lex_state = 23},
  [6923] = {.lex_state = 80, .external_lex_state = 43},
  [6924] = {.lex_state = 82, .external_lex_state = 35},
  [6925] = {.lex_state = 81, .external_lex_state = 35},
  [6926] = {.lex_state = 87, .external_lex_state = 40},
  [6927] = {.lex_state = 87, .external_lex_state = 45},
  [6928] = {.lex_state = 80, .external_lex_state = 43},
  [6929] = {.lex_state = 87, .external_lex_state = 46},
  [6930] = {.lex_state = 78, .external_lex_state = 50},
  [6931] = {.lex_state = 80, .external_lex_state = 42},
  [6932] = {.lex_state = 87, .external_lex_state = 40},
  [6933] = {.lex_state = 87, .external_lex_state = 40},
  [6934] = {.lex_state = 87, .external_lex_state = 39},
  [6935] = {.lex_state = 96, .external_lex_state = 31},
  [6936] = {.lex_state = 95, .external_lex_state = 39},
  [6937] = {.lex_state = 75, .external_lex_state = 34},
  [6938] = {.lex_state = 95, .external_lex_state = 29},
  [6939] = {.lex_state = 75, .external_lex_state = 46},
  [6940] = {.lex_state = 75, .external_lex_state = 54},
  [6941] = {.lex_state = 34},
  [6942] = {.lex_state = 79, .external_lex_state = 52},
  [6943] = {.lex_state = 78, .external_lex_state = 50},
  [6944] = {.lex_state = 94, .external_lex_state = 35},
  [6945] = {.lex_state = 80, .external_lex_state = 42},
  [6946] = {.lex_state = 87, .external_lex_state = 45},
  [6947] = {.lex_state = 85, .external_lex_state = 26},
  [6948] = {.lex_state = 83, .external_lex_state = 50},
  [6949] = {.lex_state = 87, .external_lex_state = 38},
  [6950] = {.lex_state = 96, .external_lex_state = 31},
  [6951] = {.lex_state = 95, .external_lex_state = 29},
  [6952] = {.lex_state = 95, .external_lex_state = 29},
  [6953] = {.lex_state = 87, .external_lex_state = 40},
  [6954] = {.lex_state = 87, .external_lex_state = 38},
  [6955] = {.lex_state = 79, .external_lex_state = 52},
  [6956] = {.lex_state = 85, .external_lex_state = 26},
  [6957] = {.lex_state = 83, .external_lex_state = 50},
  [6958] = {.lex_state = 79, .external_lex_state = 52},
  [6959] = {.lex_state = 87, .external_lex_state = 40},
  [6960] = {.lex_state = 87, .external_lex_state = 40},
  [6961] = {.lex_state = 85, .external_lex_state = 26},
  [6962] = {.lex_state = 34},
  [6963] = {.lex_state = 78, .external_lex_state = 50},
  [6964] = {.lex_state = 87, .external_lex_state = 38},
  [6965] = {.lex_state = 79, .external_lex_state = 52},
  [6966] = {.lex_state = 87, .external_lex_state = 38},
  [6967] = {.lex_state = 78, .external_lex_state = 49},
  [6968] = {.lex_state = 87, .external_lex_state = 39},
  [6969] = {.lex_state = 83, .external_lex_state = 35},
  [6970] = {.lex_state = 87, .external_lex_state = 38},
  [6971] = {.lex_state = 79, .external_lex_state = 26},
  [6972] = {.lex_state = 79, .external_lex_state = 48},
  [6973] = {.lex_state = 87, .external_lex_state = 38},
  [6974] = {.lex_state = 87, .external_lex_state = 40},
  [6975] = {.lex_state = 83, .external_lex_state = 50},
  [6976] = {.lex_state = 79, .external_lex_state = 48},
  [6977] = {.lex_state = 87, .external_lex_state = 40},
  [6978] = {.lex_state = 96, .external_lex_state = 32},
  [6979] = {.lex_state = 79, .external_lex_state = 48},
  [6980] = {.lex_state = 78, .external_lex_state = 50},
  [6981] = {.lex_state = 75, .external_lex_state = 51},
  [6982] = {.lex_state = 88, .external_lex_state = 47},
  [6983] = {.lex_state = 79, .external_lex_state = 48},
  [6984] = {.lex_state = 83, .external_lex_state = 50},
  [6985] = {.lex_state = 87, .external_lex_state = 38},
  [6986] = {.lex_state = 87, .external_lex_state = 38},
  [6987] = {.lex_state = 79, .external_lex_state = 48},
  [6988] = {.lex_state = 79, .external_lex_state = 48},
  [6989] = {.lex_state = 79, .external_lex_state = 48},
  [6990] = {.lex_state = 94, .external_lex_state = 35},
  [6991] = {.lex_state = 83, .external_lex_state = 50},
  [6992] = {.lex_state = 78, .external_lex_state = 50},
  [6993] = {.lex_state = 75, .external_lex_state = 55},
  [6994] = {.lex_state = 87, .external_lex_state = 24},
  [6995] = {.lex_state = 87, .external_lex_state = 38},
  [6996] = {.lex_state = 87, .external_lex_state = 24},
  [6997] = {.lex_state = 83, .external_lex_state = 50},
  [6998] = {.lex_state = 80, .external_lex_state = 33},
  [6999] = {.lex_state = 94, .external_lex_state = 37},
  [7000] = {.lex_state = 87, .external_lex_state = 38},
  [7001] = {.lex_state = 87, .external_lex_state = 38},
  [7002] = {.lex_state = 83, .external_lex_state = 50},
  [7003] = {.lex_state = 87, .external_lex_state = 23},
  [7004] = {.lex_state = 80, .external_lex_state = 49},
  [7005] = {.lex_state = 75, .external_lex_state = 55},
  [7006] = {.lex_state = 87, .external_lex_state = 23},
  [7007] = {.lex_state = 82, .external_lex_state = 35},
  [7008] = {.lex_state = 86, .external_lex_state = 27},
  [7009] = {.lex_state = 86, .external_lex_state = 41},
  [7010] = {.lex_state = 78, .external_lex_state = 50},
  [7011] = {.lex_state = 75, .external_lex_state = 30},
  [7012] = {.lex_state = 75, .external_lex_state = 24},
  [7013] = {.lex_state = 83, .external_lex_state = 50},
  [7014] = {.lex_state = 94, .external_lex_state = 37},
  [7015] = {.lex_state = 87, .external_lex_state = 39},
  [7016] = {.lex_state = 78, .external_lex_state = 26},
  [7017] = {.lex_state = 79, .external_lex_state = 26},
  [7018] = {.lex_state = 87, .external_lex_state = 39},
  [7019] = {.lex_state = 90, .external_lex_state = 29},
  [7020] = {.lex_state = 87, .external_lex_state = 38},
  [7021] = {.lex_state = 87, .external_lex_state = 38},
  [7022] = {.lex_state = 78, .external_lex_state = 49},
  [7023] = {.lex_state = 86, .external_lex_state = 27},
  [7024] = {.lex_state = 78, .external_lex_state = 50},
  [7025] = {.lex_state = 87, .external_lex_state = 39},
  [7026] = {.lex_state = 87, .external_lex_state = 40},
  [7027] = {.lex_state = 87, .external_lex_state = 38},
  [7028] = {.lex_state = 79, .external_lex_state = 52},
  [7029] = {.lex_state = 81, .external_lex_state = 35},
  [7030] = {.lex_state = 100, .external_lex_state = 35},
  [7031] = {.lex_state = 87, .external_lex_state = 40},
  [7032] = {.lex_state = 87, .external_lex_state = 23},
  [7033] = {.lex_state = 97, .external_lex_state = 34},
  [7034] = {.lex_state = 87, .external_lex_state = 40},
  [7035] = {.lex_state = 87, .external_lex_state = 23},
  [7036] = {.lex_state = 87, .external_lex_state = 29},
  [7037] = {.lex_state = 75, .external_lex_state = 51},
  [7038] = {.lex_state = 11, .external_lex_state = 49},
  [7039] = {.lex_state = 88, .external_lex_state = 52},
  [7040] = {.lex_state = 96, .external_lex_state = 33},
  [7041] = {.lex_state = 87, .external_lex_state = 39},
  [7042] = {.lex_state = 87, .external_lex_state = 40},
  [7043] = {.lex_state = 87, .external_lex_state = 39},
  [7044] = {.lex_state = 87, .external_lex_state = 39},
  [7045] = {.lex_state = 87, .external_lex_state = 39},
  [7046] = {.lex_state = 87, .external_lex_state = 39},
  [7047] = {.lex_state = 95, .external_lex_state = 38},
  [7048] = {.lex_state = 87, .external_lex_state = 39},
  [7049] = {.lex_state = 86, .external_lex_state = 50},
  [7050] = {.lex_state = 96, .external_lex_state = 33},
  [7051] = {.lex_state = 87, .external_lex_state = 39},
  [7052] = {.lex_state = 83, .external_lex_state = 50},
  [7053] = {.lex_state = 87, .external_lex_state = 39},
  [7054] = {.lex_state = 88, .external_lex_state = 42},
  [7055] = {.lex_state = 80, .external_lex_state = 26},
  [7056] = {.lex_state = 75, .external_lex_state = 50},
  [7057] = {.lex_state = 87, .external_lex_state = 39},
  [7058] = {.lex_state = 87, .external_lex_state = 35},
  [7059] = {.lex_state = 78, .external_lex_state = 47},
  [7060] = {.lex_state = 34},
  [7061] = {.lex_state = 11, .external_lex_state = 49},
  [7062] = {.lex_state = 87, .external_lex_state = 40},
  [7063] = {.lex_state = 79, .external_lex_state = 47},
  [7064] = {.lex_state = 80, .external_lex_state = 32},
  [7065] = {.lex_state = 28, .external_lex_state = 49},
  [7066] = {.lex_state = 87, .external_lex_state = 23},
  [7067] = {.lex_state = 87, .external_lex_state = 39},
  [7068] = {.lex_state = 87, .external_lex_state = 39},
  [7069] = {.lex_state = 96, .external_lex_state = 33},
  [7070] = {.lex_state = 87, .external_lex_state = 38},
  [7071] = {.lex_state = 79, .external_lex_state = 26},
  [7072] = {.lex_state = 79, .external_lex_state = 26},
  [7073] = {.lex_state = 88, .external_lex_state = 47},
  [7074] = {.lex_state = 87, .external_lex_state = 40},
  [7075] = {.lex_state = 75, .external_lex_state = 35},
  [7076] = {.lex_state = 78, .external_lex_state = 27},
  [7077] = {.lex_state = 28, .external_lex_state = 49},
  [7078] = {.lex_state = 87, .external_lex_state = 40},
  [7079] = {.lex_state = 79, .external_lex_state = 26},
  [7080] = {.lex_state = 85, .external_lex_state = 47},
  [7081] = {.lex_state = 87, .external_lex_state = 39},
  [7082] = {.lex_state = 79, .external_lex_state = 26},
  [7083] = {.lex_state = 34},
  [7084] = {.lex_state = 80, .external_lex_state = 26},
  [7085] = {.lex_state = 40, .external_lex_state = 49},
  [7086] = {.lex_state = 87, .external_lex_state = 39},
  [7087] = {.lex_state = 87, .external_lex_state = 39},
  [7088] = {.lex_state = 100, .external_lex_state = 35},
  [7089] = {.lex_state = 80, .external_lex_state = 26},
  [7090] = {.lex_state = 75, .external_lex_state = 54},
  [7091] = {.lex_state = 78, .external_lex_state = 33},
  [7092] = {.lex_state = 87, .external_lex_state = 39},
  [7093] = {.lex_state = 92, .external_lex_state = 35},
  [7094] = {.lex_state = 87, .external_lex_state = 58},
  [7095] = {.lex_state = 94, .external_lex_state = 42},
  [7096] = {.lex_state = 87, .external_lex_state = 38},
  [7097] = {.lex_state = 85, .external_lex_state = 49},
  [7098] = {.lex_state = 80, .external_lex_state = 26},
  [7099] = {.lex_state = 75, .external_lex_state = 35},
  [7100] = {.lex_state = 85, .external_lex_state = 28},
  [7101] = {.lex_state = 80, .external_lex_state = 26},
  [7102] = {.lex_state = 95, .external_lex_state = 29},
  [7103] = {.lex_state = 79, .external_lex_state = 48},
  [7104] = {.lex_state = 80, .external_lex_state = 26},
  [7105] = {.lex_state = 87, .external_lex_state = 38},
  [7106] = {.lex_state = 86, .external_lex_state = 49},
  [7107] = {.lex_state = 15, .external_lex_state = 49},
  [7108] = {.lex_state = 83, .external_lex_state = 50},
  [7109] = {.lex_state = 80, .external_lex_state = 26},
  [7110] = {.lex_state = 86, .external_lex_state = 49},
  [7111] = {.lex_state = 83, .external_lex_state = 50},
  [7112] = {.lex_state = 78, .external_lex_state = 50},
  [7113] = {.lex_state = 78, .external_lex_state = 52},
  [7114] = {.lex_state = 80, .external_lex_state = 26},
  [7115] = {.lex_state = 78, .external_lex_state = 49},
  [7116] = {.lex_state = 79, .external_lex_state = 35},
  [7117] = {.lex_state = 83, .external_lex_state = 50},
  [7118] = {.lex_state = 78, .external_lex_state = 50},
  [7119] = {.lex_state = 10, .external_lex_state = 49},
  [7120] = {.lex_state = 88, .external_lex_state = 52},
  [7121] = {.lex_state = 78, .external_lex_state = 50},
  [7122] = {.lex_state = 87, .external_lex_state = 45},
  [7123] = {.lex_state = 75, .external_lex_state = 23},
  [7124] = {.lex_state = 86, .external_lex_state = 27},
  [7125] = {.lex_state = 75, .external_lex_state = 51},
  [7126] = {.lex_state = 86, .external_lex_state = 50},
  [7127] = {.lex_state = 87, .external_lex_state = 40},
  [7128] = {.lex_state = 82, .external_lex_state = 35},
  [7129] = {.lex_state = 87, .external_lex_state = 39},
  [7130] = {.lex_state = 78, .external_lex_state = 50},
  [7131] = {.lex_state = 92, .external_lex_state = 35},
  [7132] = {.lex_state = 87, .external_lex_state = 40},
  [7133] = {.lex_state = 34},
  [7134] = {.lex_state = 80, .external_lex_state = 28},
  [7135] = {.lex_state = 80, .external_lex_state = 28},
  [7136] = {.lex_state = 82, .external_lex_state = 35},
  [7137] = {.lex_state = 87, .external_lex_state = 40},
  [7138] = {.lex_state = 87, .external_lex_state = 38},
  [7139] = {.lex_state = 82, .external_lex_state = 35},
  [7140] = {.lex_state = 87, .external_lex_state = 40},
  [7141] = {.lex_state = 87, .external_lex_state = 39},
  [7142] = {.lex_state = 82, .external_lex_state = 35},
  [7143] = {.lex_state = 82, .external_lex_state = 35},
  [7144] = {.lex_state = 75, .external_lex_state = 50},
  [7145] = {.lex_state = 87, .external_lex_state = 40},
  [7146] = {.lex_state = 85, .external_lex_state = 52},
  [7147] = {.lex_state = 87, .external_lex_state = 35},
  [7148] = {.lex_state = 87, .external_lex_state = 40},
  [7149] = {.lex_state = 87, .external_lex_state = 38},
  [7150] = {.lex_state = 83, .external_lex_state = 50},
  [7151] = {.lex_state = 88, .external_lex_state = 49},
  [7152] = {.lex_state = 87, .external_lex_state = 40},
  [7153] = {.lex_state = 78, .external_lex_state = 50},
  [7154] = {.lex_state = 92, .external_lex_state = 35},
  [7155] = {.lex_state = 94, .external_lex_state = 36},
  [7156] = {.lex_state = 86, .external_lex_state = 44},
  [7157] = {.lex_state = 79, .external_lex_state = 52},
  [7158] = {.lex_state = 87, .external_lex_state = 39},
  [7159] = {.lex_state = 94, .external_lex_state = 35},
  [7160] = {.lex_state = 86, .external_lex_state = 50},
  [7161] = {.lex_state = 85, .external_lex_state = 28},
  [7162] = {.lex_state = 88, .external_lex_state = 42},
  [7163] = {.lex_state = 94, .external_lex_state = 36},
  [7164] = {.lex_state = 92, .external_lex_state = 35},
  [7165] = {.lex_state = 78, .external_lex_state = 49},
  [7166] = {.lex_state = 79, .external_lex_state = 52},
  [7167] = {.lex_state = 87, .external_lex_state = 40},
  [7168] = {.lex_state = 87, .external_lex_state = 40},
  [7169] = {.lex_state = 87, .external_lex_state = 40},
  [7170] = {.lex_state = 88, .external_lex_state = 42},
  [7171] = {.lex_state = 87, .external_lex_state = 38},
  [7172] = {.lex_state = 79, .external_lex_state = 52},
  [7173] = {.lex_state = 88, .external_lex_state = 42},
  [7174] = {.lex_state = 79, .external_lex_state = 48},
  [7175] = {.lex_state = 75, .external_lex_state = 50},
  [7176] = {.lex_state = 79, .external_lex_state = 52},
  [7177] = {.lex_state = 87, .external_lex_state = 39},
  [7178] = {.lex_state = 87, .external_lex_state = 57},
  [7179] = {.lex_state = 85, .external_lex_state = 50},
  [7180] = {.lex_state = 79, .external_lex_state = 52},
  [7181] = {.lex_state = 79, .external_lex_state = 48},
  [7182] = {.lex_state = 85, .external_lex_state = 47},
  [7183] = {.lex_state = 87, .external_lex_state = 40},
  [7184] = {.lex_state = 79, .external_lex_state = 52},
  [7185] = {.lex_state = 87, .external_lex_state = 38},
  [7186] = {.lex_state = 87, .external_lex_state = 39},
  [7187] = {.lex_state = 87, .external_lex_state = 43},
  [7188] = {.lex_state = 85, .external_lex_state = 47},
  [7189] = {.lex_state = 78, .external_lex_state = 27},
  [7190] = {.lex_state = 92, .external_lex_state = 50},
  [7191] = {.lex_state = 87, .external_lex_state = 40},
  [7192] = {.lex_state = 79, .external_lex_state = 52},
  [7193] = {.lex_state = 87, .external_lex_state = 40},
  [7194] = {.lex_state = 78, .external_lex_state = 49},
  [7195] = {.lex_state = 85, .external_lex_state = 47},
  [7196] = {.lex_state = 85, .external_lex_state = 27},
  [7197] = {.lex_state = 75, .external_lex_state = 53},
  [7198] = {.lex_state = 78, .external_lex_state = 27},
  [7199] = {.lex_state = 87, .external_lex_state = 40},
  [7200] = {.lex_state = 86, .external_lex_state = 41},
  [7201] = {.lex_state = 88, .external_lex_state = 41},
  [7202] = {.lex_state = 95, .external_lex_state = 29},
  [7203] = {.lex_state = 10, .external_lex_state = 49},
  [7204] = {.lex_state = 86, .external_lex_state = 41},
  [7205] = {.lex_state = 87, .external_lex_state = 39},
  [7206] = {.lex_state = 87, .external_lex_state = 40},
  [7207] = {.lex_state = 96, .external_lex_state = 37},
  [7208] = {.lex_state = 78, .external_lex_state = 32},
  [7209] = {.lex_state = 78, .external_lex_state = 49},
  [7210] = {.lex_state = 93, .external_lex_state = 35},
  [7211] = {.lex_state = 78, .external_lex_state = 32},
  [7212] = {.lex_state = 88, .external_lex_state = 48},
  [7213] = {.lex_state = 86, .external_lex_state = 28},
  [7214] = {.lex_state = 78, .external_lex_state = 49},
  [7215] = {.lex_state = 85, .external_lex_state = 52},
  [7216] = {.lex_state = 79, .external_lex_state = 52},
  [7217] = {.lex_state = 79, .external_lex_state = 47},
  [7218] = {.lex_state = 79, .external_lex_state = 48},
  [7219] = {.lex_state = 87, .external_lex_state = 40},
  [7220] = {.lex_state = 86, .external_lex_state = 41},
  [7221] = {.lex_state = 87, .external_lex_state = 38},
  [7222] = {.lex_state = 87, .external_lex_state = 39},
  [7223] = {.lex_state = 87, .external_lex_state = 39},
  [7224] = {.lex_state = 93, .external_lex_state = 35},
  [7225] = {.lex_state = 86, .external_lex_state = 28},
  [7226] = {.lex_state = 80, .external_lex_state = 48},
  [7227] = {.lex_state = 85, .external_lex_state = 52},
  [7228] = {.lex_state = 85, .external_lex_state = 52},
  [7229] = {.lex_state = 86, .external_lex_state = 43},
  [7230] = {.lex_state = 4},
  [7231] = {.lex_state = 83, .external_lex_state = 35},
  [7232] = {.lex_state = 78, .external_lex_state = 49},
  [7233] = {.lex_state = 87, .external_lex_state = 40},
  [7234] = {.lex_state = 81, .external_lex_state = 50},
  [7235] = {.lex_state = 80, .external_lex_state = 48},
  [7236] = {.lex_state = 80, .external_lex_state = 48},
  [7237] = {.lex_state = 87, .external_lex_state = 38},
  [7238] = {.lex_state = 80, .external_lex_state = 27},
  [7239] = {.lex_state = 80, .external_lex_state = 27},
  [7240] = {.lex_state = 80, .external_lex_state = 48},
  [7241] = {.lex_state = 80, .external_lex_state = 50},
  [7242] = {.lex_state = 87, .external_lex_state = 39},
  [7243] = {.lex_state = 87, .external_lex_state = 38},
  [7244] = {.lex_state = 81, .external_lex_state = 49},
  [7245] = {.lex_state = 88, .external_lex_state = 37},
  [7246] = {.lex_state = 81, .external_lex_state = 50},
  [7247] = {.lex_state = 88, .external_lex_state = 41},
  [7248] = {.lex_state = 94, .external_lex_state = 35},
  [7249] = {.lex_state = 86, .external_lex_state = 41},
  [7250] = {.lex_state = 83, .external_lex_state = 35},
  [7251] = {.lex_state = 80, .external_lex_state = 50},
  [7252] = {.lex_state = 78, .external_lex_state = 49},
  [7253] = {.lex_state = 83, .external_lex_state = 35},
  [7254] = {.lex_state = 88, .external_lex_state = 41},
  [7255] = {.lex_state = 78, .external_lex_state = 35},
  [7256] = {.lex_state = 78, .external_lex_state = 28},
  [7257] = {.lex_state = 88, .external_lex_state = 41},
  [7258] = {.lex_state = 79, .external_lex_state = 52},
  [7259] = {.lex_state = 78, .external_lex_state = 32},
  [7260] = {.lex_state = 87, .external_lex_state = 58},
  [7261] = {.lex_state = 78, .external_lex_state = 28},
  [7262] = {.lex_state = 83, .external_lex_state = 35},
  [7263] = {.lex_state = 78, .external_lex_state = 28},
  [7264] = {.lex_state = 78, .external_lex_state = 28},
  [7265] = {.lex_state = 79, .external_lex_state = 52},
  [7266] = {.lex_state = 80, .external_lex_state = 52},
  [7267] = {.lex_state = 88, .external_lex_state = 48},
  [7268] = {.lex_state = 12, .external_lex_state = 49},
  [7269] = {.lex_state = 83, .external_lex_state = 35},
  [7270] = {.lex_state = 87, .external_lex_state = 23},
  [7271] = {.lex_state = 80, .external_lex_state = 47},
  [7272] = {.lex_state = 79, .external_lex_state = 47},
  [7273] = {.lex_state = 4},
  [7274] = {.lex_state = 96, .external_lex_state = 36},
  [7275] = {.lex_state = 83, .external_lex_state = 35},
  [7276] = {.lex_state = 79, .external_lex_state = 26},
  [7277] = {.lex_state = 85, .external_lex_state = 42},
  [7278] = {.lex_state = 87, .external_lex_state = 40},
  [7279] = {.lex_state = 86, .external_lex_state = 42},
  [7280] = {.lex_state = 75, .external_lex_state = 53},
  [7281] = {.lex_state = 75, .external_lex_state = 50},
  [7282] = {.lex_state = 80, .external_lex_state = 52},
  [7283] = {.lex_state = 78, .external_lex_state = 27},
  [7284] = {.lex_state = 80, .external_lex_state = 52},
  [7285] = {.lex_state = 86, .external_lex_state = 42},
  [7286] = {.lex_state = 80, .external_lex_state = 52},
  [7287] = {.lex_state = 87, .external_lex_state = 42},
  [7288] = {.lex_state = 87, .external_lex_state = 38},
  [7289] = {.lex_state = 94, .external_lex_state = 43},
  [7290] = {.lex_state = 87, .external_lex_state = 38},
  [7291] = {.lex_state = 86, .external_lex_state = 49},
  [7292] = {.lex_state = 80, .external_lex_state = 47},
  [7293] = {.lex_state = 4},
  [7294] = {.lex_state = 87, .external_lex_state = 40},
  [7295] = {.lex_state = 75, .external_lex_state = 35},
  [7296] = {.lex_state = 83, .external_lex_state = 35},
  [7297] = {.lex_state = 79, .external_lex_state = 47},
  [7298] = {.lex_state = 86, .external_lex_state = 42},
  [7299] = {.lex_state = 80, .external_lex_state = 47},
  [7300] = {.lex_state = 92, .external_lex_state = 50},
  [7301] = {.lex_state = 79, .external_lex_state = 52},
  [7302] = {.lex_state = 80, .external_lex_state = 47},
  [7303] = {.lex_state = 80, .external_lex_state = 47},
  [7304] = {.lex_state = 87, .external_lex_state = 40},
  [7305] = {.lex_state = 80, .external_lex_state = 47},
  [7306] = {.lex_state = 80, .external_lex_state = 47},
  [7307] = {.lex_state = 80, .external_lex_state = 47},
  [7308] = {.lex_state = 83, .external_lex_state = 35},
  [7309] = {.lex_state = 79, .external_lex_state = 47},
  [7310] = {.lex_state = 80, .external_lex_state = 47},
  [7311] = {.lex_state = 80, .external_lex_state = 47},
  [7312] = {.lex_state = 82, .external_lex_state = 50},
  [7313] = {.lex_state = 88, .external_lex_state = 49},
  [7314] = {.lex_state = 88, .external_lex_state = 49},
  [7315] = {.lex_state = 88, .external_lex_state = 49},
  [7316] = {.lex_state = 83, .external_lex_state = 35},
  [7317] = {.lex_state = 87, .external_lex_state = 38},
  [7318] = {.lex_state = 87, .external_lex_state = 39},
  [7319] = {.lex_state = 87, .external_lex_state = 38},
  [7320] = {.lex_state = 87, .external_lex_state = 38},
  [7321] = {.lex_state = 88, .external_lex_state = 43},
  [7322] = {.lex_state = 80, .external_lex_state = 47},
  [7323] = {.lex_state = 75, .external_lex_state = 39},
  [7324] = {.lex_state = 88, .external_lex_state = 43},
  [7325] = {.lex_state = 75, .external_lex_state = 50},
  [7326] = {.lex_state = 87, .external_lex_state = 38},
  [7327] = {.lex_state = 80, .external_lex_state = 47},
  [7328] = {.lex_state = 86, .external_lex_state = 50},
  [7329] = {.lex_state = 87, .external_lex_state = 40},
  [7330] = {.lex_state = 79, .external_lex_state = 26},
  [7331] = {.lex_state = 88, .external_lex_state = 43},
  [7332] = {.lex_state = 75, .external_lex_state = 35},
  [7333] = {.lex_state = 88, .external_lex_state = 36},
  [7334] = {.lex_state = 87, .external_lex_state = 38},
  [7335] = {.lex_state = 88, .external_lex_state = 43},
  [7336] = {.lex_state = 10, .external_lex_state = 49},
  [7337] = {.lex_state = 80, .external_lex_state = 26},
  [7338] = {.lex_state = 87, .external_lex_state = 38},
  [7339] = {.lex_state = 78, .external_lex_state = 27},
  [7340] = {.lex_state = 82, .external_lex_state = 50},
  [7341] = {.lex_state = 83, .external_lex_state = 35},
  [7342] = {.lex_state = 10, .external_lex_state = 49},
  [7343] = {.lex_state = 85, .external_lex_state = 44},
  [7344] = {.lex_state = 80, .external_lex_state = 52},
  [7345] = {.lex_state = 85, .external_lex_state = 43},
  [7346] = {.lex_state = 78, .external_lex_state = 33},
  [7347] = {.lex_state = 75, .external_lex_state = 54},
  [7348] = {.lex_state = 75, .external_lex_state = 46},
  [7349] = {.lex_state = 78, .external_lex_state = 27},
  [7350] = {.lex_state = 11, .external_lex_state = 49},
  [7351] = {.lex_state = 94, .external_lex_state = 35},
  [7352] = {.lex_state = 78, .external_lex_state = 48},
  [7353] = {.lex_state = 87, .external_lex_state = 38},
  [7354] = {.lex_state = 78, .external_lex_state = 27},
  [7355] = {.lex_state = 87, .external_lex_state = 23},
  [7356] = {.lex_state = 10, .external_lex_state = 49},
  [7357] = {.lex_state = 87, .external_lex_state = 46},
  [7358] = {.lex_state = 87, .external_lex_state = 39},
  [7359] = {.lex_state = 10, .external_lex_state = 49},
  [7360] = {.lex_state = 10, .external_lex_state = 49},
  [7361] = {.lex_state = 78, .external_lex_state = 27},
  [7362] = {.lex_state = 34},
  [7363] = {.lex_state = 87, .external_lex_state = 38},
  [7364] = {.lex_state = 80, .external_lex_state = 52},
  [7365] = {.lex_state = 80, .external_lex_state = 52},
  [7366] = {.lex_state = 87, .external_lex_state = 38},
  [7367] = {.lex_state = 78, .external_lex_state = 50},
  [7368] = {.lex_state = 86, .external_lex_state = 27},
  [7369] = {.lex_state = 10, .external_lex_state = 49},
  [7370] = {.lex_state = 87, .external_lex_state = 34},
  [7371] = {.lex_state = 75, .external_lex_state = 29},
  [7372] = {.lex_state = 85, .external_lex_state = 33},
  [7373] = {.lex_state = 80, .external_lex_state = 28},
  [7374] = {.lex_state = 87, .external_lex_state = 24},
  [7375] = {.lex_state = 80, .external_lex_state = 52},
  [7376] = {.lex_state = 80, .external_lex_state = 52},
  [7377] = {.lex_state = 87, .external_lex_state = 38},
  [7378] = {.lex_state = 83, .external_lex_state = 35},
  [7379] = {.lex_state = 80, .external_lex_state = 52},
  [7380] = {.lex_state = 78, .external_lex_state = 27},
  [7381] = {.lex_state = 10, .external_lex_state = 49},
  [7382] = {.lex_state = 80, .external_lex_state = 52},
  [7383] = {.lex_state = 88, .external_lex_state = 28},
  [7384] = {.lex_state = 80, .external_lex_state = 52},
  [7385] = {.lex_state = 78, .external_lex_state = 33},
  [7386] = {.lex_state = 88, .external_lex_state = 28},
  [7387] = {.lex_state = 85, .external_lex_state = 33},
  [7388] = {.lex_state = 87, .external_lex_state = 56},
  [7389] = {.lex_state = 78, .external_lex_state = 49},
  [7390] = {.lex_state = 14, .external_lex_state = 49},
  [7391] = {.lex_state = 87, .external_lex_state = 39},
  [7392] = {.lex_state = 81, .external_lex_state = 35},
  [7393] = {.lex_state = 96, .external_lex_state = 32},
  [7394] = {.lex_state = 79, .external_lex_state = 47},
  [7395] = {.lex_state = 75, .external_lex_state = 24},
  [7396] = {.lex_state = 86, .external_lex_state = 44},
  [7397] = {.lex_state = 87, .external_lex_state = 39},
  [7398] = {.lex_state = 85, .external_lex_state = 41},
  [7399] = {.lex_state = 78, .external_lex_state = 28},
  [7400] = {.lex_state = 80, .external_lex_state = 48},
  [7401] = {.lex_state = 87, .external_lex_state = 39},
  [7402] = {.lex_state = 83, .external_lex_state = 35},
  [7403] = {.lex_state = 78, .external_lex_state = 27},
  [7404] = {.lex_state = 85, .external_lex_state = 50},
  [7405] = {.lex_state = 87, .external_lex_state = 38},
  [7406] = {.lex_state = 83, .external_lex_state = 35},
  [7407] = {.lex_state = 87, .external_lex_state = 39},
  [7408] = {.lex_state = 94, .external_lex_state = 44},
  [7409] = {.lex_state = 77},
  [7410] = {.lex_state = 75, .external_lex_state = 51},
  [7411] = {.lex_state = 79, .external_lex_state = 47},
  [7412] = {.lex_state = 87, .external_lex_state = 30},
  [7413] = {.lex_state = 87, .external_lex_state = 39},
  [7414] = {.lex_state = 88, .external_lex_state = 27},
  [7415] = {.lex_state = 80, .external_lex_state = 27},
  [7416] = {.lex_state = 79, .external_lex_state = 52},
  [7417] = {.lex_state = 77},
  [7418] = {.lex_state = 79, .external_lex_state = 26},
  [7419] = {.lex_state = 78, .external_lex_state = 28},
  [7420] = {.lex_state = 78, .external_lex_state = 28},
  [7421] = {.lex_state = 86, .external_lex_state = 49},
  [7422] = {.lex_state = 79, .external_lex_state = 47},
  [7423] = {.lex_state = 78, .external_lex_state = 28},
  [7424] = {.lex_state = 80, .external_lex_state = 26},
  [7425] = {.lex_state = 87, .external_lex_state = 30},
  [7426] = {.lex_state = 78, .external_lex_state = 28},
  [7427] = {.lex_state = 86, .external_lex_state = 43},
  [7428] = {.lex_state = 11, .external_lex_state = 49},
  [7429] = {.lex_state = 86, .external_lex_state = 42},
  [7430] = {.lex_state = 86, .external_lex_state = 44},
  [7431] = {.lex_state = 86, .external_lex_state = 43},
  [7432] = {.lex_state = 79, .external_lex_state = 47},
  [7433] = {.lex_state = 78, .external_lex_state = 27},
  [7434] = {.lex_state = 87, .external_lex_state = 40},
  [7435] = {.lex_state = 87, .external_lex_state = 39},
  [7436] = {.lex_state = 88, .external_lex_state = 27},
  [7437] = {.lex_state = 78, .external_lex_state = 28},
  [7438] = {.lex_state = 78, .external_lex_state = 28},
  [7439] = {.lex_state = 87, .external_lex_state = 23},
  [7440] = {.lex_state = 86, .external_lex_state = 43},
  [7441] = {.lex_state = 78, .external_lex_state = 26},
  [7442] = {.lex_state = 87, .external_lex_state = 40},
  [7443] = {.lex_state = 79, .external_lex_state = 47},
  [7444] = {.lex_state = 78, .external_lex_state = 28},
  [7445] = {.lex_state = 78, .external_lex_state = 28},
  [7446] = {.lex_state = 94, .external_lex_state = 41},
  [7447] = {.lex_state = 79, .external_lex_state = 47},
  [7448] = {.lex_state = 79, .external_lex_state = 26},
  [7449] = {.lex_state = 87, .external_lex_state = 23},
  [7450] = {.lex_state = 78, .external_lex_state = 27},
  [7451] = {.lex_state = 87, .external_lex_state = 40},
  [7452] = {.lex_state = 77},
  [7453] = {.lex_state = 80, .external_lex_state = 47},
  [7454] = {.lex_state = 78, .external_lex_state = 27},
  [7455] = {.lex_state = 86, .external_lex_state = 44},
  [7456] = {.lex_state = 10, .external_lex_state = 49},
  [7457] = {.lex_state = 78, .external_lex_state = 26},
  [7458] = {.lex_state = 80, .external_lex_state = 27},
  [7459] = {.lex_state = 81, .external_lex_state = 50},
  [7460] = {.lex_state = 79, .external_lex_state = 47},
  [7461] = {.lex_state = 75, .external_lex_state = 50},
  [7462] = {.lex_state = 86, .external_lex_state = 44},
  [7463] = {.lex_state = 86, .external_lex_state = 43},
  [7464] = {.lex_state = 87, .external_lex_state = 39},
  [7465] = {.lex_state = 80, .external_lex_state = 26},
  [7466] = {.lex_state = 40, .external_lex_state = 49},
  [7467] = {.lex_state = 80, .external_lex_state = 48},
  [7468] = {.lex_state = 80, .external_lex_state = 26},
  [7469] = {.lex_state = 80, .external_lex_state = 48},
  [7470] = {.lex_state = 80, .external_lex_state = 26},
  [7471] = {.lex_state = 100, .external_lex_state = 35},
  [7472] = {.lex_state = 78, .external_lex_state = 27},
  [7473] = {.lex_state = 87, .external_lex_state = 39},
  [7474] = {.lex_state = 80, .external_lex_state = 48},
  [7475] = {.lex_state = 87, .external_lex_state = 23},
  [7476] = {.lex_state = 85, .external_lex_state = 48},
  [7477] = {.lex_state = 80, .external_lex_state = 48},
  [7478] = {.lex_state = 87, .external_lex_state = 39},
  [7479] = {.lex_state = 87, .external_lex_state = 41},
  [7480] = {.lex_state = 80, .external_lex_state = 50},
  [7481] = {.lex_state = 80, .external_lex_state = 48},
  [7482] = {.lex_state = 80, .external_lex_state = 48},
  [7483] = {.lex_state = 78, .external_lex_state = 48},
  [7484] = {.lex_state = 80, .external_lex_state = 52},
  [7485] = {.lex_state = 80, .external_lex_state = 48},
  [7486] = {.lex_state = 75, .external_lex_state = 55},
  [7487] = {.lex_state = 96, .external_lex_state = 32},
  [7488] = {.lex_state = 85, .external_lex_state = 27},
  [7489] = {.lex_state = 79, .external_lex_state = 35},
  [7490] = {.lex_state = 79, .external_lex_state = 48},
  [7491] = {.lex_state = 79, .external_lex_state = 48},
  [7492] = {.lex_state = 79, .external_lex_state = 48},
  [7493] = {.lex_state = 78, .external_lex_state = 48},
  [7494] = {.lex_state = 87, .external_lex_state = 34},
  [7495] = {.lex_state = 80, .external_lex_state = 28},
  [7496] = {.lex_state = 85, .external_lex_state = 48},
  [7497] = {.lex_state = 79, .external_lex_state = 48},
  [7498] = {.lex_state = 87, .external_lex_state = 39},
  [7499] = {.lex_state = 85, .external_lex_state = 48},
  [7500] = {.lex_state = 80, .external_lex_state = 48},
  [7501] = {.lex_state = 85, .external_lex_state = 48},
  [7502] = {.lex_state = 87, .external_lex_state = 45},
  [7503] = {.lex_state = 87, .external_lex_state = 45},
  [7504] = {.lex_state = 85, .external_lex_state = 28},
  [7505] = {.lex_state = 79, .external_lex_state = 50},
  [7506] = {.lex_state = 85, .external_lex_state = 28},
  [7507] = {.lex_state = 11, .external_lex_state = 49},
  [7508] = {.lex_state = 41, .external_lex_state = 49},
  [7509] = {.lex_state = 85, .external_lex_state = 28},
  [7510] = {.lex_state = 32},
  [7511] = {.lex_state = 87, .external_lex_state = 46},
  [7512] = {.lex_state = 87, .external_lex_state = 23},
  [7513] = {.lex_state = 81, .external_lex_state = 35},
  [7514] = {.lex_state = 85, .external_lex_state = 28},
  [7515] = {.lex_state = 87, .external_lex_state = 34},
  [7516] = {.lex_state = 90, .external_lex_state = 34},
  [7517] = {.lex_state = 80, .external_lex_state = 59},
  [7518] = {.lex_state = 11, .external_lex_state = 49},
  [7519] = {.lex_state = 88, .external_lex_state = 50},
  [7520] = {.lex_state = 79, .external_lex_state = 28},
  [7521] = {.lex_state = 88, .external_lex_state = 52},
  [7522] = {.lex_state = 79, .external_lex_state = 49},
  [7523] = {.lex_state = 88, .external_lex_state = 52},
  [7524] = {.lex_state = 79, .external_lex_state = 28},
  [7525] = {.lex_state = 87, .external_lex_state = 41},
  [7526] = {.lex_state = 32},
  [7527] = {.lex_state = 87, .external_lex_state = 46},
  [7528] = {.lex_state = 79, .external_lex_state = 28},
  [7529] = {.lex_state = 88, .external_lex_state = 52},
  [7530] = {.lex_state = 79, .external_lex_state = 50},
  [7531] = {.lex_state = 78, .external_lex_state = 35},
  [7532] = {.lex_state = 87, .external_lex_state = 41},
  [7533] = {.lex_state = 15, .external_lex_state = 49},
  [7534] = {.lex_state = 78, .external_lex_state = 28},
  [7535] = {.lex_state = 80, .external_lex_state = 28},
  [7536] = {.lex_state = 5},
  [7537] = {.lex_state = 11, .external_lex_state = 49},
  [7538] = {.lex_state = 86, .external_lex_state = 52},
  [7539] = {.lex_state = 78, .external_lex_state = 35},
  [7540] = {.lex_state = 80, .external_lex_state = 52},
  [7541] = {.lex_state = 87, .external_lex_state = 46},
  [7542] = {.lex_state = 79, .external_lex_state = 50},
  [7543] = {.lex_state = 79, .external_lex_state = 50},
  [7544] = {.lex_state = 32},
  [7545] = {.lex_state = 88, .external_lex_state = 52},
  [7546] = {.lex_state = 95, .external_lex_state = 46},
  [7547] = {.lex_state = 79, .external_lex_state = 49},
  [7548] = {.lex_state = 28, .external_lex_state = 49},
  [7549] = {.lex_state = 88, .external_lex_state = 47},
  [7550] = {.lex_state = 88, .external_lex_state = 47},
  [7551] = {.lex_state = 79, .external_lex_state = 28},
  [7552] = {.lex_state = 80, .external_lex_state = 52},
  [7553] = {.lex_state = 32},
  [7554] = {.lex_state = 88, .external_lex_state = 47},
  [7555] = {.lex_state = 79, .external_lex_state = 50},
  [7556] = {.lex_state = 86, .external_lex_state = 32},
  [7557] = {.lex_state = 80, .external_lex_state = 28},
  [7558] = {.lex_state = 80, .external_lex_state = 28},
  [7559] = {.lex_state = 80, .external_lex_state = 28},
  [7560] = {.lex_state = 94, .external_lex_state = 41},
  [7561] = {.lex_state = 79, .external_lex_state = 27},
  [7562] = {.lex_state = 79, .external_lex_state = 49},
  [7563] = {.lex_state = 79, .external_lex_state = 49},
  [7564] = {.lex_state = 80, .external_lex_state = 28},
  [7565] = {.lex_state = 79, .external_lex_state = 49},
  [7566] = {.lex_state = 92, .external_lex_state = 35},
  [7567] = {.lex_state = 86, .external_lex_state = 32},
  [7568] = {.lex_state = 88, .external_lex_state = 47},
  [7569] = {.lex_state = 80, .external_lex_state = 28},
  [7570] = {.lex_state = 75, .external_lex_state = 29},
  [7571] = {.lex_state = 80, .external_lex_state = 28},
  [7572] = {.lex_state = 32},
  [7573] = {.lex_state = 79, .external_lex_state = 49},
  [7574] = {.lex_state = 80, .external_lex_state = 28},
  [7575] = {.lex_state = 87, .external_lex_state = 46},
  [7576] = {.lex_state = 32},
  [7577] = {.lex_state = 87, .external_lex_state = 23},
  [7578] = {.lex_state = 85, .external_lex_state = 49},
  [7579] = {.lex_state = 32},
  [7580] = {.lex_state = 95, .external_lex_state = 23},
  [7581] = {.lex_state = 92, .external_lex_state = 35},
  [7582] = {.lex_state = 94, .external_lex_state = 41},
  [7583] = {.lex_state = 78, .external_lex_state = 28},
  [7584] = {.lex_state = 87, .external_lex_state = 23},
  [7585] = {.lex_state = 79, .external_lex_state = 50},
  [7586] = {.lex_state = 90, .external_lex_state = 30},
  [7587] = {.lex_state = 79, .external_lex_state = 49},
  [7588] = {.lex_state = 88, .external_lex_state = 44},
  [7589] = {.lex_state = 79, .external_lex_state = 49},
  [7590] = {.lex_state = 94, .external_lex_state = 44},
  [7591] = {.lex_state = 79, .external_lex_state = 49},
  [7592] = {.lex_state = 92, .external_lex_state = 35},
  [7593] = {.lex_state = 75, .external_lex_state = 35},
  [7594] = {.lex_state = 78, .external_lex_state = 28},
  [7595] = {.lex_state = 88, .external_lex_state = 48},
  [7596] = {.lex_state = 79, .external_lex_state = 50},
  [7597] = {.lex_state = 88, .external_lex_state = 48},
  [7598] = {.lex_state = 95, .external_lex_state = 34},
  [7599] = {.lex_state = 79, .external_lex_state = 50},
  [7600] = {.lex_state = 95, .external_lex_state = 34},
  [7601] = {.lex_state = 88, .external_lex_state = 49},
  [7602] = {.lex_state = 87, .external_lex_state = 24},
  [7603] = {.lex_state = 79, .external_lex_state = 50},
  [7604] = {.lex_state = 90, .external_lex_state = 30},
  [7605] = {.lex_state = 95, .external_lex_state = 34},
  [7606] = {.lex_state = 86, .external_lex_state = 33},
  [7607] = {.lex_state = 32},
  [7608] = {.lex_state = 45, .external_lex_state = 49},
  [7609] = {.lex_state = 75, .external_lex_state = 30},
  [7610] = {.lex_state = 88, .external_lex_state = 48},
  [7611] = {.lex_state = 88, .external_lex_state = 48},
  [7612] = {.lex_state = 95, .external_lex_state = 34},
  [7613] = {.lex_state = 32},
  [7614] = {.lex_state = 95, .external_lex_state = 34},
  [7615] = {.lex_state = 75, .external_lex_state = 56},
  [7616] = {.lex_state = 80, .external_lex_state = 28},
  [7617] = {.lex_state = 79, .external_lex_state = 50},
  [7618] = {.lex_state = 75, .external_lex_state = 35},
  [7619] = {.lex_state = 87, .external_lex_state = 52},
  [7620] = {.lex_state = 87, .external_lex_state = 23},
  [7621] = {.lex_state = 87, .external_lex_state = 23},
  [7622] = {.lex_state = 93, .external_lex_state = 50},
  [7623] = {.lex_state = 32},
  [7624] = {.lex_state = 92, .external_lex_state = 35},
  [7625] = {.lex_state = 79, .external_lex_state = 27},
  [7626] = {.lex_state = 32},
  [7627] = {.lex_state = 87, .external_lex_state = 24},
  [7628] = {.lex_state = 79, .external_lex_state = 49},
  [7629] = {.lex_state = 94, .external_lex_state = 44},
  [7630] = {.lex_state = 87, .external_lex_state = 45},
  [7631] = {.lex_state = 32},
  [7632] = {.lex_state = 78, .external_lex_state = 50},
  [7633] = {.lex_state = 88, .external_lex_state = 43},
  [7634] = {.lex_state = 32},
  [7635] = {.lex_state = 87, .external_lex_state = 46},
  [7636] = {.lex_state = 87, .external_lex_state = 45},
  [7637] = {.lex_state = 17},
  [7638] = {.lex_state = 87, .external_lex_state = 45},
  [7639] = {.lex_state = 32},
  [7640] = {.lex_state = 87, .external_lex_state = 26},
  [7641] = {.lex_state = 87, .external_lex_state = 45},
  [7642] = {.lex_state = 79, .external_lex_state = 50},
  [7643] = {.lex_state = 32},
  [7644] = {.lex_state = 87, .external_lex_state = 46},
  [7645] = {.lex_state = 87, .external_lex_state = 45},
  [7646] = {.lex_state = 32},
  [7647] = {.lex_state = 75, .external_lex_state = 34},
  [7648] = {.lex_state = 45, .external_lex_state = 49},
  [7649] = {.lex_state = 87, .external_lex_state = 46},
  [7650] = {.lex_state = 78, .external_lex_state = 49},
  [7651] = {.lex_state = 87, .external_lex_state = 46},
  [7652] = {.lex_state = 78, .external_lex_state = 50},
  [7653] = {.lex_state = 86, .external_lex_state = 47},
  [7654] = {.lex_state = 32},
  [7655] = {.lex_state = 32},
  [7656] = {.lex_state = 87, .external_lex_state = 45},
  [7657] = {.lex_state = 96, .external_lex_state = 35},
  [7658] = {.lex_state = 95, .external_lex_state = 30},
  [7659] = {.lex_state = 32},
  [7660] = {.lex_state = 81, .external_lex_state = 35},
  [7661] = {.lex_state = 78, .external_lex_state = 49},
  [7662] = {.lex_state = 80, .external_lex_state = 47},
  [7663] = {.lex_state = 32},
  [7664] = {.lex_state = 79, .external_lex_state = 49},
  [7665] = {.lex_state = 87, .external_lex_state = 46},
  [7666] = {.lex_state = 97, .external_lex_state = 39},
  [7667] = {.lex_state = 80, .external_lex_state = 47},
  [7668] = {.lex_state = 87, .external_lex_state = 46},
  [7669] = {.lex_state = 87, .external_lex_state = 46},
  [7670] = {.lex_state = 87, .external_lex_state = 46},
  [7671] = {.lex_state = 90, .external_lex_state = 29},
  [7672] = {.lex_state = 88, .external_lex_state = 50},
  [7673] = {.lex_state = 32},
  [7674] = {.lex_state = 95, .external_lex_state = 30},
  [7675] = {.lex_state = 96, .external_lex_state = 43},
  [7676] = {.lex_state = 87, .external_lex_state = 45},
  [7677] = {.lex_state = 89, .external_lex_state = 35},
  [7678] = {.lex_state = 32},
  [7679] = {.lex_state = 87, .external_lex_state = 45},
  [7680] = {.lex_state = 79, .external_lex_state = 27},
  [7681] = {.lex_state = 87, .external_lex_state = 46},
  [7682] = {.lex_state = 87, .external_lex_state = 46},
  [7683] = {.lex_state = 88, .external_lex_state = 26},
  [7684] = {.lex_state = 79, .external_lex_state = 49},
  [7685] = {.lex_state = 88, .external_lex_state = 26},
  [7686] = {.lex_state = 78, .external_lex_state = 50},
  [7687] = {.lex_state = 96, .external_lex_state = 49},
  [7688] = {.lex_state = 32},
  [7689] = {.lex_state = 80, .external_lex_state = 28},
  [7690] = {.lex_state = 97, .external_lex_state = 29},
  [7691] = {.lex_state = 94, .external_lex_state = 43},
  [7692] = {.lex_state = 79, .external_lex_state = 27},
  [7693] = {.lex_state = 87, .external_lex_state = 45},
  [7694] = {.lex_state = 88, .external_lex_state = 26},
  [7695] = {.lex_state = 89, .external_lex_state = 35},
  [7696] = {.lex_state = 32},
  [7697] = {.lex_state = 85, .external_lex_state = 49},
  [7698] = {.lex_state = 78, .external_lex_state = 27},
  [7699] = {.lex_state = 88, .external_lex_state = 28},
  [7700] = {.lex_state = 85, .external_lex_state = 49},
  [7701] = {.lex_state = 32},
  [7702] = {.lex_state = 95, .external_lex_state = 34},
  [7703] = {.lex_state = 87, .external_lex_state = 42},
  [7704] = {.lex_state = 94, .external_lex_state = 43},
  [7705] = {.lex_state = 85, .external_lex_state = 49},
  [7706] = {.lex_state = 32},
  [7707] = {.lex_state = 87, .external_lex_state = 45},
  [7708] = {.lex_state = 78, .external_lex_state = 32},
  [7709] = {.lex_state = 87, .external_lex_state = 46},
  [7710] = {.lex_state = 87, .external_lex_state = 45},
  [7711] = {.lex_state = 87, .external_lex_state = 45},
  [7712] = {.lex_state = 87, .external_lex_state = 46},
  [7713] = {.lex_state = 78, .external_lex_state = 33},
  [7714] = {.lex_state = 88, .external_lex_state = 32},
  [7715] = {.lex_state = 87, .external_lex_state = 46},
  [7716] = {.lex_state = 79, .external_lex_state = 27},
  [7717] = {.lex_state = 96, .external_lex_state = 36},
  [7718] = {.lex_state = 32},
  [7719] = {.lex_state = 79, .external_lex_state = 27},
  [7720] = {.lex_state = 87, .external_lex_state = 45},
  [7721] = {.lex_state = 88, .external_lex_state = 32},
  [7722] = {.lex_state = 95, .external_lex_state = 30},
  [7723] = {.lex_state = 79, .external_lex_state = 27},
  [7724] = {.lex_state = 32},
  [7725] = {.lex_state = 87, .external_lex_state = 46},
  [7726] = {.lex_state = 96, .external_lex_state = 36},
  [7727] = {.lex_state = 87, .external_lex_state = 46},
  [7728] = {.lex_state = 97, .external_lex_state = 38},
  [7729] = {.lex_state = 78, .external_lex_state = 27},
  [7730] = {.lex_state = 87, .external_lex_state = 53},
  [7731] = {.lex_state = 75, .external_lex_state = 45},
  [7732] = {.lex_state = 79, .external_lex_state = 27},
  [7733] = {.lex_state = 87, .external_lex_state = 45},
  [7734] = {.lex_state = 87, .external_lex_state = 45},
  [7735] = {.lex_state = 5},
  [7736] = {.lex_state = 7},
  [7737] = {.lex_state = 32},
  [7738] = {.lex_state = 88, .external_lex_state = 26},
  [7739] = {.lex_state = 87, .external_lex_state = 45},
  [7740] = {.lex_state = 94, .external_lex_state = 26},
  [7741] = {.lex_state = 87, .external_lex_state = 46},
  [7742] = {.lex_state = 87, .external_lex_state = 46},
  [7743] = {.lex_state = 78, .external_lex_state = 32},
  [7744] = {.lex_state = 32},
  [7745] = {.lex_state = 95, .external_lex_state = 30},
  [7746] = {.lex_state = 86, .external_lex_state = 48},
  [7747] = {.lex_state = 78, .external_lex_state = 32},
  [7748] = {.lex_state = 86, .external_lex_state = 48},
  [7749] = {.lex_state = 81, .external_lex_state = 35},
  [7750] = {.lex_state = 34},
  [7751] = {.lex_state = 32},
  [7752] = {.lex_state = 78, .external_lex_state = 27},
  [7753] = {.lex_state = 12, .external_lex_state = 49},
  [7754] = {.lex_state = 78, .external_lex_state = 32},
  [7755] = {.lex_state = 87, .external_lex_state = 30},
  [7756] = {.lex_state = 79, .external_lex_state = 27},
  [7757] = {.lex_state = 96, .external_lex_state = 44},
  [7758] = {.lex_state = 81, .external_lex_state = 35},
  [7759] = {.lex_state = 86, .external_lex_state = 48},
  [7760] = {.lex_state = 88, .external_lex_state = 28},
  [7761] = {.lex_state = 87, .external_lex_state = 45},
  [7762] = {.lex_state = 87, .external_lex_state = 46},
  [7763] = {.lex_state = 87, .external_lex_state = 46},
  [7764] = {.lex_state = 86, .external_lex_state = 26},
  [7765] = {.lex_state = 80, .external_lex_state = 33},
  [7766] = {.lex_state = 81, .external_lex_state = 35},
  [7767] = {.lex_state = 87, .external_lex_state = 45},
  [7768] = {.lex_state = 93, .external_lex_state = 50},
  [7769] = {.lex_state = 79, .external_lex_state = 28},
  [7770] = {.lex_state = 87, .external_lex_state = 42},
  [7771] = {.lex_state = 95, .external_lex_state = 30},
  [7772] = {.lex_state = 95, .external_lex_state = 34},
  [7773] = {.lex_state = 41, .external_lex_state = 49},
  [7774] = {.lex_state = 80, .external_lex_state = 28},
  [7775] = {.lex_state = 80, .external_lex_state = 28},
  [7776] = {.lex_state = 85, .external_lex_state = 33},
  [7777] = {.lex_state = 80, .external_lex_state = 32},
  [7778] = {.lex_state = 32},
  [7779] = {.lex_state = 87, .external_lex_state = 45},
  [7780] = {.lex_state = 80, .external_lex_state = 33},
  [7781] = {.lex_state = 75},
  [7782] = {.lex_state = 87, .external_lex_state = 46},
  [7783] = {.lex_state = 32},
  [7784] = {.lex_state = 80, .external_lex_state = 28},
  [7785] = {.lex_state = 87, .external_lex_state = 46},
  [7786] = {.lex_state = 32},
  [7787] = {.lex_state = 87, .external_lex_state = 55},
  [7788] = {.lex_state = 87, .external_lex_state = 55},
  [7789] = {.lex_state = 32},
  [7790] = {.lex_state = 87, .external_lex_state = 23},
  [7791] = {.lex_state = 11, .external_lex_state = 49},
  [7792] = {.lex_state = 80, .external_lex_state = 33},
  [7793] = {.lex_state = 83, .external_lex_state = 35},
  [7794] = {.lex_state = 95, .external_lex_state = 34},
  [7795] = {.lex_state = 96, .external_lex_state = 37},
  [7796] = {.lex_state = 90, .external_lex_state = 34},
  [7797] = {.lex_state = 75, .external_lex_state = 57},
  [7798] = {.lex_state = 87, .external_lex_state = 46},
  [7799] = {.lex_state = 95, .external_lex_state = 45},
  [7800] = {.lex_state = 95, .external_lex_state = 34},
  [7801] = {.lex_state = 87, .external_lex_state = 40},
  [7802] = {.lex_state = 95, .external_lex_state = 34},
  [7803] = {.lex_state = 87, .external_lex_state = 45},
  [7804] = {.lex_state = 87, .external_lex_state = 45},
  [7805] = {.lex_state = 96, .external_lex_state = 37},
  [7806] = {.lex_state = 75, .external_lex_state = 58},
  [7807] = {.lex_state = 32},
  [7808] = {.lex_state = 83, .external_lex_state = 35},
  [7809] = {.lex_state = 97, .external_lex_state = 29},
  [7810] = {.lex_state = 87, .external_lex_state = 46},
  [7811] = {.lex_state = 87, .external_lex_state = 46},
  [7812] = {.lex_state = 81, .external_lex_state = 35},
  [7813] = {.lex_state = 32},
  [7814] = {.lex_state = 97, .external_lex_state = 29},
  [7815] = {.lex_state = 32},
  [7816] = {.lex_state = 83, .external_lex_state = 35},
  [7817] = {.lex_state = 87, .external_lex_state = 46},
  [7818] = {.lex_state = 81, .external_lex_state = 35},
  [7819] = {.lex_state = 83, .external_lex_state = 50},
  [7820] = {.lex_state = 28, .external_lex_state = 49},
  [7821] = {.lex_state = 81, .external_lex_state = 35},
  [7822] = {.lex_state = 87, .external_lex_state = 43},
  [7823] = {.lex_state = 87, .external_lex_state = 46},
  [7824] = {.lex_state = 87, .external_lex_state = 46},
  [7825] = {.lex_state = 85, .external_lex_state = 32},
  [7826] = {.lex_state = 87, .external_lex_state = 23},
  [7827] = {.lex_state = 97, .external_lex_state = 29},
  [7828] = {.lex_state = 85, .external_lex_state = 50},
  [7829] = {.lex_state = 87, .external_lex_state = 46},
  [7830] = {.lex_state = 75, .external_lex_state = 57},
  [7831] = {.lex_state = 97, .external_lex_state = 29},
  [7832] = {.lex_state = 97, .external_lex_state = 29},
  [7833] = {.lex_state = 32},
  [7834] = {.lex_state = 87, .external_lex_state = 43},
  [7835] = {.lex_state = 97, .external_lex_state = 29},
  [7836] = {.lex_state = 45, .external_lex_state = 49},
  [7837] = {.lex_state = 32},
  [7838] = {.lex_state = 81, .external_lex_state = 35},
  [7839] = {.lex_state = 81, .external_lex_state = 35},
  [7840] = {.lex_state = 83, .external_lex_state = 50},
  [7841] = {.lex_state = 85, .external_lex_state = 50},
  [7842] = {.lex_state = 87, .external_lex_state = 46},
  [7843] = {.lex_state = 80, .external_lex_state = 48},
  [7844] = {.lex_state = 79, .external_lex_state = 50},
  [7845] = {.lex_state = 87, .external_lex_state = 46},
  [7846] = {.lex_state = 87, .external_lex_state = 46},
  [7847] = {.lex_state = 79, .external_lex_state = 28},
  [7848] = {.lex_state = 87, .external_lex_state = 47},
  [7849] = {.lex_state = 85, .external_lex_state = 50},
  [7850] = {.lex_state = 87, .external_lex_state = 46},
  [7851] = {.lex_state = 80, .external_lex_state = 48},
  [7852] = {.lex_state = 86, .external_lex_state = 26},
  [7853] = {.lex_state = 86, .external_lex_state = 32},
  [7854] = {.lex_state = 96, .external_lex_state = 35},
  [7855] = {.lex_state = 79, .external_lex_state = 28},
  [7856] = {.lex_state = 85, .external_lex_state = 26},
  [7857] = {.lex_state = 92, .external_lex_state = 35},
  [7858] = {.lex_state = 32},
  [7859] = {.lex_state = 86, .external_lex_state = 48},
  [7860] = {.lex_state = 81, .external_lex_state = 35},
  [7861] = {.lex_state = 6},
  [7862] = {.lex_state = 80, .external_lex_state = 32},
  [7863] = {.lex_state = 80, .external_lex_state = 32},
  [7864] = {.lex_state = 85, .external_lex_state = 50},
  [7865] = {.lex_state = 79, .external_lex_state = 27},
  [7866] = {.lex_state = 87, .external_lex_state = 45},
  [7867] = {.lex_state = 81, .external_lex_state = 35},
  [7868] = {.lex_state = 87, .external_lex_state = 23},
  [7869] = {.lex_state = 32},
  [7870] = {.lex_state = 87, .external_lex_state = 40},
  [7871] = {.lex_state = 32},
  [7872] = {.lex_state = 6},
  [7873] = {.lex_state = 97, .external_lex_state = 40},
  [7874] = {.lex_state = 32},
  [7875] = {.lex_state = 96, .external_lex_state = 35},
  [7876] = {.lex_state = 86, .external_lex_state = 26},
  [7877] = {.lex_state = 83, .external_lex_state = 35},
  [7878] = {.lex_state = 79, .external_lex_state = 49},
  [7879] = {.lex_state = 32},
  [7880] = {.lex_state = 87, .external_lex_state = 45},
  [7881] = {.lex_state = 80, .external_lex_state = 50},
  [7882] = {.lex_state = 87, .external_lex_state = 45},
  [7883] = {.lex_state = 85, .external_lex_state = 48},
  [7884] = {.lex_state = 81, .external_lex_state = 50},
  [7885] = {.lex_state = 32},
  [7886] = {.lex_state = 79, .external_lex_state = 27},
  [7887] = {.lex_state = 87, .external_lex_state = 23},
  [7888] = {.lex_state = 87, .external_lex_state = 45},
  [7889] = {.lex_state = 86, .external_lex_state = 26},
  [7890] = {.lex_state = 87, .external_lex_state = 45},
  [7891] = {.lex_state = 32},
  [7892] = {.lex_state = 32},
  [7893] = {.lex_state = 87, .external_lex_state = 23},
  [7894] = {.lex_state = 87, .external_lex_state = 23},
  [7895] = {.lex_state = 87, .external_lex_state = 23},
  [7896] = {.lex_state = 86, .external_lex_state = 50},
  [7897] = {.lex_state = 86, .external_lex_state = 26},
  [7898] = {.lex_state = 80, .external_lex_state = 50},
  [7899] = {.lex_state = 32},
  [7900] = {.lex_state = 75, .external_lex_state = 35},
  [7901] = {.lex_state = 75, .external_lex_state = 56},
  [7902] = {.lex_state = 75, .external_lex_state = 57},
  [7903] = {.lex_state = 32},
  [7904] = {.lex_state = 78, .external_lex_state = 35},
  [7905] = {.lex_state = 6},
  [7906] = {.lex_state = 82, .external_lex_state = 49},
  [7907] = {.lex_state = 6},
  [7908] = {.lex_state = 80, .external_lex_state = 50},
  [7909] = {.lex_state = 75, .external_lex_state = 35},
  [7910] = {.lex_state = 86, .external_lex_state = 33},
  [7911] = {.lex_state = 87, .external_lex_state = 23},
  [7912] = {.lex_state = 7},
  [7913] = {.lex_state = 32},
  [7914] = {.lex_state = 32},
  [7915] = {.lex_state = 75, .external_lex_state = 58},
  [7916] = {.lex_state = 94, .external_lex_state = 42},
  [7917] = {.lex_state = 88, .external_lex_state = 27},
  [7918] = {.lex_state = 5},
  [7919] = {.lex_state = 80, .external_lex_state = 35},
  [7920] = {.lex_state = 80, .external_lex_state = 50},
  [7921] = {.lex_state = 14, .external_lex_state = 49},
  [7922] = {.lex_state = 83, .external_lex_state = 35},
  [7923] = {.lex_state = 12, .external_lex_state = 49},
  [7924] = {.lex_state = 81, .external_lex_state = 50},
  [7925] = {.lex_state = 79, .external_lex_state = 28},
  [7926] = {.lex_state = 79, .external_lex_state = 28},
  [7927] = {.lex_state = 80, .external_lex_state = 50},
  [7928] = {.lex_state = 32},
  [7929] = {.lex_state = 81, .external_lex_state = 50},
  [7930] = {.lex_state = 81, .external_lex_state = 50},
  [7931] = {.lex_state = 79, .external_lex_state = 28},
  [7932] = {.lex_state = 81, .external_lex_state = 50},
  [7933] = {.lex_state = 80, .external_lex_state = 50},
  [7934] = {.lex_state = 79, .external_lex_state = 28},
  [7935] = {.lex_state = 94, .external_lex_state = 48},
  [7936] = {.lex_state = 87, .external_lex_state = 23},
  [7937] = {.lex_state = 79, .external_lex_state = 28},
  [7938] = {.lex_state = 78, .external_lex_state = 32},
  [7939] = {.lex_state = 81, .external_lex_state = 35},
  [7940] = {.lex_state = 80, .external_lex_state = 50},
  [7941] = {.lex_state = 83, .external_lex_state = 35},
  [7942] = {.lex_state = 75},
  [7943] = {.lex_state = 79, .external_lex_state = 28},
  [7944] = {.lex_state = 86, .external_lex_state = 50},
  [7945] = {.lex_state = 32},
  [7946] = {.lex_state = 87},
  [7947] = {.lex_state = 32},
  [7948] = {.lex_state = 80, .external_lex_state = 50},
  [7949] = {.lex_state = 83, .external_lex_state = 35},
  [7950] = {.lex_state = 79, .external_lex_state = 28},
  [7951] = {.lex_state = 79, .external_lex_state = 28},
  [7952] = {.lex_state = 14, .external_lex_state = 49},
  [7953] = {.lex_state = 14, .external_lex_state = 49},
  [7954] = {.lex_state = 75, .external_lex_state = 56},
  [7955] = {.lex_state = 5},
  [7956] = {.lex_state = 81, .external_lex_state = 50},
  [7957] = {.lex_state = 80, .external_lex_state = 50},
  [7958] = {.lex_state = 80, .external_lex_state = 50},
  [7959] = {.lex_state = 80, .external_lex_state = 50},
  [7960] = {.lex_state = 85, .external_lex_state = 32},
  [7961] = {.lex_state = 87, .external_lex_state = 23},
  [7962] = {.lex_state = 79, .external_lex_state = 27},
  [7963] = {.lex_state = 29, .external_lex_state = 49},
  [7964] = {.lex_state = 80, .external_lex_state = 50},
  [7965] = {.lex_state = 92, .external_lex_state = 35},
  [7966] = {.lex_state = 32},
  [7967] = {.lex_state = 94, .external_lex_state = 42},
  [7968] = {.lex_state = 81, .external_lex_state = 50},
  [7969] = {.lex_state = 87, .external_lex_state = 46},
  [7970] = {.lex_state = 87, .external_lex_state = 46},
  [7971] = {.lex_state = 75, .external_lex_state = 58},
  [7972] = {.lex_state = 32},
  [7973] = {.lex_state = 87, .external_lex_state = 45},
  [7974] = {.lex_state = 87, .external_lex_state = 23},
  [7975] = {.lex_state = 81, .external_lex_state = 50},
  [7976] = {.lex_state = 87, .external_lex_state = 39},
  [7977] = {.lex_state = 86, .external_lex_state = 50},
  [7978] = {.lex_state = 29, .external_lex_state = 49},
  [7979] = {.lex_state = 38, .external_lex_state = 49},
  [7980] = {.lex_state = 41, .external_lex_state = 49},
  [7981] = {.lex_state = 81, .external_lex_state = 50},
  [7982] = {.lex_state = 95, .external_lex_state = 30},
  [7983] = {.lex_state = 32},
  [7984] = {.lex_state = 78, .external_lex_state = 33},
  [7985] = {.lex_state = 87},
  [7986] = {.lex_state = 12, .external_lex_state = 49},
  [7987] = {.lex_state = 87, .external_lex_state = 46},
  [7988] = {.lex_state = 81, .external_lex_state = 50},
  [7989] = {.lex_state = 79, .external_lex_state = 50},
  [7990] = {.lex_state = 95, .external_lex_state = 30},
  [7991] = {.lex_state = 32},
  [7992] = {.lex_state = 78, .external_lex_state = 33},
  [7993] = {.lex_state = 75, .external_lex_state = 29},
  [7994] = {.lex_state = 83, .external_lex_state = 35},
  [7995] = {.lex_state = 16, .external_lex_state = 49},
  [7996] = {.lex_state = 81, .external_lex_state = 50},
  [7997] = {.lex_state = 78, .external_lex_state = 33},
  [7998] = {.lex_state = 32},
  [7999] = {.lex_state = 87, .external_lex_state = 45},
  [8000] = {.lex_state = 87, .external_lex_state = 23},
  [8001] = {.lex_state = 78, .external_lex_state = 49},
  [8002] = {.lex_state = 87, .external_lex_state = 45},
  [8003] = {.lex_state = 32},
  [8004] = {.lex_state = 75, .external_lex_state = 29},
  [8005] = {.lex_state = 79, .external_lex_state = 50},
  [8006] = {.lex_state = 79, .external_lex_state = 28},
  [8007] = {.lex_state = 81, .external_lex_state = 50},
  [8008] = {.lex_state = 87, .external_lex_state = 23},
  [8009] = {.lex_state = 83, .external_lex_state = 35},
  [8010] = {.lex_state = 79, .external_lex_state = 50},
  [8011] = {.lex_state = 75, .external_lex_state = 35},
  [8012] = {.lex_state = 87, .external_lex_state = 45},
  [8013] = {.lex_state = 87, .external_lex_state = 45},
  [8014] = {.lex_state = 87, .external_lex_state = 55},
  [8015] = {.lex_state = 95, .external_lex_state = 30},
  [8016] = {.lex_state = 85, .external_lex_state = 33},
  [8017] = {.lex_state = 83, .external_lex_state = 35},
  [8018] = {.lex_state = 86, .external_lex_state = 47},
  [8019] = {.lex_state = 32},
  [8020] = {.lex_state = 32},
  [8021] = {.lex_state = 82, .external_lex_state = 35},
  [8022] = {.lex_state = 78, .external_lex_state = 33},
  [8023] = {.lex_state = 80, .external_lex_state = 27},
  [8024] = {.lex_state = 14, .external_lex_state = 49},
  [8025] = {.lex_state = 75, .external_lex_state = 35},
  [8026] = {.lex_state = 79, .external_lex_state = 50},
  [8027] = {.lex_state = 34},
  [8028] = {.lex_state = 93, .external_lex_state = 35},
  [8029] = {.lex_state = 82, .external_lex_state = 35},
  [8030] = {.lex_state = 80, .external_lex_state = 27},
  [8031] = {.lex_state = 87, .external_lex_state = 23},
  [8032] = {.lex_state = 87, .external_lex_state = 23},
  [8033] = {.lex_state = 83, .external_lex_state = 35},
  [8034] = {.lex_state = 11, .external_lex_state = 49},
  [8035] = {.lex_state = 87, .external_lex_state = 54},
  [8036] = {.lex_state = 75, .external_lex_state = 40},
  [8037] = {.lex_state = 87, .external_lex_state = 51},
  [8038] = {.lex_state = 32},
  [8039] = {.lex_state = 87, .external_lex_state = 51},
  [8040] = {.lex_state = 32},
  [8041] = {.lex_state = 12, .external_lex_state = 49},
  [8042] = {.lex_state = 32},
  [8043] = {.lex_state = 10, .external_lex_state = 49},
  [8044] = {.lex_state = 17},
  [8045] = {.lex_state = 78, .external_lex_state = 33},
  [8046] = {.lex_state = 75, .external_lex_state = 54},
  [8047] = {.lex_state = 80, .external_lex_state = 27},
  [8048] = {.lex_state = 80, .external_lex_state = 26},
  [8049] = {.lex_state = 81, .external_lex_state = 35},
  [8050] = {.lex_state = 32},
  [8051] = {.lex_state = 40, .external_lex_state = 49},
  [8052] = {.lex_state = 11, .external_lex_state = 49},
  [8053] = {.lex_state = 79, .external_lex_state = 27},
  [8054] = {.lex_state = 78, .external_lex_state = 32},
  [8055] = {.lex_state = 80, .external_lex_state = 27},
  [8056] = {.lex_state = 93, .external_lex_state = 35},
  [8057] = {.lex_state = 83, .external_lex_state = 35},
  [8058] = {.lex_state = 80, .external_lex_state = 26},
  [8059] = {.lex_state = 34},
  [8060] = {.lex_state = 87, .external_lex_state = 23},
  [8061] = {.lex_state = 75, .external_lex_state = 38},
  [8062] = {.lex_state = 11, .external_lex_state = 49},
  [8063] = {.lex_state = 32},
  [8064] = {.lex_state = 87, .external_lex_state = 45},
  [8065] = {.lex_state = 97, .external_lex_state = 29},
  [8066] = {.lex_state = 79, .external_lex_state = 27},
  [8067] = {.lex_state = 32},
  [8068] = {.lex_state = 87, .external_lex_state = 23},
  [8069] = {.lex_state = 87, .external_lex_state = 23},
  [8070] = {.lex_state = 11, .external_lex_state = 49},
  [8071] = {.lex_state = 80, .external_lex_state = 27},
  [8072] = {.lex_state = 75, .external_lex_state = 58},
  [8073] = {.lex_state = 93, .external_lex_state = 35},
  [8074] = {.lex_state = 80, .external_lex_state = 27},
  [8075] = {.lex_state = 32},
  [8076] = {.lex_state = 97, .external_lex_state = 29},
  [8077] = {.lex_state = 97, .external_lex_state = 29},
  [8078] = {.lex_state = 87, .external_lex_state = 23},
  [8079] = {.lex_state = 96, .external_lex_state = 35},
  [8080] = {.lex_state = 80, .external_lex_state = 27},
  [8081] = {.lex_state = 11, .external_lex_state = 49},
  [8082] = {.lex_state = 75, .external_lex_state = 53},
  [8083] = {.lex_state = 80, .external_lex_state = 27},
  [8084] = {.lex_state = 87, .external_lex_state = 45},
  [8085] = {.lex_state = 79, .external_lex_state = 49},
  [8086] = {.lex_state = 87, .external_lex_state = 46},
  [8087] = {.lex_state = 32},
  [8088] = {.lex_state = 80, .external_lex_state = 27},
  [8089] = {.lex_state = 87, .external_lex_state = 46},
  [8090] = {.lex_state = 11, .external_lex_state = 49},
  [8091] = {.lex_state = 32},
  [8092] = {.lex_state = 92, .external_lex_state = 50},
  [8093] = {.lex_state = 80, .external_lex_state = 27},
  [8094] = {.lex_state = 78, .external_lex_state = 33},
  [8095] = {.lex_state = 87, .external_lex_state = 46},
  [8096] = {.lex_state = 92, .external_lex_state = 50},
  [8097] = {.lex_state = 79, .external_lex_state = 27},
  [8098] = {.lex_state = 87, .external_lex_state = 46},
  [8099] = {.lex_state = 83, .external_lex_state = 35},
  [8100] = {.lex_state = 79, .external_lex_state = 49},
  [8101] = {.lex_state = 32},
  [8102] = {.lex_state = 81, .external_lex_state = 50},
  [8103] = {.lex_state = 92, .external_lex_state = 50},
  [8104] = {.lex_state = 34},
  [8105] = {.lex_state = 87, .external_lex_state = 46},
  [8106] = {.lex_state = 11, .external_lex_state = 49},
  [8107] = {.lex_state = 6},
  [8108] = {.lex_state = 10, .external_lex_state = 49},
  [8109] = {.lex_state = 86, .external_lex_state = 33},
  [8110] = {.lex_state = 87, .external_lex_state = 45},
  [8111] = {.lex_state = 32},
  [8112] = {.lex_state = 17},
  [8113] = {.lex_state = 11, .external_lex_state = 49},
  [8114] = {.lex_state = 86, .external_lex_state = 32},
  [8115] = {.lex_state = 32},
  [8116] = {.lex_state = 32},
  [8117] = {.lex_state = 96, .external_lex_state = 35},
  [8118] = {.lex_state = 80, .external_lex_state = 27},
  [8119] = {.lex_state = 87, .external_lex_state = 23},
  [8120] = {.lex_state = 6},
  [8121] = {.lex_state = 87, .external_lex_state = 23},
  [8122] = {.lex_state = 77},
  [8123] = {.lex_state = 80, .external_lex_state = 50},
  [8124] = {.lex_state = 96, .external_lex_state = 42},
  [8125] = {.lex_state = 87, .external_lex_state = 23},
  [8126] = {.lex_state = 86, .external_lex_state = 33},
  [8127] = {.lex_state = 87, .external_lex_state = 23},
  [8128] = {.lex_state = 32},
  [8129] = {.lex_state = 32},
  [8130] = {.lex_state = 87, .external_lex_state = 23},
  [8131] = {.lex_state = 34},
  [8132] = {.lex_state = 87, .external_lex_state = 23},
  [8133] = {.lex_state = 7},
  [8134] = {.lex_state = 87, .external_lex_state = 23},
  [8135] = {.lex_state = 87, .external_lex_state = 44},
  [8136] = {.lex_state = 87, .external_lex_state = 54},
  [8137] = {.lex_state = 32},
  [8138] = {.lex_state = 32},
  [8139] = {.lex_state = 87, .external_lex_state = 45},
  [8140] = {.lex_state = 87, .external_lex_state = 45},
  [8141] = {.lex_state = 81, .external_lex_state = 35},
  [8142] = {.lex_state = 32},
  [8143] = {.lex_state = 87, .external_lex_state = 38},
  [8144] = {.lex_state = 87, .external_lex_state = 45},
  [8145] = {.lex_state = 32},
  [8146] = {.lex_state = 87, .external_lex_state = 45},
  [8147] = {.lex_state = 80, .external_lex_state = 32},
  [8148] = {.lex_state = 32},
  [8149] = {.lex_state = 87, .external_lex_state = 45},
  [8150] = {.lex_state = 75, .external_lex_state = 29},
  [8151] = {.lex_state = 78, .external_lex_state = 33},
  [8152] = {.lex_state = 32},
  [8153] = {.lex_state = 88, .external_lex_state = 33},
  [8154] = {.lex_state = 88, .external_lex_state = 33},
  [8155] = {.lex_state = 32},
  [8156] = {.lex_state = 83, .external_lex_state = 35},
  [8157] = {.lex_state = 5},
  [8158] = {.lex_state = 87, .external_lex_state = 45},
  [8159] = {.lex_state = 87, .external_lex_state = 45},
  [8160] = {.lex_state = 32},
  [8161] = {.lex_state = 6},
  [8162] = {.lex_state = 87, .external_lex_state = 23},
  [8163] = {.lex_state = 87, .external_lex_state = 23},
  [8164] = {.lex_state = 87, .external_lex_state = 23},
  [8165] = {.lex_state = 81, .external_lex_state = 35},
  [8166] = {.lex_state = 6},
  [8167] = {.lex_state = 87, .external_lex_state = 45},
  [8168] = {.lex_state = 87, .external_lex_state = 39},
  [8169] = {.lex_state = 87, .external_lex_state = 23},
  [8170] = {.lex_state = 94, .external_lex_state = 47},
  [8171] = {.lex_state = 79, .external_lex_state = 49},
  [8172] = {.lex_state = 87, .external_lex_state = 53},
  [8173] = {.lex_state = 17},
  [8174] = {.lex_state = 87, .external_lex_state = 51},
  [8175] = {.lex_state = 87, .external_lex_state = 23},
  [8176] = {.lex_state = 5},
  [8177] = {.lex_state = 87, .external_lex_state = 45},
  [8178] = {.lex_state = 79, .external_lex_state = 50},
  [8179] = {.lex_state = 78, .external_lex_state = 35},
  [8180] = {.lex_state = 87, .external_lex_state = 44},
  [8181] = {.lex_state = 86, .external_lex_state = 52},
  [8182] = {.lex_state = 79, .external_lex_state = 49},
  [8183] = {.lex_state = 78, .external_lex_state = 33},
  [8184] = {.lex_state = 80, .external_lex_state = 27},
  [8185] = {.lex_state = 95, .external_lex_state = 30},
  [8186] = {.lex_state = 34},
  [8187] = {.lex_state = 87, .external_lex_state = 45},
  [8188] = {.lex_state = 5},
  [8189] = {.lex_state = 75, .external_lex_state = 24},
  [8190] = {.lex_state = 86, .external_lex_state = 52},
  [8191] = {.lex_state = 32},
  [8192] = {.lex_state = 87, .external_lex_state = 23},
  [8193] = {.lex_state = 75, .external_lex_state = 54},
  [8194] = {.lex_state = 87, .external_lex_state = 45},
  [8195] = {.lex_state = 5},
  [8196] = {.lex_state = 75, .external_lex_state = 53},
  [8197] = {.lex_state = 87, .external_lex_state = 23},
  [8198] = {.lex_state = 75, .external_lex_state = 23},
  [8199] = {.lex_state = 86, .external_lex_state = 52},
  [8200] = {.lex_state = 11, .external_lex_state = 49},
  [8201] = {.lex_state = 87, .external_lex_state = 23},
  [8202] = {.lex_state = 92, .external_lex_state = 50},
  [8203] = {.lex_state = 87, .external_lex_state = 55},
  [8204] = {.lex_state = 86, .external_lex_state = 52},
  [8205] = {.lex_state = 78, .external_lex_state = 33},
  [8206] = {.lex_state = 87, .external_lex_state = 23},
  [8207] = {.lex_state = 87, .external_lex_state = 38},
  [8208] = {.lex_state = 87, .external_lex_state = 23},
  [8209] = {.lex_state = 32},
  [8210] = {.lex_state = 85, .external_lex_state = 27},
  [8211] = {.lex_state = 78, .external_lex_state = 32},
  [8212] = {.lex_state = 81, .external_lex_state = 49},
  [8213] = {.lex_state = 75, .external_lex_state = 40},
  [8214] = {.lex_state = 87, .external_lex_state = 23},
  [8215] = {.lex_state = 32},
  [8216] = {.lex_state = 88, .external_lex_state = 41},
  [8217] = {.lex_state = 79, .external_lex_state = 27},
  [8218] = {.lex_state = 32},
  [8219] = {.lex_state = 85, .external_lex_state = 35},
  [8220] = {.lex_state = 87, .external_lex_state = 23},
  [8221] = {.lex_state = 95, .external_lex_state = 30},
  [8222] = {.lex_state = 87, .external_lex_state = 51},
  [8223] = {.lex_state = 85, .external_lex_state = 35},
  [8224] = {.lex_state = 78, .external_lex_state = 33},
  [8225] = {.lex_state = 79, .external_lex_state = 28},
  [8226] = {.lex_state = 75, .external_lex_state = 23},
  [8227] = {.lex_state = 85, .external_lex_state = 27},
  [8228] = {.lex_state = 78, .external_lex_state = 33},
  [8229] = {.lex_state = 86, .external_lex_state = 48},
  [8230] = {.lex_state = 88, .external_lex_state = 42},
  [8231] = {.lex_state = 93, .external_lex_state = 35},
  [8232] = {.lex_state = 6},
  [8233] = {.lex_state = 85, .external_lex_state = 27},
  [8234] = {.lex_state = 6},
  [8235] = {.lex_state = 78, .external_lex_state = 33},
  [8236] = {.lex_state = 87, .external_lex_state = 23},
  [8237] = {.lex_state = 88, .external_lex_state = 27},
  [8238] = {.lex_state = 89, .external_lex_state = 50},
  [8239] = {.lex_state = 80, .external_lex_state = 33},
  [8240] = {.lex_state = 32},
  [8241] = {.lex_state = 75, .external_lex_state = 38},
  [8242] = {.lex_state = 89, .external_lex_state = 50},
  [8243] = {.lex_state = 80, .external_lex_state = 27},
  [8244] = {.lex_state = 32},
  [8245] = {.lex_state = 32},
  [8246] = {.lex_state = 85, .external_lex_state = 52},
  [8247] = {.lex_state = 86, .external_lex_state = 47},
  [8248] = {.lex_state = 86, .external_lex_state = 47},
  [8249] = {.lex_state = 78, .external_lex_state = 33},
  [8250] = {.lex_state = 96, .external_lex_state = 41},
  [8251] = {.lex_state = 87, .external_lex_state = 46},
  [8252] = {.lex_state = 87, .external_lex_state = 23},
  [8253] = {.lex_state = 86, .external_lex_state = 47},
  [8254] = {.lex_state = 83, .external_lex_state = 35},
  [8255] = {.lex_state = 87, .external_lex_state = 23},
  [8256] = {.lex_state = 32},
  [8257] = {.lex_state = 94, .external_lex_state = 52},
  [8258] = {.lex_state = 87, .external_lex_state = 46},
  [8259] = {.lex_state = 87, .external_lex_state = 46},
  [8260] = {.lex_state = 87, .external_lex_state = 23},
  [8261] = {.lex_state = 87, .external_lex_state = 23},
  [8262] = {.lex_state = 87, .external_lex_state = 23},
  [8263] = {.lex_state = 32},
  [8264] = {.lex_state = 34},
  [8265] = {.lex_state = 81, .external_lex_state = 35},
  [8266] = {.lex_state = 87, .external_lex_state = 23},
  [8267] = {.lex_state = 78, .external_lex_state = 32},
  [8268] = {.lex_state = 78, .external_lex_state = 32},
  [8269] = {.lex_state = 78, .external_lex_state = 32},
  [8270] = {.lex_state = 75, .external_lex_state = 58},
  [8271] = {.lex_state = 87, .external_lex_state = 48},
  [8272] = {.lex_state = 85, .external_lex_state = 47},
  [8273] = {.lex_state = 78, .external_lex_state = 32},
  [8274] = {.lex_state = 87, .external_lex_state = 23},
  [8275] = {.lex_state = 79, .external_lex_state = 27},
  [8276] = {.lex_state = 78, .external_lex_state = 32},
  [8277] = {.lex_state = 85, .external_lex_state = 27},
  [8278] = {.lex_state = 32},
  [8279] = {.lex_state = 78, .external_lex_state = 32},
  [8280] = {.lex_state = 87, .external_lex_state = 23},
  [8281] = {.lex_state = 78, .external_lex_state = 32},
  [8282] = {.lex_state = 87, .external_lex_state = 53},
  [8283] = {.lex_state = 80, .external_lex_state = 32},
  [8284] = {.lex_state = 14, .external_lex_state = 49},
  [8285] = {.lex_state = 79, .external_lex_state = 32},
  [8286] = {.lex_state = 17},
  [8287] = {.lex_state = 26},
  [8288] = {.lex_state = 75, .external_lex_state = 39},
  [8289] = {.lex_state = 12, .external_lex_state = 49},
  [8290] = {.lex_state = 12, .external_lex_state = 49},
  [8291] = {.lex_state = 94, .external_lex_state = 49},
  [8292] = {.lex_state = 87, .external_lex_state = 48},
  [8293] = {.lex_state = 87, .external_lex_state = 26},
  [8294] = {.lex_state = 87, .external_lex_state = 51},
  [8295] = {.lex_state = 87, .external_lex_state = 58},
  [8296] = {.lex_state = 87, .external_lex_state = 55},
  [8297] = {.lex_state = 86, .external_lex_state = 49},
  [8298] = {.lex_state = 87, .external_lex_state = 29},
  [8299] = {.lex_state = 97, .external_lex_state = 30},
  [8300] = {.lex_state = 87, .external_lex_state = 52},
  [8301] = {.lex_state = 17},
  [8302] = {.lex_state = 87, .external_lex_state = 54},
  [8303] = {.lex_state = 87, .external_lex_state = 46},
  [8304] = {.lex_state = 79, .external_lex_state = 33},
  [8305] = {.lex_state = 87, .external_lex_state = 48},
  [8306] = {.lex_state = 87, .external_lex_state = 51},
  [8307] = {.lex_state = 87, .external_lex_state = 51},
  [8308] = {.lex_state = 14, .external_lex_state = 49},
  [8309] = {.lex_state = 78, .external_lex_state = 32},
  [8310] = {.lex_state = 86, .external_lex_state = 49},
  [8311] = {.lex_state = 87, .external_lex_state = 27},
  [8312] = {.lex_state = 86, .external_lex_state = 49},
  [8313] = {.lex_state = 87, .external_lex_state = 51},
  [8314] = {.lex_state = 79, .external_lex_state = 33},
  [8315] = {.lex_state = 81, .external_lex_state = 49},
  [8316] = {.lex_state = 34},
  [8317] = {.lex_state = 96, .external_lex_state = 41},
  [8318] = {.lex_state = 28, .external_lex_state = 49},
  [8319] = {.lex_state = 87, .external_lex_state = 51},
  [8320] = {.lex_state = 28, .external_lex_state = 49},
  [8321] = {.lex_state = 4},
  [8322] = {.lex_state = 75, .external_lex_state = 49},
  [8323] = {.lex_state = 87, .external_lex_state = 54},
  [8324] = {.lex_state = 87, .external_lex_state = 51},
  [8325] = {.lex_state = 79, .external_lex_state = 33},
  [8326] = {.lex_state = 99, .external_lex_state = 35},
  [8327] = {.lex_state = 28, .external_lex_state = 49},
  [8328] = {.lex_state = 87, .external_lex_state = 40},
  [8329] = {.lex_state = 87, .external_lex_state = 54},
  [8330] = {.lex_state = 12, .external_lex_state = 49},
  [8331] = {.lex_state = 88, .external_lex_state = 50},
  [8332] = {.lex_state = 94, .external_lex_state = 52},
  [8333] = {.lex_state = 87, .external_lex_state = 26},
  [8334] = {.lex_state = 87, .external_lex_state = 54},
  [8335] = {.lex_state = 87, .external_lex_state = 54},
  [8336] = {.lex_state = 90, .external_lex_state = 38},
  [8337] = {.lex_state = 87, .external_lex_state = 53},
  [8338] = {.lex_state = 87, .external_lex_state = 51},
  [8339] = {.lex_state = 96, .external_lex_state = 41},
  [8340] = {.lex_state = 87, .external_lex_state = 53},
  [8341] = {.lex_state = 85, .external_lex_state = 33},
  [8342] = {.lex_state = 87, .external_lex_state = 53},
  [8343] = {.lex_state = 78, .external_lex_state = 32},
  [8344] = {.lex_state = 95, .external_lex_state = 51},
  [8345] = {.lex_state = 88, .external_lex_state = 35},
  [8346] = {.lex_state = 75, .external_lex_state = 24},
  [8347] = {.lex_state = 87, .external_lex_state = 54},
  [8348] = {.lex_state = 12, .external_lex_state = 49},
  [8349] = {.lex_state = 87, .external_lex_state = 53},
  [8350] = {.lex_state = 86, .external_lex_state = 49},
  [8351] = {.lex_state = 99, .external_lex_state = 49},
  [8352] = {.lex_state = 87, .external_lex_state = 54},
  [8353] = {.lex_state = 81, .external_lex_state = 35},
  [8354] = {.lex_state = 88, .external_lex_state = 28},
  [8355] = {.lex_state = 88, .external_lex_state = 28},
  [8356] = {.lex_state = 87, .external_lex_state = 53},
  [8357] = {.lex_state = 14, .external_lex_state = 49},
  [8358] = {.lex_state = 80, .external_lex_state = 35},
  [8359] = {.lex_state = 87, .external_lex_state = 29},
  [8360] = {.lex_state = 87, .external_lex_state = 53},
  [8361] = {.lex_state = 94, .external_lex_state = 50},
  [8362] = {.lex_state = 87, .external_lex_state = 51},
  [8363] = {.lex_state = 87, .external_lex_state = 53},
  [8364] = {.lex_state = 12, .external_lex_state = 49},
  [8365] = {.lex_state = 88, .external_lex_state = 28},
  [8366] = {.lex_state = 75},
  [8367] = {.lex_state = 88, .external_lex_state = 28},
  [8368] = {.lex_state = 87, .external_lex_state = 54},
  [8369] = {.lex_state = 87, .external_lex_state = 55},
  [8370] = {.lex_state = 87, .external_lex_state = 55},
  [8371] = {.lex_state = 80, .external_lex_state = 33},
  [8372] = {.lex_state = 87, .external_lex_state = 55},
  [8373] = {.lex_state = 87, .external_lex_state = 55},
  [8374] = {.lex_state = 90, .external_lex_state = 29},
  [8375] = {.lex_state = 79, .external_lex_state = 32},
  [8376] = {.lex_state = 78, .external_lex_state = 33},
  [8377] = {.lex_state = 80, .external_lex_state = 32},
  [8378] = {.lex_state = 14, .external_lex_state = 49},
  [8379] = {.lex_state = 80, .external_lex_state = 35},
  [8380] = {.lex_state = 81, .external_lex_state = 35},
  [8381] = {.lex_state = 87, .external_lex_state = 54},
  [8382] = {.lex_state = 87, .external_lex_state = 28},
  [8383] = {.lex_state = 87, .external_lex_state = 54},
  [8384] = {.lex_state = 87, .external_lex_state = 54},
  [8385] = {.lex_state = 87, .external_lex_state = 54},
  [8386] = {.lex_state = 12, .external_lex_state = 49},
  [8387] = {.lex_state = 81, .external_lex_state = 35},
  [8388] = {.lex_state = 87, .external_lex_state = 53},
  [8389] = {.lex_state = 14, .external_lex_state = 49},
  [8390] = {.lex_state = 26},
  [8391] = {.lex_state = 87, .external_lex_state = 54},
  [8392] = {.lex_state = 87, .external_lex_state = 54},
  [8393] = {.lex_state = 97, .external_lex_state = 23},
  [8394] = {.lex_state = 94, .external_lex_state = 52},
  [8395] = {.lex_state = 86, .external_lex_state = 50},
  [8396] = {.lex_state = 81, .external_lex_state = 49},
  [8397] = {.lex_state = 87, .external_lex_state = 55},
  [8398] = {.lex_state = 87, .external_lex_state = 55},
  [8399] = {.lex_state = 87, .external_lex_state = 55},
  [8400] = {.lex_state = 87, .external_lex_state = 55},
  [8401] = {.lex_state = 80, .external_lex_state = 33},
  [8402] = {.lex_state = 86, .external_lex_state = 35},
  [8403] = {.lex_state = 87, .external_lex_state = 52},
  [8404] = {.lex_state = 87, .external_lex_state = 51},
  [8405] = {.lex_state = 95, .external_lex_state = 40},
  [8406] = {.lex_state = 86, .external_lex_state = 35},
  [8407] = {.lex_state = 80, .external_lex_state = 32},
  [8408] = {.lex_state = 87, .external_lex_state = 47},
  [8409] = {.lex_state = 75, .external_lex_state = 34},
  [8410] = {.lex_state = 87, .external_lex_state = 53},
  [8411] = {.lex_state = 80, .external_lex_state = 32},
  [8412] = {.lex_state = 93, .external_lex_state = 50},
  [8413] = {.lex_state = 80, .external_lex_state = 32},
  [8414] = {.lex_state = 87, .external_lex_state = 53},
  [8415] = {.lex_state = 87, .external_lex_state = 53},
  [8416] = {.lex_state = 17},
  [8417] = {.lex_state = 80, .external_lex_state = 33},
  [8418] = {.lex_state = 75, .external_lex_state = 49},
  [8419] = {.lex_state = 87, .external_lex_state = 54},
  [8420] = {.lex_state = 87, .external_lex_state = 55},
  [8421] = {.lex_state = 14, .external_lex_state = 49},
  [8422] = {.lex_state = 96, .external_lex_state = 26},
  [8423] = {.lex_state = 87, .external_lex_state = 55},
  [8424] = {.lex_state = 87, .external_lex_state = 51},
  [8425] = {.lex_state = 86, .external_lex_state = 35},
  [8426] = {.lex_state = 87, .external_lex_state = 53},
  [8427] = {.lex_state = 87, .external_lex_state = 55},
  [8428] = {.lex_state = 79, .external_lex_state = 33},
  [8429] = {.lex_state = 87, .external_lex_state = 51},
  [8430] = {.lex_state = 87, .external_lex_state = 53},
  [8431] = {.lex_state = 87, .external_lex_state = 54},
  [8432] = {.lex_state = 14, .external_lex_state = 49},
  [8433] = {.lex_state = 87, .external_lex_state = 51},
  [8434] = {.lex_state = 87, .external_lex_state = 51},
  [8435] = {.lex_state = 14, .external_lex_state = 49},
  [8436] = {.lex_state = 87, .external_lex_state = 55},
  [8437] = {.lex_state = 87, .external_lex_state = 55},
  [8438] = {.lex_state = 80, .external_lex_state = 33},
  [8439] = {.lex_state = 87, .external_lex_state = 55},
  [8440] = {.lex_state = 87, .external_lex_state = 55},
  [8441] = {.lex_state = 95, .external_lex_state = 39},
  [8442] = {.lex_state = 87, .external_lex_state = 55},
  [8443] = {.lex_state = 87, .external_lex_state = 55},
  [8444] = {.lex_state = 14, .external_lex_state = 49},
  [8445] = {.lex_state = 80, .external_lex_state = 33},
  [8446] = {.lex_state = 87, .external_lex_state = 51},
  [8447] = {.lex_state = 87, .external_lex_state = 51},
  [8448] = {.lex_state = 87, .external_lex_state = 55},
  [8449] = {.lex_state = 14, .external_lex_state = 49},
  [8450] = {.lex_state = 87, .external_lex_state = 53},
  [8451] = {.lex_state = 88, .external_lex_state = 32},
  [8452] = {.lex_state = 88, .external_lex_state = 35},
  [8453] = {.lex_state = 80, .external_lex_state = 33},
  [8454] = {.lex_state = 95, .external_lex_state = 39},
  [8455] = {.lex_state = 95, .external_lex_state = 39},
  [8456] = {.lex_state = 96, .external_lex_state = 44},
  [8457] = {.lex_state = 97, .external_lex_state = 30},
  [8458] = {.lex_state = 87, .external_lex_state = 55},
  [8459] = {.lex_state = 87, .external_lex_state = 51},
  [8460] = {.lex_state = 87, .external_lex_state = 51},
  [8461] = {.lex_state = 75, .external_lex_state = 30},
  [8462] = {.lex_state = 87, .external_lex_state = 55},
  [8463] = {.lex_state = 95, .external_lex_state = 40},
  [8464] = {.lex_state = 87, .external_lex_state = 55},
  [8465] = {.lex_state = 12, .external_lex_state = 49},
  [8466] = {.lex_state = 80, .external_lex_state = 33},
  [8467] = {.lex_state = 94, .external_lex_state = 47},
  [8468] = {.lex_state = 87, .external_lex_state = 54},
  [8469] = {.lex_state = 12, .external_lex_state = 49},
  [8470] = {.lex_state = 95, .external_lex_state = 40},
  [8471] = {.lex_state = 87, .external_lex_state = 51},
  [8472] = {.lex_state = 89, .external_lex_state = 35},
  [8473] = {.lex_state = 87, .external_lex_state = 55},
  [8474] = {.lex_state = 86, .external_lex_state = 27},
  [8475] = {.lex_state = 79, .external_lex_state = 32},
  [8476] = {.lex_state = 86, .external_lex_state = 28},
  [8477] = {.lex_state = 87, .external_lex_state = 55},
  [8478] = {.lex_state = 93, .external_lex_state = 35},
  [8479] = {.lex_state = 87, .external_lex_state = 51},
  [8480] = {.lex_state = 87, .external_lex_state = 53},
  [8481] = {.lex_state = 75, .external_lex_state = 23},
  [8482] = {.lex_state = 26},
  [8483] = {.lex_state = 17},
  [8484] = {.lex_state = 87, .external_lex_state = 55},
  [8485] = {.lex_state = 87, .external_lex_state = 54},
  [8486] = {.lex_state = 75, .external_lex_state = 55},
  [8487] = {.lex_state = 93, .external_lex_state = 35},
  [8488] = {.lex_state = 95, .external_lex_state = 40},
  [8489] = {.lex_state = 14, .external_lex_state = 49},
  [8490] = {.lex_state = 75, .external_lex_state = 30},
  [8491] = {.lex_state = 26},
  [8492] = {.lex_state = 95, .external_lex_state = 38},
  [8493] = {.lex_state = 87, .external_lex_state = 55},
  [8494] = {.lex_state = 78, .external_lex_state = 35},
  [8495] = {.lex_state = 87, .external_lex_state = 54},
  [8496] = {.lex_state = 30, .external_lex_state = 49},
  [8497] = {.lex_state = 94, .external_lex_state = 27},
  [8498] = {.lex_state = 87, .external_lex_state = 23},
  [8499] = {.lex_state = 26},
  [8500] = {.lex_state = 90, .external_lex_state = 39},
  [8501] = {.lex_state = 78, .external_lex_state = 35},
  [8502] = {.lex_state = 75, .external_lex_state = 38},
  [8503] = {.lex_state = 82, .external_lex_state = 49},
  [8504] = {.lex_state = 85, .external_lex_state = 27},
  [8505] = {.lex_state = 97, .external_lex_state = 34},
  [8506] = {.lex_state = 87, .external_lex_state = 51},
  [8507] = {.lex_state = 97, .external_lex_state = 34},
  [8508] = {.lex_state = 87, .external_lex_state = 51},
  [8509] = {.lex_state = 89, .external_lex_state = 35},
  [8510] = {.lex_state = 79, .external_lex_state = 33},
  [8511] = {.lex_state = 97, .external_lex_state = 34},
  [8512] = {.lex_state = 96, .external_lex_state = 44},
  [8513] = {.lex_state = 12, .external_lex_state = 49},
  [8514] = {.lex_state = 79, .external_lex_state = 32},
  [8515] = {.lex_state = 97, .external_lex_state = 34},
  [8516] = {.lex_state = 88, .external_lex_state = 26},
  [8517] = {.lex_state = 75, .external_lex_state = 34},
  [8518] = {.lex_state = 95, .external_lex_state = 38},
  [8519] = {.lex_state = 93, .external_lex_state = 35},
  [8520] = {.lex_state = 95, .external_lex_state = 40},
  [8521] = {.lex_state = 79, .external_lex_state = 32},
  [8522] = {.lex_state = 26},
  [8523] = {.lex_state = 81, .external_lex_state = 35},
  [8524] = {.lex_state = 95, .external_lex_state = 38},
  [8525] = {.lex_state = 95, .external_lex_state = 38},
  [8526] = {.lex_state = 87, .external_lex_state = 53},
  [8527] = {.lex_state = 97, .external_lex_state = 34},
  [8528] = {.lex_state = 79, .external_lex_state = 32},
  [8529] = {.lex_state = 87, .external_lex_state = 53},
  [8530] = {.lex_state = 90, .external_lex_state = 40},
  [8531] = {.lex_state = 87, .external_lex_state = 53},
  [8532] = {.lex_state = 11, .external_lex_state = 49},
  [8533] = {.lex_state = 95, .external_lex_state = 38},
  [8534] = {.lex_state = 88, .external_lex_state = 50},
  [8535] = {.lex_state = 95, .external_lex_state = 38},
  [8536] = {.lex_state = 87, .external_lex_state = 55},
  [8537] = {.lex_state = 87, .external_lex_state = 56},
  [8538] = {.lex_state = 87, .external_lex_state = 55},
  [8539] = {.lex_state = 87, .external_lex_state = 54},
  [8540] = {.lex_state = 87, .external_lex_state = 58},
  [8541] = {.lex_state = 29, .external_lex_state = 49},
  [8542] = {.lex_state = 87, .external_lex_state = 51},
  [8543] = {.lex_state = 87, .external_lex_state = 51},
  [8544] = {.lex_state = 12, .external_lex_state = 49},
  [8545] = {.lex_state = 93, .external_lex_state = 35},
  [8546] = {.lex_state = 88, .external_lex_state = 50},
  [8547] = {.lex_state = 95, .external_lex_state = 38},
  [8548] = {.lex_state = 95, .external_lex_state = 40},
  [8549] = {.lex_state = 87, .external_lex_state = 55},
  [8550] = {.lex_state = 88, .external_lex_state = 50},
  [8551] = {.lex_state = 95, .external_lex_state = 38},
  [8552] = {.lex_state = 12, .external_lex_state = 49},
  [8553] = {.lex_state = 87, .external_lex_state = 51},
  [8554] = {.lex_state = 89, .external_lex_state = 35},
  [8555] = {.lex_state = 87, .external_lex_state = 53},
  [8556] = {.lex_state = 87, .external_lex_state = 46},
  [8557] = {.lex_state = 85, .external_lex_state = 50},
  [8558] = {.lex_state = 87, .external_lex_state = 54},
  [8559] = {.lex_state = 79, .external_lex_state = 32},
  [8560] = {.lex_state = 75, .external_lex_state = 56},
  [8561] = {.lex_state = 86, .external_lex_state = 27},
  [8562] = {.lex_state = 30, .external_lex_state = 49},
  [8563] = {.lex_state = 79, .external_lex_state = 33},
  [8564] = {.lex_state = 88, .external_lex_state = 32},
  [8565] = {.lex_state = 89, .external_lex_state = 35},
  [8566] = {.lex_state = 93, .external_lex_state = 35},
  [8567] = {.lex_state = 97, .external_lex_state = 30},
  [8568] = {.lex_state = 79, .external_lex_state = 32},
  [8569] = {.lex_state = 87, .external_lex_state = 51},
  [8570] = {.lex_state = 11, .external_lex_state = 49},
  [8571] = {.lex_state = 40, .external_lex_state = 49},
  [8572] = {.lex_state = 85, .external_lex_state = 32},
  [8573] = {.lex_state = 80, .external_lex_state = 50},
  [8574] = {.lex_state = 87, .external_lex_state = 53},
  [8575] = {.lex_state = 94, .external_lex_state = 47},
  [8576] = {.lex_state = 17},
  [8577] = {.lex_state = 97, .external_lex_state = 30},
  [8578] = {.lex_state = 79, .external_lex_state = 33},
  [8579] = {.lex_state = 87, .external_lex_state = 55},
  [8580] = {.lex_state = 79, .external_lex_state = 33},
  [8581] = {.lex_state = 87, .external_lex_state = 54},
  [8582] = {.lex_state = 17},
  [8583] = {.lex_state = 87, .external_lex_state = 55},
  [8584] = {.lex_state = 26},
  [8585] = {.lex_state = 79, .external_lex_state = 33},
  [8586] = {.lex_state = 89, .external_lex_state = 50},
  [8587] = {.lex_state = 46, .external_lex_state = 49},
  [8588] = {.lex_state = 87, .external_lex_state = 49},
  [8589] = {.lex_state = 90, .external_lex_state = 39},
  [8590] = {.lex_state = 88, .external_lex_state = 27},
  [8591] = {.lex_state = 79, .external_lex_state = 32},
  [8592] = {.lex_state = 87, .external_lex_state = 55},
  [8593] = {.lex_state = 85, .external_lex_state = 35},
  [8594] = {.lex_state = 97, .external_lex_state = 30},
  [8595] = {.lex_state = 79, .external_lex_state = 32},
  [8596] = {.lex_state = 95, .external_lex_state = 38},
  [8597] = {.lex_state = 79, .external_lex_state = 33},
  [8598] = {.lex_state = 95, .external_lex_state = 39},
  [8599] = {.lex_state = 95, .external_lex_state = 54},
  [8600] = {.lex_state = 95, .external_lex_state = 40},
  [8601] = {.lex_state = 12, .external_lex_state = 49},
  [8602] = {.lex_state = 15, .external_lex_state = 49},
  [8603] = {.lex_state = 78, .external_lex_state = 35},
  [8604] = {.lex_state = 86, .external_lex_state = 35},
  [8605] = {.lex_state = 95, .external_lex_state = 39},
  [8606] = {.lex_state = 87, .external_lex_state = 29},
  [8607] = {.lex_state = 75, .external_lex_state = 24},
  [8608] = {.lex_state = 87, .external_lex_state = 54},
  [8609] = {.lex_state = 17},
  [8610] = {.lex_state = 86, .external_lex_state = 27},
  [8611] = {.lex_state = 87, .external_lex_state = 55},
  [8612] = {.lex_state = 87, .external_lex_state = 54},
  [8613] = {.lex_state = 87, .external_lex_state = 51},
  [8614] = {.lex_state = 93, .external_lex_state = 50},
  [8615] = {.lex_state = 95, .external_lex_state = 39},
  [8616] = {.lex_state = 97, .external_lex_state = 30},
  [8617] = {.lex_state = 90, .external_lex_state = 30},
  [8618] = {.lex_state = 87, .external_lex_state = 55},
  [8619] = {.lex_state = 96, .external_lex_state = 42},
  [8620] = {.lex_state = 80, .external_lex_state = 33},
  [8621] = {.lex_state = 87, .external_lex_state = 58},
  [8622] = {.lex_state = 14, .external_lex_state = 49},
  [8623] = {.lex_state = 75, .external_lex_state = 23},
  [8624] = {.lex_state = 87, .external_lex_state = 55},
  [8625] = {.lex_state = 79, .external_lex_state = 32},
  [8626] = {.lex_state = 93, .external_lex_state = 50},
  [8627] = {.lex_state = 95, .external_lex_state = 39},
  [8628] = {.lex_state = 14, .external_lex_state = 49},
  [8629] = {.lex_state = 87, .external_lex_state = 45},
  [8630] = {.lex_state = 93, .external_lex_state = 50},
  [8631] = {.lex_state = 95, .external_lex_state = 39},
  [8632] = {.lex_state = 79, .external_lex_state = 33},
  [8633] = {.lex_state = 16, .external_lex_state = 49},
  [8634] = {.lex_state = 79, .external_lex_state = 32},
  [8635] = {.lex_state = 87, .external_lex_state = 51},
  [8636] = {.lex_state = 80, .external_lex_state = 50},
  [8637] = {.lex_state = 87, .external_lex_state = 51},
  [8638] = {.lex_state = 78, .external_lex_state = 35},
  [8639] = {.lex_state = 87, .external_lex_state = 54},
  [8640] = {.lex_state = 87},
  [8641] = {.lex_state = 87, .external_lex_state = 53},
  [8642] = {.lex_state = 87, .external_lex_state = 53},
  [8643] = {.lex_state = 17},
  [8644] = {.lex_state = 87, .external_lex_state = 53},
  [8645] = {.lex_state = 87, .external_lex_state = 55},
  [8646] = {.lex_state = 86, .external_lex_state = 35},
  [8647] = {.lex_state = 95, .external_lex_state = 40},
  [8648] = {.lex_state = 79, .external_lex_state = 32},
  [8649] = {.lex_state = 87, .external_lex_state = 55},
  [8650] = {.lex_state = 78, .external_lex_state = 35},
  [8651] = {.lex_state = 26},
  [8652] = {.lex_state = 80, .external_lex_state = 32},
  [8653] = {.lex_state = 95, .external_lex_state = 40},
  [8654] = {.lex_state = 86, .external_lex_state = 35},
  [8655] = {.lex_state = 79, .external_lex_state = 32},
  [8656] = {.lex_state = 97, .external_lex_state = 30},
  [8657] = {.lex_state = 95, .external_lex_state = 55},
  [8658] = {.lex_state = 87},
  [8659] = {.lex_state = 87, .external_lex_state = 47},
  [8660] = {.lex_state = 86, .external_lex_state = 35},
  [8661] = {.lex_state = 79, .external_lex_state = 33},
  [8662] = {.lex_state = 97, .external_lex_state = 34},
  [8663] = {.lex_state = 81, .external_lex_state = 35},
  [8664] = {.lex_state = 90, .external_lex_state = 29},
  [8665] = {.lex_state = 96, .external_lex_state = 42},
  [8666] = {.lex_state = 79, .external_lex_state = 33},
  [8667] = {.lex_state = 75, .external_lex_state = 40},
  [8668] = {.lex_state = 31},
  [8669] = {.lex_state = 82, .external_lex_state = 49},
  [8670] = {.lex_state = 80, .external_lex_state = 35},
  [8671] = {.lex_state = 81, .external_lex_state = 35},
  [8672] = {.lex_state = 4},
  [8673] = {.lex_state = 90, .external_lex_state = 29},
  [8674] = {.lex_state = 97, .external_lex_state = 34},
  [8675] = {.lex_state = 97, .external_lex_state = 34},
  [8676] = {.lex_state = 95, .external_lex_state = 53},
  [8677] = {.lex_state = 5},
  [8678] = {.lex_state = 95, .external_lex_state = 39},
  [8679] = {.lex_state = 87, .external_lex_state = 51},
  [8680] = {.lex_state = 90, .external_lex_state = 29},
  [8681] = {.lex_state = 12, .external_lex_state = 49},
  [8682] = {.lex_state = 75, .external_lex_state = 56},
  [8683] = {.lex_state = 86, .external_lex_state = 27},
  [8684] = {.lex_state = 79, .external_lex_state = 33},
  [8685] = {.lex_state = 90, .external_lex_state = 40},
  [8686] = {.lex_state = 96, .external_lex_state = 43},
  [8687] = {.lex_state = 90, .external_lex_state = 34},
  [8688] = {.lex_state = 87, .external_lex_state = 51},
  [8689] = {.lex_state = 87, .external_lex_state = 55},
  [8690] = {.lex_state = 95, .external_lex_state = 40},
  [8691] = {.lex_state = 87, .external_lex_state = 24},
  [8692] = {.lex_state = 15, .external_lex_state = 49},
  [8693] = {.lex_state = 78, .external_lex_state = 35},
  [8694] = {.lex_state = 87, .external_lex_state = 51},
  [8695] = {.lex_state = 75, .external_lex_state = 57},
  [8696] = {.lex_state = 87, .external_lex_state = 57},
  [8697] = {.lex_state = 5},
  [8698] = {.lex_state = 96, .external_lex_state = 43},
  [8699] = {.lex_state = 35, .external_lex_state = 49},
  [8700] = {.lex_state = 87, .external_lex_state = 51},
  [8701] = {.lex_state = 75, .external_lex_state = 39},
  [8702] = {.lex_state = 4},
  [8703] = {.lex_state = 5},
  [8704] = {.lex_state = 95, .external_lex_state = 39},
  [8705] = {.lex_state = 97, .external_lex_state = 34},
  [8706] = {.lex_state = 87, .external_lex_state = 53},
  [8707] = {.lex_state = 87, .external_lex_state = 53},
  [8708] = {.lex_state = 87, .external_lex_state = 51},
  [8709] = {.lex_state = 87, .external_lex_state = 51},
  [8710] = {.lex_state = 81, .external_lex_state = 35},
  [8711] = {.lex_state = 78, .external_lex_state = 32},
  [8712] = {.lex_state = 87, .external_lex_state = 58},
  [8713] = {.lex_state = 99, .external_lex_state = 50},
  [8714] = {.lex_state = 26},
  [8715] = {.lex_state = 87, .external_lex_state = 51},
  [8716] = {.lex_state = 87, .external_lex_state = 29},
  [8717] = {.lex_state = 15, .external_lex_state = 49},
  [8718] = {.lex_state = 96, .external_lex_state = 49},
  [8719] = {.lex_state = 17},
  [8720] = {.lex_state = 87, .external_lex_state = 53},
  [8721] = {.lex_state = 79, .external_lex_state = 32},
  [8722] = {.lex_state = 90, .external_lex_state = 29},
  [8723] = {.lex_state = 87},
  [8724] = {.lex_state = 87, .external_lex_state = 54},
  [8725] = {.lex_state = 87, .external_lex_state = 51},
  [8726] = {.lex_state = 80, .external_lex_state = 59},
  [8727] = {.lex_state = 79, .external_lex_state = 33},
  [8728] = {.lex_state = 87, .external_lex_state = 55},
  [8729] = {.lex_state = 87, .external_lex_state = 53},
  [8730] = {.lex_state = 88, .external_lex_state = 27},
  [8731] = {.lex_state = 79, .external_lex_state = 32},
  [8732] = {.lex_state = 87, .external_lex_state = 51},
  [8733] = {.lex_state = 87, .external_lex_state = 53},
  [8734] = {.lex_state = 17},
  [8735] = {.lex_state = 86, .external_lex_state = 28},
  [8736] = {.lex_state = 97, .external_lex_state = 45},
  [8737] = {.lex_state = 92, .external_lex_state = 35},
  [8738] = {.lex_state = 86, .external_lex_state = 28},
  [8739] = {.lex_state = 94, .external_lex_state = 26},
  [8740] = {.lex_state = 78, .external_lex_state = 35},
  [8741] = {.lex_state = 89, .external_lex_state = 50},
  [8742] = {.lex_state = 96, .external_lex_state = 47},
  [8743] = {.lex_state = 87, .external_lex_state = 51},
  [8744] = {.lex_state = 86, .external_lex_state = 49},
  [8745] = {.lex_state = 87, .external_lex_state = 51},
  [8746] = {.lex_state = 86, .external_lex_state = 28},
  [8747] = {.lex_state = 88, .external_lex_state = 27},
  [8748] = {.lex_state = 79, .external_lex_state = 32},
  [8749] = {.lex_state = 90, .external_lex_state = 29},
  [8750] = {.lex_state = 46, .external_lex_state = 49},
  [8751] = {.lex_state = 87, .external_lex_state = 51},
  [8752] = {.lex_state = 31},
  [8753] = {.lex_state = 87, .external_lex_state = 55},
  [8754] = {.lex_state = 96, .external_lex_state = 49},
  [8755] = {.lex_state = 88, .external_lex_state = 48},
  [8756] = {.lex_state = 87, .external_lex_state = 54},
  [8757] = {.lex_state = 78, .external_lex_state = 35},
  [8758] = {.lex_state = 35, .external_lex_state = 49},
  [8759] = {.lex_state = 78, .external_lex_state = 35},
  [8760] = {.lex_state = 78, .external_lex_state = 35},
  [8761] = {.lex_state = 46, .external_lex_state = 49},
  [8762] = {.lex_state = 87},
  [8763] = {.lex_state = 90, .external_lex_state = 29},
  [8764] = {.lex_state = 88, .external_lex_state = 27},
  [8765] = {.lex_state = 87, .external_lex_state = 38},
  [8766] = {.lex_state = 87, .external_lex_state = 53},
  [8767] = {.lex_state = 87, .external_lex_state = 53},
  [8768] = {.lex_state = 87},
  [8769] = {.lex_state = 87, .external_lex_state = 51},
  [8770] = {.lex_state = 17},
  [8771] = {.lex_state = 16, .external_lex_state = 49},
  [8772] = {.lex_state = 94, .external_lex_state = 26},
  [8773] = {.lex_state = 87, .external_lex_state = 51},
  [8774] = {.lex_state = 85, .external_lex_state = 32},
  [8775] = {.lex_state = 87, .external_lex_state = 51},
  [8776] = {.lex_state = 78, .external_lex_state = 35},
  [8777] = {.lex_state = 87, .external_lex_state = 45},
  [8778] = {.lex_state = 87, .external_lex_state = 53},
  [8779] = {.lex_state = 87, .external_lex_state = 53},
  [8780] = {.lex_state = 87, .external_lex_state = 56},
  [8781] = {.lex_state = 81, .external_lex_state = 50},
  [8782] = {.lex_state = 81, .external_lex_state = 35},
  [8783] = {.lex_state = 80, .external_lex_state = 35},
  [8784] = {.lex_state = 75, .external_lex_state = 30},
  [8785] = {.lex_state = 75},
  [8786] = {.lex_state = 85, .external_lex_state = 32},
  [8787] = {.lex_state = 87},
  [8788] = {.lex_state = 87, .external_lex_state = 55},
  [8789] = {.lex_state = 87},
  [8790] = {.lex_state = 85, .external_lex_state = 32},
  [8791] = {.lex_state = 80, .external_lex_state = 33},
  [8792] = {.lex_state = 81, .external_lex_state = 50},
  [8793] = {.lex_state = 78, .external_lex_state = 35},
  [8794] = {.lex_state = 17},
  [8795] = {.lex_state = 15, .external_lex_state = 49},
  [8796] = {.lex_state = 92, .external_lex_state = 35},
  [8797] = {.lex_state = 97, .external_lex_state = 34},
  [8798] = {.lex_state = 87, .external_lex_state = 51},
  [8799] = {.lex_state = 87, .external_lex_state = 55},
  [8800] = {.lex_state = 87, .external_lex_state = 53},
  [8801] = {.lex_state = 78, .external_lex_state = 35},
  [8802] = {.lex_state = 87},
  [8803] = {.lex_state = 38, .external_lex_state = 49},
  [8804] = {.lex_state = 79, .external_lex_state = 33},
  [8805] = {.lex_state = 87},
  [8806] = {.lex_state = 87, .external_lex_state = 54},
  [8807] = {.lex_state = 75, .external_lex_state = 23},
  [8808] = {.lex_state = 87, .external_lex_state = 54},
  [8809] = {.lex_state = 87, .external_lex_state = 54},
  [8810] = {.lex_state = 4},
  [8811] = {.lex_state = 82, .external_lex_state = 49},
  [8812] = {.lex_state = 75, .external_lex_state = 30},
  [8813] = {.lex_state = 87, .external_lex_state = 54},
  [8814] = {.lex_state = 87},
  [8815] = {.lex_state = 88, .external_lex_state = 33},
  [8816] = {.lex_state = 80, .external_lex_state = 33},
  [8817] = {.lex_state = 5},
  [8818] = {.lex_state = 96, .external_lex_state = 48},
  [8819] = {.lex_state = 87},
  [8820] = {.lex_state = 87},
  [8821] = {.lex_state = 87, .external_lex_state = 54},
  [8822] = {.lex_state = 96, .external_lex_state = 52},
  [8823] = {.lex_state = 97, .external_lex_state = 30},
  [8824] = {.lex_state = 86, .external_lex_state = 28},
  [8825] = {.lex_state = 82, .external_lex_state = 49},
  [8826] = {.lex_state = 17},
  [8827] = {.lex_state = 78, .external_lex_state = 33},
  [8828] = {.lex_state = 92, .external_lex_state = 35},
  [8829] = {.lex_state = 87, .external_lex_state = 55},
  [8830] = {.lex_state = 75, .external_lex_state = 34},
  [8831] = {.lex_state = 80, .external_lex_state = 33},
  [8832] = {.lex_state = 80, .external_lex_state = 33},
  [8833] = {.lex_state = 87, .external_lex_state = 54},
  [8834] = {.lex_state = 87, .external_lex_state = 54},
  [8835] = {.lex_state = 80, .external_lex_state = 33},
  [8836] = {.lex_state = 88, .external_lex_state = 47},
  [8837] = {.lex_state = 87, .external_lex_state = 53},
  [8838] = {.lex_state = 90, .external_lex_state = 38},
  [8839] = {.lex_state = 94, .external_lex_state = 48},
  [8840] = {.lex_state = 87, .external_lex_state = 53},
  [8841] = {.lex_state = 87, .external_lex_state = 54},
  [8842] = {.lex_state = 87, .external_lex_state = 57},
  [8843] = {.lex_state = 85, .external_lex_state = 49},
  [8844] = {.lex_state = 87, .external_lex_state = 54},
  [8845] = {.lex_state = 81, .external_lex_state = 35},
  [8846] = {.lex_state = 81, .external_lex_state = 49},
  [8847] = {.lex_state = 87, .external_lex_state = 53},
  [8848] = {.lex_state = 99, .external_lex_state = 49},
  [8849] = {.lex_state = 92, .external_lex_state = 50},
  [8850] = {.lex_state = 85, .external_lex_state = 33},
  [8851] = {.lex_state = 90, .external_lex_state = 29},
  [8852] = {.lex_state = 4},
  [8853] = {.lex_state = 90, .external_lex_state = 29},
  [8854] = {.lex_state = 87, .external_lex_state = 54},
  [8855] = {.lex_state = 87, .external_lex_state = 51},
  [8856] = {.lex_state = 87, .external_lex_state = 54},
  [8857] = {.lex_state = 87, .external_lex_state = 54},
  [8858] = {.lex_state = 87, .external_lex_state = 53},
  [8859] = {.lex_state = 87, .external_lex_state = 54},
  [8860] = {.lex_state = 94, .external_lex_state = 48},
  [8861] = {.lex_state = 86, .external_lex_state = 27},
  [8862] = {.lex_state = 85, .external_lex_state = 33},
  [8863] = {.lex_state = 92, .external_lex_state = 35},
  [8864] = {.lex_state = 87, .external_lex_state = 53},
  [8865] = {.lex_state = 26},
  [8866] = {.lex_state = 75, .external_lex_state = 34},
  [8867] = {.lex_state = 87, .external_lex_state = 53},
  [8868] = {.lex_state = 4},
  [8869] = {.lex_state = 81, .external_lex_state = 35},
  [8870] = {.lex_state = 29, .external_lex_state = 49},
  [8871] = {.lex_state = 93, .external_lex_state = 35},
  [8872] = {.lex_state = 87, .external_lex_state = 54},
  [8873] = {.lex_state = 28, .external_lex_state = 49},
  [8874] = {.lex_state = 78, .external_lex_state = 33},
  [8875] = {.lex_state = 85, .external_lex_state = 33},
  [8876] = {.lex_state = 97, .external_lex_state = 30},
  [8877] = {.lex_state = 87, .external_lex_state = 54},
  [8878] = {.lex_state = 75},
  [8879] = {.lex_state = 97, .external_lex_state = 30},
  [8880] = {.lex_state = 7},
  [8881] = {.lex_state = 87, .external_lex_state = 54},
  [8882] = {.lex_state = 97, .external_lex_state = 46},
  [8883] = {.lex_state = 79, .external_lex_state = 33},
  [8884] = {.lex_state = 75, .external_lex_state = 57},
  [8885] = {.lex_state = 7},
  [8886] = {.lex_state = 85, .external_lex_state = 35},
  [8887] = {.lex_state = 75, .external_lex_state = 49},
  [8888] = {.lex_state = 81, .external_lex_state = 35},
  [8889] = {.lex_state = 87, .external_lex_state = 53},
  [8890] = {.lex_state = 87, .external_lex_state = 54},
  [8891] = {.lex_state = 86, .external_lex_state = 50},
  [8892] = {.lex_state = 87, .external_lex_state = 54},
  [8893] = {.lex_state = 87, .external_lex_state = 55},
  [8894] = {.lex_state = 87, .external_lex_state = 53},
  [8895] = {.lex_state = 7},
  [8896] = {.lex_state = 88, .external_lex_state = 33},
  [8897] = {.lex_state = 87, .external_lex_state = 50},
  [8898] = {.lex_state = 85, .external_lex_state = 28},
  [8899] = {.lex_state = 80, .external_lex_state = 32},
  [8900] = {.lex_state = 87, .external_lex_state = 51},
  [8901] = {.lex_state = 99, .external_lex_state = 49},
  [8902] = {.lex_state = 94, .external_lex_state = 28},
  [8903] = {.lex_state = 81, .external_lex_state = 49},
  [8904] = {.lex_state = 80, .external_lex_state = 32},
  [8905] = {.lex_state = 83, .external_lex_state = 35},
  [8906] = {.lex_state = 81, .external_lex_state = 35},
  [8907] = {.lex_state = 80, .external_lex_state = 32},
  [8908] = {.lex_state = 87, .external_lex_state = 54},
  [8909] = {.lex_state = 87, .external_lex_state = 53},
  [8910] = {.lex_state = 80, .external_lex_state = 27},
  [8911] = {.lex_state = 78, .external_lex_state = 35},
  [8912] = {.lex_state = 80, .external_lex_state = 32},
  [8913] = {.lex_state = 87, .external_lex_state = 54},
  [8914] = {.lex_state = 80, .external_lex_state = 28},
  [8915] = {.lex_state = 87, .external_lex_state = 55},
  [8916] = {.lex_state = 88, .external_lex_state = 52},
  [8917] = {.lex_state = 87, .external_lex_state = 51},
  [8918] = {.lex_state = 87, .external_lex_state = 55},
  [8919] = {.lex_state = 80, .external_lex_state = 32},
  [8920] = {.lex_state = 81, .external_lex_state = 35},
  [8921] = {.lex_state = 83, .external_lex_state = 35},
  [8922] = {.lex_state = 77},
  [8923] = {.lex_state = 75},
  [8924] = {.lex_state = 87, .external_lex_state = 53},
  [8925] = {.lex_state = 80, .external_lex_state = 28},
  [8926] = {.lex_state = 87, .external_lex_state = 53},
  [8927] = {.lex_state = 81, .external_lex_state = 35},
  [8928] = {.lex_state = 80, .external_lex_state = 27},
  [8929] = {.lex_state = 95, .external_lex_state = 38},
  [8930] = {.lex_state = 87, .external_lex_state = 53},
  [8931] = {.lex_state = 26},
  [8932] = {.lex_state = 87, .external_lex_state = 53},
  [8933] = {.lex_state = 80, .external_lex_state = 32},
  [8934] = {.lex_state = 75, .external_lex_state = 51},
  [8935] = {.lex_state = 80, .external_lex_state = 32},
  [8936] = {.lex_state = 81, .external_lex_state = 35},
  [8937] = {.lex_state = 87, .external_lex_state = 55},
  [8938] = {.lex_state = 92, .external_lex_state = 35},
  [8939] = {.lex_state = 97, .external_lex_state = 54},
  [8940] = {.lex_state = 86, .external_lex_state = 32},
  [8941] = {.lex_state = 95, .external_lex_state = 46},
  [8942] = {.lex_state = 95, .external_lex_state = 46},
  [8943] = {.lex_state = 87, .external_lex_state = 34},
  [8944] = {.lex_state = 94, .external_lex_state = 49},
  [8945] = {.lex_state = 87, .external_lex_state = 56},
  [8946] = {.lex_state = 32},
  [8947] = {.lex_state = 32},
  [8948] = {.lex_state = 87, .external_lex_state = 57},
  [8949] = {.lex_state = 30, .external_lex_state = 49},
  [8950] = {.lex_state = 87, .external_lex_state = 56},
  [8951] = {.lex_state = 79, .external_lex_state = 35},
  [8952] = {.lex_state = 79, .external_lex_state = 35},
  [8953] = {.lex_state = 75, .external_lex_state = 40},
  [8954] = {.lex_state = 85, .external_lex_state = 35},
  [8955] = {.lex_state = 97, .external_lex_state = 39},
  [8956] = {.lex_state = 32},
  [8957] = {.lex_state = 87, .external_lex_state = 57},
  [8958] = {.lex_state = 87, .external_lex_state = 29},
  [8959] = {.lex_state = 87, .external_lex_state = 24},
  [8960] = {.lex_state = 90, .external_lex_state = 34},
  [8961] = {.lex_state = 80, .external_lex_state = 32},
  [8962] = {.lex_state = 87, .external_lex_state = 24},
  [8963] = {.lex_state = 79, .external_lex_state = 35},
  [8964] = {.lex_state = 87, .external_lex_state = 23},
  [8965] = {.lex_state = 32},
  [8966] = {.lex_state = 32},
  [8967] = {.lex_state = 32},
  [8968] = {.lex_state = 29, .external_lex_state = 49},
  [8969] = {.lex_state = 32},
  [8970] = {.lex_state = 87, .external_lex_state = 29},
  [8971] = {.lex_state = 87, .external_lex_state = 29},
  [8972] = {.lex_state = 93, .external_lex_state = 35},
  [8973] = {.lex_state = 32},
  [8974] = {.lex_state = 87, .external_lex_state = 24},
  [8975] = {.lex_state = 81, .external_lex_state = 49},
  [8976] = {.lex_state = 82, .external_lex_state = 49},
  [8977] = {.lex_state = 96, .external_lex_state = 49},
  [8978] = {.lex_state = 81, .external_lex_state = 49},
  [8979] = {.lex_state = 88, .external_lex_state = 35},
  [8980] = {.lex_state = 32},
  [8981] = {.lex_state = 87, .external_lex_state = 29},
  [8982] = {.lex_state = 85, .external_lex_state = 35},
  [8983] = {.lex_state = 87, .external_lex_state = 58},
  [8984] = {.lex_state = 87, .external_lex_state = 56},
  [8985] = {.lex_state = 32},
  [8986] = {.lex_state = 81, .external_lex_state = 49},
  [8987] = {.lex_state = 32},
  [8988] = {.lex_state = 32},
  [8989] = {.lex_state = 36, .external_lex_state = 49},
  [8990] = {.lex_state = 95, .external_lex_state = 45},
  [8991] = {.lex_state = 81, .external_lex_state = 49},
  [8992] = {.lex_state = 87, .external_lex_state = 56},
  [8993] = {.lex_state = 87, .external_lex_state = 50},
  [8994] = {.lex_state = 75, .external_lex_state = 24},
  [8995] = {.lex_state = 79, .external_lex_state = 35},
  [8996] = {.lex_state = 94, .external_lex_state = 28},
  [8997] = {.lex_state = 87, .external_lex_state = 53},
  [8998] = {.lex_state = 87, .external_lex_state = 24},
  [8999] = {.lex_state = 97},
  [9000] = {.lex_state = 87, .external_lex_state = 58},
  [9001] = {.lex_state = 87, .external_lex_state = 29},
  [9002] = {.lex_state = 87, .external_lex_state = 24},
  [9003] = {.lex_state = 32},
  [9004] = {.lex_state = 87, .external_lex_state = 29},
  [9005] = {.lex_state = 87, .external_lex_state = 29},
  [9006] = {.lex_state = 32},
  [9007] = {.lex_state = 99, .external_lex_state = 35},
  [9008] = {.lex_state = 87, .external_lex_state = 56},
  [9009] = {.lex_state = 90, .external_lex_state = 34},
  [9010] = {.lex_state = 90, .external_lex_state = 34},
  [9011] = {.lex_state = 96, .external_lex_state = 27},
  [9012] = {.lex_state = 87, .external_lex_state = 57},
  [9013] = {.lex_state = 32},
  [9014] = {.lex_state = 32},
  [9015] = {.lex_state = 87},
  [9016] = {.lex_state = 31},
  [9017] = {.lex_state = 32},
  [9018] = {.lex_state = 80, .external_lex_state = 35},
  [9019] = {.lex_state = 87, .external_lex_state = 57},
  [9020] = {.lex_state = 87, .external_lex_state = 29},
  [9021] = {.lex_state = 99, .external_lex_state = 35},
  [9022] = {.lex_state = 95, .external_lex_state = 58},
  [9023] = {.lex_state = 82, .external_lex_state = 49},
  [9024] = {.lex_state = 87, .external_lex_state = 29},
  [9025] = {.lex_state = 87, .external_lex_state = 23},
  [9026] = {.lex_state = 80, .external_lex_state = 32},
  [9027] = {.lex_state = 87, .external_lex_state = 24},
  [9028] = {.lex_state = 93, .external_lex_state = 35},
  [9029] = {.lex_state = 87, .external_lex_state = 27},
  [9030] = {.lex_state = 88, .external_lex_state = 27},
  [9031] = {.lex_state = 87, .external_lex_state = 58},
  [9032] = {.lex_state = 32},
  [9033] = {.lex_state = 32},
  [9034] = {.lex_state = 87, .external_lex_state = 50},
  [9035] = {.lex_state = 87, .external_lex_state = 54},
  [9036] = {.lex_state = 32},
  [9037] = {.lex_state = 87},
  [9038] = {.lex_state = 94, .external_lex_state = 32},
  [9039] = {.lex_state = 94, .external_lex_state = 28},
  [9040] = {.lex_state = 92, .external_lex_state = 35},
  [9041] = {.lex_state = 87, .external_lex_state = 56},
  [9042] = {.lex_state = 97, .external_lex_state = 38},
  [9043] = {.lex_state = 87, .external_lex_state = 58},
  [9044] = {.lex_state = 90, .external_lex_state = 45},
  [9045] = {.lex_state = 87, .external_lex_state = 58},
  [9046] = {.lex_state = 32},
  [9047] = {.lex_state = 87, .external_lex_state = 56},
  [9048] = {.lex_state = 36, .external_lex_state = 49},
  [9049] = {.lex_state = 80, .external_lex_state = 35},
  [9050] = {.lex_state = 32},
  [9051] = {.lex_state = 32},
  [9052] = {.lex_state = 32},
  [9053] = {.lex_state = 79, .external_lex_state = 35},
  [9054] = {.lex_state = 75, .external_lex_state = 24},
  [9055] = {.lex_state = 82, .external_lex_state = 49},
  [9056] = {.lex_state = 87, .external_lex_state = 56},
  [9057] = {.lex_state = 87, .external_lex_state = 29},
  [9058] = {.lex_state = 87, .external_lex_state = 29},
  [9059] = {.lex_state = 32},
  [9060] = {.lex_state = 32},
  [9061] = {.lex_state = 32},
  [9062] = {.lex_state = 82, .external_lex_state = 49},
  [9063] = {.lex_state = 75, .external_lex_state = 40},
  [9064] = {.lex_state = 32},
  [9065] = {.lex_state = 87, .external_lex_state = 56},
  [9066] = {.lex_state = 87, .external_lex_state = 24},
  [9067] = {.lex_state = 32},
  [9068] = {.lex_state = 87, .external_lex_state = 29},
  [9069] = {.lex_state = 14, .external_lex_state = 49},
  [9070] = {.lex_state = 87, .external_lex_state = 29},
  [9071] = {.lex_state = 32},
  [9072] = {.lex_state = 87, .external_lex_state = 56},
  [9073] = {.lex_state = 87, .external_lex_state = 56},
  [9074] = {.lex_state = 96, .external_lex_state = 59},
  [9075] = {.lex_state = 32},
  [9076] = {.lex_state = 75, .external_lex_state = 38},
  [9077] = {.lex_state = 87, .external_lex_state = 56},
  [9078] = {.lex_state = 97, .external_lex_state = 38},
  [9079] = {.lex_state = 87, .external_lex_state = 56},
  [9080] = {.lex_state = 87, .external_lex_state = 29},
  [9081] = {.lex_state = 87, .external_lex_state = 57},
  [9082] = {.lex_state = 87, .external_lex_state = 58},
  [9083] = {.lex_state = 32},
  [9084] = {.lex_state = 87, .external_lex_state = 58},
  [9085] = {.lex_state = 97, .external_lex_state = 38},
  [9086] = {.lex_state = 87, .external_lex_state = 29},
  [9087] = {.lex_state = 87, .external_lex_state = 23},
  [9088] = {.lex_state = 14, .external_lex_state = 49},
  [9089] = {.lex_state = 87, .external_lex_state = 57},
  [9090] = {.lex_state = 85, .external_lex_state = 33},
  [9091] = {.lex_state = 80, .external_lex_state = 35},
  [9092] = {.lex_state = 87, .external_lex_state = 57},
  [9093] = {.lex_state = 90, .external_lex_state = 34},
  [9094] = {.lex_state = 32},
  [9095] = {.lex_state = 97, .external_lex_state = 38},
  [9096] = {.lex_state = 95, .external_lex_state = 45},
  [9097] = {.lex_state = 75, .external_lex_state = 45},
  [9098] = {.lex_state = 85, .external_lex_state = 32},
  [9099] = {.lex_state = 87, .external_lex_state = 58},
  [9100] = {.lex_state = 78, .external_lex_state = 49},
  [9101] = {.lex_state = 87, .external_lex_state = 56},
  [9102] = {.lex_state = 87, .external_lex_state = 54},
  [9103] = {.lex_state = 87, .external_lex_state = 58},
  [9104] = {.lex_state = 81, .external_lex_state = 49},
  [9105] = {.lex_state = 87, .external_lex_state = 56},
  [9106] = {.lex_state = 75, .external_lex_state = 58},
  [9107] = {.lex_state = 97, .external_lex_state = 38},
  [9108] = {.lex_state = 29, .external_lex_state = 49},
  [9109] = {.lex_state = 87, .external_lex_state = 58},
  [9110] = {.lex_state = 87, .external_lex_state = 57},
  [9111] = {.lex_state = 97, .external_lex_state = 38},
  [9112] = {.lex_state = 95, .external_lex_state = 23},
  [9113] = {.lex_state = 87, .external_lex_state = 56},
  [9114] = {.lex_state = 87, .external_lex_state = 58},
  [9115] = {.lex_state = 86, .external_lex_state = 32},
  [9116] = {.lex_state = 32},
  [9117] = {.lex_state = 87, .external_lex_state = 56},
  [9118] = {.lex_state = 86, .external_lex_state = 33},
  [9119] = {.lex_state = 96, .external_lex_state = 48},
  [9120] = {.lex_state = 4},
  [9121] = {.lex_state = 87, .external_lex_state = 56},
  [9122] = {.lex_state = 29, .external_lex_state = 49},
  [9123] = {.lex_state = 80, .external_lex_state = 35},
  [9124] = {.lex_state = 80, .external_lex_state = 35},
  [9125] = {.lex_state = 29, .external_lex_state = 49},
  [9126] = {.lex_state = 87, .external_lex_state = 34},
  [9127] = {.lex_state = 32},
  [9128] = {.lex_state = 32},
  [9129] = {.lex_state = 87, .external_lex_state = 58},
  [9130] = {.lex_state = 90, .external_lex_state = 30},
  [9131] = {.lex_state = 32},
  [9132] = {.lex_state = 90, .external_lex_state = 34},
  [9133] = {.lex_state = 90, .external_lex_state = 30},
  [9134] = {.lex_state = 87, .external_lex_state = 56},
  [9135] = {.lex_state = 82, .external_lex_state = 49},
  [9136] = {.lex_state = 86, .external_lex_state = 32},
  [9137] = {.lex_state = 32},
  [9138] = {.lex_state = 87, .external_lex_state = 58},
  [9139] = {.lex_state = 97, .external_lex_state = 39},
  [9140] = {.lex_state = 96, .external_lex_state = 48},
  [9141] = {.lex_state = 96, .external_lex_state = 52},
  [9142] = {.lex_state = 89, .external_lex_state = 35},
  [9143] = {.lex_state = 75, .external_lex_state = 24},
  [9144] = {.lex_state = 93, .external_lex_state = 35},
  [9145] = {.lex_state = 75, .external_lex_state = 40},
  [9146] = {.lex_state = 87, .external_lex_state = 24},
  [9147] = {.lex_state = 32},
  [9148] = {.lex_state = 87, .external_lex_state = 30},
  [9149] = {.lex_state = 87, .external_lex_state = 30},
  [9150] = {.lex_state = 87, .external_lex_state = 29},
  [9151] = {.lex_state = 87, .external_lex_state = 29},
  [9152] = {.lex_state = 87, .external_lex_state = 58},
  [9153] = {.lex_state = 75, .external_lex_state = 23},
  [9154] = {.lex_state = 87, .external_lex_state = 58},
  [9155] = {.lex_state = 80, .external_lex_state = 35},
  [9156] = {.lex_state = 87, .external_lex_state = 58},
  [9157] = {.lex_state = 87, .external_lex_state = 29},
  [9158] = {.lex_state = 87, .external_lex_state = 58},
  [9159] = {.lex_state = 32},
  [9160] = {.lex_state = 87, .external_lex_state = 57},
  [9161] = {.lex_state = 97, .external_lex_state = 39},
  [9162] = {.lex_state = 87, .external_lex_state = 58},
  [9163] = {.lex_state = 87, .external_lex_state = 58},
  [9164] = {.lex_state = 32},
  [9165] = {.lex_state = 90, .external_lex_state = 38},
  [9166] = {.lex_state = 97, .external_lex_state = 39},
  [9167] = {.lex_state = 95, .external_lex_state = 45},
  [9168] = {.lex_state = 95, .external_lex_state = 45},
  [9169] = {.lex_state = 95, .external_lex_state = 23},
  [9170] = {.lex_state = 87, .external_lex_state = 28},
  [9171] = {.lex_state = 87, .external_lex_state = 58},
  [9172] = {.lex_state = 32},
  [9173] = {.lex_state = 87},
  [9174] = {.lex_state = 93, .external_lex_state = 50},
  [9175] = {.lex_state = 87, .external_lex_state = 27},
  [9176] = {.lex_state = 87, .external_lex_state = 56},
  [9177] = {.lex_state = 86, .external_lex_state = 32},
  [9178] = {.lex_state = 81, .external_lex_state = 35},
  [9179] = {.lex_state = 78, .external_lex_state = 49},
  [9180] = {.lex_state = 94, .external_lex_state = 49},
  [9181] = {.lex_state = 95, .external_lex_state = 45},
  [9182] = {.lex_state = 96, .external_lex_state = 28},
  [9183] = {.lex_state = 87},
  [9184] = {.lex_state = 15, .external_lex_state = 49},
  [9185] = {.lex_state = 96, .external_lex_state = 52},
  [9186] = {.lex_state = 32},
  [9187] = {.lex_state = 79, .external_lex_state = 35},
  [9188] = {.lex_state = 87, .external_lex_state = 57},
  [9189] = {.lex_state = 87, .external_lex_state = 29},
  [9190] = {.lex_state = 32},
  [9191] = {.lex_state = 87, .external_lex_state = 56},
  [9192] = {.lex_state = 80, .external_lex_state = 35},
  [9193] = {.lex_state = 94, .external_lex_state = 50},
  [9194] = {.lex_state = 89, .external_lex_state = 50},
  [9195] = {.lex_state = 81, .external_lex_state = 35},
  [9196] = {.lex_state = 75, .external_lex_state = 23},
  [9197] = {.lex_state = 75, .external_lex_state = 24},
  [9198] = {.lex_state = 97, .external_lex_state = 39},
  [9199] = {.lex_state = 87, .external_lex_state = 58},
  [9200] = {.lex_state = 87, .external_lex_state = 56},
  [9201] = {.lex_state = 80, .external_lex_state = 35},
  [9202] = {.lex_state = 97, .external_lex_state = 55},
  [9203] = {.lex_state = 87, .external_lex_state = 56},
  [9204] = {.lex_state = 32},
  [9205] = {.lex_state = 97, .external_lex_state = 39},
  [9206] = {.lex_state = 32},
  [9207] = {.lex_state = 87, .external_lex_state = 28},
  [9208] = {.lex_state = 78, .external_lex_state = 49},
  [9209] = {.lex_state = 32},
  [9210] = {.lex_state = 87, .external_lex_state = 56},
  [9211] = {.lex_state = 32},
  [9212] = {.lex_state = 15, .external_lex_state = 49},
  [9213] = {.lex_state = 32},
  [9214] = {.lex_state = 87, .external_lex_state = 56},
  [9215] = {.lex_state = 97, .external_lex_state = 39},
  [9216] = {.lex_state = 87, .external_lex_state = 58},
  [9217] = {.lex_state = 90, .external_lex_state = 34},
  [9218] = {.lex_state = 32},
  [9219] = {.lex_state = 87, .external_lex_state = 57},
  [9220] = {.lex_state = 96, .external_lex_state = 59},
  [9221] = {.lex_state = 15, .external_lex_state = 49},
  [9222] = {.lex_state = 79, .external_lex_state = 35},
  [9223] = {.lex_state = 32},
  [9224] = {.lex_state = 87, .external_lex_state = 57},
  [9225] = {.lex_state = 79, .external_lex_state = 35},
  [9226] = {.lex_state = 87, .external_lex_state = 58},
  [9227] = {.lex_state = 97, .external_lex_state = 39},
  [9228] = {.lex_state = 80, .external_lex_state = 35},
  [9229] = {.lex_state = 90, .external_lex_state = 30},
  [9230] = {.lex_state = 32},
  [9231] = {.lex_state = 97, .external_lex_state = 39},
  [9232] = {.lex_state = 75, .external_lex_state = 38},
  [9233] = {.lex_state = 32},
  [9234] = {.lex_state = 32},
  [9235] = {.lex_state = 85, .external_lex_state = 35},
  [9236] = {.lex_state = 79, .external_lex_state = 35},
  [9237] = {.lex_state = 32},
  [9238] = {.lex_state = 32},
  [9239] = {.lex_state = 89, .external_lex_state = 49},
  [9240] = {.lex_state = 79, .external_lex_state = 35},
  [9241] = {.lex_state = 89, .external_lex_state = 35},
  [9242] = {.lex_state = 95, .external_lex_state = 23},
  [9243] = {.lex_state = 15, .external_lex_state = 49},
  [9244] = {.lex_state = 87, .external_lex_state = 56},
  [9245] = {.lex_state = 32},
  [9246] = {.lex_state = 79, .external_lex_state = 35},
  [9247] = {.lex_state = 75, .external_lex_state = 38},
  [9248] = {.lex_state = 96, .external_lex_state = 26},
  [9249] = {.lex_state = 87, .external_lex_state = 57},
  [9250] = {.lex_state = 87, .external_lex_state = 51},
  [9251] = {.lex_state = 87, .external_lex_state = 58},
  [9252] = {.lex_state = 88, .external_lex_state = 32},
  [9253] = {.lex_state = 88, .external_lex_state = 33},
  [9254] = {.lex_state = 87, .external_lex_state = 56},
  [9255] = {.lex_state = 88, .external_lex_state = 33},
  [9256] = {.lex_state = 87, .external_lex_state = 56},
  [9257] = {.lex_state = 87, .external_lex_state = 56},
  [9258] = {.lex_state = 80, .external_lex_state = 35},
  [9259] = {.lex_state = 32},
  [9260] = {.lex_state = 32},
  [9261] = {.lex_state = 87, .external_lex_state = 57},
  [9262] = {.lex_state = 97, .external_lex_state = 38},
  [9263] = {.lex_state = 87, .external_lex_state = 57},
  [9264] = {.lex_state = 96, .external_lex_state = 47},
  [9265] = {.lex_state = 89, .external_lex_state = 35},
  [9266] = {.lex_state = 32},
  [9267] = {.lex_state = 87, .external_lex_state = 58},
  [9268] = {.lex_state = 32},
  [9269] = {.lex_state = 87, .external_lex_state = 56},
  [9270] = {.lex_state = 94, .external_lex_state = 50},
  [9271] = {.lex_state = 87, .external_lex_state = 24},
  [9272] = {.lex_state = 87, .external_lex_state = 56},
  [9273] = {.lex_state = 15, .external_lex_state = 49},
  [9274] = {.lex_state = 87, .external_lex_state = 58},
  [9275] = {.lex_state = 95, .external_lex_state = 23},
  [9276] = {.lex_state = 88, .external_lex_state = 28},
  [9277] = {.lex_state = 95, .external_lex_state = 23},
  [9278] = {.lex_state = 88, .external_lex_state = 33},
  [9279] = {.lex_state = 97, .external_lex_state = 39},
  [9280] = {.lex_state = 87, .external_lex_state = 56},
  [9281] = {.lex_state = 87, .external_lex_state = 53},
  [9282] = {.lex_state = 87, .external_lex_state = 58},
  [9283] = {.lex_state = 86, .external_lex_state = 33},
  [9284] = {.lex_state = 87, .external_lex_state = 57},
  [9285] = {.lex_state = 95, .external_lex_state = 23},
  [9286] = {.lex_state = 32},
  [9287] = {.lex_state = 32},
  [9288] = {.lex_state = 87, .external_lex_state = 33},
  [9289] = {.lex_state = 97, .external_lex_state = 38},
  [9290] = {.lex_state = 100, .external_lex_state = 35},
  [9291] = {.lex_state = 97, .external_lex_state = 38},
  [9292] = {.lex_state = 32},
  [9293] = {.lex_state = 79, .external_lex_state = 35},
  [9294] = {.lex_state = 87, .external_lex_state = 58},
  [9295] = {.lex_state = 32},
  [9296] = {.lex_state = 39, .external_lex_state = 49},
  [9297] = {.lex_state = 96, .external_lex_state = 47},
  [9298] = {.lex_state = 82, .external_lex_state = 49},
  [9299] = {.lex_state = 32},
  [9300] = {.lex_state = 97, .external_lex_state = 38},
  [9301] = {.lex_state = 86, .external_lex_state = 32},
  [9302] = {.lex_state = 85, .external_lex_state = 35},
  [9303] = {.lex_state = 99, .external_lex_state = 50},
  [9304] = {.lex_state = 32},
  [9305] = {.lex_state = 15, .external_lex_state = 49},
  [9306] = {.lex_state = 32},
  [9307] = {.lex_state = 93, .external_lex_state = 35},
  [9308] = {.lex_state = 96, .external_lex_state = 26},
  [9309] = {.lex_state = 80, .external_lex_state = 35},
  [9310] = {.lex_state = 89, .external_lex_state = 35},
  [9311] = {.lex_state = 15, .external_lex_state = 49},
  [9312] = {.lex_state = 87, .external_lex_state = 46},
  [9313] = {.lex_state = 90, .external_lex_state = 30},
  [9314] = {.lex_state = 32},
  [9315] = {.lex_state = 80, .external_lex_state = 33},
  [9316] = {.lex_state = 87, .external_lex_state = 51},
  [9317] = {.lex_state = 87, .external_lex_state = 29},
  [9318] = {.lex_state = 95, .external_lex_state = 46},
  [9319] = {.lex_state = 32},
  [9320] = {.lex_state = 32},
  [9321] = {.lex_state = 32},
  [9322] = {.lex_state = 80, .external_lex_state = 35},
  [9323] = {.lex_state = 89, .external_lex_state = 49},
  [9324] = {.lex_state = 32},
  [9325] = {.lex_state = 95, .external_lex_state = 46},
  [9326] = {.lex_state = 87, .external_lex_state = 56},
  [9327] = {.lex_state = 87, .external_lex_state = 34},
  [9328] = {.lex_state = 87, .external_lex_state = 58},
  [9329] = {.lex_state = 96, .external_lex_state = 59},
  [9330] = {.lex_state = 87, .external_lex_state = 24},
  [9331] = {.lex_state = 90, .external_lex_state = 39},
  [9332] = {.lex_state = 87, .external_lex_state = 58},
  [9333] = {.lex_state = 87, .external_lex_state = 58},
  [9334] = {.lex_state = 88, .external_lex_state = 32},
  [9335] = {.lex_state = 95, .external_lex_state = 46},
  [9336] = {.lex_state = 32},
  [9337] = {.lex_state = 95, .external_lex_state = 23},
  [9338] = {.lex_state = 87, .external_lex_state = 58},
  [9339] = {.lex_state = 32},
  [9340] = {.lex_state = 87, .external_lex_state = 55},
  [9341] = {.lex_state = 32},
  [9342] = {.lex_state = 32},
  [9343] = {.lex_state = 81, .external_lex_state = 49},
  [9344] = {.lex_state = 89, .external_lex_state = 35},
  [9345] = {.lex_state = 32},
  [9346] = {.lex_state = 88, .external_lex_state = 32},
  [9347] = {.lex_state = 95, .external_lex_state = 46},
  [9348] = {.lex_state = 90, .external_lex_state = 34},
  [9349] = {.lex_state = 99, .external_lex_state = 50},
  [9350] = {.lex_state = 88, .external_lex_state = 32},
  [9351] = {.lex_state = 95, .external_lex_state = 46},
  [9352] = {.lex_state = 95, .external_lex_state = 29},
  [9353] = {.lex_state = 90, .external_lex_state = 34},
  [9354] = {.lex_state = 87, .external_lex_state = 34},
  [9355] = {.lex_state = 88, .external_lex_state = 50},
  [9356] = {.lex_state = 95, .external_lex_state = 46},
  [9357] = {.lex_state = 87, .external_lex_state = 57},
  [9358] = {.lex_state = 87, .external_lex_state = 57},
  [9359] = {.lex_state = 75, .external_lex_state = 38},
  [9360] = {.lex_state = 80, .external_lex_state = 59},
  [9361] = {.lex_state = 87, .external_lex_state = 29},
  [9362] = {.lex_state = 95, .external_lex_state = 23},
  [9363] = {.lex_state = 75, .external_lex_state = 45},
  [9364] = {.lex_state = 97, .external_lex_state = 51},
  [9365] = {.lex_state = 89, .external_lex_state = 35},
  [9366] = {.lex_state = 87, .external_lex_state = 30},
  [9367] = {.lex_state = 75, .external_lex_state = 40},
  [9368] = {.lex_state = 97, .external_lex_state = 40},
  [9369] = {.lex_state = 87, .external_lex_state = 57},
  [9370] = {.lex_state = 81, .external_lex_state = 49},
  [9371] = {.lex_state = 87, .external_lex_state = 56},
  [9372] = {.lex_state = 87, .external_lex_state = 58},
  [9373] = {.lex_state = 32},
  [9374] = {.lex_state = 32},
  [9375] = {.lex_state = 87, .external_lex_state = 29},
  [9376] = {.lex_state = 87, .external_lex_state = 55},
  [9377] = {.lex_state = 87, .external_lex_state = 56},
  [9378] = {.lex_state = 87, .external_lex_state = 57},
  [9379] = {.lex_state = 80, .external_lex_state = 33},
  [9380] = {.lex_state = 87, .external_lex_state = 58},
  [9381] = {.lex_state = 38},
  [9382] = {.lex_state = 87, .external_lex_state = 58},
  [9383] = {.lex_state = 87, .external_lex_state = 58},
  [9384] = {.lex_state = 81, .external_lex_state = 49},
  [9385] = {.lex_state = 32},
  [9386] = {.lex_state = 92, .external_lex_state = 49},
  [9387] = {.lex_state = 93, .external_lex_state = 35},
  [9388] = {.lex_state = 32},
  [9389] = {.lex_state = 32},
  [9390] = {.lex_state = 87, .external_lex_state = 29},
  [9391] = {.lex_state = 32},
  [9392] = {.lex_state = 79, .external_lex_state = 35},
  [9393] = {.lex_state = 82, .external_lex_state = 49},
  [9394] = {.lex_state = 87, .external_lex_state = 58},
  [9395] = {.lex_state = 15, .external_lex_state = 49},
  [9396] = {.lex_state = 78, .external_lex_state = 35},
  [9397] = {.lex_state = 87, .external_lex_state = 29},
  [9398] = {.lex_state = 32},
  [9399] = {.lex_state = 87, .external_lex_state = 24},
  [9400] = {.lex_state = 87, .external_lex_state = 29},
  [9401] = {.lex_state = 12, .external_lex_state = 49},
  [9402] = {.lex_state = 87, .external_lex_state = 57},
  [9403] = {.lex_state = 90, .external_lex_state = 34},
  [9404] = {.lex_state = 87, .external_lex_state = 58},
  [9405] = {.lex_state = 87, .external_lex_state = 57},
  [9406] = {.lex_state = 32},
  [9407] = {.lex_state = 87, .external_lex_state = 56},
  [9408] = {.lex_state = 32},
  [9409] = {.lex_state = 15, .external_lex_state = 49},
  [9410] = {.lex_state = 87, .external_lex_state = 24},
  [9411] = {.lex_state = 90, .external_lex_state = 30},
  [9412] = {.lex_state = 96, .external_lex_state = 49},
  [9413] = {.lex_state = 28, .external_lex_state = 49},
  [9414] = {.lex_state = 99, .external_lex_state = 35},
  [9415] = {.lex_state = 79, .external_lex_state = 35},
  [9416] = {.lex_state = 32},
  [9417] = {.lex_state = 90, .external_lex_state = 30},
  [9418] = {.lex_state = 32},
  [9419] = {.lex_state = 32},
  [9420] = {.lex_state = 80, .external_lex_state = 35},
  [9421] = {.lex_state = 82, .external_lex_state = 49},
  [9422] = {.lex_state = 100, .external_lex_state = 50},
  [9423] = {.lex_state = 32},
  [9424] = {.lex_state = 97, .external_lex_state = 40},
  [9425] = {.lex_state = 80, .external_lex_state = 59},
  [9426] = {.lex_state = 87, .external_lex_state = 56},
  [9427] = {.lex_state = 87, .external_lex_state = 23},
  [9428] = {.lex_state = 81, .external_lex_state = 49},
  [9429] = {.lex_state = 87, .external_lex_state = 57},
  [9430] = {.lex_state = 87, .external_lex_state = 57},
  [9431] = {.lex_state = 87, .external_lex_state = 57},
  [9432] = {.lex_state = 32},
  [9433] = {.lex_state = 87, .external_lex_state = 57},
  [9434] = {.lex_state = 87, .external_lex_state = 24},
  [9435] = {.lex_state = 97, .external_lex_state = 40},
  [9436] = {.lex_state = 87, .external_lex_state = 29},
  [9437] = {.lex_state = 32},
  [9438] = {.lex_state = 97, .external_lex_state = 40},
  [9439] = {.lex_state = 87, .external_lex_state = 56},
  [9440] = {.lex_state = 12, .external_lex_state = 49},
  [9441] = {.lex_state = 15, .external_lex_state = 49},
  [9442] = {.lex_state = 95, .external_lex_state = 23},
  [9443] = {.lex_state = 87, .external_lex_state = 57},
  [9444] = {.lex_state = 32},
  [9445] = {.lex_state = 86, .external_lex_state = 33},
  [9446] = {.lex_state = 97, .external_lex_state = 40},
  [9447] = {.lex_state = 81, .external_lex_state = 49},
  [9448] = {.lex_state = 32},
  [9449] = {.lex_state = 35, .external_lex_state = 49},
  [9450] = {.lex_state = 94, .external_lex_state = 33},
  [9451] = {.lex_state = 87, .external_lex_state = 58},
  [9452] = {.lex_state = 86, .external_lex_state = 33},
  [9453] = {.lex_state = 90, .external_lex_state = 30},
  [9454] = {.lex_state = 97, .external_lex_state = 40},
  [9455] = {.lex_state = 80, .external_lex_state = 59},
  [9456] = {.lex_state = 99, .external_lex_state = 23},
  [9457] = {.lex_state = 80, .external_lex_state = 59},
  [9458] = {.lex_state = 97, .external_lex_state = 40},
  [9459] = {.lex_state = 78, .external_lex_state = 35},
  [9460] = {.lex_state = 82, .external_lex_state = 49},
  [9461] = {.lex_state = 87, .external_lex_state = 56},
  [9462] = {.lex_state = 32},
  [9463] = {.lex_state = 90, .external_lex_state = 30},
  [9464] = {.lex_state = 82, .external_lex_state = 49},
  [9465] = {.lex_state = 38},
  [9466] = {.lex_state = 32},
  [9467] = {.lex_state = 87, .external_lex_state = 58},
  [9468] = {.lex_state = 87, .external_lex_state = 58},
  [9469] = {.lex_state = 87, .external_lex_state = 29},
  [9470] = {.lex_state = 32},
  [9471] = {.lex_state = 32},
  [9472] = {.lex_state = 32},
  [9473] = {.lex_state = 94, .external_lex_state = 27},
  [9474] = {.lex_state = 96, .external_lex_state = 49},
  [9475] = {.lex_state = 95, .external_lex_state = 46},
  [9476] = {.lex_state = 87, .external_lex_state = 56},
  [9477] = {.lex_state = 32},
  [9478] = {.lex_state = 88, .external_lex_state = 35},
  [9479] = {.lex_state = 87, .external_lex_state = 29},
  [9480] = {.lex_state = 82, .external_lex_state = 49},
  [9481] = {.lex_state = 90, .external_lex_state = 46},
  [9482] = {.lex_state = 87, .external_lex_state = 49},
  [9483] = {.lex_state = 87, .external_lex_state = 57},
  [9484] = {.lex_state = 87, .external_lex_state = 57},
  [9485] = {.lex_state = 32},
  [9486] = {.lex_state = 87, .external_lex_state = 30},
  [9487] = {.lex_state = 97, .external_lex_state = 40},
  [9488] = {.lex_state = 90, .external_lex_state = 45},
  [9489] = {.lex_state = 87, .external_lex_state = 46},
  [9490] = {.lex_state = 32},
  [9491] = {.lex_state = 92, .external_lex_state = 49},
  [9492] = {.lex_state = 96, .external_lex_state = 50},
  [9493] = {.lex_state = 81, .external_lex_state = 49},
  [9494] = {.lex_state = 87, .external_lex_state = 57},
  [9495] = {.lex_state = 95, .external_lex_state = 45},
  [9496] = {.lex_state = 87, .external_lex_state = 29},
  [9497] = {.lex_state = 81, .external_lex_state = 49},
  [9498] = {.lex_state = 87, .external_lex_state = 57},
  [9499] = {.lex_state = 79, .external_lex_state = 35},
  [9500] = {.lex_state = 95, .external_lex_state = 45},
  [9501] = {.lex_state = 87, .external_lex_state = 58},
  [9502] = {.lex_state = 97, .external_lex_state = 40},
  [9503] = {.lex_state = 87, .external_lex_state = 56},
  [9504] = {.lex_state = 35, .external_lex_state = 49},
  [9505] = {.lex_state = 97, .external_lex_state = 40},
  [9506] = {.lex_state = 95, .external_lex_state = 45},
  [9507] = {.lex_state = 87, .external_lex_state = 57},
  [9508] = {.lex_state = 95, .external_lex_state = 23},
  [9509] = {.lex_state = 95, .external_lex_state = 56},
  [9510] = {.lex_state = 87, .external_lex_state = 57},
  [9511] = {.lex_state = 82, .external_lex_state = 49},
  [9512] = {.lex_state = 30, .external_lex_state = 49},
  [9513] = {.lex_state = 32},
  [9514] = {.lex_state = 87, .external_lex_state = 56},
  [9515] = {.lex_state = 95, .external_lex_state = 45},
  [9516] = {.lex_state = 87, .external_lex_state = 29},
  [9517] = {.lex_state = 32},
  [9518] = {.lex_state = 90, .external_lex_state = 40},
  [9519] = {.lex_state = 95, .external_lex_state = 45},
  [9520] = {.lex_state = 32},
  [9521] = {.lex_state = 15, .external_lex_state = 49},
  [9522] = {.lex_state = 81, .external_lex_state = 49},
  [9523] = {.lex_state = 32},
  [9524] = {.lex_state = 88, .external_lex_state = 33},
  [9525] = {.lex_state = 32},
  [9526] = {.lex_state = 87, .external_lex_state = 24},
  [9527] = {.lex_state = 87, .external_lex_state = 32},
  [9528] = {.lex_state = 32},
  [9529] = {.lex_state = 87, .external_lex_state = 58},
  [9530] = {.lex_state = 87, .external_lex_state = 57},
  [9531] = {.lex_state = 87, .external_lex_state = 57},
  [9532] = {.lex_state = 97, .external_lex_state = 53},
  [9533] = {.lex_state = 78, .external_lex_state = 35},
  [9534] = {.lex_state = 32},
  [9535] = {.lex_state = 32},
  [9536] = {.lex_state = 32},
  [9537] = {.lex_state = 15, .external_lex_state = 49},
  [9538] = {.lex_state = 87, .external_lex_state = 58},
  [9539] = {.lex_state = 79, .external_lex_state = 35},
  [9540] = {.lex_state = 87, .external_lex_state = 57},
  [9541] = {.lex_state = 32},
  [9542] = {.lex_state = 32},
  [9543] = {.lex_state = 86, .external_lex_state = 33},
  [9544] = {.lex_state = 87, .external_lex_state = 57},
  [9545] = {.lex_state = 87, .external_lex_state = 49},
  [9546] = {.lex_state = 87, .external_lex_state = 56},
  [9547] = {.lex_state = 89, .external_lex_state = 50},
  [9548] = {.lex_state = 87, .external_lex_state = 57},
  [9549] = {.lex_state = 6},
  [9550] = {.lex_state = 99, .external_lex_state = 24},
  [9551] = {.lex_state = 87, .external_lex_state = 57},
  [9552] = {.lex_state = 15, .external_lex_state = 49},
  [9553] = {.lex_state = 89, .external_lex_state = 50},
  [9554] = {.lex_state = 32},
  [9555] = {.lex_state = 87, .external_lex_state = 57},
  [9556] = {.lex_state = 87, .external_lex_state = 58},
  [9557] = {.lex_state = 32},
  [9558] = {.lex_state = 82, .external_lex_state = 49},
  [9559] = {.lex_state = 87, .external_lex_state = 39},
  [9560] = {.lex_state = 87, .external_lex_state = 57},
  [9561] = {.lex_state = 87, .external_lex_state = 58},
  [9562] = {.lex_state = 87, .external_lex_state = 57},
  [9563] = {.lex_state = 87, .external_lex_state = 57},
  [9564] = {.lex_state = 90, .external_lex_state = 46},
  [9565] = {.lex_state = 87, .external_lex_state = 57},
  [9566] = {.lex_state = 87, .external_lex_state = 56},
  [9567] = {.lex_state = 87, .external_lex_state = 57},
  [9568] = {.lex_state = 6},
  [9569] = {.lex_state = 87, .external_lex_state = 57},
  [9570] = {.lex_state = 75},
  [9571] = {.lex_state = 87, .external_lex_state = 56},
  [9572] = {.lex_state = 95, .external_lex_state = 46},
  [9573] = {.lex_state = 87, .external_lex_state = 57},
  [9574] = {.lex_state = 38},
  [9575] = {.lex_state = 87, .external_lex_state = 29},
  [9576] = {.lex_state = 6},
  [9577] = {.lex_state = 90, .external_lex_state = 30},
  [9578] = {.lex_state = 87, .external_lex_state = 56},
  [9579] = {.lex_state = 95, .external_lex_state = 57},
  [9580] = {.lex_state = 79, .external_lex_state = 35},
  [9581] = {.lex_state = 89, .external_lex_state = 50},
  [9582] = {.lex_state = 94, .external_lex_state = 27},
  [9583] = {.lex_state = 32},
  [9584] = {.lex_state = 32},
  [9585] = {.lex_state = 32},
  [9586] = {.lex_state = 87, .external_lex_state = 56},
  [9587] = {.lex_state = 87, .external_lex_state = 58},
  [9588] = {.lex_state = 95, .external_lex_state = 30},
  [9589] = {.lex_state = 80, .external_lex_state = 59},
  [9590] = {.lex_state = 90, .external_lex_state = 51},
  [9591] = {.lex_state = 97, .external_lex_state = 23},
  [9592] = {.lex_state = 80, .external_lex_state = 59},
  [9593] = {.lex_state = 87, .external_lex_state = 30},
  [9594] = {.lex_state = 87, .external_lex_state = 34},
  [9595] = {.lex_state = 87, .external_lex_state = 34},
  [9596] = {.lex_state = 32},
  [9597] = {.lex_state = 20, .external_lex_state = 2},
  [9598] = {.lex_state = 80, .external_lex_state = 59},
  [9599] = {.lex_state = 87, .external_lex_state = 34},
  [9600] = {.lex_state = 32},
  [9601] = {.lex_state = 80, .external_lex_state = 59},
  [9602] = {.lex_state = 87, .external_lex_state = 34},
  [9603] = {.lex_state = 30, .external_lex_state = 49},
  [9604] = {.lex_state = 97, .external_lex_state = 46},
  [9605] = {.lex_state = 88, .external_lex_state = 35},
  [9606] = {.lex_state = 80, .external_lex_state = 59},
  [9607] = {.lex_state = 87, .external_lex_state = 35},
  [9608] = {.lex_state = 97, .external_lex_state = 46},
  [9609] = {.lex_state = 100, .external_lex_state = 35},
  [9610] = {.lex_state = 80, .external_lex_state = 59},
  [9611] = {.lex_state = 20, .external_lex_state = 2},
  [9612] = {.lex_state = 97, .external_lex_state = 46},
  [9613] = {.lex_state = 87, .external_lex_state = 32},
  [9614] = {.lex_state = 87, .external_lex_state = 23},
  [9615] = {.lex_state = 87, .external_lex_state = 30},
  [9616] = {.lex_state = 87, .external_lex_state = 34},
  [9617] = {.lex_state = 88, .external_lex_state = 32},
  [9618] = {.lex_state = 87, .external_lex_state = 34},
  [9619] = {.lex_state = 97, .external_lex_state = 46},
  [9620] = {.lex_state = 87, .external_lex_state = 30},
  [9621] = {.lex_state = 97, .external_lex_state = 46},
  [9622] = {.lex_state = 95, .external_lex_state = 54},
  [9623] = {.lex_state = 88, .external_lex_state = 35},
  [9624] = {.lex_state = 87},
  [9625] = {.lex_state = 87, .external_lex_state = 34},
  [9626] = {.lex_state = 80, .external_lex_state = 59},
  [9627] = {.lex_state = 20, .external_lex_state = 2},
  [9628] = {.lex_state = 87, .external_lex_state = 30},
  [9629] = {.lex_state = 90, .external_lex_state = 38},
  [9630] = {.lex_state = 95, .external_lex_state = 55},
  [9631] = {.lex_state = 97, .external_lex_state = 23},
  [9632] = {.lex_state = 87, .external_lex_state = 34},
  [9633] = {.lex_state = 95, .external_lex_state = 53},
  [9634] = {.lex_state = 90, .external_lex_state = 23},
  [9635] = {.lex_state = 87, .external_lex_state = 30},
  [9636] = {.lex_state = 87, .external_lex_state = 34},
  [9637] = {.lex_state = 97, .external_lex_state = 57},
  [9638] = {.lex_state = 87, .external_lex_state = 24},
  [9639] = {.lex_state = 75, .external_lex_state = 50},
  [9640] = {.lex_state = 87, .external_lex_state = 32},
  [9641] = {.lex_state = 87, .external_lex_state = 24},
  [9642] = {.lex_state = 87, .external_lex_state = 34},
  [9643] = {.lex_state = 87, .external_lex_state = 30},
  [9644] = {.lex_state = 90, .external_lex_state = 38},
  [9645] = {.lex_state = 87},
  [9646] = {.lex_state = 87},
  [9647] = {.lex_state = 97, .external_lex_state = 23},
  [9648] = {.lex_state = 29, .external_lex_state = 49},
  [9649] = {.lex_state = 87, .external_lex_state = 30},
  [9650] = {.lex_state = 87, .external_lex_state = 30},
  [9651] = {.lex_state = 90, .external_lex_state = 39},
  [9652] = {.lex_state = 87, .external_lex_state = 34},
  [9653] = {.lex_state = 90, .external_lex_state = 38},
  [9654] = {.lex_state = 90, .external_lex_state = 45},
  [9655] = {.lex_state = 95, .external_lex_state = 55},
  [9656] = {.lex_state = 99, .external_lex_state = 35},
  [9657] = {.lex_state = 97, .external_lex_state = 23},
  [9658] = {.lex_state = 90, .external_lex_state = 40},
  [9659] = {.lex_state = 90, .external_lex_state = 40},
  [9660] = {.lex_state = 87, .external_lex_state = 57},
  [9661] = {.lex_state = 20, .external_lex_state = 2},
  [9662] = {.lex_state = 87, .external_lex_state = 30},
  [9663] = {.lex_state = 90, .external_lex_state = 39},
  [9664] = {.lex_state = 87, .external_lex_state = 30},
  [9665] = {.lex_state = 95, .external_lex_state = 55},
  [9666] = {.lex_state = 87, .external_lex_state = 34},
  [9667] = {.lex_state = 97, .external_lex_state = 23},
  [9668] = {.lex_state = 81, .external_lex_state = 49},
  [9669] = {.lex_state = 90, .external_lex_state = 38},
  [9670] = {.lex_state = 87, .external_lex_state = 30},
  [9671] = {.lex_state = 20, .external_lex_state = 2},
  [9672] = {.lex_state = 87, .external_lex_state = 34},
  [9673] = {.lex_state = 88, .external_lex_state = 35},
  [9674] = {.lex_state = 100, .external_lex_state = 50},
  [9675] = {.lex_state = 97, .external_lex_state = 45},
  [9676] = {.lex_state = 86, .external_lex_state = 35},
  [9677] = {.lex_state = 31},
  [9678] = {.lex_state = 94, .external_lex_state = 35},
  [9679] = {.lex_state = 75, .external_lex_state = 23},
  [9680] = {.lex_state = 97, .external_lex_state = 45},
  [9681] = {.lex_state = 87, .external_lex_state = 34},
  [9682] = {.lex_state = 87},
  [9683] = {.lex_state = 97, .external_lex_state = 23},
  [9684] = {.lex_state = 96, .external_lex_state = 50},
  [9685] = {.lex_state = 97, .external_lex_state = 45},
  [9686] = {.lex_state = 90, .external_lex_state = 39},
  [9687] = {.lex_state = 95, .external_lex_state = 54},
  [9688] = {.lex_state = 95, .external_lex_state = 54},
  [9689] = {.lex_state = 95, .external_lex_state = 55},
  [9690] = {.lex_state = 95, .external_lex_state = 53},
  [9691] = {.lex_state = 87, .external_lex_state = 30},
  [9692] = {.lex_state = 80, .external_lex_state = 49},
  [9693] = {.lex_state = 87, .external_lex_state = 30},
  [9694] = {.lex_state = 97, .external_lex_state = 45},
  [9695] = {.lex_state = 87, .external_lex_state = 34},
  [9696] = {.lex_state = 87, .external_lex_state = 34},
  [9697] = {.lex_state = 87},
  [9698] = {.lex_state = 97, .external_lex_state = 45},
  [9699] = {.lex_state = 87},
  [9700] = {.lex_state = 97, .external_lex_state = 45},
  [9701] = {.lex_state = 95, .external_lex_state = 53},
  [9702] = {.lex_state = 94, .external_lex_state = 33},
  [9703] = {.lex_state = 75, .external_lex_state = 35},
  [9704] = {.lex_state = 95, .external_lex_state = 53},
  [9705] = {.lex_state = 95, .external_lex_state = 53},
  [9706] = {.lex_state = 37, .external_lex_state = 49},
  [9707] = {.lex_state = 87, .external_lex_state = 30},
  [9708] = {.lex_state = 90, .external_lex_state = 55},
  [9709] = {.lex_state = 95, .external_lex_state = 53},
  [9710] = {.lex_state = 97, .external_lex_state = 23},
  [9711] = {.lex_state = 90, .external_lex_state = 40},
  [9712] = {.lex_state = 88, .external_lex_state = 59},
  [9713] = {.lex_state = 81, .external_lex_state = 49},
  [9714] = {.lex_state = 95, .external_lex_state = 53},
  [9715] = {.lex_state = 97, .external_lex_state = 23},
  [9716] = {.lex_state = 4},
  [9717] = {.lex_state = 80, .external_lex_state = 35},
  [9718] = {.lex_state = 100, .external_lex_state = 50},
  [9719] = {.lex_state = 39, .external_lex_state = 49},
  [9720] = {.lex_state = 88, .external_lex_state = 59},
  [9721] = {.lex_state = 90, .external_lex_state = 39},
  [9722] = {.lex_state = 90, .external_lex_state = 23},
  [9723] = {.lex_state = 95, .external_lex_state = 53},
  [9724] = {.lex_state = 95, .external_lex_state = 54},
  [9725] = {.lex_state = 31},
  [9726] = {.lex_state = 99, .external_lex_state = 35},
  [9727] = {.lex_state = 95, .external_lex_state = 53},
  [9728] = {.lex_state = 97, .external_lex_state = 23},
  [9729] = {.lex_state = 37, .external_lex_state = 49},
  [9730] = {.lex_state = 87, .external_lex_state = 38},
  [9731] = {.lex_state = 97, .external_lex_state = 45},
  [9732] = {.lex_state = 90, .external_lex_state = 40},
  [9733] = {.lex_state = 15, .external_lex_state = 49},
  [9734] = {.lex_state = 75, .external_lex_state = 49},
  [9735] = {.lex_state = 90, .external_lex_state = 38},
  [9736] = {.lex_state = 97, .external_lex_state = 45},
  [9737] = {.lex_state = 89, .external_lex_state = 35},
  [9738] = {.lex_state = 97, .external_lex_state = 45},
  [9739] = {.lex_state = 95, .external_lex_state = 55},
  [9740] = {.lex_state = 95, .external_lex_state = 55},
  [9741] = {.lex_state = 87},
  [9742] = {.lex_state = 36, .external_lex_state = 49},
  [9743] = {.lex_state = 95, .external_lex_state = 51},
  [9744] = {.lex_state = 80, .external_lex_state = 59},
  [9745] = {.lex_state = 80, .external_lex_state = 35},
  [9746] = {.lex_state = 96, .external_lex_state = 50},
  [9747] = {.lex_state = 75, .external_lex_state = 49},
  [9748] = {.lex_state = 95, .external_lex_state = 55},
  [9749] = {.lex_state = 96, .external_lex_state = 32},
  [9750] = {.lex_state = 95, .external_lex_state = 34},
  [9751] = {.lex_state = 90, .external_lex_state = 40},
  [9752] = {.lex_state = 90, .external_lex_state = 40},
  [9753] = {.lex_state = 75, .external_lex_state = 23},
  [9754] = {.lex_state = 32},
  [9755] = {.lex_state = 90, .external_lex_state = 40},
  [9756] = {.lex_state = 94, .external_lex_state = 33},
  [9757] = {.lex_state = 87, .external_lex_state = 24},
  [9758] = {.lex_state = 89, .external_lex_state = 49},
  [9759] = {.lex_state = 90, .external_lex_state = 55},
  [9760] = {.lex_state = 87},
  [9761] = {.lex_state = 90, .external_lex_state = 38},
  [9762] = {.lex_state = 4},
  [9763] = {.lex_state = 87, .external_lex_state = 24},
  [9764] = {.lex_state = 37, .external_lex_state = 49},
  [9765] = {.lex_state = 87},
  [9766] = {.lex_state = 87},
  [9767] = {.lex_state = 87, .external_lex_state = 30},
  [9768] = {.lex_state = 39},
  [9769] = {.lex_state = 95, .external_lex_state = 53},
  [9770] = {.lex_state = 87, .external_lex_state = 24},
  [9771] = {.lex_state = 89, .external_lex_state = 35},
  [9772] = {.lex_state = 90, .external_lex_state = 38},
  [9773] = {.lex_state = 20, .external_lex_state = 2},
  [9774] = {.lex_state = 89, .external_lex_state = 35},
  [9775] = {.lex_state = 90, .external_lex_state = 39},
  [9776] = {.lex_state = 80, .external_lex_state = 59},
  [9777] = {.lex_state = 32},
  [9778] = {.lex_state = 15, .external_lex_state = 49},
  [9779] = {.lex_state = 87, .external_lex_state = 24},
  [9780] = {.lex_state = 90, .external_lex_state = 23},
  [9781] = {.lex_state = 90, .external_lex_state = 38},
  [9782] = {.lex_state = 100, .external_lex_state = 35},
  [9783] = {.lex_state = 86, .external_lex_state = 35},
  [9784] = {.lex_state = 32},
  [9785] = {.lex_state = 90, .external_lex_state = 39},
  [9786] = {.lex_state = 90, .external_lex_state = 39},
  [9787] = {.lex_state = 87, .external_lex_state = 34},
  [9788] = {.lex_state = 95, .external_lex_state = 51},
  [9789] = {.lex_state = 87, .external_lex_state = 53},
  [9790] = {.lex_state = 95, .external_lex_state = 51},
  [9791] = {.lex_state = 90, .external_lex_state = 53},
  [9792] = {.lex_state = 32},
  [9793] = {.lex_state = 87, .external_lex_state = 24},
  [9794] = {.lex_state = 87, .external_lex_state = 53},
  [9795] = {.lex_state = 87},
  [9796] = {.lex_state = 4},
  [9797] = {.lex_state = 90, .external_lex_state = 39},
  [9798] = {.lex_state = 87, .external_lex_state = 24},
  [9799] = {.lex_state = 80, .external_lex_state = 59},
  [9800] = {.lex_state = 87},
  [9801] = {.lex_state = 89, .external_lex_state = 35},
  [9802] = {.lex_state = 39, .external_lex_state = 49},
  [9803] = {.lex_state = 95, .external_lex_state = 51},
  [9804] = {.lex_state = 87, .external_lex_state = 24},
  [9805] = {.lex_state = 75, .external_lex_state = 23},
  [9806] = {.lex_state = 87, .external_lex_state = 24},
  [9807] = {.lex_state = 87, .external_lex_state = 38},
  [9808] = {.lex_state = 87, .external_lex_state = 30},
  [9809] = {.lex_state = 89, .external_lex_state = 35},
  [9810] = {.lex_state = 32},
  [9811] = {.lex_state = 95, .external_lex_state = 51},
  [9812] = {.lex_state = 87, .external_lex_state = 30},
  [9813] = {.lex_state = 90, .external_lex_state = 53},
  [9814] = {.lex_state = 4},
  [9815] = {.lex_state = 87, .external_lex_state = 30},
  [9816] = {.lex_state = 87, .external_lex_state = 33},
  [9817] = {.lex_state = 95, .external_lex_state = 51},
  [9818] = {.lex_state = 80, .external_lex_state = 59},
  [9819] = {.lex_state = 87, .external_lex_state = 24},
  [9820] = {.lex_state = 80, .external_lex_state = 59},
  [9821] = {.lex_state = 97, .external_lex_state = 45},
  [9822] = {.lex_state = 80, .external_lex_state = 59},
  [9823] = {.lex_state = 89, .external_lex_state = 50},
  [9824] = {.lex_state = 87, .external_lex_state = 34},
  [9825] = {.lex_state = 87, .external_lex_state = 34},
  [9826] = {.lex_state = 97, .external_lex_state = 46},
  [9827] = {.lex_state = 87, .external_lex_state = 56},
  [9828] = {.lex_state = 87},
  [9829] = {.lex_state = 87, .external_lex_state = 24},
  [9830] = {.lex_state = 97, .external_lex_state = 46},
  [9831] = {.lex_state = 97, .external_lex_state = 46},
  [9832] = {.lex_state = 87, .external_lex_state = 30},
  [9833] = {.lex_state = 90, .external_lex_state = 46},
  [9834] = {.lex_state = 87, .external_lex_state = 24},
  [9835] = {.lex_state = 30, .external_lex_state = 49},
  [9836] = {.lex_state = 90, .external_lex_state = 38},
  [9837] = {.lex_state = 31},
  [9838] = {.lex_state = 87, .external_lex_state = 54},
  [9839] = {.lex_state = 87, .external_lex_state = 23},
  [9840] = {.lex_state = 30, .external_lex_state = 49},
  [9841] = {.lex_state = 87, .external_lex_state = 30},
  [9842] = {.lex_state = 87, .external_lex_state = 34},
  [9843] = {.lex_state = 75, .external_lex_state = 51},
  [9844] = {.lex_state = 87, .external_lex_state = 58},
  [9845] = {.lex_state = 76, .external_lex_state = 23},
  [9846] = {.lex_state = 87, .external_lex_state = 34},
  [9847] = {.lex_state = 87, .external_lex_state = 40},
  [9848] = {.lex_state = 87, .external_lex_state = 23},
  [9849] = {.lex_state = 31},
  [9850] = {.lex_state = 32},
  [9851] = {.lex_state = 30, .external_lex_state = 49},
  [9852] = {.lex_state = 89, .external_lex_state = 49},
  [9853] = {.lex_state = 35, .external_lex_state = 49},
  [9854] = {.lex_state = 4},
  [9855] = {.lex_state = 75, .external_lex_state = 24},
  [9856] = {.lex_state = 37, .external_lex_state = 49},
  [9857] = {.lex_state = 87, .external_lex_state = 24},
  [9858] = {.lex_state = 87, .external_lex_state = 30},
  [9859] = {.lex_state = 87, .external_lex_state = 30},
  [9860] = {.lex_state = 35, .external_lex_state = 49},
  [9861] = {.lex_state = 87, .external_lex_state = 30},
  [9862] = {.lex_state = 87, .external_lex_state = 29},
  [9863] = {.lex_state = 35, .external_lex_state = 49},
  [9864] = {.lex_state = 32},
  [9865] = {.lex_state = 35, .external_lex_state = 49},
  [9866] = {.lex_state = 97, .external_lex_state = 23},
  [9867] = {.lex_state = 87, .external_lex_state = 23},
  [9868] = {.lex_state = 87, .external_lex_state = 34},
  [9869] = {.lex_state = 90, .external_lex_state = 40},
  [9870] = {.lex_state = 87, .external_lex_state = 24},
  [9871] = {.lex_state = 97, .external_lex_state = 58},
  [9872] = {.lex_state = 87, .external_lex_state = 30},
  [9873] = {.lex_state = 87, .external_lex_state = 24},
  [9874] = {.lex_state = 87, .external_lex_state = 24},
  [9875] = {.lex_state = 87, .external_lex_state = 24},
  [9876] = {.lex_state = 100, .external_lex_state = 35},
  [9877] = {.lex_state = 96, .external_lex_state = 27},
  [9878] = {.lex_state = 87, .external_lex_state = 23},
  [9879] = {.lex_state = 87},
  [9880] = {.lex_state = 87, .external_lex_state = 24},
  [9881] = {.lex_state = 95, .external_lex_state = 54},
  [9882] = {.lex_state = 95, .external_lex_state = 55},
  [9883] = {.lex_state = 92, .external_lex_state = 49},
  [9884] = {.lex_state = 36, .external_lex_state = 49},
  [9885] = {.lex_state = 87, .external_lex_state = 40},
  [9886] = {.lex_state = 87, .external_lex_state = 34},
  [9887] = {.lex_state = 95, .external_lex_state = 54},
  [9888] = {.lex_state = 96, .external_lex_state = 28},
  [9889] = {.lex_state = 87, .external_lex_state = 30},
  [9890] = {.lex_state = 99, .external_lex_state = 23},
  [9891] = {.lex_state = 87},
  [9892] = {.lex_state = 75, .external_lex_state = 55},
  [9893] = {.lex_state = 87, .external_lex_state = 24},
  [9894] = {.lex_state = 87, .external_lex_state = 30},
  [9895] = {.lex_state = 87, .external_lex_state = 38},
  [9896] = {.lex_state = 90, .external_lex_state = 51},
  [9897] = {.lex_state = 96, .external_lex_state = 28},
  [9898] = {.lex_state = 87},
  [9899] = {.lex_state = 87, .external_lex_state = 30},
  [9900] = {.lex_state = 32},
  [9901] = {.lex_state = 87, .external_lex_state = 57},
  [9902] = {.lex_state = 95, .external_lex_state = 24},
  [9903] = {.lex_state = 95, .external_lex_state = 54},
  [9904] = {.lex_state = 95, .external_lex_state = 55},
  [9905] = {.lex_state = 87, .external_lex_state = 40},
  [9906] = {.lex_state = 32},
  [9907] = {.lex_state = 75, .external_lex_state = 49},
  [9908] = {.lex_state = 87, .external_lex_state = 24},
  [9909] = {.lex_state = 90, .external_lex_state = 40},
  [9910] = {.lex_state = 87, .external_lex_state = 33},
  [9911] = {.lex_state = 95, .external_lex_state = 54},
  [9912] = {.lex_state = 82, .external_lex_state = 49},
  [9913] = {.lex_state = 32},
  [9914] = {.lex_state = 87},
  [9915] = {.lex_state = 87},
  [9916] = {.lex_state = 87},
  [9917] = {.lex_state = 95, .external_lex_state = 54},
  [9918] = {.lex_state = 95, .external_lex_state = 51},
  [9919] = {.lex_state = 87},
  [9920] = {.lex_state = 87, .external_lex_state = 34},
  [9921] = {.lex_state = 75, .external_lex_state = 55},
  [9922] = {.lex_state = 90, .external_lex_state = 54},
  [9923] = {.lex_state = 87},
  [9924] = {.lex_state = 87, .external_lex_state = 24},
  [9925] = {.lex_state = 87, .external_lex_state = 24},
  [9926] = {.lex_state = 93, .external_lex_state = 35},
  [9927] = {.lex_state = 87, .external_lex_state = 24},
  [9928] = {.lex_state = 87, .external_lex_state = 34},
  [9929] = {.lex_state = 87, .external_lex_state = 24},
  [9930] = {.lex_state = 87, .external_lex_state = 34},
  [9931] = {.lex_state = 87, .external_lex_state = 24},
  [9932] = {.lex_state = 87},
  [9933] = {.lex_state = 32},
  [9934] = {.lex_state = 87, .external_lex_state = 30},
  [9935] = {.lex_state = 87, .external_lex_state = 30},
  [9936] = {.lex_state = 78, .external_lex_state = 49},
  [9937] = {.lex_state = 96, .external_lex_state = 33},
  [9938] = {.lex_state = 95, .external_lex_state = 51},
  [9939] = {.lex_state = 87, .external_lex_state = 29},
  [9940] = {.lex_state = 92, .external_lex_state = 49},
  [9941] = {.lex_state = 32},
  [9942] = {.lex_state = 87, .external_lex_state = 24},
  [9943] = {.lex_state = 94, .external_lex_state = 32},
  [9944] = {.lex_state = 87, .external_lex_state = 24},
  [9945] = {.lex_state = 87},
  [9946] = {.lex_state = 82, .external_lex_state = 49},
  [9947] = {.lex_state = 87},
  [9948] = {.lex_state = 20, .external_lex_state = 2},
  [9949] = {.lex_state = 87},
  [9950] = {.lex_state = 87, .external_lex_state = 24},
  [9951] = {.lex_state = 87, .external_lex_state = 23},
  [9952] = {.lex_state = 87},
  [9953] = {.lex_state = 87},
  [9954] = {.lex_state = 87},
  [9955] = {.lex_state = 87},
  [9956] = {.lex_state = 87, .external_lex_state = 45},
  [9957] = {.lex_state = 87},
  [9958] = {.lex_state = 20, .external_lex_state = 2},
  [9959] = {.lex_state = 94, .external_lex_state = 32},
  [9960] = {.lex_state = 87, .external_lex_state = 34},
  [9961] = {.lex_state = 95, .external_lex_state = 55},
  [9962] = {.lex_state = 87, .external_lex_state = 34},
  [9963] = {.lex_state = 90, .external_lex_state = 39},
  [9964] = {.lex_state = 97, .external_lex_state = 46},
  [9965] = {.lex_state = 87, .external_lex_state = 34},
  [9966] = {.lex_state = 87, .external_lex_state = 40},
  [9967] = {.lex_state = 87, .external_lex_state = 30},
  [9968] = {.lex_state = 87, .external_lex_state = 30},
  [9969] = {.lex_state = 87, .external_lex_state = 34},
  [9970] = {.lex_state = 40, .external_lex_state = 49},
  [9971] = {.lex_state = 75, .external_lex_state = 51},
  [9972] = {.lex_state = 32},
  [9973] = {.lex_state = 96, .external_lex_state = 27},
  [9974] = {.lex_state = 87},
  [9975] = {.lex_state = 90, .external_lex_state = 23},
  [9976] = {.lex_state = 87},
  [9977] = {.lex_state = 87, .external_lex_state = 24},
  [9978] = {.lex_state = 75, .external_lex_state = 23},
  [9979] = {.lex_state = 87, .external_lex_state = 24},
  [9980] = {.lex_state = 97, .external_lex_state = 46},
  [9981] = {.lex_state = 87},
  [9982] = {.lex_state = 95, .external_lex_state = 54},
  [9983] = {.lex_state = 87, .external_lex_state = 29},
  [9984] = {.lex_state = 87},
  [9985] = {.lex_state = 97, .external_lex_state = 29},
  [9986] = {.lex_state = 87, .external_lex_state = 34},
  [9987] = {.lex_state = 32},
  [9988] = {.lex_state = 80, .external_lex_state = 49},
  [9989] = {.lex_state = 97, .external_lex_state = 56},
  [9990] = {.lex_state = 87},
  [9991] = {.lex_state = 88, .external_lex_state = 33},
  [9992] = {.lex_state = 95},
  [9993] = {.lex_state = 87, .external_lex_state = 38},
  [9994] = {.lex_state = 87, .external_lex_state = 56},
  [9995] = {.lex_state = 87, .external_lex_state = 24},
  [9996] = {.lex_state = 95, .external_lex_state = 51},
  [9997] = {.lex_state = 87},
  [9998] = {.lex_state = 32},
  [9999] = {.lex_state = 95, .external_lex_state = 51},
  [10000] = {.lex_state = 87},
  [10001] = {.lex_state = 85, .external_lex_state = 35},
  [10002] = {.lex_state = 88, .external_lex_state = 35},
  [10003] = {.lex_state = 32},
  [10004] = {.lex_state = 87, .external_lex_state = 58},
  [10005] = {.lex_state = 87},
  [10006] = {.lex_state = 87, .external_lex_state = 24},
  [10007] = {.lex_state = 90, .external_lex_state = 54},
  [10008] = {.lex_state = 87, .external_lex_state = 54},
  [10009] = {.lex_state = 87, .external_lex_state = 24},
  [10010] = {.lex_state = 87},
  [10011] = {.lex_state = 95, .external_lex_state = 56},
  [10012] = {.lex_state = 95, .external_lex_state = 56},
  [10013] = {.lex_state = 87, .external_lex_state = 40},
  [10014] = {.lex_state = 99, .external_lex_state = 23},
  [10015] = {.lex_state = 6},
  [10016] = {.lex_state = 90, .external_lex_state = 46},
  [10017] = {.lex_state = 95, .external_lex_state = 29},
  [10018] = {.lex_state = 95, .external_lex_state = 29},
  [10019] = {.lex_state = 6},
  [10020] = {.lex_state = 75, .external_lex_state = 58},
  [10021] = {.lex_state = 16, .external_lex_state = 49},
  [10022] = {.lex_state = 95, .external_lex_state = 58},
  [10023] = {.lex_state = 95, .external_lex_state = 58},
  [10024] = {.lex_state = 87, .external_lex_state = 39},
  [10025] = {.lex_state = 97},
  [10026] = {.lex_state = 90, .external_lex_state = 51},
  [10027] = {.lex_state = 99, .external_lex_state = 23},
  [10028] = {.lex_state = 87, .external_lex_state = 40},
  [10029] = {.lex_state = 99, .external_lex_state = 23},
  [10030] = {.lex_state = 95, .external_lex_state = 58},
  [10031] = {.lex_state = 95, .external_lex_state = 58},
  [10032] = {.lex_state = 95, .external_lex_state = 29},
  [10033] = {.lex_state = 99, .external_lex_state = 23},
  [10034] = {.lex_state = 99, .external_lex_state = 23},
  [10035] = {.lex_state = 90, .external_lex_state = 23},
  [10036] = {.lex_state = 90, .external_lex_state = 56},
  [10037] = {.lex_state = 97, .external_lex_state = 51},
  [10038] = {.lex_state = 90, .external_lex_state = 46},
  [10039] = {.lex_state = 78, .external_lex_state = 49},
  [10040] = {.lex_state = 78, .external_lex_state = 49},
  [10041] = {.lex_state = 95, .external_lex_state = 29},
  [10042] = {.lex_state = 87, .external_lex_state = 35},
  [10043] = {.lex_state = 90, .external_lex_state = 55},
  [10044] = {.lex_state = 78, .external_lex_state = 49},
  [10045] = {.lex_state = 99, .external_lex_state = 23},
  [10046] = {.lex_state = 5},
  [10047] = {.lex_state = 95, .external_lex_state = 57},
  [10048] = {.lex_state = 95, .external_lex_state = 57},
  [10049] = {.lex_state = 97, .external_lex_state = 51},
  [10050] = {.lex_state = 87, .external_lex_state = 23},
  [10051] = {.lex_state = 97, .external_lex_state = 51},
  [10052] = {.lex_state = 97, .external_lex_state = 55},
  [10053] = {.lex_state = 87, .external_lex_state = 40},
  [10054] = {.lex_state = 95, .external_lex_state = 57},
  [10055] = {.lex_state = 95, .external_lex_state = 29},
  [10056] = {.lex_state = 95, .external_lex_state = 29},
  [10057] = {.lex_state = 96, .external_lex_state = 35},
  [10058] = {.lex_state = 87, .external_lex_state = 40},
  [10059] = {.lex_state = 5},
  [10060] = {.lex_state = 78, .external_lex_state = 49},
  [10061] = {.lex_state = 87, .external_lex_state = 40},
  [10062] = {.lex_state = 87, .external_lex_state = 40},
  [10063] = {.lex_state = 90, .external_lex_state = 53},
  [10064] = {.lex_state = 90, .external_lex_state = 46},
  [10065] = {.lex_state = 90, .external_lex_state = 23},
  [10066] = {.lex_state = 96, .external_lex_state = 32},
  [10067] = {.lex_state = 97, .external_lex_state = 54},
  [10068] = {.lex_state = 97, .external_lex_state = 54},
  [10069] = {.lex_state = 87, .external_lex_state = 24},
  [10070] = {.lex_state = 92, .external_lex_state = 49},
  [10071] = {.lex_state = 97, .external_lex_state = 53},
  [10072] = {.lex_state = 96, .external_lex_state = 32},
  [10073] = {.lex_state = 97, .external_lex_state = 54},
  [10074] = {.lex_state = 92, .external_lex_state = 49},
  [10075] = {.lex_state = 97, .external_lex_state = 51},
  [10076] = {.lex_state = 16, .external_lex_state = 49},
  [10077] = {.lex_state = 92, .external_lex_state = 49},
  [10078] = {.lex_state = 87, .external_lex_state = 40},
  [10079] = {.lex_state = 97, .external_lex_state = 51},
  [10080] = {.lex_state = 99, .external_lex_state = 24},
  [10081] = {.lex_state = 16, .external_lex_state = 49},
  [10082] = {.lex_state = 99, .external_lex_state = 24},
  [10083] = {.lex_state = 87, .external_lex_state = 40},
  [10084] = {.lex_state = 87, .external_lex_state = 40},
  [10085] = {.lex_state = 87, .external_lex_state = 38},
  [10086] = {.lex_state = 16, .external_lex_state = 49},
  [10087] = {.lex_state = 75, .external_lex_state = 35},
  [10088] = {.lex_state = 16, .external_lex_state = 49},
  [10089] = {.lex_state = 87, .external_lex_state = 40},
  [10090] = {.lex_state = 5},
  [10091] = {.lex_state = 87, .external_lex_state = 23},
  [10092] = {.lex_state = 99, .external_lex_state = 24},
  [10093] = {.lex_state = 78, .external_lex_state = 49},
  [10094] = {.lex_state = 90, .external_lex_state = 57},
  [10095] = {.lex_state = 87, .external_lex_state = 57},
  [10096] = {.lex_state = 78, .external_lex_state = 49},
  [10097] = {.lex_state = 92, .external_lex_state = 49},
  [10098] = {.lex_state = 6},
  [10099] = {.lex_state = 75, .external_lex_state = 35},
  [10100] = {.lex_state = 87, .external_lex_state = 38},
  [10101] = {.lex_state = 16, .external_lex_state = 49},
  [10102] = {.lex_state = 97},
  [10103] = {.lex_state = 6},
  [10104] = {.lex_state = 99, .external_lex_state = 23},
  [10105] = {.lex_state = 5},
  [10106] = {.lex_state = 99, .external_lex_state = 24},
  [10107] = {.lex_state = 87, .external_lex_state = 35},
  [10108] = {.lex_state = 97},
  [10109] = {.lex_state = 97},
  [10110] = {.lex_state = 87, .external_lex_state = 40},
  [10111] = {.lex_state = 97},
  [10112] = {.lex_state = 87, .external_lex_state = 40},
  [10113] = {.lex_state = 89, .external_lex_state = 49},
  [10114] = {.lex_state = 78, .external_lex_state = 49},
  [10115] = {.lex_state = 95, .external_lex_state = 57},
  [10116] = {.lex_state = 89, .external_lex_state = 49},
  [10117] = {.lex_state = 38},
  [10118] = {.lex_state = 99, .external_lex_state = 24},
  [10119] = {.lex_state = 89, .external_lex_state = 49},
  [10120] = {.lex_state = 78, .external_lex_state = 49},
  [10121] = {.lex_state = 87, .external_lex_state = 34},
  [10122] = {.lex_state = 7},
  [10123] = {.lex_state = 87, .external_lex_state = 40},
  [10124] = {.lex_state = 97},
  [10125] = {.lex_state = 95, .external_lex_state = 38},
  [10126] = {.lex_state = 97, .external_lex_state = 53},
  [10127] = {.lex_state = 36, .external_lex_state = 49},
  [10128] = {.lex_state = 90, .external_lex_state = 23},
  [10129] = {.lex_state = 78, .external_lex_state = 49},
  [10130] = {.lex_state = 36, .external_lex_state = 49},
  [10131] = {.lex_state = 90, .external_lex_state = 46},
  [10132] = {.lex_state = 6},
  [10133] = {.lex_state = 36, .external_lex_state = 49},
  [10134] = {.lex_state = 90, .external_lex_state = 46},
  [10135] = {.lex_state = 90, .external_lex_state = 58},
  [10136] = {.lex_state = 78, .external_lex_state = 49},
  [10137] = {.lex_state = 6},
  [10138] = {.lex_state = 99, .external_lex_state = 23},
  [10139] = {.lex_state = 97, .external_lex_state = 51},
  [10140] = {.lex_state = 97, .external_lex_state = 51},
  [10141] = {.lex_state = 87, .external_lex_state = 38},
  [10142] = {.lex_state = 95, .external_lex_state = 58},
  [10143] = {.lex_state = 97, .external_lex_state = 51},
  [10144] = {.lex_state = 87, .external_lex_state = 38},
  [10145] = {.lex_state = 87, .external_lex_state = 40},
  [10146] = {.lex_state = 26},
  [10147] = {.lex_state = 4},
  [10148] = {.lex_state = 87, .external_lex_state = 38},
  [10149] = {.lex_state = 97, .external_lex_state = 51},
  [10150] = {.lex_state = 95, .external_lex_state = 58},
  [10151] = {.lex_state = 99, .external_lex_state = 24},
  [10152] = {.lex_state = 95, .external_lex_state = 58},
  [10153] = {.lex_state = 16, .external_lex_state = 49},
  [10154] = {.lex_state = 87, .external_lex_state = 40},
  [10155] = {.lex_state = 87, .external_lex_state = 23},
  [10156] = {.lex_state = 78, .external_lex_state = 49},
  [10157] = {.lex_state = 95, .external_lex_state = 58},
  [10158] = {.lex_state = 97, .external_lex_state = 55},
  [10159] = {.lex_state = 90, .external_lex_state = 46},
  [10160] = {.lex_state = 87, .external_lex_state = 38},
  [10161] = {.lex_state = 75, .external_lex_state = 58},
  [10162] = {.lex_state = 87, .external_lex_state = 56},
  [10163] = {.lex_state = 95, .external_lex_state = 58},
  [10164] = {.lex_state = 97, .external_lex_state = 55},
  [10165] = {.lex_state = 97, .external_lex_state = 55},
  [10166] = {.lex_state = 77, .external_lex_state = 25},
  [10167] = {.lex_state = 95, .external_lex_state = 58},
  [10168] = {.lex_state = 87, .external_lex_state = 57},
  [10169] = {.lex_state = 97, .external_lex_state = 54},
  [10170] = {.lex_state = 97, .external_lex_state = 55},
  [10171] = {.lex_state = 87, .external_lex_state = 39},
  [10172] = {.lex_state = 87, .external_lex_state = 40},
  [10173] = {.lex_state = 87, .external_lex_state = 38},
  [10174] = {.lex_state = 95, .external_lex_state = 29},
  [10175] = {.lex_state = 90, .external_lex_state = 46},
  [10176] = {.lex_state = 87, .external_lex_state = 38},
  [10177] = {.lex_state = 87, .external_lex_state = 38},
  [10178] = {.lex_state = 97, .external_lex_state = 30},
  [10179] = {.lex_state = 78, .external_lex_state = 49},
  [10180] = {.lex_state = 75, .external_lex_state = 35},
  [10181] = {.lex_state = 45, .external_lex_state = 49},
  [10182] = {.lex_state = 5},
  [10183] = {.lex_state = 87, .external_lex_state = 38},
  [10184] = {.lex_state = 97, .external_lex_state = 53},
  [10185] = {.lex_state = 87, .external_lex_state = 38},
  [10186] = {.lex_state = 87, .external_lex_state = 38},
  [10187] = {.lex_state = 87, .external_lex_state = 38},
  [10188] = {.lex_state = 78, .external_lex_state = 49},
  [10189] = {.lex_state = 87, .external_lex_state = 38},
  [10190] = {.lex_state = 90, .external_lex_state = 23},
  [10191] = {.lex_state = 90, .external_lex_state = 23},
  [10192] = {.lex_state = 97, .external_lex_state = 24},
  [10193] = {.lex_state = 87, .external_lex_state = 38},
  [10194] = {.lex_state = 90, .external_lex_state = 29},
  [10195] = {.lex_state = 97, .external_lex_state = 53},
  [10196] = {.lex_state = 87, .external_lex_state = 38},
  [10197] = {.lex_state = 78, .external_lex_state = 49},
  [10198] = {.lex_state = 31},
  [10199] = {.lex_state = 97, .external_lex_state = 51},
  [10200] = {.lex_state = 97, .external_lex_state = 53},
  [10201] = {.lex_state = 90, .external_lex_state = 23},
  [10202] = {.lex_state = 95, .external_lex_state = 57},
  [10203] = {.lex_state = 7},
  [10204] = {.lex_state = 95, .external_lex_state = 57},
  [10205] = {.lex_state = 16, .external_lex_state = 49},
  [10206] = {.lex_state = 97, .external_lex_state = 53},
  [10207] = {.lex_state = 97, .external_lex_state = 53},
  [10208] = {.lex_state = 95, .external_lex_state = 57},
  [10209] = {.lex_state = 95, .external_lex_state = 57},
  [10210] = {.lex_state = 90, .external_lex_state = 23},
  [10211] = {.lex_state = 95, .external_lex_state = 57},
  [10212] = {.lex_state = 95, .external_lex_state = 57},
  [10213] = {.lex_state = 97, .external_lex_state = 34},
  [10214] = {.lex_state = 90, .external_lex_state = 54},
  [10215] = {.lex_state = 87},
  [10216] = {.lex_state = 87, .external_lex_state = 55},
  [10217] = {.lex_state = 97, .external_lex_state = 54},
  [10218] = {.lex_state = 41, .external_lex_state = 49},
  [10219] = {.lex_state = 94, .external_lex_state = 35},
  [10220] = {.lex_state = 98, .external_lex_state = 24},
  [10221] = {.lex_state = 98, .external_lex_state = 23},
  [10222] = {.lex_state = 87, .external_lex_state = 38},
  [10223] = {.lex_state = 97, .external_lex_state = 54},
  [10224] = {.lex_state = 75, .external_lex_state = 50},
  [10225] = {.lex_state = 78, .external_lex_state = 49},
  [10226] = {.lex_state = 97, .external_lex_state = 54},
  [10227] = {.lex_state = 97, .external_lex_state = 54},
  [10228] = {.lex_state = 97, .external_lex_state = 54},
  [10229] = {.lex_state = 90, .external_lex_state = 29},
  [10230] = {.lex_state = 87, .external_lex_state = 40},
  [10231] = {.lex_state = 97},
  [10232] = {.lex_state = 90, .external_lex_state = 58},
  [10233] = {.lex_state = 78, .external_lex_state = 49},
  [10234] = {.lex_state = 95, .external_lex_state = 40},
  [10235] = {.lex_state = 16, .external_lex_state = 49},
  [10236] = {.lex_state = 87, .external_lex_state = 38},
  [10237] = {.lex_state = 87, .external_lex_state = 38},
  [10238] = {.lex_state = 78, .external_lex_state = 49},
  [10239] = {.lex_state = 100, .external_lex_state = 35},
  [10240] = {.lex_state = 95, .external_lex_state = 29},
  [10241] = {.lex_state = 88, .external_lex_state = 59},
  [10242] = {.lex_state = 95, .external_lex_state = 29},
  [10243] = {.lex_state = 95, .external_lex_state = 29},
  [10244] = {.lex_state = 87, .external_lex_state = 40},
  [10245] = {.lex_state = 87},
  [10246] = {.lex_state = 16, .external_lex_state = 49},
  [10247] = {.lex_state = 87, .external_lex_state = 38},
  [10248] = {.lex_state = 87, .external_lex_state = 40},
  [10249] = {.lex_state = 87, .external_lex_state = 40},
  [10250] = {.lex_state = 95, .external_lex_state = 56},
  [10251] = {.lex_state = 87, .external_lex_state = 38},
  [10252] = {.lex_state = 95, .external_lex_state = 56},
  [10253] = {.lex_state = 87, .external_lex_state = 38},
  [10254] = {.lex_state = 40, .external_lex_state = 49},
  [10255] = {.lex_state = 87, .external_lex_state = 40},
  [10256] = {.lex_state = 99, .external_lex_state = 23},
  [10257] = {.lex_state = 87, .external_lex_state = 51},
  [10258] = {.lex_state = 87, .external_lex_state = 40},
  [10259] = {.lex_state = 97, .external_lex_state = 54},
  [10260] = {.lex_state = 30, .external_lex_state = 49},
  [10261] = {.lex_state = 96, .external_lex_state = 49},
  [10262] = {.lex_state = 5},
  [10263] = {.lex_state = 87, .external_lex_state = 38},
  [10264] = {.lex_state = 99, .external_lex_state = 24},
  [10265] = {.lex_state = 78, .external_lex_state = 49},
  [10266] = {.lex_state = 40},
  [10267] = {.lex_state = 16, .external_lex_state = 49},
  [10268] = {.lex_state = 101, .external_lex_state = 23},
  [10269] = {.lex_state = 16, .external_lex_state = 49},
  [10270] = {.lex_state = 90, .external_lex_state = 45},
  [10271] = {.lex_state = 75},
  [10272] = {.lex_state = 75},
  [10273] = {.lex_state = 36, .external_lex_state = 49},
  [10274] = {.lex_state = 99, .external_lex_state = 24},
  [10275] = {.lex_state = 90, .external_lex_state = 45},
  [10276] = {.lex_state = 87, .external_lex_state = 40},
  [10277] = {.lex_state = 99, .external_lex_state = 24},
  [10278] = {.lex_state = 78, .external_lex_state = 49},
  [10279] = {.lex_state = 87, .external_lex_state = 40},
  [10280] = {.lex_state = 90, .external_lex_state = 45},
  [10281] = {.lex_state = 87, .external_lex_state = 40},
  [10282] = {.lex_state = 88, .external_lex_state = 59},
  [10283] = {.lex_state = 97, .external_lex_state = 55},
  [10284] = {.lex_state = 87, .external_lex_state = 40},
  [10285] = {.lex_state = 97, .external_lex_state = 55},
  [10286] = {.lex_state = 87, .external_lex_state = 38},
  [10287] = {.lex_state = 87, .external_lex_state = 34},
  [10288] = {.lex_state = 87, .external_lex_state = 38},
  [10289] = {.lex_state = 78, .external_lex_state = 49},
  [10290] = {.lex_state = 16, .external_lex_state = 49},
  [10291] = {.lex_state = 5},
  [10292] = {.lex_state = 96, .external_lex_state = 33},
  [10293] = {.lex_state = 97, .external_lex_state = 55},
  [10294] = {.lex_state = 87, .external_lex_state = 40},
  [10295] = {.lex_state = 40, .external_lex_state = 49},
  [10296] = {.lex_state = 16, .external_lex_state = 49},
  [10297] = {.lex_state = 87, .external_lex_state = 38},
  [10298] = {.lex_state = 76, .external_lex_state = 23},
  [10299] = {.lex_state = 100, .external_lex_state = 35},
  [10300] = {.lex_state = 90, .external_lex_state = 57},
  [10301] = {.lex_state = 87, .external_lex_state = 30},
  [10302] = {.lex_state = 97, .external_lex_state = 55},
  [10303] = {.lex_state = 90, .external_lex_state = 45},
  [10304] = {.lex_state = 99, .external_lex_state = 24},
  [10305] = {.lex_state = 96, .external_lex_state = 33},
  [10306] = {.lex_state = 97, .external_lex_state = 55},
  [10307] = {.lex_state = 87, .external_lex_state = 38},
  [10308] = {.lex_state = 87, .external_lex_state = 38},
  [10309] = {.lex_state = 6},
  [10310] = {.lex_state = 78, .external_lex_state = 49},
  [10311] = {.lex_state = 75, .external_lex_state = 50},
  [10312] = {.lex_state = 87, .external_lex_state = 40},
  [10313] = {.lex_state = 87, .external_lex_state = 40},
  [10314] = {.lex_state = 7},
  [10315] = {.lex_state = 87, .external_lex_state = 38},
  [10316] = {.lex_state = 16, .external_lex_state = 49},
  [10317] = {.lex_state = 87, .external_lex_state = 38},
  [10318] = {.lex_state = 87, .external_lex_state = 30},
  [10319] = {.lex_state = 89, .external_lex_state = 49},
  [10320] = {.lex_state = 97},
  [10321] = {.lex_state = 97},
  [10322] = {.lex_state = 95, .external_lex_state = 56},
  [10323] = {.lex_state = 88, .external_lex_state = 35},
  [10324] = {.lex_state = 6},
  [10325] = {.lex_state = 90, .external_lex_state = 56},
  [10326] = {.lex_state = 6},
  [10327] = {.lex_state = 87, .external_lex_state = 56},
  [10328] = {.lex_state = 97, .external_lex_state = 53},
  [10329] = {.lex_state = 78, .external_lex_state = 49},
  [10330] = {.lex_state = 94, .external_lex_state = 35},
  [10331] = {.lex_state = 97, .external_lex_state = 53},
  [10332] = {.lex_state = 5},
  [10333] = {.lex_state = 97, .external_lex_state = 53},
  [10334] = {.lex_state = 80, .external_lex_state = 59},
  [10335] = {.lex_state = 87, .external_lex_state = 30},
  [10336] = {.lex_state = 90, .external_lex_state = 45},
  [10337] = {.lex_state = 90, .external_lex_state = 23},
  [10338] = {.lex_state = 16, .external_lex_state = 49},
  [10339] = {.lex_state = 87, .external_lex_state = 38},
  [10340] = {.lex_state = 90, .external_lex_state = 23},
  [10341] = {.lex_state = 80, .external_lex_state = 59},
  [10342] = {.lex_state = 97},
  [10343] = {.lex_state = 87, .external_lex_state = 34},
  [10344] = {.lex_state = 99, .external_lex_state = 23},
  [10345] = {.lex_state = 87, .external_lex_state = 40},
  [10346] = {.lex_state = 89, .external_lex_state = 35},
  [10347] = {.lex_state = 87, .external_lex_state = 40},
  [10348] = {.lex_state = 95, .external_lex_state = 56},
  [10349] = {.lex_state = 90, .external_lex_state = 45},
  [10350] = {.lex_state = 101, .external_lex_state = 24},
  [10351] = {.lex_state = 90, .external_lex_state = 45},
  [10352] = {.lex_state = 90, .external_lex_state = 46},
  [10353] = {.lex_state = 16, .external_lex_state = 49},
  [10354] = {.lex_state = 90, .external_lex_state = 46},
  [10355] = {.lex_state = 78, .external_lex_state = 49},
  [10356] = {.lex_state = 95, .external_lex_state = 56},
  [10357] = {.lex_state = 35, .external_lex_state = 49},
  [10358] = {.lex_state = 6},
  [10359] = {.lex_state = 95, .external_lex_state = 56},
  [10360] = {.lex_state = 95, .external_lex_state = 56},
  [10361] = {.lex_state = 78, .external_lex_state = 49},
  [10362] = {.lex_state = 90, .external_lex_state = 45},
  [10363] = {.lex_state = 95, .external_lex_state = 56},
  [10364] = {.lex_state = 90, .external_lex_state = 45},
  [10365] = {.lex_state = 44},
  [10366] = {.lex_state = 97, .external_lex_state = 29},
  [10367] = {.lex_state = 95, .external_lex_state = 34},
  [10368] = {.lex_state = 87, .external_lex_state = 45},
  [10369] = {.lex_state = 87, .external_lex_state = 40},
  [10370] = {.lex_state = 90, .external_lex_state = 54},
  [10371] = {.lex_state = 95, .external_lex_state = 23},
  [10372] = {.lex_state = 95, .external_lex_state = 24},
  [10373] = {.lex_state = 95, .external_lex_state = 24},
  [10374] = {.lex_state = 95},
  [10375] = {.lex_state = 99, .external_lex_state = 23},
  [10376] = {.lex_state = 95},
  [10377] = {.lex_state = 90, .external_lex_state = 55},
  [10378] = {.lex_state = 95},
  [10379] = {.lex_state = 32, .external_lex_state = 25},
  [10380] = {.lex_state = 90, .external_lex_state = 55},
  [10381] = {.lex_state = 95, .external_lex_state = 34},
  [10382] = {.lex_state = 95},
  [10383] = {.lex_state = 90, .external_lex_state = 51},
  [10384] = {.lex_state = 97, .external_lex_state = 57},
  [10385] = {.lex_state = 97, .external_lex_state = 40},
  [10386] = {.lex_state = 78, .external_lex_state = 49},
  [10387] = {.lex_state = 90, .external_lex_state = 51},
  [10388] = {.lex_state = 90, .external_lex_state = 54},
  [10389] = {.lex_state = 32, .external_lex_state = 25},
  [10390] = {.lex_state = 97, .external_lex_state = 57},
  [10391] = {.lex_state = 95},
  [10392] = {.lex_state = 90, .external_lex_state = 54},
  [10393] = {.lex_state = 99, .external_lex_state = 23},
  [10394] = {.lex_state = 95},
  [10395] = {.lex_state = 97, .external_lex_state = 57},
  [10396] = {.lex_state = 99, .external_lex_state = 23},
  [10397] = {.lex_state = 97, .external_lex_state = 57},
  [10398] = {.lex_state = 95},
  [10399] = {.lex_state = 78, .external_lex_state = 49},
  [10400] = {.lex_state = 99, .external_lex_state = 23},
  [10401] = {.lex_state = 95},
  [10402] = {.lex_state = 97, .external_lex_state = 57},
  [10403] = {.lex_state = 87, .external_lex_state = 24},
  [10404] = {.lex_state = 78, .external_lex_state = 49},
  [10405] = {.lex_state = 5},
  [10406] = {.lex_state = 95},
  [10407] = {.lex_state = 78, .external_lex_state = 49},
  [10408] = {.lex_state = 4},
  [10409] = {.lex_state = 39},
  [10410] = {.lex_state = 95, .external_lex_state = 34},
  [10411] = {.lex_state = 5},
  [10412] = {.lex_state = 87, .external_lex_state = 38},
  [10413] = {.lex_state = 78, .external_lex_state = 49},
  [10414] = {.lex_state = 96, .external_lex_state = 35},
  [10415] = {.lex_state = 90, .external_lex_state = 53},
  [10416] = {.lex_state = 90, .external_lex_state = 55},
  [10417] = {.lex_state = 26},
  [10418] = {.lex_state = 75},
  [10419] = {.lex_state = 37, .external_lex_state = 49},
  [10420] = {.lex_state = 90, .external_lex_state = 53},
  [10421] = {.lex_state = 95, .external_lex_state = 34},
  [10422] = {.lex_state = 99, .external_lex_state = 23},
  [10423] = {.lex_state = 32, .external_lex_state = 25},
  [10424] = {.lex_state = 77, .external_lex_state = 60},
  [10425] = {.lex_state = 87, .external_lex_state = 23},
  [10426] = {.lex_state = 99, .external_lex_state = 23},
  [10427] = {.lex_state = 90, .external_lex_state = 54},
  [10428] = {.lex_state = 99, .external_lex_state = 23},
  [10429] = {.lex_state = 90, .external_lex_state = 34},
  [10430] = {.lex_state = 32, .external_lex_state = 25},
  [10431] = {.lex_state = 4},
  [10432] = {.lex_state = 78, .external_lex_state = 49},
  [10433] = {.lex_state = 90, .external_lex_state = 29},
  [10434] = {.lex_state = 90, .external_lex_state = 55},
  [10435] = {.lex_state = 95, .external_lex_state = 24},
  [10436] = {.lex_state = 99, .external_lex_state = 23},
  [10437] = {.lex_state = 95},
  [10438] = {.lex_state = 5},
  [10439] = {.lex_state = 39},
  [10440] = {.lex_state = 90, .external_lex_state = 53},
  [10441] = {.lex_state = 39},
  [10442] = {.lex_state = 87, .external_lex_state = 24},
  [10443] = {.lex_state = 26},
  [10444] = {.lex_state = 39},
  [10445] = {.lex_state = 97, .external_lex_state = 56},
  [10446] = {.lex_state = 39},
  [10447] = {.lex_state = 87, .external_lex_state = 23},
  [10448] = {.lex_state = 4},
  [10449] = {.lex_state = 90, .external_lex_state = 57},
  [10450] = {.lex_state = 95, .external_lex_state = 34},
  [10451] = {.lex_state = 97, .external_lex_state = 56},
  [10452] = {.lex_state = 87, .external_lex_state = 23},
  [10453] = {.lex_state = 97, .external_lex_state = 57},
  [10454] = {.lex_state = 95, .external_lex_state = 24},
  [10455] = {.lex_state = 97, .external_lex_state = 56},
  [10456] = {.lex_state = 95, .external_lex_state = 30},
  [10457] = {.lex_state = 78, .external_lex_state = 49},
  [10458] = {.lex_state = 32, .external_lex_state = 25},
  [10459] = {.lex_state = 32, .external_lex_state = 25},
  [10460] = {.lex_state = 96, .external_lex_state = 35},
  [10461] = {.lex_state = 39},
  [10462] = {.lex_state = 78, .external_lex_state = 49},
  [10463] = {.lex_state = 97, .external_lex_state = 58},
  [10464] = {.lex_state = 26},
  [10465] = {.lex_state = 97, .external_lex_state = 58},
  [10466] = {.lex_state = 46, .external_lex_state = 49},
  [10467] = {.lex_state = 31},
  [10468] = {.lex_state = 87, .external_lex_state = 23},
  [10469] = {.lex_state = 97, .external_lex_state = 29},
  [10470] = {.lex_state = 97, .external_lex_state = 29},
  [10471] = {.lex_state = 32, .external_lex_state = 25},
  [10472] = {.lex_state = 78, .external_lex_state = 49},
  [10473] = {.lex_state = 97, .external_lex_state = 58},
  [10474] = {.lex_state = 95, .external_lex_state = 34},
  [10475] = {.lex_state = 90, .external_lex_state = 51},
  [10476] = {.lex_state = 77, .external_lex_state = 29},
  [10477] = {.lex_state = 97, .external_lex_state = 58},
  [10478] = {.lex_state = 97, .external_lex_state = 29},
  [10479] = {.lex_state = 75, .external_lex_state = 35},
  [10480] = {.lex_state = 32, .external_lex_state = 25},
  [10481] = {.lex_state = 97, .external_lex_state = 58},
  [10482] = {.lex_state = 90, .external_lex_state = 55},
  [10483] = {.lex_state = 78, .external_lex_state = 49},
  [10484] = {.lex_state = 87, .external_lex_state = 40},
  [10485] = {.lex_state = 97, .external_lex_state = 38},
  [10486] = {.lex_state = 32, .external_lex_state = 25},
  [10487] = {.lex_state = 90, .external_lex_state = 34},
  [10488] = {.lex_state = 90, .external_lex_state = 51},
  [10489] = {.lex_state = 44},
  [10490] = {.lex_state = 87, .external_lex_state = 23},
  [10491] = {.lex_state = 97, .external_lex_state = 58},
  [10492] = {.lex_state = 87, .external_lex_state = 24},
  [10493] = {.lex_state = 78, .external_lex_state = 49},
  [10494] = {.lex_state = 90, .external_lex_state = 51},
  [10495] = {.lex_state = 97, .external_lex_state = 29},
  [10496] = {.lex_state = 32, .external_lex_state = 25},
  [10497] = {.lex_state = 90, .external_lex_state = 30},
  [10498] = {.lex_state = 87, .external_lex_state = 58},
  [10499] = {.lex_state = 87, .external_lex_state = 23},
  [10500] = {.lex_state = 75, .external_lex_state = 49},
  [10501] = {.lex_state = 32, .external_lex_state = 25},
  [10502] = {.lex_state = 7},
  [10503] = {.lex_state = 95, .external_lex_state = 24},
  [10504] = {.lex_state = 78, .external_lex_state = 49},
  [10505] = {.lex_state = 99, .external_lex_state = 49},
  [10506] = {.lex_state = 90, .external_lex_state = 51},
  [10507] = {.lex_state = 90, .external_lex_state = 55},
  [10508] = {.lex_state = 26},
  [10509] = {.lex_state = 78, .external_lex_state = 49},
  [10510] = {.lex_state = 87, .external_lex_state = 23},
  [10511] = {.lex_state = 87, .external_lex_state = 38},
  [10512] = {.lex_state = 87, .external_lex_state = 23},
  [10513] = {.lex_state = 87, .external_lex_state = 40},
  [10514] = {.lex_state = 31},
  [10515] = {.lex_state = 4},
  [10516] = {.lex_state = 32, .external_lex_state = 25},
  [10517] = {.lex_state = 87, .external_lex_state = 23},
  [10518] = {.lex_state = 90, .external_lex_state = 51},
  [10519] = {.lex_state = 90, .external_lex_state = 53},
  [10520] = {.lex_state = 78, .external_lex_state = 49},
  [10521] = {.lex_state = 39},
  [10522] = {.lex_state = 87, .external_lex_state = 23},
  [10523] = {.lex_state = 32, .external_lex_state = 25},
  [10524] = {.lex_state = 87, .external_lex_state = 23},
  [10525] = {.lex_state = 32, .external_lex_state = 25},
  [10526] = {.lex_state = 87, .external_lex_state = 23},
  [10527] = {.lex_state = 87, .external_lex_state = 23},
  [10528] = {.lex_state = 45, .external_lex_state = 49},
  [10529] = {.lex_state = 92, .external_lex_state = 49},
  [10530] = {.lex_state = 98, .external_lex_state = 23},
  [10531] = {.lex_state = 90, .external_lex_state = 55},
  [10532] = {.lex_state = 90, .external_lex_state = 55},
  [10533] = {.lex_state = 89, .external_lex_state = 49},
  [10534] = {.lex_state = 37, .external_lex_state = 49},
  [10535] = {.lex_state = 4},
  [10536] = {.lex_state = 87, .external_lex_state = 45},
  [10537] = {.lex_state = 32, .external_lex_state = 25},
  [10538] = {.lex_state = 6},
  [10539] = {.lex_state = 37, .external_lex_state = 49},
  [10540] = {.lex_state = 78, .external_lex_state = 49},
  [10541] = {.lex_state = 90, .external_lex_state = 30},
  [10542] = {.lex_state = 37, .external_lex_state = 49},
  [10543] = {.lex_state = 90, .external_lex_state = 54},
  [10544] = {.lex_state = 95, .external_lex_state = 24},
  [10545] = {.lex_state = 37, .external_lex_state = 49},
  [10546] = {.lex_state = 90, .external_lex_state = 55},
  [10547] = {.lex_state = 39},
  [10548] = {.lex_state = 4},
  [10549] = {.lex_state = 87, .external_lex_state = 23},
  [10550] = {.lex_state = 95, .external_lex_state = 30},
  [10551] = {.lex_state = 36, .external_lex_state = 49},
  [10552] = {.lex_state = 97, .external_lex_state = 56},
  [10553] = {.lex_state = 95, .external_lex_state = 30},
  [10554] = {.lex_state = 75, .external_lex_state = 35},
  [10555] = {.lex_state = 4},
  [10556] = {.lex_state = 87, .external_lex_state = 23},
  [10557] = {.lex_state = 39},
  [10558] = {.lex_state = 38, .external_lex_state = 49},
  [10559] = {.lex_state = 78, .external_lex_state = 49},
  [10560] = {.lex_state = 87, .external_lex_state = 38},
  [10561] = {.lex_state = 45, .external_lex_state = 49},
  [10562] = {.lex_state = 39},
  [10563] = {.lex_state = 97, .external_lex_state = 56},
  [10564] = {.lex_state = 32, .external_lex_state = 25},
  [10565] = {.lex_state = 78, .external_lex_state = 49},
  [10566] = {.lex_state = 99, .external_lex_state = 23},
  [10567] = {.lex_state = 90, .external_lex_state = 53},
  [10568] = {.lex_state = 32, .external_lex_state = 25},
  [10569] = {.lex_state = 90, .external_lex_state = 51},
  [10570] = {.lex_state = 97, .external_lex_state = 56},
  [10571] = {.lex_state = 95, .external_lex_state = 30},
  [10572] = {.lex_state = 87, .external_lex_state = 23},
  [10573] = {.lex_state = 88, .external_lex_state = 59},
  [10574] = {.lex_state = 90, .external_lex_state = 51},
  [10575] = {.lex_state = 5},
  [10576] = {.lex_state = 32, .external_lex_state = 25},
  [10577] = {.lex_state = 87, .external_lex_state = 23},
  [10578] = {.lex_state = 78, .external_lex_state = 49},
  [10579] = {.lex_state = 78, .external_lex_state = 49},
  [10580] = {.lex_state = 32, .external_lex_state = 25},
  [10581] = {.lex_state = 90, .external_lex_state = 53},
  [10582] = {.lex_state = 97, .external_lex_state = 56},
  [10583] = {.lex_state = 87, .external_lex_state = 23},
  [10584] = {.lex_state = 32, .external_lex_state = 25},
  [10585] = {.lex_state = 7},
  [10586] = {.lex_state = 95, .external_lex_state = 24},
  [10587] = {.lex_state = 95, .external_lex_state = 30},
  [10588] = {.lex_state = 88, .external_lex_state = 59},
  [10589] = {.lex_state = 78, .external_lex_state = 49},
  [10590] = {.lex_state = 87, .external_lex_state = 24},
  [10591] = {.lex_state = 87, .external_lex_state = 24},
  [10592] = {.lex_state = 90},
  [10593] = {.lex_state = 88, .external_lex_state = 59},
  [10594] = {.lex_state = 97, .external_lex_state = 56},
  [10595] = {.lex_state = 99, .external_lex_state = 23},
  [10596] = {.lex_state = 97, .external_lex_state = 58},
  [10597] = {.lex_state = 95, .external_lex_state = 34},
  [10598] = {.lex_state = 4},
  [10599] = {.lex_state = 4},
  [10600] = {.lex_state = 95, .external_lex_state = 24},
  [10601] = {.lex_state = 90, .external_lex_state = 56},
  [10602] = {.lex_state = 7},
  [10603] = {.lex_state = 95, .external_lex_state = 34},
  [10604] = {.lex_state = 95, .external_lex_state = 34},
  [10605] = {.lex_state = 32, .external_lex_state = 25},
  [10606] = {.lex_state = 98, .external_lex_state = 24},
  [10607] = {.lex_state = 90, .external_lex_state = 54},
  [10608] = {.lex_state = 95, .external_lex_state = 30},
  [10609] = {.lex_state = 45},
  [10610] = {.lex_state = 95, .external_lex_state = 34},
  [10611] = {.lex_state = 78, .external_lex_state = 49},
  [10612] = {.lex_state = 97, .external_lex_state = 56},
  [10613] = {.lex_state = 87, .external_lex_state = 23},
  [10614] = {.lex_state = 5},
  [10615] = {.lex_state = 5},
  [10616] = {.lex_state = 41, .external_lex_state = 49},
  [10617] = {.lex_state = 13},
  [10618] = {.lex_state = 97, .external_lex_state = 58},
  [10619] = {.lex_state = 32, .external_lex_state = 25},
  [10620] = {.lex_state = 97, .external_lex_state = 58},
  [10621] = {.lex_state = 88, .external_lex_state = 59},
  [10622] = {.lex_state = 90},
  [10623] = {.lex_state = 97, .external_lex_state = 58},
  [10624] = {.lex_state = 95, .external_lex_state = 30},
  [10625] = {.lex_state = 32, .external_lex_state = 25},
  [10626] = {.lex_state = 87, .external_lex_state = 23},
  [10627] = {.lex_state = 75},
  [10628] = {.lex_state = 7},
  [10629] = {.lex_state = 90, .external_lex_state = 54},
  [10630] = {.lex_state = 78, .external_lex_state = 49},
  [10631] = {.lex_state = 95, .external_lex_state = 24},
  [10632] = {.lex_state = 87, .external_lex_state = 23},
  [10633] = {.lex_state = 98, .external_lex_state = 23},
  [10634] = {.lex_state = 32, .external_lex_state = 25},
  [10635] = {.lex_state = 87, .external_lex_state = 23},
  [10636] = {.lex_state = 97, .external_lex_state = 29},
  [10637] = {.lex_state = 97, .external_lex_state = 57},
  [10638] = {.lex_state = 95, .external_lex_state = 30},
  [10639] = {.lex_state = 95, .external_lex_state = 30},
  [10640] = {.lex_state = 87, .external_lex_state = 23},
  [10641] = {.lex_state = 97, .external_lex_state = 56},
  [10642] = {.lex_state = 7},
  [10643] = {.lex_state = 95, .external_lex_state = 30},
  [10644] = {.lex_state = 90, .external_lex_state = 53},
  [10645] = {.lex_state = 87, .external_lex_state = 23},
  [10646] = {.lex_state = 32, .external_lex_state = 25},
  [10647] = {.lex_state = 90, .external_lex_state = 54},
  [10648] = {.lex_state = 44},
  [10649] = {.lex_state = 87, .external_lex_state = 23},
  [10650] = {.lex_state = 87, .external_lex_state = 23},
  [10651] = {.lex_state = 41, .external_lex_state = 49},
  [10652] = {.lex_state = 78, .external_lex_state = 49},
  [10653] = {.lex_state = 90, .external_lex_state = 53},
  [10654] = {.lex_state = 78, .external_lex_state = 49},
  [10655] = {.lex_state = 97, .external_lex_state = 29},
  [10656] = {.lex_state = 90, .external_lex_state = 53},
  [10657] = {.lex_state = 97, .external_lex_state = 29},
  [10658] = {.lex_state = 101, .external_lex_state = 23},
  [10659] = {.lex_state = 44},
  [10660] = {.lex_state = 90, .external_lex_state = 54},
  [10661] = {.lex_state = 6},
  [10662] = {.lex_state = 97, .external_lex_state = 29},
  [10663] = {.lex_state = 31},
  [10664] = {.lex_state = 97, .external_lex_state = 57},
  [10665] = {.lex_state = 97, .external_lex_state = 57},
  [10666] = {.lex_state = 95, .external_lex_state = 24},
  [10667] = {.lex_state = 90, .external_lex_state = 58},
  [10668] = {.lex_state = 97, .external_lex_state = 29},
  [10669] = {.lex_state = 97, .external_lex_state = 57},
  [10670] = {.lex_state = 95, .external_lex_state = 38},
  [10671] = {.lex_state = 42},
  [10672] = {.lex_state = 90, .external_lex_state = 40},
  [10673] = {.lex_state = 90, .external_lex_state = 29},
  [10674] = {.lex_state = 95, .external_lex_state = 40},
  [10675] = {.lex_state = 96, .external_lex_state = 59},
  [10676] = {.lex_state = 98, .external_lex_state = 23},
  [10677] = {.lex_state = 40},
  [10678] = {.lex_state = 97, .external_lex_state = 23},
  [10679] = {.lex_state = 90, .external_lex_state = 29},
  [10680] = {.lex_state = 90, .external_lex_state = 57},
  [10681] = {.lex_state = 90, .external_lex_state = 58},
  [10682] = {.lex_state = 90, .external_lex_state = 29},
  [10683] = {.lex_state = 90, .external_lex_state = 58},
  [10684] = {.lex_state = 40},
  [10685] = {.lex_state = 44},
  [10686] = {.lex_state = 87, .external_lex_state = 51},
  [10687] = {.lex_state = 95, .external_lex_state = 38},
  [10688] = {.lex_state = 90, .external_lex_state = 57},
  [10689] = {.lex_state = 90, .external_lex_state = 58},
  [10690] = {.lex_state = 90, .external_lex_state = 30},
  [10691] = {.lex_state = 90, .external_lex_state = 57},
  [10692] = {.lex_state = 40},
  [10693] = {.lex_state = 95, .external_lex_state = 38},
  [10694] = {.lex_state = 99, .external_lex_state = 49},
  [10695] = {.lex_state = 98, .external_lex_state = 23},
  [10696] = {.lex_state = 26},
  [10697] = {.lex_state = 77, .external_lex_state = 61},
  [10698] = {.lex_state = 90, .external_lex_state = 58},
  [10699] = {.lex_state = 95, .external_lex_state = 38},
  [10700] = {.lex_state = 90, .external_lex_state = 56},
  [10701] = {.lex_state = 97, .external_lex_state = 30},
  [10702] = {.lex_state = 87, .external_lex_state = 55},
  [10703] = {.lex_state = 101, .external_lex_state = 24},
  [10704] = {.lex_state = 95, .external_lex_state = 38},
  [10705] = {.lex_state = 90, .external_lex_state = 57},
  [10706] = {.lex_state = 44},
  [10707] = {.lex_state = 95, .external_lex_state = 40},
  [10708] = {.lex_state = 95, .external_lex_state = 38},
  [10709] = {.lex_state = 44},
  [10710] = {.lex_state = 101, .external_lex_state = 23},
  [10711] = {.lex_state = 90, .external_lex_state = 56},
  [10712] = {.lex_state = 90, .external_lex_state = 38},
  [10713] = {.lex_state = 101, .external_lex_state = 23},
  [10714] = {.lex_state = 87},
  [10715] = {.lex_state = 97, .external_lex_state = 30},
  [10716] = {.lex_state = 97, .external_lex_state = 34},
  [10717] = {.lex_state = 44},
  [10718] = {.lex_state = 90, .external_lex_state = 56},
  [10719] = {.lex_state = 90, .external_lex_state = 23},
  [10720] = {.lex_state = 101, .external_lex_state = 24},
  [10721] = {.lex_state = 27},
  [10722] = {.lex_state = 5},
  [10723] = {.lex_state = 90, .external_lex_state = 24},
  [10724] = {.lex_state = 101, .external_lex_state = 23},
  [10725] = {.lex_state = 97, .external_lex_state = 34},
  [10726] = {.lex_state = 90, .external_lex_state = 58},
  [10727] = {.lex_state = 90, .external_lex_state = 23},
  [10728] = {.lex_state = 97, .external_lex_state = 24},
  [10729] = {.lex_state = 90, .external_lex_state = 57},
  [10730] = {.lex_state = 90, .external_lex_state = 56},
  [10731] = {.lex_state = 90},
  [10732] = {.lex_state = 90, .external_lex_state = 57},
  [10733] = {.lex_state = 101, .external_lex_state = 23},
  [10734] = {.lex_state = 40},
  [10735] = {.lex_state = 90, .external_lex_state = 24},
  [10736] = {.lex_state = 90, .external_lex_state = 57},
  [10737] = {.lex_state = 27},
  [10738] = {.lex_state = 5},
  [10739] = {.lex_state = 97, .external_lex_state = 34},
  [10740] = {.lex_state = 97, .external_lex_state = 34},
  [10741] = {.lex_state = 87, .external_lex_state = 23},
  [10742] = {.lex_state = 90, .external_lex_state = 58},
  [10743] = {.lex_state = 90, .external_lex_state = 58},
  [10744] = {.lex_state = 46, .external_lex_state = 49},
  [10745] = {.lex_state = 46},
  [10746] = {.lex_state = 97, .external_lex_state = 34},
  [10747] = {.lex_state = 90, .external_lex_state = 40},
  [10748] = {.lex_state = 95, .external_lex_state = 40},
  [10749] = {.lex_state = 40},
  [10750] = {.lex_state = 26},
  [10751] = {.lex_state = 97, .external_lex_state = 24},
  [10752] = {.lex_state = 90, .external_lex_state = 29},
  [10753] = {.lex_state = 101, .external_lex_state = 23},
  [10754] = {.lex_state = 97, .external_lex_state = 30},
  [10755] = {.lex_state = 90, .external_lex_state = 56},
  [10756] = {.lex_state = 95, .external_lex_state = 38},
  [10757] = {.lex_state = 90, .external_lex_state = 57},
  [10758] = {.lex_state = 97, .external_lex_state = 34},
  [10759] = {.lex_state = 98, .external_lex_state = 23},
  [10760] = {.lex_state = 97, .external_lex_state = 34},
  [10761] = {.lex_state = 5},
  [10762] = {.lex_state = 38},
  [10763] = {.lex_state = 98, .external_lex_state = 24},
  [10764] = {.lex_state = 27},
  [10765] = {.lex_state = 5},
  [10766] = {.lex_state = 27},
  [10767] = {.lex_state = 90, .external_lex_state = 29},
  [10768] = {.lex_state = 97, .external_lex_state = 34},
  [10769] = {.lex_state = 90, .external_lex_state = 58},
  [10770] = {.lex_state = 26},
  [10771] = {.lex_state = 46, .external_lex_state = 49},
  [10772] = {.lex_state = 90, .external_lex_state = 57},
  [10773] = {.lex_state = 97, .external_lex_state = 24},
  [10774] = {.lex_state = 90, .external_lex_state = 56},
  [10775] = {.lex_state = 98, .external_lex_state = 23},
  [10776] = {.lex_state = 95, .external_lex_state = 38},
  [10777] = {.lex_state = 44},
  [10778] = {.lex_state = 97, .external_lex_state = 34},
  [10779] = {.lex_state = 98, .external_lex_state = 23},
  [10780] = {.lex_state = 38, .external_lex_state = 49},
  [10781] = {.lex_state = 101, .external_lex_state = 23},
  [10782] = {.lex_state = 95, .external_lex_state = 38},
  [10783] = {.lex_state = 98, .external_lex_state = 23},
  [10784] = {.lex_state = 98, .external_lex_state = 23},
  [10785] = {.lex_state = 97, .external_lex_state = 30},
  [10786] = {.lex_state = 40},
  [10787] = {.lex_state = 87, .external_lex_state = 55},
  [10788] = {.lex_state = 90, .external_lex_state = 29},
  [10789] = {.lex_state = 90, .external_lex_state = 29},
  [10790] = {.lex_state = 98, .external_lex_state = 24},
  [10791] = {.lex_state = 77, .external_lex_state = 62},
  [10792] = {.lex_state = 90, .external_lex_state = 29},
  [10793] = {.lex_state = 44},
  [10794] = {.lex_state = 98, .external_lex_state = 24},
  [10795] = {.lex_state = 5},
  [10796] = {.lex_state = 101, .external_lex_state = 23},
  [10797] = {.lex_state = 27},
  [10798] = {.lex_state = 26},
  [10799] = {.lex_state = 90, .external_lex_state = 58},
  [10800] = {.lex_state = 87, .external_lex_state = 23},
  [10801] = {.lex_state = 90, .external_lex_state = 24},
  [10802] = {.lex_state = 40},
  [10803] = {.lex_state = 98, .external_lex_state = 24},
  [10804] = {.lex_state = 26},
  [10805] = {.lex_state = 90, .external_lex_state = 24},
  [10806] = {.lex_state = 40},
  [10807] = {.lex_state = 5},
  [10808] = {.lex_state = 97, .external_lex_state = 24},
  [10809] = {.lex_state = 77, .external_lex_state = 61},
  [10810] = {.lex_state = 97, .external_lex_state = 30},
  [10811] = {.lex_state = 97, .external_lex_state = 30},
  [10812] = {.lex_state = 75},
  [10813] = {.lex_state = 27},
  [10814] = {.lex_state = 90, .external_lex_state = 29},
  [10815] = {.lex_state = 44},
  [10816] = {.lex_state = 6},
  [10817] = {.lex_state = 95, .external_lex_state = 40},
  [10818] = {.lex_state = 97, .external_lex_state = 30},
  [10819] = {.lex_state = 97, .external_lex_state = 24},
  [10820] = {.lex_state = 97, .external_lex_state = 34},
  [10821] = {.lex_state = 6},
  [10822] = {.lex_state = 95, .external_lex_state = 40},
  [10823] = {.lex_state = 90, .external_lex_state = 56},
  [10824] = {.lex_state = 90, .external_lex_state = 56},
  [10825] = {.lex_state = 95, .external_lex_state = 40},
  [10826] = {.lex_state = 88, .external_lex_state = 59},
  [10827] = {.lex_state = 6},
  [10828] = {.lex_state = 27},
  [10829] = {.lex_state = 97, .external_lex_state = 24},
  [10830] = {.lex_state = 77, .external_lex_state = 30},
  [10831] = {.lex_state = 5},
  [10832] = {.lex_state = 90, .external_lex_state = 56},
  [10833] = {.lex_state = 97, .external_lex_state = 24},
  [10834] = {.lex_state = 87, .external_lex_state = 51},
  [10835] = {.lex_state = 90, .external_lex_state = 38},
  [10836] = {.lex_state = 99},
  [10837] = {.lex_state = 7},
  [10838] = {.lex_state = 95, .external_lex_state = 38},
  [10839] = {.lex_state = 90, .external_lex_state = 34},
  [10840] = {.lex_state = 33},
  [10841] = {.lex_state = 98, .external_lex_state = 24},
  [10842] = {.lex_state = 101, .external_lex_state = 24},
  [10843] = {.lex_state = 90, .external_lex_state = 24},
  [10844] = {.lex_state = 33},
  [10845] = {.lex_state = 97, .external_lex_state = 24},
  [10846] = {.lex_state = 75, .external_lex_state = 49},
  [10847] = {.lex_state = 98, .external_lex_state = 23},
  [10848] = {.lex_state = 38, .external_lex_state = 49},
  [10849] = {.lex_state = 75, .external_lex_state = 49},
  [10850] = {.lex_state = 101, .external_lex_state = 24},
  [10851] = {.lex_state = 87, .external_lex_state = 23},
  [10852] = {.lex_state = 97, .external_lex_state = 30},
  [10853] = {.lex_state = 5},
  [10854] = {.lex_state = 98, .external_lex_state = 23},
  [10855] = {.lex_state = 99, .external_lex_state = 49},
  [10856] = {.lex_state = 97, .external_lex_state = 24},
  [10857] = {.lex_state = 95, .external_lex_state = 40},
  [10858] = {.lex_state = 97, .external_lex_state = 24},
  [10859] = {.lex_state = 27},
  [10860] = {.lex_state = 87, .external_lex_state = 24},
  [10861] = {.lex_state = 97, .external_lex_state = 30},
  [10862] = {.lex_state = 33},
  [10863] = {.lex_state = 7},
  [10864] = {.lex_state = 98, .external_lex_state = 24},
  [10865] = {.lex_state = 38},
  [10866] = {.lex_state = 101, .external_lex_state = 24},
  [10867] = {.lex_state = 90, .external_lex_state = 24},
  [10868] = {.lex_state = 7},
  [10869] = {.lex_state = 101, .external_lex_state = 24},
  [10870] = {.lex_state = 98, .external_lex_state = 24},
  [10871] = {.lex_state = 101, .external_lex_state = 24},
  [10872] = {.lex_state = 77, .external_lex_state = 34},
  [10873] = {.lex_state = 98, .external_lex_state = 23},
  [10874] = {.lex_state = 95, .external_lex_state = 40},
  [10875] = {.lex_state = 95, .external_lex_state = 40},
  [10876] = {.lex_state = 98, .external_lex_state = 24},
  [10877] = {.lex_state = 101, .external_lex_state = 24},
  [10878] = {.lex_state = 26},
  [10879] = {.lex_state = 97, .external_lex_state = 30},
  [10880] = {.lex_state = 101, .external_lex_state = 24},
  [10881] = {.lex_state = 101, .external_lex_state = 23},
  [10882] = {.lex_state = 75},
  [10883] = {.lex_state = 101, .external_lex_state = 23},
  [10884] = {.lex_state = 98, .external_lex_state = 24},
  [10885] = {.lex_state = 87, .external_lex_state = 23},
  [10886] = {.lex_state = 98, .external_lex_state = 23},
  [10887] = {.lex_state = 40},
  [10888] = {.lex_state = 101, .external_lex_state = 24},
  [10889] = {.lex_state = 98, .external_lex_state = 24},
  [10890] = {.lex_state = 101, .external_lex_state = 23},
  [10891] = {.lex_state = 95, .external_lex_state = 40},
  [10892] = {.lex_state = 90},
  [10893] = {.lex_state = 7},
  [10894] = {.lex_state = 77, .external_lex_state = 23},
  [10895] = {.lex_state = 95, .external_lex_state = 23},
  [10896] = {.lex_state = 95, .external_lex_state = 23},
  [10897] = {.lex_state = 90, .external_lex_state = 30},
  [10898] = {.lex_state = 4},
  [10899] = {.lex_state = 77, .external_lex_state = 63},
  [10900] = {.lex_state = 26},
  [10901] = {.lex_state = 38},
  [10902] = {.lex_state = 4},
  [10903] = {.lex_state = 13},
  [10904] = {.lex_state = 38},
  [10905] = {.lex_state = 90},
  [10906] = {.lex_state = 90, .external_lex_state = 34},
  [10907] = {.lex_state = 38},
  [10908] = {.lex_state = 90, .external_lex_state = 34},
  [10909] = {.lex_state = 90, .external_lex_state = 24},
  [10910] = {.lex_state = 26},
  [10911] = {.lex_state = 90, .external_lex_state = 34},
  [10912] = {.lex_state = 26},
  [10913] = {.lex_state = 90, .external_lex_state = 24},
  [10914] = {.lex_state = 38},
  [10915] = {.lex_state = 77, .external_lex_state = 25},
  [10916] = {.lex_state = 91, .external_lex_state = 23},
  [10917] = {.lex_state = 38},
  [10918] = {.lex_state = 98, .external_lex_state = 23},
  [10919] = {.lex_state = 98, .external_lex_state = 23},
  [10920] = {.lex_state = 4},
  [10921] = {.lex_state = 90, .external_lex_state = 23},
  [10922] = {.lex_state = 31},
  [10923] = {.lex_state = 98},
  [10924] = {.lex_state = 98, .external_lex_state = 23},
  [10925] = {.lex_state = 91, .external_lex_state = 24},
  [10926] = {.lex_state = 77, .external_lex_state = 25},
  [10927] = {.lex_state = 91, .external_lex_state = 24},
  [10928] = {.lex_state = 31},
  [10929] = {.lex_state = 38},
  [10930] = {.lex_state = 77, .external_lex_state = 25},
  [10931] = {.lex_state = 31},
  [10932] = {.lex_state = 77, .external_lex_state = 25},
  [10933] = {.lex_state = 77, .external_lex_state = 25},
  [10934] = {.lex_state = 38},
  [10935] = {.lex_state = 38},
  [10936] = {.lex_state = 38},
  [10937] = {.lex_state = 77, .external_lex_state = 29},
  [10938] = {.lex_state = 27},
  [10939] = {.lex_state = 33},
  [10940] = {.lex_state = 77, .external_lex_state = 25},
  [10941] = {.lex_state = 77, .external_lex_state = 25},
  [10942] = {.lex_state = 98, .external_lex_state = 23},
  [10943] = {.lex_state = 98, .external_lex_state = 23},
  [10944] = {.lex_state = 90, .external_lex_state = 34},
  [10945] = {.lex_state = 90, .external_lex_state = 23},
  [10946] = {.lex_state = 13},
  [10947] = {.lex_state = 38},
  [10948] = {.lex_state = 38},
  [10949] = {.lex_state = 90},
  [10950] = {.lex_state = 91, .external_lex_state = 23},
  [10951] = {.lex_state = 91, .external_lex_state = 23},
  [10952] = {.lex_state = 77, .external_lex_state = 29},
  [10953] = {.lex_state = 91, .external_lex_state = 23},
  [10954] = {.lex_state = 77, .external_lex_state = 25},
  [10955] = {.lex_state = 38},
  [10956] = {.lex_state = 33},
  [10957] = {.lex_state = 77, .external_lex_state = 29},
  [10958] = {.lex_state = 91, .external_lex_state = 24},
  [10959] = {.lex_state = 91, .external_lex_state = 24},
  [10960] = {.lex_state = 77, .external_lex_state = 25},
  [10961] = {.lex_state = 96},
  [10962] = {.lex_state = 31},
  [10963] = {.lex_state = 91, .external_lex_state = 23},
  [10964] = {.lex_state = 38},
  [10965] = {.lex_state = 101, .external_lex_state = 23},
  [10966] = {.lex_state = 27},
  [10967] = {.lex_state = 97, .external_lex_state = 38},
  [10968] = {.lex_state = 97, .external_lex_state = 38},
  [10969] = {.lex_state = 91, .external_lex_state = 23},
  [10970] = {.lex_state = 90, .external_lex_state = 38},
  [10971] = {.lex_state = 90, .external_lex_state = 24},
  [10972] = {.lex_state = 27},
  [10973] = {.lex_state = 38},
  [10974] = {.lex_state = 97, .external_lex_state = 38},
  [10975] = {.lex_state = 97, .external_lex_state = 38},
  [10976] = {.lex_state = 95, .external_lex_state = 23},
  [10977] = {.lex_state = 101, .external_lex_state = 23},
  [10978] = {.lex_state = 91, .external_lex_state = 23},
  [10979] = {.lex_state = 91, .external_lex_state = 24},
  [10980] = {.lex_state = 34},
  [10981] = {.lex_state = 90, .external_lex_state = 24},
  [10982] = {.lex_state = 91, .external_lex_state = 24},
  [10983] = {.lex_state = 38},
  [10984] = {.lex_state = 38},
  [10985] = {.lex_state = 5},
  [10986] = {.lex_state = 38},
  [10987] = {.lex_state = 38},
  [10988] = {.lex_state = 38},
  [10989] = {.lex_state = 90},
  [10990] = {.lex_state = 90},
  [10991] = {.lex_state = 77, .external_lex_state = 25},
  [10992] = {.lex_state = 77, .external_lex_state = 25},
  [10993] = {.lex_state = 38},
  [10994] = {.lex_state = 45},
  [10995] = {.lex_state = 27},
  [10996] = {.lex_state = 90, .external_lex_state = 30},
  [10997] = {.lex_state = 90, .external_lex_state = 24},
  [10998] = {.lex_state = 33},
  [10999] = {.lex_state = 38},
  [11000] = {.lex_state = 90, .external_lex_state = 34},
  [11001] = {.lex_state = 97, .external_lex_state = 40},
  [11002] = {.lex_state = 45},
  [11003] = {.lex_state = 98, .external_lex_state = 23},
  [11004] = {.lex_state = 45},
  [11005] = {.lex_state = 91, .external_lex_state = 23},
  [11006] = {.lex_state = 4},
  [11007] = {.lex_state = 95, .external_lex_state = 23},
  [11008] = {.lex_state = 38},
  [11009] = {.lex_state = 45},
  [11010] = {.lex_state = 91, .external_lex_state = 24},
  [11011] = {.lex_state = 77, .external_lex_state = 38},
  [11012] = {.lex_state = 77, .external_lex_state = 40},
  [11013] = {.lex_state = 45},
  [11014] = {.lex_state = 90, .external_lex_state = 24},
  [11015] = {.lex_state = 45},
  [11016] = {.lex_state = 101, .external_lex_state = 23},
  [11017] = {.lex_state = 26},
  [11018] = {.lex_state = 31},
  [11019] = {.lex_state = 76, .external_lex_state = 23},
  [11020] = {.lex_state = 38},
  [11021] = {.lex_state = 27},
  [11022] = {.lex_state = 101, .external_lex_state = 23},
  [11023] = {.lex_state = 31},
  [11024] = {.lex_state = 38},
  [11025] = {.lex_state = 91, .external_lex_state = 23},
  [11026] = {.lex_state = 91, .external_lex_state = 24},
  [11027] = {.lex_state = 45},
  [11028] = {.lex_state = 91, .external_lex_state = 23},
  [11029] = {.lex_state = 91, .external_lex_state = 24},
  [11030] = {.lex_state = 38},
  [11031] = {.lex_state = 98, .external_lex_state = 23},
  [11032] = {.lex_state = 98, .external_lex_state = 23},
  [11033] = {.lex_state = 77, .external_lex_state = 61},
  [11034] = {.lex_state = 27},
  [11035] = {.lex_state = 27},
  [11036] = {.lex_state = 90, .external_lex_state = 30},
  [11037] = {.lex_state = 87, .external_lex_state = 58},
  [11038] = {.lex_state = 77, .external_lex_state = 61},
  [11039] = {.lex_state = 26},
  [11040] = {.lex_state = 38},
  [11041] = {.lex_state = 90},
  [11042] = {.lex_state = 77, .external_lex_state = 29},
  [11043] = {.lex_state = 97, .external_lex_state = 38},
  [11044] = {.lex_state = 33},
  [11045] = {.lex_state = 4},
  [11046] = {.lex_state = 90},
  [11047] = {.lex_state = 97, .external_lex_state = 40},
  [11048] = {.lex_state = 38},
  [11049] = {.lex_state = 27},
  [11050] = {.lex_state = 5},
  [11051] = {.lex_state = 90, .external_lex_state = 30},
  [11052] = {.lex_state = 38},
  [11053] = {.lex_state = 38},
  [11054] = {.lex_state = 96, .external_lex_state = 59},
  [11055] = {.lex_state = 4},
  [11056] = {.lex_state = 97, .external_lex_state = 38},
  [11057] = {.lex_state = 38},
  [11058] = {.lex_state = 40},
  [11059] = {.lex_state = 97, .external_lex_state = 40},
  [11060] = {.lex_state = 97, .external_lex_state = 38},
  [11061] = {.lex_state = 31},
  [11062] = {.lex_state = 98, .external_lex_state = 23},
  [11063] = {.lex_state = 91, .external_lex_state = 24},
  [11064] = {.lex_state = 31},
  [11065] = {.lex_state = 27},
  [11066] = {.lex_state = 91, .external_lex_state = 23},
  [11067] = {.lex_state = 38},
  [11068] = {.lex_state = 101, .external_lex_state = 23},
  [11069] = {.lex_state = 38},
  [11070] = {.lex_state = 97, .external_lex_state = 40},
  [11071] = {.lex_state = 38},
  [11072] = {.lex_state = 91, .external_lex_state = 24},
  [11073] = {.lex_state = 90},
  [11074] = {.lex_state = 91, .external_lex_state = 24},
  [11075] = {.lex_state = 5},
  [11076] = {.lex_state = 97, .external_lex_state = 40},
  [11077] = {.lex_state = 27},
  [11078] = {.lex_state = 95, .external_lex_state = 23},
  [11079] = {.lex_state = 101, .external_lex_state = 23},
  [11080] = {.lex_state = 38},
  [11081] = {.lex_state = 91, .external_lex_state = 23},
  [11082] = {.lex_state = 38},
  [11083] = {.lex_state = 91, .external_lex_state = 23},
  [11084] = {.lex_state = 31},
  [11085] = {.lex_state = 31},
  [11086] = {.lex_state = 91, .external_lex_state = 23},
  [11087] = {.lex_state = 91, .external_lex_state = 23},
  [11088] = {.lex_state = 98, .external_lex_state = 23},
  [11089] = {.lex_state = 7},
  [11090] = {.lex_state = 45},
  [11091] = {.lex_state = 101, .external_lex_state = 23},
  [11092] = {.lex_state = 95, .external_lex_state = 23},
  [11093] = {.lex_state = 38},
  [11094] = {.lex_state = 26},
  [11095] = {.lex_state = 38},
  [11096] = {.lex_state = 38},
  [11097] = {.lex_state = 4},
  [11098] = {.lex_state = 45},
  [11099] = {.lex_state = 77, .external_lex_state = 61},
  [11100] = {.lex_state = 77, .external_lex_state = 61},
  [11101] = {.lex_state = 91, .external_lex_state = 23},
  [11102] = {.lex_state = 38},
  [11103] = {.lex_state = 13},
  [11104] = {.lex_state = 90, .external_lex_state = 24},
  [11105] = {.lex_state = 97, .external_lex_state = 38},
  [11106] = {.lex_state = 91, .external_lex_state = 24},
  [11107] = {.lex_state = 33},
  [11108] = {.lex_state = 27},
  [11109] = {.lex_state = 91, .external_lex_state = 23},
  [11110] = {.lex_state = 34},
  [11111] = {.lex_state = 38},
  [11112] = {.lex_state = 84, .external_lex_state = 29},
  [11113] = {.lex_state = 90, .external_lex_state = 34},
  [11114] = {.lex_state = 38},
  [11115] = {.lex_state = 38},
  [11116] = {.lex_state = 95, .external_lex_state = 23},
  [11117] = {.lex_state = 38},
  [11118] = {.lex_state = 90, .external_lex_state = 34},
  [11119] = {.lex_state = 101, .external_lex_state = 23},
  [11120] = {.lex_state = 97, .external_lex_state = 38},
  [11121] = {.lex_state = 77, .external_lex_state = 25},
  [11122] = {.lex_state = 77, .external_lex_state = 25},
  [11123] = {.lex_state = 45},
  [11124] = {.lex_state = 13},
  [11125] = {.lex_state = 91, .external_lex_state = 24},
  [11126] = {.lex_state = 31},
  [11127] = {.lex_state = 7},
  [11128] = {.lex_state = 97, .external_lex_state = 38},
  [11129] = {.lex_state = 91, .external_lex_state = 23},
  [11130] = {.lex_state = 90, .external_lex_state = 24},
  [11131] = {.lex_state = 33},
  [11132] = {.lex_state = 91, .external_lex_state = 24},
  [11133] = {.lex_state = 91, .external_lex_state = 24},
  [11134] = {.lex_state = 101, .external_lex_state = 23},
  [11135] = {.lex_state = 91, .external_lex_state = 23},
  [11136] = {.lex_state = 31},
  [11137] = {.lex_state = 101, .external_lex_state = 23},
  [11138] = {.lex_state = 31},
  [11139] = {.lex_state = 95, .external_lex_state = 23},
  [11140] = {.lex_state = 91, .external_lex_state = 23},
  [11141] = {.lex_state = 77, .external_lex_state = 60},
  [11142] = {.lex_state = 96, .external_lex_state = 59},
  [11143] = {.lex_state = 31},
  [11144] = {.lex_state = 90, .external_lex_state = 34},
  [11145] = {.lex_state = 31},
  [11146] = {.lex_state = 90, .external_lex_state = 34},
  [11147] = {.lex_state = 95, .external_lex_state = 23},
  [11148] = {.lex_state = 97, .external_lex_state = 40},
  [11149] = {.lex_state = 91, .external_lex_state = 24},
  [11150] = {.lex_state = 91, .external_lex_state = 24},
  [11151] = {.lex_state = 90, .external_lex_state = 30},
  [11152] = {.lex_state = 27},
  [11153] = {.lex_state = 97, .external_lex_state = 40},
  [11154] = {.lex_state = 77, .external_lex_state = 60},
  [11155] = {.lex_state = 91, .external_lex_state = 23},
  [11156] = {.lex_state = 97, .external_lex_state = 40},
  [11157] = {.lex_state = 5},
  [11158] = {.lex_state = 91, .external_lex_state = 24},
  [11159] = {.lex_state = 91, .external_lex_state = 24},
  [11160] = {.lex_state = 91, .external_lex_state = 24},
  [11161] = {.lex_state = 90, .external_lex_state = 30},
  [11162] = {.lex_state = 31},
  [11163] = {.lex_state = 90, .external_lex_state = 30},
  [11164] = {.lex_state = 38},
  [11165] = {.lex_state = 38},
  [11166] = {.lex_state = 90, .external_lex_state = 24},
  [11167] = {.lex_state = 87, .external_lex_state = 58},
  [11168] = {.lex_state = 90},
  [11169] = {.lex_state = 97, .external_lex_state = 40},
  [11170] = {.lex_state = 38},
  [11171] = {.lex_state = 95, .external_lex_state = 23},
  [11172] = {.lex_state = 97, .external_lex_state = 40},
  [11173] = {.lex_state = 84, .external_lex_state = 29},
  [11174] = {.lex_state = 77, .external_lex_state = 25},
  [11175] = {.lex_state = 90, .external_lex_state = 30},
  [11176] = {.lex_state = 90, .external_lex_state = 30},
  [11177] = {.lex_state = 31},
  [11178] = {.lex_state = 77, .external_lex_state = 63},
  [11179] = {.lex_state = 31},
  [11180] = {.lex_state = 38},
  [11181] = {.lex_state = 90, .external_lex_state = 40},
  [11182] = {.lex_state = 27},
  [11183] = {.lex_state = 91, .external_lex_state = 24},
  [11184] = {.lex_state = 40},
  [11185] = {.lex_state = 42},
  [11186] = {.lex_state = 42},
  [11187] = {.lex_state = 42},
  [11188] = {.lex_state = 77, .external_lex_state = 63},
  [11189] = {.lex_state = 42},
  [11190] = {.lex_state = 99},
  [11191] = {.lex_state = 91, .external_lex_state = 23},
  [11192] = {.lex_state = 91, .external_lex_state = 23},
  [11193] = {.lex_state = 91, .external_lex_state = 23},
  [11194] = {.lex_state = 99},
  [11195] = {.lex_state = 13},
  [11196] = {.lex_state = 46},
  [11197] = {.lex_state = 91, .external_lex_state = 23},
  [11198] = {.lex_state = 91, .external_lex_state = 23},
  [11199] = {.lex_state = 46},
  [11200] = {.lex_state = 84, .external_lex_state = 29},
  [11201] = {.lex_state = 46},
  [11202] = {.lex_state = 46},
  [11203] = {.lex_state = 31},
  [11204] = {.lex_state = 46},
  [11205] = {.lex_state = 91, .external_lex_state = 23},
  [11206] = {.lex_state = 90, .external_lex_state = 40},
  [11207] = {.lex_state = 91, .external_lex_state = 23},
  [11208] = {.lex_state = 13},
  [11209] = {.lex_state = 42},
  [11210] = {.lex_state = 97, .external_lex_state = 23},
  [11211] = {.lex_state = 77, .external_lex_state = 30},
  [11212] = {.lex_state = 26},
  [11213] = {.lex_state = 26},
  [11214] = {.lex_state = 90, .external_lex_state = 40},
  [11215] = {.lex_state = 91},
  [11216] = {.lex_state = 6},
  [11217] = {.lex_state = 13},
  [11218] = {.lex_state = 91},
  [11219] = {.lex_state = 6},
  [11220] = {.lex_state = 97, .external_lex_state = 23},
  [11221] = {.lex_state = 27},
  [11222] = {.lex_state = 6},
  [11223] = {.lex_state = 99},
  [11224] = {.lex_state = 26},
  [11225] = {.lex_state = 98},
  [11226] = {.lex_state = 91},
  [11227] = {.lex_state = 27},
  [11228] = {.lex_state = 98},
  [11229] = {.lex_state = 98},
  [11230] = {.lex_state = 98},
  [11231] = {.lex_state = 91, .external_lex_state = 23},
  [11232] = {.lex_state = 77, .external_lex_state = 30},
  [11233] = {.lex_state = 98},
  [11234] = {.lex_state = 26},
  [11235] = {.lex_state = 77, .external_lex_state = 62},
  [11236] = {.lex_state = 77, .external_lex_state = 63},
  [11237] = {.lex_state = 97, .external_lex_state = 23},
  [11238] = {.lex_state = 77, .external_lex_state = 29},
  [11239] = {.lex_state = 42},
  [11240] = {.lex_state = 46},
  [11241] = {.lex_state = 77, .external_lex_state = 60},
  [11242] = {.lex_state = 46},
  [11243] = {.lex_state = 26},
  [11244] = {.lex_state = 77, .external_lex_state = 62},
  [11245] = {.lex_state = 90, .external_lex_state = 40},
  [11246] = {.lex_state = 26},
  [11247] = {.lex_state = 42},
  [11248] = {.lex_state = 6},
  [11249] = {.lex_state = 77, .external_lex_state = 23},
  [11250] = {.lex_state = 26},
  [11251] = {.lex_state = 46},
  [11252] = {.lex_state = 91},
  [11253] = {.lex_state = 26},
  [11254] = {.lex_state = 98},
  [11255] = {.lex_state = 77, .external_lex_state = 61},
  [11256] = {.lex_state = 98},
  [11257] = {.lex_state = 99},
  [11258] = {.lex_state = 77, .external_lex_state = 34},
  [11259] = {.lex_state = 97, .external_lex_state = 23},
  [11260] = {.lex_state = 87},
  [11261] = {.lex_state = 91, .external_lex_state = 23},
  [11262] = {.lex_state = 91, .external_lex_state = 23},
  [11263] = {.lex_state = 26},
  [11264] = {.lex_state = 97, .external_lex_state = 23},
  [11265] = {.lex_state = 26},
  [11266] = {.lex_state = 91, .external_lex_state = 23},
  [11267] = {.lex_state = 91, .external_lex_state = 23},
  [11268] = {.lex_state = 77, .external_lex_state = 29},
  [11269] = {.lex_state = 97, .external_lex_state = 23},
  [11270] = {.lex_state = 26},
  [11271] = {.lex_state = 87},
  [11272] = {.lex_state = 84, .external_lex_state = 30},
  [11273] = {.lex_state = 98},
  [11274] = {.lex_state = 27},
  [11275] = {.lex_state = 6},
  [11276] = {.lex_state = 84, .external_lex_state = 34},
  [11277] = {.lex_state = 91, .external_lex_state = 23},
  [11278] = {.lex_state = 84, .external_lex_state = 34},
  [11279] = {.lex_state = 77, .external_lex_state = 29},
  [11280] = {.lex_state = 91},
  [11281] = {.lex_state = 77, .external_lex_state = 63},
  [11282] = {.lex_state = 6},
  [11283] = {.lex_state = 91, .external_lex_state = 23},
  [11284] = {.lex_state = 33},
  [11285] = {.lex_state = 26},
  [11286] = {.lex_state = 13},
  [11287] = {.lex_state = 90, .external_lex_state = 38},
  [11288] = {.lex_state = 13},
  [11289] = {.lex_state = 46},
  [11290] = {.lex_state = 26},
  [11291] = {.lex_state = 26},
  [11292] = {.lex_state = 91},
  [11293] = {.lex_state = 77, .external_lex_state = 29},
  [11294] = {.lex_state = 27},
  [11295] = {.lex_state = 26},
  [11296] = {.lex_state = 90, .external_lex_state = 38},
  [11297] = {.lex_state = 26},
  [11298] = {.lex_state = 77, .external_lex_state = 29},
  [11299] = {.lex_state = 90, .external_lex_state = 38},
  [11300] = {.lex_state = 90, .external_lex_state = 40},
  [11301] = {.lex_state = 26},
  [11302] = {.lex_state = 26},
  [11303] = {.lex_state = 26},
  [11304] = {.lex_state = 91, .external_lex_state = 23},
  [11305] = {.lex_state = 76, .external_lex_state = 24},
  [11306] = {.lex_state = 26},
  [11307] = {.lex_state = 26},
  [11308] = {.lex_state = 77, .external_lex_state = 29},
  [11309] = {.lex_state = 90, .external_lex_state = 38},
  [11310] = {.lex_state = 26},
  [11311] = {.lex_state = 90, .external_lex_state = 40},
  [11312] = {.lex_state = 42},
  [11313] = {.lex_state = 84, .external_lex_state = 30},
  [11314] = {.lex_state = 26},
  [11315] = {.lex_state = 90, .external_lex_state = 40},
  [11316] = {.lex_state = 27},
  [11317] = {.lex_state = 97, .external_lex_state = 23},
  [11318] = {.lex_state = 6},
  [11319] = {.lex_state = 99},
  [11320] = {.lex_state = 77, .external_lex_state = 29},
  [11321] = {.lex_state = 77, .external_lex_state = 60},
  [11322] = {.lex_state = 38},
  [11323] = {.lex_state = 77, .external_lex_state = 29},
  [11324] = {.lex_state = 26},
  [11325] = {.lex_state = 91},
  [11326] = {.lex_state = 90, .external_lex_state = 38},
  [11327] = {.lex_state = 97, .external_lex_state = 23},
  [11328] = {.lex_state = 26},
  [11329] = {.lex_state = 90, .external_lex_state = 23},
  [11330] = {.lex_state = 99},
  [11331] = {.lex_state = 77, .external_lex_state = 29},
  [11332] = {.lex_state = 27},
  [11333] = {.lex_state = 77, .external_lex_state = 30},
  [11334] = {.lex_state = 76, .external_lex_state = 23},
  [11335] = {.lex_state = 90, .external_lex_state = 38},
  [11336] = {.lex_state = 98},
  [11337] = {.lex_state = 91, .external_lex_state = 23},
  [11338] = {.lex_state = 77, .external_lex_state = 39},
  [11339] = {.lex_state = 77, .external_lex_state = 29},
  [11340] = {.lex_state = 77, .external_lex_state = 34},
  [11341] = {.lex_state = 42},
  [11342] = {.lex_state = 13},
  [11343] = {.lex_state = 42},
  [11344] = {.lex_state = 99},
  [11345] = {.lex_state = 26},
  [11346] = {.lex_state = 77, .external_lex_state = 29},
  [11347] = {.lex_state = 98},
  [11348] = {.lex_state = 77, .external_lex_state = 29},
  [11349] = {.lex_state = 90, .external_lex_state = 38},
  [11350] = {.lex_state = 46},
  [11351] = {.lex_state = 13},
  [11352] = {.lex_state = 38},
  [11353] = {.lex_state = 33},
  [11354] = {.lex_state = 99},
  [11355] = {.lex_state = 33},
  [11356] = {.lex_state = 76, .external_lex_state = 24},
  [11357] = {.lex_state = 97, .external_lex_state = 64},
  [11358] = {.lex_state = 99},
  [11359] = {.lex_state = 90, .external_lex_state = 40},
  [11360] = {.lex_state = 91, .external_lex_state = 23},
  [11361] = {.lex_state = 91},
  [11362] = {.lex_state = 97, .external_lex_state = 23},
  [11363] = {.lex_state = 33},
  [11364] = {.lex_state = 6},
  [11365] = {.lex_state = 6},
  [11366] = {.lex_state = 13},
  [11367] = {.lex_state = 33},
  [11368] = {.lex_state = 91, .external_lex_state = 23},
  [11369] = {.lex_state = 90, .external_lex_state = 38},
  [11370] = {.lex_state = 91, .external_lex_state = 23},
  [11371] = {.lex_state = 91},
  [11372] = {.lex_state = 6},
  [11373] = {.lex_state = 26},
  [11374] = {.lex_state = 91},
  [11375] = {.lex_state = 13},
  [11376] = {.lex_state = 6},
  [11377] = {.lex_state = 77, .external_lex_state = 23},
  [11378] = {.lex_state = 13},
  [11379] = {.lex_state = 90, .external_lex_state = 38},
  [11380] = {.lex_state = 91, .external_lex_state = 23},
  [11381] = {.lex_state = 91, .external_lex_state = 23},
  [11382] = {.lex_state = 77, .external_lex_state = 61},
  [11383] = {.lex_state = 77, .external_lex_state = 63},
  [11384] = {.lex_state = 91},
  [11385] = {.lex_state = 33},
  [11386] = {.lex_state = 91},
  [11387] = {.lex_state = 77, .external_lex_state = 30},
  [11388] = {.lex_state = 91, .external_lex_state = 23},
  [11389] = {.lex_state = 6},
  [11390] = {.lex_state = 90, .external_lex_state = 40},
  [11391] = {.lex_state = 34},
  [11392] = {.lex_state = 91},
  [11393] = {.lex_state = 13},
  [11394] = {.lex_state = 77, .external_lex_state = 29},
  [11395] = {.lex_state = 6},
  [11396] = {.lex_state = 91, .external_lex_state = 24},
  [11397] = {.lex_state = 99},
  [11398] = {.lex_state = 26},
  [11399] = {.lex_state = 97, .external_lex_state = 23},
  [11400] = {.lex_state = 77, .external_lex_state = 34},
  [11401] = {.lex_state = 98},
  [11402] = {.lex_state = 91, .external_lex_state = 23},
  [11403] = {.lex_state = 13},
  [11404] = {.lex_state = 77, .external_lex_state = 34},
  [11405] = {.lex_state = 13},
  [11406] = {.lex_state = 90, .external_lex_state = 40},
  [11407] = {.lex_state = 32},
  [11408] = {.lex_state = 32},
  [11409] = {.lex_state = 91},
  [11410] = {.lex_state = 32},
  [11411] = {.lex_state = 32},
  [11412] = {.lex_state = 76, .external_lex_state = 23},
  [11413] = {.lex_state = 32},
  [11414] = {.lex_state = 32},
  [11415] = {.lex_state = 32},
  [11416] = {.lex_state = 32},
  [11417] = {.lex_state = 32},
  [11418] = {.lex_state = 32},
  [11419] = {.lex_state = 96},
  [11420] = {.lex_state = 77, .external_lex_state = 60},
  [11421] = {.lex_state = 77, .external_lex_state = 34},
  [11422] = {.lex_state = 32},
  [11423] = {.lex_state = 32},
  [11424] = {.lex_state = 77, .external_lex_state = 34},
  [11425] = {.lex_state = 34},
  [11426] = {.lex_state = 76, .external_lex_state = 23},
  [11427] = {.lex_state = 32},
  [11428] = {.lex_state = 32},
  [11429] = {.lex_state = 76, .external_lex_state = 23},
  [11430] = {.lex_state = 77, .external_lex_state = 61},
  [11431] = {.lex_state = 76, .external_lex_state = 23},
  [11432] = {.lex_state = 32},
  [11433] = {.lex_state = 32},
  [11434] = {.lex_state = 32},
  [11435] = {.lex_state = 32},
  [11436] = {.lex_state = 32},
  [11437] = {.lex_state = 90, .external_lex_state = 23},
  [11438] = {.lex_state = 90, .external_lex_state = 23},
  [11439] = {.lex_state = 77, .external_lex_state = 63},
  [11440] = {.lex_state = 32},
  [11441] = {.lex_state = 77, .external_lex_state = 30},
  [11442] = {.lex_state = 32},
  [11443] = {.lex_state = 32},
  [11444] = {.lex_state = 90, .external_lex_state = 23},
  [11445] = {.lex_state = 32},
  [11446] = {.lex_state = 91},
  [11447] = {.lex_state = 77, .external_lex_state = 40},
  [11448] = {.lex_state = 77, .external_lex_state = 29},
  [11449] = {.lex_state = 77, .external_lex_state = 29},
  [11450] = {.lex_state = 91},
  [11451] = {.lex_state = 32},
  [11452] = {.lex_state = 84, .external_lex_state = 40},
  [11453] = {.lex_state = 77, .external_lex_state = 30},
  [11454] = {.lex_state = 96},
  [11455] = {.lex_state = 7},
  [11456] = {.lex_state = 5},
  [11457] = {.lex_state = 77, .external_lex_state = 34},
  [11458] = {.lex_state = 32},
  [11459] = {.lex_state = 77, .external_lex_state = 29},
  [11460] = {.lex_state = 32},
  [11461] = {.lex_state = 91},
  [11462] = {.lex_state = 91},
  [11463] = {.lex_state = 32},
  [11464] = {.lex_state = 32},
  [11465] = {.lex_state = 77, .external_lex_state = 34},
  [11466] = {.lex_state = 84, .external_lex_state = 40},
  [11467] = {.lex_state = 77, .external_lex_state = 34},
  [11468] = {.lex_state = 34},
  [11469] = {.lex_state = 32},
  [11470] = {.lex_state = 77, .external_lex_state = 60},
  [11471] = {.lex_state = 32},
  [11472] = {.lex_state = 34},
  [11473] = {.lex_state = 77, .external_lex_state = 38},
  [11474] = {.lex_state = 32},
  [11475] = {.lex_state = 32},
  [11476] = {.lex_state = 32},
  [11477] = {.lex_state = 77, .external_lex_state = 34},
  [11478] = {.lex_state = 77, .external_lex_state = 38},
  [11479] = {.lex_state = 77, .external_lex_state = 40},
  [11480] = {.lex_state = 91},
  [11481] = {.lex_state = 77, .external_lex_state = 29},
  [11482] = {.lex_state = 77, .external_lex_state = 29},
  [11483] = {.lex_state = 91},
  [11484] = {.lex_state = 32},
  [11485] = {.lex_state = 32},
  [11486] = {.lex_state = 32},
  [11487] = {.lex_state = 77, .external_lex_state = 34},
  [11488] = {.lex_state = 32},
  [11489] = {.lex_state = 32},
  [11490] = {.lex_state = 32},
  [11491] = {.lex_state = 76, .external_lex_state = 23},
  [11492] = {.lex_state = 32},
  [11493] = {.lex_state = 76, .external_lex_state = 23},
  [11494] = {.lex_state = 32},
  [11495] = {.lex_state = 32},
  [11496] = {.lex_state = 77, .external_lex_state = 46},
  [11497] = {.lex_state = 32},
  [11498] = {.lex_state = 32},
  [11499] = {.lex_state = 84, .external_lex_state = 29},
  [11500] = {.lex_state = 32},
  [11501] = {.lex_state = 32},
  [11502] = {.lex_state = 32},
  [11503] = {.lex_state = 77, .external_lex_state = 30},
  [11504] = {.lex_state = 32},
  [11505] = {.lex_state = 32},
  [11506] = {.lex_state = 84, .external_lex_state = 30},
  [11507] = {.lex_state = 77, .external_lex_state = 40},
  [11508] = {.lex_state = 32},
  [11509] = {.lex_state = 32},
  [11510] = {.lex_state = 77, .external_lex_state = 29},
  [11511] = {.lex_state = 77, .external_lex_state = 60},
  [11512] = {.lex_state = 77, .external_lex_state = 50},
  [11513] = {.lex_state = 77, .external_lex_state = 29},
  [11514] = {.lex_state = 32},
  [11515] = {.lex_state = 77, .external_lex_state = 34},
  [11516] = {.lex_state = 77, .external_lex_state = 30},
  [11517] = {.lex_state = 91},
  [11518] = {.lex_state = 90, .external_lex_state = 23},
  [11519] = {.lex_state = 90, .external_lex_state = 23},
  [11520] = {.lex_state = 32},
  [11521] = {.lex_state = 47},
  [11522] = {.lex_state = 96},
  [11523] = {.lex_state = 77, .external_lex_state = 40},
  [11524] = {.lex_state = 77, .external_lex_state = 61},
  [11525] = {.lex_state = 77, .external_lex_state = 30},
  [11526] = {.lex_state = 77, .external_lex_state = 34},
  [11527] = {.lex_state = 77, .external_lex_state = 30},
  [11528] = {.lex_state = 84, .external_lex_state = 34},
  [11529] = {.lex_state = 32},
  [11530] = {.lex_state = 31},
  [11531] = {.lex_state = 32},
  [11532] = {.lex_state = 32},
  [11533] = {.lex_state = 77, .external_lex_state = 63},
  [11534] = {.lex_state = 76, .external_lex_state = 23},
  [11535] = {.lex_state = 91},
  [11536] = {.lex_state = 77, .external_lex_state = 30},
  [11537] = {.lex_state = 96},
  [11538] = {.lex_state = 77, .external_lex_state = 50},
  [11539] = {.lex_state = 32},
  [11540] = {.lex_state = 32},
  [11541] = {.lex_state = 32},
  [11542] = {.lex_state = 32},
  [11543] = {.lex_state = 77, .external_lex_state = 35},
  [11544] = {.lex_state = 77, .external_lex_state = 30},
  [11545] = {.lex_state = 32},
  [11546] = {.lex_state = 32},
  [11547] = {.lex_state = 77, .external_lex_state = 34},
  [11548] = {.lex_state = 77, .external_lex_state = 60},
  [11549] = {.lex_state = 77, .external_lex_state = 30},
  [11550] = {.lex_state = 91},
  [11551] = {.lex_state = 32},
  [11552] = {.lex_state = 77, .external_lex_state = 34},
  [11553] = {.lex_state = 32},
  [11554] = {.lex_state = 77, .external_lex_state = 29},
  [11555] = {.lex_state = 77, .external_lex_state = 34},
  [11556] = {.lex_state = 91},
  [11557] = {.lex_state = 77, .external_lex_state = 29},
  [11558] = {.lex_state = 32},
  [11559] = {.lex_state = 32},
  [11560] = {.lex_state = 34},
  [11561] = {.lex_state = 77, .external_lex_state = 29},
  [11562] = {.lex_state = 32},
  [11563] = {.lex_state = 77, .external_lex_state = 38},
  [11564] = {.lex_state = 76, .external_lex_state = 23},
  [11565] = {.lex_state = 32},
  [11566] = {.lex_state = 32},
  [11567] = {.lex_state = 96},
  [11568] = {.lex_state = 77, .external_lex_state = 38},
  [11569] = {.lex_state = 32},
  [11570] = {.lex_state = 32},
  [11571] = {.lex_state = 77, .external_lex_state = 29},
  [11572] = {.lex_state = 77, .external_lex_state = 29},
  [11573] = {.lex_state = 32},
  [11574] = {.lex_state = 32},
  [11575] = {.lex_state = 77, .external_lex_state = 30},
  [11576] = {.lex_state = 77, .external_lex_state = 29},
  [11577] = {.lex_state = 32},
  [11578] = {.lex_state = 77, .external_lex_state = 30},
  [11579] = {.lex_state = 32},
  [11580] = {.lex_state = 32},
  [11581] = {.lex_state = 32},
  [11582] = {.lex_state = 32},
  [11583] = {.lex_state = 32},
  [11584] = {.lex_state = 91},
  [11585] = {.lex_state = 32},
  [11586] = {.lex_state = 32},
  [11587] = {.lex_state = 32},
  [11588] = {.lex_state = 90, .external_lex_state = 23},
  [11589] = {.lex_state = 32},
  [11590] = {.lex_state = 77, .external_lex_state = 60},
  [11591] = {.lex_state = 32},
  [11592] = {.lex_state = 32},
  [11593] = {.lex_state = 90, .external_lex_state = 23},
  [11594] = {.lex_state = 32},
  [11595] = {.lex_state = 32},
  [11596] = {.lex_state = 77, .external_lex_state = 62},
  [11597] = {.lex_state = 32},
  [11598] = {.lex_state = 90, .external_lex_state = 23},
  [11599] = {.lex_state = 77, .external_lex_state = 60},
  [11600] = {.lex_state = 32},
  [11601] = {.lex_state = 32},
  [11602] = {.lex_state = 32},
  [11603] = {.lex_state = 32},
  [11604] = {.lex_state = 32},
  [11605] = {.lex_state = 32},
  [11606] = {.lex_state = 32},
  [11607] = {.lex_state = 32},
  [11608] = {.lex_state = 32},
  [11609] = {.lex_state = 32},
  [11610] = {.lex_state = 32},
  [11611] = {.lex_state = 76, .external_lex_state = 23},
  [11612] = {.lex_state = 77, .external_lex_state = 29},
  [11613] = {.lex_state = 76, .external_lex_state = 23},
  [11614] = {.lex_state = 32},
  [11615] = {.lex_state = 32},
  [11616] = {.lex_state = 77, .external_lex_state = 30},
  [11617] = {.lex_state = 32},
  [11618] = {.lex_state = 32},
  [11619] = {.lex_state = 91},
  [11620] = {.lex_state = 32},
  [11621] = {.lex_state = 32},
  [11622] = {.lex_state = 77, .external_lex_state = 35},
  [11623] = {.lex_state = 76, .external_lex_state = 23},
  [11624] = {.lex_state = 32},
  [11625] = {.lex_state = 76, .external_lex_state = 23},
  [11626] = {.lex_state = 32},
  [11627] = {.lex_state = 32},
  [11628] = {.lex_state = 32},
  [11629] = {.lex_state = 32},
  [11630] = {.lex_state = 32},
  [11631] = {.lex_state = 76, .external_lex_state = 23},
  [11632] = {.lex_state = 32},
  [11633] = {.lex_state = 32},
  [11634] = {.lex_state = 77, .external_lex_state = 34},
  [11635] = {.lex_state = 32},
  [11636] = {.lex_state = 32},
  [11637] = {.lex_state = 76, .external_lex_state = 23},
  [11638] = {.lex_state = 32},
  [11639] = {.lex_state = 32},
  [11640] = {.lex_state = 91},
  [11641] = {.lex_state = 91},
  [11642] = {.lex_state = 76, .external_lex_state = 23},
  [11643] = {.lex_state = 77, .external_lex_state = 30},
  [11644] = {.lex_state = 76, .external_lex_state = 23},
  [11645] = {.lex_state = 96},
  [11646] = {.lex_state = 96},
  [11647] = {.lex_state = 76, .external_lex_state = 23},
  [11648] = {.lex_state = 32},
  [11649] = {.lex_state = 77, .external_lex_state = 29},
  [11650] = {.lex_state = 77, .external_lex_state = 29},
  [11651] = {.lex_state = 77, .external_lex_state = 29},
  [11652] = {.lex_state = 32},
  [11653] = {.lex_state = 32},
  [11654] = {.lex_state = 32},
  [11655] = {.lex_state = 32},
  [11656] = {.lex_state = 77, .external_lex_state = 29},
  [11657] = {.lex_state = 32},
  [11658] = {.lex_state = 77, .external_lex_state = 62},
  [11659] = {.lex_state = 77, .external_lex_state = 29},
  [11660] = {.lex_state = 32},
  [11661] = {.lex_state = 91},
  [11662] = {.lex_state = 96},
  [11663] = {.lex_state = 32},
  [11664] = {.lex_state = 32},
  [11665] = {.lex_state = 32},
  [11666] = {.lex_state = 96},
  [11667] = {.lex_state = 96},
  [11668] = {.lex_state = 32},
  [11669] = {.lex_state = 77, .external_lex_state = 61},
  [11670] = {.lex_state = 32},
  [11671] = {.lex_state = 32},
  [11672] = {.lex_state = 77, .external_lex_state = 45},
  [11673] = {.lex_state = 90, .external_lex_state = 23},
  [11674] = {.lex_state = 77, .external_lex_state = 60},
  [11675] = {.lex_state = 77, .external_lex_state = 61},
  [11676] = {.lex_state = 32},
  [11677] = {.lex_state = 32},
  [11678] = {.lex_state = 32},
  [11679] = {.lex_state = 32},
  [11680] = {.lex_state = 32},
  [11681] = {.lex_state = 77, .external_lex_state = 29},
  [11682] = {.lex_state = 32},
  [11683] = {.lex_state = 32},
  [11684] = {.lex_state = 84, .external_lex_state = 38},
  [11685] = {.lex_state = 32},
  [11686] = {.lex_state = 32},
  [11687] = {.lex_state = 77, .external_lex_state = 29},
  [11688] = {.lex_state = 32},
  [11689] = {.lex_state = 84, .external_lex_state = 38},
  [11690] = {.lex_state = 32},
  [11691] = {.lex_state = 32},
  [11692] = {.lex_state = 32},
  [11693] = {.lex_state = 32},
  [11694] = {.lex_state = 32},
  [11695] = {.lex_state = 32},
  [11696] = {.lex_state = 32},
  [11697] = {.lex_state = 32},
  [11698] = {.lex_state = 32},
  [11699] = {.lex_state = 76, .external_lex_state = 23},
  [11700] = {.lex_state = 32},
  [11701] = {.lex_state = 32},
  [11702] = {.lex_state = 33},
  [11703] = {.lex_state = 27},
  [11704] = {.lex_state = 27},
  [11705] = {.lex_state = 27},
  [11706] = {.lex_state = 27},
  [11707] = {.lex_state = 27},
  [11708] = {.lex_state = 27},
  [11709] = {.lex_state = 27},
  [11710] = {.lex_state = 27},
  [11711] = {.lex_state = 77, .external_lex_state = 63},
  [11712] = {.lex_state = 27},
  [11713] = {.lex_state = 33},
  [11714] = {.lex_state = 84, .external_lex_state = 29},
  [11715] = {.lex_state = 84, .external_lex_state = 29},
  [11716] = {.lex_state = 32},
  [11717] = {.lex_state = 84, .external_lex_state = 29},
  [11718] = {.lex_state = 77, .external_lex_state = 50},
  [11719] = {.lex_state = 84, .external_lex_state = 29},
  [11720] = {.lex_state = 84, .external_lex_state = 29},
  [11721] = {.lex_state = 84, .external_lex_state = 29},
  [11722] = {.lex_state = 77, .external_lex_state = 30},
  [11723] = {.lex_state = 84, .external_lex_state = 29},
  [11724] = {.lex_state = 84, .external_lex_state = 38},
  [11725] = {.lex_state = 84, .external_lex_state = 29},
  [11726] = {.lex_state = 32},
  [11727] = {.lex_state = 77, .external_lex_state = 63},
  [11728] = {.lex_state = 32},
  [11729] = {.lex_state = 32},
  [11730] = {.lex_state = 32},
  [11731] = {.lex_state = 77, .external_lex_state = 60},
  [11732] = {.lex_state = 77, .external_lex_state = 35},
  [11733] = {.lex_state = 27},
  [11734] = {.lex_state = 27},
  [11735] = {.lex_state = 32},
  [11736] = {.lex_state = 27},
  [11737] = {.lex_state = 77, .external_lex_state = 60},
  [11738] = {.lex_state = 77, .external_lex_state = 30},
  [11739] = {.lex_state = 77, .external_lex_state = 61},
  [11740] = {.lex_state = 27},
  [11741] = {.lex_state = 27},
  [11742] = {.lex_state = 77, .external_lex_state = 30},
  [11743] = {.lex_state = 77, .external_lex_state = 30},
  [11744] = {.lex_state = 77, .external_lex_state = 23},
  [11745] = {.lex_state = 32},
  [11746] = {.lex_state = 76},
  [11747] = {.lex_state = 32},
  [11748] = {.lex_state = 27},
  [11749] = {.lex_state = 77, .external_lex_state = 34},
  [11750] = {.lex_state = 77, .external_lex_state = 34},
  [11751] = {.lex_state = 77, .external_lex_state = 62},
  [11752] = {.lex_state = 77, .external_lex_state = 34},
  [11753] = {.lex_state = 77, .external_lex_state = 34},
  [11754] = {.lex_state = 76},
  [11755] = {.lex_state = 77, .external_lex_state = 34},
  [11756] = {.lex_state = 77, .external_lex_state = 60},
  [11757] = {.lex_state = 76},
  [11758] = {.lex_state = 76},
  [11759] = {.lex_state = 77, .external_lex_state = 30},
  [11760] = {.lex_state = 76},
  [11761] = {.lex_state = 77, .external_lex_state = 61},
  [11762] = {.lex_state = 76},
  [11763] = {.lex_state = 77, .external_lex_state = 30},
  [11764] = {.lex_state = 77, .external_lex_state = 30},
  [11765] = {.lex_state = 32},
  [11766] = {.lex_state = 32},
  [11767] = {.lex_state = 77, .external_lex_state = 60},
  [11768] = {.lex_state = 77, .external_lex_state = 34},
  [11769] = {.lex_state = 77, .external_lex_state = 61},
  [11770] = {.lex_state = 27},
  [11771] = {.lex_state = 77, .external_lex_state = 35},
  [11772] = {.lex_state = 77, .external_lex_state = 30},
  [11773] = {.lex_state = 77, .external_lex_state = 60},
  [11774] = {.lex_state = 77, .external_lex_state = 62},
  [11775] = {.lex_state = 33},
  [11776] = {.lex_state = 84, .external_lex_state = 30},
  [11777] = {.lex_state = 33},
  [11778] = {.lex_state = 6},
  [11779] = {.lex_state = 77, .external_lex_state = 39},
  [11780] = {.lex_state = 27},
  [11781] = {.lex_state = 32},
  [11782] = {.lex_state = 77, .external_lex_state = 34},
  [11783] = {.lex_state = 32},
  [11784] = {.lex_state = 32},
  [11785] = {.lex_state = 33},
  [11786] = {.lex_state = 32},
  [11787] = {.lex_state = 27},
  [11788] = {.lex_state = 32},
  [11789] = {.lex_state = 77, .external_lex_state = 61},
  [11790] = {.lex_state = 77, .external_lex_state = 34},
  [11791] = {.lex_state = 84, .external_lex_state = 29},
  [11792] = {.lex_state = 77, .external_lex_state = 61},
  [11793] = {.lex_state = 84, .external_lex_state = 23},
  [11794] = {.lex_state = 77, .external_lex_state = 30},
  [11795] = {.lex_state = 77, .external_lex_state = 34},
  [11796] = {.lex_state = 47},
  [11797] = {.lex_state = 27},
  [11798] = {.lex_state = 77, .external_lex_state = 61},
  [11799] = {.lex_state = 76},
  [11800] = {.lex_state = 77, .external_lex_state = 38},
  [11801] = {.lex_state = 77, .external_lex_state = 60},
  [11802] = {.lex_state = 32},
  [11803] = {.lex_state = 27},
  [11804] = {.lex_state = 27},
  [11805] = {.lex_state = 32},
  [11806] = {.lex_state = 77, .external_lex_state = 61},
  [11807] = {.lex_state = 32},
  [11808] = {.lex_state = 77, .external_lex_state = 62},
  [11809] = {.lex_state = 77, .external_lex_state = 61},
  [11810] = {.lex_state = 77, .external_lex_state = 34},
  [11811] = {.lex_state = 33},
  [11812] = {.lex_state = 27},
  [11813] = {.lex_state = 27},
  [11814] = {.lex_state = 77, .external_lex_state = 61},
  [11815] = {.lex_state = 32},
  [11816] = {.lex_state = 33},
  [11817] = {.lex_state = 27},
  [11818] = {.lex_state = 77, .external_lex_state = 34},
  [11819] = {.lex_state = 77, .external_lex_state = 30},
  [11820] = {.lex_state = 77, .external_lex_state = 34},
  [11821] = {.lex_state = 77, .external_lex_state = 30},
  [11822] = {.lex_state = 32},
  [11823] = {.lex_state = 32},
  [11824] = {.lex_state = 77, .external_lex_state = 30},
  [11825] = {.lex_state = 77, .external_lex_state = 34},
  [11826] = {.lex_state = 32},
  [11827] = {.lex_state = 77, .external_lex_state = 34},
  [11828] = {.lex_state = 77},
  [11829] = {.lex_state = 32},
  [11830] = {.lex_state = 32},
  [11831] = {.lex_state = 32},
  [11832] = {.lex_state = 84, .external_lex_state = 23},
  [11833] = {.lex_state = 77, .external_lex_state = 34},
  [11834] = {.lex_state = 77, .external_lex_state = 34},
  [11835] = {.lex_state = 33},
  [11836] = {.lex_state = 27},
  [11837] = {.lex_state = 77, .external_lex_state = 38},
  [11838] = {.lex_state = 77, .external_lex_state = 60},
  [11839] = {.lex_state = 32},
  [11840] = {.lex_state = 97, .external_lex_state = 64},
  [11841] = {.lex_state = 77, .external_lex_state = 30},
  [11842] = {.lex_state = 32},
  [11843] = {.lex_state = 32},
  [11844] = {.lex_state = 77, .external_lex_state = 38},
  [11845] = {.lex_state = 77, .external_lex_state = 38},
  [11846] = {.lex_state = 77, .external_lex_state = 60},
  [11847] = {.lex_state = 77, .external_lex_state = 63},
  [11848] = {.lex_state = 77, .external_lex_state = 38},
  [11849] = {.lex_state = 77, .external_lex_state = 38},
  [11850] = {.lex_state = 84, .external_lex_state = 29},
  [11851] = {.lex_state = 77, .external_lex_state = 38},
  [11852] = {.lex_state = 33},
  [11853] = {.lex_state = 77, .external_lex_state = 38},
  [11854] = {.lex_state = 32},
  [11855] = {.lex_state = 84, .external_lex_state = 29},
  [11856] = {.lex_state = 84, .external_lex_state = 29},
  [11857] = {.lex_state = 33},
  [11858] = {.lex_state = 77, .external_lex_state = 39},
  [11859] = {.lex_state = 77, .external_lex_state = 39},
  [11860] = {.lex_state = 76},
  [11861] = {.lex_state = 77, .external_lex_state = 60},
  [11862] = {.lex_state = 76},
  [11863] = {.lex_state = 76},
  [11864] = {.lex_state = 84, .external_lex_state = 29},
  [11865] = {.lex_state = 32},
  [11866] = {.lex_state = 33},
  [11867] = {.lex_state = 77, .external_lex_state = 61},
  [11868] = {.lex_state = 77, .external_lex_state = 38},
  [11869] = {.lex_state = 77, .external_lex_state = 61},
  [11870] = {.lex_state = 76},
  [11871] = {.lex_state = 77, .external_lex_state = 50},
  [11872] = {.lex_state = 32},
  [11873] = {.lex_state = 77, .external_lex_state = 50},
  [11874] = {.lex_state = 76},
  [11875] = {.lex_state = 77, .external_lex_state = 61},
  [11876] = {.lex_state = 77, .external_lex_state = 61},
  [11877] = {.lex_state = 32},
  [11878] = {.lex_state = 84, .external_lex_state = 29},
  [11879] = {.lex_state = 32},
  [11880] = {.lex_state = 76},
  [11881] = {.lex_state = 84, .external_lex_state = 29},
  [11882] = {.lex_state = 84, .external_lex_state = 29},
  [11883] = {.lex_state = 84, .external_lex_state = 29},
  [11884] = {.lex_state = 33},
  [11885] = {.lex_state = 84, .external_lex_state = 29},
  [11886] = {.lex_state = 33},
  [11887] = {.lex_state = 76},
  [11888] = {.lex_state = 33},
  [11889] = {.lex_state = 84, .external_lex_state = 29},
  [11890] = {.lex_state = 84, .external_lex_state = 29},
  [11891] = {.lex_state = 32},
  [11892] = {.lex_state = 32},
  [11893] = {.lex_state = 77, .external_lex_state = 60},
  [11894] = {.lex_state = 97, .external_lex_state = 64},
  [11895] = {.lex_state = 84, .external_lex_state = 29},
  [11896] = {.lex_state = 84, .external_lex_state = 29},
  [11897] = {.lex_state = 84, .external_lex_state = 29},
  [11898] = {.lex_state = 77, .external_lex_state = 60},
  [11899] = {.lex_state = 32},
  [11900] = {.lex_state = 77, .external_lex_state = 60},
  [11901] = {.lex_state = 84, .external_lex_state = 29},
  [11902] = {.lex_state = 76},
  [11903] = {.lex_state = 32},
  [11904] = {.lex_state = 84, .external_lex_state = 29},
  [11905] = {.lex_state = 77, .external_lex_state = 34},
  [11906] = {.lex_state = 76},
  [11907] = {.lex_state = 32},
  [11908] = {.lex_state = 77, .external_lex_state = 38},
  [11909] = {.lex_state = 33},
  [11910] = {.lex_state = 77, .external_lex_state = 35},
  [11911] = {.lex_state = 77, .external_lex_state = 30},
  [11912] = {.lex_state = 84, .external_lex_state = 29},
  [11913] = {.lex_state = 77, .external_lex_state = 38},
  [11914] = {.lex_state = 32},
  [11915] = {.lex_state = 33},
  [11916] = {.lex_state = 33},
  [11917] = {.lex_state = 32},
  [11918] = {.lex_state = 77, .external_lex_state = 30},
  [11919] = {.lex_state = 32},
  [11920] = {.lex_state = 84, .external_lex_state = 29},
  [11921] = {.lex_state = 32},
  [11922] = {.lex_state = 84, .external_lex_state = 29},
  [11923] = {.lex_state = 32},
  [11924] = {.lex_state = 84, .external_lex_state = 29},
  [11925] = {.lex_state = 32},
  [11926] = {.lex_state = 32},
  [11927] = {.lex_state = 84, .external_lex_state = 29},
  [11928] = {.lex_state = 33},
  [11929] = {.lex_state = 32},
  [11930] = {.lex_state = 33},
  [11931] = {.lex_state = 33},
  [11932] = {.lex_state = 77, .external_lex_state = 38},
  [11933] = {.lex_state = 97, .external_lex_state = 64},
  [11934] = {.lex_state = 77, .external_lex_state = 61},
  [11935] = {.lex_state = 33},
  [11936] = {.lex_state = 77, .external_lex_state = 62},
  [11937] = {.lex_state = 32},
  [11938] = {.lex_state = 32},
  [11939] = {.lex_state = 33},
  [11940] = {.lex_state = 77, .external_lex_state = 60},
  [11941] = {.lex_state = 77, .external_lex_state = 40},
  [11942] = {.lex_state = 77, .external_lex_state = 40},
  [11943] = {.lex_state = 33},
  [11944] = {.lex_state = 97, .external_lex_state = 64},
  [11945] = {.lex_state = 77, .external_lex_state = 40},
  [11946] = {.lex_state = 77, .external_lex_state = 40},
  [11947] = {.lex_state = 33},
  [11948] = {.lex_state = 32},
  [11949] = {.lex_state = 33},
  [11950] = {.lex_state = 77, .external_lex_state = 40},
  [11951] = {.lex_state = 33},
  [11952] = {.lex_state = 77, .external_lex_state = 53},
  [11953] = {.lex_state = 32},
  [11954] = {.lex_state = 32},
  [11955] = {.lex_state = 97, .external_lex_state = 64},
  [11956] = {.lex_state = 97, .external_lex_state = 64},
  [11957] = {.lex_state = 77, .external_lex_state = 30},
  [11958] = {.lex_state = 77, .external_lex_state = 30},
  [11959] = {.lex_state = 77, .external_lex_state = 61},
  [11960] = {.lex_state = 76, .external_lex_state = 23},
  [11961] = {.lex_state = 77, .external_lex_state = 35},
  [11962] = {.lex_state = 77, .external_lex_state = 40},
  [11963] = {.lex_state = 77, .external_lex_state = 62},
  [11964] = {.lex_state = 77, .external_lex_state = 54},
  [11965] = {.lex_state = 84, .external_lex_state = 39},
  [11966] = {.lex_state = 77, .external_lex_state = 63},
  [11967] = {.lex_state = 77, .external_lex_state = 40},
  [11968] = {.lex_state = 77, .external_lex_state = 40},
  [11969] = {.lex_state = 77, .external_lex_state = 34},
  [11970] = {.lex_state = 33},
  [11971] = {.lex_state = 84, .external_lex_state = 39},
  [11972] = {.lex_state = 32},
  [11973] = {.lex_state = 32},
  [11974] = {.lex_state = 77, .external_lex_state = 30},
  [11975] = {.lex_state = 34},
  [11976] = {.lex_state = 77, .external_lex_state = 60},
  [11977] = {.lex_state = 77, .external_lex_state = 34},
  [11978] = {.lex_state = 77, .external_lex_state = 34},
  [11979] = {.lex_state = 77, .external_lex_state = 34},
  [11980] = {.lex_state = 77, .external_lex_state = 30},
  [11981] = {.lex_state = 33},
  [11982] = {.lex_state = 77, .external_lex_state = 30},
  [11983] = {.lex_state = 32},
  [11984] = {.lex_state = 77, .external_lex_state = 40},
  [11985] = {.lex_state = 77, .external_lex_state = 61},
  [11986] = {.lex_state = 97, .external_lex_state = 64},
  [11987] = {.lex_state = 77, .external_lex_state = 60},
  [11988] = {.lex_state = 33},
  [11989] = {.lex_state = 32},
  [11990] = {.lex_state = 97, .external_lex_state = 64},
  [11991] = {.lex_state = 77, .external_lex_state = 40},
  [11992] = {.lex_state = 77, .external_lex_state = 38},
  [11993] = {.lex_state = 97, .external_lex_state = 64},
  [11994] = {.lex_state = 77, .external_lex_state = 40},
  [11995] = {.lex_state = 32},
  [11996] = {.lex_state = 32},
  [11997] = {.lex_state = 32},
  [11998] = {.lex_state = 97},
  [11999] = {.lex_state = 97, .external_lex_state = 64},
  [12000] = {.lex_state = 77, .external_lex_state = 62},
  [12001] = {.lex_state = 32},
  [12002] = {.lex_state = 32},
  [12003] = {.lex_state = 77, .external_lex_state = 40},
  [12004] = {.lex_state = 33},
  [12005] = {.lex_state = 32},
  [12006] = {.lex_state = 32},
  [12007] = {.lex_state = 32},
  [12008] = {.lex_state = 32},
  [12009] = {.lex_state = 84, .external_lex_state = 34},
  [12010] = {.lex_state = 32},
  [12011] = {.lex_state = 77, .external_lex_state = 30},
  [12012] = {.lex_state = 33},
  [12013] = {.lex_state = 32},
  [12014] = {.lex_state = 76},
  [12015] = {.lex_state = 32},
  [12016] = {.lex_state = 76, .external_lex_state = 35},
  [12017] = {.lex_state = 90, .external_lex_state = 25},
  [12018] = {.lex_state = 76},
  [12019] = {.lex_state = 77, .external_lex_state = 40},
  [12020] = {.lex_state = 76},
  [12021] = {.lex_state = 27},
  [12022] = {.lex_state = 27},
  [12023] = {.lex_state = 32},
  [12024] = {.lex_state = 32},
  [12025] = {.lex_state = 33},
  [12026] = {.lex_state = 33},
  [12027] = {.lex_state = 77, .external_lex_state = 50},
  [12028] = {.lex_state = 77, .external_lex_state = 61},
  [12029] = {.lex_state = 32},
  [12030] = {.lex_state = 32},
  [12031] = {.lex_state = 32},
  [12032] = {.lex_state = 32},
  [12033] = {.lex_state = 32},
  [12034] = {.lex_state = 32},
  [12035] = {.lex_state = 32},
  [12036] = {.lex_state = 84, .external_lex_state = 40},
  [12037] = {.lex_state = 27},
  [12038] = {.lex_state = 32},
  [12039] = {.lex_state = 32},
  [12040] = {.lex_state = 32},
  [12041] = {.lex_state = 32},
  [12042] = {.lex_state = 27},
  [12043] = {.lex_state = 77, .external_lex_state = 51},
  [12044] = {.lex_state = 27},
  [12045] = {.lex_state = 27},
  [12046] = {.lex_state = 27},
  [12047] = {.lex_state = 27},
  [12048] = {.lex_state = 77, .external_lex_state = 39},
  [12049] = {.lex_state = 32},
  [12050] = {.lex_state = 32},
  [12051] = {.lex_state = 77, .external_lex_state = 55},
  [12052] = {.lex_state = 90},
  [12053] = {.lex_state = 77, .external_lex_state = 60},
  [12054] = {.lex_state = 32},
  [12055] = {.lex_state = 32},
  [12056] = {.lex_state = 84, .external_lex_state = 45},
  [12057] = {.lex_state = 77, .external_lex_state = 46},
  [12058] = {.lex_state = 32},
  [12059] = {.lex_state = 84, .external_lex_state = 45},
  [12060] = {.lex_state = 76, .external_lex_state = 35},
  [12061] = {.lex_state = 32},
  [12062] = {.lex_state = 32},
  [12063] = {.lex_state = 32},
  [12064] = {.lex_state = 32},
  [12065] = {.lex_state = 77, .external_lex_state = 50},
  [12066] = {.lex_state = 32},
  [12067] = {.lex_state = 91},
  [12068] = {.lex_state = 32},
  [12069] = {.lex_state = 91},
  [12070] = {.lex_state = 91},
  [12071] = {.lex_state = 32},
  [12072] = {.lex_state = 91},
  [12073] = {.lex_state = 91},
  [12074] = {.lex_state = 32},
  [12075] = {.lex_state = 84, .external_lex_state = 23},
  [12076] = {.lex_state = 32},
  [12077] = {.lex_state = 32},
  [12078] = {.lex_state = 91},
  [12079] = {.lex_state = 77, .external_lex_state = 38},
  [12080] = {.lex_state = 32},
  [12081] = {.lex_state = 32},
  [12082] = {.lex_state = 32},
  [12083] = {.lex_state = 91},
  [12084] = {.lex_state = 32},
  [12085] = {.lex_state = 91},
  [12086] = {.lex_state = 91},
  [12087] = {.lex_state = 32},
  [12088] = {.lex_state = 91},
  [12089] = {.lex_state = 77, .external_lex_state = 23},
  [12090] = {.lex_state = 91},
  [12091] = {.lex_state = 32},
  [12092] = {.lex_state = 32},
  [12093] = {.lex_state = 77, .external_lex_state = 40},
  [12094] = {.lex_state = 32},
  [12095] = {.lex_state = 32},
  [12096] = {.lex_state = 77, .external_lex_state = 39},
  [12097] = {.lex_state = 91},
  [12098] = {.lex_state = 77, .external_lex_state = 39},
  [12099] = {.lex_state = 77, .external_lex_state = 39},
  [12100] = {.lex_state = 77, .external_lex_state = 58},
  [12101] = {.lex_state = 32},
  [12102] = {.lex_state = 32},
  [12103] = {.lex_state = 77, .external_lex_state = 39},
  [12104] = {.lex_state = 32},
  [12105] = {.lex_state = 32},
  [12106] = {.lex_state = 77, .external_lex_state = 23},
  [12107] = {.lex_state = 77, .external_lex_state = 39},
  [12108] = {.lex_state = 77, .external_lex_state = 39},
  [12109] = {.lex_state = 77, .external_lex_state = 39},
  [12110] = {.lex_state = 32},
  [12111] = {.lex_state = 77, .external_lex_state = 24},
  [12112] = {.lex_state = 77, .external_lex_state = 63},
  [12113] = {.lex_state = 77, .external_lex_state = 40},
  [12114] = {.lex_state = 77, .external_lex_state = 63},
  [12115] = {.lex_state = 77, .external_lex_state = 35},
  [12116] = {.lex_state = 32},
  [12117] = {.lex_state = 32},
  [12118] = {.lex_state = 77, .external_lex_state = 23},
  [12119] = {.lex_state = 32},
  [12120] = {.lex_state = 77, .external_lex_state = 40},
  [12121] = {.lex_state = 77, .external_lex_state = 35},
  [12122] = {.lex_state = 32},
  [12123] = {.lex_state = 90},
  [12124] = {.lex_state = 90},
  [12125] = {.lex_state = 77, .external_lex_state = 40},
  [12126] = {.lex_state = 77, .external_lex_state = 40},
  [12127] = {.lex_state = 77, .external_lex_state = 40},
  [12128] = {.lex_state = 90},
  [12129] = {.lex_state = 90},
  [12130] = {.lex_state = 77, .external_lex_state = 23},
  [12131] = {.lex_state = 32},
  [12132] = {.lex_state = 32},
  [12133] = {.lex_state = 32},
  [12134] = {.lex_state = 77, .external_lex_state = 62},
  [12135] = {.lex_state = 32},
  [12136] = {.lex_state = 77, .external_lex_state = 57},
  [12137] = {.lex_state = 77, .external_lex_state = 39},
  [12138] = {.lex_state = 91},
  [12139] = {.lex_state = 77, .external_lex_state = 40},
  [12140] = {.lex_state = 91},
  [12141] = {.lex_state = 32},
  [12142] = {.lex_state = 91},
  [12143] = {.lex_state = 32},
  [12144] = {.lex_state = 32},
  [12145] = {.lex_state = 32},
  [12146] = {.lex_state = 77, .external_lex_state = 40},
  [12147] = {.lex_state = 32},
  [12148] = {.lex_state = 76, .external_lex_state = 24},
  [12149] = {.lex_state = 77, .external_lex_state = 65},
  [12150] = {.lex_state = 77, .external_lex_state = 62},
  [12151] = {.lex_state = 77, .external_lex_state = 40},
  [12152] = {.lex_state = 32},
  [12153] = {.lex_state = 77, .external_lex_state = 45},
  [12154] = {.lex_state = 91},
  [12155] = {.lex_state = 32},
  [12156] = {.lex_state = 32},
  [12157] = {.lex_state = 32},
  [12158] = {.lex_state = 91},
  [12159] = {.lex_state = 91},
  [12160] = {.lex_state = 32},
  [12161] = {.lex_state = 47},
  [12162] = {.lex_state = 32},
  [12163] = {.lex_state = 32},
  [12164] = {.lex_state = 91},
  [12165] = {.lex_state = 32},
  [12166] = {.lex_state = 47},
  [12167] = {.lex_state = 47},
  [12168] = {.lex_state = 47},
  [12169] = {.lex_state = 84, .external_lex_state = 30},
  [12170] = {.lex_state = 32},
  [12171] = {.lex_state = 76, .external_lex_state = 24},
  [12172] = {.lex_state = 32},
  [12173] = {.lex_state = 32},
  [12174] = {.lex_state = 84, .external_lex_state = 34},
  [12175] = {.lex_state = 32},
  [12176] = {.lex_state = 32},
  [12177] = {.lex_state = 32},
  [12178] = {.lex_state = 32},
  [12179] = {.lex_state = 84, .external_lex_state = 30},
  [12180] = {.lex_state = 32},
  [12181] = {.lex_state = 91},
  [12182] = {.lex_state = 32},
  [12183] = {.lex_state = 32},
  [12184] = {.lex_state = 32},
  [12185] = {.lex_state = 91},
  [12186] = {.lex_state = 47},
  [12187] = {.lex_state = 32},
  [12188] = {.lex_state = 84, .external_lex_state = 34},
  [12189] = {.lex_state = 32},
  [12190] = {.lex_state = 32},
  [12191] = {.lex_state = 32},
  [12192] = {.lex_state = 47},
  [12193] = {.lex_state = 77, .external_lex_state = 23},
  [12194] = {.lex_state = 77, .external_lex_state = 45},
  [12195] = {.lex_state = 91},
  [12196] = {.lex_state = 91},
  [12197] = {.lex_state = 77, .external_lex_state = 40},
  [12198] = {.lex_state = 77, .external_lex_state = 40},
  [12199] = {.lex_state = 91},
  [12200] = {.lex_state = 77, .external_lex_state = 45},
  [12201] = {.lex_state = 84, .external_lex_state = 30},
  [12202] = {.lex_state = 32},
  [12203] = {.lex_state = 84, .external_lex_state = 30},
  [12204] = {.lex_state = 91},
  [12205] = {.lex_state = 91},
  [12206] = {.lex_state = 32},
  [12207] = {.lex_state = 77, .external_lex_state = 23},
  [12208] = {.lex_state = 32},
  [12209] = {.lex_state = 91},
  [12210] = {.lex_state = 84, .external_lex_state = 30},
  [12211] = {.lex_state = 91},
  [12212] = {.lex_state = 77, .external_lex_state = 46},
  [12213] = {.lex_state = 47},
  [12214] = {.lex_state = 32},
  [12215] = {.lex_state = 32},
  [12216] = {.lex_state = 77, .external_lex_state = 23},
  [12217] = {.lex_state = 91},
  [12218] = {.lex_state = 32},
  [12219] = {.lex_state = 84, .external_lex_state = 34},
  [12220] = {.lex_state = 32},
  [12221] = {.lex_state = 77, .external_lex_state = 46},
  [12222] = {.lex_state = 32},
  [12223] = {.lex_state = 32},
  [12224] = {.lex_state = 84, .external_lex_state = 34},
  [12225] = {.lex_state = 77, .external_lex_state = 62},
  [12226] = {.lex_state = 32},
  [12227] = {.lex_state = 77, .external_lex_state = 39},
  [12228] = {.lex_state = 77, .external_lex_state = 62},
  [12229] = {.lex_state = 32},
  [12230] = {.lex_state = 91},
  [12231] = {.lex_state = 77, .external_lex_state = 62},
  [12232] = {.lex_state = 77, .external_lex_state = 23},
  [12233] = {.lex_state = 77, .external_lex_state = 23},
  [12234] = {.lex_state = 32},
  [12235] = {.lex_state = 77, .external_lex_state = 46},
  [12236] = {.lex_state = 77, .external_lex_state = 62},
  [12237] = {.lex_state = 32},
  [12238] = {.lex_state = 77, .external_lex_state = 62},
  [12239] = {.lex_state = 32},
  [12240] = {.lex_state = 32},
  [12241] = {.lex_state = 91},
  [12242] = {.lex_state = 91},
  [12243] = {.lex_state = 32},
  [12244] = {.lex_state = 77, .external_lex_state = 23},
  [12245] = {.lex_state = 32},
  [12246] = {.lex_state = 91},
  [12247] = {.lex_state = 84, .external_lex_state = 30},
  [12248] = {.lex_state = 32},
  [12249] = {.lex_state = 84, .external_lex_state = 34},
  [12250] = {.lex_state = 32},
  [12251] = {.lex_state = 32},
  [12252] = {.lex_state = 32},
  [12253] = {.lex_state = 84, .external_lex_state = 39},
  [12254] = {.lex_state = 77, .external_lex_state = 62},
  [12255] = {.lex_state = 32},
  [12256] = {.lex_state = 77, .external_lex_state = 62},
  [12257] = {.lex_state = 84, .external_lex_state = 34},
  [12258] = {.lex_state = 32},
  [12259] = {.lex_state = 32},
  [12260] = {.lex_state = 84, .external_lex_state = 34},
  [12261] = {.lex_state = 84, .external_lex_state = 34},
  [12262] = {.lex_state = 77, .external_lex_state = 63},
  [12263] = {.lex_state = 91},
  [12264] = {.lex_state = 32},
  [12265] = {.lex_state = 32},
  [12266] = {.lex_state = 77, .external_lex_state = 60},
  [12267] = {.lex_state = 77, .external_lex_state = 60},
  [12268] = {.lex_state = 32},
  [12269] = {.lex_state = 77, .external_lex_state = 60},
  [12270] = {.lex_state = 77, .external_lex_state = 23},
  [12271] = {.lex_state = 84, .external_lex_state = 30},
  [12272] = {.lex_state = 84, .external_lex_state = 30},
  [12273] = {.lex_state = 84, .external_lex_state = 40},
  [12274] = {.lex_state = 84, .external_lex_state = 30},
  [12275] = {.lex_state = 32},
  [12276] = {.lex_state = 32},
  [12277] = {.lex_state = 84, .external_lex_state = 30},
  [12278] = {.lex_state = 91},
  [12279] = {.lex_state = 32},
  [12280] = {.lex_state = 77, .external_lex_state = 38},
  [12281] = {.lex_state = 32},
  [12282] = {.lex_state = 77, .external_lex_state = 61},
  [12283] = {.lex_state = 77, .external_lex_state = 63},
  [12284] = {.lex_state = 84, .external_lex_state = 30},
  [12285] = {.lex_state = 32},
  [12286] = {.lex_state = 91},
  [12287] = {.lex_state = 77, .external_lex_state = 63},
  [12288] = {.lex_state = 77, .external_lex_state = 38},
  [12289] = {.lex_state = 91},
  [12290] = {.lex_state = 84, .external_lex_state = 30},
  [12291] = {.lex_state = 32},
  [12292] = {.lex_state = 77, .external_lex_state = 38},
  [12293] = {.lex_state = 77, .external_lex_state = 56},
  [12294] = {.lex_state = 84, .external_lex_state = 30},
  [12295] = {.lex_state = 84, .external_lex_state = 30},
  [12296] = {.lex_state = 84, .external_lex_state = 30},
  [12297] = {.lex_state = 32},
  [12298] = {.lex_state = 84, .external_lex_state = 30},
  [12299] = {.lex_state = 32},
  [12300] = {.lex_state = 84, .external_lex_state = 30},
  [12301] = {.lex_state = 77, .external_lex_state = 63},
  [12302] = {.lex_state = 84, .external_lex_state = 30},
  [12303] = {.lex_state = 32},
  [12304] = {.lex_state = 91},
  [12305] = {.lex_state = 84, .external_lex_state = 34},
  [12306] = {.lex_state = 84, .external_lex_state = 34},
  [12307] = {.lex_state = 32},
  [12308] = {.lex_state = 84, .external_lex_state = 34},
  [12309] = {.lex_state = 84, .external_lex_state = 34},
  [12310] = {.lex_state = 77, .external_lex_state = 38},
  [12311] = {.lex_state = 77, .external_lex_state = 63},
  [12312] = {.lex_state = 77, .external_lex_state = 62},
  [12313] = {.lex_state = 77, .external_lex_state = 40},
  [12314] = {.lex_state = 77, .external_lex_state = 38},
  [12315] = {.lex_state = 77, .external_lex_state = 38},
  [12316] = {.lex_state = 77, .external_lex_state = 38},
  [12317] = {.lex_state = 77, .external_lex_state = 66},
  [12318] = {.lex_state = 77, .external_lex_state = 63},
  [12319] = {.lex_state = 77, .external_lex_state = 63},
  [12320] = {.lex_state = 77, .external_lex_state = 38},
  [12321] = {.lex_state = 77, .external_lex_state = 38},
  [12322] = {.lex_state = 77, .external_lex_state = 63},
  [12323] = {.lex_state = 77, .external_lex_state = 63},
  [12324] = {.lex_state = 32},
  [12325] = {.lex_state = 77, .external_lex_state = 38},
  [12326] = {.lex_state = 32},
  [12327] = {.lex_state = 32},
  [12328] = {.lex_state = 84, .external_lex_state = 30},
  [12329] = {.lex_state = 32},
  [12330] = {.lex_state = 90},
  [12331] = {.lex_state = 77, .external_lex_state = 38},
  [12332] = {.lex_state = 32},
  [12333] = {.lex_state = 84, .external_lex_state = 34},
  [12334] = {.lex_state = 77, .external_lex_state = 63},
  [12335] = {.lex_state = 90},
  [12336] = {.lex_state = 32},
  [12337] = {.lex_state = 84, .external_lex_state = 34},
  [12338] = {.lex_state = 90},
  [12339] = {.lex_state = 90},
  [12340] = {.lex_state = 84, .external_lex_state = 30},
  [12341] = {.lex_state = 90},
  [12342] = {.lex_state = 32},
  [12343] = {.lex_state = 77, .external_lex_state = 40},
  [12344] = {.lex_state = 91},
  [12345] = {.lex_state = 77, .external_lex_state = 40},
  [12346] = {.lex_state = 90},
  [12347] = {.lex_state = 77, .external_lex_state = 40},
  [12348] = {.lex_state = 32},
  [12349] = {.lex_state = 77, .external_lex_state = 38},
  [12350] = {.lex_state = 77, .external_lex_state = 40},
  [12351] = {.lex_state = 77, .external_lex_state = 40},
  [12352] = {.lex_state = 77, .external_lex_state = 63},
  [12353] = {.lex_state = 32},
  [12354] = {.lex_state = 84, .external_lex_state = 34},
  [12355] = {.lex_state = 90},
  [12356] = {.lex_state = 77, .external_lex_state = 38},
  [12357] = {.lex_state = 84, .external_lex_state = 30},
  [12358] = {.lex_state = 32},
  [12359] = {.lex_state = 84, .external_lex_state = 34},
  [12360] = {.lex_state = 32},
  [12361] = {.lex_state = 77, .external_lex_state = 38},
  [12362] = {.lex_state = 77, .external_lex_state = 60},
  [12363] = {.lex_state = 84, .external_lex_state = 30},
  [12364] = {.lex_state = 32},
  [12365] = {.lex_state = 32},
  [12366] = {.lex_state = 32},
  [12367] = {.lex_state = 77, .external_lex_state = 40},
  [12368] = {.lex_state = 84, .external_lex_state = 30},
  [12369] = {.lex_state = 84, .external_lex_state = 34},
  [12370] = {.lex_state = 77, .external_lex_state = 63},
  [12371] = {.lex_state = 77, .external_lex_state = 40},
  [12372] = {.lex_state = 84, .external_lex_state = 30},
  [12373] = {.lex_state = 32},
  [12374] = {.lex_state = 77, .external_lex_state = 38},
  [12375] = {.lex_state = 32},
  [12376] = {.lex_state = 84, .external_lex_state = 46},
  [12377] = {.lex_state = 90},
  [12378] = {.lex_state = 77, .external_lex_state = 38},
  [12379] = {.lex_state = 84, .external_lex_state = 34},
  [12380] = {.lex_state = 32},
  [12381] = {.lex_state = 32},
  [12382] = {.lex_state = 77, .external_lex_state = 38},
  [12383] = {.lex_state = 32},
  [12384] = {.lex_state = 77, .external_lex_state = 63},
  [12385] = {.lex_state = 32},
  [12386] = {.lex_state = 84, .external_lex_state = 30},
  [12387] = {.lex_state = 84, .external_lex_state = 34},
  [12388] = {.lex_state = 32},
  [12389] = {.lex_state = 84, .external_lex_state = 30},
  [12390] = {.lex_state = 77, .external_lex_state = 38},
  [12391] = {.lex_state = 77, .external_lex_state = 62},
  [12392] = {.lex_state = 77, .external_lex_state = 62},
  [12393] = {.lex_state = 84, .external_lex_state = 46},
  [12394] = {.lex_state = 32},
  [12395] = {.lex_state = 32},
  [12396] = {.lex_state = 84, .external_lex_state = 30},
  [12397] = {.lex_state = 32},
  [12398] = {.lex_state = 84, .external_lex_state = 34},
  [12399] = {.lex_state = 84, .external_lex_state = 34},
  [12400] = {.lex_state = 84, .external_lex_state = 34},
  [12401] = {.lex_state = 47},
  [12402] = {.lex_state = 32},
  [12403] = {.lex_state = 47},
  [12404] = {.lex_state = 84, .external_lex_state = 34},
  [12405] = {.lex_state = 32},
  [12406] = {.lex_state = 32},
  [12407] = {.lex_state = 84, .external_lex_state = 30},
  [12408] = {.lex_state = 32},
  [12409] = {.lex_state = 32},
  [12410] = {.lex_state = 32},
  [12411] = {.lex_state = 32},
  [12412] = {.lex_state = 77, .external_lex_state = 63},
  [12413] = {.lex_state = 32},
  [12414] = {.lex_state = 77, .external_lex_state = 40},
  [12415] = {.lex_state = 90},
  [12416] = {.lex_state = 77, .external_lex_state = 66},
  [12417] = {.lex_state = 84, .external_lex_state = 34},
  [12418] = {.lex_state = 91},
  [12419] = {.lex_state = 84, .external_lex_state = 34},
  [12420] = {.lex_state = 84, .external_lex_state = 34},
  [12421] = {.lex_state = 91},
  [12422] = {.lex_state = 32},
  [12423] = {.lex_state = 84, .external_lex_state = 34},
  [12424] = {.lex_state = 77, .external_lex_state = 38},
  [12425] = {.lex_state = 77, .external_lex_state = 65},
  [12426] = {.lex_state = 77, .external_lex_state = 38},
  [12427] = {.lex_state = 32},
  [12428] = {.lex_state = 32},
  [12429] = {.lex_state = 77, .external_lex_state = 62},
  [12430] = {.lex_state = 90},
  [12431] = {.lex_state = 32},
  [12432] = {.lex_state = 32},
  [12433] = {.lex_state = 77, .external_lex_state = 62},
  [12434] = {.lex_state = 32},
  [12435] = {.lex_state = 32},
  [12436] = {.lex_state = 84, .external_lex_state = 34},
  [12437] = {.lex_state = 32},
  [12438] = {.lex_state = 77, .external_lex_state = 62},
  [12439] = {.lex_state = 32},
  [12440] = {.lex_state = 76, .external_lex_state = 35},
  [12441] = {.lex_state = 32},
  [12442] = {.lex_state = 84, .external_lex_state = 30},
  [12443] = {.lex_state = 84, .external_lex_state = 30},
  [12444] = {.lex_state = 77, .external_lex_state = 50},
  [12445] = {.lex_state = 77, .external_lex_state = 45},
  [12446] = {.lex_state = 84, .external_lex_state = 38},
  [12447] = {.lex_state = 32},
  [12448] = {.lex_state = 77, .external_lex_state = 40},
  [12449] = {.lex_state = 32},
  [12450] = {.lex_state = 77, .external_lex_state = 39},
  [12451] = {.lex_state = 77, .external_lex_state = 39},
  [12452] = {.lex_state = 84, .external_lex_state = 34},
  [12453] = {.lex_state = 32},
  [12454] = {.lex_state = 32},
  [12455] = {.lex_state = 77, .external_lex_state = 39},
  [12456] = {.lex_state = 32},
  [12457] = {.lex_state = 32},
  [12458] = {.lex_state = 91},
  [12459] = {.lex_state = 32},
  [12460] = {.lex_state = 84, .external_lex_state = 34},
  [12461] = {.lex_state = 91},
  [12462] = {.lex_state = 32},
  [12463] = {.lex_state = 32},
  [12464] = {.lex_state = 77, .external_lex_state = 63},
  [12465] = {.lex_state = 77, .external_lex_state = 39},
  [12466] = {.lex_state = 32},
  [12467] = {.lex_state = 32},
  [12468] = {.lex_state = 84},
  [12469] = {.lex_state = 84},
  [12470] = {.lex_state = 84, .external_lex_state = 38},
  [12471] = {.lex_state = 32},
  [12472] = {.lex_state = 77, .external_lex_state = 39},
  [12473] = {.lex_state = 77, .external_lex_state = 53},
  [12474] = {.lex_state = 32},
  [12475] = {.lex_state = 84},
  [12476] = {.lex_state = 32},
  [12477] = {.lex_state = 32},
  [12478] = {.lex_state = 84, .external_lex_state = 38},
  [12479] = {.lex_state = 84, .external_lex_state = 38},
  [12480] = {.lex_state = 32},
  [12481] = {.lex_state = 32},
  [12482] = {.lex_state = 32},
  [12483] = {.lex_state = 77, .external_lex_state = 61},
  [12484] = {.lex_state = 76, .external_lex_state = 23},
  [12485] = {.lex_state = 76, .external_lex_state = 23},
  [12486] = {.lex_state = 77, .external_lex_state = 51},
  [12487] = {.lex_state = 84, .external_lex_state = 38},
  [12488] = {.lex_state = 32},
  [12489] = {.lex_state = 32},
  [12490] = {.lex_state = 32},
  [12491] = {.lex_state = 32},
  [12492] = {.lex_state = 84, .external_lex_state = 40},
  [12493] = {.lex_state = 32},
  [12494] = {.lex_state = 84, .external_lex_state = 38},
  [12495] = {.lex_state = 32},
  [12496] = {.lex_state = 32},
  [12497] = {.lex_state = 84, .external_lex_state = 38},
  [12498] = {.lex_state = 32},
  [12499] = {.lex_state = 32},
  [12500] = {.lex_state = 77, .external_lex_state = 55},
  [12501] = {.lex_state = 32},
  [12502] = {.lex_state = 84, .external_lex_state = 40},
  [12503] = {.lex_state = 84, .external_lex_state = 40},
  [12504] = {.lex_state = 32},
  [12505] = {.lex_state = 32},
  [12506] = {.lex_state = 77, .external_lex_state = 24},
  [12507] = {.lex_state = 77, .external_lex_state = 60},
  [12508] = {.lex_state = 32},
  [12509] = {.lex_state = 32},
  [12510] = {.lex_state = 76, .external_lex_state = 24},
  [12511] = {.lex_state = 32},
  [12512] = {.lex_state = 32},
  [12513] = {.lex_state = 32},
  [12514] = {.lex_state = 32},
  [12515] = {.lex_state = 32},
  [12516] = {.lex_state = 32},
  [12517] = {.lex_state = 32},
  [12518] = {.lex_state = 84, .external_lex_state = 40},
  [12519] = {.lex_state = 84, .external_lex_state = 40},
  [12520] = {.lex_state = 97},
  [12521] = {.lex_state = 32},
  [12522] = {.lex_state = 77, .external_lex_state = 23},
  [12523] = {.lex_state = 32},
  [12524] = {.lex_state = 32},
  [12525] = {.lex_state = 77, .external_lex_state = 39},
  [12526] = {.lex_state = 84},
  [12527] = {.lex_state = 84},
  [12528] = {.lex_state = 77, .external_lex_state = 55},
  [12529] = {.lex_state = 32},
  [12530] = {.lex_state = 32},
  [12531] = {.lex_state = 76, .external_lex_state = 23},
  [12532] = {.lex_state = 77, .external_lex_state = 39},
  [12533] = {.lex_state = 32},
  [12534] = {.lex_state = 84, .external_lex_state = 29},
  [12535] = {.lex_state = 32},
  [12536] = {.lex_state = 32},
  [12537] = {.lex_state = 32},
  [12538] = {.lex_state = 77, .external_lex_state = 61},
  [12539] = {.lex_state = 32},
  [12540] = {.lex_state = 32},
  [12541] = {.lex_state = 32},
  [12542] = {.lex_state = 84},
  [12543] = {.lex_state = 84},
  [12544] = {.lex_state = 32},
  [12545] = {.lex_state = 77, .external_lex_state = 60},
  [12546] = {.lex_state = 32},
  [12547] = {.lex_state = 32},
  [12548] = {.lex_state = 32},
  [12549] = {.lex_state = 84, .external_lex_state = 40},
  [12550] = {.lex_state = 77, .external_lex_state = 50},
  [12551] = {.lex_state = 32},
  [12552] = {.lex_state = 77, .external_lex_state = 39},
  [12553] = {.lex_state = 32},
  [12554] = {.lex_state = 77, .external_lex_state = 61},
  [12555] = {.lex_state = 84, .external_lex_state = 29},
  [12556] = {.lex_state = 32},
  [12557] = {.lex_state = 84, .external_lex_state = 67},
  [12558] = {.lex_state = 84},
  [12559] = {.lex_state = 32},
  [12560] = {.lex_state = 84},
  [12561] = {.lex_state = 77, .external_lex_state = 60},
  [12562] = {.lex_state = 77, .external_lex_state = 60},
  [12563] = {.lex_state = 32},
  [12564] = {.lex_state = 32},
  [12565] = {.lex_state = 77, .external_lex_state = 60},
  [12566] = {.lex_state = 32},
  [12567] = {.lex_state = 77},
  [12568] = {.lex_state = 32},
  [12569] = {.lex_state = 84},
  [12570] = {.lex_state = 32},
  [12571] = {.lex_state = 77, .external_lex_state = 53},
  [12572] = {.lex_state = 84},
  [12573] = {.lex_state = 32},
  [12574] = {.lex_state = 84},
  [12575] = {.lex_state = 32},
  [12576] = {.lex_state = 84},
  [12577] = {.lex_state = 32},
  [12578] = {.lex_state = 32},
  [12579] = {.lex_state = 32},
  [12580] = {.lex_state = 32},
  [12581] = {.lex_state = 32},
  [12582] = {.lex_state = 32},
  [12583] = {.lex_state = 77, .external_lex_state = 63},
  [12584] = {.lex_state = 32},
  [12585] = {.lex_state = 32},
  [12586] = {.lex_state = 32},
  [12587] = {.lex_state = 32},
  [12588] = {.lex_state = 77, .external_lex_state = 46},
  [12589] = {.lex_state = 77, .external_lex_state = 46},
  [12590] = {.lex_state = 77, .external_lex_state = 61},
  [12591] = {.lex_state = 77, .external_lex_state = 46},
  [12592] = {.lex_state = 32},
  [12593] = {.lex_state = 32},
  [12594] = {.lex_state = 32},
  [12595] = {.lex_state = 84, .external_lex_state = 23},
  [12596] = {.lex_state = 32},
  [12597] = {.lex_state = 77, .external_lex_state = 39},
  [12598] = {.lex_state = 77, .external_lex_state = 54},
  [12599] = {.lex_state = 32},
  [12600] = {.lex_state = 77, .external_lex_state = 46},
  [12601] = {.lex_state = 84},
  [12602] = {.lex_state = 84},
  [12603] = {.lex_state = 32},
  [12604] = {.lex_state = 32},
  [12605] = {.lex_state = 32},
  [12606] = {.lex_state = 77, .external_lex_state = 61},
  [12607] = {.lex_state = 32},
  [12608] = {.lex_state = 77, .external_lex_state = 39},
  [12609] = {.lex_state = 32},
  [12610] = {.lex_state = 32},
  [12611] = {.lex_state = 32},
  [12612] = {.lex_state = 77, .external_lex_state = 45},
  [12613] = {.lex_state = 77, .external_lex_state = 24},
  [12614] = {.lex_state = 32},
  [12615] = {.lex_state = 84},
  [12616] = {.lex_state = 84},
  [12617] = {.lex_state = 32},
  [12618] = {.lex_state = 32},
  [12619] = {.lex_state = 84, .external_lex_state = 38},
  [12620] = {.lex_state = 77, .external_lex_state = 45},
  [12621] = {.lex_state = 77, .external_lex_state = 45},
  [12622] = {.lex_state = 32},
  [12623] = {.lex_state = 32},
  [12624] = {.lex_state = 77, .external_lex_state = 45},
  [12625] = {.lex_state = 77, .external_lex_state = 45},
  [12626] = {.lex_state = 84, .external_lex_state = 38},
  [12627] = {.lex_state = 84},
  [12628] = {.lex_state = 84},
  [12629] = {.lex_state = 77, .external_lex_state = 45},
  [12630] = {.lex_state = 77, .external_lex_state = 45},
  [12631] = {.lex_state = 32},
  [12632] = {.lex_state = 84, .external_lex_state = 38},
  [12633] = {.lex_state = 84, .external_lex_state = 38},
  [12634] = {.lex_state = 32},
  [12635] = {.lex_state = 32},
  [12636] = {.lex_state = 77, .external_lex_state = 45},
  [12637] = {.lex_state = 32},
  [12638] = {.lex_state = 77, .external_lex_state = 45},
  [12639] = {.lex_state = 84, .external_lex_state = 29},
  [12640] = {.lex_state = 77, .external_lex_state = 45},
  [12641] = {.lex_state = 32},
  [12642] = {.lex_state = 76, .external_lex_state = 23},
  [12643] = {.lex_state = 32},
  [12644] = {.lex_state = 32},
  [12645] = {.lex_state = 77, .external_lex_state = 39},
  [12646] = {.lex_state = 32},
  [12647] = {.lex_state = 84},
  [12648] = {.lex_state = 84},
  [12649] = {.lex_state = 84},
  [12650] = {.lex_state = 77, .external_lex_state = 51},
  [12651] = {.lex_state = 32},
  [12652] = {.lex_state = 77, .external_lex_state = 51},
  [12653] = {.lex_state = 32},
  [12654] = {.lex_state = 77, .external_lex_state = 54},
  [12655] = {.lex_state = 77, .external_lex_state = 54},
  [12656] = {.lex_state = 32},
  [12657] = {.lex_state = 32},
  [12658] = {.lex_state = 77, .external_lex_state = 60},
  [12659] = {.lex_state = 77, .external_lex_state = 50},
  [12660] = {.lex_state = 77, .external_lex_state = 45},
  [12661] = {.lex_state = 84, .external_lex_state = 39},
  [12662] = {.lex_state = 32},
  [12663] = {.lex_state = 32},
  [12664] = {.lex_state = 77, .external_lex_state = 50},
  [12665] = {.lex_state = 77, .external_lex_state = 60},
  [12666] = {.lex_state = 77, .external_lex_state = 60},
  [12667] = {.lex_state = 32},
  [12668] = {.lex_state = 32},
  [12669] = {.lex_state = 32},
  [12670] = {.lex_state = 77, .external_lex_state = 60},
  [12671] = {.lex_state = 32},
  [12672] = {.lex_state = 32},
  [12673] = {.lex_state = 84, .external_lex_state = 40},
  [12674] = {.lex_state = 32},
  [12675] = {.lex_state = 77, .external_lex_state = 60},
  [12676] = {.lex_state = 32},
  [12677] = {.lex_state = 32},
  [12678] = {.lex_state = 84, .external_lex_state = 40},
  [12679] = {.lex_state = 32},
  [12680] = {.lex_state = 84, .external_lex_state = 40},
  [12681] = {.lex_state = 84, .external_lex_state = 40},
  [12682] = {.lex_state = 32},
  [12683] = {.lex_state = 32},
  [12684] = {.lex_state = 77, .external_lex_state = 35},
  [12685] = {.lex_state = 77, .external_lex_state = 61},
  [12686] = {.lex_state = 77, .external_lex_state = 55},
  [12687] = {.lex_state = 77, .external_lex_state = 39},
  [12688] = {.lex_state = 84},
  [12689] = {.lex_state = 84},
  [12690] = {.lex_state = 32},
  [12691] = {.lex_state = 32},
  [12692] = {.lex_state = 77, .external_lex_state = 39},
  [12693] = {.lex_state = 84, .external_lex_state = 40},
  [12694] = {.lex_state = 32},
  [12695] = {.lex_state = 32},
  [12696] = {.lex_state = 32},
  [12697] = {.lex_state = 32},
  [12698] = {.lex_state = 32},
  [12699] = {.lex_state = 32},
  [12700] = {.lex_state = 77, .external_lex_state = 45},
  [12701] = {.lex_state = 84, .external_lex_state = 40},
  [12702] = {.lex_state = 32},
  [12703] = {.lex_state = 77, .external_lex_state = 39},
  [12704] = {.lex_state = 77, .external_lex_state = 39},
  [12705] = {.lex_state = 32},
  [12706] = {.lex_state = 32},
  [12707] = {.lex_state = 32},
  [12708] = {.lex_state = 32},
  [12709] = {.lex_state = 77, .external_lex_state = 60},
  [12710] = {.lex_state = 32},
  [12711] = {.lex_state = 84, .external_lex_state = 40},
  [12712] = {.lex_state = 32},
  [12713] = {.lex_state = 84, .external_lex_state = 40},
  [12714] = {.lex_state = 32},
  [12715] = {.lex_state = 32},
  [12716] = {.lex_state = 77, .external_lex_state = 68},
  [12717] = {.lex_state = 84, .external_lex_state = 40},
  [12718] = {.lex_state = 32},
  [12719] = {.lex_state = 84, .external_lex_state = 40},
  [12720] = {.lex_state = 32},
  [12721] = {.lex_state = 84, .external_lex_state = 40},
  [12722] = {.lex_state = 84},
  [12723] = {.lex_state = 32},
  [12724] = {.lex_state = 84},
  [12725] = {.lex_state = 84},
  [12726] = {.lex_state = 84, .external_lex_state = 38},
  [12727] = {.lex_state = 84, .external_lex_state = 40},
  [12728] = {.lex_state = 84},
  [12729] = {.lex_state = 77},
  [12730] = {.lex_state = 84, .external_lex_state = 40},
  [12731] = {.lex_state = 84, .external_lex_state = 40},
  [12732] = {.lex_state = 32},
  [12733] = {.lex_state = 32},
  [12734] = {.lex_state = 84, .external_lex_state = 40},
  [12735] = {.lex_state = 84, .external_lex_state = 40},
  [12736] = {.lex_state = 32},
  [12737] = {.lex_state = 77, .external_lex_state = 65},
  [12738] = {.lex_state = 32},
  [12739] = {.lex_state = 32},
  [12740] = {.lex_state = 32},
  [12741] = {.lex_state = 32},
  [12742] = {.lex_state = 84, .external_lex_state = 53},
  [12743] = {.lex_state = 84, .external_lex_state = 29},
  [12744] = {.lex_state = 32},
  [12745] = {.lex_state = 77, .external_lex_state = 68},
  [12746] = {.lex_state = 32},
  [12747] = {.lex_state = 32},
  [12748] = {.lex_state = 84, .external_lex_state = 53},
  [12749] = {.lex_state = 84},
  [12750] = {.lex_state = 32},
  [12751] = {.lex_state = 32},
  [12752] = {.lex_state = 77, .external_lex_state = 60},
  [12753] = {.lex_state = 84},
  [12754] = {.lex_state = 77, .external_lex_state = 60},
  [12755] = {.lex_state = 84, .external_lex_state = 40},
  [12756] = {.lex_state = 32},
  [12757] = {.lex_state = 84, .external_lex_state = 54},
  [12758] = {.lex_state = 84, .external_lex_state = 69},
  [12759] = {.lex_state = 84},
  [12760] = {.lex_state = 84},
  [12761] = {.lex_state = 32},
  [12762] = {.lex_state = 77, .external_lex_state = 46},
  [12763] = {.lex_state = 84, .external_lex_state = 54},
  [12764] = {.lex_state = 84, .external_lex_state = 40},
  [12765] = {.lex_state = 84, .external_lex_state = 40},
  [12766] = {.lex_state = 32},
  [12767] = {.lex_state = 77, .external_lex_state = 60},
  [12768] = {.lex_state = 77, .external_lex_state = 60},
  [12769] = {.lex_state = 84, .external_lex_state = 39},
  [12770] = {.lex_state = 32},
  [12771] = {.lex_state = 32},
  [12772] = {.lex_state = 32},
  [12773] = {.lex_state = 84, .external_lex_state = 40},
  [12774] = {.lex_state = 77, .external_lex_state = 53},
  [12775] = {.lex_state = 84, .external_lex_state = 39},
  [12776] = {.lex_state = 77, .external_lex_state = 39},
  [12777] = {.lex_state = 77, .external_lex_state = 61},
  [12778] = {.lex_state = 32},
  [12779] = {.lex_state = 32},
  [12780] = {.lex_state = 77, .external_lex_state = 54},
  [12781] = {.lex_state = 32},
  [12782] = {.lex_state = 32},
  [12783] = {.lex_state = 32},
  [12784] = {.lex_state = 84},
  [12785] = {.lex_state = 32},
  [12786] = {.lex_state = 32},
  [12787] = {.lex_state = 77, .external_lex_state = 39},
  [12788] = {.lex_state = 77, .external_lex_state = 39},
  [12789] = {.lex_state = 77, .external_lex_state = 53},
  [12790] = {.lex_state = 32},
  [12791] = {.lex_state = 32},
  [12792] = {.lex_state = 32},
  [12793] = {.lex_state = 32},
  [12794] = {.lex_state = 84, .external_lex_state = 46},
  [12795] = {.lex_state = 77, .external_lex_state = 39},
  [12796] = {.lex_state = 32},
  [12797] = {.lex_state = 32},
  [12798] = {.lex_state = 84, .external_lex_state = 38},
  [12799] = {.lex_state = 32},
  [12800] = {.lex_state = 84, .external_lex_state = 39},
  [12801] = {.lex_state = 32},
  [12802] = {.lex_state = 32},
  [12803] = {.lex_state = 84},
  [12804] = {.lex_state = 32},
  [12805] = {.lex_state = 32},
  [12806] = {.lex_state = 84},
  [12807] = {.lex_state = 77, .external_lex_state = 39},
  [12808] = {.lex_state = 76, .external_lex_state = 49},
  [12809] = {.lex_state = 32},
  [12810] = {.lex_state = 77, .external_lex_state = 46},
  [12811] = {.lex_state = 84, .external_lex_state = 40},
  [12812] = {.lex_state = 77, .external_lex_state = 46},
  [12813] = {.lex_state = 32},
  [12814] = {.lex_state = 32},
  [12815] = {.lex_state = 32},
  [12816] = {.lex_state = 32},
  [12817] = {.lex_state = 77, .external_lex_state = 39},
  [12818] = {.lex_state = 32},
  [12819] = {.lex_state = 77, .external_lex_state = 39},
  [12820] = {.lex_state = 77, .external_lex_state = 46},
  [12821] = {.lex_state = 32},
  [12822] = {.lex_state = 77, .external_lex_state = 46},
  [12823] = {.lex_state = 84, .external_lex_state = 39},
  [12824] = {.lex_state = 77, .external_lex_state = 46},
  [12825] = {.lex_state = 84, .external_lex_state = 39},
  [12826] = {.lex_state = 77, .external_lex_state = 46},
  [12827] = {.lex_state = 32},
  [12828] = {.lex_state = 77, .external_lex_state = 46},
  [12829] = {.lex_state = 84, .external_lex_state = 39},
  [12830] = {.lex_state = 84},
  [12831] = {.lex_state = 84},
  [12832] = {.lex_state = 77, .external_lex_state = 39},
  [12833] = {.lex_state = 77, .external_lex_state = 39},
  [12834] = {.lex_state = 32},
  [12835] = {.lex_state = 32},
  [12836] = {.lex_state = 32},
  [12837] = {.lex_state = 77, .external_lex_state = 50},
  [12838] = {.lex_state = 32},
  [12839] = {.lex_state = 77, .external_lex_state = 39},
  [12840] = {.lex_state = 84},
  [12841] = {.lex_state = 32},
  [12842] = {.lex_state = 84, .external_lex_state = 45},
  [12843] = {.lex_state = 32},
  [12844] = {.lex_state = 32},
  [12845] = {.lex_state = 84},
  [12846] = {.lex_state = 84},
  [12847] = {.lex_state = 32},
  [12848] = {.lex_state = 32},
  [12849] = {.lex_state = 77, .external_lex_state = 55},
  [12850] = {.lex_state = 77, .external_lex_state = 60},
  [12851] = {.lex_state = 32},
  [12852] = {.lex_state = 32},
  [12853] = {.lex_state = 32},
  [12854] = {.lex_state = 32},
  [12855] = {.lex_state = 77, .external_lex_state = 65},
  [12856] = {.lex_state = 77, .external_lex_state = 46},
  [12857] = {.lex_state = 77, .external_lex_state = 62},
  [12858] = {.lex_state = 32},
  [12859] = {.lex_state = 32},
  [12860] = {.lex_state = 84, .external_lex_state = 29},
  [12861] = {.lex_state = 84, .external_lex_state = 38},
  [12862] = {.lex_state = 32},
  [12863] = {.lex_state = 84},
  [12864] = {.lex_state = 32},
  [12865] = {.lex_state = 84},
  [12866] = {.lex_state = 32},
  [12867] = {.lex_state = 32},
  [12868] = {.lex_state = 32},
  [12869] = {.lex_state = 32},
  [12870] = {.lex_state = 32},
  [12871] = {.lex_state = 32},
  [12872] = {.lex_state = 32},
  [12873] = {.lex_state = 77, .external_lex_state = 65},
  [12874] = {.lex_state = 32},
  [12875] = {.lex_state = 84, .external_lex_state = 38},
  [12876] = {.lex_state = 77, .external_lex_state = 62},
  [12877] = {.lex_state = 77, .external_lex_state = 62},
  [12878] = {.lex_state = 32},
  [12879] = {.lex_state = 77, .external_lex_state = 23},
  [12880] = {.lex_state = 32},
  [12881] = {.lex_state = 32},
  [12882] = {.lex_state = 84},
  [12883] = {.lex_state = 84, .external_lex_state = 38},
  [12884] = {.lex_state = 32},
  [12885] = {.lex_state = 32},
  [12886] = {.lex_state = 84, .external_lex_state = 38},
  [12887] = {.lex_state = 84, .external_lex_state = 39},
  [12888] = {.lex_state = 32},
  [12889] = {.lex_state = 84, .external_lex_state = 38},
  [12890] = {.lex_state = 84, .external_lex_state = 38},
  [12891] = {.lex_state = 32},
  [12892] = {.lex_state = 84, .external_lex_state = 38},
  [12893] = {.lex_state = 32},
  [12894] = {.lex_state = 32},
  [12895] = {.lex_state = 84, .external_lex_state = 38},
  [12896] = {.lex_state = 84, .external_lex_state = 38},
  [12897] = {.lex_state = 32},
  [12898] = {.lex_state = 32},
  [12899] = {.lex_state = 32},
  [12900] = {.lex_state = 84},
  [12901] = {.lex_state = 84},
  [12902] = {.lex_state = 32},
  [12903] = {.lex_state = 32},
  [12904] = {.lex_state = 32},
  [12905] = {.lex_state = 84, .external_lex_state = 38},
  [12906] = {.lex_state = 32},
  [12907] = {.lex_state = 84},
  [12908] = {.lex_state = 84},
  [12909] = {.lex_state = 84, .external_lex_state = 51},
  [12910] = {.lex_state = 84, .external_lex_state = 51},
  [12911] = {.lex_state = 84, .external_lex_state = 55},
  [12912] = {.lex_state = 84},
  [12913] = {.lex_state = 84},
  [12914] = {.lex_state = 84},
  [12915] = {.lex_state = 77, .external_lex_state = 62},
  [12916] = {.lex_state = 32},
  [12917] = {.lex_state = 32},
  [12918] = {.lex_state = 84, .external_lex_state = 55},
  [12919] = {.lex_state = 32},
  [12920] = {.lex_state = 84, .external_lex_state = 38},
  [12921] = {.lex_state = 84, .external_lex_state = 38},
  [12922] = {.lex_state = 32},
  [12923] = {.lex_state = 84},
  [12924] = {.lex_state = 84},
  [12925] = {.lex_state = 84},
  [12926] = {.lex_state = 32},
  [12927] = {.lex_state = 32},
  [12928] = {.lex_state = 77, .external_lex_state = 51},
  [12929] = {.lex_state = 32},
  [12930] = {.lex_state = 32},
  [12931] = {.lex_state = 84, .external_lex_state = 29},
  [12932] = {.lex_state = 32},
  [12933] = {.lex_state = 32},
  [12934] = {.lex_state = 84, .external_lex_state = 38},
  [12935] = {.lex_state = 32},
  [12936] = {.lex_state = 32},
  [12937] = {.lex_state = 32},
  [12938] = {.lex_state = 84, .external_lex_state = 38},
  [12939] = {.lex_state = 84, .external_lex_state = 38},
  [12940] = {.lex_state = 84, .external_lex_state = 38},
  [12941] = {.lex_state = 84, .external_lex_state = 38},
  [12942] = {.lex_state = 32},
  [12943] = {.lex_state = 32},
  [12944] = {.lex_state = 77, .external_lex_state = 35},
  [12945] = {.lex_state = 84, .external_lex_state = 38},
  [12946] = {.lex_state = 84},
  [12947] = {.lex_state = 32},
  [12948] = {.lex_state = 77, .external_lex_state = 45},
  [12949] = {.lex_state = 77, .external_lex_state = 65},
  [12950] = {.lex_state = 77, .external_lex_state = 45},
  [12951] = {.lex_state = 77, .external_lex_state = 54},
  [12952] = {.lex_state = 32},
  [12953] = {.lex_state = 76, .external_lex_state = 49},
  [12954] = {.lex_state = 32},
  [12955] = {.lex_state = 77, .external_lex_state = 51},
  [12956] = {.lex_state = 77, .external_lex_state = 46},
  [12957] = {.lex_state = 84},
  [12958] = {.lex_state = 77, .external_lex_state = 46},
  [12959] = {.lex_state = 77, .external_lex_state = 51},
  [12960] = {.lex_state = 84, .external_lex_state = 23},
  [12961] = {.lex_state = 77, .external_lex_state = 46},
  [12962] = {.lex_state = 76, .external_lex_state = 49},
  [12963] = {.lex_state = 77, .external_lex_state = 51},
  [12964] = {.lex_state = 76, .external_lex_state = 49},
  [12965] = {.lex_state = 84, .external_lex_state = 46},
  [12966] = {.lex_state = 77, .external_lex_state = 58},
  [12967] = {.lex_state = 84, .external_lex_state = 39},
  [12968] = {.lex_state = 77, .external_lex_state = 65},
  [12969] = {.lex_state = 84, .external_lex_state = 23},
  [12970] = {.lex_state = 84, .external_lex_state = 29},
  [12971] = {.lex_state = 76, .external_lex_state = 49},
  [12972] = {.lex_state = 76, .external_lex_state = 49},
  [12973] = {.lex_state = 77, .external_lex_state = 61},
  [12974] = {.lex_state = 76, .external_lex_state = 49},
  [12975] = {.lex_state = 84, .external_lex_state = 46},
  [12976] = {.lex_state = 32},
  [12977] = {.lex_state = 76, .external_lex_state = 49},
  [12978] = {.lex_state = 77, .external_lex_state = 35},
  [12979] = {.lex_state = 76, .external_lex_state = 24},
  [12980] = {.lex_state = 76, .external_lex_state = 49},
  [12981] = {.lex_state = 32},
  [12982] = {.lex_state = 77, .external_lex_state = 46},
  [12983] = {.lex_state = 76, .external_lex_state = 49},
  [12984] = {.lex_state = 76, .external_lex_state = 49},
  [12985] = {.lex_state = 77, .external_lex_state = 61},
  [12986] = {.lex_state = 77, .external_lex_state = 61},
  [12987] = {.lex_state = 32},
  [12988] = {.lex_state = 76, .external_lex_state = 49},
  [12989] = {.lex_state = 77, .external_lex_state = 46},
  [12990] = {.lex_state = 84, .external_lex_state = 29},
  [12991] = {.lex_state = 32},
  [12992] = {.lex_state = 32},
  [12993] = {.lex_state = 84, .external_lex_state = 39},
  [12994] = {.lex_state = 84, .external_lex_state = 46},
  [12995] = {.lex_state = 32},
  [12996] = {.lex_state = 84},
  [12997] = {.lex_state = 84, .external_lex_state = 46},
  [12998] = {.lex_state = 76, .external_lex_state = 49},
  [12999] = {.lex_state = 84, .external_lex_state = 46},
  [13000] = {.lex_state = 76, .external_lex_state = 49},
  [13001] = {.lex_state = 77, .external_lex_state = 61},
  [13002] = {.lex_state = 32},
  [13003] = {.lex_state = 77, .external_lex_state = 61},
  [13004] = {.lex_state = 77, .external_lex_state = 45},
  [13005] = {.lex_state = 32},
  [13006] = {.lex_state = 76, .external_lex_state = 49},
  [13007] = {.lex_state = 77, .external_lex_state = 45},
  [13008] = {.lex_state = 77, .external_lex_state = 45},
  [13009] = {.lex_state = 84, .external_lex_state = 46},
  [13010] = {.lex_state = 84, .external_lex_state = 46},
  [13011] = {.lex_state = 84},
  [13012] = {.lex_state = 76, .external_lex_state = 49},
  [13013] = {.lex_state = 84, .external_lex_state = 46},
  [13014] = {.lex_state = 77, .external_lex_state = 60},
  [13015] = {.lex_state = 76, .external_lex_state = 49},
  [13016] = {.lex_state = 76, .external_lex_state = 49},
  [13017] = {.lex_state = 77, .external_lex_state = 62},
  [13018] = {.lex_state = 32},
  [13019] = {.lex_state = 76, .external_lex_state = 49},
  [13020] = {.lex_state = 76, .external_lex_state = 49},
  [13021] = {.lex_state = 32},
  [13022] = {.lex_state = 77, .external_lex_state = 23},
  [13023] = {.lex_state = 77, .external_lex_state = 62},
  [13024] = {.lex_state = 32},
  [13025] = {.lex_state = 32},
  [13026] = {.lex_state = 76, .external_lex_state = 24},
  [13027] = {.lex_state = 84, .external_lex_state = 46},
  [13028] = {.lex_state = 84, .external_lex_state = 30},
  [13029] = {.lex_state = 32},
  [13030] = {.lex_state = 76, .external_lex_state = 49},
  [13031] = {.lex_state = 32},
  [13032] = {.lex_state = 77, .external_lex_state = 62},
  [13033] = {.lex_state = 32},
  [13034] = {.lex_state = 77, .external_lex_state = 63},
  [13035] = {.lex_state = 77, .external_lex_state = 61},
  [13036] = {.lex_state = 76, .external_lex_state = 49},
  [13037] = {.lex_state = 84},
  [13038] = {.lex_state = 84, .external_lex_state = 46},
  [13039] = {.lex_state = 77, .external_lex_state = 23},
  [13040] = {.lex_state = 77, .external_lex_state = 63},
  [13041] = {.lex_state = 32},
  [13042] = {.lex_state = 84, .external_lex_state = 29},
  [13043] = {.lex_state = 77, .external_lex_state = 63},
  [13044] = {.lex_state = 77, .external_lex_state = 63},
  [13045] = {.lex_state = 84, .external_lex_state = 23},
  [13046] = {.lex_state = 84},
  [13047] = {.lex_state = 76, .external_lex_state = 23},
  [13048] = {.lex_state = 84, .external_lex_state = 23},
  [13049] = {.lex_state = 84, .external_lex_state = 29},
  [13050] = {.lex_state = 84, .external_lex_state = 39},
  [13051] = {.lex_state = 84, .external_lex_state = 46},
  [13052] = {.lex_state = 77, .external_lex_state = 63},
  [13053] = {.lex_state = 32},
  [13054] = {.lex_state = 32},
  [13055] = {.lex_state = 76, .external_lex_state = 49},
  [13056] = {.lex_state = 32},
  [13057] = {.lex_state = 84, .external_lex_state = 23},
  [13058] = {.lex_state = 84, .external_lex_state = 23},
  [13059] = {.lex_state = 77, .external_lex_state = 45},
  [13060] = {.lex_state = 84, .external_lex_state = 46},
  [13061] = {.lex_state = 77, .external_lex_state = 55},
  [13062] = {.lex_state = 84, .external_lex_state = 53},
  [13063] = {.lex_state = 77, .external_lex_state = 55},
  [13064] = {.lex_state = 32},
  [13065] = {.lex_state = 77, .external_lex_state = 60},
  [13066] = {.lex_state = 84, .external_lex_state = 23},
  [13067] = {.lex_state = 84, .external_lex_state = 29},
  [13068] = {.lex_state = 77, .external_lex_state = 23},
  [13069] = {.lex_state = 77, .external_lex_state = 51},
  [13070] = {.lex_state = 32},
  [13071] = {.lex_state = 76, .external_lex_state = 23},
  [13072] = {.lex_state = 84, .external_lex_state = 30},
  [13073] = {.lex_state = 32},
  [13074] = {.lex_state = 77, .external_lex_state = 23},
  [13075] = {.lex_state = 84, .external_lex_state = 23},
  [13076] = {.lex_state = 84, .external_lex_state = 45},
  [13077] = {.lex_state = 77, .external_lex_state = 55},
  [13078] = {.lex_state = 32},
  [13079] = {.lex_state = 77, .external_lex_state = 35},
  [13080] = {.lex_state = 84, .external_lex_state = 23},
  [13081] = {.lex_state = 77, .external_lex_state = 55},
  [13082] = {.lex_state = 77, .external_lex_state = 55},
  [13083] = {.lex_state = 77, .external_lex_state = 55},
  [13084] = {.lex_state = 84, .external_lex_state = 45},
  [13085] = {.lex_state = 77, .external_lex_state = 55},
  [13086] = {.lex_state = 77, .external_lex_state = 63},
  [13087] = {.lex_state = 77, .external_lex_state = 35},
  [13088] = {.lex_state = 84, .external_lex_state = 45},
  [13089] = {.lex_state = 77, .external_lex_state = 55},
  [13090] = {.lex_state = 76, .external_lex_state = 24},
  [13091] = {.lex_state = 77, .external_lex_state = 46},
  [13092] = {.lex_state = 77, .external_lex_state = 51},
  [13093] = {.lex_state = 77, .external_lex_state = 46},
  [13094] = {.lex_state = 84, .external_lex_state = 23},
  [13095] = {.lex_state = 84, .external_lex_state = 23},
  [13096] = {.lex_state = 77, .external_lex_state = 50},
  [13097] = {.lex_state = 84, .external_lex_state = 23},
  [13098] = {.lex_state = 84, .external_lex_state = 45},
  [13099] = {.lex_state = 76, .external_lex_state = 23},
  [13100] = {.lex_state = 76, .external_lex_state = 23},
  [13101] = {.lex_state = 77, .external_lex_state = 57},
  [13102] = {.lex_state = 84, .external_lex_state = 23},
  [13103] = {.lex_state = 84, .external_lex_state = 39},
  [13104] = {.lex_state = 84, .external_lex_state = 39},
  [13105] = {.lex_state = 84, .external_lex_state = 39},
  [13106] = {.lex_state = 76, .external_lex_state = 49},
  [13107] = {.lex_state = 77, .external_lex_state = 56},
  [13108] = {.lex_state = 84, .external_lex_state = 30},
  [13109] = {.lex_state = 77, .external_lex_state = 50},
  [13110] = {.lex_state = 84, .external_lex_state = 23},
  [13111] = {.lex_state = 32},
  [13112] = {.lex_state = 32},
  [13113] = {.lex_state = 84, .external_lex_state = 45},
  [13114] = {.lex_state = 84, .external_lex_state = 23},
  [13115] = {.lex_state = 32},
  [13116] = {.lex_state = 84, .external_lex_state = 39},
  [13117] = {.lex_state = 76, .external_lex_state = 24},
  [13118] = {.lex_state = 77, .external_lex_state = 45},
  [13119] = {.lex_state = 32},
  [13120] = {.lex_state = 84, .external_lex_state = 39},
  [13121] = {.lex_state = 77, .external_lex_state = 55},
  [13122] = {.lex_state = 76, .external_lex_state = 49},
  [13123] = {.lex_state = 84, .external_lex_state = 23},
  [13124] = {.lex_state = 84, .external_lex_state = 39},
  [13125] = {.lex_state = 84, .external_lex_state = 39},
  [13126] = {.lex_state = 84, .external_lex_state = 39},
  [13127] = {.lex_state = 84, .external_lex_state = 39},
  [13128] = {.lex_state = 84, .external_lex_state = 23},
  [13129] = {.lex_state = 84, .external_lex_state = 39},
  [13130] = {.lex_state = 76, .external_lex_state = 49},
  [13131] = {.lex_state = 84, .external_lex_state = 23},
  [13132] = {.lex_state = 84, .external_lex_state = 39},
  [13133] = {.lex_state = 84, .external_lex_state = 23},
  [13134] = {.lex_state = 76, .external_lex_state = 23},
  [13135] = {.lex_state = 76, .external_lex_state = 24},
  [13136] = {.lex_state = 84, .external_lex_state = 39},
  [13137] = {.lex_state = 32},
  [13138] = {.lex_state = 84, .external_lex_state = 39},
  [13139] = {.lex_state = 84, .external_lex_state = 39},
  [13140] = {.lex_state = 84, .external_lex_state = 39},
  [13141] = {.lex_state = 76, .external_lex_state = 49},
  [13142] = {.lex_state = 76, .external_lex_state = 49},
  [13143] = {.lex_state = 77, .external_lex_state = 45},
  [13144] = {.lex_state = 32},
  [13145] = {.lex_state = 32},
  [13146] = {.lex_state = 84, .external_lex_state = 23},
  [13147] = {.lex_state = 77, .external_lex_state = 35},
  [13148] = {.lex_state = 77, .external_lex_state = 35},
  [13149] = {.lex_state = 84, .external_lex_state = 39},
  [13150] = {.lex_state = 77, .external_lex_state = 54},
  [13151] = {.lex_state = 77, .external_lex_state = 62},
  [13152] = {.lex_state = 84, .external_lex_state = 39},
  [13153] = {.lex_state = 32},
  [13154] = {.lex_state = 77, .external_lex_state = 45},
  [13155] = {.lex_state = 77, .external_lex_state = 45},
  [13156] = {.lex_state = 84, .external_lex_state = 39},
  [13157] = {.lex_state = 84, .external_lex_state = 30},
  [13158] = {.lex_state = 77, .external_lex_state = 45},
  [13159] = {.lex_state = 32},
  [13160] = {.lex_state = 77, .external_lex_state = 54},
  [13161] = {.lex_state = 77, .external_lex_state = 46},
  [13162] = {.lex_state = 77, .external_lex_state = 54},
  [13163] = {.lex_state = 77, .external_lex_state = 54},
  [13164] = {.lex_state = 84, .external_lex_state = 39},
  [13165] = {.lex_state = 32},
  [13166] = {.lex_state = 32},
  [13167] = {.lex_state = 77, .external_lex_state = 35},
  [13168] = {.lex_state = 77, .external_lex_state = 45},
  [13169] = {.lex_state = 77, .external_lex_state = 45},
  [13170] = {.lex_state = 76, .external_lex_state = 23},
  [13171] = {.lex_state = 77, .external_lex_state = 45},
  [13172] = {.lex_state = 84, .external_lex_state = 45},
  [13173] = {.lex_state = 76, .external_lex_state = 23},
  [13174] = {.lex_state = 77, .external_lex_state = 46},
  [13175] = {.lex_state = 77, .external_lex_state = 46},
  [13176] = {.lex_state = 32},
  [13177] = {.lex_state = 77, .external_lex_state = 46},
  [13178] = {.lex_state = 77, .external_lex_state = 46},
  [13179] = {.lex_state = 77, .external_lex_state = 46},
  [13180] = {.lex_state = 77, .external_lex_state = 45},
  [13181] = {.lex_state = 84, .external_lex_state = 45},
  [13182] = {.lex_state = 84, .external_lex_state = 46},
  [13183] = {.lex_state = 84, .external_lex_state = 23},
  [13184] = {.lex_state = 76, .external_lex_state = 49},
  [13185] = {.lex_state = 77, .external_lex_state = 45},
  [13186] = {.lex_state = 77, .external_lex_state = 45},
  [13187] = {.lex_state = 84, .external_lex_state = 23},
  [13188] = {.lex_state = 84, .external_lex_state = 23},
  [13189] = {.lex_state = 84, .external_lex_state = 39},
  [13190] = {.lex_state = 77, .external_lex_state = 35},
  [13191] = {.lex_state = 77, .external_lex_state = 54},
  [13192] = {.lex_state = 76, .external_lex_state = 23},
  [13193] = {.lex_state = 32},
  [13194] = {.lex_state = 84, .external_lex_state = 30},
  [13195] = {.lex_state = 32},
  [13196] = {.lex_state = 76, .external_lex_state = 49},
  [13197] = {.lex_state = 32},
  [13198] = {.lex_state = 32},
  [13199] = {.lex_state = 76, .external_lex_state = 49},
  [13200] = {.lex_state = 84, .external_lex_state = 58},
  [13201] = {.lex_state = 32},
  [13202] = {.lex_state = 32},
  [13203] = {.lex_state = 32},
  [13204] = {.lex_state = 32},
  [13205] = {.lex_state = 77, .external_lex_state = 46},
  [13206] = {.lex_state = 84, .external_lex_state = 58},
  [13207] = {.lex_state = 84},
  [13208] = {.lex_state = 32},
  [13209] = {.lex_state = 32},
  [13210] = {.lex_state = 84, .external_lex_state = 39},
  [13211] = {.lex_state = 76, .external_lex_state = 23},
  [13212] = {.lex_state = 84, .external_lex_state = 39},
  [13213] = {.lex_state = 32},
  [13214] = {.lex_state = 84, .external_lex_state = 23},
  [13215] = {.lex_state = 32},
  [13216] = {.lex_state = 84, .external_lex_state = 23},
  [13217] = {.lex_state = 32},
  [13218] = {.lex_state = 84, .external_lex_state = 30},
  [13219] = {.lex_state = 32},
  [13220] = {.lex_state = 32},
  [13221] = {.lex_state = 84, .external_lex_state = 23},
  [13222] = {.lex_state = 84, .external_lex_state = 23},
  [13223] = {.lex_state = 32},
  [13224] = {.lex_state = 77, .external_lex_state = 65},
  [13225] = {.lex_state = 84, .external_lex_state = 23},
  [13226] = {.lex_state = 84, .external_lex_state = 23},
  [13227] = {.lex_state = 84},
  [13228] = {.lex_state = 77, .external_lex_state = 50},
  [13229] = {.lex_state = 32},
  [13230] = {.lex_state = 77, .external_lex_state = 63},
  [13231] = {.lex_state = 76, .external_lex_state = 49},
  [13232] = {.lex_state = 77, .external_lex_state = 53},
  [13233] = {.lex_state = 32},
  [13234] = {.lex_state = 84},
  [13235] = {.lex_state = 84, .external_lex_state = 39},
  [13236] = {.lex_state = 32},
  [13237] = {.lex_state = 84, .external_lex_state = 57},
  [13238] = {.lex_state = 77, .external_lex_state = 35},
  [13239] = {.lex_state = 84, .external_lex_state = 57},
  [13240] = {.lex_state = 32},
  [13241] = {.lex_state = 32},
  [13242] = {.lex_state = 32},
  [13243] = {.lex_state = 76, .external_lex_state = 24},
  [13244] = {.lex_state = 77, .external_lex_state = 62},
  [13245] = {.lex_state = 77, .external_lex_state = 45},
  [13246] = {.lex_state = 77, .external_lex_state = 57},
  [13247] = {.lex_state = 76, .external_lex_state = 24},
  [13248] = {.lex_state = 76, .external_lex_state = 24},
  [13249] = {.lex_state = 77, .external_lex_state = 35},
  [13250] = {.lex_state = 77, .external_lex_state = 61},
  [13251] = {.lex_state = 32},
  [13252] = {.lex_state = 77, .external_lex_state = 35},
  [13253] = {.lex_state = 76, .external_lex_state = 24},
  [13254] = {.lex_state = 77, .external_lex_state = 35},
  [13255] = {.lex_state = 77, .external_lex_state = 35},
  [13256] = {.lex_state = 32},
  [13257] = {.lex_state = 77, .external_lex_state = 35},
  [13258] = {.lex_state = 77, .external_lex_state = 35},
  [13259] = {.lex_state = 32},
  [13260] = {.lex_state = 32},
  [13261] = {.lex_state = 32},
  [13262] = {.lex_state = 77, .external_lex_state = 61},
  [13263] = {.lex_state = 84, .external_lex_state = 56},
  [13264] = {.lex_state = 77, .external_lex_state = 58},
  [13265] = {.lex_state = 32},
  [13266] = {.lex_state = 77, .external_lex_state = 56},
  [13267] = {.lex_state = 77, .external_lex_state = 46},
  [13268] = {.lex_state = 77, .external_lex_state = 50},
  [13269] = {.lex_state = 84, .external_lex_state = 54},
  [13270] = {.lex_state = 77, .external_lex_state = 50},
  [13271] = {.lex_state = 32},
  [13272] = {.lex_state = 77, .external_lex_state = 57},
  [13273] = {.lex_state = 76, .external_lex_state = 24},
  [13274] = {.lex_state = 32},
  [13275] = {.lex_state = 77, .external_lex_state = 57},
  [13276] = {.lex_state = 77, .external_lex_state = 50},
  [13277] = {.lex_state = 77, .external_lex_state = 61},
  [13278] = {.lex_state = 32},
  [13279] = {.lex_state = 77, .external_lex_state = 35},
  [13280] = {.lex_state = 76, .external_lex_state = 24},
  [13281] = {.lex_state = 76, .external_lex_state = 24},
  [13282] = {.lex_state = 77, .external_lex_state = 58},
  [13283] = {.lex_state = 32},
  [13284] = {.lex_state = 77, .external_lex_state = 62},
  [13285] = {.lex_state = 77, .external_lex_state = 62},
  [13286] = {.lex_state = 77, .external_lex_state = 62},
  [13287] = {.lex_state = 77, .external_lex_state = 50},
  [13288] = {.lex_state = 77, .external_lex_state = 51},
  [13289] = {.lex_state = 77, .external_lex_state = 45},
  [13290] = {.lex_state = 77, .external_lex_state = 50},
  [13291] = {.lex_state = 77, .external_lex_state = 62},
  [13292] = {.lex_state = 32},
  [13293] = {.lex_state = 84, .external_lex_state = 56},
  [13294] = {.lex_state = 77, .external_lex_state = 56},
  [13295] = {.lex_state = 77, .external_lex_state = 45},
  [13296] = {.lex_state = 32},
  [13297] = {.lex_state = 77, .external_lex_state = 61},
  [13298] = {.lex_state = 77, .external_lex_state = 55},
  [13299] = {.lex_state = 77, .external_lex_state = 45},
  [13300] = {.lex_state = 77, .external_lex_state = 45},
  [13301] = {.lex_state = 77, .external_lex_state = 55},
  [13302] = {.lex_state = 77, .external_lex_state = 50},
  [13303] = {.lex_state = 77, .external_lex_state = 50},
  [13304] = {.lex_state = 77, .external_lex_state = 55},
  [13305] = {.lex_state = 32},
  [13306] = {.lex_state = 77, .external_lex_state = 53},
  [13307] = {.lex_state = 77, .external_lex_state = 51},
  [13308] = {.lex_state = 84},
  [13309] = {.lex_state = 77, .external_lex_state = 51},
  [13310] = {.lex_state = 77, .external_lex_state = 53},
  [13311] = {.lex_state = 32},
  [13312] = {.lex_state = 77, .external_lex_state = 51},
  [13313] = {.lex_state = 77, .external_lex_state = 50},
  [13314] = {.lex_state = 77, .external_lex_state = 50},
  [13315] = {.lex_state = 77, .external_lex_state = 53},
  [13316] = {.lex_state = 77, .external_lex_state = 53},
  [13317] = {.lex_state = 32},
  [13318] = {.lex_state = 77, .external_lex_state = 50},
  [13319] = {.lex_state = 77, .external_lex_state = 56},
  [13320] = {.lex_state = 32},
  [13321] = {.lex_state = 77, .external_lex_state = 58},
  [13322] = {.lex_state = 77, .external_lex_state = 61},
  [13323] = {.lex_state = 77, .external_lex_state = 66},
  [13324] = {.lex_state = 77, .external_lex_state = 51},
  [13325] = {.lex_state = 77, .external_lex_state = 51},
  [13326] = {.lex_state = 32},
  [13327] = {.lex_state = 77, .external_lex_state = 51},
  [13328] = {.lex_state = 77, .external_lex_state = 50},
  [13329] = {.lex_state = 32},
  [13330] = {.lex_state = 32},
  [13331] = {.lex_state = 32},
  [13332] = {.lex_state = 76, .external_lex_state = 24},
  [13333] = {.lex_state = 77, .external_lex_state = 50},
  [13334] = {.lex_state = 32},
  [13335] = {.lex_state = 77, .external_lex_state = 35},
  [13336] = {.lex_state = 77, .external_lex_state = 50},
  [13337] = {.lex_state = 77, .external_lex_state = 35},
  [13338] = {.lex_state = 77, .external_lex_state = 51},
  [13339] = {.lex_state = 77, .external_lex_state = 66},
  [13340] = {.lex_state = 76, .external_lex_state = 24},
  [13341] = {.lex_state = 76, .external_lex_state = 24},
  [13342] = {.lex_state = 77, .external_lex_state = 61},
  [13343] = {.lex_state = 32},
  [13344] = {.lex_state = 77, .external_lex_state = 55},
  [13345] = {.lex_state = 32},
  [13346] = {.lex_state = 84, .external_lex_state = 51},
  [13347] = {.lex_state = 84},
  [13348] = {.lex_state = 32},
  [13349] = {.lex_state = 32},
  [13350] = {.lex_state = 84, .external_lex_state = 55},
  [13351] = {.lex_state = 77, .external_lex_state = 50},
  [13352] = {.lex_state = 32},
  [13353] = {.lex_state = 77, .external_lex_state = 66},
  [13354] = {.lex_state = 77, .external_lex_state = 61},
  [13355] = {.lex_state = 77, .external_lex_state = 61},
  [13356] = {.lex_state = 77, .external_lex_state = 54},
  [13357] = {.lex_state = 32},
  [13358] = {.lex_state = 32},
  [13359] = {.lex_state = 32},
  [13360] = {.lex_state = 77, .external_lex_state = 46},
  [13361] = {.lex_state = 32},
  [13362] = {.lex_state = 77, .external_lex_state = 53},
  [13363] = {.lex_state = 77, .external_lex_state = 61},
  [13364] = {.lex_state = 77, .external_lex_state = 53},
  [13365] = {.lex_state = 32},
  [13366] = {.lex_state = 32},
  [13367] = {.lex_state = 77, .external_lex_state = 46},
  [13368] = {.lex_state = 77, .external_lex_state = 53},
  [13369] = {.lex_state = 77, .external_lex_state = 46},
  [13370] = {.lex_state = 77, .external_lex_state = 62},
  [13371] = {.lex_state = 77, .external_lex_state = 46},
  [13372] = {.lex_state = 77, .external_lex_state = 62},
  [13373] = {.lex_state = 77, .external_lex_state = 62},
  [13374] = {.lex_state = 77, .external_lex_state = 46},
  [13375] = {.lex_state = 77, .external_lex_state = 62},
  [13376] = {.lex_state = 77, .external_lex_state = 62},
  [13377] = {.lex_state = 77, .external_lex_state = 54},
  [13378] = {.lex_state = 77, .external_lex_state = 53},
  [13379] = {.lex_state = 77, .external_lex_state = 54},
  [13380] = {.lex_state = 76, .external_lex_state = 24},
  [13381] = {.lex_state = 77, .external_lex_state = 53},
  [13382] = {.lex_state = 76, .external_lex_state = 24},
  [13383] = {.lex_state = 32},
  [13384] = {.lex_state = 32},
  [13385] = {.lex_state = 77, .external_lex_state = 54},
  [13386] = {.lex_state = 77, .external_lex_state = 54},
  [13387] = {.lex_state = 77, .external_lex_state = 54},
  [13388] = {.lex_state = 76, .external_lex_state = 24},
  [13389] = {.lex_state = 32},
  [13390] = {.lex_state = 76, .external_lex_state = 24},
  [13391] = {.lex_state = 84, .external_lex_state = 46},
  [13392] = {.lex_state = 77, .external_lex_state = 53},
  [13393] = {.lex_state = 32},
  [13394] = {.lex_state = 77, .external_lex_state = 53},
  [13395] = {.lex_state = 77, .external_lex_state = 62},
  [13396] = {.lex_state = 77, .external_lex_state = 62},
  [13397] = {.lex_state = 76, .external_lex_state = 24},
  [13398] = {.lex_state = 77, .external_lex_state = 46},
  [13399] = {.lex_state = 77, .external_lex_state = 54},
  [13400] = {.lex_state = 76, .external_lex_state = 24},
  [13401] = {.lex_state = 76, .external_lex_state = 24},
  [13402] = {.lex_state = 77, .external_lex_state = 53},
  [13403] = {.lex_state = 84, .external_lex_state = 45},
  [13404] = {.lex_state = 32},
  [13405] = {.lex_state = 76, .external_lex_state = 24},
  [13406] = {.lex_state = 77, .external_lex_state = 60},
  [13407] = {.lex_state = 84, .external_lex_state = 29},
  [13408] = {.lex_state = 84, .external_lex_state = 45},
  [13409] = {.lex_state = 77, .external_lex_state = 55},
  [13410] = {.lex_state = 77, .external_lex_state = 53},
  [13411] = {.lex_state = 84, .external_lex_state = 55},
  [13412] = {.lex_state = 77, .external_lex_state = 63},
  [13413] = {.lex_state = 76, .external_lex_state = 24},
  [13414] = {.lex_state = 84, .external_lex_state = 45},
  [13415] = {.lex_state = 77, .external_lex_state = 56},
  [13416] = {.lex_state = 77, .external_lex_state = 63},
  [13417] = {.lex_state = 77, .external_lex_state = 63},
  [13418] = {.lex_state = 84, .external_lex_state = 45},
  [13419] = {.lex_state = 77, .external_lex_state = 53},
  [13420] = {.lex_state = 84, .external_lex_state = 45},
  [13421] = {.lex_state = 84, .external_lex_state = 53},
  [13422] = {.lex_state = 84, .external_lex_state = 45},
  [13423] = {.lex_state = 77, .external_lex_state = 53},
  [13424] = {.lex_state = 84, .external_lex_state = 45},
  [13425] = {.lex_state = 84, .external_lex_state = 45},
  [13426] = {.lex_state = 77, .external_lex_state = 58},
  [13427] = {.lex_state = 84, .external_lex_state = 45},
  [13428] = {.lex_state = 84, .external_lex_state = 45},
  [13429] = {.lex_state = 84, .external_lex_state = 55},
  [13430] = {.lex_state = 84, .external_lex_state = 45},
  [13431] = {.lex_state = 77, .external_lex_state = 63},
  [13432] = {.lex_state = 77, .external_lex_state = 24},
  [13433] = {.lex_state = 84, .external_lex_state = 51},
  [13434] = {.lex_state = 84, .external_lex_state = 45},
  [13435] = {.lex_state = 77, .external_lex_state = 63},
  [13436] = {.lex_state = 77, .external_lex_state = 60},
  [13437] = {.lex_state = 84, .external_lex_state = 45},
  [13438] = {.lex_state = 77, .external_lex_state = 60},
  [13439] = {.lex_state = 84, .external_lex_state = 45},
  [13440] = {.lex_state = 77, .external_lex_state = 63},
  [13441] = {.lex_state = 84, .external_lex_state = 45},
  [13442] = {.lex_state = 84, .external_lex_state = 39},
  [13443] = {.lex_state = 77, .external_lex_state = 54},
  [13444] = {.lex_state = 84, .external_lex_state = 55},
  [13445] = {.lex_state = 84, .external_lex_state = 55},
  [13446] = {.lex_state = 77, .external_lex_state = 58},
  [13447] = {.lex_state = 84, .external_lex_state = 45},
  [13448] = {.lex_state = 84},
  [13449] = {.lex_state = 77, .external_lex_state = 58},
  [13450] = {.lex_state = 77, .external_lex_state = 54},
  [13451] = {.lex_state = 84, .external_lex_state = 45},
  [13452] = {.lex_state = 77, .external_lex_state = 56},
  [13453] = {.lex_state = 77, .external_lex_state = 54},
  [13454] = {.lex_state = 84, .external_lex_state = 54},
  [13455] = {.lex_state = 77, .external_lex_state = 66},
  [13456] = {.lex_state = 0},
  [13457] = {.lex_state = 77, .external_lex_state = 58},
  [13458] = {.lex_state = 84, .external_lex_state = 55},
  [13459] = {.lex_state = 84, .external_lex_state = 29},
  [13460] = {.lex_state = 84, .external_lex_state = 45},
  [13461] = {.lex_state = 84, .external_lex_state = 45},
  [13462] = {.lex_state = 84},
  [13463] = {.lex_state = 84, .external_lex_state = 45},
  [13464] = {.lex_state = 0},
  [13465] = {.lex_state = 84, .external_lex_state = 45},
  [13466] = {.lex_state = 84, .external_lex_state = 51},
  [13467] = {.lex_state = 84, .external_lex_state = 45},
  [13468] = {.lex_state = 84, .external_lex_state = 45},
  [13469] = {.lex_state = 84, .external_lex_state = 45},
  [13470] = {.lex_state = 84, .external_lex_state = 29},
  [13471] = {.lex_state = 77, .external_lex_state = 55},
  [13472] = {.lex_state = 84, .external_lex_state = 53},
  [13473] = {.lex_state = 77, .external_lex_state = 63},
  [13474] = {.lex_state = 77, .external_lex_state = 55},
  [13475] = {.lex_state = 77, .external_lex_state = 65},
  [13476] = {.lex_state = 84, .external_lex_state = 34},
  [13477] = {.lex_state = 77, .external_lex_state = 53},
  [13478] = {.lex_state = 77, .external_lex_state = 68},
  [13479] = {.lex_state = 84, .external_lex_state = 53},
  [13480] = {.lex_state = 84, .external_lex_state = 53},
  [13481] = {.lex_state = 77, .external_lex_state = 56},
  [13482] = {.lex_state = 84, .external_lex_state = 24},
  [13483] = {.lex_state = 77, .external_lex_state = 54},
  [13484] = {.lex_state = 77, .external_lex_state = 51},
  [13485] = {.lex_state = 77, .external_lex_state = 54},
  [13486] = {.lex_state = 84, .external_lex_state = 46},
  [13487] = {.lex_state = 84, .external_lex_state = 46},
  [13488] = {.lex_state = 77, .external_lex_state = 60},
  [13489] = {.lex_state = 84, .external_lex_state = 34},
  [13490] = {.lex_state = 77, .external_lex_state = 54},
  [13491] = {.lex_state = 77, .external_lex_state = 56},
  [13492] = {.lex_state = 77, .external_lex_state = 54},
  [13493] = {.lex_state = 77, .external_lex_state = 51},
  [13494] = {.lex_state = 84, .external_lex_state = 24},
  [13495] = {.lex_state = 84, .external_lex_state = 51},
  [13496] = {.lex_state = 77, .external_lex_state = 54},
  [13497] = {.lex_state = 84, .external_lex_state = 30},
  [13498] = {.lex_state = 77, .external_lex_state = 56},
  [13499] = {.lex_state = 84, .external_lex_state = 46},
  [13500] = {.lex_state = 84, .external_lex_state = 57},
  [13501] = {.lex_state = 77, .external_lex_state = 56},
  [13502] = {.lex_state = 77, .external_lex_state = 60},
  [13503] = {.lex_state = 77, .external_lex_state = 53},
  [13504] = {.lex_state = 77, .external_lex_state = 60},
  [13505] = {.lex_state = 84, .external_lex_state = 30},
  [13506] = {.lex_state = 77, .external_lex_state = 55},
  [13507] = {.lex_state = 77, .external_lex_state = 55},
  [13508] = {.lex_state = 77, .external_lex_state = 56},
  [13509] = {.lex_state = 77, .external_lex_state = 54},
  [13510] = {.lex_state = 77, .external_lex_state = 58},
  [13511] = {.lex_state = 77, .external_lex_state = 58},
  [13512] = {.lex_state = 77, .external_lex_state = 53},
  [13513] = {.lex_state = 77, .external_lex_state = 63},
  [13514] = {.lex_state = 84, .external_lex_state = 29},
  [13515] = {.lex_state = 77, .external_lex_state = 65},
  [13516] = {.lex_state = 84, .external_lex_state = 34},
  [13517] = {.lex_state = 84, .external_lex_state = 29},
  [13518] = {.lex_state = 77, .external_lex_state = 53},
  [13519] = {.lex_state = 84},
  [13520] = {.lex_state = 84, .external_lex_state = 54},
  [13521] = {.lex_state = 77, .external_lex_state = 65},
  [13522] = {.lex_state = 84, .external_lex_state = 30},
  [13523] = {.lex_state = 77, .external_lex_state = 54},
  [13524] = {.lex_state = 77, .external_lex_state = 54},
  [13525] = {.lex_state = 84, .external_lex_state = 53},
  [13526] = {.lex_state = 77, .external_lex_state = 63},
  [13527] = {.lex_state = 77, .external_lex_state = 58},
  [13528] = {.lex_state = 77, .external_lex_state = 56},
  [13529] = {.lex_state = 77, .external_lex_state = 63},
  [13530] = {.lex_state = 77, .external_lex_state = 58},
  [13531] = {.lex_state = 77, .external_lex_state = 54},
  [13532] = {.lex_state = 77, .external_lex_state = 55},
  [13533] = {.lex_state = 77, .external_lex_state = 54},
  [13534] = {.lex_state = 77, .external_lex_state = 51},
  [13535] = {.lex_state = 77, .external_lex_state = 58},
  [13536] = {.lex_state = 77, .external_lex_state = 51},
  [13537] = {.lex_state = 84, .external_lex_state = 51},
  [13538] = {.lex_state = 84, .external_lex_state = 54},
  [13539] = {.lex_state = 84, .external_lex_state = 54},
  [13540] = {.lex_state = 77, .external_lex_state = 51},
  [13541] = {.lex_state = 84, .external_lex_state = 54},
  [13542] = {.lex_state = 84, .external_lex_state = 53},
  [13543] = {.lex_state = 77, .external_lex_state = 54},
  [13544] = {.lex_state = 77, .external_lex_state = 66},
  [13545] = {.lex_state = 77, .external_lex_state = 56},
  [13546] = {.lex_state = 77, .external_lex_state = 58},
  [13547] = {.lex_state = 77, .external_lex_state = 49},
  [13548] = {.lex_state = 77, .external_lex_state = 58},
  [13549] = {.lex_state = 77, .external_lex_state = 55},
  [13550] = {.lex_state = 77, .external_lex_state = 60},
  [13551] = {.lex_state = 77, .external_lex_state = 60},
  [13552] = {.lex_state = 76, .external_lex_state = 23},
  [13553] = {.lex_state = 84, .external_lex_state = 56},
  [13554] = {.lex_state = 77, .external_lex_state = 53},
  [13555] = {.lex_state = 84, .external_lex_state = 53},
  [13556] = {.lex_state = 77, .external_lex_state = 58},
  [13557] = {.lex_state = 77, .external_lex_state = 60},
  [13558] = {.lex_state = 77, .external_lex_state = 61},
  [13559] = {.lex_state = 77, .external_lex_state = 60},
  [13560] = {.lex_state = 77, .external_lex_state = 66},
  [13561] = {.lex_state = 76, .external_lex_state = 24},
  [13562] = {.lex_state = 77, .external_lex_state = 54},
  [13563] = {.lex_state = 77, .external_lex_state = 51},
  [13564] = {.lex_state = 77, .external_lex_state = 60},
  [13565] = {.lex_state = 77, .external_lex_state = 53},
  [13566] = {.lex_state = 77, .external_lex_state = 55},
  [13567] = {.lex_state = 77, .external_lex_state = 60},
  [13568] = {.lex_state = 84, .external_lex_state = 58},
  [13569] = {.lex_state = 77, .external_lex_state = 53},
  [13570] = {.lex_state = 77, .external_lex_state = 53},
  [13571] = {.lex_state = 77, .external_lex_state = 63},
  [13572] = {.lex_state = 84, .external_lex_state = 54},
  [13573] = {.lex_state = 77, .external_lex_state = 53},
  [13574] = {.lex_state = 77, .external_lex_state = 57},
  [13575] = {.lex_state = 77, .external_lex_state = 63},
  [13576] = {.lex_state = 77, .external_lex_state = 57},
  [13577] = {.lex_state = 84, .external_lex_state = 29},
  [13578] = {.lex_state = 77, .external_lex_state = 66},
  [13579] = {.lex_state = 77, .external_lex_state = 63},
  [13580] = {.lex_state = 77, .external_lex_state = 68},
  [13581] = {.lex_state = 84, .external_lex_state = 29},
  [13582] = {.lex_state = 77, .external_lex_state = 55},
  [13583] = {.lex_state = 90},
  [13584] = {.lex_state = 77, .external_lex_state = 51},
  [13585] = {.lex_state = 77, .external_lex_state = 53},
  [13586] = {.lex_state = 84, .external_lex_state = 54},
  [13587] = {.lex_state = 77, .external_lex_state = 51},
  [13588] = {.lex_state = 84, .external_lex_state = 54},
  [13589] = {.lex_state = 77, .external_lex_state = 57},
  [13590] = {.lex_state = 77, .external_lex_state = 54},
  [13591] = {.lex_state = 77, .external_lex_state = 60},
  [13592] = {.lex_state = 77, .external_lex_state = 63},
  [13593] = {.lex_state = 84, .external_lex_state = 29},
  [13594] = {.lex_state = 84, .external_lex_state = 29},
  [13595] = {.lex_state = 84, .external_lex_state = 54},
  [13596] = {.lex_state = 77, .external_lex_state = 51},
  [13597] = {.lex_state = 77, .external_lex_state = 54},
  [13598] = {.lex_state = 77, .external_lex_state = 51},
  [13599] = {.lex_state = 84, .external_lex_state = 55},
  [13600] = {.lex_state = 77, .external_lex_state = 53},
  [13601] = {.lex_state = 77, .external_lex_state = 57},
  [13602] = {.lex_state = 77, .external_lex_state = 57},
  [13603] = {.lex_state = 77, .external_lex_state = 53},
  [13604] = {.lex_state = 77, .external_lex_state = 54},
  [13605] = {.lex_state = 77, .external_lex_state = 57},
  [13606] = {.lex_state = 76, .external_lex_state = 24},
  [13607] = {.lex_state = 77, .external_lex_state = 53},
  [13608] = {.lex_state = 77, .external_lex_state = 51},
  [13609] = {.lex_state = 84, .external_lex_state = 55},
  [13610] = {.lex_state = 76, .external_lex_state = 24},
  [13611] = {.lex_state = 84, .external_lex_state = 46},
  [13612] = {.lex_state = 84, .external_lex_state = 46},
  [13613] = {.lex_state = 77, .external_lex_state = 54},
  [13614] = {.lex_state = 77, .external_lex_state = 51},
  [13615] = {.lex_state = 76, .external_lex_state = 24},
  [13616] = {.lex_state = 77, .external_lex_state = 66},
  [13617] = {.lex_state = 77, .external_lex_state = 53},
  [13618] = {.lex_state = 77, .external_lex_state = 55},
  [13619] = {.lex_state = 77, .external_lex_state = 66},
  [13620] = {.lex_state = 84, .external_lex_state = 51},
  [13621] = {.lex_state = 77, .external_lex_state = 65},
  [13622] = {.lex_state = 77, .external_lex_state = 66},
  [13623] = {.lex_state = 77, .external_lex_state = 55},
  [13624] = {.lex_state = 84, .external_lex_state = 46},
  [13625] = {.lex_state = 77, .external_lex_state = 24},
  [13626] = {.lex_state = 77, .external_lex_state = 51},
  [13627] = {.lex_state = 84, .external_lex_state = 46},
  [13628] = {.lex_state = 77, .external_lex_state = 57},
  [13629] = {.lex_state = 77, .external_lex_state = 66},
  [13630] = {.lex_state = 77, .external_lex_state = 60},
  [13631] = {.lex_state = 84, .external_lex_state = 46},
  [13632] = {.lex_state = 84, .external_lex_state = 46},
  [13633] = {.lex_state = 76, .external_lex_state = 24},
  [13634] = {.lex_state = 77, .external_lex_state = 53},
  [13635] = {.lex_state = 84, .external_lex_state = 46},
  [13636] = {.lex_state = 77, .external_lex_state = 53},
  [13637] = {.lex_state = 84, .external_lex_state = 53},
  [13638] = {.lex_state = 77, .external_lex_state = 66},
  [13639] = {.lex_state = 77, .external_lex_state = 66},
  [13640] = {.lex_state = 77, .external_lex_state = 24},
  [13641] = {.lex_state = 77, .external_lex_state = 55},
  [13642] = {.lex_state = 77, .external_lex_state = 57},
  [13643] = {.lex_state = 77, .external_lex_state = 51},
  [13644] = {.lex_state = 77, .external_lex_state = 66},
  [13645] = {.lex_state = 84, .external_lex_state = 55},
  [13646] = {.lex_state = 77, .external_lex_state = 66},
  [13647] = {.lex_state = 77, .external_lex_state = 55},
  [13648] = {.lex_state = 77, .external_lex_state = 63},
  [13649] = {.lex_state = 77, .external_lex_state = 68},
  [13650] = {.lex_state = 84, .external_lex_state = 30},
  [13651] = {.lex_state = 84, .external_lex_state = 46},
  [13652] = {.lex_state = 84, .external_lex_state = 34},
  [13653] = {.lex_state = 77, .external_lex_state = 57},
  [13654] = {.lex_state = 84, .external_lex_state = 46},
  [13655] = {.lex_state = 84, .external_lex_state = 46},
  [13656] = {.lex_state = 77, .external_lex_state = 56},
  [13657] = {.lex_state = 77, .external_lex_state = 66},
  [13658] = {.lex_state = 77, .external_lex_state = 55},
  [13659] = {.lex_state = 77, .external_lex_state = 57},
  [13660] = {.lex_state = 77, .external_lex_state = 57},
  [13661] = {.lex_state = 77, .external_lex_state = 55},
  [13662] = {.lex_state = 77, .external_lex_state = 55},
  [13663] = {.lex_state = 77, .external_lex_state = 66},
  [13664] = {.lex_state = 77, .external_lex_state = 51},
  [13665] = {.lex_state = 77, .external_lex_state = 55},
  [13666] = {.lex_state = 84, .external_lex_state = 46},
  [13667] = {.lex_state = 84, .external_lex_state = 46},
  [13668] = {.lex_state = 84, .external_lex_state = 46},
  [13669] = {.lex_state = 84, .external_lex_state = 46},
  [13670] = {.lex_state = 84, .external_lex_state = 46},
  [13671] = {.lex_state = 77, .external_lex_state = 56},
  [13672] = {.lex_state = 77, .external_lex_state = 56},
  [13673] = {.lex_state = 77, .external_lex_state = 57},
  [13674] = {.lex_state = 77, .external_lex_state = 51},
  [13675] = {.lex_state = 77, .external_lex_state = 51},
  [13676] = {.lex_state = 84, .external_lex_state = 54},
  [13677] = {.lex_state = 77, .external_lex_state = 53},
  [13678] = {.lex_state = 77, .external_lex_state = 56},
  [13679] = {.lex_state = 77, .external_lex_state = 54},
  [13680] = {.lex_state = 77, .external_lex_state = 51},
  [13681] = {.lex_state = 77, .external_lex_state = 53},
  [13682] = {.lex_state = 84, .external_lex_state = 46},
  [13683] = {.lex_state = 77, .external_lex_state = 55},
  [13684] = {.lex_state = 84, .external_lex_state = 54},
  [13685] = {.lex_state = 84, .external_lex_state = 46},
  [13686] = {.lex_state = 84, .external_lex_state = 54},
  [13687] = {.lex_state = 77, .external_lex_state = 55},
  [13688] = {.lex_state = 84, .external_lex_state = 46},
  [13689] = {.lex_state = 77, .external_lex_state = 60},
  [13690] = {.lex_state = 77, .external_lex_state = 66},
  [13691] = {.lex_state = 77, .external_lex_state = 54},
  [13692] = {.lex_state = 84, .external_lex_state = 46},
  [13693] = {.lex_state = 77, .external_lex_state = 51},
  [13694] = {.lex_state = 84, .external_lex_state = 51},
  [13695] = {.lex_state = 77, .external_lex_state = 55},
  [13696] = {.lex_state = 84, .external_lex_state = 46},
  [13697] = {.lex_state = 77, .external_lex_state = 58},
  [13698] = {.lex_state = 77, .external_lex_state = 66},
  [13699] = {.lex_state = 77, .external_lex_state = 55},
  [13700] = {.lex_state = 76, .external_lex_state = 23},
  [13701] = {.lex_state = 77, .external_lex_state = 57},
  [13702] = {.lex_state = 84, .external_lex_state = 46},
  [13703] = {.lex_state = 84, .external_lex_state = 30},
  [13704] = {.lex_state = 77, .external_lex_state = 24},
  [13705] = {.lex_state = 84, .external_lex_state = 54},
  [13706] = {.lex_state = 84, .external_lex_state = 29},
  [13707] = {.lex_state = 77, .external_lex_state = 23},
  [13708] = {.lex_state = 77, .external_lex_state = 24},
  [13709] = {.lex_state = 76, .external_lex_state = 24},
  [13710] = {.lex_state = 84, .external_lex_state = 51},
  [13711] = {.lex_state = 76, .external_lex_state = 24},
  [13712] = {.lex_state = 84, .external_lex_state = 54},
  [13713] = {.lex_state = 84, .external_lex_state = 29},
  [13714] = {.lex_state = 84, .external_lex_state = 29},
  [13715] = {.lex_state = 84, .external_lex_state = 46},
  [13716] = {.lex_state = 77, .external_lex_state = 51},
  [13717] = {.lex_state = 77, .external_lex_state = 51},
  [13718] = {.lex_state = 84, .external_lex_state = 56},
  [13719] = {.lex_state = 77, .external_lex_state = 35},
  [13720] = {.lex_state = 84, .external_lex_state = 51},
  [13721] = {.lex_state = 77, .external_lex_state = 35},
  [13722] = {.lex_state = 84, .external_lex_state = 54},
  [13723] = {.lex_state = 77, .external_lex_state = 35},
  [13724] = {.lex_state = 84, .external_lex_state = 54},
  [13725] = {.lex_state = 84, .external_lex_state = 55},
  [13726] = {.lex_state = 84, .external_lex_state = 51},
  [13727] = {.lex_state = 77, .external_lex_state = 58},
  [13728] = {.lex_state = 84, .external_lex_state = 29},
  [13729] = {.lex_state = 84, .external_lex_state = 58},
  [13730] = {.lex_state = 84, .external_lex_state = 38},
  [13731] = {.lex_state = 77, .external_lex_state = 58},
  [13732] = {.lex_state = 77, .external_lex_state = 57},
  [13733] = {.lex_state = 84, .external_lex_state = 54},
  [13734] = {.lex_state = 84, .external_lex_state = 51},
  [13735] = {.lex_state = 77, .external_lex_state = 65},
  [13736] = {.lex_state = 77, .external_lex_state = 56},
  [13737] = {.lex_state = 84, .external_lex_state = 51},
  [13738] = {.lex_state = 84, .external_lex_state = 54},
  [13739] = {.lex_state = 77, .external_lex_state = 57},
  [13740] = {.lex_state = 77, .external_lex_state = 58},
  [13741] = {.lex_state = 77, .external_lex_state = 58},
  [13742] = {.lex_state = 77, .external_lex_state = 50},
  [13743] = {.lex_state = 84, .external_lex_state = 46},
  [13744] = {.lex_state = 77, .external_lex_state = 50},
  [13745] = {.lex_state = 84, .external_lex_state = 54},
  [13746] = {.lex_state = 77, .external_lex_state = 68},
  [13747] = {.lex_state = 77, .external_lex_state = 58},
  [13748] = {.lex_state = 84, .external_lex_state = 23},
  [13749] = {.lex_state = 84, .external_lex_state = 51},
  [13750] = {.lex_state = 84, .external_lex_state = 51},
  [13751] = {.lex_state = 84, .external_lex_state = 39},
  [13752] = {.lex_state = 77, .external_lex_state = 58},
  [13753] = {.lex_state = 84, .external_lex_state = 54},
  [13754] = {.lex_state = 84, .external_lex_state = 30},
  [13755] = {.lex_state = 84, .external_lex_state = 54},
  [13756] = {.lex_state = 84, .external_lex_state = 51},
  [13757] = {.lex_state = 77, .external_lex_state = 56},
  [13758] = {.lex_state = 77, .external_lex_state = 57},
  [13759] = {.lex_state = 84, .external_lex_state = 53},
  [13760] = {.lex_state = 84, .external_lex_state = 54},
  [13761] = {.lex_state = 84, .external_lex_state = 53},
  [13762] = {.lex_state = 84, .external_lex_state = 51},
  [13763] = {.lex_state = 77, .external_lex_state = 58},
  [13764] = {.lex_state = 84, .external_lex_state = 55},
  [13765] = {.lex_state = 84, .external_lex_state = 34},
  [13766] = {.lex_state = 84, .external_lex_state = 55},
  [13767] = {.lex_state = 84, .external_lex_state = 38},
  [13768] = {.lex_state = 77, .external_lex_state = 57},
  [13769] = {.lex_state = 84, .external_lex_state = 51},
  [13770] = {.lex_state = 84, .external_lex_state = 55},
  [13771] = {.lex_state = 84, .external_lex_state = 58},
  [13772] = {.lex_state = 84, .external_lex_state = 29},
  [13773] = {.lex_state = 84, .external_lex_state = 29},
  [13774] = {.lex_state = 84, .external_lex_state = 51},
  [13775] = {.lex_state = 84, .external_lex_state = 56},
  [13776] = {.lex_state = 84, .external_lex_state = 55},
  [13777] = {.lex_state = 84, .external_lex_state = 34},
  [13778] = {.lex_state = 76, .external_lex_state = 23},
  [13779] = {.lex_state = 77, .external_lex_state = 23},
  [13780] = {.lex_state = 84, .external_lex_state = 34},
  [13781] = {.lex_state = 84, .external_lex_state = 29},
  [13782] = {.lex_state = 84, .external_lex_state = 34},
  [13783] = {.lex_state = 84, .external_lex_state = 55},
  [13784] = {.lex_state = 84, .external_lex_state = 29},
  [13785] = {.lex_state = 84, .external_lex_state = 34},
  [13786] = {.lex_state = 84, .external_lex_state = 34},
  [13787] = {.lex_state = 84, .external_lex_state = 34},
  [13788] = {.lex_state = 77, .external_lex_state = 23},
  [13789] = {.lex_state = 77, .external_lex_state = 23},
  [13790] = {.lex_state = 84, .external_lex_state = 55},
  [13791] = {.lex_state = 84, .external_lex_state = 39},
  [13792] = {.lex_state = 84, .external_lex_state = 34},
  [13793] = {.lex_state = 84, .external_lex_state = 55},
  [13794] = {.lex_state = 77, .external_lex_state = 57},
  [13795] = {.lex_state = 84, .external_lex_state = 55},
  [13796] = {.lex_state = 77, .external_lex_state = 35},
  [13797] = {.lex_state = 84, .external_lex_state = 53},
  [13798] = {.lex_state = 77, .external_lex_state = 56},
  [13799] = {.lex_state = 77, .external_lex_state = 56},
  [13800] = {.lex_state = 77, .external_lex_state = 65},
  [13801] = {.lex_state = 77, .external_lex_state = 65},
  [13802] = {.lex_state = 77, .external_lex_state = 65},
  [13803] = {.lex_state = 84, .external_lex_state = 45},
  [13804] = {.lex_state = 84, .external_lex_state = 29},
  [13805] = {.lex_state = 77, .external_lex_state = 35},
  [13806] = {.lex_state = 77, .external_lex_state = 65},
  [13807] = {.lex_state = 77, .external_lex_state = 56},
  [13808] = {.lex_state = 77, .external_lex_state = 62},
  [13809] = {.lex_state = 77, .external_lex_state = 62},
  [13810] = {.lex_state = 84, .external_lex_state = 54},
  [13811] = {.lex_state = 84, .external_lex_state = 53},
  [13812] = {.lex_state = 84, .external_lex_state = 45},
  [13813] = {.lex_state = 77, .external_lex_state = 56},
  [13814] = {.lex_state = 84, .external_lex_state = 53},
  [13815] = {.lex_state = 77, .external_lex_state = 50},
  [13816] = {.lex_state = 84, .external_lex_state = 55},
  [13817] = {.lex_state = 84, .external_lex_state = 56},
  [13818] = {.lex_state = 84, .external_lex_state = 54},
  [13819] = {.lex_state = 84, .external_lex_state = 39},
  [13820] = {.lex_state = 77, .external_lex_state = 68},
  [13821] = {.lex_state = 77, .external_lex_state = 56},
  [13822] = {.lex_state = 84, .external_lex_state = 55},
  [13823] = {.lex_state = 77, .external_lex_state = 62},
  [13824] = {.lex_state = 84, .external_lex_state = 39},
  [13825] = {.lex_state = 77, .external_lex_state = 57},
  [13826] = {.lex_state = 84, .external_lex_state = 46},
  [13827] = {.lex_state = 77, .external_lex_state = 62},
  [13828] = {.lex_state = 84, .external_lex_state = 29},
  [13829] = {.lex_state = 84, .external_lex_state = 53},
  [13830] = {.lex_state = 84, .external_lex_state = 34},
  [13831] = {.lex_state = 84, .external_lex_state = 56},
  [13832] = {.lex_state = 84, .external_lex_state = 55},
  [13833] = {.lex_state = 76, .external_lex_state = 23},
  [13834] = {.lex_state = 84, .external_lex_state = 39},
  [13835] = {.lex_state = 84, .external_lex_state = 54},
  [13836] = {.lex_state = 76, .external_lex_state = 49},
  [13837] = {.lex_state = 84, .external_lex_state = 53},
  [13838] = {.lex_state = 84, .external_lex_state = 46},
  [13839] = {.lex_state = 84, .external_lex_state = 53},
  [13840] = {.lex_state = 77, .external_lex_state = 58},
  [13841] = {.lex_state = 76, .external_lex_state = 24},
  [13842] = {.lex_state = 77, .external_lex_state = 62},
  [13843] = {.lex_state = 84, .external_lex_state = 54},
  [13844] = {.lex_state = 84, .external_lex_state = 53},
  [13845] = {.lex_state = 84, .external_lex_state = 54},
  [13846] = {.lex_state = 84, .external_lex_state = 55},
  [13847] = {.lex_state = 84, .external_lex_state = 55},
  [13848] = {.lex_state = 84, .external_lex_state = 53},
  [13849] = {.lex_state = 77, .external_lex_state = 58},
  [13850] = {.lex_state = 84, .external_lex_state = 56},
  [13851] = {.lex_state = 77, .external_lex_state = 62},
  [13852] = {.lex_state = 84, .external_lex_state = 54},
  [13853] = {.lex_state = 77, .external_lex_state = 58},
  [13854] = {.lex_state = 84, .external_lex_state = 54},
  [13855] = {.lex_state = 77, .external_lex_state = 56},
  [13856] = {.lex_state = 77, .external_lex_state = 58},
  [13857] = {.lex_state = 77, .external_lex_state = 58},
  [13858] = {.lex_state = 84, .external_lex_state = 55},
  [13859] = {.lex_state = 84, .external_lex_state = 51},
  [13860] = {.lex_state = 77, .external_lex_state = 57},
  [13861] = {.lex_state = 84, .external_lex_state = 54},
  [13862] = {.lex_state = 77, .external_lex_state = 58},
  [13863] = {.lex_state = 77, .external_lex_state = 58},
  [13864] = {.lex_state = 77, .external_lex_state = 68},
  [13865] = {.lex_state = 77, .external_lex_state = 56},
  [13866] = {.lex_state = 77, .external_lex_state = 35},
  [13867] = {.lex_state = 84, .external_lex_state = 54},
  [13868] = {.lex_state = 77, .external_lex_state = 65},
  [13869] = {.lex_state = 77, .external_lex_state = 56},
  [13870] = {.lex_state = 77, .external_lex_state = 24},
  [13871] = {.lex_state = 84, .external_lex_state = 51},
  [13872] = {.lex_state = 84, .external_lex_state = 53},
  [13873] = {.lex_state = 77, .external_lex_state = 65},
  [13874] = {.lex_state = 77, .external_lex_state = 56},
  [13875] = {.lex_state = 77, .external_lex_state = 68},
  [13876] = {.lex_state = 84, .external_lex_state = 58},
  [13877] = {.lex_state = 77, .external_lex_state = 65},
  [13878] = {.lex_state = 84, .external_lex_state = 55},
  [13879] = {.lex_state = 84, .external_lex_state = 34},
  [13880] = {.lex_state = 84, .external_lex_state = 54},
  [13881] = {.lex_state = 84, .external_lex_state = 55},
  [13882] = {.lex_state = 84, .external_lex_state = 53},
  [13883] = {.lex_state = 77, .external_lex_state = 24},
  [13884] = {.lex_state = 84, .external_lex_state = 53},
  [13885] = {.lex_state = 77, .external_lex_state = 56},
  [13886] = {.lex_state = 77, .external_lex_state = 23},
  [13887] = {.lex_state = 84, .external_lex_state = 55},
  [13888] = {.lex_state = 77, .external_lex_state = 62},
  [13889] = {.lex_state = 76, .external_lex_state = 23},
  [13890] = {.lex_state = 77, .external_lex_state = 58},
  [13891] = {.lex_state = 84, .external_lex_state = 55},
  [13892] = {.lex_state = 77, .external_lex_state = 57},
  [13893] = {.lex_state = 77, .external_lex_state = 65},
  [13894] = {.lex_state = 84, .external_lex_state = 58},
  [13895] = {.lex_state = 77, .external_lex_state = 24},
  [13896] = {.lex_state = 84, .external_lex_state = 54},
  [13897] = {.lex_state = 77, .external_lex_state = 62},
  [13898] = {.lex_state = 77, .external_lex_state = 50},
  [13899] = {.lex_state = 77, .external_lex_state = 58},
  [13900] = {.lex_state = 76, .external_lex_state = 23},
  [13901] = {.lex_state = 77, .external_lex_state = 24},
  [13902] = {.lex_state = 77, .external_lex_state = 65},
  [13903] = {.lex_state = 84, .external_lex_state = 53},
  [13904] = {.lex_state = 77, .external_lex_state = 24},
  [13905] = {.lex_state = 77, .external_lex_state = 56},
  [13906] = {.lex_state = 77, .external_lex_state = 58},
  [13907] = {.lex_state = 77, .external_lex_state = 65},
  [13908] = {.lex_state = 76, .external_lex_state = 49},
  [13909] = {.lex_state = 77, .external_lex_state = 68},
  [13910] = {.lex_state = 77, .external_lex_state = 57},
  [13911] = {.lex_state = 77, .external_lex_state = 57},
  [13912] = {.lex_state = 77, .external_lex_state = 56},
  [13913] = {.lex_state = 84, .external_lex_state = 55},
  [13914] = {.lex_state = 77, .external_lex_state = 62},
  [13915] = {.lex_state = 77, .external_lex_state = 57},
  [13916] = {.lex_state = 84, .external_lex_state = 29},
  [13917] = {.lex_state = 84, .external_lex_state = 53},
  [13918] = {.lex_state = 84, .external_lex_state = 39},
  [13919] = {.lex_state = 77, .external_lex_state = 68},
  [13920] = {.lex_state = 84, .external_lex_state = 51},
  [13921] = {.lex_state = 84, .external_lex_state = 23},
  [13922] = {.lex_state = 84, .external_lex_state = 51},
  [13923] = {.lex_state = 84, .external_lex_state = 51},
  [13924] = {.lex_state = 84, .external_lex_state = 54},
  [13925] = {.lex_state = 84, .external_lex_state = 53},
  [13926] = {.lex_state = 84, .external_lex_state = 51},
  [13927] = {.lex_state = 84, .external_lex_state = 55},
  [13928] = {.lex_state = 84, .external_lex_state = 29},
  [13929] = {.lex_state = 77, .external_lex_state = 65},
  [13930] = {.lex_state = 77, .external_lex_state = 68},
  [13931] = {.lex_state = 77, .external_lex_state = 62},
  [13932] = {.lex_state = 77, .external_lex_state = 68},
  [13933] = {.lex_state = 84, .external_lex_state = 56},
  [13934] = {.lex_state = 84, .external_lex_state = 56},
  [13935] = {.lex_state = 77, .external_lex_state = 68},
  [13936] = {.lex_state = 77, .external_lex_state = 56},
  [13937] = {.lex_state = 77, .external_lex_state = 57},
  [13938] = {.lex_state = 77, .external_lex_state = 65},
  [13939] = {.lex_state = 84, .external_lex_state = 53},
  [13940] = {.lex_state = 84, .external_lex_state = 53},
  [13941] = {.lex_state = 77, .external_lex_state = 56},
  [13942] = {.lex_state = 84, .external_lex_state = 30},
  [13943] = {.lex_state = 77, .external_lex_state = 65},
  [13944] = {.lex_state = 84, .external_lex_state = 55},
  [13945] = {.lex_state = 77, .external_lex_state = 24},
  [13946] = {.lex_state = 77, .external_lex_state = 58},
  [13947] = {.lex_state = 84, .external_lex_state = 58},
  [13948] = {.lex_state = 77, .external_lex_state = 68},
  [13949] = {.lex_state = 84, .external_lex_state = 51},
  [13950] = {.lex_state = 76, .external_lex_state = 49},
  [13951] = {.lex_state = 84, .external_lex_state = 55},
  [13952] = {.lex_state = 84, .external_lex_state = 54},
  [13953] = {.lex_state = 84, .external_lex_state = 53},
  [13954] = {.lex_state = 84, .external_lex_state = 29},
  [13955] = {.lex_state = 77, .external_lex_state = 68},
  [13956] = {.lex_state = 77, .external_lex_state = 58},
  [13957] = {.lex_state = 76, .external_lex_state = 23},
  [13958] = {.lex_state = 77, .external_lex_state = 24},
  [13959] = {.lex_state = 77, .external_lex_state = 63},
  [13960] = {.lex_state = 84, .external_lex_state = 54},
  [13961] = {.lex_state = 84, .external_lex_state = 54},
  [13962] = {.lex_state = 84, .external_lex_state = 54},
  [13963] = {.lex_state = 76, .external_lex_state = 23},
  [13964] = {.lex_state = 76, .external_lex_state = 23},
  [13965] = {.lex_state = 84, .external_lex_state = 55},
  [13966] = {.lex_state = 84, .external_lex_state = 39},
  [13967] = {.lex_state = 84, .external_lex_state = 58},
  [13968] = {.lex_state = 76, .external_lex_state = 23},
  [13969] = {.lex_state = 77, .external_lex_state = 24},
  [13970] = {.lex_state = 84, .external_lex_state = 55},
  [13971] = {.lex_state = 84, .external_lex_state = 30},
  [13972] = {.lex_state = 84, .external_lex_state = 57},
  [13973] = {.lex_state = 84, .external_lex_state = 46},
  [13974] = {.lex_state = 84, .external_lex_state = 53},
  [13975] = {.lex_state = 84, .external_lex_state = 57},
  [13976] = {.lex_state = 84, .external_lex_state = 46},
  [13977] = {.lex_state = 84, .external_lex_state = 29},
  [13978] = {.lex_state = 77, .external_lex_state = 56},
  [13979] = {.lex_state = 77, .external_lex_state = 57},
  [13980] = {.lex_state = 84, .external_lex_state = 51},
  [13981] = {.lex_state = 84, .external_lex_state = 53},
  [13982] = {.lex_state = 77, .external_lex_state = 24},
  [13983] = {.lex_state = 77, .external_lex_state = 68},
  [13984] = {.lex_state = 84, .external_lex_state = 57},
  [13985] = {.lex_state = 76, .external_lex_state = 23},
  [13986] = {.lex_state = 77, .external_lex_state = 58},
  [13987] = {.lex_state = 77, .external_lex_state = 68},
  [13988] = {.lex_state = 84, .external_lex_state = 53},
  [13989] = {.lex_state = 77, .external_lex_state = 62},
  [13990] = {.lex_state = 84, .external_lex_state = 53},
  [13991] = {.lex_state = 77, .external_lex_state = 62},
  [13992] = {.lex_state = 84, .external_lex_state = 53},
  [13993] = {.lex_state = 77, .external_lex_state = 57},
  [13994] = {.lex_state = 77, .external_lex_state = 68},
  [13995] = {.lex_state = 77},
  [13996] = {.lex_state = 76, .external_lex_state = 23},
  [13997] = {.lex_state = 77, .external_lex_state = 62},
  [13998] = {.lex_state = 84, .external_lex_state = 29},
  [13999] = {.lex_state = 77, .external_lex_state = 68},
  [14000] = {.lex_state = 77, .external_lex_state = 62},
  [14001] = {.lex_state = 84, .external_lex_state = 46},
  [14002] = {.lex_state = 84, .external_lex_state = 54},
  [14003] = {.lex_state = 77, .external_lex_state = 62},
  [14004] = {.lex_state = 77, .external_lex_state = 57},
  [14005] = {.lex_state = 84, .external_lex_state = 53},
  [14006] = {.lex_state = 77, .external_lex_state = 24},
  [14007] = {.lex_state = 77, .external_lex_state = 50},
  [14008] = {.lex_state = 84, .external_lex_state = 38},
  [14009] = {.lex_state = 84, .external_lex_state = 53},
  [14010] = {.lex_state = 84, .external_lex_state = 54},
  [14011] = {.lex_state = 84, .external_lex_state = 56},
  [14012] = {.lex_state = 84, .external_lex_state = 51},
  [14013] = {.lex_state = 84, .external_lex_state = 51},
  [14014] = {.lex_state = 77, .external_lex_state = 57},
  [14015] = {.lex_state = 77, .external_lex_state = 24},
  [14016] = {.lex_state = 77, .external_lex_state = 58},
  [14017] = {.lex_state = 84},
  [14018] = {.lex_state = 77, .external_lex_state = 56},
  [14019] = {.lex_state = 84, .external_lex_state = 38},
  [14020] = {.lex_state = 84, .external_lex_state = 24},
  [14021] = {.lex_state = 84, .external_lex_state = 58},
  [14022] = {.lex_state = 77, .external_lex_state = 57},
  [14023] = {.lex_state = 84, .external_lex_state = 57},
  [14024] = {.lex_state = 84, .external_lex_state = 39},
  [14025] = {.lex_state = 77, .external_lex_state = 49},
  [14026] = {.lex_state = 84, .external_lex_state = 58},
  [14027] = {.lex_state = 77, .external_lex_state = 57},
  [14028] = {.lex_state = 77, .external_lex_state = 57},
  [14029] = {.lex_state = 84, .external_lex_state = 39},
  [14030] = {.lex_state = 84, .external_lex_state = 51},
  [14031] = {.lex_state = 84, .external_lex_state = 30},
  [14032] = {.lex_state = 77, .external_lex_state = 57},
  [14033] = {.lex_state = 84, .external_lex_state = 57},
  [14034] = {.lex_state = 76, .external_lex_state = 23},
  [14035] = {.lex_state = 76, .external_lex_state = 23},
  [14036] = {.lex_state = 76, .external_lex_state = 49},
  [14037] = {.lex_state = 77, .external_lex_state = 65},
  [14038] = {.lex_state = 77, .external_lex_state = 56},
  [14039] = {.lex_state = 77, .external_lex_state = 23},
  [14040] = {.lex_state = 77, .external_lex_state = 56},
  [14041] = {.lex_state = 77, .external_lex_state = 50},
  [14042] = {.lex_state = 84, .external_lex_state = 53},
  [14043] = {.lex_state = 84, .external_lex_state = 30},
  [14044] = {.lex_state = 77, .external_lex_state = 57},
  [14045] = {.lex_state = 77, .external_lex_state = 65},
  [14046] = {.lex_state = 84, .external_lex_state = 46},
  [14047] = {.lex_state = 84, .external_lex_state = 55},
  [14048] = {.lex_state = 84, .external_lex_state = 46},
  [14049] = {.lex_state = 84, .external_lex_state = 57},
  [14050] = {.lex_state = 84, .external_lex_state = 57},
  [14051] = {.lex_state = 77, .external_lex_state = 68},
  [14052] = {.lex_state = 84, .external_lex_state = 39},
  [14053] = {.lex_state = 77, .external_lex_state = 56},
  [14054] = {.lex_state = 77, .external_lex_state = 65},
  [14055] = {.lex_state = 84, .external_lex_state = 57},
  [14056] = {.lex_state = 84, .external_lex_state = 53},
  [14057] = {.lex_state = 76, .external_lex_state = 49},
  [14058] = {.lex_state = 76, .external_lex_state = 49},
  [14059] = {.lex_state = 84, .external_lex_state = 34},
  [14060] = {.lex_state = 0},
  [14061] = {.lex_state = 84, .external_lex_state = 34},
  [14062] = {.lex_state = 76, .external_lex_state = 49},
  [14063] = {.lex_state = 84, .external_lex_state = 34},
  [14064] = {.lex_state = 76, .external_lex_state = 49},
  [14065] = {.lex_state = 84, .external_lex_state = 53},
  [14066] = {.lex_state = 84, .external_lex_state = 56},
  [14067] = {.lex_state = 84, .external_lex_state = 53},
  [14068] = {.lex_state = 84, .external_lex_state = 35},
  [14069] = {.lex_state = 84, .external_lex_state = 56},
  [14070] = {.lex_state = 84, .external_lex_state = 30},
  [14071] = {.lex_state = 76, .external_lex_state = 49},
  [14072] = {.lex_state = 77, .external_lex_state = 23},
  [14073] = {.lex_state = 84, .external_lex_state = 57},
  [14074] = {.lex_state = 84, .external_lex_state = 38},
  [14075] = {.lex_state = 84, .external_lex_state = 34},
  [14076] = {.lex_state = 76, .external_lex_state = 49},
  [14077] = {.lex_state = 84, .external_lex_state = 67},
  [14078] = {.lex_state = 84, .external_lex_state = 69},
  [14079] = {.lex_state = 77, .external_lex_state = 60},
  [14080] = {.lex_state = 76, .external_lex_state = 24},
  [14081] = {.lex_state = 84, .external_lex_state = 57},
  [14082] = {.lex_state = 84, .external_lex_state = 53},
  [14083] = {.lex_state = 84, .external_lex_state = 57},
  [14084] = {.lex_state = 84, .external_lex_state = 56},
  [14085] = {.lex_state = 84, .external_lex_state = 53},
  [14086] = {.lex_state = 77, .external_lex_state = 23},
  [14087] = {.lex_state = 84, .external_lex_state = 57},
  [14088] = {.lex_state = 84, .external_lex_state = 34},
  [14089] = {.lex_state = 84, .external_lex_state = 57},
  [14090] = {.lex_state = 76, .external_lex_state = 24},
  [14091] = {.lex_state = 84, .external_lex_state = 57},
  [14092] = {.lex_state = 0},
  [14093] = {.lex_state = 84, .external_lex_state = 34},
  [14094] = {.lex_state = 84, .external_lex_state = 57},
  [14095] = {.lex_state = 84, .external_lex_state = 24},
  [14096] = {.lex_state = 0},
  [14097] = {.lex_state = 84, .external_lex_state = 57},
  [14098] = {.lex_state = 76, .external_lex_state = 23},
  [14099] = {.lex_state = 84, .external_lex_state = 57},
  [14100] = {.lex_state = 84, .external_lex_state = 23},
  [14101] = {.lex_state = 84, .external_lex_state = 34},
  [14102] = {.lex_state = 84, .external_lex_state = 57},
  [14103] = {.lex_state = 77, .external_lex_state = 35},
  [14104] = {.lex_state = 76, .external_lex_state = 24},
  [14105] = {.lex_state = 84, .external_lex_state = 57},
  [14106] = {.lex_state = 84, .external_lex_state = 24},
  [14107] = {.lex_state = 84, .external_lex_state = 57},
  [14108] = {.lex_state = 84, .external_lex_state = 57},
  [14109] = {.lex_state = 84, .external_lex_state = 57},
  [14110] = {.lex_state = 84, .external_lex_state = 57},
  [14111] = {.lex_state = 0},
  [14112] = {.lex_state = 84, .external_lex_state = 58},
  [14113] = {.lex_state = 76, .external_lex_state = 23},
  [14114] = {.lex_state = 84, .external_lex_state = 57},
  [14115] = {.lex_state = 84, .external_lex_state = 56},
  [14116] = {.lex_state = 84, .external_lex_state = 58},
  [14117] = {.lex_state = 76, .external_lex_state = 49},
  [14118] = {.lex_state = 0},
  [14119] = {.lex_state = 76, .external_lex_state = 49},
  [14120] = {.lex_state = 84, .external_lex_state = 40},
  [14121] = {.lex_state = 76, .external_lex_state = 49},
  [14122] = {.lex_state = 76, .external_lex_state = 24},
  [14123] = {.lex_state = 77, .external_lex_state = 24},
  [14124] = {.lex_state = 76, .external_lex_state = 24},
  [14125] = {.lex_state = 84, .external_lex_state = 56},
  [14126] = {.lex_state = 84, .external_lex_state = 30},
  [14127] = {.lex_state = 84, .external_lex_state = 55},
  [14128] = {.lex_state = 84, .external_lex_state = 30},
  [14129] = {.lex_state = 84, .external_lex_state = 40},
  [14130] = {.lex_state = 76, .external_lex_state = 24},
  [14131] = {.lex_state = 77, .external_lex_state = 60},
  [14132] = {.lex_state = 0},
  [14133] = {.lex_state = 84, .external_lex_state = 56},
  [14134] = {.lex_state = 0},
  [14135] = {.lex_state = 84, .external_lex_state = 58},
  [14136] = {.lex_state = 0},
  [14137] = {.lex_state = 84, .external_lex_state = 56},
  [14138] = {.lex_state = 76, .external_lex_state = 49},
  [14139] = {.lex_state = 84, .external_lex_state = 30},
  [14140] = {.lex_state = 84, .external_lex_state = 56},
  [14141] = {.lex_state = 84, .external_lex_state = 58},
  [14142] = {.lex_state = 77, .external_lex_state = 60},
  [14143] = {.lex_state = 84, .external_lex_state = 57},
  [14144] = {.lex_state = 84, .external_lex_state = 23},
  [14145] = {.lex_state = 77, .external_lex_state = 60},
  [14146] = {.lex_state = 77, .external_lex_state = 24},
  [14147] = {.lex_state = 76, .external_lex_state = 49},
  [14148] = {.lex_state = 84, .external_lex_state = 40},
  [14149] = {.lex_state = 84, .external_lex_state = 58},
  [14150] = {.lex_state = 0, .external_lex_state = 23},
  [14151] = {.lex_state = 84, .external_lex_state = 58},
  [14152] = {.lex_state = 84, .external_lex_state = 23},
  [14153] = {.lex_state = 84, .external_lex_state = 34},
  [14154] = {.lex_state = 84, .external_lex_state = 57},
  [14155] = {.lex_state = 76, .external_lex_state = 49},
  [14156] = {.lex_state = 84, .external_lex_state = 57},
  [14157] = {.lex_state = 84},
  [14158] = {.lex_state = 84, .external_lex_state = 53},
  [14159] = {.lex_state = 84, .external_lex_state = 57},
  [14160] = {.lex_state = 84, .external_lex_state = 67},
  [14161] = {.lex_state = 84},
  [14162] = {.lex_state = 84, .external_lex_state = 24},
  [14163] = {.lex_state = 84, .external_lex_state = 50},
  [14164] = {.lex_state = 84, .external_lex_state = 45},
  [14165] = {.lex_state = 84, .external_lex_state = 53},
  [14166] = {.lex_state = 84},
  [14167] = {.lex_state = 84, .external_lex_state = 56},
  [14168] = {.lex_state = 84, .external_lex_state = 58},
  [14169] = {.lex_state = 84, .external_lex_state = 40},
  [14170] = {.lex_state = 84, .external_lex_state = 38},
  [14171] = {.lex_state = 84, .external_lex_state = 69},
  [14172] = {.lex_state = 84, .external_lex_state = 30},
  [14173] = {.lex_state = 84, .external_lex_state = 56},
  [14174] = {.lex_state = 84, .external_lex_state = 24},
  [14175] = {.lex_state = 84, .external_lex_state = 24},
  [14176] = {.lex_state = 84, .external_lex_state = 56},
  [14177] = {.lex_state = 84, .external_lex_state = 56},
  [14178] = {.lex_state = 77, .external_lex_state = 60},
  [14179] = {.lex_state = 84, .external_lex_state = 58},
  [14180] = {.lex_state = 84, .external_lex_state = 34},
  [14181] = {.lex_state = 76, .external_lex_state = 24},
  [14182] = {.lex_state = 84, .external_lex_state = 56},
  [14183] = {.lex_state = 84, .external_lex_state = 58},
  [14184] = {.lex_state = 77, .external_lex_state = 60},
  [14185] = {.lex_state = 84, .external_lex_state = 56},
  [14186] = {.lex_state = 84, .external_lex_state = 29},
  [14187] = {.lex_state = 84, .external_lex_state = 58},
  [14188] = {.lex_state = 84, .external_lex_state = 56},
  [14189] = {.lex_state = 77, .external_lex_state = 60},
  [14190] = {.lex_state = 77, .external_lex_state = 66},
  [14191] = {.lex_state = 84, .external_lex_state = 34},
  [14192] = {.lex_state = 76, .external_lex_state = 49},
  [14193] = {.lex_state = 84, .external_lex_state = 58},
  [14194] = {.lex_state = 77, .external_lex_state = 24},
  [14195] = {.lex_state = 76, .external_lex_state = 24},
  [14196] = {.lex_state = 84, .external_lex_state = 40},
  [14197] = {.lex_state = 0},
  [14198] = {.lex_state = 84},
  [14199] = {.lex_state = 76, .external_lex_state = 24},
  [14200] = {.lex_state = 84, .external_lex_state = 56},
  [14201] = {.lex_state = 84, .external_lex_state = 45},
  [14202] = {.lex_state = 84, .external_lex_state = 30},
  [14203] = {.lex_state = 84, .external_lex_state = 58},
  [14204] = {.lex_state = 84, .external_lex_state = 24},
  [14205] = {.lex_state = 76, .external_lex_state = 24},
  [14206] = {.lex_state = 84, .external_lex_state = 53},
  [14207] = {.lex_state = 84, .external_lex_state = 58},
  [14208] = {.lex_state = 84, .external_lex_state = 56},
  [14209] = {.lex_state = 77, .external_lex_state = 35},
  [14210] = {.lex_state = 77, .external_lex_state = 24},
  [14211] = {.lex_state = 84, .external_lex_state = 58},
  [14212] = {.lex_state = 77, .external_lex_state = 50},
  [14213] = {.lex_state = 84, .external_lex_state = 56},
  [14214] = {.lex_state = 84, .external_lex_state = 58},
  [14215] = {.lex_state = 0},
  [14216] = {.lex_state = 84, .external_lex_state = 58},
  [14217] = {.lex_state = 77, .external_lex_state = 24},
  [14218] = {.lex_state = 84, .external_lex_state = 56},
  [14219] = {.lex_state = 84},
  [14220] = {.lex_state = 84, .external_lex_state = 34},
  [14221] = {.lex_state = 84, .external_lex_state = 58},
  [14222] = {.lex_state = 84, .external_lex_state = 45},
  [14223] = {.lex_state = 77, .external_lex_state = 50},
  [14224] = {.lex_state = 77},
  [14225] = {.lex_state = 77, .external_lex_state = 60},
  [14226] = {.lex_state = 77, .external_lex_state = 60},
  [14227] = {.lex_state = 77, .external_lex_state = 60},
  [14228] = {.lex_state = 76, .external_lex_state = 49},
  [14229] = {.lex_state = 84, .external_lex_state = 58},
  [14230] = {.lex_state = 77, .external_lex_state = 24},
  [14231] = {.lex_state = 84, .external_lex_state = 45},
  [14232] = {.lex_state = 77, .external_lex_state = 65},
  [14233] = {.lex_state = 84, .external_lex_state = 34},
  [14234] = {.lex_state = 84, .external_lex_state = 39},
  [14235] = {.lex_state = 84, .external_lex_state = 29},
  [14236] = {.lex_state = 84, .external_lex_state = 56},
  [14237] = {.lex_state = 76},
  [14238] = {.lex_state = 76},
  [14239] = {.lex_state = 84, .external_lex_state = 56},
  [14240] = {.lex_state = 84, .external_lex_state = 56},
  [14241] = {.lex_state = 84, .external_lex_state = 24},
  [14242] = {.lex_state = 76, .external_lex_state = 49},
  [14243] = {.lex_state = 84, .external_lex_state = 29},
  [14244] = {.lex_state = 84, .external_lex_state = 29},
  [14245] = {.lex_state = 84, .external_lex_state = 50},
  [14246] = {.lex_state = 84, .external_lex_state = 40},
  [14247] = {.lex_state = 84, .external_lex_state = 40},
  [14248] = {.lex_state = 76, .external_lex_state = 23},
  [14249] = {.lex_state = 76, .external_lex_state = 23},
  [14250] = {.lex_state = 84, .external_lex_state = 56},
  [14251] = {.lex_state = 84, .external_lex_state = 23},
  [14252] = {.lex_state = 84, .external_lex_state = 58},
  [14253] = {.lex_state = 76, .external_lex_state = 49},
  [14254] = {.lex_state = 84, .external_lex_state = 56},
  [14255] = {.lex_state = 84, .external_lex_state = 30},
  [14256] = {.lex_state = 84, .external_lex_state = 34},
  [14257] = {.lex_state = 84, .external_lex_state = 30},
  [14258] = {.lex_state = 84, .external_lex_state = 24},
  [14259] = {.lex_state = 84, .external_lex_state = 24},
  [14260] = {.lex_state = 84, .external_lex_state = 35},
  [14261] = {.lex_state = 76, .external_lex_state = 24},
  [14262] = {.lex_state = 84, .external_lex_state = 58},
  [14263] = {.lex_state = 84, .external_lex_state = 58},
  [14264] = {.lex_state = 84, .external_lex_state = 23},
  [14265] = {.lex_state = 84, .external_lex_state = 56},
  [14266] = {.lex_state = 84, .external_lex_state = 58},
  [14267] = {.lex_state = 84, .external_lex_state = 56},
  [14268] = {.lex_state = 84},
  [14269] = {.lex_state = 84, .external_lex_state = 40},
  [14270] = {.lex_state = 76, .external_lex_state = 49},
  [14271] = {.lex_state = 84, .external_lex_state = 24},
  [14272] = {.lex_state = 84, .external_lex_state = 39},
  [14273] = {.lex_state = 84, .external_lex_state = 56},
  [14274] = {.lex_state = 84, .external_lex_state = 58},
  [14275] = {.lex_state = 84, .external_lex_state = 24},
  [14276] = {.lex_state = 84, .external_lex_state = 24},
  [14277] = {.lex_state = 84, .external_lex_state = 23},
  [14278] = {.lex_state = 76, .external_lex_state = 24},
  [14279] = {.lex_state = 0, .external_lex_state = 23},
  [14280] = {.lex_state = 76, .external_lex_state = 23},
  [14281] = {.lex_state = 84, .external_lex_state = 23},
  [14282] = {.lex_state = 77, .external_lex_state = 24},
  [14283] = {.lex_state = 84, .external_lex_state = 23},
  [14284] = {.lex_state = 84, .external_lex_state = 39},
  [14285] = {.lex_state = 84, .external_lex_state = 39},
  [14286] = {.lex_state = 77, .external_lex_state = 70},
  [14287] = {.lex_state = 84, .external_lex_state = 55},
  [14288] = {.lex_state = 84},
  [14289] = {.lex_state = 84, .external_lex_state = 40},
  [14290] = {.lex_state = 84, .external_lex_state = 40},
  [14291] = {.lex_state = 76, .external_lex_state = 23},
  [14292] = {.lex_state = 84, .external_lex_state = 24},
  [14293] = {.lex_state = 84, .external_lex_state = 57},
  [14294] = {.lex_state = 84, .external_lex_state = 57},
  [14295] = {.lex_state = 84, .external_lex_state = 45},
  [14296] = {.lex_state = 76, .external_lex_state = 23},
  [14297] = {.lex_state = 84, .external_lex_state = 40},
  [14298] = {.lex_state = 77, .external_lex_state = 70},
  [14299] = {.lex_state = 84},
  [14300] = {.lex_state = 84, .external_lex_state = 35},
  [14301] = {.lex_state = 84, .external_lex_state = 38},
  [14302] = {.lex_state = 84, .external_lex_state = 40},
  [14303] = {.lex_state = 84, .external_lex_state = 40},
  [14304] = {.lex_state = 84, .external_lex_state = 67},
  [14305] = {.lex_state = 84, .external_lex_state = 39},
  [14306] = {.lex_state = 77, .external_lex_state = 65},
  [14307] = {.lex_state = 84, .external_lex_state = 45},
  [14308] = {.lex_state = 77, .external_lex_state = 65},
  [14309] = {.lex_state = 84, .external_lex_state = 34},
  [14310] = {.lex_state = 84, .external_lex_state = 40},
  [14311] = {.lex_state = 84, .external_lex_state = 24},
  [14312] = {.lex_state = 84, .external_lex_state = 24},
  [14313] = {.lex_state = 84, .external_lex_state = 24},
  [14314] = {.lex_state = 84},
  [14315] = {.lex_state = 77, .external_lex_state = 65},
  [14316] = {.lex_state = 84, .external_lex_state = 57},
  [14317] = {.lex_state = 84, .external_lex_state = 34},
  [14318] = {.lex_state = 84, .external_lex_state = 38},
  [14319] = {.lex_state = 84, .external_lex_state = 24},
  [14320] = {.lex_state = 84, .external_lex_state = 40},
  [14321] = {.lex_state = 84, .external_lex_state = 39},
  [14322] = {.lex_state = 84, .external_lex_state = 38},
  [14323] = {.lex_state = 84, .external_lex_state = 57},
  [14324] = {.lex_state = 76, .external_lex_state = 23},
  [14325] = {.lex_state = 84, .external_lex_state = 38},
  [14326] = {.lex_state = 84, .external_lex_state = 57},
  [14327] = {.lex_state = 84, .external_lex_state = 69},
  [14328] = {.lex_state = 84, .external_lex_state = 38},
  [14329] = {.lex_state = 84, .external_lex_state = 34},
  [14330] = {.lex_state = 84, .external_lex_state = 57},
  [14331] = {.lex_state = 76, .external_lex_state = 23},
  [14332] = {.lex_state = 84},
  [14333] = {.lex_state = 84, .external_lex_state = 24},
  [14334] = {.lex_state = 84, .external_lex_state = 57},
  [14335] = {.lex_state = 77, .external_lex_state = 70},
  [14336] = {.lex_state = 84, .external_lex_state = 55},
  [14337] = {.lex_state = 77, .external_lex_state = 65},
  [14338] = {.lex_state = 84, .external_lex_state = 35},
  [14339] = {.lex_state = 84, .external_lex_state = 39},
  [14340] = {.lex_state = 84, .external_lex_state = 39},
  [14341] = {.lex_state = 84, .external_lex_state = 39},
  [14342] = {.lex_state = 84, .external_lex_state = 55},
  [14343] = {.lex_state = 76, .external_lex_state = 24},
  [14344] = {.lex_state = 77, .external_lex_state = 70},
  [14345] = {.lex_state = 76, .external_lex_state = 23},
  [14346] = {.lex_state = 84, .external_lex_state = 57},
  [14347] = {.lex_state = 84},
  [14348] = {.lex_state = 84, .external_lex_state = 24},
  [14349] = {.lex_state = 84, .external_lex_state = 38},
  [14350] = {.lex_state = 84, .external_lex_state = 38},
  [14351] = {.lex_state = 84, .external_lex_state = 24},
  [14352] = {.lex_state = 77, .external_lex_state = 65},
  [14353] = {.lex_state = 84, .external_lex_state = 35},
  [14354] = {.lex_state = 84, .external_lex_state = 23},
  [14355] = {.lex_state = 76, .external_lex_state = 23},
  [14356] = {.lex_state = 84, .external_lex_state = 24},
  [14357] = {.lex_state = 84, .external_lex_state = 24},
  [14358] = {.lex_state = 84, .external_lex_state = 34},
  [14359] = {.lex_state = 77, .external_lex_state = 65},
  [14360] = {.lex_state = 77, .external_lex_state = 24},
  [14361] = {.lex_state = 84, .external_lex_state = 23},
  [14362] = {.lex_state = 84, .external_lex_state = 69},
  [14363] = {.lex_state = 84, .external_lex_state = 23},
  [14364] = {.lex_state = 0, .external_lex_state = 23},
  [14365] = {.lex_state = 84, .external_lex_state = 50},
  [14366] = {.lex_state = 84, .external_lex_state = 55},
  [14367] = {.lex_state = 0, .external_lex_state = 23},
  [14368] = {.lex_state = 84, .external_lex_state = 23},
  [14369] = {.lex_state = 84, .external_lex_state = 24},
  [14370] = {.lex_state = 84, .external_lex_state = 23},
  [14371] = {.lex_state = 84, .external_lex_state = 55},
  [14372] = {.lex_state = 84, .external_lex_state = 45},
  [14373] = {.lex_state = 84, .external_lex_state = 24},
  [14374] = {.lex_state = 84},
  [14375] = {.lex_state = 84, .external_lex_state = 24},
  [14376] = {.lex_state = 84, .external_lex_state = 51},
  [14377] = {.lex_state = 84, .external_lex_state = 69},
  [14378] = {.lex_state = 84, .external_lex_state = 40},
  [14379] = {.lex_state = 84, .external_lex_state = 51},
  [14380] = {.lex_state = 84, .external_lex_state = 24},
  [14381] = {.lex_state = 77, .external_lex_state = 65},
  [14382] = {.lex_state = 84},
  [14383] = {.lex_state = 84, .external_lex_state = 67},
  [14384] = {.lex_state = 84, .external_lex_state = 38},
  [14385] = {.lex_state = 84, .external_lex_state = 24},
  [14386] = {.lex_state = 84},
  [14387] = {.lex_state = 84},
  [14388] = {.lex_state = 84, .external_lex_state = 55},
  [14389] = {.lex_state = 84, .external_lex_state = 24},
  [14390] = {.lex_state = 76, .external_lex_state = 24},
  [14391] = {.lex_state = 84, .external_lex_state = 24},
  [14392] = {.lex_state = 77, .external_lex_state = 68},
  [14393] = {.lex_state = 84},
  [14394] = {.lex_state = 76, .external_lex_state = 23},
  [14395] = {.lex_state = 84, .external_lex_state = 24},
  [14396] = {.lex_state = 84, .external_lex_state = 50},
  [14397] = {.lex_state = 84},
  [14398] = {.lex_state = 76, .external_lex_state = 24},
  [14399] = {.lex_state = 84},
  [14400] = {.lex_state = 76, .external_lex_state = 23},
  [14401] = {.lex_state = 84, .external_lex_state = 38},
  [14402] = {.lex_state = 84, .external_lex_state = 56},
  [14403] = {.lex_state = 84, .external_lex_state = 58},
  [14404] = {.lex_state = 84, .external_lex_state = 24},
  [14405] = {.lex_state = 84, .external_lex_state = 50},
  [14406] = {.lex_state = 84, .external_lex_state = 24},
  [14407] = {.lex_state = 84, .external_lex_state = 24},
  [14408] = {.lex_state = 84, .external_lex_state = 24},
  [14409] = {.lex_state = 84, .external_lex_state = 24},
  [14410] = {.lex_state = 84, .external_lex_state = 24},
  [14411] = {.lex_state = 76, .external_lex_state = 23},
  [14412] = {.lex_state = 84, .external_lex_state = 24},
  [14413] = {.lex_state = 84, .external_lex_state = 40},
  [14414] = {.lex_state = 84, .external_lex_state = 45},
  [14415] = {.lex_state = 84},
  [14416] = {.lex_state = 84, .external_lex_state = 38},
  [14417] = {.lex_state = 84, .external_lex_state = 24},
  [14418] = {.lex_state = 84, .external_lex_state = 40},
  [14419] = {.lex_state = 84},
  [14420] = {.lex_state = 84},
  [14421] = {.lex_state = 84, .external_lex_state = 51},
  [14422] = {.lex_state = 84, .external_lex_state = 58},
  [14423] = {.lex_state = 84, .external_lex_state = 67},
  [14424] = {.lex_state = 84},
  [14425] = {.lex_state = 84, .external_lex_state = 39},
  [14426] = {.lex_state = 84, .external_lex_state = 23},
  [14427] = {.lex_state = 76, .external_lex_state = 24},
  [14428] = {.lex_state = 76, .external_lex_state = 24},
  [14429] = {.lex_state = 84},
  [14430] = {.lex_state = 84},
  [14431] = {.lex_state = 84, .external_lex_state = 51},
  [14432] = {.lex_state = 84},
  [14433] = {.lex_state = 84, .external_lex_state = 35},
  [14434] = {.lex_state = 77, .external_lex_state = 65},
  [14435] = {.lex_state = 0, .external_lex_state = 24},
  [14436] = {.lex_state = 84},
  [14437] = {.lex_state = 76, .external_lex_state = 24},
  [14438] = {.lex_state = 76, .external_lex_state = 49},
  [14439] = {.lex_state = 84, .external_lex_state = 45},
  [14440] = {.lex_state = 84, .external_lex_state = 45},
  [14441] = {.lex_state = 84},
  [14442] = {.lex_state = 84, .external_lex_state = 50},
  [14443] = {.lex_state = 84, .external_lex_state = 50},
  [14444] = {.lex_state = 84, .external_lex_state = 24},
  [14445] = {.lex_state = 84},
  [14446] = {.lex_state = 84},
  [14447] = {.lex_state = 0, .external_lex_state = 24},
  [14448] = {.lex_state = 84, .external_lex_state = 24},
  [14449] = {.lex_state = 84, .external_lex_state = 24},
  [14450] = {.lex_state = 77, .external_lex_state = 65},
  [14451] = {.lex_state = 77, .external_lex_state = 65},
  [14452] = {.lex_state = 0, .external_lex_state = 23},
  [14453] = {.lex_state = 84},
  [14454] = {.lex_state = 77},
  [14455] = {.lex_state = 77},
  [14456] = {.lex_state = 84},
  [14457] = {.lex_state = 84, .external_lex_state = 45},
  [14458] = {.lex_state = 77},
  [14459] = {.lex_state = 84, .external_lex_state = 50},
  [14460] = {.lex_state = 84},
  [14461] = {.lex_state = 0, .external_lex_state = 24},
  [14462] = {.lex_state = 76, .external_lex_state = 23},
  [14463] = {.lex_state = 76, .external_lex_state = 23},
  [14464] = {.lex_state = 76, .external_lex_state = 23},
  [14465] = {.lex_state = 76, .external_lex_state = 23},
  [14466] = {.lex_state = 84, .external_lex_state = 45},
  [14467] = {.lex_state = 76, .external_lex_state = 24},
  [14468] = {.lex_state = 84, .external_lex_state = 50},
  [14469] = {.lex_state = 77, .external_lex_state = 65},
  [14470] = {.lex_state = 76, .external_lex_state = 23},
  [14471] = {.lex_state = 84, .external_lex_state = 40},
  [14472] = {.lex_state = 84},
  [14473] = {.lex_state = 0, .external_lex_state = 23},
  [14474] = {.lex_state = 0, .external_lex_state = 23},
  [14475] = {.lex_state = 0, .external_lex_state = 23},
  [14476] = {.lex_state = 77, .external_lex_state = 65},
  [14477] = {.lex_state = 9},
  [14478] = {.lex_state = 84, .external_lex_state = 35},
  [14479] = {.lex_state = 0, .external_lex_state = 23},
  [14480] = {.lex_state = 84, .external_lex_state = 45},
  [14481] = {.lex_state = 84, .external_lex_state = 23},
  [14482] = {.lex_state = 0, .external_lex_state = 24},
  [14483] = {.lex_state = 84, .external_lex_state = 45},
  [14484] = {.lex_state = 84, .external_lex_state = 23},
  [14485] = {.lex_state = 77, .external_lex_state = 65},
  [14486] = {.lex_state = 84, .external_lex_state = 24},
  [14487] = {.lex_state = 84, .external_lex_state = 24},
  [14488] = {.lex_state = 77, .external_lex_state = 65},
  [14489] = {.lex_state = 84, .external_lex_state = 50},
  [14490] = {.lex_state = 9},
  [14491] = {.lex_state = 84, .external_lex_state = 40},
  [14492] = {.lex_state = 84, .external_lex_state = 35},
  [14493] = {.lex_state = 84, .external_lex_state = 50},
  [14494] = {.lex_state = 84, .external_lex_state = 40},
  [14495] = {.lex_state = 84, .external_lex_state = 50},
  [14496] = {.lex_state = 84, .external_lex_state = 35},
  [14497] = {.lex_state = 76, .external_lex_state = 23},
  [14498] = {.lex_state = 84, .external_lex_state = 40},
  [14499] = {.lex_state = 84, .external_lex_state = 23},
  [14500] = {.lex_state = 0, .external_lex_state = 23},
  [14501] = {.lex_state = 84, .external_lex_state = 50},
  [14502] = {.lex_state = 84, .external_lex_state = 50},
  [14503] = {.lex_state = 84, .external_lex_state = 40},
  [14504] = {.lex_state = 84},
  [14505] = {.lex_state = 77},
  [14506] = {.lex_state = 84, .external_lex_state = 57},
  [14507] = {.lex_state = 84, .external_lex_state = 23},
  [14508] = {.lex_state = 84},
  [14509] = {.lex_state = 84},
  [14510] = {.lex_state = 84},
  [14511] = {.lex_state = 84},
  [14512] = {.lex_state = 77, .external_lex_state = 71},
  [14513] = {.lex_state = 84, .external_lex_state = 24},
  [14514] = {.lex_state = 84, .external_lex_state = 69},
  [14515] = {.lex_state = 84},
  [14516] = {.lex_state = 76, .external_lex_state = 24},
  [14517] = {.lex_state = 77, .external_lex_state = 65},
  [14518] = {.lex_state = 84},
  [14519] = {.lex_state = 84},
  [14520] = {.lex_state = 84, .external_lex_state = 35},
  [14521] = {.lex_state = 84, .external_lex_state = 45},
  [14522] = {.lex_state = 84, .external_lex_state = 45},
  [14523] = {.lex_state = 84},
  [14524] = {.lex_state = 76, .external_lex_state = 23},
  [14525] = {.lex_state = 76},
  [14526] = {.lex_state = 84, .external_lex_state = 35},
  [14527] = {.lex_state = 84, .external_lex_state = 23},
  [14528] = {.lex_state = 84},
  [14529] = {.lex_state = 76, .external_lex_state = 23},
  [14530] = {.lex_state = 76, .external_lex_state = 23},
  [14531] = {.lex_state = 84, .external_lex_state = 23},
  [14532] = {.lex_state = 84, .external_lex_state = 35},
  [14533] = {.lex_state = 84},
  [14534] = {.lex_state = 77, .external_lex_state = 65},
  [14535] = {.lex_state = 77, .external_lex_state = 65},
  [14536] = {.lex_state = 76, .external_lex_state = 49},
  [14537] = {.lex_state = 84, .external_lex_state = 50},
  [14538] = {.lex_state = 84, .external_lex_state = 67},
  [14539] = {.lex_state = 0, .external_lex_state = 23},
  [14540] = {.lex_state = 77, .external_lex_state = 71},
  [14541] = {.lex_state = 84, .external_lex_state = 23},
  [14542] = {.lex_state = 84, .external_lex_state = 23},
  [14543] = {.lex_state = 84, .external_lex_state = 35},
  [14544] = {.lex_state = 84, .external_lex_state = 23},
  [14545] = {.lex_state = 84, .external_lex_state = 24},
  [14546] = {.lex_state = 76, .external_lex_state = 49},
  [14547] = {.lex_state = 84, .external_lex_state = 55},
  [14548] = {.lex_state = 84, .external_lex_state = 23},
  [14549] = {.lex_state = 84, .external_lex_state = 24},
  [14550] = {.lex_state = 77, .external_lex_state = 65},
  [14551] = {.lex_state = 84, .external_lex_state = 35},
  [14552] = {.lex_state = 84},
  [14553] = {.lex_state = 84, .external_lex_state = 23},
  [14554] = {.lex_state = 76, .external_lex_state = 49},
  [14555] = {.lex_state = 84, .external_lex_state = 23},
  [14556] = {.lex_state = 0},
  [14557] = {.lex_state = 76, .external_lex_state = 23},
  [14558] = {.lex_state = 76, .external_lex_state = 24},
  [14559] = {.lex_state = 84, .external_lex_state = 24},
  [14560] = {.lex_state = 84},
  [14561] = {.lex_state = 77, .external_lex_state = 65},
  [14562] = {.lex_state = 84, .external_lex_state = 55},
  [14563] = {.lex_state = 77, .external_lex_state = 71},
  [14564] = {.lex_state = 76, .external_lex_state = 24},
  [14565] = {.lex_state = 76, .external_lex_state = 23},
  [14566] = {.lex_state = 84},
  [14567] = {.lex_state = 84},
  [14568] = {.lex_state = 77, .external_lex_state = 65},
  [14569] = {.lex_state = 84, .external_lex_state = 23},
  [14570] = {.lex_state = 84, .external_lex_state = 23},
  [14571] = {.lex_state = 84},
  [14572] = {.lex_state = 84},
  [14573] = {.lex_state = 77, .external_lex_state = 65},
  [14574] = {.lex_state = 84, .external_lex_state = 57},
  [14575] = {.lex_state = 77, .external_lex_state = 65},
  [14576] = {.lex_state = 0, .external_lex_state = 23},
  [14577] = {.lex_state = 76},
  [14578] = {.lex_state = 76},
  [14579] = {.lex_state = 84},
  [14580] = {.lex_state = 84, .external_lex_state = 35},
  [14581] = {.lex_state = 84, .external_lex_state = 50},
  [14582] = {.lex_state = 76},
  [14583] = {.lex_state = 84},
  [14584] = {.lex_state = 84, .external_lex_state = 35},
  [14585] = {.lex_state = 76, .external_lex_state = 23},
  [14586] = {.lex_state = 84, .external_lex_state = 35},
  [14587] = {.lex_state = 84, .external_lex_state = 23},
  [14588] = {.lex_state = 0, .external_lex_state = 23},
  [14589] = {.lex_state = 84, .external_lex_state = 23},
  [14590] = {.lex_state = 84, .external_lex_state = 50},
  [14591] = {.lex_state = 84, .external_lex_state = 23},
  [14592] = {.lex_state = 84, .external_lex_state = 40},
  [14593] = {.lex_state = 84, .external_lex_state = 23},
  [14594] = {.lex_state = 76, .external_lex_state = 49},
  [14595] = {.lex_state = 84, .external_lex_state = 23},
  [14596] = {.lex_state = 0, .external_lex_state = 23},
  [14597] = {.lex_state = 84},
  [14598] = {.lex_state = 84, .external_lex_state = 23},
  [14599] = {.lex_state = 0},
  [14600] = {.lex_state = 76, .external_lex_state = 49},
  [14601] = {.lex_state = 84, .external_lex_state = 23},
  [14602] = {.lex_state = 0},
  [14603] = {.lex_state = 0, .external_lex_state = 24},
  [14604] = {.lex_state = 84, .external_lex_state = 23},
  [14605] = {.lex_state = 84, .external_lex_state = 23},
  [14606] = {.lex_state = 84, .external_lex_state = 23},
  [14607] = {.lex_state = 0},
  [14608] = {.lex_state = 84, .external_lex_state = 23},
  [14609] = {.lex_state = 84, .external_lex_state = 23},
  [14610] = {.lex_state = 84, .external_lex_state = 23},
  [14611] = {.lex_state = 0},
  [14612] = {.lex_state = 84, .external_lex_state = 24},
  [14613] = {.lex_state = 0},
  [14614] = {.lex_state = 77, .external_lex_state = 71},
  [14615] = {.lex_state = 84, .external_lex_state = 23},
  [14616] = {.lex_state = 84, .external_lex_state = 58},
  [14617] = {.lex_state = 0},
  [14618] = {.lex_state = 76, .external_lex_state = 24},
  [14619] = {.lex_state = 0},
  [14620] = {.lex_state = 84, .external_lex_state = 23},
  [14621] = {.lex_state = 0},
  [14622] = {.lex_state = 84, .external_lex_state = 23},
  [14623] = {.lex_state = 0},
  [14624] = {.lex_state = 0},
  [14625] = {.lex_state = 84, .external_lex_state = 23},
  [14626] = {.lex_state = 77, .external_lex_state = 71},
  [14627] = {.lex_state = 0},
  [14628] = {.lex_state = 0},
  [14629] = {.lex_state = 84, .external_lex_state = 23},
  [14630] = {.lex_state = 76, .external_lex_state = 24},
  [14631] = {.lex_state = 0},
  [14632] = {.lex_state = 84, .external_lex_state = 23},
  [14633] = {.lex_state = 84, .external_lex_state = 23},
  [14634] = {.lex_state = 84, .external_lex_state = 23},
  [14635] = {.lex_state = 84, .external_lex_state = 23},
  [14636] = {.lex_state = 84, .external_lex_state = 24},
  [14637] = {.lex_state = 77, .external_lex_state = 71},
  [14638] = {.lex_state = 0},
  [14639] = {.lex_state = 84, .external_lex_state = 23},
  [14640] = {.lex_state = 0},
  [14641] = {.lex_state = 0},
  [14642] = {.lex_state = 84, .external_lex_state = 23},
  [14643] = {.lex_state = 84, .external_lex_state = 23},
  [14644] = {.lex_state = 84, .external_lex_state = 23},
  [14645] = {.lex_state = 84, .external_lex_state = 23},
  [14646] = {.lex_state = 0},
  [14647] = {.lex_state = 76, .external_lex_state = 24},
  [14648] = {.lex_state = 76, .external_lex_state = 24},
  [14649] = {.lex_state = 0},
  [14650] = {.lex_state = 84, .external_lex_state = 23},
  [14651] = {.lex_state = 0},
  [14652] = {.lex_state = 0},
  [14653] = {.lex_state = 76, .external_lex_state = 23},
  [14654] = {.lex_state = 84},
  [14655] = {.lex_state = 77, .external_lex_state = 71},
  [14656] = {.lex_state = 84, .external_lex_state = 23},
  [14657] = {.lex_state = 0},
  [14658] = {.lex_state = 84, .external_lex_state = 51},
  [14659] = {.lex_state = 84, .external_lex_state = 23},
  [14660] = {.lex_state = 77, .external_lex_state = 65},
  [14661] = {.lex_state = 84, .external_lex_state = 67},
  [14662] = {.lex_state = 84, .external_lex_state = 51},
  [14663] = {.lex_state = 0},
  [14664] = {.lex_state = 84, .external_lex_state = 23},
  [14665] = {.lex_state = 84, .external_lex_state = 69},
  [14666] = {.lex_state = 0},
  [14667] = {.lex_state = 0, .external_lex_state = 23},
  [14668] = {.lex_state = 0},
  [14669] = {.lex_state = 0},
  [14670] = {.lex_state = 84, .external_lex_state = 23},
  [14671] = {.lex_state = 76, .external_lex_state = 24},
  [14672] = {.lex_state = 76, .external_lex_state = 23},
  [14673] = {.lex_state = 0},
  [14674] = {.lex_state = 84, .external_lex_state = 67},
  [14675] = {.lex_state = 0, .external_lex_state = 23},
  [14676] = {.lex_state = 76, .external_lex_state = 24},
  [14677] = {.lex_state = 84, .external_lex_state = 67},
  [14678] = {.lex_state = 0},
  [14679] = {.lex_state = 84, .external_lex_state = 23},
  [14680] = {.lex_state = 0},
  [14681] = {.lex_state = 84, .external_lex_state = 23},
  [14682] = {.lex_state = 0, .external_lex_state = 24},
  [14683] = {.lex_state = 0, .external_lex_state = 24},
  [14684] = {.lex_state = 0},
  [14685] = {.lex_state = 0, .external_lex_state = 24},
  [14686] = {.lex_state = 84, .external_lex_state = 23},
  [14687] = {.lex_state = 84, .external_lex_state = 23},
  [14688] = {.lex_state = 77, .external_lex_state = 71},
  [14689] = {.lex_state = 0},
  [14690] = {.lex_state = 0},
  [14691] = {.lex_state = 84, .external_lex_state = 51},
  [14692] = {.lex_state = 84, .external_lex_state = 58},
  [14693] = {.lex_state = 84, .external_lex_state = 23},
  [14694] = {.lex_state = 0},
  [14695] = {.lex_state = 0},
  [14696] = {.lex_state = 84, .external_lex_state = 69},
  [14697] = {.lex_state = 84, .external_lex_state = 51},
  [14698] = {.lex_state = 0},
  [14699] = {.lex_state = 0},
  [14700] = {.lex_state = 0, .external_lex_state = 23},
  [14701] = {.lex_state = 84, .external_lex_state = 24},
  [14702] = {.lex_state = 84, .external_lex_state = 58},
  [14703] = {.lex_state = 0},
  [14704] = {.lex_state = 84, .external_lex_state = 24},
  [14705] = {.lex_state = 0},
  [14706] = {.lex_state = 77, .external_lex_state = 71},
  [14707] = {.lex_state = 84, .external_lex_state = 24},
  [14708] = {.lex_state = 0},
  [14709] = {.lex_state = 84, .external_lex_state = 51},
  [14710] = {.lex_state = 77},
  [14711] = {.lex_state = 76, .external_lex_state = 23},
  [14712] = {.lex_state = 84, .external_lex_state = 51},
  [14713] = {.lex_state = 84, .external_lex_state = 51},
  [14714] = {.lex_state = 77, .external_lex_state = 71},
  [14715] = {.lex_state = 0, .external_lex_state = 24},
  [14716] = {.lex_state = 84, .external_lex_state = 23},
  [14717] = {.lex_state = 84, .external_lex_state = 23},
  [14718] = {.lex_state = 0},
  [14719] = {.lex_state = 0},
  [14720] = {.lex_state = 84, .external_lex_state = 23},
  [14721] = {.lex_state = 84, .external_lex_state = 67},
  [14722] = {.lex_state = 0},
  [14723] = {.lex_state = 84, .external_lex_state = 23},
  [14724] = {.lex_state = 77, .external_lex_state = 71},
  [14725] = {.lex_state = 84, .external_lex_state = 23},
  [14726] = {.lex_state = 0},
  [14727] = {.lex_state = 84, .external_lex_state = 69},
  [14728] = {.lex_state = 84, .external_lex_state = 23},
  [14729] = {.lex_state = 84, .external_lex_state = 23},
  [14730] = {.lex_state = 0},
  [14731] = {.lex_state = 77, .external_lex_state = 49},
  [14732] = {.lex_state = 84, .external_lex_state = 23},
  [14733] = {.lex_state = 76, .external_lex_state = 24},
  [14734] = {.lex_state = 84, .external_lex_state = 23},
  [14735] = {.lex_state = 84, .external_lex_state = 23},
  [14736] = {.lex_state = 84, .external_lex_state = 23},
  [14737] = {.lex_state = 84, .external_lex_state = 24},
  [14738] = {.lex_state = 84, .external_lex_state = 23},
  [14739] = {.lex_state = 76, .external_lex_state = 24},
  [14740] = {.lex_state = 84, .external_lex_state = 23},
  [14741] = {.lex_state = 77, .external_lex_state = 71},
  [14742] = {.lex_state = 84, .external_lex_state = 51},
  [14743] = {.lex_state = 84, .external_lex_state = 23},
  [14744] = {.lex_state = 84, .external_lex_state = 24},
  [14745] = {.lex_state = 84, .external_lex_state = 23},
  [14746] = {.lex_state = 77, .external_lex_state = 71},
  [14747] = {.lex_state = 84, .external_lex_state = 69},
  [14748] = {.lex_state = 84, .external_lex_state = 23},
  [14749] = {.lex_state = 84, .external_lex_state = 23},
  [14750] = {.lex_state = 84, .external_lex_state = 23},
  [14751] = {.lex_state = 84, .external_lex_state = 23},
  [14752] = {.lex_state = 0},
  [14753] = {.lex_state = 84},
  [14754] = {.lex_state = 0},
  [14755] = {.lex_state = 0},
  [14756] = {.lex_state = 0, .external_lex_state = 23},
  [14757] = {.lex_state = 0},
  [14758] = {.lex_state = 0, .external_lex_state = 23},
  [14759] = {.lex_state = 0, .external_lex_state = 23},
  [14760] = {.lex_state = 77, .external_lex_state = 24},
  [14761] = {.lex_state = 77, .external_lex_state = 71},
  [14762] = {.lex_state = 84, .external_lex_state = 67},
  [14763] = {.lex_state = 84, .external_lex_state = 24},
  [14764] = {.lex_state = 84, .external_lex_state = 23},
  [14765] = {.lex_state = 0},
  [14766] = {.lex_state = 0, .external_lex_state = 23},
  [14767] = {.lex_state = 0},
  [14768] = {.lex_state = 0},
  [14769] = {.lex_state = 84, .external_lex_state = 58},
  [14770] = {.lex_state = 84, .external_lex_state = 24},
  [14771] = {.lex_state = 0},
  [14772] = {.lex_state = 84, .external_lex_state = 24},
  [14773] = {.lex_state = 0},
  [14774] = {.lex_state = 84, .external_lex_state = 69},
  [14775] = {.lex_state = 0},
  [14776] = {.lex_state = 0},
  [14777] = {.lex_state = 0},
  [14778] = {.lex_state = 84},
  [14779] = {.lex_state = 84},
  [14780] = {.lex_state = 84, .external_lex_state = 23},
  [14781] = {.lex_state = 84, .external_lex_state = 67},
  [14782] = {.lex_state = 0, .external_lex_state = 23},
  [14783] = {.lex_state = 77, .external_lex_state = 71},
  [14784] = {.lex_state = 84, .external_lex_state = 23},
  [14785] = {.lex_state = 84, .external_lex_state = 23},
  [14786] = {.lex_state = 84, .external_lex_state = 23},
  [14787] = {.lex_state = 84, .external_lex_state = 23},
  [14788] = {.lex_state = 84, .external_lex_state = 23},
  [14789] = {.lex_state = 84},
  [14790] = {.lex_state = 84, .external_lex_state = 69},
  [14791] = {.lex_state = 77, .external_lex_state = 71},
  [14792] = {.lex_state = 0},
  [14793] = {.lex_state = 84, .external_lex_state = 23},
  [14794] = {.lex_state = 0},
  [14795] = {.lex_state = 0},
  [14796] = {.lex_state = 0},
  [14797] = {.lex_state = 84, .external_lex_state = 23},
  [14798] = {.lex_state = 77, .external_lex_state = 71},
  [14799] = {.lex_state = 76, .external_lex_state = 23},
  [14800] = {.lex_state = 0},
  [14801] = {.lex_state = 84, .external_lex_state = 23},
  [14802] = {.lex_state = 84, .external_lex_state = 23},
  [14803] = {.lex_state = 0},
  [14804] = {.lex_state = 84},
  [14805] = {.lex_state = 84, .external_lex_state = 23},
  [14806] = {.lex_state = 0},
  [14807] = {.lex_state = 0},
  [14808] = {.lex_state = 84, .external_lex_state = 23},
  [14809] = {.lex_state = 77, .external_lex_state = 71},
  [14810] = {.lex_state = 84},
  [14811] = {.lex_state = 0},
  [14812] = {.lex_state = 84, .external_lex_state = 23},
  [14813] = {.lex_state = 0},
  [14814] = {.lex_state = 0},
  [14815] = {.lex_state = 84, .external_lex_state = 23},
  [14816] = {.lex_state = 84, .external_lex_state = 23},
  [14817] = {.lex_state = 0},
  [14818] = {.lex_state = 84},
  [14819] = {.lex_state = 84, .external_lex_state = 23},
  [14820] = {.lex_state = 84},
  [14821] = {.lex_state = 84},
  [14822] = {.lex_state = 77, .external_lex_state = 71},
  [14823] = {.lex_state = 84, .external_lex_state = 23},
  [14824] = {.lex_state = 77, .external_lex_state = 71},
  [14825] = {.lex_state = 0},
  [14826] = {.lex_state = 77, .external_lex_state = 71},
  [14827] = {.lex_state = 0, .external_lex_state = 23},
  [14828] = {.lex_state = 77, .external_lex_state = 71},
  [14829] = {.lex_state = 0},
  [14830] = {.lex_state = 0},
  [14831] = {.lex_state = 84},
  [14832] = {.lex_state = 84, .external_lex_state = 24},
  [14833] = {.lex_state = 0, .external_lex_state = 24},
  [14834] = {.lex_state = 0},
  [14835] = {.lex_state = 84},
  [14836] = {.lex_state = 0},
  [14837] = {.lex_state = 0},
  [14838] = {.lex_state = 77},
  [14839] = {.lex_state = 84, .external_lex_state = 67},
  [14840] = {.lex_state = 84, .external_lex_state = 23},
  [14841] = {.lex_state = 0},
  [14842] = {.lex_state = 0},
  [14843] = {.lex_state = 84, .external_lex_state = 23},
  [14844] = {.lex_state = 76, .external_lex_state = 24},
  [14845] = {.lex_state = 84, .external_lex_state = 69},
  [14846] = {.lex_state = 0},
  [14847] = {.lex_state = 84, .external_lex_state = 23},
  [14848] = {.lex_state = 84, .external_lex_state = 23},
  [14849] = {.lex_state = 84, .external_lex_state = 23},
  [14850] = {.lex_state = 0},
  [14851] = {.lex_state = 77, .external_lex_state = 71},
  [14852] = {.lex_state = 84, .external_lex_state = 23},
  [14853] = {.lex_state = 84},
  [14854] = {.lex_state = 76},
  [14855] = {.lex_state = 0, .external_lex_state = 24},
  [14856] = {.lex_state = 0, .external_lex_state = 25},
  [14857] = {.lex_state = 84, .external_lex_state = 24},
  [14858] = {.lex_state = 84, .external_lex_state = 24},
  [14859] = {.lex_state = 84, .external_lex_state = 24},
  [14860] = {.lex_state = 0, .external_lex_state = 25},
  [14861] = {.lex_state = 84},
  [14862] = {.lex_state = 84, .external_lex_state = 64},
  [14863] = {.lex_state = 84, .external_lex_state = 24},
  [14864] = {.lex_state = 84},
  [14865] = {.lex_state = 84, .external_lex_state = 24},
  [14866] = {.lex_state = 84},
  [14867] = {.lex_state = 84, .external_lex_state = 64},
  [14868] = {.lex_state = 84},
  [14869] = {.lex_state = 84},
  [14870] = {.lex_state = 84, .external_lex_state = 64},
  [14871] = {.lex_state = 84, .external_lex_state = 64},
  [14872] = {.lex_state = 84},
  [14873] = {.lex_state = 76},
  [14874] = {.lex_state = 84, .external_lex_state = 64},
  [14875] = {.lex_state = 84},
  [14876] = {.lex_state = 84, .external_lex_state = 64},
  [14877] = {.lex_state = 84, .external_lex_state = 24},
  [14878] = {.lex_state = 84, .external_lex_state = 64},
  [14879] = {.lex_state = 0, .external_lex_state = 23},
  [14880] = {.lex_state = 84, .external_lex_state = 24},
  [14881] = {.lex_state = 84},
  [14882] = {.lex_state = 0, .external_lex_state = 25},
  [14883] = {.lex_state = 0, .external_lex_state = 25},
  [14884] = {.lex_state = 84},
  [14885] = {.lex_state = 84, .external_lex_state = 64},
  [14886] = {.lex_state = 84, .external_lex_state = 24},
  [14887] = {.lex_state = 0, .external_lex_state = 25},
  [14888] = {.lex_state = 84},
  [14889] = {.lex_state = 0, .external_lex_state = 23},
  [14890] = {.lex_state = 84, .external_lex_state = 24},
  [14891] = {.lex_state = 0, .external_lex_state = 24},
  [14892] = {.lex_state = 84, .external_lex_state = 64},
  [14893] = {.lex_state = 84, .external_lex_state = 24},
  [14894] = {.lex_state = 0},
  [14895] = {.lex_state = 84, .external_lex_state = 24},
  [14896] = {.lex_state = 84, .external_lex_state = 24},
  [14897] = {.lex_state = 84, .external_lex_state = 64},
  [14898] = {.lex_state = 76},
  [14899] = {.lex_state = 84},
  [14900] = {.lex_state = 0},
  [14901] = {.lex_state = 0, .external_lex_state = 23},
  [14902] = {.lex_state = 84, .external_lex_state = 64},
  [14903] = {.lex_state = 84, .external_lex_state = 64},
  [14904] = {.lex_state = 84, .external_lex_state = 64},
  [14905] = {.lex_state = 84},
  [14906] = {.lex_state = 84, .external_lex_state = 64},
  [14907] = {.lex_state = 76},
  [14908] = {.lex_state = 84, .external_lex_state = 64},
  [14909] = {.lex_state = 84},
  [14910] = {.lex_state = 0, .external_lex_state = 25},
  [14911] = {.lex_state = 84},
  [14912] = {.lex_state = 84},
  [14913] = {.lex_state = 0},
  [14914] = {.lex_state = 84},
  [14915] = {.lex_state = 0, .external_lex_state = 25},
  [14916] = {.lex_state = 76},
  [14917] = {.lex_state = 84, .external_lex_state = 64},
  [14918] = {.lex_state = 84, .external_lex_state = 24},
  [14919] = {.lex_state = 84, .external_lex_state = 64},
  [14920] = {.lex_state = 0, .external_lex_state = 23},
  [14921] = {.lex_state = 84},
  [14922] = {.lex_state = 0, .external_lex_state = 24},
  [14923] = {.lex_state = 84, .external_lex_state = 64},
  [14924] = {.lex_state = 84, .external_lex_state = 64},
  [14925] = {.lex_state = 84, .external_lex_state = 24},
  [14926] = {.lex_state = 84},
  [14927] = {.lex_state = 84, .external_lex_state = 64},
  [14928] = {.lex_state = 84},
  [14929] = {.lex_state = 77},
  [14930] = {.lex_state = 0, .external_lex_state = 25},
  [14931] = {.lex_state = 0, .external_lex_state = 25},
  [14932] = {.lex_state = 84, .external_lex_state = 64},
  [14933] = {.lex_state = 84, .external_lex_state = 64},
  [14934] = {.lex_state = 0, .external_lex_state = 25},
  [14935] = {.lex_state = 84},
  [14936] = {.lex_state = 0, .external_lex_state = 24},
  [14937] = {.lex_state = 84},
  [14938] = {.lex_state = 84, .external_lex_state = 24},
  [14939] = {.lex_state = 84, .external_lex_state = 24},
  [14940] = {.lex_state = 76},
  [14941] = {.lex_state = 0, .external_lex_state = 25},
  [14942] = {.lex_state = 84, .external_lex_state = 64},
  [14943] = {.lex_state = 84, .external_lex_state = 24},
  [14944] = {.lex_state = 0, .external_lex_state = 25},
  [14945] = {.lex_state = 84},
  [14946] = {.lex_state = 84, .external_lex_state = 64},
  [14947] = {.lex_state = 76},
  [14948] = {.lex_state = 84, .external_lex_state = 64},
  [14949] = {.lex_state = 84, .external_lex_state = 64},
  [14950] = {.lex_state = 84, .external_lex_state = 24},
  [14951] = {.lex_state = 76},
  [14952] = {.lex_state = 84, .external_lex_state = 24},
  [14953] = {.lex_state = 0, .external_lex_state = 25},
  [14954] = {.lex_state = 84, .external_lex_state = 24},
  [14955] = {.lex_state = 84, .external_lex_state = 24},
  [14956] = {.lex_state = 84},
  [14957] = {.lex_state = 0, .external_lex_state = 25},
  [14958] = {.lex_state = 84},
  [14959] = {.lex_state = 84},
  [14960] = {.lex_state = 84},
  [14961] = {.lex_state = 0, .external_lex_state = 25},
  [14962] = {.lex_state = 84},
  [14963] = {.lex_state = 84, .external_lex_state = 64},
  [14964] = {.lex_state = 0},
  [14965] = {.lex_state = 84},
  [14966] = {.lex_state = 84},
  [14967] = {.lex_state = 84, .external_lex_state = 64},
  [14968] = {.lex_state = 84, .external_lex_state = 24},
  [14969] = {.lex_state = 84},
  [14970] = {.lex_state = 84, .external_lex_state = 64},
  [14971] = {.lex_state = 0, .external_lex_state = 23},
  [14972] = {.lex_state = 84},
  [14973] = {.lex_state = 84, .external_lex_state = 64},
  [14974] = {.lex_state = 76},
  [14975] = {.lex_state = 84, .external_lex_state = 24},
  [14976] = {.lex_state = 84, .external_lex_state = 24},
  [14977] = {.lex_state = 84, .external_lex_state = 24},
  [14978] = {.lex_state = 0, .external_lex_state = 24},
  [14979] = {.lex_state = 84},
  [14980] = {.lex_state = 84, .external_lex_state = 24},
  [14981] = {.lex_state = 84, .external_lex_state = 24},
  [14982] = {.lex_state = 84, .external_lex_state = 24},
  [14983] = {.lex_state = 84},
  [14984] = {.lex_state = 84},
  [14985] = {.lex_state = 84, .external_lex_state = 64},
  [14986] = {.lex_state = 84, .external_lex_state = 64},
  [14987] = {.lex_state = 0, .external_lex_state = 23},
  [14988] = {.lex_state = 0, .external_lex_state = 25},
  [14989] = {.lex_state = 84, .external_lex_state = 64},
  [14990] = {.lex_state = 84, .external_lex_state = 64},
  [14991] = {.lex_state = 84},
  [14992] = {.lex_state = 84},
  [14993] = {.lex_state = 84, .external_lex_state = 64},
  [14994] = {.lex_state = 84, .external_lex_state = 64},
  [14995] = {.lex_state = 84, .external_lex_state = 24},
  [14996] = {.lex_state = 84, .external_lex_state = 23},
  [14997] = {.lex_state = 84, .external_lex_state = 24},
  [14998] = {.lex_state = 76, .external_lex_state = 23},
  [14999] = {.lex_state = 0},
  [15000] = {.lex_state = 84},
  [15001] = {.lex_state = 84, .external_lex_state = 24},
  [15002] = {.lex_state = 84, .external_lex_state = 64},
  [15003] = {.lex_state = 84, .external_lex_state = 24},
  [15004] = {.lex_state = 84, .external_lex_state = 64},
  [15005] = {.lex_state = 76, .external_lex_state = 23},
  [15006] = {.lex_state = 84},
  [15007] = {.lex_state = 84},
  [15008] = {.lex_state = 0, .external_lex_state = 25},
  [15009] = {.lex_state = 0, .external_lex_state = 25},
  [15010] = {.lex_state = 0, .external_lex_state = 23},
  [15011] = {.lex_state = 84},
  [15012] = {.lex_state = 84, .external_lex_state = 64},
  [15013] = {.lex_state = 84, .external_lex_state = 64},
  [15014] = {.lex_state = 84, .external_lex_state = 64},
  [15015] = {.lex_state = 84, .external_lex_state = 64},
  [15016] = {.lex_state = 0, .external_lex_state = 25},
  [15017] = {.lex_state = 84, .external_lex_state = 64},
  [15018] = {.lex_state = 0, .external_lex_state = 25},
  [15019] = {.lex_state = 84},
  [15020] = {.lex_state = 84},
  [15021] = {.lex_state = 84},
  [15022] = {.lex_state = 84, .external_lex_state = 64},
  [15023] = {.lex_state = 0, .external_lex_state = 23},
  [15024] = {.lex_state = 0, .external_lex_state = 24},
  [15025] = {.lex_state = 76},
  [15026] = {.lex_state = 76},
  [15027] = {.lex_state = 84, .external_lex_state = 24},
  [15028] = {.lex_state = 84, .external_lex_state = 24},
  [15029] = {.lex_state = 84, .external_lex_state = 24},
  [15030] = {.lex_state = 0},
  [15031] = {.lex_state = 0, .external_lex_state = 25},
  [15032] = {.lex_state = 84},
  [15033] = {.lex_state = 84, .external_lex_state = 64},
  [15034] = {.lex_state = 0, .external_lex_state = 23},
  [15035] = {.lex_state = 76, .external_lex_state = 23},
  [15036] = {.lex_state = 84},
  [15037] = {.lex_state = 0, .external_lex_state = 25},
  [15038] = {.lex_state = 84, .external_lex_state = 24},
  [15039] = {.lex_state = 84, .external_lex_state = 64},
  [15040] = {.lex_state = 76},
  [15041] = {.lex_state = 76},
  [15042] = {.lex_state = 84, .external_lex_state = 24},
  [15043] = {.lex_state = 84, .external_lex_state = 24},
  [15044] = {.lex_state = 0, .external_lex_state = 25},
  [15045] = {.lex_state = 84, .external_lex_state = 24},
  [15046] = {.lex_state = 84, .external_lex_state = 24},
  [15047] = {.lex_state = 84, .external_lex_state = 64},
  [15048] = {.lex_state = 84, .external_lex_state = 64},
  [15049] = {.lex_state = 0, .external_lex_state = 23},
  [15050] = {.lex_state = 84},
  [15051] = {.lex_state = 0},
  [15052] = {.lex_state = 0},
  [15053] = {.lex_state = 84, .external_lex_state = 24},
  [15054] = {.lex_state = 84},
  [15055] = {.lex_state = 84, .external_lex_state = 24},
  [15056] = {.lex_state = 84, .external_lex_state = 24},
  [15057] = {.lex_state = 84, .external_lex_state = 24},
  [15058] = {.lex_state = 84},
  [15059] = {.lex_state = 84},
  [15060] = {.lex_state = 84, .external_lex_state = 64},
  [15061] = {.lex_state = 0, .external_lex_state = 24},
  [15062] = {.lex_state = 84, .external_lex_state = 64},
  [15063] = {.lex_state = 84, .external_lex_state = 24},
  [15064] = {.lex_state = 84},
  [15065] = {.lex_state = 84, .external_lex_state = 64},
  [15066] = {.lex_state = 84, .external_lex_state = 24},
  [15067] = {.lex_state = 84},
  [15068] = {.lex_state = 84},
  [15069] = {.lex_state = 84, .external_lex_state = 24},
  [15070] = {.lex_state = 84, .external_lex_state = 64},
  [15071] = {.lex_state = 84},
  [15072] = {.lex_state = 0, .external_lex_state = 23},
  [15073] = {.lex_state = 84, .external_lex_state = 64},
  [15074] = {.lex_state = 0, .external_lex_state = 25},
  [15075] = {.lex_state = 84},
  [15076] = {.lex_state = 84},
  [15077] = {.lex_state = 84, .external_lex_state = 64},
  [15078] = {.lex_state = 0},
  [15079] = {.lex_state = 84, .external_lex_state = 24},
  [15080] = {.lex_state = 84, .external_lex_state = 24},
  [15081] = {.lex_state = 84},
  [15082] = {.lex_state = 0, .external_lex_state = 25},
  [15083] = {.lex_state = 0, .external_lex_state = 25},
  [15084] = {.lex_state = 0, .external_lex_state = 25},
  [15085] = {.lex_state = 84},
  [15086] = {.lex_state = 0},
  [15087] = {.lex_state = 84},
  [15088] = {.lex_state = 84},
  [15089] = {.lex_state = 84, .external_lex_state = 24},
  [15090] = {.lex_state = 84, .external_lex_state = 24},
  [15091] = {.lex_state = 0},
  [15092] = {.lex_state = 76},
  [15093] = {.lex_state = 84},
  [15094] = {.lex_state = 84},
  [15095] = {.lex_state = 84, .external_lex_state = 24},
  [15096] = {.lex_state = 84, .external_lex_state = 24},
  [15097] = {.lex_state = 76},
  [15098] = {.lex_state = 84, .external_lex_state = 24},
  [15099] = {.lex_state = 84},
  [15100] = {.lex_state = 84, .external_lex_state = 24},
  [15101] = {.lex_state = 84, .external_lex_state = 64},
  [15102] = {.lex_state = 0, .external_lex_state = 25},
  [15103] = {.lex_state = 84, .external_lex_state = 24},
  [15104] = {.lex_state = 84},
  [15105] = {.lex_state = 84, .external_lex_state = 24},
  [15106] = {.lex_state = 84, .external_lex_state = 24},
  [15107] = {.lex_state = 84, .external_lex_state = 24},
  [15108] = {.lex_state = 84, .external_lex_state = 24},
  [15109] = {.lex_state = 0, .external_lex_state = 23},
  [15110] = {.lex_state = 0},
  [15111] = {.lex_state = 0, .external_lex_state = 24},
  [15112] = {.lex_state = 84},
  [15113] = {.lex_state = 0, .external_lex_state = 23},
  [15114] = {.lex_state = 76},
  [15115] = {.lex_state = 0, .external_lex_state = 24},
  [15116] = {.lex_state = 0, .external_lex_state = 25},
  [15117] = {.lex_state = 0},
  [15118] = {.lex_state = 84},
  [15119] = {.lex_state = 0},
  [15120] = {.lex_state = 84, .external_lex_state = 64},
  [15121] = {.lex_state = 0},
  [15122] = {.lex_state = 84, .external_lex_state = 24},
  [15123] = {.lex_state = 84, .external_lex_state = 64},
  [15124] = {.lex_state = 84, .external_lex_state = 64},
  [15125] = {.lex_state = 84, .external_lex_state = 64},
  [15126] = {.lex_state = 84, .external_lex_state = 64},
  [15127] = {.lex_state = 84, .external_lex_state = 24},
  [15128] = {.lex_state = 84, .external_lex_state = 24},
  [15129] = {.lex_state = 84, .external_lex_state = 64},
  [15130] = {.lex_state = 84, .external_lex_state = 64},
  [15131] = {.lex_state = 84, .external_lex_state = 24},
  [15132] = {.lex_state = 84, .external_lex_state = 24},
  [15133] = {.lex_state = 84, .external_lex_state = 24},
  [15134] = {.lex_state = 84, .external_lex_state = 24},
  [15135] = {.lex_state = 84},
  [15136] = {.lex_state = 84, .external_lex_state = 24},
  [15137] = {.lex_state = 0},
  [15138] = {.lex_state = 0, .external_lex_state = 24},
  [15139] = {.lex_state = 0},
  [15140] = {.lex_state = 0},
  [15141] = {.lex_state = 77, .external_lex_state = 49},
  [15142] = {.lex_state = 0},
  [15143] = {.lex_state = 84, .external_lex_state = 64},
  [15144] = {.lex_state = 0, .external_lex_state = 25},
  [15145] = {.lex_state = 84, .external_lex_state = 24},
  [15146] = {.lex_state = 84},
  [15147] = {.lex_state = 84},
  [15148] = {.lex_state = 0, .external_lex_state = 23},
  [15149] = {.lex_state = 84},
  [15150] = {.lex_state = 0, .external_lex_state = 25},
  [15151] = {.lex_state = 84, .external_lex_state = 24},
  [15152] = {.lex_state = 84},
  [15153] = {.lex_state = 0, .external_lex_state = 25},
  [15154] = {.lex_state = 84, .external_lex_state = 24},
  [15155] = {.lex_state = 0, .external_lex_state = 24},
  [15156] = {.lex_state = 0, .external_lex_state = 25},
  [15157] = {.lex_state = 0, .external_lex_state = 23},
  [15158] = {.lex_state = 84},
  [15159] = {.lex_state = 84, .external_lex_state = 64},
  [15160] = {.lex_state = 84, .external_lex_state = 64},
  [15161] = {.lex_state = 84, .external_lex_state = 64},
  [15162] = {.lex_state = 84},
  [15163] = {.lex_state = 84, .external_lex_state = 64},
  [15164] = {.lex_state = 84, .external_lex_state = 64},
  [15165] = {.lex_state = 84, .external_lex_state = 64},
  [15166] = {.lex_state = 84},
  [15167] = {.lex_state = 84},
  [15168] = {.lex_state = 0, .external_lex_state = 25},
  [15169] = {.lex_state = 84, .external_lex_state = 64},
  [15170] = {.lex_state = 84},
  [15171] = {.lex_state = 84, .external_lex_state = 64},
  [15172] = {.lex_state = 84, .external_lex_state = 64},
  [15173] = {.lex_state = 84},
  [15174] = {.lex_state = 84, .external_lex_state = 64},
  [15175] = {.lex_state = 84, .external_lex_state = 64},
  [15176] = {.lex_state = 0, .external_lex_state = 23},
  [15177] = {.lex_state = 84},
  [15178] = {.lex_state = 84, .external_lex_state = 64},
  [15179] = {.lex_state = 0, .external_lex_state = 24},
  [15180] = {.lex_state = 84, .external_lex_state = 64},
  [15181] = {.lex_state = 84},
  [15182] = {.lex_state = 0, .external_lex_state = 25},
  [15183] = {.lex_state = 84},
  [15184] = {.lex_state = 84, .external_lex_state = 64},
  [15185] = {.lex_state = 84},
  [15186] = {.lex_state = 76, .external_lex_state = 23},
  [15187] = {.lex_state = 0, .external_lex_state = 25},
  [15188] = {.lex_state = 84, .external_lex_state = 64},
  [15189] = {.lex_state = 84},
  [15190] = {.lex_state = 84},
  [15191] = {.lex_state = 84, .external_lex_state = 64},
  [15192] = {.lex_state = 0},
  [15193] = {.lex_state = 0, .external_lex_state = 72},
  [15194] = {.lex_state = 1},
  [15195] = {.lex_state = 0},
  [15196] = {.lex_state = 0},
  [15197] = {.lex_state = 84},
  [15198] = {.lex_state = 0, .external_lex_state = 23},
  [15199] = {.lex_state = 0},
  [15200] = {.lex_state = 0},
  [15201] = {.lex_state = 0},
  [15202] = {.lex_state = 0},
  [15203] = {.lex_state = 1},
  [15204] = {.lex_state = 0},
  [15205] = {.lex_state = 0},
  [15206] = {.lex_state = 0, .external_lex_state = 72},
  [15207] = {.lex_state = 0},
  [15208] = {.lex_state = 84, .external_lex_state = 49},
  [15209] = {.lex_state = 0},
  [15210] = {.lex_state = 84},
  [15211] = {.lex_state = 0},
  [15212] = {.lex_state = 186},
  [15213] = {.lex_state = 0, .external_lex_state = 72},
  [15214] = {.lex_state = 0},
  [15215] = {.lex_state = 0},
  [15216] = {.lex_state = 0},
  [15217] = {.lex_state = 0},
  [15218] = {.lex_state = 76},
  [15219] = {.lex_state = 0, .external_lex_state = 73},
  [15220] = {.lex_state = 0},
  [15221] = {.lex_state = 0, .external_lex_state = 73},
  [15222] = {.lex_state = 0},
  [15223] = {.lex_state = 0},
  [15224] = {.lex_state = 0},
  [15225] = {.lex_state = 0, .external_lex_state = 25},
  [15226] = {.lex_state = 0},
  [15227] = {.lex_state = 84},
  [15228] = {.lex_state = 84},
  [15229] = {.lex_state = 0},
  [15230] = {.lex_state = 0},
  [15231] = {.lex_state = 0, .external_lex_state = 72},
  [15232] = {.lex_state = 0, .external_lex_state = 73},
  [15233] = {.lex_state = 0},
  [15234] = {.lex_state = 0},
  [15235] = {.lex_state = 1},
  [15236] = {.lex_state = 0},
  [15237] = {.lex_state = 0, .external_lex_state = 23},
  [15238] = {.lex_state = 0},
  [15239] = {.lex_state = 0, .external_lex_state = 23},
  [15240] = {.lex_state = 0, .external_lex_state = 23},
  [15241] = {.lex_state = 0},
  [15242] = {.lex_state = 0},
  [15243] = {.lex_state = 0, .external_lex_state = 72},
  [15244] = {.lex_state = 0},
  [15245] = {.lex_state = 0},
  [15246] = {.lex_state = 0, .external_lex_state = 73},
  [15247] = {.lex_state = 0},
  [15248] = {.lex_state = 0},
  [15249] = {.lex_state = 0},
  [15250] = {.lex_state = 0},
  [15251] = {.lex_state = 0},
  [15252] = {.lex_state = 0},
  [15253] = {.lex_state = 0},
  [15254] = {.lex_state = 0},
  [15255] = {.lex_state = 0},
  [15256] = {.lex_state = 0},
  [15257] = {.lex_state = 0},
  [15258] = {.lex_state = 0, .external_lex_state = 25},
  [15259] = {.lex_state = 0},
  [15260] = {.lex_state = 0},
  [15261] = {.lex_state = 0},
  [15262] = {.lex_state = 0},
  [15263] = {.lex_state = 0},
  [15264] = {.lex_state = 0},
  [15265] = {.lex_state = 0},
  [15266] = {.lex_state = 0},
  [15267] = {.lex_state = 0},
  [15268] = {.lex_state = 0},
  [15269] = {.lex_state = 0},
  [15270] = {.lex_state = 0},
  [15271] = {.lex_state = 0},
  [15272] = {.lex_state = 0},
  [15273] = {.lex_state = 0},
  [15274] = {.lex_state = 0},
  [15275] = {.lex_state = 0},
  [15276] = {.lex_state = 0},
  [15277] = {.lex_state = 0},
  [15278] = {.lex_state = 0},
  [15279] = {.lex_state = 0},
  [15280] = {.lex_state = 0, .external_lex_state = 23},
  [15281] = {.lex_state = 0},
  [15282] = {.lex_state = 0},
  [15283] = {.lex_state = 0},
  [15284] = {.lex_state = 0},
  [15285] = {.lex_state = 0},
  [15286] = {.lex_state = 0},
  [15287] = {.lex_state = 0},
  [15288] = {.lex_state = 0},
  [15289] = {.lex_state = 0},
  [15290] = {.lex_state = 0},
  [15291] = {.lex_state = 0},
  [15292] = {.lex_state = 0},
  [15293] = {.lex_state = 0},
  [15294] = {.lex_state = 0},
  [15295] = {.lex_state = 0},
  [15296] = {.lex_state = 0},
  [15297] = {.lex_state = 0},
  [15298] = {.lex_state = 0},
  [15299] = {.lex_state = 0},
  [15300] = {.lex_state = 0},
  [15301] = {.lex_state = 0},
  [15302] = {.lex_state = 0},
  [15303] = {.lex_state = 0},
  [15304] = {.lex_state = 84},
  [15305] = {.lex_state = 0},
  [15306] = {.lex_state = 0},
  [15307] = {.lex_state = 0},
  [15308] = {.lex_state = 0},
  [15309] = {.lex_state = 0},
  [15310] = {.lex_state = 9},
  [15311] = {.lex_state = 0},
  [15312] = {.lex_state = 0, .external_lex_state = 72},
  [15313] = {.lex_state = 0},
  [15314] = {.lex_state = 0},
  [15315] = {.lex_state = 0},
  [15316] = {.lex_state = 9},
  [15317] = {.lex_state = 0},
  [15318] = {.lex_state = 0},
  [15319] = {.lex_state = 0},
  [15320] = {.lex_state = 0},
  [15321] = {.lex_state = 0},
  [15322] = {.lex_state = 0, .external_lex_state = 73},
  [15323] = {.lex_state = 0},
  [15324] = {.lex_state = 0, .external_lex_state = 72},
  [15325] = {.lex_state = 0},
  [15326] = {.lex_state = 0},
  [15327] = {.lex_state = 0},
  [15328] = {.lex_state = 0},
  [15329] = {.lex_state = 0},
  [15330] = {.lex_state = 0},
  [15331] = {.lex_state = 0},
  [15332] = {.lex_state = 0},
  [15333] = {.lex_state = 0},
  [15334] = {.lex_state = 0},
  [15335] = {.lex_state = 0},
  [15336] = {.lex_state = 0},
  [15337] = {.lex_state = 0},
  [15338] = {.lex_state = 0},
  [15339] = {.lex_state = 0},
  [15340] = {.lex_state = 0},
  [15341] = {.lex_state = 0},
  [15342] = {.lex_state = 0},
  [15343] = {.lex_state = 0},
  [15344] = {.lex_state = 0},
  [15345] = {.lex_state = 0},
  [15346] = {.lex_state = 0, .external_lex_state = 73},
  [15347] = {.lex_state = 0},
  [15348] = {.lex_state = 0},
  [15349] = {.lex_state = 0},
  [15350] = {.lex_state = 0},
  [15351] = {.lex_state = 0},
  [15352] = {.lex_state = 0, .external_lex_state = 73},
  [15353] = {.lex_state = 0},
  [15354] = {.lex_state = 0},
  [15355] = {.lex_state = 0},
  [15356] = {.lex_state = 0},
  [15357] = {.lex_state = 0},
  [15358] = {.lex_state = 0},
  [15359] = {.lex_state = 0},
  [15360] = {.lex_state = 0},
  [15361] = {.lex_state = 0},
  [15362] = {.lex_state = 0},
  [15363] = {.lex_state = 0},
  [15364] = {.lex_state = 0},
  [15365] = {.lex_state = 0},
  [15366] = {.lex_state = 0},
  [15367] = {.lex_state = 0},
  [15368] = {.lex_state = 0},
  [15369] = {.lex_state = 0},
  [15370] = {.lex_state = 0},
  [15371] = {.lex_state = 0, .external_lex_state = 72},
  [15372] = {.lex_state = 0},
  [15373] = {.lex_state = 0},
  [15374] = {.lex_state = 0},
  [15375] = {.lex_state = 0},
  [15376] = {.lex_state = 0},
  [15377] = {.lex_state = 84},
  [15378] = {.lex_state = 0},
  [15379] = {.lex_state = 0},
  [15380] = {.lex_state = 0},
  [15381] = {.lex_state = 0},
  [15382] = {.lex_state = 0, .external_lex_state = 25},
  [15383] = {.lex_state = 0},
  [15384] = {.lex_state = 0},
  [15385] = {.lex_state = 0},
  [15386] = {.lex_state = 0},
  [15387] = {.lex_state = 0},
  [15388] = {.lex_state = 0},
  [15389] = {.lex_state = 0},
  [15390] = {.lex_state = 0},
  [15391] = {.lex_state = 0},
  [15392] = {.lex_state = 0},
  [15393] = {.lex_state = 0},
  [15394] = {.lex_state = 0},
  [15395] = {.lex_state = 0},
  [15396] = {.lex_state = 0},
  [15397] = {.lex_state = 0},
  [15398] = {.lex_state = 0},
  [15399] = {.lex_state = 0},
  [15400] = {.lex_state = 0},
  [15401] = {.lex_state = 0},
  [15402] = {.lex_state = 0},
  [15403] = {.lex_state = 0},
  [15404] = {.lex_state = 0},
  [15405] = {.lex_state = 0},
  [15406] = {.lex_state = 0},
  [15407] = {.lex_state = 0},
  [15408] = {.lex_state = 0},
  [15409] = {.lex_state = 0},
  [15410] = {.lex_state = 0},
  [15411] = {.lex_state = 0},
  [15412] = {.lex_state = 0},
  [15413] = {.lex_state = 0},
  [15414] = {.lex_state = 0},
  [15415] = {.lex_state = 0},
  [15416] = {.lex_state = 0},
  [15417] = {.lex_state = 0},
  [15418] = {.lex_state = 0},
  [15419] = {.lex_state = 0},
  [15420] = {.lex_state = 0, .external_lex_state = 73},
  [15421] = {.lex_state = 0},
  [15422] = {.lex_state = 0},
  [15423] = {.lex_state = 0},
  [15424] = {.lex_state = 0},
  [15425] = {.lex_state = 84},
  [15426] = {.lex_state = 0},
  [15427] = {.lex_state = 0},
  [15428] = {.lex_state = 0},
  [15429] = {.lex_state = 0},
  [15430] = {.lex_state = 0},
  [15431] = {.lex_state = 0},
  [15432] = {.lex_state = 0},
  [15433] = {.lex_state = 0},
  [15434] = {.lex_state = 0},
  [15435] = {.lex_state = 0},
  [15436] = {.lex_state = 0},
  [15437] = {.lex_state = 0},
  [15438] = {.lex_state = 0, .external_lex_state = 72},
  [15439] = {.lex_state = 0},
  [15440] = {.lex_state = 0},
  [15441] = {.lex_state = 0},
  [15442] = {.lex_state = 0},
  [15443] = {.lex_state = 0},
  [15444] = {.lex_state = 0},
  [15445] = {.lex_state = 0},
  [15446] = {.lex_state = 0},
  [15447] = {.lex_state = 0},
  [15448] = {.lex_state = 0},
  [15449] = {.lex_state = 0},
  [15450] = {.lex_state = 0},
  [15451] = {.lex_state = 0},
  [15452] = {.lex_state = 0},
  [15453] = {.lex_state = 0},
  [15454] = {.lex_state = 0},
  [15455] = {.lex_state = 0},
  [15456] = {.lex_state = 0, .external_lex_state = 72},
  [15457] = {.lex_state = 0},
  [15458] = {.lex_state = 0},
  [15459] = {.lex_state = 0},
  [15460] = {.lex_state = 0, .external_lex_state = 25},
  [15461] = {.lex_state = 0},
  [15462] = {.lex_state = 0},
  [15463] = {.lex_state = 0},
  [15464] = {.lex_state = 0},
  [15465] = {.lex_state = 0},
  [15466] = {.lex_state = 84},
  [15467] = {.lex_state = 0, .external_lex_state = 72},
  [15468] = {.lex_state = 0},
  [15469] = {.lex_state = 0},
  [15470] = {.lex_state = 0},
  [15471] = {.lex_state = 0},
  [15472] = {.lex_state = 0, .external_lex_state = 73},
  [15473] = {.lex_state = 0},
  [15474] = {.lex_state = 0, .external_lex_state = 73},
  [15475] = {.lex_state = 0},
  [15476] = {.lex_state = 0},
  [15477] = {.lex_state = 0},
  [15478] = {.lex_state = 0},
  [15479] = {.lex_state = 0},
  [15480] = {.lex_state = 0},
  [15481] = {.lex_state = 0},
  [15482] = {.lex_state = 0},
  [15483] = {.lex_state = 0},
  [15484] = {.lex_state = 0},
  [15485] = {.lex_state = 0},
  [15486] = {.lex_state = 0},
  [15487] = {.lex_state = 0},
  [15488] = {.lex_state = 0},
  [15489] = {.lex_state = 0},
  [15490] = {.lex_state = 0},
  [15491] = {.lex_state = 0, .external_lex_state = 23},
  [15492] = {.lex_state = 0},
  [15493] = {.lex_state = 0},
  [15494] = {.lex_state = 0},
  [15495] = {.lex_state = 77, .external_lex_state = 71},
  [15496] = {.lex_state = 0},
  [15497] = {.lex_state = 0},
  [15498] = {.lex_state = 0},
  [15499] = {.lex_state = 0},
  [15500] = {.lex_state = 0},
  [15501] = {.lex_state = 0},
  [15502] = {.lex_state = 0},
  [15503] = {.lex_state = 0},
  [15504] = {.lex_state = 0},
  [15505] = {.lex_state = 0},
  [15506] = {.lex_state = 0},
  [15507] = {.lex_state = 0},
  [15508] = {.lex_state = 0},
  [15509] = {.lex_state = 0},
  [15510] = {.lex_state = 0},
  [15511] = {.lex_state = 0},
  [15512] = {.lex_state = 0},
  [15513] = {.lex_state = 0},
  [15514] = {.lex_state = 0},
  [15515] = {.lex_state = 0},
  [15516] = {.lex_state = 0},
  [15517] = {.lex_state = 0},
  [15518] = {.lex_state = 0},
  [15519] = {.lex_state = 0},
  [15520] = {.lex_state = 0},
  [15521] = {.lex_state = 0},
  [15522] = {.lex_state = 0},
  [15523] = {.lex_state = 0},
  [15524] = {.lex_state = 0},
  [15525] = {.lex_state = 0},
  [15526] = {.lex_state = 0},
  [15527] = {.lex_state = 0},
  [15528] = {.lex_state = 0},
  [15529] = {.lex_state = 0},
  [15530] = {.lex_state = 0},
  [15531] = {.lex_state = 0},
  [15532] = {.lex_state = 0},
  [15533] = {.lex_state = 76},
  [15534] = {.lex_state = 0},
  [15535] = {.lex_state = 0},
  [15536] = {.lex_state = 0},
  [15537] = {.lex_state = 0},
  [15538] = {.lex_state = 0},
  [15539] = {.lex_state = 0},
  [15540] = {.lex_state = 0},
  [15541] = {.lex_state = 0},
  [15542] = {.lex_state = 0},
  [15543] = {.lex_state = 0},
  [15544] = {.lex_state = 0},
  [15545] = {.lex_state = 0},
  [15546] = {.lex_state = 84},
  [15547] = {.lex_state = 0},
  [15548] = {.lex_state = 0},
  [15549] = {.lex_state = 0},
  [15550] = {.lex_state = 0},
  [15551] = {.lex_state = 0},
  [15552] = {.lex_state = 0},
  [15553] = {.lex_state = 0},
  [15554] = {.lex_state = 0},
  [15555] = {.lex_state = 0},
  [15556] = {.lex_state = 0},
  [15557] = {.lex_state = 0},
  [15558] = {.lex_state = 0, .external_lex_state = 73},
  [15559] = {.lex_state = 0},
  [15560] = {.lex_state = 0},
  [15561] = {.lex_state = 0},
  [15562] = {.lex_state = 0},
  [15563] = {.lex_state = 0},
  [15564] = {.lex_state = 0, .external_lex_state = 25},
  [15565] = {.lex_state = 0},
  [15566] = {.lex_state = 0},
  [15567] = {.lex_state = 0},
  [15568] = {.lex_state = 0, .external_lex_state = 72},
  [15569] = {.lex_state = 0},
  [15570] = {.lex_state = 0},
  [15571] = {.lex_state = 0},
  [15572] = {.lex_state = 0},
  [15573] = {.lex_state = 0},
  [15574] = {.lex_state = 0, .external_lex_state = 72},
  [15575] = {.lex_state = 0},
  [15576] = {.lex_state = 0},
  [15577] = {.lex_state = 0},
  [15578] = {.lex_state = 0},
  [15579] = {.lex_state = 0},
  [15580] = {.lex_state = 0},
  [15581] = {.lex_state = 0},
  [15582] = {.lex_state = 0},
  [15583] = {.lex_state = 0},
  [15584] = {.lex_state = 0},
  [15585] = {.lex_state = 0},
  [15586] = {.lex_state = 0},
  [15587] = {.lex_state = 0, .external_lex_state = 73},
  [15588] = {.lex_state = 0},
  [15589] = {.lex_state = 0},
  [15590] = {.lex_state = 0},
  [15591] = {.lex_state = 0},
  [15592] = {.lex_state = 0},
  [15593] = {.lex_state = 0},
  [15594] = {.lex_state = 0},
  [15595] = {.lex_state = 0},
  [15596] = {.lex_state = 0, .external_lex_state = 23},
  [15597] = {.lex_state = 0},
  [15598] = {.lex_state = 0},
  [15599] = {.lex_state = 0, .external_lex_state = 23},
  [15600] = {.lex_state = 0, .external_lex_state = 23},
  [15601] = {.lex_state = 0},
  [15602] = {.lex_state = 0},
  [15603] = {.lex_state = 0},
  [15604] = {.lex_state = 0},
  [15605] = {.lex_state = 0},
  [15606] = {.lex_state = 0},
  [15607] = {.lex_state = 0},
  [15608] = {.lex_state = 0},
  [15609] = {.lex_state = 0},
  [15610] = {.lex_state = 84},
  [15611] = {.lex_state = 0},
  [15612] = {.lex_state = 0},
  [15613] = {.lex_state = 0},
  [15614] = {.lex_state = 0, .external_lex_state = 25},
  [15615] = {.lex_state = 0},
  [15616] = {.lex_state = 0},
  [15617] = {.lex_state = 0},
  [15618] = {.lex_state = 0},
  [15619] = {.lex_state = 0},
  [15620] = {.lex_state = 0},
  [15621] = {.lex_state = 0},
  [15622] = {.lex_state = 0},
  [15623] = {.lex_state = 0},
  [15624] = {.lex_state = 0},
  [15625] = {.lex_state = 0},
  [15626] = {.lex_state = 0},
  [15627] = {.lex_state = 0},
  [15628] = {.lex_state = 0},
  [15629] = {.lex_state = 0},
  [15630] = {.lex_state = 0},
  [15631] = {.lex_state = 0},
  [15632] = {.lex_state = 84},
  [15633] = {.lex_state = 0},
  [15634] = {.lex_state = 0},
  [15635] = {.lex_state = 0},
  [15636] = {.lex_state = 0},
  [15637] = {.lex_state = 0},
  [15638] = {.lex_state = 0},
  [15639] = {.lex_state = 0},
  [15640] = {.lex_state = 76},
  [15641] = {.lex_state = 0},
  [15642] = {.lex_state = 0},
  [15643] = {.lex_state = 0},
  [15644] = {.lex_state = 0},
  [15645] = {.lex_state = 0},
  [15646] = {.lex_state = 76},
  [15647] = {.lex_state = 0},
  [15648] = {.lex_state = 0},
  [15649] = {.lex_state = 76},
  [15650] = {.lex_state = 0},
  [15651] = {.lex_state = 0},
  [15652] = {.lex_state = 0},
  [15653] = {.lex_state = 0},
  [15654] = {.lex_state = 0},
  [15655] = {.lex_state = 76},
  [15656] = {.lex_state = 0, .external_lex_state = 23},
  [15657] = {.lex_state = 0},
  [15658] = {.lex_state = 0},
  [15659] = {.lex_state = 0},
  [15660] = {.lex_state = 0},
  [15661] = {.lex_state = 0},
  [15662] = {.lex_state = 0},
  [15663] = {.lex_state = 0},
  [15664] = {.lex_state = 0},
  [15665] = {.lex_state = 0},
  [15666] = {.lex_state = 0},
  [15667] = {.lex_state = 0},
  [15668] = {.lex_state = 84},
  [15669] = {.lex_state = 0},
  [15670] = {.lex_state = 0},
  [15671] = {.lex_state = 76},
  [15672] = {.lex_state = 0},
  [15673] = {.lex_state = 0},
  [15674] = {.lex_state = 0},
  [15675] = {.lex_state = 0},
  [15676] = {.lex_state = 76},
  [15677] = {.lex_state = 0, .external_lex_state = 23},
  [15678] = {.lex_state = 0},
  [15679] = {.lex_state = 0},
  [15680] = {.lex_state = 0, .external_lex_state = 73},
  [15681] = {.lex_state = 0},
  [15682] = {.lex_state = 76},
  [15683] = {.lex_state = 0},
  [15684] = {.lex_state = 0},
  [15685] = {.lex_state = 0},
  [15686] = {.lex_state = 76},
  [15687] = {.lex_state = 0},
  [15688] = {.lex_state = 0},
  [15689] = {.lex_state = 0},
  [15690] = {.lex_state = 0, .external_lex_state = 72},
  [15691] = {.lex_state = 0},
  [15692] = {.lex_state = 0},
  [15693] = {.lex_state = 0},
  [15694] = {.lex_state = 0},
  [15695] = {.lex_state = 0, .external_lex_state = 24},
  [15696] = {.lex_state = 0},
  [15697] = {.lex_state = 0},
  [15698] = {.lex_state = 76},
  [15699] = {.lex_state = 0},
  [15700] = {.lex_state = 0},
  [15701] = {.lex_state = 76},
  [15702] = {.lex_state = 0, .external_lex_state = 24},
  [15703] = {.lex_state = 0},
  [15704] = {.lex_state = 0, .external_lex_state = 24},
  [15705] = {.lex_state = 0},
  [15706] = {.lex_state = 0},
  [15707] = {.lex_state = 0},
  [15708] = {.lex_state = 0},
  [15709] = {.lex_state = 84},
  [15710] = {.lex_state = 0, .external_lex_state = 72},
  [15711] = {.lex_state = 0},
  [15712] = {.lex_state = 0, .external_lex_state = 73},
  [15713] = {.lex_state = 0},
  [15714] = {.lex_state = 0},
  [15715] = {.lex_state = 0},
  [15716] = {.lex_state = 0},
  [15717] = {.lex_state = 0},
  [15718] = {.lex_state = 0},
  [15719] = {.lex_state = 0, .external_lex_state = 24},
  [15720] = {.lex_state = 0, .external_lex_state = 24},
  [15721] = {.lex_state = 0},
  [15722] = {.lex_state = 0},
  [15723] = {.lex_state = 0},
  [15724] = {.lex_state = 0, .external_lex_state = 24},
  [15725] = {.lex_state = 0},
  [15726] = {.lex_state = 0},
  [15727] = {.lex_state = 0},
  [15728] = {.lex_state = 0, .external_lex_state = 24},
  [15729] = {.lex_state = 0},
  [15730] = {.lex_state = 0, .external_lex_state = 24},
  [15731] = {.lex_state = 0},
  [15732] = {.lex_state = 0, .external_lex_state = 24},
  [15733] = {.lex_state = 0},
  [15734] = {.lex_state = 0},
  [15735] = {.lex_state = 0},
  [15736] = {.lex_state = 0, .external_lex_state = 73},
  [15737] = {.lex_state = 0, .external_lex_state = 25},
  [15738] = {.lex_state = 0},
  [15739] = {.lex_state = 0},
  [15740] = {.lex_state = 0},
  [15741] = {.lex_state = 0, .external_lex_state = 72},
  [15742] = {.lex_state = 0},
  [15743] = {.lex_state = 0},
  [15744] = {.lex_state = 0},
  [15745] = {.lex_state = 84},
  [15746] = {.lex_state = 0, .external_lex_state = 25},
  [15747] = {.lex_state = 0},
  [15748] = {.lex_state = 0},
  [15749] = {.lex_state = 0},
  [15750] = {.lex_state = 0},
  [15751] = {.lex_state = 0},
  [15752] = {.lex_state = 0},
  [15753] = {.lex_state = 84},
  [15754] = {.lex_state = 0},
  [15755] = {.lex_state = 0},
  [15756] = {.lex_state = 84},
  [15757] = {.lex_state = 0},
  [15758] = {.lex_state = 0},
  [15759] = {.lex_state = 0, .external_lex_state = 73},
  [15760] = {.lex_state = 0},
  [15761] = {.lex_state = 0},
  [15762] = {.lex_state = 0, .external_lex_state = 72},
  [15763] = {.lex_state = 0},
  [15764] = {.lex_state = 0},
  [15765] = {.lex_state = 0},
  [15766] = {.lex_state = 0},
  [15767] = {.lex_state = 0},
  [15768] = {.lex_state = 0},
  [15769] = {.lex_state = 0},
  [15770] = {.lex_state = 0},
  [15771] = {.lex_state = 0},
  [15772] = {.lex_state = 0},
  [15773] = {.lex_state = 0},
  [15774] = {.lex_state = 0},
  [15775] = {.lex_state = 0},
  [15776] = {.lex_state = 0},
  [15777] = {.lex_state = 0},
  [15778] = {.lex_state = 0},
  [15779] = {.lex_state = 0},
  [15780] = {.lex_state = 0},
  [15781] = {.lex_state = 0},
  [15782] = {.lex_state = 0},
  [15783] = {.lex_state = 0},
  [15784] = {.lex_state = 0},
  [15785] = {.lex_state = 0},
  [15786] = {.lex_state = 0},
  [15787] = {.lex_state = 0},
  [15788] = {.lex_state = 0},
  [15789] = {.lex_state = 0},
  [15790] = {.lex_state = 0},
  [15791] = {.lex_state = 0},
  [15792] = {.lex_state = 0},
  [15793] = {.lex_state = 0, .external_lex_state = 73},
  [15794] = {.lex_state = 0},
  [15795] = {.lex_state = 84},
  [15796] = {.lex_state = 0},
  [15797] = {.lex_state = 0},
  [15798] = {.lex_state = 0},
  [15799] = {.lex_state = 0},
  [15800] = {.lex_state = 0},
  [15801] = {.lex_state = 0},
  [15802] = {.lex_state = 0},
  [15803] = {.lex_state = 76},
  [15804] = {.lex_state = 0},
  [15805] = {.lex_state = 84},
  [15806] = {.lex_state = 0},
  [15807] = {.lex_state = 0, .external_lex_state = 72},
  [15808] = {.lex_state = 0},
  [15809] = {.lex_state = 0},
  [15810] = {.lex_state = 0},
  [15811] = {.lex_state = 0},
  [15812] = {.lex_state = 0},
  [15813] = {.lex_state = 0, .external_lex_state = 25},
  [15814] = {.lex_state = 0},
  [15815] = {.lex_state = 84},
  [15816] = {.lex_state = 0},
  [15817] = {.lex_state = 0},
  [15818] = {.lex_state = 0},
  [15819] = {.lex_state = 0, .external_lex_state = 72},
  [15820] = {.lex_state = 0},
  [15821] = {.lex_state = 0},
  [15822] = {.lex_state = 0},
  [15823] = {.lex_state = 0},
  [15824] = {.lex_state = 0},
  [15825] = {.lex_state = 0, .external_lex_state = 23},
  [15826] = {.lex_state = 0},
  [15827] = {.lex_state = 0},
  [15828] = {.lex_state = 0},
  [15829] = {.lex_state = 0},
  [15830] = {.lex_state = 0},
  [15831] = {.lex_state = 0},
  [15832] = {.lex_state = 0},
  [15833] = {.lex_state = 0},
  [15834] = {.lex_state = 0},
  [15835] = {.lex_state = 0},
  [15836] = {.lex_state = 0},
  [15837] = {.lex_state = 0},
  [15838] = {.lex_state = 0},
  [15839] = {.lex_state = 0},
  [15840] = {.lex_state = 0, .external_lex_state = 25},
  [15841] = {.lex_state = 0},
  [15842] = {.lex_state = 0},
  [15843] = {.lex_state = 0},
  [15844] = {.lex_state = 0},
  [15845] = {.lex_state = 0},
  [15846] = {.lex_state = 0},
  [15847] = {.lex_state = 0},
  [15848] = {.lex_state = 0},
  [15849] = {.lex_state = 0},
  [15850] = {.lex_state = 0},
  [15851] = {.lex_state = 0},
  [15852] = {.lex_state = 84},
  [15853] = {.lex_state = 0, .external_lex_state = 72},
  [15854] = {.lex_state = 0, .external_lex_state = 73},
  [15855] = {.lex_state = 0},
  [15856] = {.lex_state = 0},
  [15857] = {.lex_state = 0},
  [15858] = {.lex_state = 0},
  [15859] = {.lex_state = 0},
  [15860] = {.lex_state = 0},
  [15861] = {.lex_state = 0},
  [15862] = {.lex_state = 0},
  [15863] = {.lex_state = 0},
  [15864] = {.lex_state = 0},
  [15865] = {.lex_state = 0},
  [15866] = {.lex_state = 0},
  [15867] = {.lex_state = 0},
  [15868] = {.lex_state = 0},
  [15869] = {.lex_state = 0},
  [15870] = {.lex_state = 0, .external_lex_state = 73},
  [15871] = {.lex_state = 0},
  [15872] = {.lex_state = 0},
  [15873] = {.lex_state = 0},
  [15874] = {.lex_state = 0, .external_lex_state = 73},
  [15875] = {.lex_state = 0},
  [15876] = {.lex_state = 0},
  [15877] = {.lex_state = 84},
  [15878] = {.lex_state = 0, .external_lex_state = 25},
  [15879] = {.lex_state = 0},
  [15880] = {.lex_state = 0, .external_lex_state = 72},
  [15881] = {.lex_state = 0},
  [15882] = {.lex_state = 0},
  [15883] = {.lex_state = 0},
  [15884] = {.lex_state = 0},
  [15885] = {.lex_state = 0},
  [15886] = {.lex_state = 0},
  [15887] = {.lex_state = 0},
  [15888] = {.lex_state = 0},
  [15889] = {.lex_state = 0},
  [15890] = {.lex_state = 0},
  [15891] = {.lex_state = 0},
  [15892] = {.lex_state = 0},
  [15893] = {.lex_state = 0},
  [15894] = {.lex_state = 0},
  [15895] = {.lex_state = 0},
  [15896] = {.lex_state = 0},
  [15897] = {.lex_state = 0},
  [15898] = {.lex_state = 0},
  [15899] = {.lex_state = 0},
  [15900] = {.lex_state = 0},
  [15901] = {.lex_state = 0},
  [15902] = {.lex_state = 0},
  [15903] = {.lex_state = 0},
  [15904] = {.lex_state = 0},
  [15905] = {.lex_state = 84},
  [15906] = {.lex_state = 84},
  [15907] = {.lex_state = 0},
  [15908] = {.lex_state = 0},
  [15909] = {.lex_state = 0},
  [15910] = {.lex_state = 0},
  [15911] = {.lex_state = 0},
  [15912] = {.lex_state = 0},
  [15913] = {.lex_state = 0},
  [15914] = {.lex_state = 84},
  [15915] = {.lex_state = 0},
  [15916] = {.lex_state = 0},
  [15917] = {.lex_state = 0},
  [15918] = {.lex_state = 76},
  [15919] = {.lex_state = 0},
  [15920] = {.lex_state = 0, .external_lex_state = 73},
  [15921] = {.lex_state = 0},
  [15922] = {.lex_state = 0, .external_lex_state = 72},
  [15923] = {.lex_state = 0},
  [15924] = {.lex_state = 0, .external_lex_state = 72},
  [15925] = {.lex_state = 0},
  [15926] = {.lex_state = 84},
  [15927] = {.lex_state = 0, .external_lex_state = 73},
  [15928] = {.lex_state = 0},
  [15929] = {.lex_state = 0},
  [15930] = {.lex_state = 84},
  [15931] = {.lex_state = 0, .external_lex_state = 25},
  [15932] = {.lex_state = 0},
  [15933] = {.lex_state = 0},
  [15934] = {.lex_state = 0},
  [15935] = {.lex_state = 0},
  [15936] = {.lex_state = 84},
  [15937] = {.lex_state = 0},
  [15938] = {.lex_state = 0},
  [15939] = {.lex_state = 0},
  [15940] = {.lex_state = 0},
  [15941] = {.lex_state = 0, .external_lex_state = 73},
  [15942] = {.lex_state = 84},
  [15943] = {.lex_state = 0},
  [15944] = {.lex_state = 0},
  [15945] = {.lex_state = 0},
  [15946] = {.lex_state = 0},
  [15947] = {.lex_state = 0},
  [15948] = {.lex_state = 0},
  [15949] = {.lex_state = 0, .external_lex_state = 25},
  [15950] = {.lex_state = 0},
  [15951] = {.lex_state = 0},
  [15952] = {.lex_state = 0},
  [15953] = {.lex_state = 0},
  [15954] = {.lex_state = 0},
  [15955] = {.lex_state = 0},
  [15956] = {.lex_state = 0},
  [15957] = {.lex_state = 0},
  [15958] = {.lex_state = 0},
  [15959] = {.lex_state = 0},
  [15960] = {.lex_state = 0, .external_lex_state = 25},
  [15961] = {.lex_state = 0},
  [15962] = {.lex_state = 0},
  [15963] = {.lex_state = 0},
  [15964] = {.lex_state = 0},
  [15965] = {.lex_state = 0},
  [15966] = {.lex_state = 0},
  [15967] = {.lex_state = 0},
  [15968] = {.lex_state = 0},
  [15969] = {.lex_state = 0},
  [15970] = {.lex_state = 0},
  [15971] = {.lex_state = 0},
  [15972] = {.lex_state = 0},
  [15973] = {.lex_state = 0},
  [15974] = {.lex_state = 0},
  [15975] = {.lex_state = 0},
  [15976] = {.lex_state = 0},
  [15977] = {.lex_state = 0},
  [15978] = {.lex_state = 0},
  [15979] = {.lex_state = 0, .external_lex_state = 73},
  [15980] = {.lex_state = 0},
  [15981] = {.lex_state = 0},
  [15982] = {.lex_state = 0},
  [15983] = {.lex_state = 0},
  [15984] = {.lex_state = 0},
  [15985] = {.lex_state = 0},
  [15986] = {.lex_state = 0, .external_lex_state = 72},
  [15987] = {.lex_state = 0},
  [15988] = {.lex_state = 0},
  [15989] = {.lex_state = 0},
  [15990] = {.lex_state = 0},
  [15991] = {.lex_state = 0},
  [15992] = {.lex_state = 0},
  [15993] = {.lex_state = 84},
  [15994] = {.lex_state = 0},
  [15995] = {.lex_state = 0},
  [15996] = {.lex_state = 0},
  [15997] = {.lex_state = 76},
  [15998] = {.lex_state = 0},
  [15999] = {.lex_state = 0},
  [16000] = {.lex_state = 0},
  [16001] = {.lex_state = 0},
  [16002] = {.lex_state = 0, .external_lex_state = 72},
  [16003] = {.lex_state = 0, .external_lex_state = 73},
  [16004] = {.lex_state = 0},
  [16005] = {.lex_state = 0},
  [16006] = {.lex_state = 0},
  [16007] = {.lex_state = 0, .external_lex_state = 73},
  [16008] = {.lex_state = 0},
  [16009] = {.lex_state = 0, .external_lex_state = 72},
  [16010] = {.lex_state = 0},
  [16011] = {.lex_state = 0},
  [16012] = {.lex_state = 84},
  [16013] = {.lex_state = 0, .external_lex_state = 25},
  [16014] = {.lex_state = 84},
  [16015] = {.lex_state = 0},
  [16016] = {.lex_state = 84},
  [16017] = {.lex_state = 0},
  [16018] = {.lex_state = 0, .external_lex_state = 72},
  [16019] = {.lex_state = 0, .external_lex_state = 73},
  [16020] = {.lex_state = 0},
  [16021] = {.lex_state = 0},
  [16022] = {.lex_state = 0},
  [16023] = {.lex_state = 0},
  [16024] = {.lex_state = 0},
  [16025] = {.lex_state = 0, .external_lex_state = 25},
  [16026] = {.lex_state = 0, .external_lex_state = 25},
  [16027] = {.lex_state = 0},
  [16028] = {.lex_state = 84},
  [16029] = {.lex_state = 0},
  [16030] = {.lex_state = 84},
  [16031] = {.lex_state = 0},
  [16032] = {.lex_state = 0, .external_lex_state = 25},
  [16033] = {.lex_state = 0},
  [16034] = {.lex_state = 0},
  [16035] = {.lex_state = 0},
  [16036] = {.lex_state = 0},
  [16037] = {.lex_state = 0, .external_lex_state = 25},
  [16038] = {.lex_state = 0},
  [16039] = {.lex_state = 0},
  [16040] = {.lex_state = 0},
  [16041] = {.lex_state = 0},
  [16042] = {.lex_state = 84},
  [16043] = {.lex_state = 0},
  [16044] = {.lex_state = 0},
  [16045] = {.lex_state = 84},
  [16046] = {.lex_state = 84},
  [16047] = {.lex_state = 0},
  [16048] = {.lex_state = 76},
  [16049] = {.lex_state = 0, .external_lex_state = 73},
  [16050] = {.lex_state = 0},
  [16051] = {.lex_state = 0},
  [16052] = {.lex_state = 0},
  [16053] = {.lex_state = 0},
  [16054] = {.lex_state = 0},
  [16055] = {.lex_state = 0},
  [16056] = {.lex_state = 0},
  [16057] = {.lex_state = 0},
  [16058] = {.lex_state = 0},
  [16059] = {.lex_state = 0},
  [16060] = {.lex_state = 0},
  [16061] = {.lex_state = 0, .external_lex_state = 72},
  [16062] = {.lex_state = 0},
  [16063] = {.lex_state = 0, .external_lex_state = 73},
  [16064] = {.lex_state = 0},
  [16065] = {.lex_state = 0, .external_lex_state = 72},
  [16066] = {.lex_state = 0},
  [16067] = {.lex_state = 0},
  [16068] = {.lex_state = 0},
  [16069] = {.lex_state = 0},
  [16070] = {.lex_state = 0},
  [16071] = {.lex_state = 0},
  [16072] = {.lex_state = 0, .external_lex_state = 72},
  [16073] = {.lex_state = 0, .external_lex_state = 25},
  [16074] = {.lex_state = 0, .external_lex_state = 73},
  [16075] = {.lex_state = 0},
  [16076] = {.lex_state = 0},
  [16077] = {.lex_state = 0},
  [16078] = {.lex_state = 0},
  [16079] = {.lex_state = 0},
  [16080] = {.lex_state = 84},
  [16081] = {.lex_state = 0},
  [16082] = {.lex_state = 0},
  [16083] = {.lex_state = 0, .external_lex_state = 25},
  [16084] = {.lex_state = 84},
  [16085] = {.lex_state = 0},
  [16086] = {.lex_state = 84},
  [16087] = {.lex_state = 0},
  [16088] = {.lex_state = 0},
  [16089] = {.lex_state = 84},
  [16090] = {.lex_state = 0},
  [16091] = {.lex_state = 0},
  [16092] = {.lex_state = 0, .external_lex_state = 73},
  [16093] = {.lex_state = 0, .external_lex_state = 72},
  [16094] = {.lex_state = 0, .external_lex_state = 73},
  [16095] = {.lex_state = 0},
  [16096] = {.lex_state = 0},
  [16097] = {.lex_state = 84},
  [16098] = {.lex_state = 0},
  [16099] = {.lex_state = 0, .external_lex_state = 72},
  [16100] = {.lex_state = 0, .external_lex_state = 25},
  [16101] = {.lex_state = 0, .external_lex_state = 25},
  [16102] = {.lex_state = 0},
  [16103] = {.lex_state = 0},
  [16104] = {.lex_state = 0},
  [16105] = {.lex_state = 0},
  [16106] = {.lex_state = 0},
  [16107] = {.lex_state = 0},
  [16108] = {.lex_state = 0},
  [16109] = {.lex_state = 0},
  [16110] = {.lex_state = 0},
  [16111] = {.lex_state = 0},
  [16112] = {.lex_state = 84},
  [16113] = {.lex_state = 0},
  [16114] = {.lex_state = 0, .external_lex_state = 72},
  [16115] = {.lex_state = 0, .external_lex_state = 73},
  [16116] = {.lex_state = 0},
  [16117] = {.lex_state = 0},
  [16118] = {.lex_state = 0},
  [16119] = {.lex_state = 0, .external_lex_state = 25},
  [16120] = {.lex_state = 0},
  [16121] = {.lex_state = 0, .external_lex_state = 25},
  [16122] = {.lex_state = 0},
  [16123] = {.lex_state = 0},
  [16124] = {.lex_state = 84},
  [16125] = {.lex_state = 0},
  [16126] = {.lex_state = 84},
  [16127] = {.lex_state = 0, .external_lex_state = 73},
  [16128] = {.lex_state = 0, .external_lex_state = 72},
  [16129] = {.lex_state = 84},
  [16130] = {.lex_state = 0, .external_lex_state = 25},
  [16131] = {.lex_state = 84},
  [16132] = {.lex_state = 0, .external_lex_state = 72},
  [16133] = {.lex_state = 0},
  [16134] = {.lex_state = 0, .external_lex_state = 73},
  [16135] = {.lex_state = 0},
  [16136] = {.lex_state = 0},
  [16137] = {.lex_state = 0},
  [16138] = {.lex_state = 0},
  [16139] = {.lex_state = 0},
  [16140] = {.lex_state = 84},
  [16141] = {.lex_state = 0},
  [16142] = {.lex_state = 0},
  [16143] = {.lex_state = 0},
  [16144] = {.lex_state = 0},
  [16145] = {.lex_state = 0, .external_lex_state = 72},
  [16146] = {.lex_state = 0, .external_lex_state = 73},
  [16147] = {.lex_state = 84},
  [16148] = {.lex_state = 0},
  [16149] = {.lex_state = 0},
  [16150] = {.lex_state = 0},
  [16151] = {.lex_state = 0},
  [16152] = {.lex_state = 0},
  [16153] = {.lex_state = 0},
  [16154] = {.lex_state = 0},
  [16155] = {.lex_state = 0},
  [16156] = {.lex_state = 0, .external_lex_state = 25},
  [16157] = {.lex_state = 0},
  [16158] = {.lex_state = 84},
  [16159] = {.lex_state = 84},
  [16160] = {.lex_state = 0},
  [16161] = {.lex_state = 0, .external_lex_state = 72},
  [16162] = {.lex_state = 0, .external_lex_state = 25},
  [16163] = {.lex_state = 0, .external_lex_state = 73},
  [16164] = {.lex_state = 0},
  [16165] = {.lex_state = 0},
  [16166] = {.lex_state = 0},
  [16167] = {.lex_state = 0},
  [16168] = {.lex_state = 0},
  [16169] = {.lex_state = 0},
  [16170] = {.lex_state = 0},
  [16171] = {.lex_state = 0},
  [16172] = {.lex_state = 84},
  [16173] = {.lex_state = 0, .external_lex_state = 72},
  [16174] = {.lex_state = 0},
  [16175] = {.lex_state = 0, .external_lex_state = 73},
  [16176] = {.lex_state = 0, .external_lex_state = 73},
  [16177] = {.lex_state = 84},
  [16178] = {.lex_state = 0, .external_lex_state = 72},
  [16179] = {.lex_state = 0},
  [16180] = {.lex_state = 0},
  [16181] = {.lex_state = 0},
  [16182] = {.lex_state = 0},
  [16183] = {.lex_state = 0, .external_lex_state = 25},
  [16184] = {.lex_state = 84},
  [16185] = {.lex_state = 0, .external_lex_state = 25},
  [16186] = {.lex_state = 84},
  [16187] = {.lex_state = 0, .external_lex_state = 25},
  [16188] = {.lex_state = 0},
  [16189] = {.lex_state = 0, .external_lex_state = 25},
  [16190] = {.lex_state = 0},
  [16191] = {.lex_state = 0},
  [16192] = {.lex_state = 0, .external_lex_state = 72},
  [16193] = {.lex_state = 0, .external_lex_state = 73},
  [16194] = {.lex_state = 0},
  [16195] = {.lex_state = 0},
  [16196] = {.lex_state = 0},
  [16197] = {.lex_state = 0},
  [16198] = {.lex_state = 0, .external_lex_state = 73},
  [16199] = {.lex_state = 0},
  [16200] = {.lex_state = 0},
  [16201] = {.lex_state = 0, .external_lex_state = 72},
  [16202] = {.lex_state = 0, .external_lex_state = 73},
  [16203] = {.lex_state = 0},
  [16204] = {.lex_state = 0},
  [16205] = {.lex_state = 0, .external_lex_state = 72},
  [16206] = {.lex_state = 0},
  [16207] = {.lex_state = 84},
  [16208] = {.lex_state = 0},
  [16209] = {.lex_state = 84},
  [16210] = {.lex_state = 0},
  [16211] = {.lex_state = 0},
  [16212] = {.lex_state = 84},
  [16213] = {.lex_state = 0, .external_lex_state = 25},
  [16214] = {.lex_state = 0, .external_lex_state = 25},
  [16215] = {.lex_state = 0},
  [16216] = {.lex_state = 0},
  [16217] = {.lex_state = 84},
  [16218] = {.lex_state = 0},
  [16219] = {.lex_state = 84},
  [16220] = {.lex_state = 0},
  [16221] = {.lex_state = 0, .external_lex_state = 72},
  [16222] = {.lex_state = 0, .external_lex_state = 73},
  [16223] = {.lex_state = 0},
  [16224] = {.lex_state = 0},
  [16225] = {.lex_state = 0},
  [16226] = {.lex_state = 0},
  [16227] = {.lex_state = 0},
  [16228] = {.lex_state = 0},
  [16229] = {.lex_state = 0},
  [16230] = {.lex_state = 0, .external_lex_state = 73},
  [16231] = {.lex_state = 0},
  [16232] = {.lex_state = 0, .external_lex_state = 72},
  [16233] = {.lex_state = 0, .external_lex_state = 73},
  [16234] = {.lex_state = 84},
  [16235] = {.lex_state = 0},
  [16236] = {.lex_state = 0, .external_lex_state = 72},
  [16237] = {.lex_state = 0},
  [16238] = {.lex_state = 84},
  [16239] = {.lex_state = 0},
  [16240] = {.lex_state = 0},
  [16241] = {.lex_state = 0, .external_lex_state = 25},
  [16242] = {.lex_state = 84},
  [16243] = {.lex_state = 0, .external_lex_state = 25},
  [16244] = {.lex_state = 84},
  [16245] = {.lex_state = 0},
  [16246] = {.lex_state = 84},
  [16247] = {.lex_state = 84},
  [16248] = {.lex_state = 0},
  [16249] = {.lex_state = 0},
  [16250] = {.lex_state = 0, .external_lex_state = 72},
  [16251] = {.lex_state = 0, .external_lex_state = 73},
  [16252] = {.lex_state = 0},
  [16253] = {.lex_state = 0},
  [16254] = {.lex_state = 84},
  [16255] = {.lex_state = 0},
  [16256] = {.lex_state = 0},
  [16257] = {.lex_state = 0, .external_lex_state = 25},
  [16258] = {.lex_state = 0},
  [16259] = {.lex_state = 0, .external_lex_state = 72},
  [16260] = {.lex_state = 0},
  [16261] = {.lex_state = 0, .external_lex_state = 73},
  [16262] = {.lex_state = 0},
  [16263] = {.lex_state = 0},
  [16264] = {.lex_state = 0, .external_lex_state = 25},
  [16265] = {.lex_state = 0},
  [16266] = {.lex_state = 0},
  [16267] = {.lex_state = 0},
  [16268] = {.lex_state = 0, .external_lex_state = 25},
  [16269] = {.lex_state = 0, .external_lex_state = 73},
  [16270] = {.lex_state = 0, .external_lex_state = 72},
  [16271] = {.lex_state = 84},
  [16272] = {.lex_state = 0, .external_lex_state = 25},
  [16273] = {.lex_state = 0},
  [16274] = {.lex_state = 0},
  [16275] = {.lex_state = 0},
  [16276] = {.lex_state = 84},
  [16277] = {.lex_state = 0},
  [16278] = {.lex_state = 0, .external_lex_state = 72},
  [16279] = {.lex_state = 0, .external_lex_state = 73},
  [16280] = {.lex_state = 0},
  [16281] = {.lex_state = 84},
  [16282] = {.lex_state = 0},
  [16283] = {.lex_state = 0},
  [16284] = {.lex_state = 0},
  [16285] = {.lex_state = 0},
  [16286] = {.lex_state = 0},
  [16287] = {.lex_state = 0},
  [16288] = {.lex_state = 84},
  [16289] = {.lex_state = 0},
  [16290] = {.lex_state = 0, .external_lex_state = 73},
  [16291] = {.lex_state = 0},
  [16292] = {.lex_state = 0},
  [16293] = {.lex_state = 84},
  [16294] = {.lex_state = 0, .external_lex_state = 73},
  [16295] = {.lex_state = 0},
  [16296] = {.lex_state = 0, .external_lex_state = 25},
  [16297] = {.lex_state = 0, .external_lex_state = 72},
  [16298] = {.lex_state = 0},
  [16299] = {.lex_state = 84},
  [16300] = {.lex_state = 84},
  [16301] = {.lex_state = 0, .external_lex_state = 25},
  [16302] = {.lex_state = 84},
  [16303] = {.lex_state = 0},
  [16304] = {.lex_state = 0, .external_lex_state = 72},
  [16305] = {.lex_state = 0},
  [16306] = {.lex_state = 0, .external_lex_state = 73},
  [16307] = {.lex_state = 0},
  [16308] = {.lex_state = 0},
  [16309] = {.lex_state = 84},
  [16310] = {.lex_state = 0},
  [16311] = {.lex_state = 0},
  [16312] = {.lex_state = 0},
  [16313] = {.lex_state = 0},
  [16314] = {.lex_state = 84},
  [16315] = {.lex_state = 0},
  [16316] = {.lex_state = 0},
  [16317] = {.lex_state = 0, .external_lex_state = 72},
  [16318] = {.lex_state = 0, .external_lex_state = 25},
  [16319] = {.lex_state = 0, .external_lex_state = 73},
  [16320] = {.lex_state = 0},
  [16321] = {.lex_state = 84},
  [16322] = {.lex_state = 84},
  [16323] = {.lex_state = 0},
  [16324] = {.lex_state = 0, .external_lex_state = 25},
  [16325] = {.lex_state = 0, .external_lex_state = 25},
  [16326] = {.lex_state = 84},
  [16327] = {.lex_state = 0},
  [16328] = {.lex_state = 0, .external_lex_state = 25},
  [16329] = {.lex_state = 0},
  [16330] = {.lex_state = 0, .external_lex_state = 72},
  [16331] = {.lex_state = 0, .external_lex_state = 73},
  [16332] = {.lex_state = 0},
  [16333] = {.lex_state = 0},
  [16334] = {.lex_state = 0},
  [16335] = {.lex_state = 0},
  [16336] = {.lex_state = 0},
  [16337] = {.lex_state = 0},
  [16338] = {.lex_state = 0, .external_lex_state = 73},
  [16339] = {.lex_state = 0},
  [16340] = {.lex_state = 0, .external_lex_state = 72},
  [16341] = {.lex_state = 0},
  [16342] = {.lex_state = 84},
  [16343] = {.lex_state = 0, .external_lex_state = 73},
  [16344] = {.lex_state = 0},
  [16345] = {.lex_state = 0, .external_lex_state = 72},
  [16346] = {.lex_state = 0},
  [16347] = {.lex_state = 84},
  [16348] = {.lex_state = 0},
  [16349] = {.lex_state = 0},
  [16350] = {.lex_state = 0},
  [16351] = {.lex_state = 0, .external_lex_state = 25},
  [16352] = {.lex_state = 0, .external_lex_state = 25},
  [16353] = {.lex_state = 0},
  [16354] = {.lex_state = 84},
  [16355] = {.lex_state = 84},
  [16356] = {.lex_state = 0},
  [16357] = {.lex_state = 0, .external_lex_state = 72},
  [16358] = {.lex_state = 0, .external_lex_state = 72},
  [16359] = {.lex_state = 0},
  [16360] = {.lex_state = 0, .external_lex_state = 73},
  [16361] = {.lex_state = 0},
  [16362] = {.lex_state = 0},
  [16363] = {.lex_state = 0},
  [16364] = {.lex_state = 0},
  [16365] = {.lex_state = 0},
  [16366] = {.lex_state = 0},
  [16367] = {.lex_state = 0, .external_lex_state = 73},
  [16368] = {.lex_state = 0},
  [16369] = {.lex_state = 0, .external_lex_state = 72},
  [16370] = {.lex_state = 0},
  [16371] = {.lex_state = 0, .external_lex_state = 73},
  [16372] = {.lex_state = 0, .external_lex_state = 72},
  [16373] = {.lex_state = 84},
  [16374] = {.lex_state = 0},
  [16375] = {.lex_state = 84},
  [16376] = {.lex_state = 84},
  [16377] = {.lex_state = 0},
  [16378] = {.lex_state = 0},
  [16379] = {.lex_state = 0, .external_lex_state = 25},
  [16380] = {.lex_state = 84},
  [16381] = {.lex_state = 0, .external_lex_state = 25},
  [16382] = {.lex_state = 0},
  [16383] = {.lex_state = 0},
  [16384] = {.lex_state = 0},
  [16385] = {.lex_state = 0, .external_lex_state = 25},
  [16386] = {.lex_state = 0},
  [16387] = {.lex_state = 84},
  [16388] = {.lex_state = 84},
  [16389] = {.lex_state = 0},
  [16390] = {.lex_state = 0},
  [16391] = {.lex_state = 0},
  [16392] = {.lex_state = 0},
  [16393] = {.lex_state = 84},
  [16394] = {.lex_state = 0},
  [16395] = {.lex_state = 0, .external_lex_state = 25},
  [16396] = {.lex_state = 0},
  [16397] = {.lex_state = 0},
  [16398] = {.lex_state = 84},
  [16399] = {.lex_state = 0},
  [16400] = {.lex_state = 0},
  [16401] = {.lex_state = 0},
  [16402] = {.lex_state = 84},
  [16403] = {.lex_state = 0},
  [16404] = {.lex_state = 84},
  [16405] = {.lex_state = 0, .external_lex_state = 25},
  [16406] = {.lex_state = 84},
  [16407] = {.lex_state = 0},
  [16408] = {.lex_state = 0, .external_lex_state = 25},
  [16409] = {.lex_state = 84},
  [16410] = {.lex_state = 0},
  [16411] = {.lex_state = 0},
  [16412] = {.lex_state = 0},
  [16413] = {.lex_state = 0},
  [16414] = {.lex_state = 84},
  [16415] = {.lex_state = 84},
  [16416] = {.lex_state = 0},
  [16417] = {.lex_state = 0},
  [16418] = {.lex_state = 0},
  [16419] = {.lex_state = 84},
  [16420] = {.lex_state = 0},
  [16421] = {.lex_state = 0, .external_lex_state = 25},
  [16422] = {.lex_state = 0},
  [16423] = {.lex_state = 0},
  [16424] = {.lex_state = 0},
  [16425] = {.lex_state = 0},
  [16426] = {.lex_state = 84},
  [16427] = {.lex_state = 0},
  [16428] = {.lex_state = 0},
  [16429] = {.lex_state = 84},
  [16430] = {.lex_state = 0},
  [16431] = {.lex_state = 84},
  [16432] = {.lex_state = 0, .external_lex_state = 25},
  [16433] = {.lex_state = 0},
  [16434] = {.lex_state = 0},
  [16435] = {.lex_state = 0, .external_lex_state = 25},
  [16436] = {.lex_state = 0},
  [16437] = {.lex_state = 0},
  [16438] = {.lex_state = 0},
  [16439] = {.lex_state = 84},
  [16440] = {.lex_state = 0},
  [16441] = {.lex_state = 0, .external_lex_state = 25},
  [16442] = {.lex_state = 84},
  [16443] = {.lex_state = 0},
  [16444] = {.lex_state = 84},
  [16445] = {.lex_state = 0},
  [16446] = {.lex_state = 0},
  [16447] = {.lex_state = 0},
  [16448] = {.lex_state = 0},
  [16449] = {.lex_state = 84},
  [16450] = {.lex_state = 0},
  [16451] = {.lex_state = 0, .external_lex_state = 25},
  [16452] = {.lex_state = 0},
  [16453] = {.lex_state = 0},
  [16454] = {.lex_state = 84},
  [16455] = {.lex_state = 0},
  [16456] = {.lex_state = 0},
  [16457] = {.lex_state = 0},
  [16458] = {.lex_state = 84},
  [16459] = {.lex_state = 0},
  [16460] = {.lex_state = 0},
  [16461] = {.lex_state = 0, .external_lex_state = 25},
  [16462] = {.lex_state = 0},
  [16463] = {.lex_state = 84},
  [16464] = {.lex_state = 0},
  [16465] = {.lex_state = 0},
  [16466] = {.lex_state = 84},
  [16467] = {.lex_state = 0},
  [16468] = {.lex_state = 0},
  [16469] = {.lex_state = 0, .external_lex_state = 25},
  [16470] = {.lex_state = 84},
  [16471] = {.lex_state = 0},
  [16472] = {.lex_state = 0},
  [16473] = {.lex_state = 0},
  [16474] = {.lex_state = 84},
  [16475] = {.lex_state = 84},
  [16476] = {.lex_state = 0},
  [16477] = {.lex_state = 0, .external_lex_state = 25},
  [16478] = {.lex_state = 0},
  [16479] = {.lex_state = 0},
  [16480] = {.lex_state = 0},
  [16481] = {.lex_state = 84},
  [16482] = {.lex_state = 0},
  [16483] = {.lex_state = 84},
  [16484] = {.lex_state = 0},
  [16485] = {.lex_state = 0, .external_lex_state = 25},
  [16486] = {.lex_state = 0},
  [16487] = {.lex_state = 0},
  [16488] = {.lex_state = 0, .external_lex_state = 25},
  [16489] = {.lex_state = 0},
  [16490] = {.lex_state = 0},
  [16491] = {.lex_state = 84},
  [16492] = {.lex_state = 0},
  [16493] = {.lex_state = 0},
  [16494] = {.lex_state = 76},
  [16495] = {.lex_state = 0},
  [16496] = {.lex_state = 0},
  [16497] = {.lex_state = 84},
  [16498] = {.lex_state = 84},
  [16499] = {.lex_state = 0},
  [16500] = {.lex_state = 0},
  [16501] = {.lex_state = 0, .external_lex_state = 25},
  [16502] = {.lex_state = 0},
  [16503] = {.lex_state = 84},
  [16504] = {.lex_state = 0},
  [16505] = {.lex_state = 76},
  [16506] = {.lex_state = 0},
  [16507] = {.lex_state = 84},
  [16508] = {.lex_state = 0},
  [16509] = {.lex_state = 84},
  [16510] = {.lex_state = 0},
  [16511] = {.lex_state = 0},
  [16512] = {.lex_state = 0},
  [16513] = {.lex_state = 0, .external_lex_state = 25},
  [16514] = {.lex_state = 84},
  [16515] = {.lex_state = 0},
  [16516] = {.lex_state = 0, .external_lex_state = 25},
  [16517] = {.lex_state = 0},
  [16518] = {.lex_state = 84},
  [16519] = {.lex_state = 0},
  [16520] = {.lex_state = 0},
  [16521] = {.lex_state = 0},
  [16522] = {.lex_state = 84},
  [16523] = {.lex_state = 0},
  [16524] = {.lex_state = 76},
  [16525] = {.lex_state = 76},
  [16526] = {.lex_state = 0},
  [16527] = {.lex_state = 84},
  [16528] = {.lex_state = 0},
  [16529] = {.lex_state = 84},
  [16530] = {.lex_state = 0},
  [16531] = {.lex_state = 0},
  [16532] = {.lex_state = 0, .external_lex_state = 25},
  [16533] = {.lex_state = 0, .external_lex_state = 25},
  [16534] = {.lex_state = 0},
  [16535] = {.lex_state = 84},
  [16536] = {.lex_state = 0},
  [16537] = {.lex_state = 84},
  [16538] = {.lex_state = 0},
  [16539] = {.lex_state = 0},
  [16540] = {.lex_state = 0},
  [16541] = {.lex_state = 0},
  [16542] = {.lex_state = 0},
  [16543] = {.lex_state = 0},
  [16544] = {.lex_state = 84},
  [16545] = {.lex_state = 84},
  [16546] = {.lex_state = 0},
  [16547] = {.lex_state = 0},
  [16548] = {.lex_state = 76},
  [16549] = {.lex_state = 76},
  [16550] = {.lex_state = 0},
  [16551] = {.lex_state = 84},
  [16552] = {.lex_state = 0},
  [16553] = {.lex_state = 84},
  [16554] = {.lex_state = 0},
  [16555] = {.lex_state = 0},
  [16556] = {.lex_state = 84},
  [16557] = {.lex_state = 0},
  [16558] = {.lex_state = 0, .external_lex_state = 25},
  [16559] = {.lex_state = 84},
  [16560] = {.lex_state = 0},
  [16561] = {.lex_state = 0},
  [16562] = {.lex_state = 0, .external_lex_state = 25},
  [16563] = {.lex_state = 84},
  [16564] = {.lex_state = 0},
  [16565] = {.lex_state = 0},
  [16566] = {.lex_state = 84},
  [16567] = {.lex_state = 84},
  [16568] = {.lex_state = 0},
  [16569] = {.lex_state = 84},
  [16570] = {.lex_state = 0, .external_lex_state = 25},
  [16571] = {.lex_state = 76},
  [16572] = {.lex_state = 76},
  [16573] = {.lex_state = 0},
  [16574] = {.lex_state = 84},
  [16575] = {.lex_state = 0},
  [16576] = {.lex_state = 84, .external_lex_state = 64},
  [16577] = {.lex_state = 84, .external_lex_state = 64},
  [16578] = {.lex_state = 84, .external_lex_state = 64},
  [16579] = {.lex_state = 84, .external_lex_state = 64},
  [16580] = {.lex_state = 84, .external_lex_state = 64},
  [16581] = {.lex_state = 0, .external_lex_state = 73},
  [16582] = {.lex_state = 84, .external_lex_state = 64},
  [16583] = {.lex_state = 84, .external_lex_state = 64},
  [16584] = {.lex_state = 84, .external_lex_state = 64},
  [16585] = {.lex_state = 84, .external_lex_state = 64},
  [16586] = {.lex_state = 0, .external_lex_state = 25},
  [16587] = {.lex_state = 84, .external_lex_state = 64},
  [16588] = {.lex_state = 0, .external_lex_state = 72},
  [16589] = {.lex_state = 84, .external_lex_state = 64},
  [16590] = {.lex_state = 84, .external_lex_state = 64},
  [16591] = {.lex_state = 0},
  [16592] = {.lex_state = 0},
  [16593] = {.lex_state = 84, .external_lex_state = 64},
  [16594] = {.lex_state = 84},
  [16595] = {.lex_state = 84},
  [16596] = {.lex_state = 0},
  [16597] = {.lex_state = 0},
  [16598] = {.lex_state = 84, .external_lex_state = 64},
  [16599] = {.lex_state = 0, .external_lex_state = 73},
  [16600] = {.lex_state = 0},
  [16601] = {.lex_state = 0, .external_lex_state = 72},
  [16602] = {.lex_state = 76},
  [16603] = {.lex_state = 0},
  [16604] = {.lex_state = 76},
  [16605] = {.lex_state = 0, .external_lex_state = 73},
  [16606] = {.lex_state = 0, .external_lex_state = 73},
  [16607] = {.lex_state = 0, .external_lex_state = 73},
  [16608] = {.lex_state = 76},
  [16609] = {.lex_state = 0},
  [16610] = {.lex_state = 0},
  [16611] = {.lex_state = 84, .external_lex_state = 64},
  [16612] = {.lex_state = 84, .external_lex_state = 64},
  [16613] = {.lex_state = 84, .external_lex_state = 64},
  [16614] = {.lex_state = 0},
  [16615] = {.lex_state = 0},
  [16616] = {.lex_state = 0, .external_lex_state = 25},
  [16617] = {.lex_state = 0},
  [16618] = {.lex_state = 84, .external_lex_state = 64},
  [16619] = {.lex_state = 0},
  [16620] = {.lex_state = 0},
  [16621] = {.lex_state = 0},
  [16622] = {.lex_state = 84, .external_lex_state = 49},
  [16623] = {.lex_state = 0},
  [16624] = {.lex_state = 0},
  [16625] = {.lex_state = 0},
  [16626] = {.lex_state = 0, .external_lex_state = 72},
  [16627] = {.lex_state = 0},
  [16628] = {.lex_state = 84},
  [16629] = {.lex_state = 84},
  [16630] = {.lex_state = 0},
  [16631] = {.lex_state = 0},
  [16632] = {.lex_state = 0, .external_lex_state = 72},
  [16633] = {.lex_state = 0, .external_lex_state = 72},
  [16634] = {.lex_state = 0},
  [16635] = {.lex_state = 0},
  [16636] = {.lex_state = 0},
  [16637] = {.lex_state = 0},
  [16638] = {.lex_state = 84, .external_lex_state = 49},
  [16639] = {.lex_state = 0, .external_lex_state = 73},
  [16640] = {.lex_state = 0, .external_lex_state = 72},
  [16641] = {.lex_state = 0},
  [16642] = {.lex_state = 0},
  [16643] = {.lex_state = 0},
  [16644] = {.lex_state = 0},
  [16645] = {.lex_state = 0},
  [16646] = {.lex_state = 0},
  [16647] = {.lex_state = 0, .external_lex_state = 25},
  [16648] = {.lex_state = 84, .external_lex_state = 49},
  [16649] = {.lex_state = 0, .external_lex_state = 25},
  [16650] = {.lex_state = 0},
  [16651] = {.lex_state = 0},
  [16652] = {.lex_state = 84},
  [16653] = {.lex_state = 0},
  [16654] = {.lex_state = 0},
  [16655] = {.lex_state = 0},
  [16656] = {.lex_state = 0},
  [16657] = {.lex_state = 0},
  [16658] = {.lex_state = 84, .external_lex_state = 49},
  [16659] = {.lex_state = 84},
  [16660] = {.lex_state = 84},
  [16661] = {.lex_state = 0},
  [16662] = {.lex_state = 84},
  [16663] = {.lex_state = 0, .external_lex_state = 25},
  [16664] = {.lex_state = 0},
  [16665] = {.lex_state = 0},
  [16666] = {.lex_state = 0},
  [16667] = {.lex_state = 84, .external_lex_state = 49},
  [16668] = {.lex_state = 84, .external_lex_state = 49},
  [16669] = {.lex_state = 0, .external_lex_state = 25},
  [16670] = {.lex_state = 0},
  [16671] = {.lex_state = 0},
  [16672] = {.lex_state = 0, .external_lex_state = 25},
  [16673] = {.lex_state = 84, .external_lex_state = 49},
  [16674] = {.lex_state = 0, .external_lex_state = 73},
  [16675] = {.lex_state = 0},
  [16676] = {.lex_state = 84},
  [16677] = {.lex_state = 84},
  [16678] = {.lex_state = 76},
  [16679] = {.lex_state = 76},
  [16680] = {.lex_state = 0},
  [16681] = {.lex_state = 84},
  [16682] = {.lex_state = 84, .external_lex_state = 49},
  [16683] = {.lex_state = 0},
  [16684] = {.lex_state = 84},
  [16685] = {.lex_state = 1},
  [16686] = {.lex_state = 0},
  [16687] = {.lex_state = 84},
  [16688] = {.lex_state = 9},
  [16689] = {.lex_state = 9},
  [16690] = {.lex_state = 84, .external_lex_state = 51},
  [16691] = {.lex_state = 0, .external_lex_state = 64},
  [16692] = {.lex_state = 0},
  [16693] = {.lex_state = 0},
  [16694] = {.lex_state = 84, .external_lex_state = 51},
  [16695] = {.lex_state = 9},
  [16696] = {.lex_state = 9},
  [16697] = {.lex_state = 9},
  [16698] = {.lex_state = 9},
  [16699] = {.lex_state = 0, .external_lex_state = 64},
  [16700] = {.lex_state = 0},
  [16701] = {.lex_state = 0},
  [16702] = {.lex_state = 0},
  [16703] = {.lex_state = 0},
  [16704] = {.lex_state = 0},
  [16705] = {.lex_state = 0},
  [16706] = {.lex_state = 0},
  [16707] = {.lex_state = 0, .external_lex_state = 64},
  [16708] = {.lex_state = 0},
  [16709] = {.lex_state = 84},
  [16710] = {.lex_state = 0},
  [16711] = {.lex_state = 0},
  [16712] = {.lex_state = 84, .external_lex_state = 51},
  [16713] = {.lex_state = 9},
  [16714] = {.lex_state = 9},
  [16715] = {.lex_state = 9},
  [16716] = {.lex_state = 9},
  [16717] = {.lex_state = 0, .external_lex_state = 64},
  [16718] = {.lex_state = 0},
  [16719] = {.lex_state = 0},
  [16720] = {.lex_state = 0},
  [16721] = {.lex_state = 84, .external_lex_state = 51},
  [16722] = {.lex_state = 0, .external_lex_state = 64},
  [16723] = {.lex_state = 0},
  [16724] = {.lex_state = 0},
  [16725] = {.lex_state = 0, .external_lex_state = 64},
  [16726] = {.lex_state = 0},
  [16727] = {.lex_state = 0},
  [16728] = {.lex_state = 0, .external_lex_state = 64},
  [16729] = {.lex_state = 0},
  [16730] = {.lex_state = 0},
  [16731] = {.lex_state = 0},
  [16732] = {.lex_state = 0},
  [16733] = {.lex_state = 9},
  [16734] = {.lex_state = 0, .external_lex_state = 64},
  [16735] = {.lex_state = 9},
  [16736] = {.lex_state = 9},
  [16737] = {.lex_state = 9},
  [16738] = {.lex_state = 0},
  [16739] = {.lex_state = 0},
  [16740] = {.lex_state = 84},
  [16741] = {.lex_state = 0},
  [16742] = {.lex_state = 0},
  [16743] = {.lex_state = 0},
  [16744] = {.lex_state = 0},
  [16745] = {.lex_state = 84, .external_lex_state = 51},
  [16746] = {.lex_state = 0},
  [16747] = {.lex_state = 84, .external_lex_state = 51},
  [16748] = {.lex_state = 0},
  [16749] = {.lex_state = 0},
  [16750] = {.lex_state = 84, .external_lex_state = 51},
  [16751] = {.lex_state = 0},
  [16752] = {.lex_state = 9},
  [16753] = {.lex_state = 0, .external_lex_state = 64},
  [16754] = {.lex_state = 9},
  [16755] = {.lex_state = 9},
  [16756] = {.lex_state = 0},
  [16757] = {.lex_state = 9},
  [16758] = {.lex_state = 0},
  [16759] = {.lex_state = 0},
  [16760] = {.lex_state = 0},
  [16761] = {.lex_state = 0},
  [16762] = {.lex_state = 0},
  [16763] = {.lex_state = 9},
  [16764] = {.lex_state = 0},
  [16765] = {.lex_state = 9},
  [16766] = {.lex_state = 9},
  [16767] = {.lex_state = 9},
  [16768] = {.lex_state = 0},
  [16769] = {.lex_state = 0},
  [16770] = {.lex_state = 0},
  [16771] = {.lex_state = 0},
  [16772] = {.lex_state = 0},
  [16773] = {.lex_state = 0, .external_lex_state = 64},
  [16774] = {.lex_state = 0, .external_lex_state = 64},
  [16775] = {.lex_state = 84, .external_lex_state = 51},
  [16776] = {.lex_state = 0},
  [16777] = {.lex_state = 0},
  [16778] = {.lex_state = 0},
  [16779] = {.lex_state = 0, .external_lex_state = 64},
  [16780] = {.lex_state = 84, .external_lex_state = 51},
  [16781] = {.lex_state = 84},
  [16782] = {.lex_state = 84},
  [16783] = {.lex_state = 0},
  [16784] = {.lex_state = 0},
  [16785] = {.lex_state = 84, .external_lex_state = 51},
  [16786] = {.lex_state = 0, .external_lex_state = 64},
  [16787] = {.lex_state = 0},
  [16788] = {.lex_state = 0},
  [16789] = {.lex_state = 0},
  [16790] = {.lex_state = 9},
  [16791] = {.lex_state = 0},
  [16792] = {.lex_state = 9},
  [16793] = {.lex_state = 9},
  [16794] = {.lex_state = 9},
  [16795] = {.lex_state = 0, .external_lex_state = 64},
  [16796] = {.lex_state = 84, .external_lex_state = 51},
  [16797] = {.lex_state = 0},
  [16798] = {.lex_state = 0},
  [16799] = {.lex_state = 9},
  [16800] = {.lex_state = 9},
  [16801] = {.lex_state = 0, .external_lex_state = 64},
  [16802] = {.lex_state = 9},
  [16803] = {.lex_state = 9},
  [16804] = {.lex_state = 0},
  [16805] = {.lex_state = 0},
  [16806] = {.lex_state = 0},
  [16807] = {.lex_state = 0},
  [16808] = {.lex_state = 0},
  [16809] = {.lex_state = 0},
  [16810] = {.lex_state = 0},
  [16811] = {.lex_state = 0},
  [16812] = {.lex_state = 0},
  [16813] = {.lex_state = 0},
  [16814] = {.lex_state = 0, .external_lex_state = 64},
  [16815] = {.lex_state = 9},
  [16816] = {.lex_state = 0},
  [16817] = {.lex_state = 9},
  [16818] = {.lex_state = 9},
  [16819] = {.lex_state = 9},
  [16820] = {.lex_state = 0},
  [16821] = {.lex_state = 0, .external_lex_state = 64},
  [16822] = {.lex_state = 0},
  [16823] = {.lex_state = 0},
  [16824] = {.lex_state = 0},
  [16825] = {.lex_state = 0},
  [16826] = {.lex_state = 0},
  [16827] = {.lex_state = 0, .external_lex_state = 64},
  [16828] = {.lex_state = 84, .external_lex_state = 51},
  [16829] = {.lex_state = 84},
  [16830] = {.lex_state = 84},
  [16831] = {.lex_state = 0},
  [16832] = {.lex_state = 0},
  [16833] = {.lex_state = 84, .external_lex_state = 51},
  [16834] = {.lex_state = 0, .external_lex_state = 64},
  [16835] = {.lex_state = 0},
  [16836] = {.lex_state = 0},
  [16837] = {.lex_state = 0},
  [16838] = {.lex_state = 0},
  [16839] = {.lex_state = 84, .external_lex_state = 51},
  [16840] = {.lex_state = 9},
  [16841] = {.lex_state = 0, .external_lex_state = 64},
  [16842] = {.lex_state = 9},
  [16843] = {.lex_state = 9},
  [16844] = {.lex_state = 9},
  [16845] = {.lex_state = 9},
  [16846] = {.lex_state = 9},
  [16847] = {.lex_state = 0},
  [16848] = {.lex_state = 0},
  [16849] = {.lex_state = 0, .external_lex_state = 64},
  [16850] = {.lex_state = 9},
  [16851] = {.lex_state = 9},
  [16852] = {.lex_state = 0},
  [16853] = {.lex_state = 0},
  [16854] = {.lex_state = 0},
  [16855] = {.lex_state = 0},
  [16856] = {.lex_state = 0},
  [16857] = {.lex_state = 0},
  [16858] = {.lex_state = 0},
  [16859] = {.lex_state = 0},
  [16860] = {.lex_state = 0},
  [16861] = {.lex_state = 0, .external_lex_state = 64},
  [16862] = {.lex_state = 0},
  [16863] = {.lex_state = 0},
  [16864] = {.lex_state = 0},
  [16865] = {.lex_state = 0},
  [16866] = {.lex_state = 9},
  [16867] = {.lex_state = 9},
  [16868] = {.lex_state = 9},
  [16869] = {.lex_state = 0},
  [16870] = {.lex_state = 0, .external_lex_state = 64},
  [16871] = {.lex_state = 0},
  [16872] = {.lex_state = 0},
  [16873] = {.lex_state = 84, .external_lex_state = 51},
  [16874] = {.lex_state = 0},
  [16875] = {.lex_state = 0, .external_lex_state = 64},
  [16876] = {.lex_state = 84},
  [16877] = {.lex_state = 84, .external_lex_state = 51},
  [16878] = {.lex_state = 0},
  [16879] = {.lex_state = 84},
  [16880] = {.lex_state = 84, .external_lex_state = 51},
  [16881] = {.lex_state = 0, .external_lex_state = 64},
  [16882] = {.lex_state = 0},
  [16883] = {.lex_state = 0},
  [16884] = {.lex_state = 0},
  [16885] = {.lex_state = 84, .external_lex_state = 51},
  [16886] = {.lex_state = 0},
  [16887] = {.lex_state = 0},
  [16888] = {.lex_state = 0},
  [16889] = {.lex_state = 9},
  [16890] = {.lex_state = 9},
  [16891] = {.lex_state = 9},
  [16892] = {.lex_state = 9},
  [16893] = {.lex_state = 0, .external_lex_state = 64},
  [16894] = {.lex_state = 0},
  [16895] = {.lex_state = 0},
  [16896] = {.lex_state = 0},
  [16897] = {.lex_state = 0},
  [16898] = {.lex_state = 0},
  [16899] = {.lex_state = 0},
  [16900] = {.lex_state = 0},
  [16901] = {.lex_state = 0},
  [16902] = {.lex_state = 0},
  [16903] = {.lex_state = 0},
  [16904] = {.lex_state = 9},
  [16905] = {.lex_state = 0},
  [16906] = {.lex_state = 0},
  [16907] = {.lex_state = 0, .external_lex_state = 64},
  [16908] = {.lex_state = 0},
  [16909] = {.lex_state = 9},
  [16910] = {.lex_state = 9},
  [16911] = {.lex_state = 9},
  [16912] = {.lex_state = 9},
  [16913] = {.lex_state = 9},
  [16914] = {.lex_state = 9},
  [16915] = {.lex_state = 0},
  [16916] = {.lex_state = 9},
  [16917] = {.lex_state = 0},
  [16918] = {.lex_state = 0},
  [16919] = {.lex_state = 0, .external_lex_state = 64},
  [16920] = {.lex_state = 0},
  [16921] = {.lex_state = 84, .external_lex_state = 51},
  [16922] = {.lex_state = 84},
  [16923] = {.lex_state = 0},
  [16924] = {.lex_state = 0},
  [16925] = {.lex_state = 0, .external_lex_state = 64},
  [16926] = {.lex_state = 84, .external_lex_state = 51},
  [16927] = {.lex_state = 0, .external_lex_state = 64},
  [16928] = {.lex_state = 84, .external_lex_state = 51},
  [16929] = {.lex_state = 0},
  [16930] = {.lex_state = 0},
  [16931] = {.lex_state = 84},
  [16932] = {.lex_state = 84, .external_lex_state = 51},
  [16933] = {.lex_state = 9},
  [16934] = {.lex_state = 9},
  [16935] = {.lex_state = 9},
  [16936] = {.lex_state = 9},
  [16937] = {.lex_state = 0},
  [16938] = {.lex_state = 0, .external_lex_state = 64},
  [16939] = {.lex_state = 0},
  [16940] = {.lex_state = 0},
  [16941] = {.lex_state = 0, .external_lex_state = 64},
  [16942] = {.lex_state = 0},
  [16943] = {.lex_state = 0},
  [16944] = {.lex_state = 0},
  [16945] = {.lex_state = 0},
  [16946] = {.lex_state = 0},
  [16947] = {.lex_state = 0},
  [16948] = {.lex_state = 0},
  [16949] = {.lex_state = 0},
  [16950] = {.lex_state = 0},
  [16951] = {.lex_state = 0},
  [16952] = {.lex_state = 0},
  [16953] = {.lex_state = 0},
  [16954] = {.lex_state = 0, .external_lex_state = 64},
  [16955] = {.lex_state = 9},
  [16956] = {.lex_state = 9},
  [16957] = {.lex_state = 9},
  [16958] = {.lex_state = 9},
  [16959] = {.lex_state = 0},
  [16960] = {.lex_state = 0, .external_lex_state = 64},
  [16961] = {.lex_state = 0},
  [16962] = {.lex_state = 0},
  [16963] = {.lex_state = 0},
  [16964] = {.lex_state = 84, .external_lex_state = 51},
  [16965] = {.lex_state = 9},
  [16966] = {.lex_state = 9},
  [16967] = {.lex_state = 9},
  [16968] = {.lex_state = 84},
  [16969] = {.lex_state = 9},
  [16970] = {.lex_state = 0},
  [16971] = {.lex_state = 0},
  [16972] = {.lex_state = 84, .external_lex_state = 51},
  [16973] = {.lex_state = 0, .external_lex_state = 64},
  [16974] = {.lex_state = 0},
  [16975] = {.lex_state = 0},
  [16976] = {.lex_state = 0},
  [16977] = {.lex_state = 9},
  [16978] = {.lex_state = 9},
  [16979] = {.lex_state = 9},
  [16980] = {.lex_state = 9},
  [16981] = {.lex_state = 0},
  [16982] = {.lex_state = 84, .external_lex_state = 51},
  [16983] = {.lex_state = 0},
  [16984] = {.lex_state = 0},
  [16985] = {.lex_state = 0, .external_lex_state = 64},
  [16986] = {.lex_state = 84, .external_lex_state = 51},
  [16987] = {.lex_state = 0, .external_lex_state = 64},
  [16988] = {.lex_state = 84},
  [16989] = {.lex_state = 0},
  [16990] = {.lex_state = 0},
  [16991] = {.lex_state = 0, .external_lex_state = 64},
  [16992] = {.lex_state = 0},
  [16993] = {.lex_state = 0},
  [16994] = {.lex_state = 0},
  [16995] = {.lex_state = 0},
  [16996] = {.lex_state = 0},
  [16997] = {.lex_state = 0},
  [16998] = {.lex_state = 0},
  [16999] = {.lex_state = 9},
  [17000] = {.lex_state = 9},
  [17001] = {.lex_state = 9},
  [17002] = {.lex_state = 9},
  [17003] = {.lex_state = 0},
  [17004] = {.lex_state = 0, .external_lex_state = 64},
  [17005] = {.lex_state = 0},
  [17006] = {.lex_state = 0},
  [17007] = {.lex_state = 0},
  [17008] = {.lex_state = 0, .external_lex_state = 64},
  [17009] = {.lex_state = 0},
  [17010] = {.lex_state = 84, .external_lex_state = 51},
  [17011] = {.lex_state = 0},
  [17012] = {.lex_state = 0},
  [17013] = {.lex_state = 0},
  [17014] = {.lex_state = 84},
  [17015] = {.lex_state = 0, .external_lex_state = 64},
  [17016] = {.lex_state = 0},
  [17017] = {.lex_state = 0, .external_lex_state = 64},
  [17018] = {.lex_state = 0},
  [17019] = {.lex_state = 84, .external_lex_state = 51},
  [17020] = {.lex_state = 0, .external_lex_state = 64},
  [17021] = {.lex_state = 9},
  [17022] = {.lex_state = 9},
  [17023] = {.lex_state = 9},
  [17024] = {.lex_state = 9},
  [17025] = {.lex_state = 9},
  [17026] = {.lex_state = 0},
  [17027] = {.lex_state = 0},
  [17028] = {.lex_state = 0},
  [17029] = {.lex_state = 9},
  [17030] = {.lex_state = 84, .external_lex_state = 51},
  [17031] = {.lex_state = 9},
  [17032] = {.lex_state = 9},
  [17033] = {.lex_state = 0, .external_lex_state = 64},
  [17034] = {.lex_state = 84},
  [17035] = {.lex_state = 0},
  [17036] = {.lex_state = 0},
  [17037] = {.lex_state = 84, .external_lex_state = 51},
  [17038] = {.lex_state = 0},
  [17039] = {.lex_state = 0},
  [17040] = {.lex_state = 0},
  [17041] = {.lex_state = 0},
  [17042] = {.lex_state = 0},
  [17043] = {.lex_state = 9},
  [17044] = {.lex_state = 9},
  [17045] = {.lex_state = 9},
  [17046] = {.lex_state = 9},
  [17047] = {.lex_state = 0},
  [17048] = {.lex_state = 0},
  [17049] = {.lex_state = 0},
  [17050] = {.lex_state = 0},
  [17051] = {.lex_state = 0},
  [17052] = {.lex_state = 0, .external_lex_state = 64},
  [17053] = {.lex_state = 0, .external_lex_state = 64},
  [17054] = {.lex_state = 0},
  [17055] = {.lex_state = 0},
  [17056] = {.lex_state = 0},
  [17057] = {.lex_state = 0},
  [17058] = {.lex_state = 0, .external_lex_state = 64},
  [17059] = {.lex_state = 84, .external_lex_state = 51},
  [17060] = {.lex_state = 84},
  [17061] = {.lex_state = 0, .external_lex_state = 64},
  [17062] = {.lex_state = 0},
  [17063] = {.lex_state = 0},
  [17064] = {.lex_state = 9},
  [17065] = {.lex_state = 9},
  [17066] = {.lex_state = 9},
  [17067] = {.lex_state = 9},
  [17068] = {.lex_state = 0},
  [17069] = {.lex_state = 84, .external_lex_state = 51},
  [17070] = {.lex_state = 0},
  [17071] = {.lex_state = 0},
  [17072] = {.lex_state = 0, .external_lex_state = 64},
  [17073] = {.lex_state = 0, .external_lex_state = 64},
  [17074] = {.lex_state = 0},
  [17075] = {.lex_state = 84, .external_lex_state = 51},
  [17076] = {.lex_state = 84, .external_lex_state = 51},
  [17077] = {.lex_state = 0},
  [17078] = {.lex_state = 0},
  [17079] = {.lex_state = 0, .external_lex_state = 64},
  [17080] = {.lex_state = 84},
  [17081] = {.lex_state = 9},
  [17082] = {.lex_state = 0},
  [17083] = {.lex_state = 0},
  [17084] = {.lex_state = 9},
  [17085] = {.lex_state = 9},
  [17086] = {.lex_state = 9},
  [17087] = {.lex_state = 9},
  [17088] = {.lex_state = 9},
  [17089] = {.lex_state = 9},
  [17090] = {.lex_state = 0},
  [17091] = {.lex_state = 0},
  [17092] = {.lex_state = 0},
  [17093] = {.lex_state = 0},
  [17094] = {.lex_state = 0},
  [17095] = {.lex_state = 0},
  [17096] = {.lex_state = 9},
  [17097] = {.lex_state = 0},
  [17098] = {.lex_state = 0},
  [17099] = {.lex_state = 0, .external_lex_state = 64},
  [17100] = {.lex_state = 0},
  [17101] = {.lex_state = 0},
  [17102] = {.lex_state = 0},
  [17103] = {.lex_state = 0, .external_lex_state = 64},
  [17104] = {.lex_state = 0},
  [17105] = {.lex_state = 0},
  [17106] = {.lex_state = 9},
  [17107] = {.lex_state = 9},
  [17108] = {.lex_state = 9},
  [17109] = {.lex_state = 9},
  [17110] = {.lex_state = 0},
  [17111] = {.lex_state = 0},
  [17112] = {.lex_state = 0},
  [17113] = {.lex_state = 0},
  [17114] = {.lex_state = 84},
  [17115] = {.lex_state = 0, .external_lex_state = 64},
  [17116] = {.lex_state = 0},
  [17117] = {.lex_state = 84, .external_lex_state = 51},
  [17118] = {.lex_state = 84, .external_lex_state = 51},
  [17119] = {.lex_state = 0, .external_lex_state = 64},
  [17120] = {.lex_state = 0},
  [17121] = {.lex_state = 0},
  [17122] = {.lex_state = 0, .external_lex_state = 64},
  [17123] = {.lex_state = 84, .external_lex_state = 51},
  [17124] = {.lex_state = 84, .external_lex_state = 51},
  [17125] = {.lex_state = 0},
  [17126] = {.lex_state = 84},
  [17127] = {.lex_state = 9},
  [17128] = {.lex_state = 9},
  [17129] = {.lex_state = 9},
  [17130] = {.lex_state = 9},
  [17131] = {.lex_state = 0},
  [17132] = {.lex_state = 0},
  [17133] = {.lex_state = 0},
  [17134] = {.lex_state = 0},
  [17135] = {.lex_state = 0},
  [17136] = {.lex_state = 0},
  [17137] = {.lex_state = 0},
  [17138] = {.lex_state = 0, .external_lex_state = 64},
  [17139] = {.lex_state = 0},
  [17140] = {.lex_state = 0},
  [17141] = {.lex_state = 84, .external_lex_state = 51},
  [17142] = {.lex_state = 0},
  [17143] = {.lex_state = 0},
  [17144] = {.lex_state = 0},
  [17145] = {.lex_state = 0},
  [17146] = {.lex_state = 0},
  [17147] = {.lex_state = 0, .external_lex_state = 64},
  [17148] = {.lex_state = 9},
  [17149] = {.lex_state = 9},
  [17150] = {.lex_state = 9},
  [17151] = {.lex_state = 9},
  [17152] = {.lex_state = 9},
  [17153] = {.lex_state = 9},
  [17154] = {.lex_state = 0},
  [17155] = {.lex_state = 0},
  [17156] = {.lex_state = 0},
  [17157] = {.lex_state = 9},
  [17158] = {.lex_state = 9},
  [17159] = {.lex_state = 0},
  [17160] = {.lex_state = 0},
  [17161] = {.lex_state = 84},
  [17162] = {.lex_state = 0},
  [17163] = {.lex_state = 0},
  [17164] = {.lex_state = 0, .external_lex_state = 64},
  [17165] = {.lex_state = 84, .external_lex_state = 51},
  [17166] = {.lex_state = 0, .external_lex_state = 64},
  [17167] = {.lex_state = 0},
  [17168] = {.lex_state = 84, .external_lex_state = 51},
  [17169] = {.lex_state = 9},
  [17170] = {.lex_state = 9},
  [17171] = {.lex_state = 9},
  [17172] = {.lex_state = 9},
  [17173] = {.lex_state = 0},
  [17174] = {.lex_state = 0},
  [17175] = {.lex_state = 0},
  [17176] = {.lex_state = 0},
  [17177] = {.lex_state = 84, .external_lex_state = 51},
  [17178] = {.lex_state = 0, .external_lex_state = 64},
  [17179] = {.lex_state = 84, .external_lex_state = 51},
  [17180] = {.lex_state = 0, .external_lex_state = 64},
  [17181] = {.lex_state = 84},
  [17182] = {.lex_state = 0},
  [17183] = {.lex_state = 0},
  [17184] = {.lex_state = 0, .external_lex_state = 64},
  [17185] = {.lex_state = 0},
  [17186] = {.lex_state = 0},
  [17187] = {.lex_state = 0},
  [17188] = {.lex_state = 0},
  [17189] = {.lex_state = 0},
  [17190] = {.lex_state = 9},
  [17191] = {.lex_state = 9},
  [17192] = {.lex_state = 9},
  [17193] = {.lex_state = 9},
  [17194] = {.lex_state = 0},
  [17195] = {.lex_state = 0},
  [17196] = {.lex_state = 0},
  [17197] = {.lex_state = 0},
  [17198] = {.lex_state = 0},
  [17199] = {.lex_state = 0},
  [17200] = {.lex_state = 0, .external_lex_state = 64},
  [17201] = {.lex_state = 0},
  [17202] = {.lex_state = 0},
  [17203] = {.lex_state = 0},
  [17204] = {.lex_state = 0},
  [17205] = {.lex_state = 0, .external_lex_state = 64},
  [17206] = {.lex_state = 9},
  [17207] = {.lex_state = 9},
  [17208] = {.lex_state = 84},
  [17209] = {.lex_state = 0},
  [17210] = {.lex_state = 9},
  [17211] = {.lex_state = 9},
  [17212] = {.lex_state = 9},
  [17213] = {.lex_state = 9},
  [17214] = {.lex_state = 9},
  [17215] = {.lex_state = 0},
  [17216] = {.lex_state = 9},
  [17217] = {.lex_state = 0},
  [17218] = {.lex_state = 0},
  [17219] = {.lex_state = 84, .external_lex_state = 51},
  [17220] = {.lex_state = 0, .external_lex_state = 64},
  [17221] = {.lex_state = 0},
  [17222] = {.lex_state = 0},
  [17223] = {.lex_state = 0},
  [17224] = {.lex_state = 84, .external_lex_state = 51},
  [17225] = {.lex_state = 0, .external_lex_state = 64},
  [17226] = {.lex_state = 84, .external_lex_state = 51},
  [17227] = {.lex_state = 0, .external_lex_state = 64},
  [17228] = {.lex_state = 84},
  [17229] = {.lex_state = 0},
  [17230] = {.lex_state = 0},
  [17231] = {.lex_state = 0},
  [17232] = {.lex_state = 9},
  [17233] = {.lex_state = 9},
  [17234] = {.lex_state = 9},
  [17235] = {.lex_state = 9},
  [17236] = {.lex_state = 0, .external_lex_state = 64},
  [17237] = {.lex_state = 0},
  [17238] = {.lex_state = 0},
  [17239] = {.lex_state = 0},
  [17240] = {.lex_state = 0},
  [17241] = {.lex_state = 0},
  [17242] = {.lex_state = 0},
  [17243] = {.lex_state = 0},
  [17244] = {.lex_state = 0},
  [17245] = {.lex_state = 0},
  [17246] = {.lex_state = 0},
  [17247] = {.lex_state = 0, .external_lex_state = 64},
  [17248] = {.lex_state = 0},
  [17249] = {.lex_state = 0},
  [17250] = {.lex_state = 0},
  [17251] = {.lex_state = 0},
  [17252] = {.lex_state = 0},
  [17253] = {.lex_state = 9},
  [17254] = {.lex_state = 9},
  [17255] = {.lex_state = 9},
  [17256] = {.lex_state = 9},
  [17257] = {.lex_state = 84, .external_lex_state = 51},
  [17258] = {.lex_state = 84},
  [17259] = {.lex_state = 0},
  [17260] = {.lex_state = 0},
  [17261] = {.lex_state = 9},
  [17262] = {.lex_state = 84},
  [17263] = {.lex_state = 9},
  [17264] = {.lex_state = 0},
  [17265] = {.lex_state = 9},
  [17266] = {.lex_state = 84, .external_lex_state = 51},
  [17267] = {.lex_state = 0, .external_lex_state = 64},
  [17268] = {.lex_state = 9},
  [17269] = {.lex_state = 0},
  [17270] = {.lex_state = 0, .external_lex_state = 64},
  [17271] = {.lex_state = 84, .external_lex_state = 51},
  [17272] = {.lex_state = 0},
  [17273] = {.lex_state = 0},
  [17274] = {.lex_state = 9},
  [17275] = {.lex_state = 9},
  [17276] = {.lex_state = 9},
  [17277] = {.lex_state = 9},
  [17278] = {.lex_state = 84, .external_lex_state = 51},
  [17279] = {.lex_state = 0, .external_lex_state = 64},
  [17280] = {.lex_state = 0},
  [17281] = {.lex_state = 0},
  [17282] = {.lex_state = 0, .external_lex_state = 64},
  [17283] = {.lex_state = 0},
  [17284] = {.lex_state = 0},
  [17285] = {.lex_state = 0, .external_lex_state = 64},
  [17286] = {.lex_state = 0},
  [17287] = {.lex_state = 0},
  [17288] = {.lex_state = 0},
  [17289] = {.lex_state = 0},
  [17290] = {.lex_state = 0},
  [17291] = {.lex_state = 0},
  [17292] = {.lex_state = 0},
  [17293] = {.lex_state = 0},
  [17294] = {.lex_state = 0},
  [17295] = {.lex_state = 9},
  [17296] = {.lex_state = 9},
  [17297] = {.lex_state = 9},
  [17298] = {.lex_state = 9},
  [17299] = {.lex_state = 0, .external_lex_state = 64},
  [17300] = {.lex_state = 0},
  [17301] = {.lex_state = 0},
  [17302] = {.lex_state = 0, .external_lex_state = 64},
  [17303] = {.lex_state = 0},
  [17304] = {.lex_state = 84, .external_lex_state = 51},
  [17305] = {.lex_state = 0},
  [17306] = {.lex_state = 0},
  [17307] = {.lex_state = 0},
  [17308] = {.lex_state = 84},
  [17309] = {.lex_state = 0, .external_lex_state = 64},
  [17310] = {.lex_state = 0},
  [17311] = {.lex_state = 84, .external_lex_state = 51},
  [17312] = {.lex_state = 84, .external_lex_state = 51},
  [17313] = {.lex_state = 0},
  [17314] = {.lex_state = 0, .external_lex_state = 64},
  [17315] = {.lex_state = 9},
  [17316] = {.lex_state = 9},
  [17317] = {.lex_state = 9},
  [17318] = {.lex_state = 9},
  [17319] = {.lex_state = 0, .external_lex_state = 64},
  [17320] = {.lex_state = 0},
  [17321] = {.lex_state = 0},
  [17322] = {.lex_state = 9},
  [17323] = {.lex_state = 84, .external_lex_state = 51},
  [17324] = {.lex_state = 9},
  [17325] = {.lex_state = 9},
  [17326] = {.lex_state = 0, .external_lex_state = 64},
  [17327] = {.lex_state = 9},
  [17328] = {.lex_state = 84},
  [17329] = {.lex_state = 0},
  [17330] = {.lex_state = 0},
  [17331] = {.lex_state = 0},
  [17332] = {.lex_state = 0},
  [17333] = {.lex_state = 0},
  [17334] = {.lex_state = 0},
  [17335] = {.lex_state = 9},
  [17336] = {.lex_state = 9},
  [17337] = {.lex_state = 9},
  [17338] = {.lex_state = 9},
  [17339] = {.lex_state = 0},
  [17340] = {.lex_state = 0},
  [17341] = {.lex_state = 0},
  [17342] = {.lex_state = 0, .external_lex_state = 64},
  [17343] = {.lex_state = 0},
  [17344] = {.lex_state = 0},
  [17345] = {.lex_state = 0, .external_lex_state = 64},
  [17346] = {.lex_state = 0},
  [17347] = {.lex_state = 0},
  [17348] = {.lex_state = 0},
  [17349] = {.lex_state = 0},
  [17350] = {.lex_state = 0, .external_lex_state = 64},
  [17351] = {.lex_state = 84, .external_lex_state = 51},
  [17352] = {.lex_state = 0},
  [17353] = {.lex_state = 84},
  [17354] = {.lex_state = 9},
  [17355] = {.lex_state = 9},
  [17356] = {.lex_state = 9},
  [17357] = {.lex_state = 9},
  [17358] = {.lex_state = 0, .external_lex_state = 64},
  [17359] = {.lex_state = 0},
  [17360] = {.lex_state = 0},
  [17361] = {.lex_state = 84, .external_lex_state = 51},
  [17362] = {.lex_state = 84, .external_lex_state = 51},
  [17363] = {.lex_state = 0, .external_lex_state = 64},
  [17364] = {.lex_state = 0},
  [17365] = {.lex_state = 0},
  [17366] = {.lex_state = 0},
  [17367] = {.lex_state = 84, .external_lex_state = 51},
  [17368] = {.lex_state = 84},
  [17369] = {.lex_state = 0},
  [17370] = {.lex_state = 0, .external_lex_state = 64},
  [17371] = {.lex_state = 9},
  [17372] = {.lex_state = 0},
  [17373] = {.lex_state = 9},
  [17374] = {.lex_state = 9},
  [17375] = {.lex_state = 9},
  [17376] = {.lex_state = 9},
  [17377] = {.lex_state = 0},
  [17378] = {.lex_state = 9},
  [17379] = {.lex_state = 0},
  [17380] = {.lex_state = 9},
  [17381] = {.lex_state = 0},
  [17382] = {.lex_state = 0},
  [17383] = {.lex_state = 0},
  [17384] = {.lex_state = 0},
  [17385] = {.lex_state = 9},
  [17386] = {.lex_state = 9},
  [17387] = {.lex_state = 0},
  [17388] = {.lex_state = 0, .external_lex_state = 64},
  [17389] = {.lex_state = 0},
  [17390] = {.lex_state = 0},
  [17391] = {.lex_state = 0},
  [17392] = {.lex_state = 9},
  [17393] = {.lex_state = 9},
  [17394] = {.lex_state = 9},
  [17395] = {.lex_state = 9},
  [17396] = {.lex_state = 0},
  [17397] = {.lex_state = 0},
  [17398] = {.lex_state = 0},
  [17399] = {.lex_state = 0, .external_lex_state = 64},
  [17400] = {.lex_state = 84, .external_lex_state = 51},
  [17401] = {.lex_state = 84},
  [17402] = {.lex_state = 0},
  [17403] = {.lex_state = 0},
  [17404] = {.lex_state = 0, .external_lex_state = 64},
  [17405] = {.lex_state = 84, .external_lex_state = 51},
  [17406] = {.lex_state = 0, .external_lex_state = 64},
  [17407] = {.lex_state = 84, .external_lex_state = 51},
  [17408] = {.lex_state = 0},
  [17409] = {.lex_state = 84},
  [17410] = {.lex_state = 84, .external_lex_state = 51},
  [17411] = {.lex_state = 9},
  [17412] = {.lex_state = 9},
  [17413] = {.lex_state = 9},
  [17414] = {.lex_state = 9},
  [17415] = {.lex_state = 0},
  [17416] = {.lex_state = 0},
  [17417] = {.lex_state = 0},
  [17418] = {.lex_state = 0, .external_lex_state = 64},
  [17419] = {.lex_state = 0},
  [17420] = {.lex_state = 0, .external_lex_state = 64},
  [17421] = {.lex_state = 0},
  [17422] = {.lex_state = 0},
  [17423] = {.lex_state = 0},
  [17424] = {.lex_state = 0},
  [17425] = {.lex_state = 0},
  [17426] = {.lex_state = 0},
  [17427] = {.lex_state = 0},
  [17428] = {.lex_state = 9},
  [17429] = {.lex_state = 0},
  [17430] = {.lex_state = 9},
  [17431] = {.lex_state = 9},
  [17432] = {.lex_state = 9},
  [17433] = {.lex_state = 9},
  [17434] = {.lex_state = 0},
  [17435] = {.lex_state = 0, .external_lex_state = 64},
  [17436] = {.lex_state = 0},
  [17437] = {.lex_state = 9},
  [17438] = {.lex_state = 9},
  [17439] = {.lex_state = 0},
  [17440] = {.lex_state = 9},
  [17441] = {.lex_state = 0},
  [17442] = {.lex_state = 0},
  [17443] = {.lex_state = 0, .external_lex_state = 64},
  [17444] = {.lex_state = 84},
  [17445] = {.lex_state = 84, .external_lex_state = 51},
  [17446] = {.lex_state = 0},
  [17447] = {.lex_state = 0, .external_lex_state = 64},
  [17448] = {.lex_state = 84, .external_lex_state = 51},
  [17449] = {.lex_state = 9},
  [17450] = {.lex_state = 9},
  [17451] = {.lex_state = 9},
  [17452] = {.lex_state = 9},
  [17453] = {.lex_state = 0},
  [17454] = {.lex_state = 0, .external_lex_state = 64},
  [17455] = {.lex_state = 0},
  [17456] = {.lex_state = 0},
  [17457] = {.lex_state = 0, .external_lex_state = 64},
  [17458] = {.lex_state = 84, .external_lex_state = 51},
  [17459] = {.lex_state = 84, .external_lex_state = 51},
  [17460] = {.lex_state = 84},
  [17461] = {.lex_state = 0, .external_lex_state = 64},
  [17462] = {.lex_state = 9},
  [17463] = {.lex_state = 9},
  [17464] = {.lex_state = 9},
  [17465] = {.lex_state = 9},
  [17466] = {.lex_state = 0},
  [17467] = {.lex_state = 0},
  [17468] = {.lex_state = 0, .external_lex_state = 64},
  [17469] = {.lex_state = 0},
  [17470] = {.lex_state = 0},
  [17471] = {.lex_state = 0},
  [17472] = {.lex_state = 0},
  [17473] = {.lex_state = 0},
  [17474] = {.lex_state = 0},
  [17475] = {.lex_state = 9},
  [17476] = {.lex_state = 9},
  [17477] = {.lex_state = 9},
  [17478] = {.lex_state = 9},
  [17479] = {.lex_state = 0},
  [17480] = {.lex_state = 0},
  [17481] = {.lex_state = 0},
  [17482] = {.lex_state = 0},
  [17483] = {.lex_state = 0},
  [17484] = {.lex_state = 0, .external_lex_state = 64},
  [17485] = {.lex_state = 0},
  [17486] = {.lex_state = 0},
  [17487] = {.lex_state = 0},
  [17488] = {.lex_state = 9},
  [17489] = {.lex_state = 9},
  [17490] = {.lex_state = 9},
  [17491] = {.lex_state = 9},
  [17492] = {.lex_state = 0},
  [17493] = {.lex_state = 0, .external_lex_state = 64},
  [17494] = {.lex_state = 9},
  [17495] = {.lex_state = 9},
  [17496] = {.lex_state = 9},
  [17497] = {.lex_state = 84},
  [17498] = {.lex_state = 84},
  [17499] = {.lex_state = 0},
  [17500] = {.lex_state = 84, .external_lex_state = 51},
  [17501] = {.lex_state = 9},
  [17502] = {.lex_state = 9},
  [17503] = {.lex_state = 9},
  [17504] = {.lex_state = 9},
  [17505] = {.lex_state = 0},
  [17506] = {.lex_state = 84, .external_lex_state = 51},
  [17507] = {.lex_state = 0, .external_lex_state = 64},
  [17508] = {.lex_state = 0},
  [17509] = {.lex_state = 0},
  [17510] = {.lex_state = 0},
  [17511] = {.lex_state = 84, .external_lex_state = 51},
  [17512] = {.lex_state = 0, .external_lex_state = 64},
  [17513] = {.lex_state = 84, .external_lex_state = 51},
  [17514] = {.lex_state = 9},
  [17515] = {.lex_state = 9},
  [17516] = {.lex_state = 9},
  [17517] = {.lex_state = 9},
  [17518] = {.lex_state = 0},
  [17519] = {.lex_state = 0},
  [17520] = {.lex_state = 0},
  [17521] = {.lex_state = 0, .external_lex_state = 64},
  [17522] = {.lex_state = 0},
  [17523] = {.lex_state = 0},
  [17524] = {.lex_state = 0},
  [17525] = {.lex_state = 0},
  [17526] = {.lex_state = 0},
  [17527] = {.lex_state = 9},
  [17528] = {.lex_state = 9},
  [17529] = {.lex_state = 9},
  [17530] = {.lex_state = 9},
  [17531] = {.lex_state = 0},
  [17532] = {.lex_state = 0},
  [17533] = {.lex_state = 0},
  [17534] = {.lex_state = 0},
  [17535] = {.lex_state = 0},
  [17536] = {.lex_state = 0},
  [17537] = {.lex_state = 0, .external_lex_state = 64},
  [17538] = {.lex_state = 0, .external_lex_state = 64},
  [17539] = {.lex_state = 0},
  [17540] = {.lex_state = 9},
  [17541] = {.lex_state = 9},
  [17542] = {.lex_state = 9},
  [17543] = {.lex_state = 9},
  [17544] = {.lex_state = 0},
  [17545] = {.lex_state = 0},
  [17546] = {.lex_state = 0},
  [17547] = {.lex_state = 84, .external_lex_state = 51},
  [17548] = {.lex_state = 0},
  [17549] = {.lex_state = 0, .external_lex_state = 64},
  [17550] = {.lex_state = 84},
  [17551] = {.lex_state = 9},
  [17552] = {.lex_state = 0},
  [17553] = {.lex_state = 9},
  [17554] = {.lex_state = 9},
  [17555] = {.lex_state = 9},
  [17556] = {.lex_state = 9},
  [17557] = {.lex_state = 0},
  [17558] = {.lex_state = 9},
  [17559] = {.lex_state = 84, .external_lex_state = 51},
  [17560] = {.lex_state = 0, .external_lex_state = 64},
  [17561] = {.lex_state = 9},
  [17562] = {.lex_state = 0},
  [17563] = {.lex_state = 9},
  [17564] = {.lex_state = 84, .external_lex_state = 51},
  [17565] = {.lex_state = 84, .external_lex_state = 51},
  [17566] = {.lex_state = 9},
  [17567] = {.lex_state = 9},
  [17568] = {.lex_state = 9},
  [17569] = {.lex_state = 9},
  [17570] = {.lex_state = 0},
  [17571] = {.lex_state = 0},
  [17572] = {.lex_state = 0, .external_lex_state = 64},
  [17573] = {.lex_state = 84},
  [17574] = {.lex_state = 0},
  [17575] = {.lex_state = 0},
  [17576] = {.lex_state = 0, .external_lex_state = 64},
  [17577] = {.lex_state = 0},
  [17578] = {.lex_state = 9},
  [17579] = {.lex_state = 9},
  [17580] = {.lex_state = 9},
  [17581] = {.lex_state = 9},
  [17582] = {.lex_state = 0},
  [17583] = {.lex_state = 0},
  [17584] = {.lex_state = 0},
  [17585] = {.lex_state = 0},
  [17586] = {.lex_state = 0},
  [17587] = {.lex_state = 0},
  [17588] = {.lex_state = 0},
  [17589] = {.lex_state = 0},
  [17590] = {.lex_state = 9},
  [17591] = {.lex_state = 9},
  [17592] = {.lex_state = 9},
  [17593] = {.lex_state = 9},
  [17594] = {.lex_state = 0},
  [17595] = {.lex_state = 0, .external_lex_state = 64},
  [17596] = {.lex_state = 0},
  [17597] = {.lex_state = 0, .external_lex_state = 64},
  [17598] = {.lex_state = 0},
  [17599] = {.lex_state = 84, .external_lex_state = 51},
  [17600] = {.lex_state = 0},
  [17601] = {.lex_state = 0, .external_lex_state = 64},
  [17602] = {.lex_state = 9},
  [17603] = {.lex_state = 9},
  [17604] = {.lex_state = 9},
  [17605] = {.lex_state = 9},
  [17606] = {.lex_state = 0},
  [17607] = {.lex_state = 0},
  [17608] = {.lex_state = 84},
  [17609] = {.lex_state = 84, .external_lex_state = 51},
  [17610] = {.lex_state = 0},
  [17611] = {.lex_state = 0},
  [17612] = {.lex_state = 84, .external_lex_state = 51},
  [17613] = {.lex_state = 84},
  [17614] = {.lex_state = 9},
  [17615] = {.lex_state = 9},
  [17616] = {.lex_state = 9},
  [17617] = {.lex_state = 0},
  [17618] = {.lex_state = 0, .external_lex_state = 64},
  [17619] = {.lex_state = 0},
  [17620] = {.lex_state = 0},
  [17621] = {.lex_state = 84},
  [17622] = {.lex_state = 84, .external_lex_state = 51},
  [17623] = {.lex_state = 9},
  [17624] = {.lex_state = 9},
  [17625] = {.lex_state = 9},
  [17626] = {.lex_state = 9},
  [17627] = {.lex_state = 9},
  [17628] = {.lex_state = 0},
  [17629] = {.lex_state = 9},
  [17630] = {.lex_state = 0, .external_lex_state = 64},
  [17631] = {.lex_state = 9},
  [17632] = {.lex_state = 9},
  [17633] = {.lex_state = 0},
  [17634] = {.lex_state = 0},
  [17635] = {.lex_state = 0},
  [17636] = {.lex_state = 0},
  [17637] = {.lex_state = 0},
  [17638] = {.lex_state = 0},
  [17639] = {.lex_state = 0},
  [17640] = {.lex_state = 0},
  [17641] = {.lex_state = 0, .external_lex_state = 64},
  [17642] = {.lex_state = 0},
  [17643] = {.lex_state = 84},
  [17644] = {.lex_state = 0},
  [17645] = {.lex_state = 0, .external_lex_state = 64},
  [17646] = {.lex_state = 0},
  [17647] = {.lex_state = 0},
  [17648] = {.lex_state = 0},
  [17649] = {.lex_state = 0},
  [17650] = {.lex_state = 0, .external_lex_state = 64},
  [17651] = {.lex_state = 84, .external_lex_state = 51},
  [17652] = {.lex_state = 0},
  [17653] = {.lex_state = 0, .external_lex_state = 64},
  [17654] = {.lex_state = 0},
  [17655] = {.lex_state = 84},
  [17656] = {.lex_state = 84, .external_lex_state = 51},
  [17657] = {.lex_state = 0},
  [17658] = {.lex_state = 84},
  [17659] = {.lex_state = 84, .external_lex_state = 51},
  [17660] = {.lex_state = 0},
  [17661] = {.lex_state = 0, .external_lex_state = 64},
  [17662] = {.lex_state = 0},
  [17663] = {.lex_state = 0},
  [17664] = {.lex_state = 0, .external_lex_state = 64},
  [17665] = {.lex_state = 84, .external_lex_state = 51},
  [17666] = {.lex_state = 0},
  [17667] = {.lex_state = 0},
  [17668] = {.lex_state = 0},
  [17669] = {.lex_state = 0},
  [17670] = {.lex_state = 0, .external_lex_state = 64},
  [17671] = {.lex_state = 0},
  [17672] = {.lex_state = 0},
  [17673] = {.lex_state = 0},
  [17674] = {.lex_state = 0},
  [17675] = {.lex_state = 0, .external_lex_state = 64},
  [17676] = {.lex_state = 0},
  [17677] = {.lex_state = 0},
  [17678] = {.lex_state = 0},
  [17679] = {.lex_state = 0},
  [17680] = {.lex_state = 0},
  [17681] = {.lex_state = 0},
  [17682] = {.lex_state = 9},
  [17683] = {.lex_state = 0},
  [17684] = {.lex_state = 0},
  [17685] = {.lex_state = 0},
  [17686] = {.lex_state = 0, .external_lex_state = 64},
  [17687] = {.lex_state = 9},
  [17688] = {.lex_state = 9},
  [17689] = {.lex_state = 9},
  [17690] = {.lex_state = 0},
  [17691] = {.lex_state = 0},
  [17692] = {.lex_state = 0, .external_lex_state = 64},
  [17693] = {.lex_state = 84, .external_lex_state = 51},
  [17694] = {.lex_state = 0},
  [17695] = {.lex_state = 0},
  [17696] = {.lex_state = 0},
  [17697] = {.lex_state = 84},
  [17698] = {.lex_state = 0, .external_lex_state = 64},
  [17699] = {.lex_state = 0},
  [17700] = {.lex_state = 0},
  [17701] = {.lex_state = 84, .external_lex_state = 51},
  [17702] = {.lex_state = 0},
  [17703] = {.lex_state = 0, .external_lex_state = 64},
  [17704] = {.lex_state = 0, .external_lex_state = 64},
  [17705] = {.lex_state = 0},
  [17706] = {.lex_state = 0},
  [17707] = {.lex_state = 76},
  [17708] = {.lex_state = 0},
  [17709] = {.lex_state = 76},
  [17710] = {.lex_state = 84, .external_lex_state = 51},
  [17711] = {.lex_state = 0},
  [17712] = {.lex_state = 0},
  [17713] = {.lex_state = 0, .external_lex_state = 64},
  [17714] = {.lex_state = 0},
  [17715] = {.lex_state = 0, .external_lex_state = 64},
  [17716] = {.lex_state = 84, .external_lex_state = 51},
  [17717] = {.lex_state = 0},
  [17718] = {.lex_state = 0},
  [17719] = {.lex_state = 0, .external_lex_state = 64},
  [17720] = {.lex_state = 0},
  [17721] = {.lex_state = 0},
  [17722] = {.lex_state = 0},
  [17723] = {.lex_state = 0},
  [17724] = {.lex_state = 0},
  [17725] = {.lex_state = 0},
  [17726] = {.lex_state = 0},
  [17727] = {.lex_state = 84, .external_lex_state = 51},
  [17728] = {.lex_state = 0},
  [17729] = {.lex_state = 0},
  [17730] = {.lex_state = 0, .external_lex_state = 64},
  [17731] = {.lex_state = 84, .external_lex_state = 51},
  [17732] = {.lex_state = 0},
  [17733] = {.lex_state = 84},
  [17734] = {.lex_state = 0},
  [17735] = {.lex_state = 0},
  [17736] = {.lex_state = 0},
  [17737] = {.lex_state = 0},
  [17738] = {.lex_state = 0},
  [17739] = {.lex_state = 0, .external_lex_state = 64},
  [17740] = {.lex_state = 0},
  [17741] = {.lex_state = 0},
  [17742] = {.lex_state = 0},
  [17743] = {.lex_state = 0, .external_lex_state = 64},
  [17744] = {.lex_state = 0},
  [17745] = {.lex_state = 84},
  [17746] = {.lex_state = 9},
  [17747] = {.lex_state = 0},
  [17748] = {.lex_state = 9},
  [17749] = {.lex_state = 84, .external_lex_state = 51},
  [17750] = {.lex_state = 0},
  [17751] = {.lex_state = 9},
  [17752] = {.lex_state = 9},
  [17753] = {.lex_state = 84, .external_lex_state = 51},
  [17754] = {.lex_state = 0},
  [17755] = {.lex_state = 0, .external_lex_state = 64},
  [17756] = {.lex_state = 0},
  [17757] = {.lex_state = 0, .external_lex_state = 64},
  [17758] = {.lex_state = 0},
  [17759] = {.lex_state = 0},
  [17760] = {.lex_state = 0},
  [17761] = {.lex_state = 84, .external_lex_state = 51},
  [17762] = {.lex_state = 0},
  [17763] = {.lex_state = 76},
  [17764] = {.lex_state = 76},
  [17765] = {.lex_state = 0},
  [17766] = {.lex_state = 84, .external_lex_state = 51},
  [17767] = {.lex_state = 84},
  [17768] = {.lex_state = 0},
  [17769] = {.lex_state = 0},
  [17770] = {.lex_state = 0},
  [17771] = {.lex_state = 0, .external_lex_state = 64},
  [17772] = {.lex_state = 0},
  [17773] = {.lex_state = 0},
  [17774] = {.lex_state = 0},
  [17775] = {.lex_state = 0},
  [17776] = {.lex_state = 0},
  [17777] = {.lex_state = 0, .external_lex_state = 64},
  [17778] = {.lex_state = 84, .external_lex_state = 51},
  [17779] = {.lex_state = 0},
  [17780] = {.lex_state = 0},
  [17781] = {.lex_state = 0},
  [17782] = {.lex_state = 0},
  [17783] = {.lex_state = 0},
  [17784] = {.lex_state = 0},
  [17785] = {.lex_state = 0},
  [17786] = {.lex_state = 0},
  [17787] = {.lex_state = 0},
  [17788] = {.lex_state = 0, .external_lex_state = 64},
  [17789] = {.lex_state = 0, .external_lex_state = 64},
  [17790] = {.lex_state = 84, .external_lex_state = 51},
  [17791] = {.lex_state = 84},
  [17792] = {.lex_state = 0},
  [17793] = {.lex_state = 0},
  [17794] = {.lex_state = 0},
  [17795] = {.lex_state = 0, .external_lex_state = 64},
  [17796] = {.lex_state = 0},
  [17797] = {.lex_state = 0},
  [17798] = {.lex_state = 0},
  [17799] = {.lex_state = 0},
  [17800] = {.lex_state = 0, .external_lex_state = 64},
  [17801] = {.lex_state = 0},
  [17802] = {.lex_state = 84},
  [17803] = {.lex_state = 84, .external_lex_state = 51},
  [17804] = {.lex_state = 0},
  [17805] = {.lex_state = 0},
  [17806] = {.lex_state = 0},
  [17807] = {.lex_state = 0, .external_lex_state = 64},
  [17808] = {.lex_state = 9},
  [17809] = {.lex_state = 84, .external_lex_state = 51},
  [17810] = {.lex_state = 0},
  [17811] = {.lex_state = 9},
  [17812] = {.lex_state = 9},
  [17813] = {.lex_state = 0},
  [17814] = {.lex_state = 84, .external_lex_state = 51},
  [17815] = {.lex_state = 84},
  [17816] = {.lex_state = 0},
  [17817] = {.lex_state = 0},
  [17818] = {.lex_state = 0},
  [17819] = {.lex_state = 0, .external_lex_state = 64},
  [17820] = {.lex_state = 9},
  [17821] = {.lex_state = 0, .external_lex_state = 64},
  [17822] = {.lex_state = 0},
  [17823] = {.lex_state = 0},
  [17824] = {.lex_state = 0},
  [17825] = {.lex_state = 0},
  [17826] = {.lex_state = 0},
  [17827] = {.lex_state = 0, .external_lex_state = 64},
  [17828] = {.lex_state = 0},
  [17829] = {.lex_state = 76},
  [17830] = {.lex_state = 76},
  [17831] = {.lex_state = 84, .external_lex_state = 51},
  [17832] = {.lex_state = 84, .external_lex_state = 51},
  [17833] = {.lex_state = 0},
  [17834] = {.lex_state = 0},
  [17835] = {.lex_state = 0, .external_lex_state = 64},
  [17836] = {.lex_state = 84, .external_lex_state = 51},
  [17837] = {.lex_state = 84},
  [17838] = {.lex_state = 0},
  [17839] = {.lex_state = 0, .external_lex_state = 64},
  [17840] = {.lex_state = 0},
  [17841] = {.lex_state = 0},
  [17842] = {.lex_state = 0},
  [17843] = {.lex_state = 0, .external_lex_state = 64},
  [17844] = {.lex_state = 0},
  [17845] = {.lex_state = 0},
  [17846] = {.lex_state = 0},
  [17847] = {.lex_state = 0},
  [17848] = {.lex_state = 0, .external_lex_state = 64},
  [17849] = {.lex_state = 0},
  [17850] = {.lex_state = 84, .external_lex_state = 51},
  [17851] = {.lex_state = 0},
  [17852] = {.lex_state = 0},
  [17853] = {.lex_state = 0},
  [17854] = {.lex_state = 0},
  [17855] = {.lex_state = 0},
  [17856] = {.lex_state = 0},
  [17857] = {.lex_state = 9},
  [17858] = {.lex_state = 0},
  [17859] = {.lex_state = 0},
  [17860] = {.lex_state = 0},
  [17861] = {.lex_state = 0},
  [17862] = {.lex_state = 0, .external_lex_state = 64},
  [17863] = {.lex_state = 9},
  [17864] = {.lex_state = 0},
  [17865] = {.lex_state = 0, .external_lex_state = 64},
  [17866] = {.lex_state = 9},
  [17867] = {.lex_state = 84, .external_lex_state = 51},
  [17868] = {.lex_state = 0},
  [17869] = {.lex_state = 9},
  [17870] = {.lex_state = 0},
  [17871] = {.lex_state = 84},
  [17872] = {.lex_state = 0},
  [17873] = {.lex_state = 0, .external_lex_state = 64},
  [17874] = {.lex_state = 0},
  [17875] = {.lex_state = 0},
  [17876] = {.lex_state = 0},
  [17877] = {.lex_state = 0},
  [17878] = {.lex_state = 84},
  [17879] = {.lex_state = 0, .external_lex_state = 64},
  [17880] = {.lex_state = 0},
  [17881] = {.lex_state = 84, .external_lex_state = 51},
  [17882] = {.lex_state = 0},
  [17883] = {.lex_state = 0},
  [17884] = {.lex_state = 9},
  [17885] = {.lex_state = 0},
  [17886] = {.lex_state = 0},
  [17887] = {.lex_state = 0, .external_lex_state = 64},
  [17888] = {.lex_state = 0},
  [17889] = {.lex_state = 9},
  [17890] = {.lex_state = 9},
  [17891] = {.lex_state = 0},
  [17892] = {.lex_state = 0, .external_lex_state = 64},
  [17893] = {.lex_state = 84, .external_lex_state = 51},
  [17894] = {.lex_state = 0},
  [17895] = {.lex_state = 84},
  [17896] = {.lex_state = 0, .external_lex_state = 64},
  [17897] = {.lex_state = 84, .external_lex_state = 51},
  [17898] = {.lex_state = 76},
  [17899] = {.lex_state = 0, .external_lex_state = 64},
  [17900] = {.lex_state = 0},
  [17901] = {.lex_state = 0},
  [17902] = {.lex_state = 0},
  [17903] = {.lex_state = 0},
  [17904] = {.lex_state = 9},
  [17905] = {.lex_state = 0, .external_lex_state = 64},
  [17906] = {.lex_state = 0},
  [17907] = {.lex_state = 0, .external_lex_state = 64},
  [17908] = {.lex_state = 0, .external_lex_state = 64},
  [17909] = {.lex_state = 84, .external_lex_state = 51},
  [17910] = {.lex_state = 0},
  [17911] = {.lex_state = 0, .external_lex_state = 64},
  [17912] = {.lex_state = 84, .external_lex_state = 51},
  [17913] = {.lex_state = 84},
  [17914] = {.lex_state = 0},
  [17915] = {.lex_state = 0},
  [17916] = {.lex_state = 76},
  [17917] = {.lex_state = 0, .external_lex_state = 64},
  [17918] = {.lex_state = 0},
  [17919] = {.lex_state = 84, .external_lex_state = 51},
  [17920] = {.lex_state = 0},
  [17921] = {.lex_state = 0},
  [17922] = {.lex_state = 0, .external_lex_state = 64},
  [17923] = {.lex_state = 84, .external_lex_state = 51},
  [17924] = {.lex_state = 0},
  [17925] = {.lex_state = 0, .external_lex_state = 64},
  [17926] = {.lex_state = 84, .external_lex_state = 51},
  [17927] = {.lex_state = 0},
  [17928] = {.lex_state = 0},
  [17929] = {.lex_state = 0, .external_lex_state = 64},
  [17930] = {.lex_state = 0},
  [17931] = {.lex_state = 0, .external_lex_state = 64},
  [17932] = {.lex_state = 0},
  [17933] = {.lex_state = 0},
  [17934] = {.lex_state = 84},
  [17935] = {.lex_state = 0, .external_lex_state = 64},
  [17936] = {.lex_state = 0},
  [17937] = {.lex_state = 0},
  [17938] = {.lex_state = 0},
  [17939] = {.lex_state = 0, .external_lex_state = 64},
  [17940] = {.lex_state = 0},
  [17941] = {.lex_state = 0},
  [17942] = {.lex_state = 0},
  [17943] = {.lex_state = 84, .external_lex_state = 49},
  [17944] = {.lex_state = 0},
  [17945] = {.lex_state = 0},
  [17946] = {.lex_state = 0},
  [17947] = {.lex_state = 0},
  [17948] = {.lex_state = 0},
  [17949] = {.lex_state = 0},
  [17950] = {.lex_state = 0, .external_lex_state = 64},
  [17951] = {.lex_state = 0},
  [17952] = {.lex_state = 0},
  [17953] = {.lex_state = 0, .external_lex_state = 64},
  [17954] = {.lex_state = 0},
  [17955] = {.lex_state = 0},
  [17956] = {.lex_state = 0, .external_lex_state = 64},
  [17957] = {.lex_state = 0},
  [17958] = {.lex_state = 0, .external_lex_state = 64},
  [17959] = {.lex_state = 0},
  [17960] = {.lex_state = 0, .external_lex_state = 64},
  [17961] = {.lex_state = 0, .external_lex_state = 64},
  [17962] = {.lex_state = 0},
  [17963] = {.lex_state = 0, .external_lex_state = 64},
  [17964] = {.lex_state = 0},
  [17965] = {.lex_state = 0, .external_lex_state = 64},
  [17966] = {.lex_state = 0},
  [17967] = {.lex_state = 84},
  [17968] = {.lex_state = 0, .external_lex_state = 64},
  [17969] = {.lex_state = 0},
  [17970] = {.lex_state = 0, .external_lex_state = 64},
  [17971] = {.lex_state = 0},
  [17972] = {.lex_state = 0, .external_lex_state = 64},
  [17973] = {.lex_state = 84},
  [17974] = {.lex_state = 0},
  [17975] = {.lex_state = 84},
  [17976] = {.lex_state = 0, .external_lex_state = 64},
  [17977] = {.lex_state = 0},
  [17978] = {.lex_state = 0},
  [17979] = {.lex_state = 0},
  [17980] = {.lex_state = 0, .external_lex_state = 25},
  [17981] = {.lex_state = 84},
  [17982] = {.lex_state = 84},
  [17983] = {.lex_state = 0},
  [17984] = {.lex_state = 0, .external_lex_state = 25},
  [17985] = {.lex_state = 0},
  [17986] = {.lex_state = 0},
  [17987] = {.lex_state = 84},
  [17988] = {.lex_state = 0, .external_lex_state = 64},
  [17989] = {.lex_state = 0},
  [17990] = {.lex_state = 0},
  [17991] = {.lex_state = 0},
  [17992] = {.lex_state = 0},
  [17993] = {.lex_state = 0},
  [17994] = {.lex_state = 0},
  [17995] = {.lex_state = 0, .external_lex_state = 64},
  [17996] = {.lex_state = 0},
  [17997] = {.lex_state = 0, .external_lex_state = 64},
  [17998] = {.lex_state = 0},
  [17999] = {.lex_state = 0},
  [18000] = {.lex_state = 0},
  [18001] = {.lex_state = 0, .external_lex_state = 25},
  [18002] = {.lex_state = 0},
  [18003] = {.lex_state = 0},
  [18004] = {.lex_state = 0},
  [18005] = {.lex_state = 0},
  [18006] = {.lex_state = 0},
  [18007] = {.lex_state = 0},
  [18008] = {.lex_state = 0},
  [18009] = {.lex_state = 0},
  [18010] = {.lex_state = 0},
  [18011] = {.lex_state = 0, .external_lex_state = 25},
  [18012] = {.lex_state = 0, .external_lex_state = 64},
  [18013] = {.lex_state = 0},
  [18014] = {.lex_state = 0},
  [18015] = {.lex_state = 0},
  [18016] = {.lex_state = 0},
  [18017] = {.lex_state = 0},
  [18018] = {.lex_state = 0},
  [18019] = {.lex_state = 0, .external_lex_state = 25},
  [18020] = {.lex_state = 0, .external_lex_state = 64},
  [18021] = {.lex_state = 0},
  [18022] = {.lex_state = 0},
  [18023] = {.lex_state = 0, .external_lex_state = 64},
  [18024] = {.lex_state = 0},
  [18025] = {.lex_state = 0, .external_lex_state = 64},
  [18026] = {.lex_state = 0, .external_lex_state = 25},
  [18027] = {.lex_state = 0},
  [18028] = {.lex_state = 0},
  [18029] = {.lex_state = 0},
  [18030] = {.lex_state = 0},
  [18031] = {.lex_state = 0, .external_lex_state = 64},
  [18032] = {.lex_state = 0, .external_lex_state = 64},
  [18033] = {.lex_state = 0, .external_lex_state = 25},
  [18034] = {.lex_state = 0},
  [18035] = {.lex_state = 0, .external_lex_state = 64},
  [18036] = {.lex_state = 0},
  [18037] = {.lex_state = 0},
  [18038] = {.lex_state = 0},
  [18039] = {.lex_state = 0, .external_lex_state = 64},
  [18040] = {.lex_state = 0, .external_lex_state = 25},
  [18041] = {.lex_state = 0, .external_lex_state = 64},
  [18042] = {.lex_state = 0},
  [18043] = {.lex_state = 0, .external_lex_state = 64},
  [18044] = {.lex_state = 0, .external_lex_state = 64},
  [18045] = {.lex_state = 0},
  [18046] = {.lex_state = 0},
  [18047] = {.lex_state = 0, .external_lex_state = 25},
  [18048] = {.lex_state = 0, .external_lex_state = 64},
  [18049] = {.lex_state = 0},
  [18050] = {.lex_state = 0, .external_lex_state = 64},
  [18051] = {.lex_state = 0},
  [18052] = {.lex_state = 0},
  [18053] = {.lex_state = 0, .external_lex_state = 64},
  [18054] = {.lex_state = 0, .external_lex_state = 25},
  [18055] = {.lex_state = 0},
  [18056] = {.lex_state = 0},
  [18057] = {.lex_state = 0, .external_lex_state = 64},
  [18058] = {.lex_state = 0, .external_lex_state = 64},
  [18059] = {.lex_state = 0},
  [18060] = {.lex_state = 0},
  [18061] = {.lex_state = 0, .external_lex_state = 25},
  [18062] = {.lex_state = 0, .external_lex_state = 64},
  [18063] = {.lex_state = 0},
  [18064] = {.lex_state = 0},
  [18065] = {.lex_state = 0, .external_lex_state = 64},
  [18066] = {.lex_state = 0},
  [18067] = {.lex_state = 0, .external_lex_state = 64},
  [18068] = {.lex_state = 0, .external_lex_state = 25},
  [18069] = {.lex_state = 0},
  [18070] = {.lex_state = 0, .external_lex_state = 64},
  [18071] = {.lex_state = 0, .external_lex_state = 64},
  [18072] = {.lex_state = 0},
  [18073] = {.lex_state = 0},
  [18074] = {.lex_state = 0},
  [18075] = {.lex_state = 0, .external_lex_state = 25},
  [18076] = {.lex_state = 0, .external_lex_state = 64},
  [18077] = {.lex_state = 0, .external_lex_state = 64},
  [18078] = {.lex_state = 0},
  [18079] = {.lex_state = 0, .external_lex_state = 64},
  [18080] = {.lex_state = 0},
  [18081] = {.lex_state = 0},
  [18082] = {.lex_state = 0, .external_lex_state = 25},
  [18083] = {.lex_state = 0},
  [18084] = {.lex_state = 0, .external_lex_state = 64},
  [18085] = {.lex_state = 0, .external_lex_state = 64},
  [18086] = {.lex_state = 0},
  [18087] = {.lex_state = 0},
  [18088] = {.lex_state = 0, .external_lex_state = 64},
  [18089] = {.lex_state = 0, .external_lex_state = 25},
  [18090] = {.lex_state = 0},
  [18091] = {.lex_state = 0},
  [18092] = {.lex_state = 0, .external_lex_state = 64},
  [18093] = {.lex_state = 0},
  [18094] = {.lex_state = 9},
  [18095] = {.lex_state = 0, .external_lex_state = 64},
  [18096] = {.lex_state = 0, .external_lex_state = 25},
  [18097] = {.lex_state = 0},
  [18098] = {.lex_state = 0, .external_lex_state = 64},
  [18099] = {.lex_state = 0, .external_lex_state = 64},
  [18100] = {.lex_state = 0},
  [18101] = {.lex_state = 0},
  [18102] = {.lex_state = 0},
  [18103] = {.lex_state = 0, .external_lex_state = 25},
  [18104] = {.lex_state = 0, .external_lex_state = 64},
  [18105] = {.lex_state = 0},
  [18106] = {.lex_state = 0, .external_lex_state = 64},
  [18107] = {.lex_state = 0},
  [18108] = {.lex_state = 0, .external_lex_state = 64},
  [18109] = {.lex_state = 0, .external_lex_state = 64},
  [18110] = {.lex_state = 0, .external_lex_state = 25},
  [18111] = {.lex_state = 0, .external_lex_state = 64},
  [18112] = {.lex_state = 0},
  [18113] = {.lex_state = 0},
  [18114] = {.lex_state = 0},
  [18115] = {.lex_state = 0, .external_lex_state = 64},
  [18116] = {.lex_state = 0, .external_lex_state = 25},
  [18117] = {.lex_state = 0},
  [18118] = {.lex_state = 0, .external_lex_state = 64},
  [18119] = {.lex_state = 0, .external_lex_state = 64},
  [18120] = {.lex_state = 0},
  [18121] = {.lex_state = 0},
  [18122] = {.lex_state = 0, .external_lex_state = 25},
  [18123] = {.lex_state = 0, .external_lex_state = 64},
  [18124] = {.lex_state = 0},
  [18125] = {.lex_state = 0, .external_lex_state = 64},
  [18126] = {.lex_state = 0},
  [18127] = {.lex_state = 9},
  [18128] = {.lex_state = 0, .external_lex_state = 25},
  [18129] = {.lex_state = 0},
  [18130] = {.lex_state = 0, .external_lex_state = 64},
  [18131] = {.lex_state = 0},
  [18132] = {.lex_state = 9},
  [18133] = {.lex_state = 0},
  [18134] = {.lex_state = 0, .external_lex_state = 25},
  [18135] = {.lex_state = 0, .external_lex_state = 64},
  [18136] = {.lex_state = 0},
  [18137] = {.lex_state = 0, .external_lex_state = 64},
  [18138] = {.lex_state = 0},
  [18139] = {.lex_state = 0, .external_lex_state = 64},
  [18140] = {.lex_state = 0, .external_lex_state = 25},
  [18141] = {.lex_state = 0},
  [18142] = {.lex_state = 0},
  [18143] = {.lex_state = 0},
  [18144] = {.lex_state = 0, .external_lex_state = 64},
  [18145] = {.lex_state = 0},
  [18146] = {.lex_state = 0, .external_lex_state = 25},
  [18147] = {.lex_state = 0, .external_lex_state = 64},
  [18148] = {.lex_state = 0},
  [18149] = {.lex_state = 0, .external_lex_state = 64},
  [18150] = {.lex_state = 0, .external_lex_state = 64},
  [18151] = {.lex_state = 0},
  [18152] = {.lex_state = 0, .external_lex_state = 25},
  [18153] = {.lex_state = 0},
  [18154] = {.lex_state = 84, .external_lex_state = 51},
  [18155] = {.lex_state = 0, .external_lex_state = 64},
  [18156] = {.lex_state = 0, .external_lex_state = 64},
  [18157] = {.lex_state = 0},
  [18158] = {.lex_state = 0, .external_lex_state = 25},
  [18159] = {.lex_state = 0, .external_lex_state = 64},
  [18160] = {.lex_state = 0},
  [18161] = {.lex_state = 0},
  [18162] = {.lex_state = 0},
  [18163] = {.lex_state = 0, .external_lex_state = 64},
  [18164] = {.lex_state = 0, .external_lex_state = 25},
  [18165] = {.lex_state = 0},
  [18166] = {.lex_state = 0},
  [18167] = {.lex_state = 0},
  [18168] = {.lex_state = 0, .external_lex_state = 64},
  [18169] = {.lex_state = 0},
  [18170] = {.lex_state = 0, .external_lex_state = 25},
  [18171] = {.lex_state = 0},
  [18172] = {.lex_state = 0, .external_lex_state = 64},
  [18173] = {.lex_state = 0},
  [18174] = {.lex_state = 0, .external_lex_state = 64},
  [18175] = {.lex_state = 0},
  [18176] = {.lex_state = 0, .external_lex_state = 25},
  [18177] = {.lex_state = 0, .external_lex_state = 64},
  [18178] = {.lex_state = 0},
  [18179] = {.lex_state = 0},
  [18180] = {.lex_state = 0, .external_lex_state = 64},
  [18181] = {.lex_state = 0},
  [18182] = {.lex_state = 0, .external_lex_state = 25},
  [18183] = {.lex_state = 0},
  [18184] = {.lex_state = 0, .external_lex_state = 64},
  [18185] = {.lex_state = 0},
  [18186] = {.lex_state = 0, .external_lex_state = 64},
  [18187] = {.lex_state = 0},
  [18188] = {.lex_state = 0, .external_lex_state = 25},
  [18189] = {.lex_state = 0, .external_lex_state = 64},
  [18190] = {.lex_state = 0},
  [18191] = {.lex_state = 0, .external_lex_state = 64},
  [18192] = {.lex_state = 0},
  [18193] = {.lex_state = 0},
  [18194] = {.lex_state = 0, .external_lex_state = 25},
  [18195] = {.lex_state = 0},
  [18196] = {.lex_state = 0, .external_lex_state = 64},
  [18197] = {.lex_state = 0},
  [18198] = {.lex_state = 0, .external_lex_state = 64},
  [18199] = {.lex_state = 0},
  [18200] = {.lex_state = 0, .external_lex_state = 25},
  [18201] = {.lex_state = 0, .external_lex_state = 64},
  [18202] = {.lex_state = 0},
  [18203] = {.lex_state = 0, .external_lex_state = 64},
  [18204] = {.lex_state = 0},
  [18205] = {.lex_state = 0},
  [18206] = {.lex_state = 0, .external_lex_state = 25},
  [18207] = {.lex_state = 0},
  [18208] = {.lex_state = 0},
  [18209] = {.lex_state = 0, .external_lex_state = 64},
  [18210] = {.lex_state = 0},
  [18211] = {.lex_state = 9},
  [18212] = {.lex_state = 0, .external_lex_state = 25},
  [18213] = {.lex_state = 0, .external_lex_state = 64},
  [18214] = {.lex_state = 0},
  [18215] = {.lex_state = 0},
  [18216] = {.lex_state = 0, .external_lex_state = 64},
  [18217] = {.lex_state = 0},
  [18218] = {.lex_state = 0, .external_lex_state = 25},
  [18219] = {.lex_state = 0, .external_lex_state = 64},
  [18220] = {.lex_state = 0},
  [18221] = {.lex_state = 0, .external_lex_state = 64},
  [18222] = {.lex_state = 0, .external_lex_state = 64},
  [18223] = {.lex_state = 0},
  [18224] = {.lex_state = 0, .external_lex_state = 25},
  [18225] = {.lex_state = 0},
  [18226] = {.lex_state = 0},
  [18227] = {.lex_state = 0, .external_lex_state = 64},
  [18228] = {.lex_state = 0},
  [18229] = {.lex_state = 0, .external_lex_state = 64},
  [18230] = {.lex_state = 0, .external_lex_state = 25},
  [18231] = {.lex_state = 0, .external_lex_state = 64},
  [18232] = {.lex_state = 0},
  [18233] = {.lex_state = 0, .external_lex_state = 64},
  [18234] = {.lex_state = 0},
  [18235] = {.lex_state = 0, .external_lex_state = 64},
  [18236] = {.lex_state = 0, .external_lex_state = 25},
  [18237] = {.lex_state = 0},
  [18238] = {.lex_state = 0},
  [18239] = {.lex_state = 0},
  [18240] = {.lex_state = 0},
  [18241] = {.lex_state = 0, .external_lex_state = 64},
  [18242] = {.lex_state = 0, .external_lex_state = 25},
  [18243] = {.lex_state = 0},
  [18244] = {.lex_state = 0, .external_lex_state = 64},
  [18245] = {.lex_state = 0},
  [18246] = {.lex_state = 0, .external_lex_state = 64},
  [18247] = {.lex_state = 0, .external_lex_state = 64},
  [18248] = {.lex_state = 0, .external_lex_state = 25},
  [18249] = {.lex_state = 0},
  [18250] = {.lex_state = 0},
  [18251] = {.lex_state = 0},
  [18252] = {.lex_state = 0, .external_lex_state = 64},
  [18253] = {.lex_state = 0},
  [18254] = {.lex_state = 0, .external_lex_state = 25},
  [18255] = {.lex_state = 0, .external_lex_state = 64},
  [18256] = {.lex_state = 0},
  [18257] = {.lex_state = 0},
  [18258] = {.lex_state = 0, .external_lex_state = 64},
  [18259] = {.lex_state = 76},
  [18260] = {.lex_state = 0, .external_lex_state = 25},
  [18261] = {.lex_state = 0, .external_lex_state = 64},
  [18262] = {.lex_state = 76},
  [18263] = {.lex_state = 0, .external_lex_state = 64},
  [18264] = {.lex_state = 0},
  [18265] = {.lex_state = 0},
  [18266] = {.lex_state = 0, .external_lex_state = 25},
  [18267] = {.lex_state = 0},
  [18268] = {.lex_state = 0, .external_lex_state = 64},
  [18269] = {.lex_state = 0},
  [18270] = {.lex_state = 0, .external_lex_state = 64},
  [18271] = {.lex_state = 0},
  [18272] = {.lex_state = 0, .external_lex_state = 25},
  [18273] = {.lex_state = 0, .external_lex_state = 64},
  [18274] = {.lex_state = 0},
  [18275] = {.lex_state = 0, .external_lex_state = 64},
  [18276] = {.lex_state = 0},
  [18277] = {.lex_state = 0},
  [18278] = {.lex_state = 0, .external_lex_state = 25},
  [18279] = {.lex_state = 0},
  [18280] = {.lex_state = 0, .external_lex_state = 64},
  [18281] = {.lex_state = 0},
  [18282] = {.lex_state = 0},
  [18283] = {.lex_state = 0},
  [18284] = {.lex_state = 0, .external_lex_state = 25},
  [18285] = {.lex_state = 0, .external_lex_state = 64},
  [18286] = {.lex_state = 0},
  [18287] = {.lex_state = 0},
  [18288] = {.lex_state = 0, .external_lex_state = 64},
  [18289] = {.lex_state = 84, .external_lex_state = 51},
  [18290] = {.lex_state = 0, .external_lex_state = 25},
  [18291] = {.lex_state = 0},
  [18292] = {.lex_state = 0},
  [18293] = {.lex_state = 0},
  [18294] = {.lex_state = 0, .external_lex_state = 64},
  [18295] = {.lex_state = 0},
  [18296] = {.lex_state = 0, .external_lex_state = 25},
  [18297] = {.lex_state = 0, .external_lex_state = 64},
  [18298] = {.lex_state = 0},
  [18299] = {.lex_state = 0, .external_lex_state = 64},
  [18300] = {.lex_state = 0},
  [18301] = {.lex_state = 0},
  [18302] = {.lex_state = 0, .external_lex_state = 25},
  [18303] = {.lex_state = 0, .external_lex_state = 64},
  [18304] = {.lex_state = 0},
  [18305] = {.lex_state = 0},
  [18306] = {.lex_state = 0},
  [18307] = {.lex_state = 0, .external_lex_state = 64},
  [18308] = {.lex_state = 0, .external_lex_state = 25},
  [18309] = {.lex_state = 0},
  [18310] = {.lex_state = 0, .external_lex_state = 64},
  [18311] = {.lex_state = 0},
  [18312] = {.lex_state = 0, .external_lex_state = 64},
  [18313] = {.lex_state = 0},
  [18314] = {.lex_state = 0, .external_lex_state = 25},
  [18315] = {.lex_state = 0, .external_lex_state = 64},
  [18316] = {.lex_state = 0},
  [18317] = {.lex_state = 0},
  [18318] = {.lex_state = 0},
  [18319] = {.lex_state = 0, .external_lex_state = 64},
  [18320] = {.lex_state = 0, .external_lex_state = 25},
  [18321] = {.lex_state = 0},
  [18322] = {.lex_state = 0, .external_lex_state = 64},
  [18323] = {.lex_state = 0},
  [18324] = {.lex_state = 0, .external_lex_state = 64},
  [18325] = {.lex_state = 0},
  [18326] = {.lex_state = 0, .external_lex_state = 25},
  [18327] = {.lex_state = 0, .external_lex_state = 64},
  [18328] = {.lex_state = 0},
  [18329] = {.lex_state = 0},
  [18330] = {.lex_state = 0},
  [18331] = {.lex_state = 0},
  [18332] = {.lex_state = 0, .external_lex_state = 25},
  [18333] = {.lex_state = 0},
  [18334] = {.lex_state = 0, .external_lex_state = 64},
  [18335] = {.lex_state = 0, .external_lex_state = 64},
  [18336] = {.lex_state = 0},
  [18337] = {.lex_state = 0, .external_lex_state = 64},
  [18338] = {.lex_state = 0, .external_lex_state = 25},
  [18339] = {.lex_state = 0},
  [18340] = {.lex_state = 0, .external_lex_state = 64},
  [18341] = {.lex_state = 0},
  [18342] = {.lex_state = 0},
  [18343] = {.lex_state = 0, .external_lex_state = 25},
  [18344] = {.lex_state = 0, .external_lex_state = 64},
  [18345] = {.lex_state = 0},
  [18346] = {.lex_state = 0, .external_lex_state = 64},
  [18347] = {.lex_state = 0},
  [18348] = {.lex_state = 0, .external_lex_state = 25},
  [18349] = {.lex_state = 0},
  [18350] = {.lex_state = 0},
  [18351] = {.lex_state = 0},
  [18352] = {.lex_state = 0},
  [18353] = {.lex_state = 0, .external_lex_state = 25},
  [18354] = {.lex_state = 0, .external_lex_state = 64},
  [18355] = {.lex_state = 0},
  [18356] = {.lex_state = 0},
  [18357] = {.lex_state = 193},
  [18358] = {.lex_state = 0, .external_lex_state = 25},
  [18359] = {.lex_state = 0, .external_lex_state = 64},
  [18360] = {.lex_state = 84},
  [18361] = {.lex_state = 0},
  [18362] = {.lex_state = 0, .external_lex_state = 64},
  [18363] = {.lex_state = 0, .external_lex_state = 25},
  [18364] = {.lex_state = 0},
  [18365] = {.lex_state = 0, .external_lex_state = 64},
  [18366] = {.lex_state = 0},
  [18367] = {.lex_state = 0},
  [18368] = {.lex_state = 0, .external_lex_state = 25},
  [18369] = {.lex_state = 0},
  [18370] = {.lex_state = 0, .external_lex_state = 64},
  [18371] = {.lex_state = 0},
  [18372] = {.lex_state = 0, .external_lex_state = 64},
  [18373] = {.lex_state = 0, .external_lex_state = 25},
  [18374] = {.lex_state = 0},
  [18375] = {.lex_state = 0},
  [18376] = {.lex_state = 0, .external_lex_state = 64},
  [18377] = {.lex_state = 0},
  [18378] = {.lex_state = 0, .external_lex_state = 25},
  [18379] = {.lex_state = 0},
  [18380] = {.lex_state = 0, .external_lex_state = 64},
  [18381] = {.lex_state = 0},
  [18382] = {.lex_state = 0},
  [18383] = {.lex_state = 0, .external_lex_state = 25},
  [18384] = {.lex_state = 0},
  [18385] = {.lex_state = 0, .external_lex_state = 64},
  [18386] = {.lex_state = 0},
  [18387] = {.lex_state = 0, .external_lex_state = 64},
  [18388] = {.lex_state = 0, .external_lex_state = 25},
  [18389] = {.lex_state = 0},
  [18390] = {.lex_state = 0, .external_lex_state = 64},
  [18391] = {.lex_state = 0},
  [18392] = {.lex_state = 0, .external_lex_state = 64},
  [18393] = {.lex_state = 0, .external_lex_state = 25},
  [18394] = {.lex_state = 0},
  [18395] = {.lex_state = 0},
  [18396] = {.lex_state = 0},
  [18397] = {.lex_state = 0, .external_lex_state = 64},
  [18398] = {.lex_state = 0, .external_lex_state = 25},
  [18399] = {.lex_state = 0},
  [18400] = {.lex_state = 0},
  [18401] = {.lex_state = 0, .external_lex_state = 64},
  [18402] = {.lex_state = 0},
  [18403] = {.lex_state = 0, .external_lex_state = 25},
  [18404] = {.lex_state = 0},
  [18405] = {.lex_state = 0},
  [18406] = {.lex_state = 0, .external_lex_state = 64},
  [18407] = {.lex_state = 0},
  [18408] = {.lex_state = 0, .external_lex_state = 25},
  [18409] = {.lex_state = 0, .external_lex_state = 64},
  [18410] = {.lex_state = 0, .external_lex_state = 64},
  [18411] = {.lex_state = 0, .external_lex_state = 64},
  [18412] = {.lex_state = 0},
  [18413] = {.lex_state = 0, .external_lex_state = 25},
  [18414] = {.lex_state = 0, .external_lex_state = 25},
  [18415] = {.lex_state = 0, .external_lex_state = 25},
  [18416] = {.lex_state = 0, .external_lex_state = 25},
  [18417] = {.lex_state = 0, .external_lex_state = 25},
  [18418] = {.lex_state = 0, .external_lex_state = 25},
  [18419] = {.lex_state = 0, .external_lex_state = 25},
  [18420] = {.lex_state = 0, .external_lex_state = 25},
  [18421] = {.lex_state = 0, .external_lex_state = 25},
  [18422] = {.lex_state = 0, .external_lex_state = 25},
  [18423] = {.lex_state = 0, .external_lex_state = 25},
  [18424] = {.lex_state = 0, .external_lex_state = 25},
  [18425] = {.lex_state = 0, .external_lex_state = 25},
  [18426] = {.lex_state = 0, .external_lex_state = 25},
  [18427] = {.lex_state = 0, .external_lex_state = 25},
  [18428] = {.lex_state = 0, .external_lex_state = 25},
  [18429] = {.lex_state = 0, .external_lex_state = 25},
  [18430] = {.lex_state = 0, .external_lex_state = 25},
  [18431] = {.lex_state = 0, .external_lex_state = 25},
  [18432] = {.lex_state = 0, .external_lex_state = 25},
  [18433] = {.lex_state = 0, .external_lex_state = 25},
  [18434] = {.lex_state = 0, .external_lex_state = 25},
  [18435] = {.lex_state = 0, .external_lex_state = 25},
  [18436] = {.lex_state = 0, .external_lex_state = 25},
  [18437] = {.lex_state = 0, .external_lex_state = 25},
  [18438] = {.lex_state = 0, .external_lex_state = 25},
  [18439] = {.lex_state = 0, .external_lex_state = 25},
  [18440] = {.lex_state = 0, .external_lex_state = 25},
  [18441] = {.lex_state = 0, .external_lex_state = 25},
  [18442] = {.lex_state = 0, .external_lex_state = 25},
  [18443] = {.lex_state = 0, .external_lex_state = 25},
  [18444] = {.lex_state = 0, .external_lex_state = 25},
  [18445] = {.lex_state = 0, .external_lex_state = 25},
  [18446] = {.lex_state = 0, .external_lex_state = 25},
  [18447] = {.lex_state = 0, .external_lex_state = 25},
  [18448] = {.lex_state = 0, .external_lex_state = 25},
  [18449] = {.lex_state = 0, .external_lex_state = 25},
  [18450] = {.lex_state = 0, .external_lex_state = 25},
  [18451] = {.lex_state = 0, .external_lex_state = 25},
  [18452] = {.lex_state = 0, .external_lex_state = 25},
  [18453] = {.lex_state = 0, .external_lex_state = 25},
  [18454] = {.lex_state = 0, .external_lex_state = 25},
  [18455] = {.lex_state = 0, .external_lex_state = 25},
  [18456] = {.lex_state = 0, .external_lex_state = 25},
  [18457] = {.lex_state = 0, .external_lex_state = 25},
  [18458] = {.lex_state = 0, .external_lex_state = 25},
  [18459] = {.lex_state = 0, .external_lex_state = 25},
  [18460] = {.lex_state = 0, .external_lex_state = 25},
  [18461] = {.lex_state = 0, .external_lex_state = 25},
  [18462] = {.lex_state = 0, .external_lex_state = 25},
  [18463] = {.lex_state = 0, .external_lex_state = 25},
  [18464] = {.lex_state = 0, .external_lex_state = 25},
  [18465] = {.lex_state = 0, .external_lex_state = 25},
  [18466] = {.lex_state = 0, .external_lex_state = 25},
  [18467] = {.lex_state = 0, .external_lex_state = 25},
  [18468] = {.lex_state = 0, .external_lex_state = 25},
  [18469] = {.lex_state = 0},
  [18470] = {.lex_state = 0},
  [18471] = {.lex_state = 84},
  [18472] = {.lex_state = 0},
  [18473] = {.lex_state = 0},
  [18474] = {.lex_state = 0, .external_lex_state = 25},
  [18475] = {.lex_state = 0},
  [18476] = {.lex_state = 0},
  [18477] = {.lex_state = 0, .external_lex_state = 64},
  [18478] = {.lex_state = 84, .external_lex_state = 49},
  [18479] = {.lex_state = 0, .external_lex_state = 64},
  [18480] = {.lex_state = 0},
  [18481] = {.lex_state = 0, .external_lex_state = 64},
  [18482] = {.lex_state = 0},
  [18483] = {.lex_state = 0, .external_lex_state = 64},
  [18484] = {.lex_state = 0},
  [18485] = {.lex_state = 0, .external_lex_state = 64},
  [18486] = {.lex_state = 0},
  [18487] = {.lex_state = 0},
  [18488] = {.lex_state = 0},
  [18489] = {.lex_state = 0},
  [18490] = {.lex_state = 0},
  [18491] = {.lex_state = 0, .external_lex_state = 64},
  [18492] = {.lex_state = 0},
  [18493] = {.lex_state = 0, .external_lex_state = 64},
  [18494] = {.lex_state = 84},
  [18495] = {.lex_state = 0, .external_lex_state = 64},
  [18496] = {.lex_state = 0},
  [18497] = {.lex_state = 0, .external_lex_state = 64},
  [18498] = {.lex_state = 48},
  [18499] = {.lex_state = 0},
  [18500] = {.lex_state = 0, .external_lex_state = 64},
  [18501] = {.lex_state = 0},
  [18502] = {.lex_state = 0},
  [18503] = {.lex_state = 84},
  [18504] = {.lex_state = 84},
  [18505] = {.lex_state = 0, .external_lex_state = 64},
  [18506] = {.lex_state = 0},
  [18507] = {.lex_state = 0},
  [18508] = {.lex_state = 0, .external_lex_state = 64},
  [18509] = {.lex_state = 0},
  [18510] = {.lex_state = 84},
  [18511] = {.lex_state = 0, .external_lex_state = 64},
  [18512] = {.lex_state = 0, .external_lex_state = 25},
  [18513] = {.lex_state = 0},
  [18514] = {.lex_state = 0},
  [18515] = {.lex_state = 0, .external_lex_state = 64},
  [18516] = {.lex_state = 84},
  [18517] = {.lex_state = 0},
  [18518] = {.lex_state = 0},
  [18519] = {.lex_state = 84, .external_lex_state = 49},
  [18520] = {.lex_state = 0},
  [18521] = {.lex_state = 84, .external_lex_state = 49},
  [18522] = {.lex_state = 0},
  [18523] = {.lex_state = 84, .external_lex_state = 49},
  [18524] = {.lex_state = 0, .external_lex_state = 64},
  [18525] = {.lex_state = 0},
  [18526] = {.lex_state = 0},
  [18527] = {.lex_state = 0},
  [18528] = {.lex_state = 0, .external_lex_state = 64},
  [18529] = {.lex_state = 84},
  [18530] = {.lex_state = 0},
  [18531] = {.lex_state = 0},
  [18532] = {.lex_state = 0},
  [18533] = {.lex_state = 84},
  [18534] = {(TSStateId)(-1)},
  [18535] = {(TSStateId)(-1)},
  [18536] = {(TSStateId)(-1)},
  [18537] = {(TSStateId)(-1)},
};

enum {
  ts_external_token__automatic_semicolon = 0,
  ts_external_token__indent = 1,
  ts_external_token__interpolated_string_middle = 2,
  ts_external_token__interpolated_string_end = 3,
  ts_external_token__interpolated_multiline_string_middle = 4,
  ts_external_token__interpolated_multiline_string_end = 5,
  ts_external_token__outdent = 6,
  ts_external_token__simple_multiline_string = 7,
  ts_external_token__simple_string = 8,
  ts_external_token_else = 9,
  ts_external_token_catch = 10,
  ts_external_token_finally = 11,
  ts_external_token_extends = 12,
  ts_external_token_derives = 13,
  ts_external_token_with = 14,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__automatic_semicolon] = sym__automatic_semicolon,
  [ts_external_token__indent] = sym__indent,
  [ts_external_token__interpolated_string_middle] = sym__interpolated_string_middle,
  [ts_external_token__interpolated_string_end] = sym__interpolated_string_end,
  [ts_external_token__interpolated_multiline_string_middle] = sym__interpolated_multiline_string_middle,
  [ts_external_token__interpolated_multiline_string_end] = sym__interpolated_multiline_string_end,
  [ts_external_token__outdent] = sym__outdent,
  [ts_external_token__simple_multiline_string] = sym__simple_multiline_string,
  [ts_external_token__simple_string] = sym__simple_string,
  [ts_external_token_else] = anon_sym_else,
  [ts_external_token_catch] = anon_sym_catch,
  [ts_external_token_finally] = anon_sym_finally,
  [ts_external_token_extends] = anon_sym_extends,
  [ts_external_token_derives] = anon_sym_derives,
  [ts_external_token_with] = anon_sym_with,
};

static const bool ts_external_scanner_states[74][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__indent] = true,
    [ts_external_token__interpolated_string_middle] = true,
    [ts_external_token__interpolated_string_end] = true,
    [ts_external_token__interpolated_multiline_string_middle] = true,
    [ts_external_token__interpolated_multiline_string_end] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_extends] = true,
    [ts_external_token_derives] = true,
    [ts_external_token_with] = true,
  },
  [2] = {
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
  },
  [3] = {
    [ts_external_token__indent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
  },
  [4] = {
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
  },
  [5] = {
    [ts_external_token__indent] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
  },
  [6] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [7] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
  },
  [8] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [9] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_finally] = true,
  },
  [10] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
  },
  [11] = {
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [12] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [13] = {
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
  },
  [14] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [15] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
  },
  [16] = {
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [17] = {
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
  },
  [18] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_else] = true,
  },
  [19] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
  },
  [20] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_finally] = true,
  },
  [21] = {
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
    [ts_external_token_finally] = true,
  },
  [22] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token__simple_multiline_string] = true,
    [ts_external_token__simple_string] = true,
  },
  [23] = {
    [ts_external_token__automatic_semicolon] = true,
  },
  [24] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
  },
  [25] = {
    [ts_external_token__indent] = true,
  },
  [26] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [27] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [28] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [29] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [30] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [31] = {
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [32] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [33] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_else] = true,
    [ts_external_token_with] = true,
  },
  [34] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
  },
  [35] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_with] = true,
  },
  [36] = {
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [37] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [38] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_finally] = true,
  },
  [39] = {
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [40] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_else] = true,
  },
  [41] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [42] = {
    [ts_external_token_else] = true,
    [ts_external_token_with] = true,
  },
  [43] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [44] = {
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [45] = {
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
  },
  [46] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_else] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [47] = {
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [48] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_finally] = true,
    [ts_external_token_with] = true,
  },
  [49] = {
    [ts_external_token_with] = true,
  },
  [50] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_with] = true,
  },
  [51] = {
    [ts_external_token_else] = true,
  },
  [52] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_else] = true,
    [ts_external_token_with] = true,
  },
  [53] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_else] = true,
    [ts_external_token_finally] = true,
  },
  [54] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [55] = {
    [ts_external_token_catch] = true,
    [ts_external_token_finally] = true,
  },
  [56] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_finally] = true,
  },
  [57] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_else] = true,
  },
  [58] = {
    [ts_external_token_finally] = true,
  },
  [59] = {
    [ts_external_token__outdent] = true,
    [ts_external_token_with] = true,
  },
  [60] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_extends] = true,
    [ts_external_token_derives] = true,
  },
  [61] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_derives] = true,
    [ts_external_token_with] = true,
  },
  [62] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_extends] = true,
    [ts_external_token_derives] = true,
  },
  [63] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_derives] = true,
    [ts_external_token_with] = true,
  },
  [64] = {
    [ts_external_token__outdent] = true,
  },
  [65] = {
    [ts_external_token_derives] = true,
    [ts_external_token_with] = true,
  },
  [66] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_derives] = true,
  },
  [67] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_extends] = true,
  },
  [68] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token__outdent] = true,
    [ts_external_token_derives] = true,
  },
  [69] = {
    [ts_external_token__automatic_semicolon] = true,
    [ts_external_token_extends] = true,
  },
  [70] = {
    [ts_external_token_extends] = true,
    [ts_external_token_derives] = true,
  },
  [71] = {
    [ts_external_token_derives] = true,
  },
  [72] = {
    [ts_external_token__interpolated_multiline_string_middle] = true,
    [ts_external_token__interpolated_multiline_string_end] = true,
  },
  [73] = {
    [ts_external_token__interpolated_string_middle] = true,
    [ts_external_token__interpolated_string_end] = true,
  },
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [sym_comment] = STATE(0),
    [sym_block_comment] = STATE(0),
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym__alpha_identifier] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_package] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_object] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_export] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym__] = ACTIONS(1),
    [anon_sym_given] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_trait] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_LT_COLON] = ACTIONS(1),
    [anon_sym_GT_COLON] = ACTIONS(1),
    [anon_sym_LT_PERCENT] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_match] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_this] = ACTIONS(1),
    [anon_sym_extension] = ACTIONS(1),
    [anon_sym_val] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_var] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_def] = ACTIONS(1),
    [anon_sym_opaque] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_abstract] = ACTIONS(1),
    [anon_sym_final] = ACTIONS(1),
    [anon_sym_sealed] = ACTIONS(1),
    [anon_sym_implicit] = ACTIONS(1),
    [anon_sym_lazy] = ACTIONS(1),
    [anon_sym_override] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_protected] = ACTIONS(1),
    [anon_sym_inline] = ACTIONS(1),
    [anon_sym_infix] = ACTIONS(1),
    [anon_sym_open] = ACTIONS(1),
    [anon_sym_transparent] = ACTIONS(1),
    [anon_sym_extends] = ACTIONS(1),
    [anon_sym_derives] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_using] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [anon_sym_QMARK_EQ_GT] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_then] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_finally] = ACTIONS(1),
    [anon_sym_macro] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [sym_symbol_literal] = ACTIONS(1),
    [sym__backquoted_id] = ACTIONS(1),
    [sym_integer_literal] = ACTIONS(1),
    [sym_floating_point_literal] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [sym_character_literal] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [sym__interpolated_multiline_string_start] = ACTIONS(1),
    [sym_null_literal] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_throw] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_yield] = ACTIONS(1),
    [anon_sym_LT_DASH] = ACTIONS(1),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1),
    [sym__indent] = ACTIONS(1),
    [sym__interpolated_string_middle] = ACTIONS(1),
    [sym__interpolated_string_end] = ACTIONS(1),
    [sym__interpolated_multiline_string_middle] = ACTIONS(1),
    [sym__interpolated_multiline_string_end] = ACTIONS(1),
    [sym__outdent] = ACTIONS(1),
    [sym__simple_multiline_string] = ACTIONS(1),
    [sym__simple_string] = ACTIONS(1),
  },
  [1] = {
    [sym_compilation_unit] = STATE(18527),
    [sym__top_level_definition] = STATE(15148),
    [sym_enum_definition] = STATE(15198),
    [sym_package_clause] = STATE(15198),
    [sym_package_object] = STATE(15198),
    [sym_import_declaration] = STATE(15198),
    [sym_export_declaration] = STATE(15198),
    [sym_object_definition] = STATE(15198),
    [sym_class_definition] = STATE(15198),
    [sym_trait_definition] = STATE(15198),
    [sym__end_marker] = STATE(15198),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15198),
    [sym_val_declaration] = STATE(15198),
    [sym__start_val] = STATE(4223),
    [sym_var_declaration] = STATE(15198),
    [sym_var_definition] = STATE(15198),
    [sym__start_var] = STATE(4225),
    [sym_type_definition] = STATE(15198),
    [sym_function_definition] = STATE(15198),
    [sym_function_declaration] = STATE(15198),
    [sym__function_declaration] = STATE(14524),
    [sym_opaque_modifier] = STATE(18533),
    [sym_extension_definition] = STATE(15198),
    [sym_given_definition] = STATE(15198),
    [sym_modifiers] = STATE(12957),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(577),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(14527),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym__shebang] = STATE(154),
    [sym_comment] = STATE(1),
    [sym_block_comment] = STATE(1),
    [aux_sym_enum_definition_repeat1] = STATE(4333),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [ts_builtin_sym_end] = ACTIONS(7),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_package] = ACTIONS(17),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_given] = ACTIONS(27),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(35),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_extension] = ACTIONS(47),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_def] = ACTIONS(57),
    [anon_sym_opaque] = ACTIONS(59),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(63),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(69),
    [anon_sym_open] = ACTIONS(71),
    [anon_sym_transparent] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [aux_sym__shebang_token1] = ACTIONS(101),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [2] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18175),
    [sym__braced_template_body2] = STATE(18175),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2),
    [sym_block_comment] = STATE(2),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(109),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [3] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17137),
    [sym__braced_template_body2] = STATE(17137),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(3),
    [sym_block_comment] = STATE(3),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(177),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [4] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17793),
    [sym__braced_template_body2] = STATE(17793),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(4),
    [sym_block_comment] = STATE(4),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(179),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [5] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16784),
    [sym__braced_template_body2] = STATE(16784),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(5),
    [sym_block_comment] = STATE(5),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(181),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [6] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16915),
    [sym__braced_template_body2] = STATE(16915),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(6),
    [sym_block_comment] = STATE(6),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(183),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [7] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18274),
    [sym__braced_template_body2] = STATE(18274),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(7),
    [sym_block_comment] = STATE(7),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(185),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [8] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17872),
    [sym__braced_template_body2] = STATE(17872),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(8),
    [sym_block_comment] = STATE(8),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(187),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [9] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18522),
    [sym__braced_template_body2] = STATE(18522),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(9),
    [sym_block_comment] = STATE(9),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(189),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [10] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17941),
    [sym__braced_template_body2] = STATE(17941),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(10),
    [sym_block_comment] = STATE(10),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(191),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [11] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17818),
    [sym__braced_template_body2] = STATE(17818),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(11),
    [sym_block_comment] = STATE(11),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [12] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18161),
    [sym__braced_template_body2] = STATE(18161),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(12),
    [sym_block_comment] = STATE(12),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(195),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [13] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17868),
    [sym__braced_template_body2] = STATE(17868),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(13),
    [sym_block_comment] = STATE(13),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(197),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [14] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17735),
    [sym__braced_template_body2] = STATE(17735),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(14),
    [sym_block_comment] = STATE(14),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(199),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [15] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16963),
    [sym__braced_template_body2] = STATE(16963),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(15),
    [sym_block_comment] = STATE(15),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(201),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [16] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18277),
    [sym__braced_template_body2] = STATE(18277),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(16),
    [sym_block_comment] = STATE(16),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(203),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [17] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17915),
    [sym__braced_template_body2] = STATE(17915),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(17),
    [sym_block_comment] = STATE(17),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(205),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [18] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17794),
    [sym__braced_template_body2] = STATE(17794),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(18),
    [sym_block_comment] = STATE(18),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(207),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [19] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18250),
    [sym__braced_template_body2] = STATE(18250),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(19),
    [sym_block_comment] = STATE(19),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(209),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [20] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18265),
    [sym__braced_template_body2] = STATE(18265),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(20),
    [sym_block_comment] = STATE(20),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(211),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [21] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17927),
    [sym__braced_template_body2] = STATE(17927),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(21),
    [sym_block_comment] = STATE(21),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(213),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [22] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17691),
    [sym__braced_template_body2] = STATE(17691),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(22),
    [sym_block_comment] = STATE(22),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(215),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [23] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17940),
    [sym__braced_template_body2] = STATE(17940),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(23),
    [sym_block_comment] = STATE(23),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(217),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [24] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17100),
    [sym__braced_template_body2] = STATE(17100),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(24),
    [sym_block_comment] = STATE(24),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(219),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [25] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18484),
    [sym__braced_template_body2] = STATE(18484),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(25),
    [sym_block_comment] = STATE(25),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(221),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [26] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18509),
    [sym__braced_template_body2] = STATE(18509),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(26),
    [sym_block_comment] = STATE(26),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(223),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [27] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17769),
    [sym__braced_template_body2] = STATE(17769),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(27),
    [sym_block_comment] = STATE(27),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(225),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [28] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18300),
    [sym__braced_template_body2] = STATE(18300),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(28),
    [sym_block_comment] = STATE(28),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(227),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [29] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17962),
    [sym__braced_template_body2] = STATE(17962),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(29),
    [sym_block_comment] = STATE(29),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(229),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [30] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18287),
    [sym__braced_template_body2] = STATE(18287),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(30),
    [sym_block_comment] = STATE(30),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(231),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [31] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17649),
    [sym__braced_template_body2] = STATE(17649),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(31),
    [sym_block_comment] = STATE(31),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(233),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [32] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18239),
    [sym__braced_template_body2] = STATE(18239),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(32),
    [sym_block_comment] = STATE(32),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(235),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [33] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16732),
    [sym__braced_template_body2] = STATE(16732),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(33),
    [sym_block_comment] = STATE(33),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(237),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [34] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18292),
    [sym__braced_template_body2] = STATE(18292),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(34),
    [sym_block_comment] = STATE(34),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(239),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [35] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16838),
    [sym__braced_template_body2] = STATE(16838),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(35),
    [sym_block_comment] = STATE(35),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(241),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [36] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17959),
    [sym__braced_template_body2] = STATE(17959),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(36),
    [sym_block_comment] = STATE(36),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(243),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [37] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17737),
    [sym__braced_template_body2] = STATE(17737),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(37),
    [sym_block_comment] = STATE(37),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(245),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [38] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18234),
    [sym__braced_template_body2] = STATE(18234),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(38),
    [sym_block_comment] = STATE(38),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(247),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [39] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18225),
    [sym__braced_template_body2] = STATE(18225),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(39),
    [sym_block_comment] = STATE(39),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(249),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [40] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17598),
    [sym__braced_template_body2] = STATE(17598),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(40),
    [sym_block_comment] = STATE(40),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(251),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [41] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18220),
    [sym__braced_template_body2] = STATE(18220),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(41),
    [sym_block_comment] = STATE(41),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(253),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [42] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18506),
    [sym__braced_template_body2] = STATE(18506),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(42),
    [sym_block_comment] = STATE(42),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(255),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [43] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17966),
    [sym__braced_template_body2] = STATE(17966),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(43),
    [sym_block_comment] = STATE(43),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(257),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [44] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17182),
    [sym__braced_template_body2] = STATE(17182),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(44),
    [sym_block_comment] = STATE(44),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(259),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [45] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17009),
    [sym__braced_template_body2] = STATE(17009),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(45),
    [sym_block_comment] = STATE(45),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(261),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [46] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18207),
    [sym__braced_template_body2] = STATE(18207),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(46),
    [sym_block_comment] = STATE(46),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(263),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [47] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18350),
    [sym__braced_template_body2] = STATE(18350),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(47),
    [sym_block_comment] = STATE(47),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(265),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [48] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17545),
    [sym__braced_template_body2] = STATE(17545),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(48),
    [sym_block_comment] = STATE(48),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(267),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [49] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18202),
    [sym__braced_template_body2] = STATE(18202),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(49),
    [sym_block_comment] = STATE(49),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(269),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [50] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17700),
    [sym__braced_template_body2] = STATE(17700),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(50),
    [sym_block_comment] = STATE(50),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(271),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [51] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18499),
    [sym__braced_template_body2] = STATE(18499),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(51),
    [sym_block_comment] = STATE(51),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(273),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [52] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16869),
    [sym__braced_template_body2] = STATE(16869),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(52),
    [sym_block_comment] = STATE(52),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(275),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [53] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17974),
    [sym__braced_template_body2] = STATE(17974),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(53),
    [sym_block_comment] = STATE(53),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(277),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [54] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18305),
    [sym__braced_template_body2] = STATE(18305),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(54),
    [sym_block_comment] = STATE(54),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(279),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [55] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17415),
    [sym__braced_template_body2] = STATE(17415),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(55),
    [sym_block_comment] = STATE(55),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(281),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [56] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18190),
    [sym__braced_template_body2] = STATE(18190),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(56),
    [sym_block_comment] = STATE(56),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(283),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [57] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17229),
    [sym__braced_template_body2] = STATE(17229),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(57),
    [sym_block_comment] = STATE(57),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(285),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [58] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17487),
    [sym__braced_template_body2] = STATE(17487),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(58),
    [sym_block_comment] = STATE(58),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(287),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [59] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17055),
    [sym__braced_template_body2] = STATE(17055),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(59),
    [sym_block_comment] = STATE(59),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(289),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [60] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18179),
    [sym__braced_template_body2] = STATE(18179),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(60),
    [sym_block_comment] = STATE(60),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(291),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [61] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17996),
    [sym__braced_template_body2] = STATE(17996),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(61),
    [sym_block_comment] = STATE(61),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(293),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [62] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18490),
    [sym__braced_template_body2] = STATE(18490),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(62),
    [sym_block_comment] = STATE(62),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(295),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [63] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18313),
    [sym__braced_template_body2] = STATE(18313),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(63),
    [sym_block_comment] = STATE(63),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(297),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [64] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18193),
    [sym__braced_template_body2] = STATE(18193),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(64),
    [sym_block_comment] = STATE(64),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [65] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18530),
    [sym__braced_template_body2] = STATE(18530),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(65),
    [sym_block_comment] = STATE(65),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(301),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [66] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17838),
    [sym__braced_template_body2] = STATE(17838),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(66),
    [sym_block_comment] = STATE(66),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(303),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [67] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16708),
    [sym__braced_template_body2] = STATE(16708),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(67),
    [sym_block_comment] = STATE(67),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(305),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [68] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18166),
    [sym__braced_template_body2] = STATE(18166),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(68),
    [sym_block_comment] = STATE(68),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(307),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [69] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18317),
    [sym__braced_template_body2] = STATE(18317),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(69),
    [sym_block_comment] = STATE(69),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(309),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [70] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17662),
    [sym__braced_template_body2] = STATE(17662),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(70),
    [sym_block_comment] = STATE(70),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(311),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [71] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18162),
    [sym__braced_template_body2] = STATE(18162),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(71),
    [sym_block_comment] = STATE(71),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(313),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [72] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17283),
    [sym__braced_template_body2] = STATE(17283),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(72),
    [sym_block_comment] = STATE(72),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(315),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [73] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17439),
    [sym__braced_template_body2] = STATE(17439),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(73),
    [sym_block_comment] = STATE(73),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(317),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [74] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17102),
    [sym__braced_template_body2] = STATE(17102),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(74),
    [sym_block_comment] = STATE(74),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(319),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [75] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18153),
    [sym__braced_template_body2] = STATE(18153),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(75),
    [sym_block_comment] = STATE(75),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(321),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [76] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18022),
    [sym__braced_template_body2] = STATE(18022),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(76),
    [sym_block_comment] = STATE(76),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(323),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [77] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18412),
    [sym__braced_template_body2] = STATE(18412),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(77),
    [sym_block_comment] = STATE(77),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(325),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [78] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17047),
    [sym__braced_template_body2] = STATE(17047),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(78),
    [sym_block_comment] = STATE(78),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(327),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [79] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17634),
    [sym__braced_template_body2] = STATE(17634),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(79),
    [sym_block_comment] = STATE(79),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(329),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [80] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18520),
    [sym__braced_template_body2] = STATE(18520),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(80),
    [sym_block_comment] = STATE(80),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(331),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [81] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18029),
    [sym__braced_template_body2] = STATE(18029),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(81),
    [sym_block_comment] = STATE(81),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(333),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [82] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18205),
    [sym__braced_template_body2] = STATE(18205),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(82),
    [sym_block_comment] = STATE(82),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(335),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [83] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17331),
    [sym__braced_template_body2] = STATE(17331),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(83),
    [sym_block_comment] = STATE(83),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(337),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [84] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17391),
    [sym__braced_template_body2] = STATE(17391),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(84),
    [sym_block_comment] = STATE(84),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(339),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [85] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18037),
    [sym__braced_template_body2] = STATE(18037),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(85),
    [sym_block_comment] = STATE(85),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(341),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [86] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17156),
    [sym__braced_template_body2] = STATE(17156),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(86),
    [sym_block_comment] = STATE(86),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(343),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [87] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18049),
    [sym__braced_template_body2] = STATE(18049),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(87),
    [sym_block_comment] = STATE(87),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(345),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [88] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16729),
    [sym__braced_template_body2] = STATE(16729),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(88),
    [sym_block_comment] = STATE(88),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(347),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [89] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18046),
    [sym__braced_template_body2] = STATE(18046),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(89),
    [sym_block_comment] = STATE(89),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(349),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [90] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18395),
    [sym__braced_template_body2] = STATE(18395),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(90),
    [sym_block_comment] = STATE(90),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(351),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [91] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16937),
    [sym__braced_template_body2] = STATE(16937),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(91),
    [sym_block_comment] = STATE(91),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(353),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [92] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16824),
    [sym__braced_template_body2] = STATE(16824),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(92),
    [sym_block_comment] = STATE(92),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(355),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [93] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18391),
    [sym__braced_template_body2] = STATE(18391),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(93),
    [sym_block_comment] = STATE(93),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(357),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [94] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18325),
    [sym__braced_template_body2] = STATE(18325),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(94),
    [sym_block_comment] = STATE(94),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(359),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [95] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18056),
    [sym__braced_template_body2] = STATE(18056),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(95),
    [sym_block_comment] = STATE(95),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(361),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [96] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17574),
    [sym__braced_template_body2] = STATE(17574),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(96),
    [sym_block_comment] = STATE(96),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(363),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [97] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18142),
    [sym__braced_template_body2] = STATE(18142),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(97),
    [sym_block_comment] = STATE(97),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(365),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [98] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18138),
    [sym__braced_template_body2] = STATE(18138),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(98),
    [sym_block_comment] = STATE(98),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(367),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [99] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18489),
    [sym__braced_template_body2] = STATE(18489),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(99),
    [sym_block_comment] = STATE(99),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(369),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [100] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18027),
    [sym__braced_template_body2] = STATE(18027),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(100),
    [sym_block_comment] = STATE(100),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(371),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [101] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16882),
    [sym__braced_template_body2] = STATE(16882),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(101),
    [sym_block_comment] = STATE(101),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(373),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [102] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17348),
    [sym__braced_template_body2] = STATE(17348),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(102),
    [sym_block_comment] = STATE(102),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(375),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [103] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18330),
    [sym__braced_template_body2] = STATE(18330),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(103),
    [sym_block_comment] = STATE(103),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(377),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [104] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18382),
    [sym__braced_template_body2] = STATE(18382),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(104),
    [sym_block_comment] = STATE(104),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(379),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [105] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18066),
    [sym__braced_template_body2] = STATE(18066),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(105),
    [sym_block_comment] = STATE(105),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(381),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [106] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17369),
    [sym__braced_template_body2] = STATE(17369),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(106),
    [sym_block_comment] = STATE(106),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(383),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [107] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17203),
    [sym__braced_template_body2] = STATE(17203),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(107),
    [sym_block_comment] = STATE(107),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(385),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [108] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18379),
    [sym__braced_template_body2] = STATE(18379),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(108),
    [sym_block_comment] = STATE(108),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(387),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [109] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18073),
    [sym__braced_template_body2] = STATE(18073),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(109),
    [sym_block_comment] = STATE(109),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(389),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [110] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17520),
    [sym__braced_template_body2] = STATE(17520),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(110),
    [sym_block_comment] = STATE(110),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(391),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [111] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18081),
    [sym__braced_template_body2] = STATE(18081),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(111),
    [sym_block_comment] = STATE(111),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(393),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [112] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18126),
    [sym__braced_template_body2] = STATE(18126),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(112),
    [sym_block_comment] = STATE(112),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(395),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [113] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18087),
    [sym__braced_template_body2] = STATE(18087),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(113),
    [sym_block_comment] = STATE(113),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(397),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [114] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18121),
    [sym__braced_template_body2] = STATE(18121),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(114),
    [sym_block_comment] = STATE(114),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(399),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [115] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18345),
    [sym__braced_template_body2] = STATE(18345),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(115),
    [sym_block_comment] = STATE(115),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(401),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [116] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18091),
    [sym__braced_template_body2] = STATE(18091),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(116),
    [sym_block_comment] = STATE(116),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(403),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [117] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18367),
    [sym__braced_template_body2] = STATE(18367),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(117),
    [sym_block_comment] = STATE(117),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(405),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [118] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17303),
    [sym__braced_template_body2] = STATE(17303),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(118),
    [sym_block_comment] = STATE(118),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(407),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [119] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18364),
    [sym__braced_template_body2] = STATE(18364),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(119),
    [sym_block_comment] = STATE(119),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(409),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [120] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16776),
    [sym__braced_template_body2] = STATE(16776),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(120),
    [sym_block_comment] = STATE(120),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(411),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [121] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18101),
    [sym__braced_template_body2] = STATE(18101),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(121),
    [sym_block_comment] = STATE(121),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(413),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [122] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17467),
    [sym__braced_template_body2] = STATE(17467),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(122),
    [sym_block_comment] = STATE(122),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(415),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [123] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(16989),
    [sym__braced_template_body2] = STATE(16989),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(123),
    [sym_block_comment] = STATE(123),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(417),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [124] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18105),
    [sym__braced_template_body2] = STATE(18105),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(124),
    [sym_block_comment] = STATE(124),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(419),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [125] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18351),
    [sym__braced_template_body2] = STATE(18351),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(125),
    [sym_block_comment] = STATE(125),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(421),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [126] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(17250),
    [sym__braced_template_body2] = STATE(17250),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(126),
    [sym_block_comment] = STATE(126),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(423),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [127] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__braced_template_body1] = STATE(18114),
    [sym__braced_template_body2] = STATE(18114),
    [sym__end_marker] = STATE(15109),
    [sym_self_type] = STATE(300),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18488),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6256),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(127),
    [sym_block_comment] = STATE(127),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(425),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(159),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(173),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [128] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17116),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(128),
    [sym_block_comment] = STATE(128),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15189),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(427),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [129] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17163),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(129),
    [sym_block_comment] = STATE(129),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15059),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(433),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [130] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17805),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(130),
    [sym_block_comment] = STATE(130),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15166),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(435),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [131] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17747),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(131),
    [sym_block_comment] = STATE(131),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14959),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(437),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [132] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17264),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(132),
    [sym_block_comment] = STATE(132),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14921),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(439),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [133] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16710),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(133),
    [sym_block_comment] = STATE(133),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15068),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(441),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [134] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17880),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(134),
    [sym_block_comment] = STATE(134),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14861),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(443),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [135] = {
    [sym__top_level_definition] = STATE(15280),
    [sym_enum_definition] = STATE(15198),
    [sym_package_clause] = STATE(15198),
    [sym_package_object] = STATE(15198),
    [sym_import_declaration] = STATE(15198),
    [sym_export_declaration] = STATE(15198),
    [sym_object_definition] = STATE(15198),
    [sym_class_definition] = STATE(15198),
    [sym_trait_definition] = STATE(15198),
    [sym__end_marker] = STATE(15198),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15198),
    [sym_val_declaration] = STATE(15198),
    [sym__start_val] = STATE(4223),
    [sym_var_declaration] = STATE(15198),
    [sym_var_definition] = STATE(15198),
    [sym__start_var] = STATE(4225),
    [sym_type_definition] = STATE(15198),
    [sym_function_definition] = STATE(15198),
    [sym_function_declaration] = STATE(15198),
    [sym__function_declaration] = STATE(14524),
    [sym_opaque_modifier] = STATE(18533),
    [sym_extension_definition] = STATE(15198),
    [sym_given_definition] = STATE(15198),
    [sym_modifiers] = STATE(12957),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(577),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(14527),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(135),
    [sym_block_comment] = STATE(135),
    [aux_sym_enum_definition_repeat1] = STATE(4333),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [ts_builtin_sym_end] = ACTIONS(445),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_package] = ACTIONS(17),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_given] = ACTIONS(27),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(35),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_extension] = ACTIONS(47),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_def] = ACTIONS(57),
    [anon_sym_opaque] = ACTIONS(59),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(63),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(69),
    [anon_sym_open] = ACTIONS(71),
    [anon_sym_transparent] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [136] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17699),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(136),
    [sym_block_comment] = STATE(136),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14868),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(447),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [137] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16831),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(137),
    [sym_block_comment] = STATE(137),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14960),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(449),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [138] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17657),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(138),
    [sym_block_comment] = STATE(138),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14926),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(451),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [139] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16878),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(139),
    [sym_block_comment] = STATE(139),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14899),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(453),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [140] = {
    [sym__top_level_definition] = STATE(15280),
    [sym_enum_definition] = STATE(15198),
    [sym_package_clause] = STATE(15198),
    [sym_package_object] = STATE(15198),
    [sym_import_declaration] = STATE(15198),
    [sym_export_declaration] = STATE(15198),
    [sym_object_definition] = STATE(15198),
    [sym_class_definition] = STATE(15198),
    [sym_trait_definition] = STATE(15198),
    [sym__end_marker] = STATE(15198),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15198),
    [sym_val_declaration] = STATE(15198),
    [sym__start_val] = STATE(4223),
    [sym_var_declaration] = STATE(15198),
    [sym_var_definition] = STATE(15198),
    [sym__start_var] = STATE(4225),
    [sym_type_definition] = STATE(15198),
    [sym_function_definition] = STATE(15198),
    [sym_function_declaration] = STATE(15198),
    [sym__function_declaration] = STATE(14524),
    [sym_opaque_modifier] = STATE(18533),
    [sym_extension_definition] = STATE(15198),
    [sym_given_definition] = STATE(15198),
    [sym_modifiers] = STATE(12957),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(577),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(14527),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(140),
    [sym_block_comment] = STATE(140),
    [aux_sym_enum_definition_repeat1] = STATE(4333),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [ts_builtin_sym_end] = ACTIONS(455),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_package] = ACTIONS(17),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_given] = ACTIONS(27),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(35),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_extension] = ACTIONS(47),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_def] = ACTIONS(57),
    [anon_sym_opaque] = ACTIONS(59),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(63),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(69),
    [anon_sym_open] = ACTIONS(71),
    [anon_sym_transparent] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [141] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17978),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(141),
    [sym_block_comment] = STATE(141),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14992),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(457),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [142] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17610),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(142),
    [sym_block_comment] = STATE(142),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14937),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(459),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [143] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18525),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(143),
    [sym_block_comment] = STATE(143),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15104),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(461),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [144] = {
    [sym__top_level_definition] = STATE(15280),
    [sym_enum_definition] = STATE(15198),
    [sym_package_clause] = STATE(15198),
    [sym_package_object] = STATE(15198),
    [sym_import_declaration] = STATE(15198),
    [sym_export_declaration] = STATE(15198),
    [sym_object_definition] = STATE(15198),
    [sym_class_definition] = STATE(15198),
    [sym_trait_definition] = STATE(15198),
    [sym__end_marker] = STATE(15198),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15198),
    [sym_val_declaration] = STATE(15198),
    [sym__start_val] = STATE(4223),
    [sym_var_declaration] = STATE(15198),
    [sym_var_definition] = STATE(15198),
    [sym__start_var] = STATE(4225),
    [sym_type_definition] = STATE(15198),
    [sym_function_definition] = STATE(15198),
    [sym_function_declaration] = STATE(15198),
    [sym__function_declaration] = STATE(14524),
    [sym_opaque_modifier] = STATE(18533),
    [sym_extension_definition] = STATE(15198),
    [sym_given_definition] = STATE(15198),
    [sym_modifiers] = STATE(12957),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(577),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(14527),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(144),
    [sym_block_comment] = STATE(144),
    [aux_sym_enum_definition_repeat1] = STATE(4333),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [ts_builtin_sym_end] = ACTIONS(463),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_package] = ACTIONS(17),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_given] = ACTIONS(27),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(35),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_extension] = ACTIONS(47),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_def] = ACTIONS(57),
    [anon_sym_opaque] = ACTIONS(59),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(63),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(69),
    [anon_sym_open] = ACTIONS(71),
    [anon_sym_transparent] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [145] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17215),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(145),
    [sym_block_comment] = STATE(145),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15006),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(465),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [146] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17310),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(146),
    [sym_block_comment] = STATE(146),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14872),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(467),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [147] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16924),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(147),
    [sym_block_comment] = STATE(147),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15036),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(469),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [148] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16783),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(148),
    [sym_block_comment] = STATE(148),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15147),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(471),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [149] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17552),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(149),
    [sym_block_comment] = STATE(149),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15112),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(473),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [150] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17499),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(150),
    [sym_block_comment] = STATE(150),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15183),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(475),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [151] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17063),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(151),
    [sym_block_comment] = STATE(151),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15190),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(477),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [152] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16741),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(152),
    [sym_block_comment] = STATE(152),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14935),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(479),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [153] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17446),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(153),
    [sym_block_comment] = STATE(153),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15158),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(481),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [154] = {
    [sym__top_level_definition] = STATE(14920),
    [sym_enum_definition] = STATE(15198),
    [sym_package_clause] = STATE(15198),
    [sym_package_object] = STATE(15198),
    [sym_import_declaration] = STATE(15198),
    [sym_export_declaration] = STATE(15198),
    [sym_object_definition] = STATE(15198),
    [sym_class_definition] = STATE(15198),
    [sym_trait_definition] = STATE(15198),
    [sym__end_marker] = STATE(15198),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15198),
    [sym_val_declaration] = STATE(15198),
    [sym__start_val] = STATE(4223),
    [sym_var_declaration] = STATE(15198),
    [sym_var_definition] = STATE(15198),
    [sym__start_var] = STATE(4225),
    [sym_type_definition] = STATE(15198),
    [sym_function_definition] = STATE(15198),
    [sym_function_declaration] = STATE(15198),
    [sym__function_declaration] = STATE(14524),
    [sym_opaque_modifier] = STATE(18533),
    [sym_extension_definition] = STATE(15198),
    [sym_given_definition] = STATE(15198),
    [sym_modifiers] = STATE(12957),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(577),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(14527),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(154),
    [sym_block_comment] = STATE(154),
    [aux_sym_enum_definition_repeat1] = STATE(4333),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [ts_builtin_sym_end] = ACTIONS(483),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_package] = ACTIONS(17),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_given] = ACTIONS(27),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(35),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_extension] = ACTIONS(47),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_def] = ACTIONS(57),
    [anon_sym_opaque] = ACTIONS(59),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(63),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(69),
    [anon_sym_open] = ACTIONS(71),
    [anon_sym_transparent] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [155] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17359),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(155),
    [sym_block_comment] = STATE(155),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14966),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(485),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [156] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17403),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_case_clause] = STATE(16684),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(156),
    [sym_block_comment] = STATE(156),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15058),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(487),
    [anon_sym_case] = ACTIONS(429),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [157] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17099),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(157),
    [sym_block_comment] = STATE(157),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14946),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [158] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17247),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(158),
    [sym_block_comment] = STATE(158),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15033),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [159] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16707),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(159),
    [sym_block_comment] = STATE(159),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14885),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [160] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17147),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(160),
    [sym_block_comment] = STATE(160),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14867),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [161] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17819),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(161),
    [sym_block_comment] = STATE(161),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15048),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [162] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17839),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(162),
    [sym_block_comment] = STATE(162),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15022),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [163] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16814),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(163),
    [sym_block_comment] = STATE(163),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15124),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [164] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17873),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(164),
    [sym_block_comment] = STATE(164),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14989),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [165] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17420),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(165),
    [sym_block_comment] = STATE(165),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15171),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [166] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17282),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(166),
    [sym_block_comment] = STATE(166),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15002),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [167] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17435),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(167),
    [sym_block_comment] = STATE(167),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14917),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [168] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17686),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(168),
    [sym_block_comment] = STATE(168),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14927),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [169] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17896),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(169),
    [sym_block_comment] = STATE(169),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14967),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [170] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16991),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(170),
    [sym_block_comment] = STATE(170),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14993),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [171] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17342),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(171),
    [sym_block_comment] = STATE(171),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14919),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [172] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16734),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(172),
    [sym_block_comment] = STATE(172),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14948),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [173] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16861),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(173),
    [sym_block_comment] = STATE(173),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15160),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [174] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17917),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(174),
    [sym_block_comment] = STATE(174),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15180),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [175] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17285),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(175),
    [sym_block_comment] = STATE(175),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14949),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [176] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17931),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(176),
    [sym_block_comment] = STATE(176),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14942),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [177] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17704),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(177),
    [sym_block_comment] = STATE(177),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15159),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [178] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17960),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(178),
    [sym_block_comment] = STATE(178),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14933),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [179] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17236),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(179),
    [sym_block_comment] = STATE(179),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15126),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [180] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17388),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(180),
    [sym_block_comment] = STATE(180),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15188),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [181] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18043),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(181),
    [sym_block_comment] = STATE(181),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14994),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [182] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17595),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(182),
    [sym_block_comment] = STATE(182),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14948),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [183] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17968),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(183),
    [sym_block_comment] = STATE(183),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14906),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [184] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17730),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(184),
    [sym_block_comment] = STATE(184),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14927),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [185] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17484),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(185),
    [sym_block_comment] = STATE(185),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15130),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [186] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17976),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(186),
    [sym_block_comment] = STATE(186),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15171),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [187] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17184),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(187),
    [sym_block_comment] = STATE(187),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15188),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [188] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17997),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(188),
    [sym_block_comment] = STATE(188),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14876),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [189] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16795),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(189),
    [sym_block_comment] = STATE(189),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15012),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [190] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18025),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(190),
    [sym_block_comment] = STATE(190),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14870),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [191] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18048),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(191),
    [sym_block_comment] = STATE(191),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14897),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [192] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17645),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(192),
    [sym_block_comment] = STATE(192),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14862),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [193] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16907),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(193),
    [sym_block_comment] = STATE(193),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15160),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [194] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17138),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(194),
    [sym_block_comment] = STATE(194),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15191),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [195] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17468),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(195),
    [sym_block_comment] = STATE(195),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14867),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [196] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17521),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(196),
    [sym_block_comment] = STATE(196),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15184),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [197] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(333),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18334),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6647),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(197),
    [sym_block_comment] = STATE(197),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(575),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(577),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [198] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17795),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(198),
    [sym_block_comment] = STATE(198),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15070),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [199] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17345),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(199),
    [sym_block_comment] = STATE(199),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15047),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [200] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18070),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(200),
    [sym_block_comment] = STATE(200),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14923),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [201] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17698),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(201),
    [sym_block_comment] = STATE(201),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15101),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [202] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18092),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(202),
    [sym_block_comment] = STATE(202),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14963),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [203] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18108),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(203),
    [sym_block_comment] = STATE(203),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14967),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [204] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17103),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(204),
    [sym_block_comment] = STATE(204),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15130),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [205] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18125),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(205),
    [sym_block_comment] = STATE(205),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14990),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [206] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16773),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(206),
    [sym_block_comment] = STATE(206),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15169),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [207] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17788),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(207),
    [sym_block_comment] = STATE(207),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15124),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [208] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16841),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(208),
    [sym_block_comment] = STATE(208),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15180),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [209] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17052),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(209),
    [sym_block_comment] = STATE(209),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14904),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [210] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17200),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(210),
    [sym_block_comment] = STATE(210),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14924),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [211] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17053),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(211),
    [sym_block_comment] = STATE(211),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14994),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [212] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17576),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(212),
    [sym_block_comment] = STATE(212),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14946),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [213] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17641),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(213),
    [sym_block_comment] = STATE(213),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15077),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [214] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16954),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(214),
    [sym_block_comment] = STATE(214),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15077),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [215] = {
    [sym__top_level_definition] = STATE(15280),
    [sym_enum_definition] = STATE(15198),
    [sym_package_clause] = STATE(15198),
    [sym_package_object] = STATE(15198),
    [sym_import_declaration] = STATE(15198),
    [sym_export_declaration] = STATE(15198),
    [sym_object_definition] = STATE(15198),
    [sym_class_definition] = STATE(15198),
    [sym_trait_definition] = STATE(15198),
    [sym__end_marker] = STATE(15198),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15198),
    [sym_val_declaration] = STATE(15198),
    [sym__start_val] = STATE(4223),
    [sym_var_declaration] = STATE(15198),
    [sym_var_definition] = STATE(15198),
    [sym__start_var] = STATE(4225),
    [sym_type_definition] = STATE(15198),
    [sym_function_definition] = STATE(15198),
    [sym_function_declaration] = STATE(15198),
    [sym__function_declaration] = STATE(14524),
    [sym_opaque_modifier] = STATE(18533),
    [sym_extension_definition] = STATE(15198),
    [sym_given_definition] = STATE(15198),
    [sym_modifiers] = STATE(12957),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(577),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(14527),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(215),
    [sym_block_comment] = STATE(215),
    [aux_sym_enum_definition_repeat1] = STATE(4333),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_package] = ACTIONS(17),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_given] = ACTIONS(27),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(35),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_extension] = ACTIONS(47),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(55),
    [anon_sym_def] = ACTIONS(57),
    [anon_sym_opaque] = ACTIONS(59),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(63),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(69),
    [anon_sym_open] = ACTIONS(71),
    [anon_sym_transparent] = ACTIONS(73),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [216] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16938),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(216),
    [sym_block_comment] = STATE(216),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15017),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [217] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17299),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(217),
    [sym_block_comment] = STATE(217),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15120),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [218] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18477),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(218),
    [sym_block_comment] = STATE(218),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14917),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [219] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17017),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(219),
    [sym_block_comment] = STATE(219),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14933),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [220] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17956),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(220),
    [sym_block_comment] = STATE(220),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15047),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [221] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16728),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(221),
    [sym_block_comment] = STATE(221),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15015),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [222] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17537),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(222),
    [sym_block_comment] = STATE(222),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15017),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [223] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17004),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(223),
    [sym_block_comment] = STATE(223),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15014),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [224] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17862),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(224),
    [sym_block_comment] = STATE(224),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(14904),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [225] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17664),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(225),
    [sym_block_comment] = STATE(225),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15174),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [226] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17739),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_case_clause] = STATE(16612),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(226),
    [sym_block_comment] = STATE(226),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [aux_sym_indented_cases_repeat1] = STATE(15123),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(495),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [227] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(436),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18098),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(227),
    [sym_block_comment] = STATE(227),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [228] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(413),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17538),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(228),
    [sym_block_comment] = STATE(228),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [229] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18525),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(229),
    [sym_block_comment] = STATE(229),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(581),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [230] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(370),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18380),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(230),
    [sym_block_comment] = STATE(230),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [231] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16970),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(231),
    [sym_block_comment] = STATE(231),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(583),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [232] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(384),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18346),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(232),
    [sym_block_comment] = STATE(232),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [233] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(383),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18392),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(233),
    [sym_block_comment] = STATE(233),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [234] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(373),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17279),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(234),
    [sym_block_comment] = STATE(234),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [235] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(399),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18327),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(235),
    [sym_block_comment] = STATE(235),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [236] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(402),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18315),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(236),
    [sym_block_comment] = STATE(236),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [237] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(393),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18409),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(237),
    [sym_block_comment] = STATE(237),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [238] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(409),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18303),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(238),
    [sym_block_comment] = STATE(238),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [239] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(424),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18288),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(239),
    [sym_block_comment] = STATE(239),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [240] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(417),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16919),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(240),
    [sym_block_comment] = STATE(240),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [241] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(408),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18485),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(241),
    [sym_block_comment] = STATE(241),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [242] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(385),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17899),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(242),
    [sym_block_comment] = STATE(242),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [243] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(432),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18275),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(243),
    [sym_block_comment] = STATE(243),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [244] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(428),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18500),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(244),
    [sym_block_comment] = STATE(244),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [245] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(438),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18263),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(245),
    [sym_block_comment] = STATE(245),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [246] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(443),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18247),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(246),
    [sym_block_comment] = STATE(246),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [247] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(440),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18515),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(247),
    [sym_block_comment] = STATE(247),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [248] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(448),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16960),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(248),
    [sym_block_comment] = STATE(248),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [249] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(446),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18235),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(249),
    [sym_block_comment] = STATE(249),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [250] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(444),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18528),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(250),
    [sym_block_comment] = STATE(250),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [251] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(455),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18221),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(251),
    [sym_block_comment] = STATE(251),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [252] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(458),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18203),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(252),
    [sym_block_comment] = STATE(252),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [253] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(452),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18411),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(253),
    [sym_block_comment] = STATE(253),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [254] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(371),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17033),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(254),
    [sym_block_comment] = STATE(254),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [255] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17016),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(255),
    [sym_block_comment] = STATE(255),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(585),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [256] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(468),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18191),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(256),
    [sym_block_comment] = STATE(256),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [257] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(460),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18505),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(257),
    [sym_block_comment] = STATE(257),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [258] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(521),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18177),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(258),
    [sym_block_comment] = STATE(258),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [259] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(473),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18491),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(259),
    [sym_block_comment] = STATE(259),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [260] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(481),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17008),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(260),
    [sym_block_comment] = STATE(260),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [261] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(377),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16870),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(261),
    [sym_block_comment] = STATE(261),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [262] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(366),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16987),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(262),
    [sym_block_comment] = STATE(262),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [263] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(461),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17326),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(263),
    [sym_block_comment] = STATE(263),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [264] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(483),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18479),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(264),
    [sym_block_comment] = STATE(264),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [265] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(489),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18397),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(265),
    [sym_block_comment] = STATE(265),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [266] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(494),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18385),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(266),
    [sym_block_comment] = STATE(266),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [267] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(496),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18370),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(267),
    [sym_block_comment] = STATE(267),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [268] = {
    [sym_enum_definition] = STATE(14823),
    [sym_import_declaration] = STATE(14823),
    [sym_export_declaration] = STATE(14823),
    [sym_object_definition] = STATE(14823),
    [sym_class_definition] = STATE(14823),
    [sym_trait_definition] = STATE(14823),
    [sym__end_marker] = STATE(14823),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14823),
    [sym_val_declaration] = STATE(14823),
    [sym__start_val] = STATE(4250),
    [sym_var_declaration] = STATE(14823),
    [sym_var_definition] = STATE(14823),
    [sym__start_var] = STATE(4249),
    [sym_type_definition] = STATE(14823),
    [sym_function_definition] = STATE(14823),
    [sym_function_declaration] = STATE(14823),
    [sym__function_declaration] = STATE(14345),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(14823),
    [sym_given_definition] = STATE(14823),
    [sym_modifiers] = STATE(12996),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(575),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16659),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14100),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(268),
    [sym_block_comment] = STATE(268),
    [aux_sym_enum_definition_repeat1] = STATE(4349),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(587),
    [anon_sym_case] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(591),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(603),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(605),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(607),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [269] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(498),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18354),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(269),
    [sym_block_comment] = STATE(269),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [270] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(418),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17929),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(270),
    [sym_block_comment] = STATE(270),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [271] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(510),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18335),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(271),
    [sym_block_comment] = STATE(271),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [272] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(532),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18163),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(272),
    [sym_block_comment] = STATE(272),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [273] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(539),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18150),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(273),
    [sym_block_comment] = STATE(273),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [274] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(544),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18319),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(274),
    [sym_block_comment] = STATE(274),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [275] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(556),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18139),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(275),
    [sym_block_comment] = STATE(275),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [276] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(557),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18123),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(276),
    [sym_block_comment] = STATE(276),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [277] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(554),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18111),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(277),
    [sym_block_comment] = STATE(277),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [278] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(542),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17058),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(278),
    [sym_block_comment] = STATE(278),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [279] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(546),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18099),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(279),
    [sym_block_comment] = STATE(279),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [280] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(537),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18088),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(280),
    [sym_block_comment] = STATE(280),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [281] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(396),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17843),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(281),
    [sym_block_comment] = STATE(281),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [282] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(527),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18079),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(282),
    [sym_block_comment] = STATE(282),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [283] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(511),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18071),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(283),
    [sym_block_comment] = STATE(283),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [284] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(526),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18307),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(284),
    [sym_block_comment] = STATE(284),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [285] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(507),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18062),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(285),
    [sym_block_comment] = STATE(285),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [286] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(513),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18294),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(286),
    [sym_block_comment] = STATE(286),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [287] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(491),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18053),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(287),
    [sym_block_comment] = STATE(287),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [288] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(476),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18044),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(288),
    [sym_block_comment] = STATE(288),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [289] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(470),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18035),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(289),
    [sym_block_comment] = STATE(289),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [290] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(381),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17115),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(290),
    [sym_block_comment] = STATE(290),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [291] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(467),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17961),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(291),
    [sym_block_comment] = STATE(291),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [292] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(485),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18280),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(292),
    [sym_block_comment] = STATE(292),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [293] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(368),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18268),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(293),
    [sym_block_comment] = STATE(293),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [294] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(365),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18252),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(294),
    [sym_block_comment] = STATE(294),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [295] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(553),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18337),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(295),
    [sym_block_comment] = STATE(295),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [296] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(497),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16821),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(296),
    [sym_block_comment] = STATE(296),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [297] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(379),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18241),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(297),
    [sym_block_comment] = STATE(297),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [298] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17657),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(298),
    [sym_block_comment] = STATE(298),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(617),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [299] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17952),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(299),
    [sym_block_comment] = STATE(299),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(619),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [300] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18328),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(300),
    [sym_block_comment] = STATE(300),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(621),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [301] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(386),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18227),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(301),
    [sym_block_comment] = STATE(301),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [302] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(397),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18209),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(302),
    [sym_block_comment] = STATE(302),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [303] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(403),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18196),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(303),
    [sym_block_comment] = STATE(303),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [304] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(405),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18184),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(304),
    [sym_block_comment] = STATE(304),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [305] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(378),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17370),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(305),
    [sym_block_comment] = STATE(305),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [306] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(406),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17164),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(306),
    [sym_block_comment] = STATE(306),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [307] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(407),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18168),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(307),
    [sym_block_comment] = STATE(307),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [308] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(412),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18156),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(308),
    [sym_block_comment] = STATE(308),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [309] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(416),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18144),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(309),
    [sym_block_comment] = STATE(309),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [310] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(430),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16941),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(310),
    [sym_block_comment] = STATE(310),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [311] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(422),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18130),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(311),
    [sym_block_comment] = STATE(311),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [312] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(415),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17079),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(312),
    [sym_block_comment] = STATE(312),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [313] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(426),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18115),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(313),
    [sym_block_comment] = STATE(313),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [314] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(372),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18365),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(314),
    [sym_block_comment] = STATE(314),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [315] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(445),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18076),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(315),
    [sym_block_comment] = STATE(315),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [316] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(482),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17205),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(316),
    [sym_block_comment] = STATE(316),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [317] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(464),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17771),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(317),
    [sym_block_comment] = STATE(317),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [318] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(451),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18057),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(318),
    [sym_block_comment] = STATE(318),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [319] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(456),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18031),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(319),
    [sym_block_comment] = STATE(319),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [320] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(462),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18012),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(320),
    [sym_block_comment] = STATE(320),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [321] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(369),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18180),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(321),
    [sym_block_comment] = STATE(321),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [322] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(472),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17988),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(322),
    [sym_block_comment] = STATE(322),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [323] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(486),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17970),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(323),
    [sym_block_comment] = STATE(323),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [324] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(516),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16893),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(324),
    [sym_block_comment] = STATE(324),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [325] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(493),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17963),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(325),
    [sym_block_comment] = STATE(325),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [326] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(447),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16774),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(326),
    [sym_block_comment] = STATE(326),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [327] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(504),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17950),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(327),
    [sym_block_comment] = STATE(327),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [328] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(512),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17935),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(328),
    [sym_block_comment] = STATE(328),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [329] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(518),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17922),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(329),
    [sym_block_comment] = STATE(329),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [330] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(549),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17715),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(330),
    [sym_block_comment] = STATE(330),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [331] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(540),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17907),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(331),
    [sym_block_comment] = STATE(331),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [332] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(558),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17879),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(332),
    [sym_block_comment] = STATE(332),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [333] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18216),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(333),
    [sym_block_comment] = STATE(333),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(623),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [334] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(522),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17061),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(334),
    [sym_block_comment] = STATE(334),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [335] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(550),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17319),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(335),
    [sym_block_comment] = STATE(335),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [336] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(547),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16849),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(336),
    [sym_block_comment] = STATE(336),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [337] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(543),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17848),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(337),
    [sym_block_comment] = STATE(337),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [338] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(515),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17670),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(338),
    [sym_block_comment] = STATE(338),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [339] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(524),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17827),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(339),
    [sym_block_comment] = STATE(339),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [340] = {
    [sym_enum_definition] = STATE(14763),
    [sym_import_declaration] = STATE(14763),
    [sym_export_declaration] = STATE(14763),
    [sym_object_definition] = STATE(14763),
    [sym_class_definition] = STATE(14763),
    [sym_trait_definition] = STATE(14763),
    [sym__end_marker] = STATE(14763),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14763),
    [sym_val_declaration] = STATE(14763),
    [sym__start_val] = STATE(4237),
    [sym_var_declaration] = STATE(14763),
    [sym_var_definition] = STATE(14763),
    [sym__start_var] = STATE(4234),
    [sym_type_definition] = STATE(14763),
    [sym_function_definition] = STATE(14763),
    [sym_function_declaration] = STATE(14763),
    [sym__function_declaration] = STATE(14278),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14763),
    [sym_given_definition] = STATE(14763),
    [sym_modifiers] = STATE(13037),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(574),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16611),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14106),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(340),
    [sym_block_comment] = STATE(340),
    [aux_sym_enum_definition_repeat1] = STATE(4345),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(589),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(625),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(637),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(639),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(641),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(587),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [341] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(492),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16801),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(341),
    [sym_block_comment] = STATE(341),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [342] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(508),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17800),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(342),
    [sym_block_comment] = STATE(342),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [343] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(495),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17777),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(343),
    [sym_block_comment] = STATE(343),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [344] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(478),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17630),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(344),
    [sym_block_comment] = STATE(344),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [345] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(484),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17743),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(345),
    [sym_block_comment] = STATE(345),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [346] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(449),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16753),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(346),
    [sym_block_comment] = STATE(346),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [347] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(463),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17302),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(347),
    [sym_block_comment] = STATE(347),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [348] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(466),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17713),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(348),
    [sym_block_comment] = STATE(348),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [349] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(480),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17180),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(349),
    [sym_block_comment] = STATE(349),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [350] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(454),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17675),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(350),
    [sym_block_comment] = STATE(350),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [351] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(555),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17418),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(351),
    [sym_block_comment] = STATE(351),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [352] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(441),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17572),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(352),
    [sym_block_comment] = STATE(352),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [353] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(439),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17650),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(353),
    [sym_block_comment] = STATE(353),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [354] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(431),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17597),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(354),
    [sym_block_comment] = STATE(354),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [355] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(419),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16722),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(355),
    [sym_block_comment] = STATE(355),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [356] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(411),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17227),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(356),
    [sym_block_comment] = STATE(356),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [357] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(410),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17447),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(357),
    [sym_block_comment] = STATE(357),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [358] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(367),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17350),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(358),
    [sym_block_comment] = STATE(358),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [359] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(382),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16699),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(359),
    [sym_block_comment] = STATE(359),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [360] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(376),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17399),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(360),
    [sym_block_comment] = STATE(360),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [361] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(380),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17461),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(361),
    [sym_block_comment] = STATE(361),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [362] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18473),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(362),
    [sym_block_comment] = STATE(362),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(651),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [363] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(392),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17443),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(363),
    [sym_block_comment] = STATE(363),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [364] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_self_type] = STATE(400),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17493),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6246),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(364),
    [sym_block_comment] = STATE(364),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(579),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [365] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18258),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(365),
    [sym_block_comment] = STATE(365),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [366] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16973),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(366),
    [sym_block_comment] = STATE(366),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [367] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17358),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(367),
    [sym_block_comment] = STATE(367),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [368] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18273),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(368),
    [sym_block_comment] = STATE(368),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [369] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18109),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(369),
    [sym_block_comment] = STATE(369),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [370] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18372),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(370),
    [sym_block_comment] = STATE(370),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [371] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17020),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(371),
    [sym_block_comment] = STATE(371),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [372] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18359),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(372),
    [sym_block_comment] = STATE(372),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [373] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17267),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(373),
    [sym_block_comment] = STATE(373),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [374] = {
    [sym_enum_definition] = STATE(15049),
    [sym__enum_block] = STATE(17932),
    [sym_enum_case_definitions] = STATE(15049),
    [sym_import_declaration] = STATE(15049),
    [sym_export_declaration] = STATE(15049),
    [sym_object_definition] = STATE(15049),
    [sym_class_definition] = STATE(15049),
    [sym_trait_definition] = STATE(15049),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15049),
    [sym_val_declaration] = STATE(15049),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15049),
    [sym_var_definition] = STATE(15049),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15049),
    [sym_function_definition] = STATE(15049),
    [sym_function_declaration] = STATE(15049),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15049),
    [sym_given_definition] = STATE(15049),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14283),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(374),
    [sym_block_comment] = STATE(374),
    [aux_sym_enum_definition_repeat1] = STATE(4347),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(653),
    [anon_sym_case] = ACTIONS(655),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [375] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16949),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(375),
    [sym_block_comment] = STATE(375),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [376] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17404),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(376),
    [sym_block_comment] = STATE(376),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [377] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16875),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(377),
    [sym_block_comment] = STATE(377),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [378] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17363),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(378),
    [sym_block_comment] = STATE(378),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [379] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18246),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(379),
    [sym_block_comment] = STATE(379),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [380] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17454),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(380),
    [sym_block_comment] = STATE(380),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [381] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17122),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(381),
    [sym_block_comment] = STATE(381),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [382] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16691),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(382),
    [sym_block_comment] = STATE(382),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [383] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18387),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(383),
    [sym_block_comment] = STATE(383),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [384] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18340),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(384),
    [sym_block_comment] = STATE(384),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [385] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17887),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(385),
    [sym_block_comment] = STATE(385),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [386] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18233),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(386),
    [sym_block_comment] = STATE(386),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [387] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16947),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(387),
    [sym_block_comment] = STATE(387),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [388] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17473),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(388),
    [sym_block_comment] = STATE(388),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [389] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18410),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(389),
    [sym_block_comment] = STATE(389),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [390] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17480),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(390),
    [sym_block_comment] = STATE(390),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [391] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16704),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(391),
    [sym_block_comment] = STATE(391),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [392] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17457),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(392),
    [sym_block_comment] = STATE(392),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [393] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18401),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(393),
    [sym_block_comment] = STATE(393),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [394] = {
    [sym_enum_definition] = STATE(14996),
    [sym_import_declaration] = STATE(14996),
    [sym_export_declaration] = STATE(14996),
    [sym_object_definition] = STATE(14996),
    [sym_class_definition] = STATE(14996),
    [sym_trait_definition] = STATE(14996),
    [sym__end_marker] = STATE(14996),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14996),
    [sym_val_declaration] = STATE(14996),
    [sym__start_val] = STATE(4250),
    [sym_var_declaration] = STATE(14996),
    [sym_var_definition] = STATE(14996),
    [sym__start_var] = STATE(4249),
    [sym_type_definition] = STATE(14996),
    [sym_function_definition] = STATE(14996),
    [sym_function_declaration] = STATE(14996),
    [sym__function_declaration] = STATE(14345),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(14996),
    [sym_given_definition] = STATE(14996),
    [sym_modifiers] = STATE(12996),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(575),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14281),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(394),
    [sym_block_comment] = STATE(394),
    [aux_sym_enum_definition_repeat1] = STATE(4349),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(659),
    [anon_sym_case] = ACTIONS(661),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(591),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(603),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(605),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [395] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16808),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(395),
    [sym_block_comment] = STATE(395),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [396] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17821),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(396),
    [sym_block_comment] = STATE(396),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [397] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18219),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(397),
    [sym_block_comment] = STATE(397),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [398] = {
    [sym_enum_definition] = STATE(14977),
    [sym_import_declaration] = STATE(14977),
    [sym_export_declaration] = STATE(14977),
    [sym_object_definition] = STATE(14977),
    [sym_class_definition] = STATE(14977),
    [sym_trait_definition] = STATE(14977),
    [sym__end_marker] = STATE(14977),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14977),
    [sym_val_declaration] = STATE(14977),
    [sym__start_val] = STATE(4237),
    [sym_var_declaration] = STATE(14977),
    [sym_var_definition] = STATE(14977),
    [sym__start_var] = STATE(4234),
    [sym_type_definition] = STATE(14977),
    [sym_function_definition] = STATE(14977),
    [sym_function_declaration] = STATE(14977),
    [sym__function_declaration] = STATE(14278),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14977),
    [sym_given_definition] = STATE(14977),
    [sym_modifiers] = STATE(13037),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(574),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14409),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(398),
    [sym_block_comment] = STATE(398),
    [aux_sym_enum_definition_repeat1] = STATE(4345),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(661),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(625),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(637),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(639),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(665),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(659),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [399] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18322),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(399),
    [sym_block_comment] = STATE(399),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [400] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17512),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(400),
    [sym_block_comment] = STATE(400),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [401] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18402),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(401),
    [sym_block_comment] = STATE(401),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [402] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18310),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(402),
    [sym_block_comment] = STATE(402),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [403] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18201),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(403),
    [sym_block_comment] = STATE(403),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [404] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17288),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(404),
    [sym_block_comment] = STATE(404),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [405] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18189),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(405),
    [sym_block_comment] = STATE(405),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [406] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17178),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(406),
    [sym_block_comment] = STATE(406),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [407] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18174),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(407),
    [sym_block_comment] = STATE(407),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [408] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18481),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(408),
    [sym_block_comment] = STATE(408),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [409] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18297),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(409),
    [sym_block_comment] = STATE(409),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [410] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17507),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(410),
    [sym_block_comment] = STATE(410),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [411] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17220),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(411),
    [sym_block_comment] = STATE(411),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [412] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18155),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(412),
    [sym_block_comment] = STATE(412),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [413] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17549),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(413),
    [sym_block_comment] = STATE(413),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [414] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17290),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(414),
    [sym_block_comment] = STATE(414),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [415] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17072),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(415),
    [sym_block_comment] = STATE(415),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [416] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18149),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(416),
    [sym_block_comment] = STATE(416),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [417] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16925),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(417),
    [sym_block_comment] = STATE(417),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [418] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17905),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(418),
    [sym_block_comment] = STATE(418),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [419] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16717),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(419),
    [sym_block_comment] = STATE(419),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [420] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18407),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(420),
    [sym_block_comment] = STATE(420),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [421] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17526),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(421),
    [sym_block_comment] = STATE(421),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [422] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18137),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(422),
    [sym_block_comment] = STATE(422),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [423] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17533),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(423),
    [sym_block_comment] = STATE(423),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [424] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18261),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(424),
    [sym_block_comment] = STATE(424),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [425] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17427),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(425),
    [sym_block_comment] = STATE(425),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [426] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18118),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(426),
    [sym_block_comment] = STATE(426),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [427] = {
    [sym_enum_definition] = STATE(14977),
    [sym_import_declaration] = STATE(14977),
    [sym_export_declaration] = STATE(14977),
    [sym_object_definition] = STATE(14977),
    [sym_class_definition] = STATE(14977),
    [sym_trait_definition] = STATE(14977),
    [sym__end_marker] = STATE(14977),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14977),
    [sym_val_declaration] = STATE(14977),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14977),
    [sym_var_definition] = STATE(14977),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14977),
    [sym_function_definition] = STATE(14977),
    [sym_function_declaration] = STATE(14977),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14977),
    [sym_given_definition] = STATE(14977),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14409),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(427),
    [sym_block_comment] = STATE(427),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(665),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(667),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [428] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18495),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(428),
    [sym_block_comment] = STATE(428),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [429] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17425),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(429),
    [sym_block_comment] = STATE(429),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [430] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16927),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(430),
    [sym_block_comment] = STATE(430),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [431] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17601),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(431),
    [sym_block_comment] = STATE(431),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [432] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18270),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(432),
    [sym_block_comment] = STATE(432),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [433] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16777),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(433),
    [sym_block_comment] = STATE(433),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [434] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17783),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(434),
    [sym_block_comment] = STATE(434),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [435] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17781),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(435),
    [sym_block_comment] = STATE(435),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [436] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18104),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(436),
    [sym_block_comment] = STATE(436),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [437] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17194),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(437),
    [sym_block_comment] = STATE(437),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [438] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18255),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(438),
    [sym_block_comment] = STATE(438),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [439] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17653),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(439),
    [sym_block_comment] = STATE(439),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [440] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18511),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(440),
    [sym_block_comment] = STATE(440),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [441] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17560),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(441),
    [sym_block_comment] = STATE(441),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [442] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17187),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(442),
    [sym_block_comment] = STATE(442),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [443] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18244),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(443),
    [sym_block_comment] = STATE(443),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [444] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18524),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(444),
    [sym_block_comment] = STATE(444),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [445] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18084),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(445),
    [sym_block_comment] = STATE(445),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [446] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18231),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(446),
    [sym_block_comment] = STATE(446),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [447] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16779),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(447),
    [sym_block_comment] = STATE(447),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [448] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16985),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(448),
    [sym_block_comment] = STATE(448),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [449] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16725),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(449),
    [sym_block_comment] = STATE(449),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [450] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17093),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(450),
    [sym_block_comment] = STATE(450),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [451] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18065),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(451),
    [sym_block_comment] = STATE(451),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [452] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18497),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(452),
    [sym_block_comment] = STATE(452),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [453] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16993),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(453),
    [sym_block_comment] = STATE(453),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [454] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17692),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(454),
    [sym_block_comment] = STATE(454),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [455] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18213),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(455),
    [sym_block_comment] = STATE(455),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [456] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18039),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(456),
    [sym_block_comment] = STATE(456),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [457] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16903),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(457),
    [sym_block_comment] = STATE(457),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [458] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18198),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(458),
    [sym_block_comment] = STATE(458),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [459] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17584),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(459),
    [sym_block_comment] = STATE(459),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [460] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18508),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(460),
    [sym_block_comment] = STATE(460),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [461] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17314),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(461),
    [sym_block_comment] = STATE(461),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [462] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18020),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(462),
    [sym_block_comment] = STATE(462),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [463] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17309),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(463),
    [sym_block_comment] = STATE(463),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [464] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17755),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(464),
    [sym_block_comment] = STATE(464),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [465] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17586),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(465),
    [sym_block_comment] = STATE(465),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [466] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17719),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(466),
    [sym_block_comment] = STATE(466),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [467] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18023),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(467),
    [sym_block_comment] = STATE(467),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [468] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18186),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(468),
    [sym_block_comment] = STATE(468),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [469] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17382),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(469),
    [sym_block_comment] = STATE(469),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [470] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18032),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(470),
    [sym_block_comment] = STATE(470),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [471] = {
    [sym_enum_definition] = STATE(15049),
    [sym__enum_block] = STATE(18286),
    [sym_enum_case_definitions] = STATE(15049),
    [sym_import_declaration] = STATE(15049),
    [sym_export_declaration] = STATE(15049),
    [sym_object_definition] = STATE(15049),
    [sym_class_definition] = STATE(15049),
    [sym_trait_definition] = STATE(15049),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15049),
    [sym_val_declaration] = STATE(15049),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15049),
    [sym_var_definition] = STATE(15049),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15049),
    [sym_function_definition] = STATE(15049),
    [sym_function_declaration] = STATE(15049),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15049),
    [sym_given_definition] = STATE(15049),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14283),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(471),
    [sym_block_comment] = STATE(471),
    [aux_sym_enum_definition_repeat1] = STATE(4347),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(669),
    [anon_sym_case] = ACTIONS(655),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [472] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17995),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(472),
    [sym_block_comment] = STATE(472),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [473] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18493),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(473),
    [sym_block_comment] = STATE(473),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [474] = {
    [sym_enum_definition] = STATE(14977),
    [sym_import_declaration] = STATE(14977),
    [sym_export_declaration] = STATE(14977),
    [sym_object_definition] = STATE(14977),
    [sym_class_definition] = STATE(14977),
    [sym_trait_definition] = STATE(14977),
    [sym__end_marker] = STATE(14977),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14977),
    [sym_val_declaration] = STATE(14977),
    [sym__start_val] = STATE(4237),
    [sym_var_declaration] = STATE(14977),
    [sym_var_definition] = STATE(14977),
    [sym__start_var] = STATE(4234),
    [sym_type_definition] = STATE(14977),
    [sym_function_definition] = STATE(14977),
    [sym_function_declaration] = STATE(14977),
    [sym__function_declaration] = STATE(14278),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14977),
    [sym_given_definition] = STATE(14977),
    [sym_modifiers] = STATE(13037),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(574),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14409),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(474),
    [sym_block_comment] = STATE(474),
    [aux_sym_enum_definition_repeat1] = STATE(4345),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(671),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(625),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(637),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(639),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(665),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(667),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [475] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16759),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(475),
    [sym_block_comment] = STATE(475),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [476] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18041),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(476),
    [sym_block_comment] = STATE(476),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [477] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17243),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(477),
    [sym_block_comment] = STATE(477),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [478] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17618),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(478),
    [sym_block_comment] = STATE(478),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [479] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16762),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(479),
    [sym_block_comment] = STATE(479),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [480] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17166),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(480),
    [sym_block_comment] = STATE(480),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [481] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17015),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(481),
    [sym_block_comment] = STATE(481),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [482] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17225),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(482),
    [sym_block_comment] = STATE(482),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [483] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18483),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(483),
    [sym_block_comment] = STATE(483),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [484] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17757),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(484),
    [sym_block_comment] = STATE(484),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [485] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18285),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(485),
    [sym_block_comment] = STATE(485),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [486] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17972),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(486),
    [sym_block_comment] = STATE(486),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [487] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16901),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(487),
    [sym_block_comment] = STATE(487),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [488] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17384),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(488),
    [sym_block_comment] = STATE(488),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [489] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18406),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(489),
    [sym_block_comment] = STATE(489),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [490] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17340),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(490),
    [sym_block_comment] = STATE(490),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [491] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18050),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(491),
    [sym_block_comment] = STATE(491),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [492] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16786),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(492),
    [sym_block_comment] = STATE(492),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [493] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17965),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(493),
    [sym_block_comment] = STATE(493),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [494] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18390),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(494),
    [sym_block_comment] = STATE(494),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [495] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17789),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(495),
    [sym_block_comment] = STATE(495),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [496] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18376),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(496),
    [sym_block_comment] = STATE(496),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [497] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16827),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(497),
    [sym_block_comment] = STATE(497),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [498] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18362),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(498),
    [sym_block_comment] = STATE(498),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [499] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17856),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(499),
    [sym_block_comment] = STATE(499),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [500] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17725),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(500),
    [sym_block_comment] = STATE(500),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [501] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17638),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(501),
    [sym_block_comment] = STATE(501),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [502] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17640),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(502),
    [sym_block_comment] = STATE(502),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [503] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17095),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(503),
    [sym_block_comment] = STATE(503),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [504] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17958),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(504),
    [sym_block_comment] = STATE(504),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [505] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17241),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(505),
    [sym_block_comment] = STATE(505),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [506] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17854),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(506),
    [sym_block_comment] = STATE(506),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [507] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18058),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(507),
    [sym_block_comment] = STATE(507),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [508] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17807),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(508),
    [sym_block_comment] = STATE(508),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [509] = {
    [sym_enum_definition] = STATE(14996),
    [sym_import_declaration] = STATE(14996),
    [sym_export_declaration] = STATE(14996),
    [sym_object_definition] = STATE(14996),
    [sym_class_definition] = STATE(14996),
    [sym_trait_definition] = STATE(14996),
    [sym__end_marker] = STATE(14996),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14996),
    [sym_val_declaration] = STATE(14996),
    [sym__start_val] = STATE(4250),
    [sym_var_declaration] = STATE(14996),
    [sym_var_definition] = STATE(14996),
    [sym__start_var] = STATE(4249),
    [sym_type_definition] = STATE(14996),
    [sym_function_definition] = STATE(14996),
    [sym_function_declaration] = STATE(14996),
    [sym__function_declaration] = STATE(14345),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(14996),
    [sym_given_definition] = STATE(14996),
    [sym_modifiers] = STATE(12996),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(575),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14281),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(509),
    [sym_block_comment] = STATE(509),
    [aux_sym_enum_definition_repeat1] = STATE(4349),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_case] = ACTIONS(671),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(591),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(603),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(605),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [510] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18344),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(510),
    [sym_block_comment] = STATE(510),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [511] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18067),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(511),
    [sym_block_comment] = STATE(511),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [512] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17939),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(512),
    [sym_block_comment] = STATE(512),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [513] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18299),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(513),
    [sym_block_comment] = STATE(513),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [514] = {
    [sym_enum_definition] = STATE(14996),
    [sym_import_declaration] = STATE(14996),
    [sym_export_declaration] = STATE(14996),
    [sym_object_definition] = STATE(14996),
    [sym_class_definition] = STATE(14996),
    [sym_trait_definition] = STATE(14996),
    [sym__end_marker] = STATE(14996),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14996),
    [sym_val_declaration] = STATE(14996),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(14996),
    [sym_var_definition] = STATE(14996),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(14996),
    [sym_function_definition] = STATE(14996),
    [sym_function_declaration] = STATE(14996),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(14996),
    [sym_given_definition] = STATE(14996),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14281),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(514),
    [sym_block_comment] = STATE(514),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(659),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [515] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17661),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(515),
    [sym_block_comment] = STATE(515),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [516] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16881),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(516),
    [sym_block_comment] = STATE(516),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [517] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16807),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(517),
    [sym_block_comment] = STATE(517),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [518] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17925),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(518),
    [sym_block_comment] = STATE(518),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [519] = {
    [sym_enum_definition] = STATE(14977),
    [sym_import_declaration] = STATE(14977),
    [sym_export_declaration] = STATE(14977),
    [sym_object_definition] = STATE(14977),
    [sym_class_definition] = STATE(14977),
    [sym_trait_definition] = STATE(14977),
    [sym__end_marker] = STATE(14977),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14977),
    [sym_val_declaration] = STATE(14977),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14977),
    [sym_var_definition] = STATE(14977),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14977),
    [sym_function_definition] = STATE(14977),
    [sym_function_declaration] = STATE(14977),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14977),
    [sym_given_definition] = STATE(14977),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14409),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(519),
    [sym_block_comment] = STATE(519),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(665),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(659),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [520] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16749),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(520),
    [sym_block_comment] = STATE(520),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [521] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18172),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(521),
    [sym_block_comment] = STATE(521),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [522] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17119),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(522),
    [sym_block_comment] = STATE(522),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [523] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17723),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(523),
    [sym_block_comment] = STATE(523),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [524] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17835),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(524),
    [sym_block_comment] = STATE(524),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [525] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17142),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(525),
    [sym_block_comment] = STATE(525),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [526] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18312),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(526),
    [sym_block_comment] = STATE(526),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [527] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18077),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(527),
    [sym_block_comment] = STATE(527),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [528] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16995),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(528),
    [sym_block_comment] = STATE(528),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [529] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16809),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(529),
    [sym_block_comment] = STATE(529),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [530] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17140),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(530),
    [sym_block_comment] = STATE(530),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [531] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17953),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(531),
    [sym_block_comment] = STATE(531),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [532] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18159),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(532),
    [sym_block_comment] = STATE(532),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [533] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17679),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(533),
    [sym_block_comment] = STATE(533),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [534] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17947),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(534),
    [sym_block_comment] = STATE(534),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [535] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17039),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(535),
    [sym_block_comment] = STATE(535),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [536] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16857),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(536),
    [sym_block_comment] = STATE(536),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [537] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18085),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(537),
    [sym_block_comment] = STATE(537),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [538] = {
    [sym_enum_definition] = STATE(14996),
    [sym_import_declaration] = STATE(14996),
    [sym_export_declaration] = STATE(14996),
    [sym_object_definition] = STATE(14996),
    [sym_class_definition] = STATE(14996),
    [sym_trait_definition] = STATE(14996),
    [sym__end_marker] = STATE(14996),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14996),
    [sym_val_declaration] = STATE(14996),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(14996),
    [sym_var_definition] = STATE(14996),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(14996),
    [sym_function_definition] = STATE(14996),
    [sym_function_declaration] = STATE(14996),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(14996),
    [sym_given_definition] = STATE(14996),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14281),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(538),
    [sym_block_comment] = STATE(538),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(667),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [539] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18147),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(539),
    [sym_block_comment] = STATE(539),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [540] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17911),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(540),
    [sym_block_comment] = STATE(540),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [541] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17681),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(541),
    [sym_block_comment] = STATE(541),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [542] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17073),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(542),
    [sym_block_comment] = STATE(542),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [543] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17865),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(543),
    [sym_block_comment] = STATE(543),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [544] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18324),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(544),
    [sym_block_comment] = STATE(544),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [545] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17949),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(545),
    [sym_block_comment] = STATE(545),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [546] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18095),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(546),
    [sym_block_comment] = STATE(546),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [547] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16834),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(547),
    [sym_block_comment] = STATE(547),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [548] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(16855),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(548),
    [sym_block_comment] = STATE(548),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [549] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17703),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(549),
    [sym_block_comment] = STATE(549),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [550] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17270),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(550),
    [sym_block_comment] = STATE(550),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [551] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17042),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(551),
    [sym_block_comment] = STATE(551),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [552] = {
    [sym_enum_definition] = STATE(15109),
    [sym_import_declaration] = STATE(15109),
    [sym_export_declaration] = STATE(15109),
    [sym_object_definition] = STATE(15109),
    [sym_class_definition] = STATE(15109),
    [sym_trait_definition] = STATE(15109),
    [sym__end_marker] = STATE(15109),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15109),
    [sym_val_declaration] = STATE(15109),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15109),
    [sym_var_definition] = STATE(15109),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15109),
    [sym_function_definition] = STATE(15109),
    [sym_function_declaration] = STATE(15109),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15109),
    [sym_given_definition] = STATE(15109),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17334),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14354),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(552),
    [sym_block_comment] = STATE(552),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [553] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18222),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(553),
    [sym_block_comment] = STATE(553),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [554] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18106),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(554),
    [sym_block_comment] = STATE(554),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [555] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17406),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(555),
    [sym_block_comment] = STATE(555),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [556] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18135),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(556),
    [sym_block_comment] = STATE(556),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [557] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(18119),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(557),
    [sym_block_comment] = STATE(557),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [558] = {
    [sym_enum_definition] = STATE(14855),
    [sym_import_declaration] = STATE(14855),
    [sym_export_declaration] = STATE(14855),
    [sym_object_definition] = STATE(14855),
    [sym_class_definition] = STATE(14855),
    [sym_trait_definition] = STATE(14855),
    [sym__end_marker] = STATE(14855),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14855),
    [sym_val_declaration] = STATE(14855),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14855),
    [sym_var_definition] = STATE(14855),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14855),
    [sym_function_definition] = STATE(14855),
    [sym_function_declaration] = STATE(14855),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14855),
    [sym_given_definition] = STATE(14855),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym__block] = STATE(17892),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14351),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(558),
    [sym_block_comment] = STATE(558),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(545),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [559] = {
    [sym_enum_definition] = STATE(15599),
    [sym_enum_case_definitions] = STATE(15599),
    [sym_import_declaration] = STATE(15599),
    [sym_export_declaration] = STATE(15599),
    [sym_object_definition] = STATE(15599),
    [sym_class_definition] = STATE(15599),
    [sym_trait_definition] = STATE(15599),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15599),
    [sym_val_declaration] = STATE(15599),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15599),
    [sym_var_definition] = STATE(15599),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15599),
    [sym_function_definition] = STATE(15599),
    [sym_function_declaration] = STATE(15599),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15599),
    [sym_given_definition] = STATE(15599),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14569),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(559),
    [sym_block_comment] = STATE(559),
    [aux_sym_enum_definition_repeat1] = STATE(4347),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(673),
    [anon_sym_case] = ACTIONS(655),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [560] = {
    [sym_enum_definition] = STATE(15719),
    [sym_enum_case_definitions] = STATE(15719),
    [sym_import_declaration] = STATE(15719),
    [sym_export_declaration] = STATE(15719),
    [sym_object_definition] = STATE(15719),
    [sym_class_definition] = STATE(15719),
    [sym_trait_definition] = STATE(15719),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15719),
    [sym_val_declaration] = STATE(15719),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(15719),
    [sym_var_definition] = STATE(15719),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(15719),
    [sym_function_definition] = STATE(15719),
    [sym_function_declaration] = STATE(15719),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(15719),
    [sym_given_definition] = STATE(15719),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14559),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(560),
    [sym_block_comment] = STATE(560),
    [aux_sym_enum_definition_repeat1] = STATE(4344),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(675),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(679),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [561] = {
    [sym_enum_definition] = STATE(14996),
    [sym_import_declaration] = STATE(14996),
    [sym_export_declaration] = STATE(14996),
    [sym_object_definition] = STATE(14996),
    [sym_class_definition] = STATE(14996),
    [sym_trait_definition] = STATE(14996),
    [sym__end_marker] = STATE(14996),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14996),
    [sym_val_declaration] = STATE(14996),
    [sym__start_val] = STATE(4250),
    [sym_var_declaration] = STATE(14996),
    [sym_var_definition] = STATE(14996),
    [sym__start_var] = STATE(4249),
    [sym_type_definition] = STATE(14996),
    [sym_function_definition] = STATE(14996),
    [sym_function_declaration] = STATE(14996),
    [sym__function_declaration] = STATE(14345),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(14996),
    [sym_given_definition] = STATE(14996),
    [sym_modifiers] = STATE(12996),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(575),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14281),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(561),
    [sym_block_comment] = STATE(561),
    [aux_sym_enum_definition_repeat1] = STATE(4349),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(591),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(603),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(605),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [562] = {
    [sym_enum_definition] = STATE(14977),
    [sym_import_declaration] = STATE(14977),
    [sym_export_declaration] = STATE(14977),
    [sym_object_definition] = STATE(14977),
    [sym_class_definition] = STATE(14977),
    [sym_trait_definition] = STATE(14977),
    [sym__end_marker] = STATE(14977),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14977),
    [sym_val_declaration] = STATE(14977),
    [sym__start_val] = STATE(4237),
    [sym_var_declaration] = STATE(14977),
    [sym_var_definition] = STATE(14977),
    [sym__start_var] = STATE(4234),
    [sym_type_definition] = STATE(14977),
    [sym_function_definition] = STATE(14977),
    [sym_function_declaration] = STATE(14977),
    [sym__function_declaration] = STATE(14278),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14977),
    [sym_given_definition] = STATE(14977),
    [sym_modifiers] = STATE(13037),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(574),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14409),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(562),
    [sym_block_comment] = STATE(562),
    [aux_sym_enum_definition_repeat1] = STATE(4345),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(625),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(637),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(639),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(665),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [563] = {
    [sym_enum_definition] = STATE(14977),
    [sym_import_declaration] = STATE(14977),
    [sym_export_declaration] = STATE(14977),
    [sym_object_definition] = STATE(14977),
    [sym_class_definition] = STATE(14977),
    [sym_trait_definition] = STATE(14977),
    [sym__end_marker] = STATE(14977),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14977),
    [sym_val_declaration] = STATE(14977),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14977),
    [sym_var_definition] = STATE(14977),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14977),
    [sym_function_definition] = STATE(14977),
    [sym_function_declaration] = STATE(14977),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14977),
    [sym_given_definition] = STATE(14977),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14409),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(563),
    [sym_block_comment] = STATE(563),
    [aux_sym_enum_definition_repeat1] = STATE(4343),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(573),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(513),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(665),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [564] = {
    [sym_enum_definition] = STATE(14936),
    [sym__enum_block] = STATE(18229),
    [sym_enum_case_definitions] = STATE(14936),
    [sym_import_declaration] = STATE(14936),
    [sym_export_declaration] = STATE(14936),
    [sym_object_definition] = STATE(14936),
    [sym_class_definition] = STATE(14936),
    [sym_trait_definition] = STATE(14936),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14936),
    [sym_val_declaration] = STATE(14936),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14936),
    [sym_var_definition] = STATE(14936),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14936),
    [sym_function_definition] = STATE(14936),
    [sym_function_declaration] = STATE(14936),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14936),
    [sym_given_definition] = STATE(14936),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14407),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(564),
    [sym_block_comment] = STATE(564),
    [aux_sym_enum_definition_repeat1] = STATE(4344),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(675),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [565] = {
    [sym_enum_definition] = STATE(15719),
    [sym_enum_case_definitions] = STATE(15719),
    [sym_import_declaration] = STATE(15719),
    [sym_export_declaration] = STATE(15719),
    [sym_object_definition] = STATE(15719),
    [sym_class_definition] = STATE(15719),
    [sym_trait_definition] = STATE(15719),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15719),
    [sym_val_declaration] = STATE(15719),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(15719),
    [sym_var_definition] = STATE(15719),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(15719),
    [sym_function_definition] = STATE(15719),
    [sym_function_declaration] = STATE(15719),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(15719),
    [sym_given_definition] = STATE(15719),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14559),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(565),
    [sym_block_comment] = STATE(565),
    [aux_sym_enum_definition_repeat1] = STATE(4344),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(675),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__outdent] = ACTIONS(673),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [566] = {
    [sym_enum_definition] = STATE(14996),
    [sym_import_declaration] = STATE(14996),
    [sym_export_declaration] = STATE(14996),
    [sym_object_definition] = STATE(14996),
    [sym_class_definition] = STATE(14996),
    [sym_trait_definition] = STATE(14996),
    [sym__end_marker] = STATE(14996),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14996),
    [sym_val_declaration] = STATE(14996),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(14996),
    [sym_var_definition] = STATE(14996),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(14996),
    [sym_function_definition] = STATE(14996),
    [sym_function_declaration] = STATE(14996),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(14996),
    [sym_given_definition] = STATE(14996),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14281),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(566),
    [sym_block_comment] = STATE(566),
    [aux_sym_enum_definition_repeat1] = STATE(4352),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(15),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [567] = {
    [sym_enum_definition] = STATE(15599),
    [sym_enum_case_definitions] = STATE(15599),
    [sym_import_declaration] = STATE(15599),
    [sym_export_declaration] = STATE(15599),
    [sym_object_definition] = STATE(15599),
    [sym_class_definition] = STATE(15599),
    [sym_trait_definition] = STATE(15599),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15599),
    [sym_val_declaration] = STATE(15599),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15599),
    [sym_var_definition] = STATE(15599),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15599),
    [sym_function_definition] = STATE(15599),
    [sym_function_declaration] = STATE(15599),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15599),
    [sym_given_definition] = STATE(15599),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14569),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(567),
    [sym_block_comment] = STATE(567),
    [aux_sym_enum_definition_repeat1] = STATE(4347),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(679),
    [anon_sym_case] = ACTIONS(655),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [568] = {
    [sym_enum_definition] = STATE(14936),
    [sym__enum_block] = STATE(17908),
    [sym_enum_case_definitions] = STATE(14936),
    [sym_import_declaration] = STATE(14936),
    [sym_export_declaration] = STATE(14936),
    [sym_object_definition] = STATE(14936),
    [sym_class_definition] = STATE(14936),
    [sym_trait_definition] = STATE(14936),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(14936),
    [sym_val_declaration] = STATE(14936),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(14936),
    [sym_var_definition] = STATE(14936),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(14936),
    [sym_function_definition] = STATE(14936),
    [sym_function_declaration] = STATE(14936),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(14936),
    [sym_given_definition] = STATE(14936),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14407),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(568),
    [sym_block_comment] = STATE(568),
    [aux_sym_enum_definition_repeat1] = STATE(4344),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(675),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [569] = {
    [sym_enum_definition] = STATE(15719),
    [sym_enum_case_definitions] = STATE(15719),
    [sym_import_declaration] = STATE(15719),
    [sym_export_declaration] = STATE(15719),
    [sym_object_definition] = STATE(15719),
    [sym_class_definition] = STATE(15719),
    [sym_trait_definition] = STATE(15719),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15719),
    [sym_val_declaration] = STATE(15719),
    [sym__start_val] = STATE(4214),
    [sym_var_declaration] = STATE(15719),
    [sym_var_definition] = STATE(15719),
    [sym__start_var] = STATE(4217),
    [sym_type_definition] = STATE(15719),
    [sym_function_definition] = STATE(15719),
    [sym_function_declaration] = STATE(15719),
    [sym__function_declaration] = STATE(14467),
    [sym_opaque_modifier] = STATE(17981),
    [sym_extension_definition] = STATE(15719),
    [sym_given_definition] = STATE(15719),
    [sym_modifiers] = STATE(13234),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(578),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14559),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(569),
    [sym_block_comment] = STATE(569),
    [aux_sym_enum_definition_repeat1] = STATE(4344),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_enum] = ACTIONS(491),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(675),
    [anon_sym_object] = ACTIONS(497),
    [anon_sym_import] = ACTIONS(499),
    [anon_sym_export] = ACTIONS(501),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_given] = ACTIONS(505),
    [anon_sym_class] = ACTIONS(507),
    [anon_sym_trait] = ACTIONS(509),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_extension] = ACTIONS(525),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(527),
    [anon_sym_def] = ACTIONS(529),
    [anon_sym_opaque] = ACTIONS(531),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(533),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(537),
    [anon_sym_open] = ACTIONS(539),
    [anon_sym_transparent] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [570] = {
    [sym_enum_definition] = STATE(15599),
    [sym_enum_case_definitions] = STATE(15599),
    [sym_import_declaration] = STATE(15599),
    [sym_export_declaration] = STATE(15599),
    [sym_object_definition] = STATE(15599),
    [sym_class_definition] = STATE(15599),
    [sym_trait_definition] = STATE(15599),
    [sym_annotation] = STATE(8122),
    [sym_val_definition] = STATE(15599),
    [sym_val_declaration] = STATE(15599),
    [sym__start_val] = STATE(4262),
    [sym_var_declaration] = STATE(15599),
    [sym_var_definition] = STATE(15599),
    [sym__start_var] = STATE(4258),
    [sym_type_definition] = STATE(15599),
    [sym_function_definition] = STATE(15599),
    [sym_function_declaration] = STATE(15599),
    [sym__function_declaration] = STATE(14465),
    [sym_opaque_modifier] = STATE(17973),
    [sym_extension_definition] = STATE(15599),
    [sym_given_definition] = STATE(15599),
    [sym_modifiers] = STATE(13227),
    [sym_access_modifier] = STATE(6735),
    [sym_inline_modifier] = STATE(576),
    [sym_infix_modifier] = STATE(6735),
    [sym_open_modifier] = STATE(6735),
    [sym_transparent_modifier] = STATE(6735),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(14569),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(570),
    [sym_block_comment] = STATE(570),
    [aux_sym_enum_definition_repeat1] = STATE(4347),
    [aux_sym_modifiers_repeat1] = STATE(5152),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_enum] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_case] = ACTIONS(655),
    [anon_sym_object] = ACTIONS(19),
    [anon_sym_import] = ACTIONS(21),
    [anon_sym_export] = ACTIONS(23),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_given] = ACTIONS(113),
    [anon_sym_class] = ACTIONS(29),
    [anon_sym_trait] = ACTIONS(31),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_extension] = ACTIONS(129),
    [anon_sym_val] = ACTIONS(49),
    [anon_sym_AT] = ACTIONS(51),
    [anon_sym_var] = ACTIONS(53),
    [anon_sym_type] = ACTIONS(131),
    [anon_sym_def] = ACTIONS(133),
    [anon_sym_opaque] = ACTIONS(135),
    [anon_sym_abstract] = ACTIONS(61),
    [anon_sym_final] = ACTIONS(61),
    [anon_sym_sealed] = ACTIONS(61),
    [anon_sym_implicit] = ACTIONS(137),
    [anon_sym_lazy] = ACTIONS(61),
    [anon_sym_override] = ACTIONS(61),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(141),
    [anon_sym_open] = ACTIONS(143),
    [anon_sym_transparent] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [571] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14410),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(571),
    [sym_block_comment] = STATE(571),
    [sym__alpha_identifier] = ACTIONS(681),
    [anon_sym_enum] = ACTIONS(684),
    [anon_sym_LBRACE] = ACTIONS(686),
    [anon_sym_case] = ACTIONS(684),
    [anon_sym_object] = ACTIONS(684),
    [anon_sym_import] = ACTIONS(684),
    [anon_sym_export] = ACTIONS(684),
    [anon_sym__] = ACTIONS(689),
    [anon_sym_given] = ACTIONS(684),
    [anon_sym_class] = ACTIONS(684),
    [anon_sym_trait] = ACTIONS(684),
    [anon_sym_PLUS] = ACTIONS(692),
    [anon_sym_DASH] = ACTIONS(692),
    [anon_sym_end] = ACTIONS(695),
    [anon_sym_if] = ACTIONS(698),
    [anon_sym_while] = ACTIONS(701),
    [anon_sym_for] = ACTIONS(704),
    [anon_sym_try] = ACTIONS(707),
    [anon_sym_new] = ACTIONS(710),
    [anon_sym_extension] = ACTIONS(684),
    [anon_sym_val] = ACTIONS(684),
    [anon_sym_AT] = ACTIONS(684),
    [anon_sym_var] = ACTIONS(684),
    [anon_sym_type] = ACTIONS(684),
    [anon_sym_def] = ACTIONS(684),
    [anon_sym_opaque] = ACTIONS(695),
    [anon_sym_abstract] = ACTIONS(684),
    [anon_sym_final] = ACTIONS(684),
    [anon_sym_sealed] = ACTIONS(684),
    [anon_sym_implicit] = ACTIONS(713),
    [anon_sym_lazy] = ACTIONS(684),
    [anon_sym_override] = ACTIONS(684),
    [anon_sym_private] = ACTIONS(684),
    [anon_sym_protected] = ACTIONS(684),
    [anon_sym_inline] = ACTIONS(716),
    [anon_sym_infix] = ACTIONS(695),
    [anon_sym_open] = ACTIONS(695),
    [anon_sym_transparent] = ACTIONS(695),
    [anon_sym_LPAREN] = ACTIONS(719),
    [anon_sym_SEMI] = ACTIONS(722),
    [anon_sym_macro] = ACTIONS(724),
    [anon_sym_BANG] = ACTIONS(692),
    [anon_sym_TILDE] = ACTIONS(692),
    [anon_sym_DOLLAR] = ACTIONS(727),
    [anon_sym_SQUOTE] = ACTIONS(730),
    [sym__backquoted_id] = ACTIONS(733),
    [sym_operator_identifier] = ACTIONS(736),
    [sym_integer_literal] = ACTIONS(739),
    [sym_floating_point_literal] = ACTIONS(742),
    [anon_sym_true] = ACTIONS(745),
    [anon_sym_false] = ACTIONS(745),
    [sym_character_literal] = ACTIONS(742),
    [sym_null_literal] = ACTIONS(748),
    [anon_sym_return] = ACTIONS(751),
    [anon_sym_throw] = ACTIONS(754),
    [anon_sym_do] = ACTIONS(757),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__outdent] = ACTIONS(722),
    [sym__simple_multiline_string] = ACTIONS(762),
    [sym__simple_string] = ACTIONS(762),
  },
  [572] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14410),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(572),
    [sym_block_comment] = STATE(572),
    [sym__alpha_identifier] = ACTIONS(681),
    [anon_sym_enum] = ACTIONS(684),
    [anon_sym_LBRACE] = ACTIONS(686),
    [anon_sym_case] = ACTIONS(684),
    [anon_sym_object] = ACTIONS(684),
    [anon_sym_import] = ACTIONS(684),
    [anon_sym_export] = ACTIONS(684),
    [anon_sym__] = ACTIONS(689),
    [anon_sym_given] = ACTIONS(684),
    [anon_sym_class] = ACTIONS(684),
    [anon_sym_trait] = ACTIONS(684),
    [anon_sym_PLUS] = ACTIONS(692),
    [anon_sym_DASH] = ACTIONS(692),
    [anon_sym_end] = ACTIONS(695),
    [anon_sym_if] = ACTIONS(698),
    [anon_sym_while] = ACTIONS(701),
    [anon_sym_for] = ACTIONS(704),
    [anon_sym_try] = ACTIONS(707),
    [anon_sym_new] = ACTIONS(710),
    [anon_sym_extension] = ACTIONS(684),
    [anon_sym_val] = ACTIONS(684),
    [anon_sym_AT] = ACTIONS(684),
    [anon_sym_var] = ACTIONS(684),
    [anon_sym_type] = ACTIONS(684),
    [anon_sym_def] = ACTIONS(684),
    [anon_sym_opaque] = ACTIONS(695),
    [anon_sym_abstract] = ACTIONS(684),
    [anon_sym_final] = ACTIONS(684),
    [anon_sym_sealed] = ACTIONS(684),
    [anon_sym_implicit] = ACTIONS(713),
    [anon_sym_lazy] = ACTIONS(684),
    [anon_sym_override] = ACTIONS(684),
    [anon_sym_private] = ACTIONS(684),
    [anon_sym_protected] = ACTIONS(684),
    [anon_sym_inline] = ACTIONS(716),
    [anon_sym_infix] = ACTIONS(695),
    [anon_sym_open] = ACTIONS(695),
    [anon_sym_transparent] = ACTIONS(695),
    [anon_sym_LPAREN] = ACTIONS(719),
    [anon_sym_SEMI] = ACTIONS(722),
    [anon_sym_macro] = ACTIONS(724),
    [anon_sym_BANG] = ACTIONS(692),
    [anon_sym_TILDE] = ACTIONS(692),
    [anon_sym_DOLLAR] = ACTIONS(727),
    [anon_sym_SQUOTE] = ACTIONS(730),
    [sym__backquoted_id] = ACTIONS(733),
    [sym_operator_identifier] = ACTIONS(736),
    [sym_integer_literal] = ACTIONS(739),
    [sym_floating_point_literal] = ACTIONS(742),
    [anon_sym_true] = ACTIONS(745),
    [anon_sym_false] = ACTIONS(745),
    [sym_character_literal] = ACTIONS(742),
    [sym_null_literal] = ACTIONS(748),
    [anon_sym_return] = ACTIONS(751),
    [anon_sym_throw] = ACTIONS(754),
    [anon_sym_do] = ACTIONS(757),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(762),
    [sym__simple_string] = ACTIONS(762),
  },
  [573] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(13048),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(573),
    [sym_block_comment] = STATE(573),
    [sym__alpha_identifier] = ACTIONS(765),
    [anon_sym_enum] = ACTIONS(684),
    [anon_sym_LBRACE] = ACTIONS(768),
    [anon_sym_case] = ACTIONS(684),
    [anon_sym_object] = ACTIONS(684),
    [anon_sym_import] = ACTIONS(684),
    [anon_sym_export] = ACTIONS(684),
    [anon_sym__] = ACTIONS(771),
    [anon_sym_given] = ACTIONS(684),
    [anon_sym_class] = ACTIONS(684),
    [anon_sym_trait] = ACTIONS(684),
    [anon_sym_PLUS] = ACTIONS(774),
    [anon_sym_DASH] = ACTIONS(774),
    [anon_sym_end] = ACTIONS(777),
    [anon_sym_if] = ACTIONS(780),
    [anon_sym_while] = ACTIONS(783),
    [anon_sym_for] = ACTIONS(786),
    [anon_sym_try] = ACTIONS(789),
    [anon_sym_new] = ACTIONS(792),
    [anon_sym_extension] = ACTIONS(684),
    [anon_sym_val] = ACTIONS(684),
    [anon_sym_AT] = ACTIONS(684),
    [anon_sym_var] = ACTIONS(684),
    [anon_sym_type] = ACTIONS(684),
    [anon_sym_def] = ACTIONS(684),
    [anon_sym_opaque] = ACTIONS(777),
    [anon_sym_abstract] = ACTIONS(684),
    [anon_sym_final] = ACTIONS(684),
    [anon_sym_sealed] = ACTIONS(684),
    [anon_sym_implicit] = ACTIONS(795),
    [anon_sym_lazy] = ACTIONS(684),
    [anon_sym_override] = ACTIONS(684),
    [anon_sym_private] = ACTIONS(684),
    [anon_sym_protected] = ACTIONS(684),
    [anon_sym_inline] = ACTIONS(798),
    [anon_sym_infix] = ACTIONS(777),
    [anon_sym_open] = ACTIONS(777),
    [anon_sym_transparent] = ACTIONS(777),
    [anon_sym_LPAREN] = ACTIONS(801),
    [anon_sym_SEMI] = ACTIONS(722),
    [anon_sym_macro] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(774),
    [anon_sym_TILDE] = ACTIONS(774),
    [anon_sym_DOLLAR] = ACTIONS(807),
    [anon_sym_SQUOTE] = ACTIONS(810),
    [sym__backquoted_id] = ACTIONS(813),
    [sym_operator_identifier] = ACTIONS(816),
    [sym_integer_literal] = ACTIONS(819),
    [sym_floating_point_literal] = ACTIONS(822),
    [anon_sym_true] = ACTIONS(825),
    [anon_sym_false] = ACTIONS(825),
    [sym_character_literal] = ACTIONS(822),
    [sym_null_literal] = ACTIONS(828),
    [anon_sym_return] = ACTIONS(831),
    [anon_sym_throw] = ACTIONS(834),
    [anon_sym_do] = ACTIONS(837),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(840),
    [sym__simple_multiline_string] = ACTIONS(843),
    [sym__simple_string] = ACTIONS(843),
  },
  [574] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16131),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(574),
    [sym_block_comment] = STATE(574),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym_case] = ACTIONS(850),
    [anon_sym_object] = ACTIONS(850),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_given] = ACTIONS(850),
    [anon_sym_class] = ACTIONS(850),
    [anon_sym_trait] = ACTIONS(850),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(858),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_val] = ACTIONS(850),
    [anon_sym_var] = ACTIONS(850),
    [anon_sym_type] = ACTIONS(850),
    [anon_sym_def] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(850),
    [anon_sym_abstract] = ACTIONS(850),
    [anon_sym_final] = ACTIONS(850),
    [anon_sym_sealed] = ACTIONS(850),
    [anon_sym_implicit] = ACTIONS(850),
    [anon_sym_lazy] = ACTIONS(850),
    [anon_sym_override] = ACTIONS(850),
    [anon_sym_private] = ACTIONS(850),
    [anon_sym_protected] = ACTIONS(850),
    [anon_sym_inline] = ACTIONS(850),
    [anon_sym_infix] = ACTIONS(850),
    [anon_sym_open] = ACTIONS(850),
    [anon_sym_transparent] = ACTIONS(850),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [575] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15227),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(575),
    [sym_block_comment] = STATE(575),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym_case] = ACTIONS(850),
    [anon_sym_object] = ACTIONS(850),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_given] = ACTIONS(850),
    [anon_sym_class] = ACTIONS(850),
    [anon_sym_trait] = ACTIONS(850),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(896),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_val] = ACTIONS(850),
    [anon_sym_var] = ACTIONS(850),
    [anon_sym_type] = ACTIONS(850),
    [anon_sym_def] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(850),
    [anon_sym_abstract] = ACTIONS(850),
    [anon_sym_final] = ACTIONS(850),
    [anon_sym_sealed] = ACTIONS(850),
    [anon_sym_implicit] = ACTIONS(850),
    [anon_sym_lazy] = ACTIONS(850),
    [anon_sym_override] = ACTIONS(850),
    [anon_sym_private] = ACTIONS(850),
    [anon_sym_protected] = ACTIONS(850),
    [anon_sym_inline] = ACTIONS(850),
    [anon_sym_infix] = ACTIONS(850),
    [anon_sym_open] = ACTIONS(850),
    [anon_sym_transparent] = ACTIONS(850),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [576] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15227),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(576),
    [sym_block_comment] = STATE(576),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym_case] = ACTIONS(850),
    [anon_sym_object] = ACTIONS(850),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_given] = ACTIONS(850),
    [anon_sym_class] = ACTIONS(850),
    [anon_sym_trait] = ACTIONS(850),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_val] = ACTIONS(850),
    [anon_sym_var] = ACTIONS(850),
    [anon_sym_type] = ACTIONS(850),
    [anon_sym_def] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(850),
    [anon_sym_abstract] = ACTIONS(850),
    [anon_sym_final] = ACTIONS(850),
    [anon_sym_sealed] = ACTIONS(850),
    [anon_sym_implicit] = ACTIONS(850),
    [anon_sym_lazy] = ACTIONS(850),
    [anon_sym_override] = ACTIONS(850),
    [anon_sym_private] = ACTIONS(850),
    [anon_sym_protected] = ACTIONS(850),
    [anon_sym_inline] = ACTIONS(850),
    [anon_sym_infix] = ACTIONS(850),
    [anon_sym_open] = ACTIONS(850),
    [anon_sym_transparent] = ACTIONS(850),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [577] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15227),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(577),
    [sym_block_comment] = STATE(577),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym_case] = ACTIONS(850),
    [anon_sym_object] = ACTIONS(850),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_given] = ACTIONS(850),
    [anon_sym_class] = ACTIONS(850),
    [anon_sym_trait] = ACTIONS(850),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(900),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_val] = ACTIONS(850),
    [anon_sym_var] = ACTIONS(850),
    [anon_sym_type] = ACTIONS(850),
    [anon_sym_def] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(850),
    [anon_sym_abstract] = ACTIONS(850),
    [anon_sym_final] = ACTIONS(850),
    [anon_sym_sealed] = ACTIONS(850),
    [anon_sym_implicit] = ACTIONS(850),
    [anon_sym_lazy] = ACTIONS(850),
    [anon_sym_override] = ACTIONS(850),
    [anon_sym_private] = ACTIONS(850),
    [anon_sym_protected] = ACTIONS(850),
    [anon_sym_inline] = ACTIONS(850),
    [anon_sym_infix] = ACTIONS(850),
    [anon_sym_open] = ACTIONS(850),
    [anon_sym_transparent] = ACTIONS(850),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [578] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16131),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(578),
    [sym_block_comment] = STATE(578),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym_case] = ACTIONS(850),
    [anon_sym_object] = ACTIONS(850),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_given] = ACTIONS(850),
    [anon_sym_class] = ACTIONS(850),
    [anon_sym_trait] = ACTIONS(850),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(902),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_val] = ACTIONS(850),
    [anon_sym_var] = ACTIONS(850),
    [anon_sym_type] = ACTIONS(850),
    [anon_sym_def] = ACTIONS(850),
    [anon_sym_opaque] = ACTIONS(850),
    [anon_sym_abstract] = ACTIONS(850),
    [anon_sym_final] = ACTIONS(850),
    [anon_sym_sealed] = ACTIONS(850),
    [anon_sym_implicit] = ACTIONS(850),
    [anon_sym_lazy] = ACTIONS(850),
    [anon_sym_override] = ACTIONS(850),
    [anon_sym_private] = ACTIONS(850),
    [anon_sym_protected] = ACTIONS(850),
    [anon_sym_inline] = ACTIONS(850),
    [anon_sym_infix] = ACTIONS(850),
    [anon_sym_open] = ACTIONS(850),
    [anon_sym_transparent] = ACTIONS(850),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [579] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(16355),
    [sym__simple_expression] = STATE(4482),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16939),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(6524),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4434),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(4827),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(579),
    [sym_block_comment] = STATE(579),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_COLON] = ACTIONS(906),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym_case] = ACTIONS(912),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_else] = ACTIONS(912),
    [anon_sym_catch] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(936),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_yield] = ACTIONS(912),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [580] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(15815),
    [sym__simple_expression] = STATE(4618),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17217),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(7370),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4479),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(5143),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(580),
    [sym_block_comment] = STATE(580),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_COLON] = ACTIONS(950),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym_case] = ACTIONS(912),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_else] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(972),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_yield] = ACTIONS(912),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [581] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(16045),
    [sym__simple_expression] = STATE(4609),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17201),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(7425),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4460),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(5146),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(581),
    [sym_block_comment] = STATE(581),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_COLON] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym_case] = ACTIONS(912),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_catch] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1008),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_yield] = ACTIONS(912),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [582] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(16376),
    [sym__simple_expression] = STATE(4767),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16961),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8143),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(4568),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(5737),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(582),
    [sym_block_comment] = STATE(582),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_COLON] = ACTIONS(1022),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym_case] = ACTIONS(912),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1044),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_yield] = ACTIONS(912),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [583] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(16217),
    [sym__simple_expression] = STATE(4806),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16744),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(7870),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(4607),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(6041),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(583),
    [sym_block_comment] = STATE(583),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_COLON] = ACTIONS(1058),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym_case] = ACTIONS(912),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_else] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1080),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_yield] = ACTIONS(912),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [584] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(16300),
    [sym__simple_expression] = STATE(4801),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16983),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(7976),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(4598),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(5819),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(584),
    [sym_block_comment] = STATE(584),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_COLON] = ACTIONS(1094),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym_COMMA] = ACTIONS(910),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_else] = ACTIONS(912),
    [anon_sym_then] = ACTIONS(912),
    [anon_sym_catch] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1116),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [585] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(16112),
    [sym__simple_expression] = STATE(5042),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17154),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8303),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4750),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6445),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(585),
    [sym_block_comment] = STATE(585),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_COLON] = ACTIONS(1130),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym_case] = ACTIONS(912),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_else] = ACTIONS(912),
    [anon_sym_catch] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1152),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__outdent] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [586] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(15745),
    [sym__simple_expression] = STATE(5092),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17238),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8777),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(4744),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(6749),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(586),
    [sym_block_comment] = STATE(586),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_COLON] = ACTIONS(1166),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym_COMMA] = ACTIONS(910),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_else] = ACTIONS(912),
    [anon_sym_then] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1188),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [587] = {
    [sym_inline_modifier] = STATE(2266),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(13010),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(587),
    [sym_block_comment] = STATE(587),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym_case] = ACTIONS(1200),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [588] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(16271),
    [sym__simple_expression] = STATE(5452),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16847),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9035),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(4951),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(6940),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(588),
    [sym_block_comment] = STATE(588),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_COLON] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym_case] = ACTIONS(912),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_catch] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1248),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__outdent] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [589] = {
    [sym_inline_modifier] = STATE(2108),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12825),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(589),
    [sym_block_comment] = STATE(589),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym_COMMA] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_RPAREN] = ACTIONS(1202),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_then] = ACTIONS(1200),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [590] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8958),
    [sym_expression] = STATE(16299),
    [sym__simple_expression] = STATE(6039),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16871),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9939),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5485),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8150),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(590),
    [sym_block_comment] = STATE(590),
    [ts_builtin_sym_end] = ACTIONS(910),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_COLON] = ACTIONS(1282),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_else] = ACTIONS(912),
    [anon_sym_catch] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1304),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [591] = {
    [sym_inline_modifier] = STATE(2126),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11715),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(591),
    [sym_block_comment] = STATE(591),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym_case] = ACTIONS(1200),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [592] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(15610),
    [sym__simple_expression] = STATE(5216),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17280),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8997),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(4921),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(6901),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(592),
    [sym_block_comment] = STATE(592),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_COLON] = ACTIONS(1338),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym_case] = ACTIONS(912),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_else] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1360),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__outdent] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [593] = {
    [sym_inline_modifier] = STATE(2394),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11715),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(593),
    [sym_block_comment] = STATE(593),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_RPAREN] = ACTIONS(1202),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [594] = {
    [sym_inline_modifier] = STATE(2356),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12357),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(594),
    [sym_block_comment] = STATE(594),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_RPAREN] = ACTIONS(1202),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [595] = {
    [sym_inline_modifier] = STATE(2289),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(13538),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(595),
    [sym_block_comment] = STATE(595),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym_case] = ACTIONS(1200),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [596] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(16086),
    [sym__simple_expression] = STATE(5254),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17078),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9340),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5073),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(6993),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(596),
    [sym_block_comment] = STATE(596),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_COLON] = ACTIONS(1426),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym_COMMA] = ACTIONS(910),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_then] = ACTIONS(912),
    [anon_sym_catch] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1448),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [597] = {
    [sym_inline_modifier] = STATE(2276),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12420),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(597),
    [sym_block_comment] = STATE(597),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym_case] = ACTIONS(1200),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [598] = {
    [sym_inline_modifier] = STATE(2218),
    [sym_block] = STATE(8958),
    [sym_expression] = STATE(13772),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(598),
    [sym_block_comment] = STATE(598),
    [ts_builtin_sym_end] = ACTIONS(1202),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [599] = {
    [sym_inline_modifier] = STATE(2180),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11715),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(599),
    [sym_block_comment] = STATE(599),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1200),
    [anon_sym_yield] = ACTIONS(1200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [600] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9672),
    [sym_expression] = STATE(15936),
    [sym__simple_expression] = STATE(6638),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17196),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10287),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5655),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8866),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(600),
    [sym_block_comment] = STATE(600),
    [ts_builtin_sym_end] = ACTIONS(910),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_COLON] = ACTIONS(1514),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_else] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(1536),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [601] = {
    [sym_inline_modifier] = STATE(2226),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13088),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(601),
    [sym_block_comment] = STATE(601),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym_COMMA] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_RPAREN] = ACTIONS(1202),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_then] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [602] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(16244),
    [sym__simple_expression] = STATE(5300),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16742),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9250),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(4907),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(7410),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(602),
    [sym_block_comment] = STATE(602),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_COLON] = ACTIONS(1570),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym_COMMA] = ACTIONS(910),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_else] = ACTIONS(912),
    [anon_sym_then] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1592),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [603] = {
    [sym_inline_modifier] = STATE(2361),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12420),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(603),
    [sym_block_comment] = STATE(603),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_RPAREN] = ACTIONS(1202),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [604] = {
    [sym_inline_modifier] = STATE(2380),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(13479),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(604),
    [sym_block_comment] = STATE(604),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym_case] = ACTIONS(1200),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [605] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9899),
    [sym_expression] = STATE(15993),
    [sym__simple_expression] = STATE(6676),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17307),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10335),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5779),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8461),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(605),
    [sym_block_comment] = STATE(605),
    [ts_builtin_sym_end] = ACTIONS(910),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_COLON] = ACTIONS(1640),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_catch] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1662),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [606] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(16084),
    [sym__simple_expression] = STATE(5931),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17027),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9660),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5338),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(7797),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(606),
    [sym_block_comment] = STATE(606),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_COLON] = ACTIONS(1676),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym_case] = ACTIONS(912),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_else] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(1698),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__outdent] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [607] = {
    [sym_inline_modifier] = STATE(2404),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(13010),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(607),
    [sym_block_comment] = STATE(607),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [608] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(15795),
    [sym__simple_expression] = STATE(4883),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17619),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8498),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(4736),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(6646),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(608),
    [sym_block_comment] = STATE(608),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_COLON] = ACTIONS(1724),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1726),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_yield] = ACTIONS(912),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [609] = {
    [sym_inline_modifier] = STATE(2274),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12357),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(609),
    [sym_block_comment] = STATE(609),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym_case] = ACTIONS(1200),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [610] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(16016),
    [sym__simple_expression] = STATE(5821),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17175),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9827),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5189),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(7901),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(610),
    [sym_block_comment] = STATE(610),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_COLON] = ACTIONS(1746),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym_case] = ACTIONS(912),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1768),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__outdent] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [611] = {
    [sym_inline_modifier] = STATE(2215),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13710),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(611),
    [sym_block_comment] = STATE(611),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym_COMMA] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_RPAREN] = ACTIONS(1202),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_then] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [612] = {
    [sym_inline_modifier] = STATE(2395),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(13479),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(612),
    [sym_block_comment] = STATE(612),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [613] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10013),
    [sym_expression] = STATE(16158),
    [sym__simple_expression] = STATE(7278),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16888),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10484),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6751),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(9367),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(613),
    [sym_block_comment] = STATE(613),
    [ts_builtin_sym_end] = ACTIONS(910),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_COLON] = ACTIONS(1816),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_else] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(1838),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [614] = {
    [sym_inline_modifier] = STATE(2372),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12420),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(614),
    [sym_block_comment] = STATE(614),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1200),
    [anon_sym_yield] = ACTIONS(1200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [615] = {
    [sym_inline_modifier] = STATE(2373),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12478),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(615),
    [sym_block_comment] = STATE(615),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_RPAREN] = ACTIONS(1202),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [616] = {
    [sym_inline_modifier] = STATE(2149),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(13934),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(616),
    [sym_block_comment] = STATE(616),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym_case] = ACTIONS(1200),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [617] = {
    [sym_inline_modifier] = STATE(2186),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13445),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(617),
    [sym_block_comment] = STATE(617),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym_COMMA] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_RPAREN] = ACTIONS(1202),
    [anon_sym_then] = ACTIONS(1200),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [618] = {
    [sym_inline_modifier] = STATE(2133),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12518),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(618),
    [sym_block_comment] = STATE(618),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym_case] = ACTIONS(1200),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [619] = {
    [sym_inline_modifier] = STATE(2122),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12478),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(619),
    [sym_block_comment] = STATE(619),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym_case] = ACTIONS(1200),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [620] = {
    [sym_inline_modifier] = STATE(2338),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12357),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(620),
    [sym_block_comment] = STATE(620),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1200),
    [anon_sym_yield] = ACTIONS(1200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [621] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(15795),
    [sym__simple_expression] = STATE(4883),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17619),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8498),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(4736),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(6646),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(621),
    [sym_block_comment] = STATE(621),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_COLON] = ACTIONS(1724),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym_case] = ACTIONS(912),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1726),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [622] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(16246),
    [sym__simple_expression] = STATE(5761),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17005),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9844),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(5368),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(7971),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(622),
    [sym_block_comment] = STATE(622),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_COLON] = ACTIONS(1976),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym_COMMA] = ACTIONS(910),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_then] = ACTIONS(912),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(1998),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [623] = {
    [sym_inline_modifier] = STATE(2272),
    [sym_block] = STATE(9899),
    [sym_expression] = STATE(14126),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(623),
    [sym_block_comment] = STATE(623),
    [ts_builtin_sym_end] = ACTIONS(1202),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [624] = {
    [sym_inline_modifier] = STATE(2174),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12518),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(624),
    [sym_block_comment] = STATE(624),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_RPAREN] = ACTIONS(1202),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [625] = {
    [sym_inline_modifier] = STATE(2304),
    [sym_block] = STATE(9672),
    [sym_expression] = STATE(14233),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(625),
    [sym_block_comment] = STATE(625),
    [ts_builtin_sym_end] = ACTIONS(1202),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [626] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(16126),
    [sym__simple_expression] = STATE(6150),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17012),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10069),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(5723),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(8607),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(626),
    [sym_block_comment] = STATE(626),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(2060),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(912),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2064),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__outdent] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [627] = {
    [sym_inline_modifier] = STATE(2400),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(13538),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(627),
    [sym_block_comment] = STATE(627),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [628] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10196),
    [sym_expression] = STATE(16326),
    [sym__simple_expression] = STATE(6964),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16895),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10560),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6685),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9359),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(628),
    [sym_block_comment] = STATE(628),
    [ts_builtin_sym_end] = ACTIONS(910),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_COLON] = ACTIONS(2082),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_finally] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2104),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [629] = {
    [sym_inline_modifier] = STATE(2161),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(14050),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(629),
    [sym_block_comment] = STATE(629),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym_case] = ACTIONS(1200),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [630] = {
    [sym_inline_modifier] = STATE(2104),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(14021),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(630),
    [sym_block_comment] = STATE(630),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym_COMMA] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_RPAREN] = ACTIONS(1202),
    [anon_sym_then] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [631] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(13212),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym__expr_case_clause] = STATE(13210),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(631),
    [sym_block_comment] = STATE(631),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym_case] = ACTIONS(2156),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [632] = {
    [sym_inline_modifier] = STATE(2122),
    [sym__indentable_expression] = STATE(12632),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym__expr_case_clause] = STATE(12633),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(632),
    [sym_block_comment] = STATE(632),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym_case] = ACTIONS(2176),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [633] = {
    [sym_inline_modifier] = STATE(2104),
    [sym__indentable_expression] = STATE(14262),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym__expr_case_clause] = STATE(14263),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(633),
    [sym_block_comment] = STATE(633),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym_case] = ACTIONS(2180),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [634] = {
    [sym_inline_modifier] = STATE(2149),
    [sym__indentable_expression] = STATE(14140),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym__expr_case_clause] = STATE(14185),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(634),
    [sym_block_comment] = STATE(634),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym_case] = ACTIONS(2184),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [635] = {
    [sym_inline_modifier] = STATE(2280),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12825),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(635),
    [sym_block_comment] = STATE(635),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(1200),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [636] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13212),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym__expr_case_clause] = STATE(13210),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(636),
    [sym_block_comment] = STATE(636),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym_case] = ACTIONS(2188),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [637] = {
    [sym_inline_modifier] = STATE(2410),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(13934),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(637),
    [sym_block_comment] = STATE(637),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [638] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(13469),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym__expr_case_clause] = STATE(13467),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(638),
    [sym_block_comment] = STATE(638),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym_case] = ACTIONS(2204),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [639] = {
    [sym_inline_modifier] = STATE(2328),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12518),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(639),
    [sym_block_comment] = STATE(639),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1200),
    [anon_sym_yield] = ACTIONS(1200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [640] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(12219),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym__expr_case_clause] = STATE(12224),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(640),
    [sym_block_comment] = STATE(640),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym_case] = ACTIONS(2222),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [641] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(11882),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym__expr_case_clause] = STATE(11883),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(641),
    [sym_block_comment] = STATE(641),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym_case] = ACTIONS(2228),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [642] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13795),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym__expr_case_clause] = STATE(13816),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(642),
    [sym_block_comment] = STATE(642),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym_case] = ACTIONS(2232),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [643] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13867),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym__expr_case_clause] = STATE(13861),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(643),
    [sym_block_comment] = STATE(643),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym_case] = ACTIONS(2236),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [644] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(11882),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym__expr_case_clause] = STATE(11883),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(644),
    [sym_block_comment] = STATE(644),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym_case] = ACTIONS(2240),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [645] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(15210),
    [sym__simple_expression] = STATE(7512),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10885),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(7123),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9805),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(645),
    [sym_block_comment] = STATE(645),
    [ts_builtin_sym_end] = ACTIONS(910),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_COLON] = ACTIONS(2244),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(2248),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [646] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(16126),
    [sym__simple_expression] = STATE(6150),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17012),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10069),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(5723),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(8607),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(646),
    [sym_block_comment] = STATE(646),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(2060),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2064),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(910),
    [sym__outdent] = ACTIONS(910),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [647] = {
    [sym_inline_modifier] = STATE(2410),
    [sym__indentable_expression] = STATE(14140),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym__expr_case_clause] = STATE(14185),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(647),
    [sym_block_comment] = STATE(647),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym_case] = ACTIONS(2250),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [648] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(12300),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym__expr_case_clause] = STATE(12298),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(648),
    [sym_block_comment] = STATE(648),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym_case] = ACTIONS(2254),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [649] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(11882),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym__expr_case_clause] = STATE(11883),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(649),
    [sym_block_comment] = STATE(649),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym_case] = ACTIONS(2260),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [650] = {
    [sym_inline_modifier] = STATE(2132),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13222),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(650),
    [sym_block_comment] = STATE(650),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym_case] = ACTIONS(1200),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [651] = {
    [sym_inline_modifier] = STATE(2148),
    [sym_block] = STATE(10196),
    [sym_expression] = STATE(14350),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(651),
    [sym_block_comment] = STATE(651),
    [ts_builtin_sym_end] = ACTIONS(1202),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [652] = {
    [sym_inline_modifier] = STATE(2155),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(14050),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(652),
    [sym_block_comment] = STATE(652),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [653] = {
    [sym_inline_modifier] = STATE(2379),
    [sym_block] = STATE(10013),
    [sym_expression] = STATE(14289),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(653),
    [sym_block_comment] = STATE(653),
    [ts_builtin_sym_end] = ACTIONS(1202),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [654] = {
    [sym_inline_modifier] = STATE(2352),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13222),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(654),
    [sym_block_comment] = STATE(654),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_RPAREN] = ACTIONS(1202),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [655] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(13469),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym__expr_case_clause] = STATE(13467),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(655),
    [sym_block_comment] = STATE(655),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym_case] = ACTIONS(2330),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [656] = {
    [sym_inline_modifier] = STATE(2208),
    [sym__indentable_expression] = STATE(14262),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym__expr_case_clause] = STATE(14263),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(656),
    [sym_block_comment] = STATE(656),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym_case] = ACTIONS(2348),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [657] = {
    [sym_inline_modifier] = STATE(2196),
    [sym__indentable_expression] = STATE(12632),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym__expr_case_clause] = STATE(12633),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(657),
    [sym_block_comment] = STATE(657),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym_case] = ACTIONS(2366),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [658] = {
    [sym_inline_modifier] = STATE(2373),
    [sym__indentable_expression] = STATE(12632),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym__expr_case_clause] = STATE(12633),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(658),
    [sym_block_comment] = STATE(658),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym_case] = ACTIONS(2384),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [659] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(12300),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym__expr_case_clause] = STATE(12298),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(659),
    [sym_block_comment] = STATE(659),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym_case] = ACTIONS(2388),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [660] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(12300),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym__expr_case_clause] = STATE(12298),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(660),
    [sym_block_comment] = STATE(660),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym_case] = ACTIONS(2390),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [661] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(11882),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym__expr_case_clause] = STATE(11883),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(661),
    [sym_block_comment] = STATE(661),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym_case] = ACTIONS(2392),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [662] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(12219),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym__expr_case_clause] = STATE(12224),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(662),
    [sym_block_comment] = STATE(662),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym_case] = ACTIONS(2394),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [663] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(12219),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym__expr_case_clause] = STATE(12224),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(663),
    [sym_block_comment] = STATE(663),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym_case] = ACTIONS(2396),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [664] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(13839),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym__expr_case_clause] = STATE(13837),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(664),
    [sym_block_comment] = STATE(664),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym_case] = ACTIONS(2398),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [665] = {
    [sym_inline_modifier] = STATE(2119),
    [sym__indentable_expression] = STATE(14262),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym__expr_case_clause] = STATE(14263),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(665),
    [sym_block_comment] = STATE(665),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym_case] = ACTIONS(2404),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [666] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(13839),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym__expr_case_clause] = STATE(13837),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(666),
    [sym_block_comment] = STATE(666),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym_case] = ACTIONS(2422),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [667] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(12219),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym__expr_case_clause] = STATE(12224),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(667),
    [sym_block_comment] = STATE(667),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym_case] = ACTIONS(2424),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [668] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13212),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym__expr_case_clause] = STATE(13210),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(668),
    [sym_block_comment] = STATE(668),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym_case] = ACTIONS(2428),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [669] = {
    [sym_inline_modifier] = STATE(2182),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12825),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(669),
    [sym_block_comment] = STATE(669),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [670] = {
    [sym_inline_modifier] = STATE(2148),
    [sym__indentable_expression] = STATE(12632),
    [sym_block] = STATE(10196),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(14416),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym__expr_case_clause] = STATE(12633),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(670),
    [sym_block_comment] = STATE(670),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym_case] = ACTIONS(2446),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [671] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(13795),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym__expr_case_clause] = STATE(13816),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(671),
    [sym_block_comment] = STATE(671),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym_case] = ACTIONS(2448),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [672] = {
    [sym_inline_modifier] = STATE(2127),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14174),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(672),
    [sym_block_comment] = STATE(672),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_case] = ACTIONS(1200),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [673] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13867),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym__expr_case_clause] = STATE(13861),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(673),
    [sym_block_comment] = STATE(673),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym_case] = ACTIONS(2468),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [674] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(13795),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym__expr_case_clause] = STATE(13816),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(674),
    [sym_block_comment] = STATE(674),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym_case] = ACTIONS(2472),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [675] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15914),
    [sym__simple_expression] = STATE(6570),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10245),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(675),
    [sym_block_comment] = STATE(675),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_COLON] = ACTIONS(2490),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym_COMMA] = ACTIONS(910),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(910),
    [anon_sym_then] = ACTIONS(912),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [676] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13486),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym__expr_case_clause] = STATE(13487),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(676),
    [sym_block_comment] = STATE(676),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym_case] = ACTIONS(2494),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [677] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(13469),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym__expr_case_clause] = STATE(13467),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(677),
    [sym_block_comment] = STATE(677),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym_case] = ACTIONS(2500),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [678] = {
    [sym_inline_modifier] = STATE(2196),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12478),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(678),
    [sym_block_comment] = STATE(678),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1200),
    [anon_sym_yield] = ACTIONS(1200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [679] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12300),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym__expr_case_clause] = STATE(12298),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(679),
    [sym_block_comment] = STATE(679),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym_case] = ACTIONS(2518),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [680] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13486),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym__expr_case_clause] = STATE(13487),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(680),
    [sym_block_comment] = STATE(680),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym_case] = ACTIONS(2522),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [681] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1684),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(681),
    [sym_block_comment] = STATE(681),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [682] = {
    [sym_inline_modifier] = STATE(2326),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(14542),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(682),
    [sym_block_comment] = STATE(682),
    [ts_builtin_sym_end] = ACTIONS(1202),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [683] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1072),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(683),
    [sym_block_comment] = STATE(683),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [684] = {
    [sym_inline_modifier] = STATE(2148),
    [sym_block] = STATE(10196),
    [sym_expression] = STATE(14328),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(684),
    [sym_block_comment] = STATE(684),
    [sym__alpha_identifier] = ACTIONS(2530),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2535),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2540),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2540),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2543),
    [anon_sym_infix] = ACTIONS(2540),
    [anon_sym_open] = ACTIONS(2540),
    [anon_sym_transparent] = ACTIONS(2540),
    [anon_sym_LPAREN] = ACTIONS(2546),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2549),
    [sym_operator_identifier] = ACTIONS(2552),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(2555),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [685] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1562),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(685),
    [sym_block_comment] = STATE(685),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [686] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1419),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(686),
    [sym_block_comment] = STATE(686),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [687] = {
    [sym_inline_modifier] = STATE(2126),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11719),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(687),
    [sym_block_comment] = STATE(687),
    [sym__alpha_identifier] = ACTIONS(2558),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2561),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(2564),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2564),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(2567),
    [anon_sym_infix] = ACTIONS(2564),
    [anon_sym_open] = ACTIONS(2564),
    [anon_sym_transparent] = ACTIONS(2564),
    [anon_sym_LPAREN] = ACTIONS(2570),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(2573),
    [sym_operator_identifier] = ACTIONS(2576),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(2579),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [688] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1547),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(688),
    [sym_block_comment] = STATE(688),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [689] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(886),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(689),
    [sym_block_comment] = STATE(689),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [690] = {
    [sym_inline_modifier] = STATE(2304),
    [sym_block] = STATE(9672),
    [sym_expression] = STATE(14180),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(690),
    [sym_block_comment] = STATE(690),
    [sym__alpha_identifier] = ACTIONS(2582),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2585),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(2588),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2588),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(2591),
    [anon_sym_infix] = ACTIONS(2588),
    [anon_sym_open] = ACTIONS(2588),
    [anon_sym_transparent] = ACTIONS(2588),
    [anon_sym_LPAREN] = ACTIONS(2594),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(2597),
    [sym_operator_identifier] = ACTIONS(2600),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(2603),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [691] = {
    [sym_inline_modifier] = STATE(2373),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12487),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(691),
    [sym_block_comment] = STATE(691),
    [sym__alpha_identifier] = ACTIONS(2606),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2609),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(2612),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2612),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(2615),
    [anon_sym_infix] = ACTIONS(2612),
    [anon_sym_open] = ACTIONS(2612),
    [anon_sym_transparent] = ACTIONS(2612),
    [anon_sym_LPAREN] = ACTIONS(2618),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(2621),
    [sym_operator_identifier] = ACTIONS(2624),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(2555),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [692] = {
    [sym_inline_modifier] = STATE(2132),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13146),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(692),
    [sym_block_comment] = STATE(692),
    [sym__alpha_identifier] = ACTIONS(2627),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2630),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(2633),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2633),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(2636),
    [anon_sym_infix] = ACTIONS(2633),
    [anon_sym_open] = ACTIONS(2633),
    [anon_sym_transparent] = ACTIONS(2633),
    [anon_sym_LPAREN] = ACTIONS(2639),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(2642),
    [sym_operator_identifier] = ACTIONS(2645),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(2648),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [693] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(867),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(693),
    [sym_block_comment] = STATE(693),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [694] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1615),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(694),
    [sym_block_comment] = STATE(694),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [695] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1574),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(695),
    [sym_block_comment] = STATE(695),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [696] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(979),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(696),
    [sym_block_comment] = STATE(696),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [697] = {
    [sym_inline_modifier] = STATE(2138),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13620),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(697),
    [sym_block_comment] = STATE(697),
    [sym__alpha_identifier] = ACTIONS(2651),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2654),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(2657),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2657),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(2670),
    [anon_sym_infix] = ACTIONS(2657),
    [anon_sym_open] = ACTIONS(2657),
    [anon_sym_transparent] = ACTIONS(2657),
    [anon_sym_LPAREN] = ACTIONS(2673),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(2676),
    [sym_operator_identifier] = ACTIONS(2679),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(2686),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [698] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1572),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(698),
    [sym_block_comment] = STATE(698),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [699] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(996),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(699),
    [sym_block_comment] = STATE(699),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [700] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1210),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(700),
    [sym_block_comment] = STATE(700),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [701] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1446),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(701),
    [sym_block_comment] = STATE(701),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [702] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(862),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(702),
    [sym_block_comment] = STATE(702),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [703] = {
    [sym_inline_modifier] = STATE(2162),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13146),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(703),
    [sym_block_comment] = STATE(703),
    [sym__alpha_identifier] = ACTIONS(2627),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2630),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(2633),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2633),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(2699),
    [anon_sym_infix] = ACTIONS(2633),
    [anon_sym_open] = ACTIONS(2633),
    [anon_sym_transparent] = ACTIONS(2633),
    [anon_sym_LPAREN] = ACTIONS(2639),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(2642),
    [sym_operator_identifier] = ACTIONS(2702),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(2648),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [704] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1534),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(704),
    [sym_block_comment] = STATE(704),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [705] = {
    [sym_inline_modifier] = STATE(2162),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13222),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(705),
    [sym_block_comment] = STATE(705),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(1200),
    [anon_sym_yield] = ACTIONS(1200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [706] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1605),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(706),
    [sym_block_comment] = STATE(706),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [707] = {
    [sym_inline_modifier] = STATE(2174),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12503),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(707),
    [sym_block_comment] = STATE(707),
    [sym__alpha_identifier] = ACTIONS(2711),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2714),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(2717),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2717),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(2722),
    [anon_sym_infix] = ACTIONS(2717),
    [anon_sym_open] = ACTIONS(2717),
    [anon_sym_transparent] = ACTIONS(2717),
    [anon_sym_LPAREN] = ACTIONS(2725),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(2728),
    [sym_operator_identifier] = ACTIONS(2731),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(2734),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [708] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1603),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(708),
    [sym_block_comment] = STATE(708),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [709] = {
    [sym_inline_modifier] = STATE(2200),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13620),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(709),
    [sym_block_comment] = STATE(709),
    [sym__alpha_identifier] = ACTIONS(2651),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2654),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(2657),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2657),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(2670),
    [anon_sym_infix] = ACTIONS(2657),
    [anon_sym_open] = ACTIONS(2657),
    [anon_sym_transparent] = ACTIONS(2657),
    [anon_sym_LPAREN] = ACTIONS(2673),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(2676),
    [sym_operator_identifier] = ACTIONS(2747),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(2686),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [710] = {
    [sym_inline_modifier] = STATE(2168),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13098),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(710),
    [sym_block_comment] = STATE(710),
    [sym__alpha_identifier] = ACTIONS(2754),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2757),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(2760),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2760),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(2763),
    [anon_sym_infix] = ACTIONS(2760),
    [anon_sym_open] = ACTIONS(2760),
    [anon_sym_transparent] = ACTIONS(2760),
    [anon_sym_LPAREN] = ACTIONS(2766),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(2769),
    [sym_operator_identifier] = ACTIONS(2772),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(2775),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [711] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14157),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(711),
    [sym_block_comment] = STATE(711),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym_COMMA] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(1202),
    [anon_sym_then] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [712] = {
    [sym_inline_modifier] = STATE(2122),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12487),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(712),
    [sym_block_comment] = STATE(712),
    [sym__alpha_identifier] = ACTIONS(2606),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2609),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(2612),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2612),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(2615),
    [anon_sym_infix] = ACTIONS(2612),
    [anon_sym_open] = ACTIONS(2612),
    [anon_sym_transparent] = ACTIONS(2612),
    [anon_sym_LPAREN] = ACTIONS(2618),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(2621),
    [sym_operator_identifier] = ACTIONS(2778),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(2555),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [713] = {
    [sym_inline_modifier] = STATE(2404),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(12999),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(713),
    [sym_block_comment] = STATE(713),
    [sym__alpha_identifier] = ACTIONS(2781),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2784),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(2787),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2787),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(2790),
    [anon_sym_infix] = ACTIONS(2787),
    [anon_sym_open] = ACTIONS(2787),
    [anon_sym_transparent] = ACTIONS(2787),
    [anon_sym_LPAREN] = ACTIONS(2793),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(2796),
    [sym_operator_identifier] = ACTIONS(2799),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(2802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [714] = {
    [sym_inline_modifier] = STATE(2180),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11719),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(714),
    [sym_block_comment] = STATE(714),
    [sym__alpha_identifier] = ACTIONS(2558),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2561),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(2564),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2564),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(2567),
    [anon_sym_infix] = ACTIONS(2564),
    [anon_sym_open] = ACTIONS(2564),
    [anon_sym_transparent] = ACTIONS(2564),
    [anon_sym_LPAREN] = ACTIONS(2570),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(2573),
    [sym_operator_identifier] = ACTIONS(2805),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(2579),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [715] = {
    [sym_inline_modifier] = STATE(2260),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13429),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(715),
    [sym_block_comment] = STATE(715),
    [sym__alpha_identifier] = ACTIONS(2808),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2811),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(2814),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2814),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(2817),
    [anon_sym_infix] = ACTIONS(2814),
    [anon_sym_open] = ACTIONS(2814),
    [anon_sym_transparent] = ACTIONS(2814),
    [anon_sym_LPAREN] = ACTIONS(2820),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(2823),
    [sym_operator_identifier] = ACTIONS(2826),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(2829),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [716] = {
    [sym_inline_modifier] = STATE(2168),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13088),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(716),
    [sym_block_comment] = STATE(716),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [717] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(920),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(717),
    [sym_block_comment] = STATE(717),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [718] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1586),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(718),
    [sym_block_comment] = STATE(718),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [719] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14198),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(719),
    [sym_block_comment] = STATE(719),
    [sym__alpha_identifier] = ACTIONS(2832),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(2838),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2838),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2851),
    [anon_sym_infix] = ACTIONS(2838),
    [anon_sym_open] = ACTIONS(2838),
    [anon_sym_transparent] = ACTIONS(2838),
    [anon_sym_LPAREN] = ACTIONS(2854),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(2857),
    [sym_operator_identifier] = ACTIONS(2860),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(2867),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [720] = {
    [sym_inline_modifier] = STATE(2108),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12775),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(720),
    [sym_block_comment] = STATE(720),
    [sym__alpha_identifier] = ACTIONS(2870),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2873),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(2876),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2876),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(2879),
    [anon_sym_infix] = ACTIONS(2876),
    [anon_sym_open] = ACTIONS(2876),
    [anon_sym_transparent] = ACTIONS(2876),
    [anon_sym_LPAREN] = ACTIONS(2882),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(2885),
    [sym_operator_identifier] = ACTIONS(2888),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(2891),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [721] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(900),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(721),
    [sym_block_comment] = STATE(721),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [722] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1655),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(722),
    [sym_block_comment] = STATE(722),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [723] = {
    [sym_inline_modifier] = STATE(2328),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12503),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(723),
    [sym_block_comment] = STATE(723),
    [sym__alpha_identifier] = ACTIONS(2711),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2714),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(2717),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2717),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(2722),
    [anon_sym_infix] = ACTIONS(2717),
    [anon_sym_open] = ACTIONS(2717),
    [anon_sym_transparent] = ACTIONS(2717),
    [anon_sym_LPAREN] = ACTIONS(2725),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(2728),
    [sym_operator_identifier] = ACTIONS(2896),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(2734),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [724] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1404),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(724),
    [sym_block_comment] = STATE(724),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [725] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1120),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(725),
    [sym_block_comment] = STATE(725),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [726] = {
    [sym_inline_modifier] = STATE(2104),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(13967),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(726),
    [sym_block_comment] = STATE(726),
    [sym__alpha_identifier] = ACTIONS(2899),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2902),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(2905),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2905),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(2908),
    [anon_sym_infix] = ACTIONS(2905),
    [anon_sym_open] = ACTIONS(2905),
    [anon_sym_transparent] = ACTIONS(2905),
    [anon_sym_LPAREN] = ACTIONS(2911),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(2914),
    [sym_operator_identifier] = ACTIONS(2917),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [727] = {
    [sym_inline_modifier] = STATE(2257),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13222),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(727),
    [sym_block_comment] = STATE(727),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym_RBRACE] = ACTIONS(1202),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [728] = {
    [sym_inline_modifier] = STATE(2273),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14174),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(728),
    [sym_block_comment] = STATE(728),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(1200),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [729] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(939),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(729),
    [sym_block_comment] = STATE(729),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [730] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1669),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(730),
    [sym_block_comment] = STATE(730),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [731] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1214),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(731),
    [sym_block_comment] = STATE(731),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [732] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(923),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(732),
    [sym_block_comment] = STATE(732),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [733] = {
    [sym_inline_modifier] = STATE(2274),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12368),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(733),
    [sym_block_comment] = STATE(733),
    [sym__alpha_identifier] = ACTIONS(2939),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2942),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(2945),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2945),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(2948),
    [anon_sym_infix] = ACTIONS(2945),
    [anon_sym_open] = ACTIONS(2945),
    [anon_sym_transparent] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2951),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(2954),
    [sym_operator_identifier] = ACTIONS(2957),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(2960),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [734] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(908),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(734),
    [sym_block_comment] = STATE(734),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [735] = {
    [sym_inline_modifier] = STATE(2127),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14259),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(735),
    [sym_block_comment] = STATE(735),
    [sym__alpha_identifier] = ACTIONS(2963),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2966),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(2969),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2969),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2972),
    [anon_sym_infix] = ACTIONS(2969),
    [anon_sym_open] = ACTIONS(2969),
    [anon_sym_transparent] = ACTIONS(2969),
    [anon_sym_LPAREN] = ACTIONS(2975),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(2978),
    [sym_operator_identifier] = ACTIONS(2981),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(2984),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [736] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1189),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(736),
    [sym_block_comment] = STATE(736),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [737] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(887),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(737),
    [sym_block_comment] = STATE(737),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [738] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1623),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(738),
    [sym_block_comment] = STATE(738),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [739] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(894),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(739),
    [sym_block_comment] = STATE(739),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [740] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(969),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(740),
    [sym_block_comment] = STATE(740),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [741] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(884),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(741),
    [sym_block_comment] = STATE(741),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [742] = {
    [sym_inline_modifier] = STATE(2301),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13429),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(742),
    [sym_block_comment] = STATE(742),
    [sym__alpha_identifier] = ACTIONS(2808),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2811),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(2814),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2814),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(2817),
    [anon_sym_infix] = ACTIONS(2814),
    [anon_sym_open] = ACTIONS(2814),
    [anon_sym_transparent] = ACTIONS(2814),
    [anon_sym_LPAREN] = ACTIONS(2820),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(2823),
    [sym_operator_identifier] = ACTIONS(2987),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(2829),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [743] = {
    [sym_inline_modifier] = STATE(2394),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11719),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(743),
    [sym_block_comment] = STATE(743),
    [sym__alpha_identifier] = ACTIONS(2558),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2561),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(2564),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2564),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(2567),
    [anon_sym_infix] = ACTIONS(2564),
    [anon_sym_open] = ACTIONS(2564),
    [anon_sym_transparent] = ACTIONS(2564),
    [anon_sym_LPAREN] = ACTIONS(2570),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(2573),
    [sym_operator_identifier] = ACTIONS(2990),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(2579),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [744] = {
    [sym_inline_modifier] = STATE(2257),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13146),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(744),
    [sym_block_comment] = STATE(744),
    [sym__alpha_identifier] = ACTIONS(2627),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2630),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(2633),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2633),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(2699),
    [anon_sym_infix] = ACTIONS(2633),
    [anon_sym_open] = ACTIONS(2633),
    [anon_sym_transparent] = ACTIONS(2633),
    [anon_sym_LPAREN] = ACTIONS(2639),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(2642),
    [sym_operator_identifier] = ACTIONS(2993),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(2648),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [745] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1516),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(745),
    [sym_block_comment] = STATE(745),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [746] = {
    [sym_inline_modifier] = STATE(2161),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(14033),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(746),
    [sym_block_comment] = STATE(746),
    [sym__alpha_identifier] = ACTIONS(2996),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2999),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(3002),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3002),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(3005),
    [anon_sym_infix] = ACTIONS(3002),
    [anon_sym_open] = ACTIONS(3002),
    [anon_sym_transparent] = ACTIONS(3002),
    [anon_sym_LPAREN] = ACTIONS(3008),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(3011),
    [sym_operator_identifier] = ACTIONS(3014),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(3017),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [747] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(866),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(747),
    [sym_block_comment] = STATE(747),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [748] = {
    [sym_inline_modifier] = STATE(2181),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14198),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(748),
    [sym_block_comment] = STATE(748),
    [sym__alpha_identifier] = ACTIONS(2832),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(2838),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2838),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2851),
    [anon_sym_infix] = ACTIONS(2838),
    [anon_sym_open] = ACTIONS(2838),
    [anon_sym_transparent] = ACTIONS(2838),
    [anon_sym_LPAREN] = ACTIONS(2854),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(2857),
    [sym_operator_identifier] = ACTIONS(3030),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(2867),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [749] = {
    [sym_inline_modifier] = STATE(2196),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12487),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(749),
    [sym_block_comment] = STATE(749),
    [sym__alpha_identifier] = ACTIONS(2606),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2609),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(2612),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2612),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(2615),
    [anon_sym_infix] = ACTIONS(2612),
    [anon_sym_open] = ACTIONS(2612),
    [anon_sym_transparent] = ACTIONS(2612),
    [anon_sym_LPAREN] = ACTIONS(2618),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(2621),
    [sym_operator_identifier] = ACTIONS(3037),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(2555),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [750] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1382),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(750),
    [sym_block_comment] = STATE(750),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [751] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(864),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(751),
    [sym_block_comment] = STATE(751),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [752] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(893),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(752),
    [sym_block_comment] = STATE(752),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [753] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(916),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(753),
    [sym_block_comment] = STATE(753),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [754] = {
    [sym_inline_modifier] = STATE(2182),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12775),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(754),
    [sym_block_comment] = STATE(754),
    [sym__alpha_identifier] = ACTIONS(2870),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2873),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(2876),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2876),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(2879),
    [anon_sym_infix] = ACTIONS(2876),
    [anon_sym_open] = ACTIONS(2876),
    [anon_sym_transparent] = ACTIONS(2876),
    [anon_sym_LPAREN] = ACTIONS(2882),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(2885),
    [sym_operator_identifier] = ACTIONS(3040),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(2891),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [755] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1642),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(755),
    [sym_block_comment] = STATE(755),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [756] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(982),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(756),
    [sym_block_comment] = STATE(756),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [757] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(906),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(757),
    [sym_block_comment] = STATE(757),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [758] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1699),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(758),
    [sym_block_comment] = STATE(758),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [759] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(977),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(759),
    [sym_block_comment] = STATE(759),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [760] = {
    [sym_inline_modifier] = STATE(2372),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12417),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(760),
    [sym_block_comment] = STATE(760),
    [sym__alpha_identifier] = ACTIONS(3043),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3046),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(3049),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3049),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(3052),
    [anon_sym_infix] = ACTIONS(3049),
    [anon_sym_open] = ACTIONS(3049),
    [anon_sym_transparent] = ACTIONS(3049),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(3058),
    [sym_operator_identifier] = ACTIONS(3061),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(2603),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [761] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(940),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(761),
    [sym_block_comment] = STATE(761),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [762] = {
    [sym_inline_modifier] = STATE(2226),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13098),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(762),
    [sym_block_comment] = STATE(762),
    [sym__alpha_identifier] = ACTIONS(2754),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2757),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(2760),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2760),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(2763),
    [anon_sym_infix] = ACTIONS(2760),
    [anon_sym_open] = ACTIONS(2760),
    [anon_sym_transparent] = ACTIONS(2760),
    [anon_sym_LPAREN] = ACTIONS(2766),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(2769),
    [sym_operator_identifier] = ACTIONS(3064),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(2775),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [763] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1643),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(763),
    [sym_block_comment] = STATE(763),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [764] = {
    [sym_inline_modifier] = STATE(2218),
    [sym_block] = STATE(8958),
    [sym_expression] = STATE(13804),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(764),
    [sym_block_comment] = STATE(764),
    [sym__alpha_identifier] = ACTIONS(3067),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3070),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(3073),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3073),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(3076),
    [anon_sym_infix] = ACTIONS(3073),
    [anon_sym_open] = ACTIONS(3073),
    [anon_sym_transparent] = ACTIONS(3073),
    [anon_sym_LPAREN] = ACTIONS(3079),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(3082),
    [sym_operator_identifier] = ACTIONS(3085),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(2579),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [765] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1658),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(765),
    [sym_block_comment] = STATE(765),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [766] = {
    [sym_inline_modifier] = STATE(2119),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(13967),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(766),
    [sym_block_comment] = STATE(766),
    [sym__alpha_identifier] = ACTIONS(2899),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2902),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(2905),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2905),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(2908),
    [anon_sym_infix] = ACTIONS(2905),
    [anon_sym_open] = ACTIONS(2905),
    [anon_sym_transparent] = ACTIONS(2905),
    [anon_sym_LPAREN] = ACTIONS(2911),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(2914),
    [sym_operator_identifier] = ACTIONS(3088),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [767] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(949),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(767),
    [sym_block_comment] = STATE(767),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [768] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1004),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(768),
    [sym_block_comment] = STATE(768),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [769] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1487),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(769),
    [sym_block_comment] = STATE(769),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [770] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(974),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(770),
    [sym_block_comment] = STATE(770),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [771] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1363),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(771),
    [sym_block_comment] = STATE(771),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [772] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1277),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(772),
    [sym_block_comment] = STATE(772),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [773] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(984),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(773),
    [sym_block_comment] = STATE(773),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [774] = {
    [sym_inline_modifier] = STATE(2133),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12503),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(774),
    [sym_block_comment] = STATE(774),
    [sym__alpha_identifier] = ACTIONS(2711),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2714),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(2717),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2717),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(2722),
    [anon_sym_infix] = ACTIONS(2717),
    [anon_sym_open] = ACTIONS(2717),
    [anon_sym_transparent] = ACTIONS(2717),
    [anon_sym_LPAREN] = ACTIONS(2725),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(2728),
    [sym_operator_identifier] = ACTIONS(3091),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(2734),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [775] = {
    [sym_inline_modifier] = STATE(2395),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(13525),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(775),
    [sym_block_comment] = STATE(775),
    [sym__alpha_identifier] = ACTIONS(3094),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3097),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(3100),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3100),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(3103),
    [anon_sym_infix] = ACTIONS(3100),
    [anon_sym_open] = ACTIONS(3100),
    [anon_sym_transparent] = ACTIONS(3100),
    [anon_sym_LPAREN] = ACTIONS(3106),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(3109),
    [sym_operator_identifier] = ACTIONS(3112),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(3115),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [776] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(880),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(776),
    [sym_block_comment] = STATE(776),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [777] = {
    [sym_inline_modifier] = STATE(2273),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14259),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(777),
    [sym_block_comment] = STATE(777),
    [sym__alpha_identifier] = ACTIONS(2963),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2966),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(2969),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2969),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(3120),
    [anon_sym_infix] = ACTIONS(2969),
    [anon_sym_open] = ACTIONS(2969),
    [anon_sym_transparent] = ACTIONS(2969),
    [anon_sym_LPAREN] = ACTIONS(2975),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(2978),
    [sym_operator_identifier] = ACTIONS(3123),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(2984),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [778] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1021),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(778),
    [sym_block_comment] = STATE(778),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [779] = {
    [sym_inline_modifier] = STATE(2400),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(13572),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(779),
    [sym_block_comment] = STATE(779),
    [sym__alpha_identifier] = ACTIONS(3126),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3129),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(3132),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3132),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(3135),
    [anon_sym_infix] = ACTIONS(3132),
    [anon_sym_open] = ACTIONS(3132),
    [anon_sym_transparent] = ACTIONS(3132),
    [anon_sym_LPAREN] = ACTIONS(3138),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(3141),
    [sym_operator_identifier] = ACTIONS(3144),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(3147),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [780] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14198),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(780),
    [sym_block_comment] = STATE(780),
    [sym__alpha_identifier] = ACTIONS(2832),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(2838),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2838),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2851),
    [anon_sym_infix] = ACTIONS(2838),
    [anon_sym_open] = ACTIONS(2838),
    [anon_sym_transparent] = ACTIONS(2838),
    [anon_sym_LPAREN] = ACTIONS(2854),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(2857),
    [sym_operator_identifier] = ACTIONS(3150),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(2867),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [781] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1016),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(781),
    [sym_block_comment] = STATE(781),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [782] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1025),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(782),
    [sym_block_comment] = STATE(782),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [783] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1638),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(783),
    [sym_block_comment] = STATE(783),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [784] = {
    [sym_inline_modifier] = STATE(2379),
    [sym_block] = STATE(10013),
    [sym_expression] = STATE(14310),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(784),
    [sym_block_comment] = STATE(784),
    [sym__alpha_identifier] = ACTIONS(3153),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3156),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(3159),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3159),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(3162),
    [anon_sym_infix] = ACTIONS(3159),
    [anon_sym_open] = ACTIONS(3159),
    [anon_sym_transparent] = ACTIONS(3159),
    [anon_sym_LPAREN] = ACTIONS(3165),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(3168),
    [sym_operator_identifier] = ACTIONS(3171),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(2734),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [785] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1502),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(785),
    [sym_block_comment] = STATE(785),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [786] = {
    [sym_inline_modifier] = STATE(2352),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13146),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(786),
    [sym_block_comment] = STATE(786),
    [sym__alpha_identifier] = ACTIONS(2627),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2630),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(2633),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2633),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(2699),
    [anon_sym_infix] = ACTIONS(2633),
    [anon_sym_open] = ACTIONS(2633),
    [anon_sym_transparent] = ACTIONS(2633),
    [anon_sym_LPAREN] = ACTIONS(2639),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(2642),
    [sym_operator_identifier] = ACTIONS(3176),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(2648),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [787] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1531),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(787),
    [sym_block_comment] = STATE(787),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [788] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1042),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(788),
    [sym_block_comment] = STATE(788),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [789] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1697),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(789),
    [sym_block_comment] = STATE(789),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [790] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1462),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(790),
    [sym_block_comment] = STATE(790),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [791] = {
    [sym_inline_modifier] = STATE(2360),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13088),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(791),
    [sym_block_comment] = STATE(791),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(1200),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [792] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1065),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(792),
    [sym_block_comment] = STATE(792),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [793] = {
    [sym_inline_modifier] = STATE(2360),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13098),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(793),
    [sym_block_comment] = STATE(793),
    [sym__alpha_identifier] = ACTIONS(2754),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2757),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(2760),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2760),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(2763),
    [anon_sym_infix] = ACTIONS(2760),
    [anon_sym_open] = ACTIONS(2760),
    [anon_sym_transparent] = ACTIONS(2760),
    [anon_sym_LPAREN] = ACTIONS(2766),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(2769),
    [sym_operator_identifier] = ACTIONS(3179),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(2775),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [794] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1078),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(794),
    [sym_block_comment] = STATE(794),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [795] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1234),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(795),
    [sym_block_comment] = STATE(795),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [796] = {
    [sym_inline_modifier] = STATE(2338),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12368),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(796),
    [sym_block_comment] = STATE(796),
    [sym__alpha_identifier] = ACTIONS(2939),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2942),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(2945),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2945),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(2948),
    [anon_sym_infix] = ACTIONS(2945),
    [anon_sym_open] = ACTIONS(2945),
    [anon_sym_transparent] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2951),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(2954),
    [sym_operator_identifier] = ACTIONS(3182),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(2960),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [797] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1540),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(797),
    [sym_block_comment] = STATE(797),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [798] = {
    [sym_inline_modifier] = STATE(2272),
    [sym_block] = STATE(9899),
    [sym_expression] = STATE(14255),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(798),
    [sym_block_comment] = STATE(798),
    [sym__alpha_identifier] = ACTIONS(3185),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3188),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(3191),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3191),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(3194),
    [anon_sym_infix] = ACTIONS(3191),
    [anon_sym_open] = ACTIONS(3191),
    [anon_sym_transparent] = ACTIONS(3191),
    [anon_sym_LPAREN] = ACTIONS(3197),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(3200),
    [sym_operator_identifier] = ACTIONS(3203),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(2960),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [799] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1449),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(799),
    [sym_block_comment] = STATE(799),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [800] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1460),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(800),
    [sym_block_comment] = STATE(800),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [801] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1113),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(801),
    [sym_block_comment] = STATE(801),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [802] = {
    [sym_inline_modifier] = STATE(2155),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(14033),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(802),
    [sym_block_comment] = STATE(802),
    [sym__alpha_identifier] = ACTIONS(2996),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2999),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(3002),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3002),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(3005),
    [anon_sym_infix] = ACTIONS(3002),
    [anon_sym_open] = ACTIONS(3002),
    [anon_sym_transparent] = ACTIONS(3002),
    [anon_sym_LPAREN] = ACTIONS(3008),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(3011),
    [sym_operator_identifier] = ACTIONS(3208),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(3017),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [803] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1127),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(803),
    [sym_block_comment] = STATE(803),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [804] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1338),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(804),
    [sym_block_comment] = STATE(804),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [805] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1058),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(805),
    [sym_block_comment] = STATE(805),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [806] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1301),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(806),
    [sym_block_comment] = STATE(806),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [807] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1158),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(807),
    [sym_block_comment] = STATE(807),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [808] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1167),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(808),
    [sym_block_comment] = STATE(808),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [809] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1585),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(809),
    [sym_block_comment] = STATE(809),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [810] = {
    [sym_inline_modifier] = STATE(2280),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12775),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(810),
    [sym_block_comment] = STATE(810),
    [sym__alpha_identifier] = ACTIONS(2870),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2873),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(2876),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2876),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(2879),
    [anon_sym_infix] = ACTIONS(2876),
    [anon_sym_open] = ACTIONS(2876),
    [anon_sym_transparent] = ACTIONS(2876),
    [anon_sym_LPAREN] = ACTIONS(2882),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(2885),
    [sym_operator_identifier] = ACTIONS(3211),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(2891),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [811] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(919),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(811),
    [sym_block_comment] = STATE(811),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [812] = {
    [sym_inline_modifier] = STATE(2326),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(14499),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(812),
    [sym_block_comment] = STATE(812),
    [sym__alpha_identifier] = ACTIONS(3214),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3217),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(3220),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3220),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(3223),
    [anon_sym_infix] = ACTIONS(3220),
    [anon_sym_open] = ACTIONS(3220),
    [anon_sym_transparent] = ACTIONS(3220),
    [anon_sym_LPAREN] = ACTIONS(3226),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(3229),
    [sym_operator_identifier] = ACTIONS(3232),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(2648),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [813] = {
    [sym_inline_modifier] = STATE(2410),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(13831),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(813),
    [sym_block_comment] = STATE(813),
    [sym__alpha_identifier] = ACTIONS(3235),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3238),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(3241),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3241),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(3244),
    [anon_sym_infix] = ACTIONS(3241),
    [anon_sym_open] = ACTIONS(3241),
    [anon_sym_transparent] = ACTIONS(3241),
    [anon_sym_LPAREN] = ACTIONS(3247),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(3250),
    [sym_operator_identifier] = ACTIONS(3253),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(3256),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [814] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1169),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(814),
    [sym_block_comment] = STATE(814),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [815] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1327),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(815),
    [sym_block_comment] = STATE(815),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [816] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1077),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(816),
    [sym_block_comment] = STATE(816),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [817] = {
    [sym_inline_modifier] = STATE(2186),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13429),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(817),
    [sym_block_comment] = STATE(817),
    [sym__alpha_identifier] = ACTIONS(2808),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2811),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(2814),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2814),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(2817),
    [anon_sym_infix] = ACTIONS(2814),
    [anon_sym_open] = ACTIONS(2814),
    [anon_sym_transparent] = ACTIONS(2814),
    [anon_sym_LPAREN] = ACTIONS(2820),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(2823),
    [sym_operator_identifier] = ACTIONS(3259),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(2829),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [818] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1283),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(818),
    [sym_block_comment] = STATE(818),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [819] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1200),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(819),
    [sym_block_comment] = STATE(819),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [820] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1213),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(820),
    [sym_block_comment] = STATE(820),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [821] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1544),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(821),
    [sym_block_comment] = STATE(821),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [822] = {
    [sym_inline_modifier] = STATE(2208),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(13967),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(822),
    [sym_block_comment] = STATE(822),
    [sym__alpha_identifier] = ACTIONS(2899),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2902),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(2905),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2905),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(2908),
    [anon_sym_infix] = ACTIONS(2905),
    [anon_sym_open] = ACTIONS(2905),
    [anon_sym_transparent] = ACTIONS(2905),
    [anon_sym_LPAREN] = ACTIONS(2911),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(2914),
    [sym_operator_identifier] = ACTIONS(3262),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [823] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1238),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(823),
    [sym_block_comment] = STATE(823),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [824] = {
    [sym_inline_modifier] = STATE(2276),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12417),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(824),
    [sym_block_comment] = STATE(824),
    [sym__alpha_identifier] = ACTIONS(3043),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3046),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(3049),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3049),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(3052),
    [anon_sym_infix] = ACTIONS(3049),
    [anon_sym_open] = ACTIONS(3049),
    [anon_sym_transparent] = ACTIONS(3049),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(3058),
    [sym_operator_identifier] = ACTIONS(3265),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(2603),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [825] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1096),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(825),
    [sym_block_comment] = STATE(825),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [826] = {
    [sym_inline_modifier] = STATE(2244),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14259),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(826),
    [sym_block_comment] = STATE(826),
    [sym__alpha_identifier] = ACTIONS(2963),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2966),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(2969),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2969),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(3120),
    [anon_sym_infix] = ACTIONS(2969),
    [anon_sym_open] = ACTIONS(2969),
    [anon_sym_transparent] = ACTIONS(2969),
    [anon_sym_LPAREN] = ACTIONS(2975),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(2978),
    [sym_operator_identifier] = ACTIONS(3270),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(2984),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [827] = {
    [sym_inline_modifier] = STATE(2289),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(13572),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(827),
    [sym_block_comment] = STATE(827),
    [sym__alpha_identifier] = ACTIONS(3126),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3129),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(3132),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3132),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(3135),
    [anon_sym_infix] = ACTIONS(3132),
    [anon_sym_open] = ACTIONS(3132),
    [anon_sym_transparent] = ACTIONS(3132),
    [anon_sym_LPAREN] = ACTIONS(3138),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(3141),
    [sym_operator_identifier] = ACTIONS(3273),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(3147),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [828] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1252),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(828),
    [sym_block_comment] = STATE(828),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [829] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1473),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(829),
    [sym_block_comment] = STATE(829),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [830] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1407),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(830),
    [sym_block_comment] = STATE(830),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [831] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1279),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(831),
    [sym_block_comment] = STATE(831),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [832] = {
    [sym_inline_modifier] = STATE(2244),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14174),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(832),
    [sym_block_comment] = STATE(832),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(1202),
    [sym__outdent] = ACTIONS(1202),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [833] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1114),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(833),
    [sym_block_comment] = STATE(833),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [834] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1319),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(834),
    [sym_block_comment] = STATE(834),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [835] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1171),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(835),
    [sym_block_comment] = STATE(835),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [836] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1291),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(836),
    [sym_block_comment] = STATE(836),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [837] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1292),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(837),
    [sym_block_comment] = STATE(837),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [838] = {
    [sym_inline_modifier] = STATE(2266),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(12999),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(838),
    [sym_block_comment] = STATE(838),
    [sym__alpha_identifier] = ACTIONS(2781),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2784),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(2787),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2787),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(2790),
    [anon_sym_infix] = ACTIONS(2787),
    [anon_sym_open] = ACTIONS(2787),
    [anon_sym_transparent] = ACTIONS(2787),
    [anon_sym_LPAREN] = ACTIONS(2793),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(2796),
    [sym_operator_identifier] = ACTIONS(3276),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(2802),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [839] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1286),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(839),
    [sym_block_comment] = STATE(839),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [840] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1322),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(840),
    [sym_block_comment] = STATE(840),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [841] = {
    [sym_inline_modifier] = STATE(2215),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13620),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(841),
    [sym_block_comment] = STATE(841),
    [sym__alpha_identifier] = ACTIONS(2651),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2654),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(2657),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2657),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(2670),
    [anon_sym_infix] = ACTIONS(2657),
    [anon_sym_open] = ACTIONS(2657),
    [anon_sym_transparent] = ACTIONS(2657),
    [anon_sym_LPAREN] = ACTIONS(2673),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(2676),
    [sym_operator_identifier] = ACTIONS(3279),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(2686),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [842] = {
    [sym_inline_modifier] = STATE(2361),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12417),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(842),
    [sym_block_comment] = STATE(842),
    [sym__alpha_identifier] = ACTIONS(3043),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3046),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(3049),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3049),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(3052),
    [anon_sym_infix] = ACTIONS(3049),
    [anon_sym_open] = ACTIONS(3049),
    [anon_sym_transparent] = ACTIONS(3049),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(3058),
    [sym_operator_identifier] = ACTIONS(3282),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(2603),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [843] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1255),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(843),
    [sym_block_comment] = STATE(843),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [844] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1330),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(844),
    [sym_block_comment] = STATE(844),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [845] = {
    [sym_inline_modifier] = STATE(2149),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(13831),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(845),
    [sym_block_comment] = STATE(845),
    [sym__alpha_identifier] = ACTIONS(3235),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3238),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(3241),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3241),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(3244),
    [anon_sym_infix] = ACTIONS(3241),
    [anon_sym_open] = ACTIONS(3241),
    [anon_sym_transparent] = ACTIONS(3241),
    [anon_sym_LPAREN] = ACTIONS(3247),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(3250),
    [sym_operator_identifier] = ACTIONS(3285),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(3256),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [846] = {
    [sym_inline_modifier] = STATE(2356),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12368),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(846),
    [sym_block_comment] = STATE(846),
    [sym__alpha_identifier] = ACTIONS(2939),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(2942),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(2945),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(2945),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(2948),
    [anon_sym_infix] = ACTIONS(2945),
    [anon_sym_open] = ACTIONS(2945),
    [anon_sym_transparent] = ACTIONS(2945),
    [anon_sym_LPAREN] = ACTIONS(2951),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(2954),
    [sym_operator_identifier] = ACTIONS(3288),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(2960),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [847] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1131),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(847),
    [sym_block_comment] = STATE(847),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [848] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1438),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(848),
    [sym_block_comment] = STATE(848),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [849] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1361),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(849),
    [sym_block_comment] = STATE(849),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [850] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1356),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(850),
    [sym_block_comment] = STATE(850),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [851] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(858),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(851),
    [sym_block_comment] = STATE(851),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [852] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1399),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(852),
    [sym_block_comment] = STATE(852),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [853] = {
    [sym_inline_modifier] = STATE(2380),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(13525),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(853),
    [sym_block_comment] = STATE(853),
    [sym__alpha_identifier] = ACTIONS(3094),
    [anon_sym_COLON] = ACTIONS(2533),
    [anon_sym_LBRACE] = ACTIONS(3097),
    [anon_sym_DOT] = ACTIONS(2533),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_LBRACK] = ACTIONS(2538),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(3100),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_match] = ACTIONS(2533),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_EQ] = ACTIONS(2533),
    [anon_sym_opaque] = ACTIONS(3100),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(3103),
    [anon_sym_infix] = ACTIONS(3100),
    [anon_sym_open] = ACTIONS(3100),
    [anon_sym_transparent] = ACTIONS(3100),
    [anon_sym_LPAREN] = ACTIONS(3106),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(3109),
    [sym_operator_identifier] = ACTIONS(3291),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(3115),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [854] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1409),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(854),
    [sym_block_comment] = STATE(854),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [855] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1150),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(855),
    [sym_block_comment] = STATE(855),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [856] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(18516),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym__if_condition] = STATE(1486),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(4203),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(856),
    [sym_block_comment] = STATE(856),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(2524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [857] = {
    [sym_inline_modifier] = STATE(2352),
    [sym__indentable_expression] = STATE(13102),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(857),
    [sym_block_comment] = STATE(857),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [858] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(14231),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(858),
    [sym_block_comment] = STATE(858),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [859] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(14013),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(859),
    [sym_block_comment] = STATE(859),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [860] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14102),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(860),
    [sym_block_comment] = STATE(860),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [861] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(13726),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(861),
    [sym_block_comment] = STATE(861),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [862] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(14378),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(862),
    [sym_block_comment] = STATE(862),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [863] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(13756),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(863),
    [sym_block_comment] = STATE(863),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [864] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(13765),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(864),
    [sym_block_comment] = STATE(864),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [865] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(15042),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(865),
    [sym_block_comment] = STATE(865),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [866] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(13785),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(866),
    [sym_block_comment] = STATE(866),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [867] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(14742),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(867),
    [sym_block_comment] = STATE(867),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [868] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17837),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(691),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(868),
    [sym_block_comment] = STATE(868),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [869] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(13737),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(869),
    [sym_block_comment] = STATE(869),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [870] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14097),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(870),
    [sym_block_comment] = STATE(870),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [871] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13214),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(871),
    [sym_block_comment] = STATE(871),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [872] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(15151),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(872),
    [sym_block_comment] = STATE(872),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [873] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(14342),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(873),
    [sym_block_comment] = STATE(873),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [874] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17802),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(748),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(874),
    [sym_block_comment] = STATE(874),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [875] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13216),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(875),
    [sym_block_comment] = STATE(875),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [876] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(14030),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(876),
    [sym_block_comment] = STATE(876),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [877] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(13859),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(877),
    [sym_block_comment] = STATE(877),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [878] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(13923),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(878),
    [sym_block_comment] = STATE(878),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [879] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(13926),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(879),
    [sym_block_comment] = STATE(879),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [880] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(14418),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(880),
    [sym_block_comment] = STATE(880),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [881] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(13980),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(881),
    [sym_block_comment] = STATE(881),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [882] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(14012),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(882),
    [sym_block_comment] = STATE(882),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [883] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17871),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(760),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(883),
    [sym_block_comment] = STATE(883),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [884] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(14056),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(884),
    [sym_block_comment] = STATE(884),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [885] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14094),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(885),
    [sym_block_comment] = STATE(885),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [886] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(14713),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(886),
    [sym_block_comment] = STATE(886),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [887] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(14085),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(887),
    [sym_block_comment] = STATE(887),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [888] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13961),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(888),
    [sym_block_comment] = STATE(888),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [889] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(12673),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(889),
    [sym_block_comment] = STATE(889),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [890] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14087),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(890),
    [sym_block_comment] = STATE(890),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [891] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(14299),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(891),
    [sym_block_comment] = STATE(891),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [892] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(12678),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(892),
    [sym_block_comment] = STATE(892),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [893] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(13786),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(893),
    [sym_block_comment] = STATE(893),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [894] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(14431),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(894),
    [sym_block_comment] = STATE(894),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [895] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13896),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(895),
    [sym_block_comment] = STATE(895),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [896] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(14735),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(896),
    [sym_block_comment] = STATE(896),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [897] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(12680),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(897),
    [sym_block_comment] = STATE(897),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [898] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(14043),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(898),
    [sym_block_comment] = STATE(898),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [899] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(12681),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(899),
    [sym_block_comment] = STATE(899),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [900] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14334),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(900),
    [sym_block_comment] = STATE(900),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [901] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(14738),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(901),
    [sym_block_comment] = STATE(901),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [902] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13880),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(902),
    [sym_block_comment] = STATE(902),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [903] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13852),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(903),
    [sym_block_comment] = STATE(903),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [904] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13843),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(904),
    [sym_block_comment] = STATE(904),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [905] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(14793),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(905),
    [sym_block_comment] = STATE(905),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [906] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(13782),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(906),
    [sym_block_comment] = STATE(906),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [907] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17895),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(775),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(907),
    [sym_block_comment] = STATE(907),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [908] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(13787),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(908),
    [sym_block_comment] = STATE(908),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [909] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(12693),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(909),
    [sym_block_comment] = STATE(909),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [910] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13221),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(910),
    [sym_block_comment] = STATE(910),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [911] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17815),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(743),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(911),
    [sym_block_comment] = STATE(911),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [912] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13733),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(912),
    [sym_block_comment] = STATE(912),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [913] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14089),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(913),
    [sym_block_comment] = STATE(913),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [914] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17745),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(798),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(914),
    [sym_block_comment] = STATE(914),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [915] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(14371),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(915),
    [sym_block_comment] = STATE(915),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [916] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14316),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(916),
    [sym_block_comment] = STATE(916),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [917] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(12727),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(917),
    [sym_block_comment] = STATE(917),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [918] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(16782),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(766),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(918),
    [sym_block_comment] = STATE(918),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [919] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(14379),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(919),
    [sym_block_comment] = STATE(919),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [920] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(14244),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(920),
    [sym_block_comment] = STATE(920),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [921] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(12731),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(921),
    [sym_block_comment] = STATE(921),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [922] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(12734),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(922),
    [sym_block_comment] = STATE(922),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [923] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(13792),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(923),
    [sym_block_comment] = STATE(923),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [924] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14143),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(924),
    [sym_block_comment] = STATE(924),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [925] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(12735),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(925),
    [sym_block_comment] = STATE(925),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [926] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13951),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(926),
    [sym_block_comment] = STATE(926),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [927] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(14751),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(927),
    [sym_block_comment] = STATE(927),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [928] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17878),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(780),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(928),
    [sym_block_comment] = STATE(928),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [929] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14156),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(929),
    [sym_block_comment] = STATE(929),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [930] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13738),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(930),
    [sym_block_comment] = STATE(930),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [931] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13745),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(931),
    [sym_block_comment] = STATE(931),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [932] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(14388),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(932),
    [sym_block_comment] = STATE(932),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [933] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13753),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(933),
    [sym_block_comment] = STATE(933),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [934] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(12765),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(934),
    [sym_block_comment] = STATE(934),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [935] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13755),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(935),
    [sym_block_comment] = STATE(935),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [936] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(15151),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(936),
    [sym_block_comment] = STATE(936),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [937] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(15134),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(937),
    [sym_block_comment] = STATE(937),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [938] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(15131),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(938),
    [sym_block_comment] = STATE(938),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [939] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(14243),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(939),
    [sym_block_comment] = STATE(939),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [940] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(13407),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(940),
    [sym_block_comment] = STATE(940),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [941] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(15128),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(941),
    [sym_block_comment] = STATE(941),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [942] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(15127),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(942),
    [sym_block_comment] = STATE(942),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [943] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(15100),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(943),
    [sym_block_comment] = STATE(943),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [944] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(15079),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(944),
    [sym_block_comment] = STATE(944),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [945] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14154),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(945),
    [sym_block_comment] = STATE(945),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [946] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(14013),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(946),
    [sym_block_comment] = STATE(946),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [947] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17913),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(842),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(947),
    [sym_block_comment] = STATE(947),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [948] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(15038),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(948),
    [sym_block_comment] = STATE(948),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [949] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(13714),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(949),
    [sym_block_comment] = STATE(949),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [950] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(14997),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(950),
    [sym_block_comment] = STATE(950),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [951] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(14952),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(951),
    [sym_block_comment] = STATE(951),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [952] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(12931),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(952),
    [sym_block_comment] = STATE(952),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [953] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17791),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(813),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(953),
    [sym_block_comment] = STATE(953),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [954] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(18494),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(812),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(954),
    [sym_block_comment] = STATE(954),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [955] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(11855),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(955),
    [sym_block_comment] = STATE(955),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [956] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(13226),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(956),
    [sym_block_comment] = STATE(956),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [957] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(11878),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(957),
    [sym_block_comment] = STATE(957),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [958] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17697),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(719),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(958),
    [sym_block_comment] = STATE(958),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [959] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(11881),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(959),
    [sym_block_comment] = STATE(959),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [960] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13766),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(960),
    [sym_block_comment] = STATE(960),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [961] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(13221),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(961),
    [sym_block_comment] = STATE(961),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [962] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14159),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(962),
    [sym_block_comment] = STATE(962),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [963] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(11885),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(963),
    [sym_block_comment] = STATE(963),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [964] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(11890),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(964),
    [sym_block_comment] = STATE(964),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [965] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(13216),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(965),
    [sym_block_comment] = STATE(965),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [966] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(11912),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(966),
    [sym_block_comment] = STATE(966),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [967] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(13214),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(967),
    [sym_block_comment] = STATE(967),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [968] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(13754),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(968),
    [sym_block_comment] = STATE(968),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [969] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(14658),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(969),
    [sym_block_comment] = STATE(969),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [970] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(11920),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(970),
    [sym_block_comment] = STATE(970),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [971] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(11922),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(971),
    [sym_block_comment] = STATE(971),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [972] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(13465),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(972),
    [sym_block_comment] = STATE(972),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [973] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(14635),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(973),
    [sym_block_comment] = STATE(973),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [974] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(14065),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(974),
    [sym_block_comment] = STATE(974),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [975] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(11924),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(975),
    [sym_block_comment] = STATE(975),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [976] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(11927),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(976),
    [sym_block_comment] = STATE(976),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [977] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(14491),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(977),
    [sym_block_comment] = STATE(977),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [978] = {
    [sym_inline_modifier] = STATE(2200),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13710),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(978),
    [sym_block_comment] = STATE(978),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [979] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(14521),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(979),
    [sym_block_comment] = STATE(979),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [980] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(13463),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(980),
    [sym_block_comment] = STATE(980),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [981] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(14030),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(981),
    [sym_block_comment] = STATE(981),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [982] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(14662),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(982),
    [sym_block_comment] = STATE(982),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [983] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(13187),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(983),
    [sym_block_comment] = STATE(983),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [984] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(14067),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(984),
    [sym_block_comment] = STATE(984),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [985] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(13461),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(985),
    [sym_block_comment] = STATE(985),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [986] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(13756),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(986),
    [sym_block_comment] = STATE(986),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [987] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13038),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(987),
    [sym_block_comment] = STATE(987),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [988] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17767),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(713),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(988),
    [sym_block_comment] = STATE(988),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [989] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(13726),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(989),
    [sym_block_comment] = STATE(989),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [990] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(14013),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(990),
    [sym_block_comment] = STATE(990),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [991] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(13737),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(991),
    [sym_block_comment] = STATE(991),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [992] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(13460),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(992),
    [sym_block_comment] = STATE(992),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [993] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(13102),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(993),
    [sym_block_comment] = STATE(993),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [994] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(13095),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(994),
    [sym_block_comment] = STATE(994),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [995] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(13094),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(995),
    [sym_block_comment] = STATE(995),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [996] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(14592),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(996),
    [sym_block_comment] = STATE(996),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [997] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(13075),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(997),
    [sym_block_comment] = STATE(997),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [998] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17655),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(733),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(998),
    [sym_block_comment] = STATE(998),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [999] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(14010),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(999),
    [sym_block_comment] = STATE(999),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1000] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(15134),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1000),
    [sym_block_comment] = STATE(1000),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1001] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(13971),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1001),
    [sym_block_comment] = STATE(1001),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1002] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(12765),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1002),
    [sym_block_comment] = STATE(1002),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1003] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(13859),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1003),
    [sym_block_comment] = STATE(1003),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1004] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(13781),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1004),
    [sym_block_comment] = STATE(1004),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1005] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(14031),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1005),
    [sym_block_comment] = STATE(1005),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1006] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17975),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(744),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1006),
    [sym_block_comment] = STATE(1006),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1007] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(14393),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1007),
    [sym_block_comment] = STATE(1007),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1008] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(13923),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1008),
    [sym_block_comment] = STATE(1008),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1009] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(13048),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1009),
    [sym_block_comment] = STATE(1009),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1010] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(13926),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1010),
    [sym_block_comment] = STATE(1010),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1011] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(13980),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1011),
    [sym_block_comment] = STATE(1011),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1012] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(14012),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1012),
    [sym_block_comment] = STATE(1012),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1013] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(14288),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1013),
    [sym_block_comment] = STATE(1013),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1014] = {
    [sym_inline_modifier] = STATE(2162),
    [sym__indentable_expression] = STATE(13048),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1014),
    [sym_block_comment] = STATE(1014),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1015] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(13650),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1015),
    [sym_block_comment] = STATE(1015),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1016] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(14046),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1016),
    [sym_block_comment] = STATE(1016),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1017] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(14686),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1017),
    [sym_block_comment] = STATE(1017),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1018] = {
    [sym_inline_modifier] = STATE(2162),
    [sym__indentable_expression] = STATE(13075),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1018),
    [sym_block_comment] = STATE(1018),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1019] = {
    [sym_inline_modifier] = STATE(2162),
    [sym__indentable_expression] = STATE(13094),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1019),
    [sym_block_comment] = STATE(1019),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1020] = {
    [sym_inline_modifier] = STATE(2162),
    [sym__indentable_expression] = STATE(13095),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1020),
    [sym_block_comment] = STATE(1020),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1021] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(13728),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1021),
    [sym_block_comment] = STATE(1021),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1022] = {
    [sym_inline_modifier] = STATE(2162),
    [sym__indentable_expression] = STATE(13102),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1022),
    [sym_block_comment] = STATE(1022),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1023] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(15131),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1023),
    [sym_block_comment] = STATE(1023),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1024] = {
    [sym_inline_modifier] = STATE(2162),
    [sym__indentable_expression] = STATE(13187),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1024),
    [sym_block_comment] = STATE(1024),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1025] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(14048),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1025),
    [sym_block_comment] = STATE(1025),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1026] = {
    [sym_inline_modifier] = STATE(2162),
    [sym__indentable_expression] = STATE(13214),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1026),
    [sym_block_comment] = STATE(1026),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1027] = {
    [sym_inline_modifier] = STATE(2162),
    [sym__indentable_expression] = STATE(13216),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1027),
    [sym_block_comment] = STATE(1027),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1028] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13226),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1028),
    [sym_block_comment] = STATE(1028),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1029] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(12860),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1029),
    [sym_block_comment] = STATE(1029),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1030] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17733),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(853),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1030),
    [sym_block_comment] = STATE(1030),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1031] = {
    [sym_inline_modifier] = STATE(2162),
    [sym__indentable_expression] = STATE(13221),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1031),
    [sym_block_comment] = STATE(1031),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1032] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(14786),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1032),
    [sym_block_comment] = STATE(1032),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1033] = {
    [sym_inline_modifier] = STATE(2162),
    [sym__indentable_expression] = STATE(13226),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1033),
    [sym_block_comment] = STATE(1033),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1034] = {
    [sym_inline_modifier] = STATE(2148),
    [sym__indentable_expression] = STATE(12889),
    [sym_block] = STATE(10196),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(14416),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1034),
    [sym_block_comment] = STATE(1034),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [1035] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(15128),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1035),
    [sym_block_comment] = STATE(1035),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1036] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(13770),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1036),
    [sym_block_comment] = STATE(1036),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1037] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17608),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(817),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1037),
    [sym_block_comment] = STATE(1037),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1038] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(13459),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1038),
    [sym_block_comment] = STATE(1038),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [1039] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(15127),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1039),
    [sym_block_comment] = STATE(1039),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1040] = {
    [sym_inline_modifier] = STATE(2148),
    [sym__indentable_expression] = STATE(12938),
    [sym_block] = STATE(10196),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(14416),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1040),
    [sym_block_comment] = STATE(1040),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [1041] = {
    [sym_inline_modifier] = STATE(2148),
    [sym__indentable_expression] = STATE(12939),
    [sym_block] = STATE(10196),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(14416),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1041),
    [sym_block_comment] = STATE(1041),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [1042] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13834),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1042),
    [sym_block_comment] = STATE(1042),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1043] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(13832),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1043),
    [sym_block_comment] = STATE(1043),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1044] = {
    [sym_inline_modifier] = STATE(2148),
    [sym__indentable_expression] = STATE(12945),
    [sym_block] = STATE(10196),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(14416),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1044),
    [sym_block_comment] = STATE(1044),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [1045] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(13847),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1045),
    [sym_block_comment] = STATE(1045),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1046] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(13858),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1046),
    [sym_block_comment] = STATE(1046),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1047] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(12735),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1047),
    [sym_block_comment] = STATE(1047),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1048] = {
    [sym_inline_modifier] = STATE(2148),
    [sym__indentable_expression] = STATE(12941),
    [sym_block] = STATE(10196),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(14416),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1048),
    [sym_block_comment] = STATE(1048),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [1049] = {
    [sym_inline_modifier] = STATE(2148),
    [sym__indentable_expression] = STATE(12905),
    [sym_block] = STATE(10196),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(14416),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1049),
    [sym_block_comment] = STATE(1049),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [1050] = {
    [sym_inline_modifier] = STATE(2148),
    [sym__indentable_expression] = STATE(12895),
    [sym_block] = STATE(10196),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(14416),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1050),
    [sym_block_comment] = STATE(1050),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [1051] = {
    [sym_inline_modifier] = STATE(2148),
    [sym__indentable_expression] = STATE(12892),
    [sym_block] = STATE(10196),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(14416),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1051),
    [sym_block_comment] = STATE(1051),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [1052] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(13451),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1052),
    [sym_block_comment] = STATE(1052),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1053] = {
    [sym_inline_modifier] = STATE(2148),
    [sym__indentable_expression] = STATE(12886),
    [sym_block] = STATE(10196),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(14416),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1053),
    [sym_block_comment] = STATE(1053),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [1054] = {
    [sym_inline_modifier] = STATE(2148),
    [sym__indentable_expression] = STATE(12883),
    [sym_block] = STATE(10196),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(14416),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1054),
    [sym_block_comment] = STATE(1054),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [1055] = {
    [sym_inline_modifier] = STATE(2138),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13710),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1055),
    [sym_block_comment] = STATE(1055),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(1200),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_SEMI] = ACTIONS(1202),
    [anon_sym_else] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1056] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(14030),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1056),
    [sym_block_comment] = STATE(1056),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1057] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(13756),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1057),
    [sym_block_comment] = STATE(1057),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1058] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13918),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1058),
    [sym_block_comment] = STATE(1058),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1059] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(13726),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1059),
    [sym_block_comment] = STATE(1059),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1060] = {
    [sym_inline_modifier] = STATE(2122),
    [sym__indentable_expression] = STATE(12883),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1060),
    [sym_block_comment] = STATE(1060),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1061] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(13737),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1061),
    [sym_block_comment] = STATE(1061),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1062] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(13859),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1062),
    [sym_block_comment] = STATE(1062),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1063] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14091),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1063),
    [sym_block_comment] = STATE(1063),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1064] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(13944),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1064),
    [sym_block_comment] = STATE(1064),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1065] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(14165),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1065),
    [sym_block_comment] = STATE(1065),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1066] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(13923),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1066),
    [sym_block_comment] = STATE(1066),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1067] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(13926),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1067),
    [sym_block_comment] = STATE(1067),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1068] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(13980),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1068),
    [sym_block_comment] = STATE(1068),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1069] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(14012),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1069),
    [sym_block_comment] = STATE(1069),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1070] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17550),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(826),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1070),
    [sym_block_comment] = STATE(1070),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1071] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(14366),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1071),
    [sym_block_comment] = STATE(1071),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1072] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(14522),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1072),
    [sym_block_comment] = STATE(1072),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1073] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(12734),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1073),
    [sym_block_comment] = STATE(1073),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1074] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(11855),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1074),
    [sym_block_comment] = STATE(1074),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1075] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(13881),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1075),
    [sym_block_comment] = STATE(1075),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1076] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10947),
    [sym_expression] = STATE(16186),
    [sym__simple_expression] = STATE(9465),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10947),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10947),
    [sym_call_expression] = STATE(10947),
    [sym_field_expression] = STATE(10947),
    [sym_instance_expression] = STATE(10947),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16917),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11352),
    [sym_tuple_expression] = STATE(10947),
    [sym_parenthesized_expression] = STATE(10947),
    [sym_splice_expression] = STATE(10947),
    [sym_quote_expression] = STATE(10947),
    [sym_identifier] = STATE(9570),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10882),
    [sym__non_null_literal] = STATE(10947),
    [sym_boolean_literal] = STATE(11114),
    [sym_interpolated_string_expression] = STATE(10947),
    [sym_string] = STATE(11114),
    [sym_unit] = STATE(10947),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1076),
    [sym_block_comment] = STATE(1076),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_COLON] = ACTIONS(3310),
    [anon_sym_LBRACE] = ACTIONS(3312),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_EQ_GT] = ACTIONS(912),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(3314),
    [anon_sym_DASH] = ACTIONS(3314),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(3316),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3318),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(3314),
    [anon_sym_TILDE] = ACTIONS(3314),
    [anon_sym_DOLLAR] = ACTIONS(3320),
    [anon_sym_SQUOTE] = ACTIONS(3322),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3324),
    [sym_integer_literal] = ACTIONS(3326),
    [sym_floating_point_literal] = ACTIONS(3328),
    [anon_sym_true] = ACTIONS(3330),
    [anon_sym_false] = ACTIONS(3330),
    [sym_character_literal] = ACTIONS(3328),
    [sym_null_literal] = ACTIONS(3332),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(3334),
    [sym__simple_string] = ACTIONS(3334),
  },
  [1077] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14574),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1077),
    [sym_block_comment] = STATE(1077),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1078] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(14158),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1078),
    [sym_block_comment] = STATE(1078),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1079] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(11878),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1079),
    [sym_block_comment] = STATE(1079),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1080] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(11881),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1080),
    [sym_block_comment] = STATE(1080),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1081] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(13218),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1081),
    [sym_block_comment] = STATE(1081),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1082] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(13822),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1082),
    [sym_block_comment] = STATE(1082),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1083] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17643),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(793),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1083),
    [sym_block_comment] = STATE(1083),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1084] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(13776),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1084),
    [sym_block_comment] = STATE(1084),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1085] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(13846),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1085),
    [sym_block_comment] = STATE(1085),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1086] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(16830),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(777),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1086),
    [sym_block_comment] = STATE(1086),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1087] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(11885),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1087),
    [sym_block_comment] = STATE(1087),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1088] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13187),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1088),
    [sym_block_comment] = STATE(1088),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1089] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(11890),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1089),
    [sym_block_comment] = STATE(1089),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1090] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(11912),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1090),
    [sym_block_comment] = STATE(1090),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1091] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(14332),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1091),
    [sym_block_comment] = STATE(1091),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1092] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(11920),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1092),
    [sym_block_comment] = STATE(1092),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1093] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(11922),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1093),
    [sym_block_comment] = STATE(1093),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1094] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(13783),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1094),
    [sym_block_comment] = STATE(1094),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1095] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(11924),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1095),
    [sym_block_comment] = STATE(1095),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1096] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14506),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1096),
    [sym_block_comment] = STATE(1096),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1097] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(11927),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1097),
    [sym_block_comment] = STATE(1097),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1098] = {
    [sym_inline_modifier] = STATE(2122),
    [sym__indentable_expression] = STATE(12889),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1098),
    [sym_block_comment] = STATE(1098),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1099] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(13522),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1099),
    [sym_block_comment] = STATE(1099),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1100] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13060),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1100),
    [sym_block_comment] = STATE(1100),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1101] = {
    [sym_inline_modifier] = STATE(2122),
    [sym__indentable_expression] = STATE(12938),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1101),
    [sym_block_comment] = STATE(1101),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1102] = {
    [sym_inline_modifier] = STATE(2122),
    [sym__indentable_expression] = STATE(12939),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1102),
    [sym_block_comment] = STATE(1102),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1103] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(14725),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1103),
    [sym_block_comment] = STATE(1103),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1104] = {
    [sym_inline_modifier] = STATE(2122),
    [sym__indentable_expression] = STATE(12945),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1104),
    [sym_block_comment] = STATE(1104),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1105] = {
    [sym_inline_modifier] = STATE(2260),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13445),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1105),
    [sym_block_comment] = STATE(1105),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(1200),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1106] = {
    [sym_inline_modifier] = STATE(2122),
    [sym__indentable_expression] = STATE(12941),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1106),
    [sym_block_comment] = STATE(1106),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1107] = {
    [sym_inline_modifier] = STATE(2122),
    [sym__indentable_expression] = STATE(12905),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1107),
    [sym_block_comment] = STATE(1107),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1108] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17497),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(784),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1108),
    [sym_block_comment] = STATE(1108),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1109] = {
    [sym_inline_modifier] = STATE(2260),
    [sym__indentable_expression] = STATE(14336),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1109),
    [sym_block_comment] = STATE(1109),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1110] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(13770),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1110),
    [sym_block_comment] = STATE(1110),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1111] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(14314),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1111),
    [sym_block_comment] = STATE(1111),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1112] = {
    [sym_inline_modifier] = STATE(2122),
    [sym__indentable_expression] = STATE(12895),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1112),
    [sym_block_comment] = STATE(1112),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1113] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(14466),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1113),
    [sym_block_comment] = STATE(1113),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1114] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(14471),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1114),
    [sym_block_comment] = STATE(1114),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1115] = {
    [sym_inline_modifier] = STATE(2122),
    [sym__indentable_expression] = STATE(12892),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1115),
    [sym_block_comment] = STATE(1115),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1116] = {
    [sym_inline_modifier] = STATE(2122),
    [sym__indentable_expression] = STATE(12886),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1116),
    [sym_block_comment] = STATE(1116),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1117] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(12731),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1117),
    [sym_block_comment] = STATE(1117),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1118] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(13832),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1118),
    [sym_block_comment] = STATE(1118),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1119] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(12727),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1119),
    [sym_block_comment] = STATE(1119),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1120] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(14196),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1120),
    [sym_block_comment] = STATE(1120),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1121] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(13847),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1121),
    [sym_block_comment] = STATE(1121),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1122] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13156),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1122),
    [sym_block_comment] = STATE(1122),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1123] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(13858),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1123),
    [sym_block_comment] = STATE(1123),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1124] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13140),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1124),
    [sym_block_comment] = STATE(1124),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1125] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(12693),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1125),
    [sym_block_comment] = STATE(1125),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1126] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13139),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1126),
    [sym_block_comment] = STATE(1126),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1127] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(14457),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1127),
    [sym_block_comment] = STATE(1127),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1128] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13138),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1128),
    [sym_block_comment] = STATE(1128),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1129] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13132),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1129),
    [sym_block_comment] = STATE(1129),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1130] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13116),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1130),
    [sym_block_comment] = STATE(1130),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1131] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(14494),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1131),
    [sym_block_comment] = STATE(1131),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1132] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13105),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1132),
    [sym_block_comment] = STATE(1132),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1133] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13104),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1133),
    [sym_block_comment] = STATE(1133),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1134] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13103),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1134),
    [sym_block_comment] = STATE(1134),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1135] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(12743),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1135),
    [sym_block_comment] = STATE(1135),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1136] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17658),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(749),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1136),
    [sym_block_comment] = STATE(1136),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1137] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(13430),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1137),
    [sym_block_comment] = STATE(1137),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1138] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13120),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1138),
    [sym_block_comment] = STATE(1138),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1139] = {
    [sym_inline_modifier] = STATE(2104),
    [sym__indentable_expression] = STATE(14207),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1139),
    [sym_block_comment] = STATE(1139),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1140] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14029),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1140),
    [sym_block_comment] = STATE(1140),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1141] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(13944),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1141),
    [sym_block_comment] = STATE(1141),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1142] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17613),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(754),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1142),
    [sym_block_comment] = STATE(1142),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1143] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17444),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(742),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1143),
    [sym_block_comment] = STATE(1143),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1144] = {
    [sym_inline_modifier] = STATE(2104),
    [sym__indentable_expression] = STATE(14229),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1144),
    [sym_block_comment] = STATE(1144),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1145] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(13067),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1145),
    [sym_block_comment] = STATE(1145),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1146] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(12681),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1146),
    [sym_block_comment] = STATE(1146),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1147] = {
    [sym_inline_modifier] = STATE(2104),
    [sym__indentable_expression] = STATE(14221),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1147),
    [sym_block_comment] = STATE(1147),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1148] = {
    [sym_inline_modifier] = STATE(2104),
    [sym__indentable_expression] = STATE(14216),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1148),
    [sym_block_comment] = STATE(1148),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1149] = {
    [sym_inline_modifier] = STATE(2104),
    [sym__indentable_expression] = STATE(14211),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1149),
    [sym_block_comment] = STATE(1149),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1150] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(14285),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1150),
    [sym_block_comment] = STATE(1150),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1151] = {
    [sym_inline_modifier] = STATE(2104),
    [sym__indentable_expression] = STATE(14168),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1151),
    [sym_block_comment] = STATE(1151),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1152] = {
    [sym_inline_modifier] = STATE(2104),
    [sym__indentable_expression] = STATE(14149),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1152),
    [sym_block_comment] = STATE(1152),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1153] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(13881),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1153),
    [sym_block_comment] = STATE(1153),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1154] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(14723),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1154),
    [sym_block_comment] = STATE(1154),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1155] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(13822),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1155),
    [sym_block_comment] = STATE(1155),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1156] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(13776),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1156),
    [sym_block_comment] = STATE(1156),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1157] = {
    [sym_inline_modifier] = STATE(2104),
    [sym__indentable_expression] = STATE(14141),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1157),
    [sym_block_comment] = STATE(1157),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1158] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(13879),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1158),
    [sym_block_comment] = STATE(1158),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1159] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(13846),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1159),
    [sym_block_comment] = STATE(1159),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1160] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(13427),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1160),
    [sym_block_comment] = STATE(1160),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1161] = {
    [sym_inline_modifier] = STATE(2104),
    [sym__indentable_expression] = STATE(14135),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1161),
    [sym_block_comment] = STATE(1161),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1162] = {
    [sym_inline_modifier] = STATE(2104),
    [sym__indentable_expression] = STATE(14116),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1162),
    [sym_block_comment] = STATE(1162),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1163] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(14410),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1163),
    [sym_block_comment] = STATE(1163),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1164] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(14313),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1164),
    [sym_block_comment] = STATE(1164),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1165] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(14312),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1165),
    [sym_block_comment] = STATE(1165),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1166] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(14415),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1166),
    [sym_block_comment] = STATE(1166),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1167] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(14284),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1167),
    [sym_block_comment] = STATE(1167),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1168] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(14311),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1168),
    [sym_block_comment] = STATE(1168),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1169] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(13780),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1169),
    [sym_block_comment] = STATE(1169),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1170] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(14356),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1170),
    [sym_block_comment] = STATE(1170),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1171] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(14169),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1171),
    [sym_block_comment] = STATE(1171),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1172] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13541),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1172),
    [sym_block_comment] = STATE(1172),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1173] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17621),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(714),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1173),
    [sym_block_comment] = STATE(1173),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1174] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(14373),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1174),
    [sym_block_comment] = STATE(1174),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1175] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(14404),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1175),
    [sym_block_comment] = STATE(1175),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1176] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(13425),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1176),
    [sym_block_comment] = STATE(1176),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1177] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(13783),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1177),
    [sym_block_comment] = STATE(1177),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1178] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(14395),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1178),
    [sym_block_comment] = STATE(1178),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1179] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(14419),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1179),
    [sym_block_comment] = STATE(1179),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1180] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(14385),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1180),
    [sym_block_comment] = STATE(1180),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1181] = {
    [sym_inline_modifier] = STATE(2127),
    [sym__indentable_expression] = STATE(14391),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1181),
    [sym_block_comment] = STATE(1181),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1182] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14087),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1182),
    [sym_block_comment] = STATE(1182),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1183] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17401),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(715),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1183),
    [sym_block_comment] = STATE(1183),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1184] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(12967),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1184),
    [sym_block_comment] = STATE(1184),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1185] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(14420),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1185),
    [sym_block_comment] = STATE(1185),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1186] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(14429),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1186),
    [sym_block_comment] = STATE(1186),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1187] = {
    [sym_inline_modifier] = STATE(2301),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13445),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1187),
    [sym_block_comment] = STATE(1187),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_catch] = ACTIONS(1200),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1188] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14091),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1188),
    [sym_block_comment] = STATE(1188),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1189] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14341),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1189),
    [sym_block_comment] = STATE(1189),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1190] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14094),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1190),
    [sym_block_comment] = STATE(1190),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1191] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(13424),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1191),
    [sym_block_comment] = STATE(1191),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1192] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14097),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1192),
    [sym_block_comment] = STATE(1192),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1193] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(12673),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1193),
    [sym_block_comment] = STATE(1193),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1194] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14102),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1194),
    [sym_block_comment] = STATE(1194),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1195] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14089),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1195),
    [sym_block_comment] = STATE(1195),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1196] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14143),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1196),
    [sym_block_comment] = STATE(1196),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1197] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14156),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1197),
    [sym_block_comment] = STATE(1197),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1198] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14154),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1198),
    [sym_block_comment] = STATE(1198),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1199] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14159),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1199),
    [sym_block_comment] = STATE(1199),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1200] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(13514),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1200),
    [sym_block_comment] = STATE(1200),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1201] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(12678),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1201),
    [sym_block_comment] = STATE(1201),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1202] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(13048),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1202),
    [sym_block_comment] = STATE(1202),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1203] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13156),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1203),
    [sym_block_comment] = STATE(1203),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1204] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(12680),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1204),
    [sym_block_comment] = STATE(1204),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1205] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(14686),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1205),
    [sym_block_comment] = STATE(1205),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1206] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(14728),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1206),
    [sym_block_comment] = STATE(1206),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1207] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(12681),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1207),
    [sym_block_comment] = STATE(1207),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1208] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(14852),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1208),
    [sym_block_comment] = STATE(1208),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1209] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(12680),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1209),
    [sym_block_comment] = STATE(1209),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1210] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14340),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1210),
    [sym_block_comment] = STATE(1210),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1211] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(12678),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1211),
    [sym_block_comment] = STATE(1211),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1212] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13140),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1212),
    [sym_block_comment] = STATE(1212),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1213] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(13517),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1213),
    [sym_block_comment] = STATE(1213),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1214] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(14339),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1214),
    [sym_block_comment] = STATE(1214),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1215] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13139),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1215),
    [sym_block_comment] = STATE(1215),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1216] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13027),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1216),
    [sym_block_comment] = STATE(1216),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1217] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17573),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(707),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1217),
    [sym_block_comment] = STATE(1217),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1218] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13138),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1218),
    [sym_block_comment] = STATE(1218),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1219] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13132),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1219),
    [sym_block_comment] = STATE(1219),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1220] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13116),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1220),
    [sym_block_comment] = STATE(1220),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1221] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(12693),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1221),
    [sym_block_comment] = STATE(1221),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1222] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13105),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1222),
    [sym_block_comment] = STATE(1222),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1223] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13104),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1223),
    [sym_block_comment] = STATE(1223),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1224] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13103),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1224),
    [sym_block_comment] = STATE(1224),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1225] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(12673),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1225),
    [sym_block_comment] = STATE(1225),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1226] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17353),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(692),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1226),
    [sym_block_comment] = STATE(1226),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1227] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13454),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1227),
    [sym_block_comment] = STATE(1227),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1228] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(13418),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1228),
    [sym_block_comment] = STATE(1228),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1229] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13120),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1229),
    [sym_block_comment] = STATE(1229),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1230] = {
    [sym_inline_modifier] = STATE(2119),
    [sym__indentable_expression] = STATE(14135),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1230),
    [sym_block_comment] = STATE(1230),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1231] = {
    [sym_inline_modifier] = STATE(2119),
    [sym__indentable_expression] = STATE(14207),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1231),
    [sym_block_comment] = STATE(1231),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1232] = {
    [sym_inline_modifier] = STATE(2119),
    [sym__indentable_expression] = STATE(14229),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1232),
    [sym_block_comment] = STATE(1232),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1233] = {
    [sym_inline_modifier] = STATE(2119),
    [sym__indentable_expression] = STATE(14221),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1233),
    [sym_block_comment] = STATE(1233),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1234] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(14302),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1234),
    [sym_block_comment] = STATE(1234),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1235] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(11855),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1235),
    [sym_block_comment] = STATE(1235),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1236] = {
    [sym_inline_modifier] = STATE(2119),
    [sym__indentable_expression] = STATE(14216),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1236),
    [sym_block_comment] = STATE(1236),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1237] = {
    [sym_inline_modifier] = STATE(2119),
    [sym__indentable_expression] = STATE(14211),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1237),
    [sym_block_comment] = STATE(1237),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1238] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(14246),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1238),
    [sym_block_comment] = STATE(1238),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1239] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(12727),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1239),
    [sym_block_comment] = STATE(1239),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1240] = {
    [sym_inline_modifier] = STATE(2119),
    [sym__indentable_expression] = STATE(14168),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1240),
    [sym_block_comment] = STATE(1240),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1241] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(13465),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1241),
    [sym_block_comment] = STATE(1241),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1242] = {
    [sym_inline_modifier] = STATE(2119),
    [sym__indentable_expression] = STATE(14149),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1242),
    [sym_block_comment] = STATE(1242),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1243] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(12731),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1243),
    [sym_block_comment] = STATE(1243),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1244] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(12734),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1244),
    [sym_block_comment] = STATE(1244),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1245] = {
    [sym_inline_modifier] = STATE(2119),
    [sym__indentable_expression] = STATE(14141),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1245),
    [sym_block_comment] = STATE(1245),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1246] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(12333),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1246),
    [sym_block_comment] = STATE(1246),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1247] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(12735),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1247),
    [sym_block_comment] = STATE(1247),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1248] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(15100),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1248),
    [sym_block_comment] = STATE(1248),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1249] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(14725),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1249),
    [sym_block_comment] = STATE(1249),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1250] = {
    [sym_inline_modifier] = STATE(2119),
    [sym__indentable_expression] = STATE(14116),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1250),
    [sym_block_comment] = STATE(1250),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1251] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(16879),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(786),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1251),
    [sym_block_comment] = STATE(1251),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1252] = {
    [sym_inline_modifier] = STATE(2174),
    [sym__indentable_expression] = STATE(14247),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1252),
    [sym_block_comment] = STATE(1252),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1253] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(14723),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1253),
    [sym_block_comment] = STATE(1253),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1254] = {
    [sym_inline_modifier] = STATE(2273),
    [sym__indentable_expression] = STATE(14410),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1254),
    [sym_block_comment] = STATE(1254),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1255] = {
    [sym_inline_modifier] = STATE(2133),
    [sym__indentable_expression] = STATE(14303),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1255),
    [sym_block_comment] = STATE(1255),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1256] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(12994),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1256),
    [sym_block_comment] = STATE(1256),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1257] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17498),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(802),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1257),
    [sym_block_comment] = STATE(1257),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1258] = {
    [sym_inline_modifier] = STATE(2273),
    [sym__indentable_expression] = STATE(14313),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1258),
    [sym_block_comment] = STATE(1258),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1259] = {
    [sym_inline_modifier] = STATE(2273),
    [sym__indentable_expression] = STATE(14312),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1259),
    [sym_block_comment] = STATE(1259),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1260] = {
    [sym_inline_modifier] = STATE(2273),
    [sym__indentable_expression] = STATE(14311),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1260),
    [sym_block_comment] = STATE(1260),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1261] = {
    [sym_inline_modifier] = STATE(2273),
    [sym__indentable_expression] = STATE(14356),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1261),
    [sym_block_comment] = STATE(1261),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1262] = {
    [sym_inline_modifier] = STATE(2273),
    [sym__indentable_expression] = STATE(14373),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1262),
    [sym_block_comment] = STATE(1262),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1263] = {
    [sym_inline_modifier] = STATE(2273),
    [sym__indentable_expression] = STATE(14404),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1263),
    [sym_block_comment] = STATE(1263),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1264] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(12765),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1264),
    [sym_block_comment] = STATE(1264),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1265] = {
    [sym_inline_modifier] = STATE(2273),
    [sym__indentable_expression] = STATE(14395),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1265),
    [sym_block_comment] = STATE(1265),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1266] = {
    [sym_inline_modifier] = STATE(2273),
    [sym__indentable_expression] = STATE(14385),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1266),
    [sym_block_comment] = STATE(1266),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1267] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(13075),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1267),
    [sym_block_comment] = STATE(1267),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1268] = {
    [sym_inline_modifier] = STATE(2273),
    [sym__indentable_expression] = STATE(14391),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1268),
    [sym_block_comment] = STATE(1268),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1269] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17308),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(774),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1269),
    [sym_block_comment] = STATE(1269),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1270] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(13577),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1270),
    [sym_block_comment] = STATE(1270),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [1271] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13586),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1271),
    [sym_block_comment] = STATE(1271),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1272] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(13094),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1272),
    [sym_block_comment] = STATE(1272),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1273] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(11878),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1273),
    [sym_block_comment] = STATE(1273),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1274] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(13095),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1274),
    [sym_block_comment] = STATE(1274),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1275] = {
    [sym_inline_modifier] = STATE(2352),
    [sym__indentable_expression] = STATE(13048),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1275),
    [sym_block_comment] = STATE(1275),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1276] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(11881),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1276),
    [sym_block_comment] = STATE(1276),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1277] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(14376),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1277),
    [sym_block_comment] = STATE(1277),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1278] = {
    [sym_inline_modifier] = STATE(2352),
    [sym__indentable_expression] = STATE(13075),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1278),
    [sym_block_comment] = STATE(1278),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1279] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14326),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1279),
    [sym_block_comment] = STATE(1279),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1280] = {
    [sym_inline_modifier] = STATE(2352),
    [sym__indentable_expression] = STATE(13094),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1280),
    [sym_block_comment] = STATE(1280),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1281] = {
    [sym_inline_modifier] = STATE(2352),
    [sym__indentable_expression] = STATE(13095),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1281),
    [sym_block_comment] = STATE(1281),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1282] = {
    [sym_inline_modifier] = STATE(2352),
    [sym__indentable_expression] = STATE(13187),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1282),
    [sym_block_comment] = STATE(1282),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1283] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(13594),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1283),
    [sym_block_comment] = STATE(1283),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1284] = {
    [sym_inline_modifier] = STATE(2352),
    [sym__indentable_expression] = STATE(13214),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1284),
    [sym_block_comment] = STATE(1284),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1285] = {
    [sym_inline_modifier] = STATE(2352),
    [sym__indentable_expression] = STATE(13216),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1285),
    [sym_block_comment] = STATE(1285),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1286] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(14321),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1286),
    [sym_block_comment] = STATE(1286),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1287] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(13463),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1287),
    [sym_block_comment] = STATE(1287),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1288] = {
    [sym_inline_modifier] = STATE(2352),
    [sym__indentable_expression] = STATE(13221),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1288),
    [sym_block_comment] = STATE(1288),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1289] = {
    [sym_inline_modifier] = STATE(2352),
    [sym__indentable_expression] = STATE(13226),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1289),
    [sym_block_comment] = STATE(1289),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1290] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(13102),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1290),
    [sym_block_comment] = STATE(1290),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1291] = {
    [sym_inline_modifier] = STATE(2155),
    [sym__indentable_expression] = STATE(14323),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1291),
    [sym_block_comment] = STATE(1291),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1292] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(14503),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1292),
    [sym_block_comment] = STATE(1292),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1293] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(14728),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1293),
    [sym_block_comment] = STATE(1293),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1294] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(14852),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1294),
    [sym_block_comment] = STATE(1294),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1295] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12294),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1295),
    [sym_block_comment] = STATE(1295),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1296] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(13819),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1296),
    [sym_block_comment] = STATE(1296),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1297] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17460),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(710),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1297),
    [sym_block_comment] = STATE(1297),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1298] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(14374),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1298),
    [sym_block_comment] = STATE(1298),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1299] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14391),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1299),
    [sym_block_comment] = STATE(1299),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1300] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12340),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1300),
    [sym_block_comment] = STATE(1300),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1301] = {
    [sym_inline_modifier] = STATE(2215),
    [sym__indentable_expression] = STATE(14421),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1301),
    [sym_block_comment] = STATE(1301),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1302] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12302),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1302),
    [sym_block_comment] = STATE(1302),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1303] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14385),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1303),
    [sym_block_comment] = STATE(1303),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1304] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12296),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1304),
    [sym_block_comment] = STATE(1304),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1305] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14395),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1305),
    [sym_block_comment] = STATE(1305),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1306] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12290),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1306),
    [sym_block_comment] = STATE(1306),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1307] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12247),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1307),
    [sym_block_comment] = STATE(1307),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1308] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14404),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1308),
    [sym_block_comment] = STATE(1308),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1309] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(13108),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1309),
    [sym_block_comment] = STATE(1309),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1310] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12210),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1310),
    [sym_block_comment] = STATE(1310),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1311] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12203),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1311),
    [sym_block_comment] = STATE(1311),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1312] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12201),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1312),
    [sym_block_comment] = STATE(1312),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1313] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17262),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(841),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1313),
    [sym_block_comment] = STATE(1313),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1314] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13824),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1314),
    [sym_block_comment] = STATE(1314),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1315] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(13461),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1315),
    [sym_block_comment] = STATE(1315),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1316] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14373),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1316),
    [sym_block_comment] = STATE(1316),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1317] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(12179),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1317),
    [sym_block_comment] = STATE(1317),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1318] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(14852),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1318),
    [sym_block_comment] = STATE(1318),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1319] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(14001),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1319),
    [sym_block_comment] = STATE(1319),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1320] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(13156),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1320),
    [sym_block_comment] = STATE(1320),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1321] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(16709),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(746),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1321),
    [sym_block_comment] = STATE(1321),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1322] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(14480),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1322),
    [sym_block_comment] = STATE(1322),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1323] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(13460),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1323),
    [sym_block_comment] = STATE(1323),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1324] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(11885),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1324),
    [sym_block_comment] = STATE(1324),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1325] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(13140),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1325),
    [sym_block_comment] = STATE(1325),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1326] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(14728),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1326),
    [sym_block_comment] = STATE(1326),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1327] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(13593),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1327),
    [sym_block_comment] = STATE(1327),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1328] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(13139),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1328),
    [sym_block_comment] = STATE(1328),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1329] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(13138),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1329),
    [sym_block_comment] = STATE(1329),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1330] = {
    [sym_inline_modifier] = STATE(2168),
    [sym__indentable_expression] = STATE(14483),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1330),
    [sym_block_comment] = STATE(1330),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1331] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(13132),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1331),
    [sym_block_comment] = STATE(1331),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1332] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(13116),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1332),
    [sym_block_comment] = STATE(1332),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1333] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(13105),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1333),
    [sym_block_comment] = STATE(1333),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1334] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(13194),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1334),
    [sym_block_comment] = STATE(1334),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1335] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17409),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(762),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1335),
    [sym_block_comment] = STATE(1335),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1336] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(13104),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1336),
    [sym_block_comment] = STATE(1336),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1337] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14356),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1337),
    [sym_block_comment] = STATE(1337),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1338] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13826),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1338),
    [sym_block_comment] = STATE(1338),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1339] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(13103),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1339),
    [sym_block_comment] = STATE(1339),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1340] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14311),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1340),
    [sym_block_comment] = STATE(1340),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1341] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14312),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1341),
    [sym_block_comment] = STATE(1341),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1342] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(13120),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1342),
    [sym_block_comment] = STATE(1342),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1343] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(11890),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1343),
    [sym_block_comment] = STATE(1343),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1344] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14313),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1344),
    [sym_block_comment] = STATE(1344),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1345] = {
    [sym_inline_modifier] = STATE(2208),
    [sym__indentable_expression] = STATE(14207),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1345),
    [sym_block_comment] = STATE(1345),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1346] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(11912),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1346),
    [sym_block_comment] = STATE(1346),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1347] = {
    [sym_inline_modifier] = STATE(2208),
    [sym__indentable_expression] = STATE(14229),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1347),
    [sym_block_comment] = STATE(1347),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1348] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(13451),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1348),
    [sym_block_comment] = STATE(1348),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1349] = {
    [sym_inline_modifier] = STATE(2208),
    [sym__indentable_expression] = STATE(14221),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1349),
    [sym_block_comment] = STATE(1349),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1350] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14410),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1350),
    [sym_block_comment] = STATE(1350),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1351] = {
    [sym_inline_modifier] = STATE(2208),
    [sym__indentable_expression] = STATE(14216),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1351),
    [sym_block_comment] = STATE(1351),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1352] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17208),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(827),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1352),
    [sym_block_comment] = STATE(1352),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1353] = {
    [sym_inline_modifier] = STATE(2338),
    [sym__indentable_expression] = STATE(13028),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1353),
    [sym_block_comment] = STATE(1353),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1354] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(11920),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1354),
    [sym_block_comment] = STATE(1354),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1355] = {
    [sym_inline_modifier] = STATE(2208),
    [sym__indentable_expression] = STATE(14211),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1355),
    [sym_block_comment] = STATE(1355),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1356] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14346),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1356),
    [sym_block_comment] = STATE(1356),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1357] = {
    [sym_inline_modifier] = STATE(2208),
    [sym__indentable_expression] = STATE(14168),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1357),
    [sym_block_comment] = STATE(1357),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1358] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(12460),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1358),
    [sym_block_comment] = STATE(1358),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1359] = {
    [sym_inline_modifier] = STATE(2208),
    [sym__indentable_expression] = STATE(14149),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1359),
    [sym_block_comment] = STATE(1359),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1360] = {
    [sym_inline_modifier] = STATE(2208),
    [sym__indentable_expression] = STATE(14141),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1360),
    [sym_block_comment] = STATE(1360),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1361] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(14164),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1361),
    [sym_block_comment] = STATE(1361),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1362] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13102),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1362),
    [sym_block_comment] = STATE(1362),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1363] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(14235),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1363),
    [sym_block_comment] = STATE(1363),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [1364] = {
    [sym_inline_modifier] = STATE(2208),
    [sym__indentable_expression] = STATE(14135),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1364),
    [sym_block_comment] = STATE(1364),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1365] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(12400),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1365),
    [sym_block_comment] = STATE(1365),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1366] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(11922),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1366),
    [sym_block_comment] = STATE(1366),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1367] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(14725),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1367),
    [sym_block_comment] = STATE(1367),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1368] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(12399),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1368),
    [sym_block_comment] = STATE(1368),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1369] = {
    [sym_inline_modifier] = STATE(2208),
    [sym__indentable_expression] = STATE(14116),
    [sym_block] = STATE(9084),
    [sym_indented_block] = STATE(14252),
    [sym_indented_cases] = STATE(14252),
    [sym_expression] = STATE(13771),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1369),
    [sym_block_comment] = STATE(1369),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2182),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1370] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(11924),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1370),
    [sym_block_comment] = STATE(1370),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1371] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(12398),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1371),
    [sym_block_comment] = STATE(1371),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1372] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(13497),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1372),
    [sym_block_comment] = STATE(1372),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1373] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(12387),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1373),
    [sym_block_comment] = STATE(1373),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1374] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13095),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1374),
    [sym_block_comment] = STATE(1374),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1375] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(12639),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1375),
    [sym_block_comment] = STATE(1375),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1376] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17368),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(824),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1376),
    [sym_block_comment] = STATE(1376),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1377] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(12308),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1377),
    [sym_block_comment] = STATE(1377),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1378] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(12306),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1378),
    [sym_block_comment] = STATE(1378),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1379] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(13187),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1379),
    [sym_block_comment] = STATE(1379),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1380] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(12305),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1380),
    [sym_block_comment] = STATE(1380),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1381] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13654),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1381),
    [sym_block_comment] = STATE(1381),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1382] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(14186),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1382),
    [sym_block_comment] = STATE(1382),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [1383] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(11927),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1383),
    [sym_block_comment] = STATE(1383),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1384] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13770),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1384),
    [sym_block_comment] = STATE(1384),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1385] = {
    [sym_inline_modifier] = STATE(2361),
    [sym__indentable_expression] = STATE(12257),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1385),
    [sym_block_comment] = STATE(1385),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1386] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13832),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1386),
    [sym_block_comment] = STATE(1386),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1387] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13670),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1387),
    [sym_block_comment] = STATE(1387),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1388] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13669),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1388),
    [sym_block_comment] = STATE(1388),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1389] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13847),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1389),
    [sym_block_comment] = STATE(1389),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1390] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(14635),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1390),
    [sym_block_comment] = STATE(1390),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1391] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13858),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1391),
    [sym_block_comment] = STATE(1391),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1392] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(13430),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1392),
    [sym_block_comment] = STATE(1392),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1393] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13667),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1393),
    [sym_block_comment] = STATE(1393),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1394] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17161),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(764),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1394),
    [sym_block_comment] = STATE(1394),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1395] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14024),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1395),
    [sym_block_comment] = STATE(1395),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1396] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(13427),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1396),
    [sym_block_comment] = STATE(1396),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1397] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13715),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1397),
    [sym_block_comment] = STATE(1397),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1398] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(12305),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1398),
    [sym_block_comment] = STATE(1398),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1399] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(14088),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1399),
    [sym_block_comment] = STATE(1399),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1400] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(13811),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1400),
    [sym_block_comment] = STATE(1400),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1401] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(13829),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1401),
    [sym_block_comment] = STATE(1401),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1402] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(13844),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1402),
    [sym_block_comment] = STATE(1402),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1403] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13094),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1403),
    [sym_block_comment] = STATE(1403),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1404] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(14691),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1404),
    [sym_block_comment] = STATE(1404),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1405] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(13425),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1405),
    [sym_block_comment] = STATE(1405),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1406] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13944),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1406),
    [sym_block_comment] = STATE(1406),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1407] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14330),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1407),
    [sym_block_comment] = STATE(1407),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1408] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(13848),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1408),
    [sym_block_comment] = STATE(1408),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1409] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(14061),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1409),
    [sym_block_comment] = STATE(1409),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1410] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(13872),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1410),
    [sym_block_comment] = STATE(1410),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1411] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13668),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1411),
    [sym_block_comment] = STATE(1411),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1412] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(12555),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1412),
    [sym_block_comment] = STATE(1412),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1413] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17328),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(723),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1413),
    [sym_block_comment] = STATE(1413),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1414] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(13974),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1414),
    [sym_block_comment] = STATE(1414),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1415] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(13988),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1415),
    [sym_block_comment] = STATE(1415),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1416] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(13990),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1416),
    [sym_block_comment] = STATE(1416),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1417] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(13992),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1417),
    [sym_block_comment] = STATE(1417),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1418] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13632),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1418),
    [sym_block_comment] = STATE(1418),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1419] = {
    [sym_inline_modifier] = STATE(2200),
    [sym__indentable_expression] = STATE(14697),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1419),
    [sym_block_comment] = STATE(1419),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1420] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13631),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1420),
    [sym_block_comment] = STATE(1420),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1421] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13624),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1421),
    [sym_block_comment] = STATE(1421),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1422] = {
    [sym_inline_modifier] = STATE(2395),
    [sym__indentable_expression] = STATE(13940),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1422),
    [sym_block_comment] = STATE(1422),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1423] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13612),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1423),
    [sym_block_comment] = STATE(1423),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1424] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13881),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1424),
    [sym_block_comment] = STATE(1424),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1425] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(12460),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1425),
    [sym_block_comment] = STATE(1425),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1426] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13822),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1426),
    [sym_block_comment] = STATE(1426),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1427] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13776),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1427),
    [sym_block_comment] = STATE(1427),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1428] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13846),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1428),
    [sym_block_comment] = STATE(1428),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1429] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(12400),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1429),
    [sym_block_comment] = STATE(1429),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1430] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(13424),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1430),
    [sym_block_comment] = STATE(1430),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1431] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(13072),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1431),
    [sym_block_comment] = STATE(1431),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1432] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13783),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1432),
    [sym_block_comment] = STATE(1432),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1433] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(12399),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1433),
    [sym_block_comment] = STATE(1433),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1434] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17114),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(709),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1434),
    [sym_block_comment] = STATE(1434),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1435] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(12990),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1435),
    [sym_block_comment] = STATE(1435),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1436] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(16740),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(735),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1436),
    [sym_block_comment] = STATE(1436),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1437] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(12398),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1437),
    [sym_block_comment] = STATE(1437),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1438] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(14148),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1438),
    [sym_block_comment] = STATE(1438),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1439] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13075),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1439),
    [sym_block_comment] = STATE(1439),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1440] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(14635),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1440),
    [sym_block_comment] = STATE(1440),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1441] = {
    [sym_inline_modifier] = STATE(2149),
    [sym__indentable_expression] = STATE(14250),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1441),
    [sym_block_comment] = STATE(1441),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1442] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(16931),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(796),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1442),
    [sym_block_comment] = STATE(1442),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1443] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(12387),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1443),
    [sym_block_comment] = STATE(1443),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1444] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(12333),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1444),
    [sym_block_comment] = STATE(1444),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1445] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(14314),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1445),
    [sym_block_comment] = STATE(1445),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1446] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(14129),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1446),
    [sym_block_comment] = STATE(1446),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1447] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(12308),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1447),
    [sym_block_comment] = STATE(1447),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1448] = {
    [sym_inline_modifier] = STATE(2149),
    [sym__indentable_expression] = STATE(14177),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1448),
    [sym_block_comment] = STATE(1448),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1449] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(14120),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1449),
    [sym_block_comment] = STATE(1449),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1450] = {
    [sym_inline_modifier] = STATE(2149),
    [sym__indentable_expression] = STATE(14213),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1450),
    [sym_block_comment] = STATE(1450),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1451] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(12965),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1451),
    [sym_block_comment] = STATE(1451),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1452] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17258),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(846),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1452),
    [sym_block_comment] = STATE(1452),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1453] = {
    [sym_inline_modifier] = STATE(2149),
    [sym__indentable_expression] = STATE(14236),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1453),
    [sym_block_comment] = STATE(1453),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1454] = {
    [sym_inline_modifier] = STATE(2218),
    [sym__indentable_expression] = STATE(13581),
    [sym_block] = STATE(8958),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(13954),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1454),
    [sym_block_comment] = STATE(1454),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [1455] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(12306),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1455),
    [sym_block_comment] = STATE(1455),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1456] = {
    [sym_inline_modifier] = STATE(2149),
    [sym__indentable_expression] = STATE(14188),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1456),
    [sym_block_comment] = STATE(1456),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1457] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(12305),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1457),
    [sym_block_comment] = STATE(1457),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1458] = {
    [sym_inline_modifier] = STATE(2372),
    [sym__indentable_expression] = STATE(12257),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1458),
    [sym_block_comment] = STATE(1458),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1459] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(14374),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1459),
    [sym_block_comment] = STATE(1459),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1460] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14305),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1460),
    [sym_block_comment] = STATE(1460),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1461] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(14723),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1461),
    [sym_block_comment] = STATE(1461),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1462] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(14269),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1462),
    [sym_block_comment] = STATE(1462),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1463] = {
    [sym_inline_modifier] = STATE(2149),
    [sym__indentable_expression] = STATE(14200),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1463),
    [sym_block_comment] = STATE(1463),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1464] = {
    [sym_inline_modifier] = STATE(2373),
    [sym__indentable_expression] = STATE(12883),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1464),
    [sym_block_comment] = STATE(1464),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1465] = {
    [sym_inline_modifier] = STATE(2373),
    [sym__indentable_expression] = STATE(12886),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1465),
    [sym_block_comment] = STATE(1465),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1466] = {
    [sym_inline_modifier] = STATE(2373),
    [sym__indentable_expression] = STATE(12892),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1466),
    [sym_block_comment] = STATE(1466),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1467] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(12179),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1467),
    [sym_block_comment] = STATE(1467),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1468] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(12201),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1468),
    [sym_block_comment] = STATE(1468),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1469] = {
    [sym_inline_modifier] = STATE(2373),
    [sym__indentable_expression] = STATE(12895),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1469),
    [sym_block_comment] = STATE(1469),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1470] = {
    [sym_inline_modifier] = STATE(2149),
    [sym__indentable_expression] = STATE(14208),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1470),
    [sym_block_comment] = STATE(1470),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1471] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(12203),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1471),
    [sym_block_comment] = STATE(1471),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1472] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(14332),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1472),
    [sym_block_comment] = STATE(1472),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1473] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(13713),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1473),
    [sym_block_comment] = STATE(1473),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1474] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(12210),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1474),
    [sym_block_comment] = STATE(1474),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1475] = {
    [sym_inline_modifier] = STATE(2196),
    [sym__indentable_expression] = STATE(12889),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1475),
    [sym_block_comment] = STATE(1475),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1476] = {
    [sym_inline_modifier] = STATE(2149),
    [sym__indentable_expression] = STATE(14218),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1476),
    [sym_block_comment] = STATE(1476),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1477] = {
    [sym_inline_modifier] = STATE(2149),
    [sym__indentable_expression] = STATE(14273),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1477),
    [sym_block_comment] = STATE(1477),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1478] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17060),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(703),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1478),
    [sym_block_comment] = STATE(1478),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1479] = {
    [sym_inline_modifier] = STATE(2373),
    [sym__indentable_expression] = STATE(12905),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1479),
    [sym_block_comment] = STATE(1479),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1480] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(12993),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1480),
    [sym_block_comment] = STATE(1480),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1481] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(14735),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1481),
    [sym_block_comment] = STATE(1481),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1482] = {
    [sym_inline_modifier] = STATE(2373),
    [sym__indentable_expression] = STATE(12941),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1482),
    [sym_block_comment] = STATE(1482),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1483] = {
    [sym_inline_modifier] = STATE(2373),
    [sym__indentable_expression] = STATE(12945),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1483),
    [sym_block_comment] = STATE(1483),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1484] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(15079),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1484),
    [sym_block_comment] = STATE(1484),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1485] = {
    [sym_inline_modifier] = STATE(2149),
    [sym__indentable_expression] = STATE(14267),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1485),
    [sym_block_comment] = STATE(1485),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1486] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(14329),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1486),
    [sym_block_comment] = STATE(1486),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1487] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(13706),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1487),
    [sym_block_comment] = STATE(1487),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1488] = {
    [sym_inline_modifier] = STATE(2373),
    [sym__indentable_expression] = STATE(12939),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1488),
    [sym_block_comment] = STATE(1488),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1489] = {
    [sym_inline_modifier] = STATE(2373),
    [sym__indentable_expression] = STATE(12938),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1489),
    [sym_block_comment] = STATE(1489),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1490] = {
    [sym_inline_modifier] = STATE(2373),
    [sym__indentable_expression] = STATE(12889),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1490),
    [sym_block_comment] = STATE(1490),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1491] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13751),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1491),
    [sym_block_comment] = STATE(1491),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1492] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17228),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(779),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1492),
    [sym_block_comment] = STATE(1492),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1493] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(14738),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1493),
    [sym_block_comment] = STATE(1493),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1494] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(14793),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1494),
    [sym_block_comment] = STATE(1494),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1495] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(12247),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1495),
    [sym_block_comment] = STATE(1495),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1496] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(14288),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1496),
    [sym_block_comment] = STATE(1496),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1497] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(12257),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1497),
    [sym_block_comment] = STATE(1497),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1498] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(13214),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1498),
    [sym_block_comment] = STATE(1498),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1499] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(13418),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1499),
    [sym_block_comment] = STATE(1499),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1500] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(13216),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1500),
    [sym_block_comment] = STATE(1500),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1501] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(11927),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1501),
    [sym_block_comment] = STATE(1501),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1502] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(14309),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1502),
    [sym_block_comment] = STATE(1502),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1503] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13896),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1503),
    [sym_block_comment] = STATE(1503),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1504] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(12306),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1504),
    [sym_block_comment] = STATE(1504),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1505] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(12308),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1505),
    [sym_block_comment] = STATE(1505),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1506] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(12333),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1506),
    [sym_block_comment] = STATE(1506),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1507] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(11924),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1507),
    [sym_block_comment] = STATE(1507),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1508] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(12290),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1508),
    [sym_block_comment] = STATE(1508),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1509] = {
    [sym_inline_modifier] = STATE(2196),
    [sym__indentable_expression] = STATE(12938),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1509),
    [sym_block_comment] = STATE(1509),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1510] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(14735),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1510),
    [sym_block_comment] = STATE(1510),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1511] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(12296),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1511),
    [sym_block_comment] = STATE(1511),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1512] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(14751),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1512),
    [sym_block_comment] = STATE(1512),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1513] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(14738),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1513),
    [sym_block_comment] = STATE(1513),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1514] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(12302),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1514),
    [sym_block_comment] = STATE(1514),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1515] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(12340),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1515),
    [sym_block_comment] = STATE(1515),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1516] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13976),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1516),
    [sym_block_comment] = STATE(1516),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1517] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(14793),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1517),
    [sym_block_comment] = STATE(1517),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1518] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(11922),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1518),
    [sym_block_comment] = STATE(1518),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1519] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(11920),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1519),
    [sym_block_comment] = STATE(1519),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1520] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17014),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(684),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1520),
    [sym_block_comment] = STATE(1520),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1521] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(13221),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1521),
    [sym_block_comment] = STATE(1521),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1522] = {
    [sym_inline_modifier] = STATE(2186),
    [sym__indentable_expression] = STATE(13970),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1522),
    [sym_block_comment] = STATE(1522),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1523] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(11912),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1523),
    [sym_block_comment] = STATE(1523),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1524] = {
    [sym_inline_modifier] = STATE(2196),
    [sym__indentable_expression] = STATE(12939),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1524),
    [sym_block_comment] = STATE(1524),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1525] = {
    [sym_inline_modifier] = STATE(2196),
    [sym__indentable_expression] = STATE(12945),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1525),
    [sym_block_comment] = STATE(1525),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1526] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(12387),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1526),
    [sym_block_comment] = STATE(1526),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1527] = {
    [sym_inline_modifier] = STATE(2196),
    [sym__indentable_expression] = STATE(12941),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1527),
    [sym_block_comment] = STATE(1527),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1528] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(11890),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1528),
    [sym_block_comment] = STATE(1528),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1529] = {
    [sym_inline_modifier] = STATE(2274),
    [sym__indentable_expression] = STATE(12294),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1529),
    [sym_block_comment] = STATE(1529),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1530] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(11885),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1530),
    [sym_block_comment] = STATE(1530),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1531] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13973),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1531),
    [sym_block_comment] = STATE(1531),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1532] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(11881),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1532),
    [sym_block_comment] = STATE(1532),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1533] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(14751),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1533),
    [sym_block_comment] = STATE(1533),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1534] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(14709),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1534),
    [sym_block_comment] = STATE(1534),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1535] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13050),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1535),
    [sym_block_comment] = STATE(1535),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1536] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17181),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(690),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1536),
    [sym_block_comment] = STATE(1536),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1537] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(11878),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1537),
    [sym_block_comment] = STATE(1537),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1538] = {
    [sym_inline_modifier] = STATE(2196),
    [sym__indentable_expression] = STATE(12905),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1538),
    [sym_block_comment] = STATE(1538),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1539] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(12460),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1539),
    [sym_block_comment] = STATE(1539),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1540] = {
    [sym_inline_modifier] = STATE(2280),
    [sym__indentable_expression] = STATE(14425),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1540),
    [sym_block_comment] = STATE(1540),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1541] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(12398),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1541),
    [sym_block_comment] = STATE(1541),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1542] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(12399),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1542),
    [sym_block_comment] = STATE(1542),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1543] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(12400),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1543),
    [sym_block_comment] = STATE(1543),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1544] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14294),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1544),
    [sym_block_comment] = STATE(1544),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1545] = {
    [sym_inline_modifier] = STATE(2394),
    [sym__indentable_expression] = STATE(11855),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1545),
    [sym_block_comment] = STATE(1545),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1546] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(12460),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1546),
    [sym_block_comment] = STATE(1546),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1547] = {
    [sym_inline_modifier] = STATE(2138),
    [sym__indentable_expression] = STATE(14712),
    [sym_block] = STATE(8679),
    [sym_indented_block] = STATE(13720),
    [sym_indented_cases] = STATE(13720),
    [sym_expression] = STATE(13466),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1547),
    [sym_block_comment] = STATE(1547),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3296),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1548] = {
    [sym_inline_modifier] = STATE(2196),
    [sym__indentable_expression] = STATE(12895),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1548),
    [sym_block_comment] = STATE(1548),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1549] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(14299),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1549),
    [sym_block_comment] = STATE(1549),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1550] = {
    [sym_inline_modifier] = STATE(2410),
    [sym__indentable_expression] = STATE(14267),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1550),
    [sym_block_comment] = STATE(1550),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1551] = {
    [sym_inline_modifier] = STATE(2410),
    [sym__indentable_expression] = STATE(14273),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1551),
    [sym_block_comment] = STATE(1551),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1552] = {
    [sym_inline_modifier] = STATE(2410),
    [sym__indentable_expression] = STATE(14218),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1552),
    [sym_block_comment] = STATE(1552),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1553] = {
    [sym_inline_modifier] = STATE(2410),
    [sym__indentable_expression] = STATE(14208),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1553),
    [sym_block_comment] = STATE(1553),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1554] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13961),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1554),
    [sym_block_comment] = STATE(1554),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1555] = {
    [sym_inline_modifier] = STATE(2279),
    [sym__indentable_expression] = STATE(14299),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1555),
    [sym_block_comment] = STATE(1555),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1556] = {
    [sym_inline_modifier] = STATE(2196),
    [sym__indentable_expression] = STATE(12892),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1556),
    [sym_block_comment] = STATE(1556),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1557] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(16968),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(697),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1557),
    [sym_block_comment] = STATE(1557),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1558] = {
    [sym_inline_modifier] = STATE(2289),
    [sym__indentable_expression] = STATE(13595),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1558),
    [sym_block_comment] = STATE(1558),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1559] = {
    [sym_inline_modifier] = STATE(2279),
    [sym__indentable_expression] = STATE(14288),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1559),
    [sym_block_comment] = STATE(1559),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1560] = {
    [sym_inline_modifier] = STATE(2132),
    [sym__indentable_expression] = STATE(14786),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1560),
    [sym_block_comment] = STATE(1560),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1561] = {
    [sym_inline_modifier] = STATE(2410),
    [sym__indentable_expression] = STATE(14200),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1561),
    [sym_block_comment] = STATE(1561),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1562] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(14317),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1562),
    [sym_block_comment] = STATE(1562),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1563] = {
    [sym_inline_modifier] = STATE(2196),
    [sym__indentable_expression] = STATE(12886),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1563),
    [sym_block_comment] = STATE(1563),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1564] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(12400),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1564),
    [sym_block_comment] = STATE(1564),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1565] = {
    [sym_inline_modifier] = STATE(2279),
    [sym__indentable_expression] = STATE(14332),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1565),
    [sym_block_comment] = STATE(1565),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1566] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(12399),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1566),
    [sym_block_comment] = STATE(1566),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1567] = {
    [sym_inline_modifier] = STATE(2279),
    [sym__indentable_expression] = STATE(14314),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1567),
    [sym_block_comment] = STATE(1567),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1568] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13880),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1568),
    [sym_block_comment] = STATE(1568),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1569] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(12398),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1569),
    [sym_block_comment] = STATE(1569),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1570] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13852),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1570),
    [sym_block_comment] = STATE(1570),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1571] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13843),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1571),
    [sym_block_comment] = STATE(1571),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1572] = {
    [sym_inline_modifier] = STATE(2304),
    [sym__indentable_expression] = STATE(14358),
    [sym_block] = STATE(9672),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(14256),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1572),
    [sym_block_comment] = STATE(1572),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1573] = {
    [sym_inline_modifier] = STATE(2410),
    [sym__indentable_expression] = STATE(14188),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1573),
    [sym_block_comment] = STATE(1573),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1574] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(13977),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1574),
    [sym_block_comment] = STATE(1574),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1575] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(13226),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1575),
    [sym_block_comment] = STATE(1575),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1576] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(13049),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1576),
    [sym_block_comment] = STATE(1576),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1577] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17126),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(845),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1577),
    [sym_block_comment] = STATE(1577),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1578] = {
    [sym_inline_modifier] = STATE(2196),
    [sym__indentable_expression] = STATE(12883),
    [sym_block] = STATE(6845),
    [sym_indented_block] = STATE(12626),
    [sym_indented_cases] = STATE(12626),
    [sym_expression] = STATE(12470),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1578),
    [sym_block_comment] = STATE(1578),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2178),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1579] = {
    [sym_inline_modifier] = STATE(2257),
    [sym__indentable_expression] = STATE(14786),
    [sym_block] = STATE(8208),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(13066),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1579),
    [sym_block_comment] = STATE(1579),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1580] = {
    [sym_inline_modifier] = STATE(2410),
    [sym__indentable_expression] = STATE(14236),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1580),
    [sym_block_comment] = STATE(1580),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1581] = {
    [sym_inline_modifier] = STATE(2410),
    [sym__indentable_expression] = STATE(14213),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1581),
    [sym_block_comment] = STATE(1581),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1582] = {
    [sym_inline_modifier] = STATE(2410),
    [sym__indentable_expression] = STATE(14177),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1582),
    [sym_block_comment] = STATE(1582),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1583] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13733),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1583),
    [sym_block_comment] = STATE(1583),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1584] = {
    [sym_inline_modifier] = STATE(2410),
    [sym__indentable_expression] = STATE(14250),
    [sym_block] = STATE(9117),
    [sym_indented_block] = STATE(14069),
    [sym_indented_cases] = STATE(14069),
    [sym_expression] = STATE(14011),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1584),
    [sym_block_comment] = STATE(1584),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2186),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1585] = {
    [sym_inline_modifier] = STATE(2161),
    [sym__indentable_expression] = STATE(14293),
    [sym_block] = STATE(9544),
    [sym_indented_block] = STATE(14114),
    [sym_indented_cases] = STATE(14114),
    [sym_expression] = STATE(13984),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1585),
    [sym_block_comment] = STATE(1585),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3298),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1586] = {
    [sym_inline_modifier] = STATE(2126),
    [sym__indentable_expression] = STATE(13998),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1586),
    [sym_block_comment] = STATE(1586),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1587] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(12387),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1587),
    [sym_block_comment] = STATE(1587),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1588] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13738),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1588),
    [sym_block_comment] = STATE(1588),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1589] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13745),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1589),
    [sym_block_comment] = STATE(1589),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1590] = {
    [sym_inline_modifier] = STATE(2279),
    [sym__indentable_expression] = STATE(14374),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1590),
    [sym_block_comment] = STATE(1590),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1591] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(13418),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1591),
    [sym_block_comment] = STATE(1591),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1592] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13753),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1592),
    [sym_block_comment] = STATE(1592),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1593] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13612),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1593),
    [sym_block_comment] = STATE(1593),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1594] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13624),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1594),
    [sym_block_comment] = STATE(1594),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1595] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13755),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1595),
    [sym_block_comment] = STATE(1595),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1596] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(16922),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(687),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1596),
    [sym_block_comment] = STATE(1596),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1597] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13182),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1597),
    [sym_block_comment] = STATE(1597),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1598] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13705),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1598),
    [sym_block_comment] = STATE(1598),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1599] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13631),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1599),
    [sym_block_comment] = STATE(1599),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1600] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13632),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1600),
    [sym_block_comment] = STATE(1600),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1601] = {
    [sym_inline_modifier] = STATE(2279),
    [sym__indentable_expression] = STATE(14429),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1601),
    [sym_block_comment] = STATE(1601),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1602] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13668),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1602),
    [sym_block_comment] = STATE(1602),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1603] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(14101),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1603),
    [sym_block_comment] = STATE(1603),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1604] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(16988),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(810),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1604),
    [sym_block_comment] = STATE(1604),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1605] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(14082),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1605),
    [sym_block_comment] = STATE(1605),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1606] = {
    [sym_inline_modifier] = STATE(2400),
    [sym__indentable_expression] = STATE(13520),
    [sym_block] = STATE(8806),
    [sym_indented_block] = STATE(13760),
    [sym_indented_cases] = STATE(13760),
    [sym_expression] = STATE(13676),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1606),
    [sym_block_comment] = STATE(1606),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2238),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1607] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13715),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1607),
    [sym_block_comment] = STATE(1607),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1608] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(16781),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(726),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1608),
    [sym_block_comment] = STATE(1608),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1609] = {
    [sym_inline_modifier] = STATE(2279),
    [sym__indentable_expression] = STATE(14420),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1609),
    [sym_block_comment] = STATE(1609),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1610] = {
    [sym_inline_modifier] = STATE(2279),
    [sym__indentable_expression] = STATE(14419),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1610),
    [sym_block_comment] = STATE(1610),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1611] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(12294),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1611),
    [sym_block_comment] = STATE(1611),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1612] = {
    [sym_inline_modifier] = STATE(2279),
    [sym__indentable_expression] = STATE(14415),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1612),
    [sym_block_comment] = STATE(1612),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1613] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(13424),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1613),
    [sym_block_comment] = STATE(1613),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1614] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(15042),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1614),
    [sym_block_comment] = STATE(1614),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1615] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(14206),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1615),
    [sym_block_comment] = STATE(1615),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1616] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(14686),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1616),
    [sym_block_comment] = STATE(1616),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1617] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13667),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1617),
    [sym_block_comment] = STATE(1617),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1618] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13669),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1618),
    [sym_block_comment] = STATE(1618),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1619] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13670),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1619),
    [sym_block_comment] = STATE(1619),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1620] = {
    [sym_inline_modifier] = STATE(2180),
    [sym__indentable_expression] = STATE(12534),
    [sym_block] = STATE(5679),
    [sym_indented_block] = STATE(11721),
    [sym_indented_cases] = STATE(11721),
    [sym_expression] = STATE(11714),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1620),
    [sym_block_comment] = STATE(1620),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2230),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1621] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(12340),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1621),
    [sym_block_comment] = STATE(1621),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1622] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(12302),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1622),
    [sym_block_comment] = STATE(1622),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1623] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(14093),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1623),
    [sym_block_comment] = STATE(1623),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1624] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(15038),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1624),
    [sym_block_comment] = STATE(1624),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1625] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(12333),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1625),
    [sym_block_comment] = STATE(1625),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1626] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(12296),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1626),
    [sym_block_comment] = STATE(1626),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1627] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17080),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(838),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1627),
    [sym_block_comment] = STATE(1627),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1628] = {
    [sym_inline_modifier] = STATE(2279),
    [sym__indentable_expression] = STATE(14393),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1628),
    [sym_block_comment] = STATE(1628),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1629] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(12290),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1629),
    [sym_block_comment] = STATE(1629),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1630] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(13425),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1630),
    [sym_block_comment] = STATE(1630),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1631] = {
    [sym_inline_modifier] = STATE(2404),
    [sym__indentable_expression] = STATE(13654),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1631),
    [sym_block_comment] = STATE(1631),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1632] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(12247),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1632),
    [sym_block_comment] = STATE(1632),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1633] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(12210),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1633),
    [sym_block_comment] = STATE(1633),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1634] = {
    [sym_inline_modifier] = STATE(2326),
    [sym__indentable_expression] = STATE(13048),
    [sym_block] = STATE(10468),
    [sym_indented_block] = STATE(12969),
    [sym_indented_cases] = STATE(12969),
    [sym_expression] = STATE(14548),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1634),
    [sym_block_comment] = STATE(1634),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3294),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1635] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(14429),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1635),
    [sym_block_comment] = STATE(1635),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1636] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(16876),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(712),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1636),
    [sym_block_comment] = STATE(1636),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1637] = {
    [sym_inline_modifier] = STATE(2182),
    [sym__indentable_expression] = STATE(13966),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1637),
    [sym_block_comment] = STATE(1637),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1638] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(14439),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1638),
    [sym_block_comment] = STATE(1638),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1639] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(12203),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1639),
    [sym_block_comment] = STATE(1639),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1640] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(12201),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1640),
    [sym_block_comment] = STATE(1640),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1641] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(13811),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1641),
    [sym_block_comment] = STATE(1641),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1642] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(14052),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1642),
    [sym_block_comment] = STATE(1642),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1643] = {
    [sym_inline_modifier] = STATE(2379),
    [sym__indentable_expression] = STATE(14498),
    [sym_block] = STATE(10013),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(14297),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1643),
    [sym_block_comment] = STATE(1643),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1644] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(12294),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1644),
    [sym_block_comment] = STATE(1644),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1645] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(13427),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1645),
    [sym_block_comment] = STATE(1645),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1646] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(12179),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1646),
    [sym_block_comment] = STATE(1646),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1647] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(12179),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1647),
    [sym_block_comment] = STATE(1647),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1648] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(13829),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1648),
    [sym_block_comment] = STATE(1648),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1649] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(13844),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1649),
    [sym_block_comment] = STATE(1649),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1650] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(13848),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1650),
    [sym_block_comment] = STATE(1650),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1651] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(12765),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1651),
    [sym_block_comment] = STATE(1651),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1652] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(13872),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1652),
    [sym_block_comment] = STATE(1652),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1653] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(14420),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1653),
    [sym_block_comment] = STATE(1653),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1654] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(12201),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1654),
    [sym_block_comment] = STATE(1654),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1655] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13743),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1655),
    [sym_block_comment] = STATE(1655),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1656] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(14419),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1656),
    [sym_block_comment] = STATE(1656),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1657] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(12735),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1657),
    [sym_block_comment] = STATE(1657),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1658] = {
    [sym_inline_modifier] = STATE(2108),
    [sym__indentable_expression] = STATE(13791),
    [sym_block] = STATE(7018),
    [sym_indented_block] = STATE(13235),
    [sym_indented_cases] = STATE(13235),
    [sym_expression] = STATE(12829),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1658),
    [sym_block_comment] = STATE(1658),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2174),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1659] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(12734),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1659),
    [sym_block_comment] = STATE(1659),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1660] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(12203),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1660),
    [sym_block_comment] = STATE(1660),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1661] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(12210),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1661),
    [sym_block_comment] = STATE(1661),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1662] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(12731),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1662),
    [sym_block_comment] = STATE(1662),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1663] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(12727),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1663),
    [sym_block_comment] = STATE(1663),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1664] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(13974),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1664),
    [sym_block_comment] = STATE(1664),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1665] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(13430),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1665),
    [sym_block_comment] = STATE(1665),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1666] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(13988),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1666),
    [sym_block_comment] = STATE(1666),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1667] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(13990),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1667),
    [sym_block_comment] = STATE(1667),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1668] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(13992),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1668),
    [sym_block_comment] = STATE(1668),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1669] = {
    [sym_inline_modifier] = STATE(2266),
    [sym__indentable_expression] = STATE(13838),
    [sym_block] = STATE(7727),
    [sym_indented_block] = STATE(13635),
    [sym_indented_cases] = STATE(13635),
    [sym_expression] = STATE(13013),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1669),
    [sym_block_comment] = STATE(1669),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2498),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1670] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(12693),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1670),
    [sym_block_comment] = STATE(1670),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1671] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(12308),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1671),
    [sym_block_comment] = STATE(1671),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1672] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(14393),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1672),
    [sym_block_comment] = STATE(1672),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1673] = {
    [sym_inline_modifier] = STATE(2356),
    [sym__indentable_expression] = STATE(13157),
    [sym_block] = STATE(6583),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(12328),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1673),
    [sym_block_comment] = STATE(1673),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1674] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(17034),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(822),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1674),
    [sym_block_comment] = STATE(1674),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1675] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14952),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1675),
    [sym_block_comment] = STATE(1675),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1676] = {
    [sym_inline_modifier] = STATE(2181),
    [sym__indentable_expression] = STATE(16829),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(720),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1676),
    [sym_block_comment] = STATE(1676),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3304),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1677] = {
    [sym_inline_modifier] = STATE(2301),
    [sym__indentable_expression] = STATE(14287),
    [sym_block] = STATE(8484),
    [sym_indented_block] = STATE(13891),
    [sym_indented_cases] = STATE(13891),
    [sym_expression] = STATE(13458),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1677),
    [sym_block_comment] = STATE(1677),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2234),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1678] = {
    [sym_inline_modifier] = STATE(2380),
    [sym__indentable_expression] = STATE(13940),
    [sym_block] = STATE(8837),
    [sym_indented_block] = STATE(13761),
    [sym_indented_cases] = STATE(13761),
    [sym_expression] = STATE(13472),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1678),
    [sym_block_comment] = STATE(1678),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2402),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1679] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(12306),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1679),
    [sym_block_comment] = STATE(1679),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1680] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(12681),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1680),
    [sym_block_comment] = STATE(1680),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1681] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(12247),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1681),
    [sym_block_comment] = STATE(1681),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1682] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(12680),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1682),
    [sym_block_comment] = STATE(1682),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1683] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(12678),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1683),
    [sym_block_comment] = STATE(1683),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1684] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(14222),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1684),
    [sym_block_comment] = STATE(1684),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1685] = {
    [sym_inline_modifier] = STATE(2135),
    [sym__indentable_expression] = STATE(14415),
    [sym_block] = STATE(9879),
    [sym_indented_block] = STATE(14382),
    [sym_indented_cases] = STATE(14382),
    [sym_expression] = STATE(14268),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1685),
    [sym_block_comment] = STATE(1685),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2526),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1686] = {
    [sym_inline_modifier] = STATE(2328),
    [sym__indentable_expression] = STATE(12673),
    [sym_block] = STATE(7233),
    [sym_indented_block] = STATE(12811),
    [sym_indented_cases] = STATE(12811),
    [sym_expression] = STATE(12549),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1686),
    [sym_block_comment] = STATE(1686),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(3300),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1687] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(12305),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1687),
    [sym_block_comment] = STATE(1687),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1688] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(12340),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1688),
    [sym_block_comment] = STATE(1688),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1689] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(13465),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1689),
    [sym_block_comment] = STATE(1689),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1690] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(13463),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1690),
    [sym_block_comment] = STATE(1690),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1691] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(13461),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1691),
    [sym_block_comment] = STATE(1691),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1692] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(13460),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1692),
    [sym_block_comment] = STATE(1692),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1693] = {
    [sym_inline_modifier] = STATE(2276),
    [sym__indentable_expression] = STATE(12257),
    [sym_block] = STATE(6762),
    [sym_indented_block] = STATE(12188),
    [sym_indented_cases] = STATE(12188),
    [sym_expression] = STATE(12423),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1693),
    [sym_block_comment] = STATE(1693),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2226),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1694] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(12290),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1694),
    [sym_block_comment] = STATE(1694),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1695] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(12302),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1695),
    [sym_block_comment] = STATE(1695),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1696] = {
    [sym_inline_modifier] = STATE(2244),
    [sym__indentable_expression] = STATE(14997),
    [sym_block] = STATE(9857),
    [sym_indented_block] = STATE(14319),
    [sym_indented_cases] = STATE(14319),
    [sym_expression] = STATE(14095),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1696),
    [sym_block_comment] = STATE(1696),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(760),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1697] = {
    [sym_inline_modifier] = STATE(2226),
    [sym__indentable_expression] = STATE(14201),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1697),
    [sym_block_comment] = STATE(1697),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1698] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(13451),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1698),
    [sym_block_comment] = STATE(1698),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1699] = {
    [sym_inline_modifier] = STATE(2360),
    [sym__indentable_expression] = STATE(14440),
    [sym_block] = STATE(7676),
    [sym_indented_block] = STATE(13447),
    [sym_indented_cases] = STATE(13447),
    [sym_expression] = STATE(13076),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1699),
    [sym_block_comment] = STATE(1699),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2206),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1700] = {
    [sym_inline_modifier] = STATE(2272),
    [sym__indentable_expression] = STATE(12296),
    [sym_block] = STATE(9899),
    [sym_indented_block] = STATE(12169),
    [sym_indented_cases] = STATE(12169),
    [sym_expression] = STATE(14139),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1700),
    [sym_block_comment] = STATE(1700),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__indent] = ACTIONS(2258),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1701] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8958),
    [sym_expression] = STATE(16299),
    [sym__simple_expression] = STATE(6039),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16871),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9939),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5485),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8150),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1701),
    [sym_block_comment] = STATE(1701),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_COLON] = ACTIONS(1282),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1304),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [1702] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(15795),
    [sym__simple_expression] = STATE(4883),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17619),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8498),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(4736),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(6646),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1702),
    [sym_block_comment] = STATE(1702),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_COLON] = ACTIONS(1724),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1726),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1703] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18329),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1703),
    [sym_block_comment] = STATE(1703),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3338),
    [anon_sym_RPAREN] = ACTIONS(3340),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1704] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18333),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1704),
    [sym_block_comment] = STATE(1704),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3342),
    [anon_sym_RPAREN] = ACTIONS(3344),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1705] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16804),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1705),
    [sym_block_comment] = STATE(1705),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3346),
    [anon_sym_RPAREN] = ACTIONS(3348),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1706] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17847),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1706),
    [sym_block_comment] = STATE(1706),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3350),
    [anon_sym_RPAREN] = ACTIONS(3352),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1707] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(15815),
    [sym__simple_expression] = STATE(4618),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17217),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(7370),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4479),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(5143),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1707),
    [sym_block_comment] = STATE(1707),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_COLON] = ACTIONS(950),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(972),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1708] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17057),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1708),
    [sym_block_comment] = STATE(1708),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3354),
    [anon_sym_RPAREN] = ACTIONS(3356),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1709] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(15210),
    [sym__simple_expression] = STATE(7512),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10885),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(7123),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9805),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1709),
    [sym_block_comment] = STATE(1709),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_COLON] = ACTIONS(2244),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(2248),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1710] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18316),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1710),
    [sym_block_comment] = STATE(1710),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3358),
    [anon_sym_RPAREN] = ACTIONS(3360),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1711] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18318),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1711),
    [sym_block_comment] = STATE(1711),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3362),
    [anon_sym_RPAREN] = ACTIONS(3364),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1712] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18349),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1712),
    [sym_block_comment] = STATE(1712),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3366),
    [anon_sym_RPAREN] = ACTIONS(3368),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1713] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17007),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1713),
    [sym_block_comment] = STATE(1713),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3370),
    [anon_sym_RPAREN] = ACTIONS(3372),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1714] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18304),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1714),
    [sym_block_comment] = STATE(1714),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3374),
    [anon_sym_RPAREN] = ACTIONS(3376),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1715] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16852),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1715),
    [sym_block_comment] = STATE(1715),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3378),
    [anon_sym_RPAREN] = ACTIONS(3380),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1716] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18306),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1716),
    [sym_block_comment] = STATE(1716),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3382),
    [anon_sym_RPAREN] = ACTIONS(3384),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1717] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18517),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1717),
    [sym_block_comment] = STATE(1717),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3386),
    [anon_sym_RPAREN] = ACTIONS(3388),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1718] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17776),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1718),
    [sym_block_comment] = STATE(1718),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3390),
    [anon_sym_RPAREN] = ACTIONS(3392),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1719] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(16016),
    [sym__simple_expression] = STATE(5821),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17175),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9827),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5189),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(7901),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1719),
    [sym_block_comment] = STATE(1719),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_COLON] = ACTIONS(1746),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1768),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1720] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18291),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1720),
    [sym_block_comment] = STATE(1720),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3394),
    [anon_sym_RPAREN] = ACTIONS(3396),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1721] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18293),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1721),
    [sym_block_comment] = STATE(1721),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3398),
    [anon_sym_RPAREN] = ACTIONS(3400),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1722] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(16126),
    [sym__simple_expression] = STATE(6150),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17012),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10069),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(5723),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(8607),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1722),
    [sym_block_comment] = STATE(1722),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(2060),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2064),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1723] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17111),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1723),
    [sym_block_comment] = STATE(1723),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3402),
    [anon_sym_RPAREN] = ACTIONS(3404),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1724] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16898),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1724),
    [sym_block_comment] = STATE(1724),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3406),
    [anon_sym_RPAREN] = ACTIONS(3408),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1725] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18276),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1725),
    [sym_block_comment] = STATE(1725),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3410),
    [anon_sym_RPAREN] = ACTIONS(3412),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1726] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18279),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1726),
    [sym_block_comment] = STATE(1726),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3414),
    [anon_sym_RPAREN] = ACTIONS(3416),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1727] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17877),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1727),
    [sym_block_comment] = STATE(1727),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3418),
    [anon_sym_RPAREN] = ACTIONS(3420),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1728] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(16086),
    [sym__simple_expression] = STATE(5254),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17078),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9340),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5073),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(6993),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1728),
    [sym_block_comment] = STATE(1728),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_COLON] = ACTIONS(1426),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1448),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1729] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9672),
    [sym_expression] = STATE(15936),
    [sym__simple_expression] = STATE(6638),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17196),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10287),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5655),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8866),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1729),
    [sym_block_comment] = STATE(1729),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_COLON] = ACTIONS(1514),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(1536),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1730] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18377),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1730),
    [sym_block_comment] = STATE(1730),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3422),
    [anon_sym_RPAREN] = ACTIONS(3424),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1731] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18264),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1731),
    [sym_block_comment] = STATE(1731),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3426),
    [anon_sym_RPAREN] = ACTIONS(3428),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1732] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18267),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1732),
    [sym_block_comment] = STATE(1732),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3430),
    [anon_sym_RPAREN] = ACTIONS(3432),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1733] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16944),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1733),
    [sym_block_comment] = STATE(1733),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3434),
    [anon_sym_RPAREN] = ACTIONS(3436),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1734] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18369),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1734),
    [sym_block_comment] = STATE(1734),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3438),
    [anon_sym_RPAREN] = ACTIONS(3440),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1735] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16756),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1735),
    [sym_block_comment] = STATE(1735),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3442),
    [anon_sym_RPAREN] = ACTIONS(3444),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1736] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18282),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1736),
    [sym_block_comment] = STATE(1736),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3446),
    [anon_sym_RPAREN] = ACTIONS(3448),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1737] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17162),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1737),
    [sym_block_comment] = STATE(1737),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3450),
    [anon_sym_RPAREN] = ACTIONS(3452),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1738] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18249),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1738),
    [sym_block_comment] = STATE(1738),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3454),
    [anon_sym_RPAREN] = ACTIONS(3456),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1739] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18251),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1739),
    [sym_block_comment] = STATE(1739),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3458),
    [anon_sym_RPAREN] = ACTIONS(3460),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1740] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(15745),
    [sym__simple_expression] = STATE(5092),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17238),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8777),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(4744),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(6749),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1740),
    [sym_block_comment] = STATE(1740),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_COLON] = ACTIONS(1166),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1188),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1741] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17825),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1741),
    [sym_block_comment] = STATE(1741),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3462),
    [anon_sym_RPAREN] = ACTIONS(3464),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1742] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(16246),
    [sym__simple_expression] = STATE(5761),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17005),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9844),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(5368),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(7971),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1742),
    [sym_block_comment] = STATE(1742),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_COLON] = ACTIONS(1976),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(1998),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1743] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18237),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1743),
    [sym_block_comment] = STATE(1743),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3466),
    [anon_sym_RPAREN] = ACTIONS(3468),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1744] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18240),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1744),
    [sym_block_comment] = STATE(1744),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3470),
    [anon_sym_RPAREN] = ACTIONS(3472),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1745] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(15610),
    [sym__simple_expression] = STATE(5216),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17280),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8997),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(4921),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(6901),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1745),
    [sym_block_comment] = STATE(1745),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_COLON] = ACTIONS(1338),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1360),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1746] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18223),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1746),
    [sym_block_comment] = STATE(1746),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3474),
    [anon_sym_RPAREN] = ACTIONS(3476),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1747] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18226),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1747),
    [sym_block_comment] = STATE(1747),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3478),
    [anon_sym_RPAREN] = ACTIONS(3480),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1748] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16990),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1748),
    [sym_block_comment] = STATE(1748),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3482),
    [anon_sym_RPAREN] = ACTIONS(3484),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1749] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18384),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1749),
    [sym_block_comment] = STATE(1749),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3486),
    [anon_sym_RPAREN] = ACTIONS(3488),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1750] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18112),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1750),
    [sym_block_comment] = STATE(1750),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3490),
    [anon_sym_RPAREN] = ACTIONS(3492),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1751] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17204),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1751),
    [sym_block_comment] = STATE(1751),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3494),
    [anon_sym_RPAREN] = ACTIONS(3496),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1752] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(15795),
    [sym__simple_expression] = STATE(4883),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17619),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8498),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(4736),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(6646),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1752),
    [sym_block_comment] = STATE(1752),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_COLON] = ACTIONS(1724),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1726),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1753] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17903),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1753),
    [sym_block_comment] = STATE(1753),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3498),
    [anon_sym_RPAREN] = ACTIONS(3500),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1754] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18204),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1754),
    [sym_block_comment] = STATE(1754),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3502),
    [anon_sym_RPAREN] = ACTIONS(3504),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1755] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18208),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1755),
    [sym_block_comment] = STATE(1755),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3506),
    [anon_sym_RPAREN] = ACTIONS(3508),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1756] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(16300),
    [sym__simple_expression] = STATE(4801),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16983),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(7976),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(4598),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(5819),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1756),
    [sym_block_comment] = STATE(1756),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_COLON] = ACTIONS(1094),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1116),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1757] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18192),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1757),
    [sym_block_comment] = STATE(1757),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3510),
    [anon_sym_RPAREN] = ACTIONS(3512),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1758] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18195),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1758),
    [sym_block_comment] = STATE(1758),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3514),
    [anon_sym_RPAREN] = ACTIONS(3516),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1759] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16945),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1759),
    [sym_block_comment] = STATE(1759),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3518),
    [anon_sym_RPAREN] = ACTIONS(3520),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1760] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17036),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1760),
    [sym_block_comment] = STATE(1760),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3522),
    [anon_sym_RPAREN] = ACTIONS(3524),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1761] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17248),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1761),
    [sym_block_comment] = STATE(1761),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3526),
    [anon_sym_RPAREN] = ACTIONS(3528),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1762] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18532),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1762),
    [sym_block_comment] = STATE(1762),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3530),
    [anon_sym_RPAREN] = ACTIONS(3532),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1763] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17849),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1763),
    [sym_block_comment] = STATE(1763),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3534),
    [anon_sym_RPAREN] = ACTIONS(3536),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1764] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18178),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1764),
    [sym_block_comment] = STATE(1764),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3538),
    [anon_sym_RPAREN] = ACTIONS(3540),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1765] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18183),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1765),
    [sym_block_comment] = STATE(1765),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3542),
    [anon_sym_RPAREN] = ACTIONS(3544),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1766] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18165),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1766),
    [sym_block_comment] = STATE(1766),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3546),
    [anon_sym_RPAREN] = ACTIONS(3548),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1767] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18396),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1767),
    [sym_block_comment] = STATE(1767),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3550),
    [anon_sym_RPAREN] = ACTIONS(3552),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1768] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18167),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1768),
    [sym_block_comment] = STATE(1768),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3554),
    [anon_sym_RPAREN] = ACTIONS(3556),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1769] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17082),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1769),
    [sym_block_comment] = STATE(1769),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3558),
    [anon_sym_RPAREN] = ACTIONS(3560),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1770] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17300),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1770),
    [sym_block_comment] = STATE(1770),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3562),
    [anon_sym_RPAREN] = ACTIONS(3564),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1771] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(16376),
    [sym__simple_expression] = STATE(4767),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16961),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8143),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(4568),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(5737),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1771),
    [sym_block_comment] = STATE(1771),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_COLON] = ACTIONS(1022),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1044),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1772] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16820),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1772),
    [sym_block_comment] = STATE(1772),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3566),
    [anon_sym_RPAREN] = ACTIONS(3568),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1773] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18151),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1773),
    [sym_block_comment] = STATE(1773),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3570),
    [anon_sym_RPAREN] = ACTIONS(3572),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1774] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18394),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1774),
    [sym_block_comment] = STATE(1774),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3574),
    [anon_sym_RPAREN] = ACTIONS(3576),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1775] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18064),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1775),
    [sym_block_comment] = STATE(1775),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3578),
    [anon_sym_RPAREN] = ACTIONS(3580),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1776] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17136),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1776),
    [sym_block_comment] = STATE(1776),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3582),
    [anon_sym_RPAREN] = ACTIONS(3584),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1777] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17349),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1777),
    [sym_block_comment] = STATE(1777),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3586),
    [anon_sym_RPAREN] = ACTIONS(3588),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1778] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16723),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1778),
    [sym_block_comment] = STATE(1778),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3590),
    [anon_sym_RPAREN] = ACTIONS(3592),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1779] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17718),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1779),
    [sym_block_comment] = STATE(1779),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3594),
    [anon_sym_RPAREN] = ACTIONS(3596),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1780] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18141),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1780),
    [sym_block_comment] = STATE(1780),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3598),
    [anon_sym_RPAREN] = ACTIONS(3600),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1781] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18143),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1781),
    [sym_block_comment] = STATE(1781),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3602),
    [anon_sym_RPAREN] = ACTIONS(3604),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1782] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(16355),
    [sym__simple_expression] = STATE(4482),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16939),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(6524),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4434),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(4827),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1782),
    [sym_block_comment] = STATE(1782),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_COLON] = ACTIONS(906),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(936),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1783] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17397),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1783),
    [sym_block_comment] = STATE(1783),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3606),
    [anon_sym_RPAREN] = ACTIONS(3608),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1784] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17183),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1784),
    [sym_block_comment] = STATE(1784),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3610),
    [anon_sym_RPAREN] = ACTIONS(3612),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1785] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18469),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1785),
    [sym_block_comment] = STATE(1785),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3614),
    [anon_sym_RPAREN] = ACTIONS(3616),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1786] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(16045),
    [sym__simple_expression] = STATE(4609),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17201),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(7425),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4460),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(5146),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1786),
    [sym_block_comment] = STATE(1786),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_COLON] = ACTIONS(986),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1008),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1787] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18366),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1787),
    [sym_block_comment] = STATE(1787),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3618),
    [anon_sym_RPAREN] = ACTIONS(3620),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1788] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18124),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1788),
    [sym_block_comment] = STATE(1788),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3622),
    [anon_sym_RPAREN] = ACTIONS(3624),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1789] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18129),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1789),
    [sym_block_comment] = STATE(1789),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3626),
    [anon_sym_RPAREN] = ACTIONS(3628),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1790] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10196),
    [sym_expression] = STATE(16326),
    [sym__simple_expression] = STATE(6964),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16895),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10560),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6685),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9359),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1790),
    [sym_block_comment] = STATE(1790),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_COLON] = ACTIONS(2082),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2104),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [1791] = {
    [sym_inline_modifier] = STATE(2208),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(14021),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1791),
    [sym_block_comment] = STATE(1791),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(1200),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1792] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17441),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1792),
    [sym_block_comment] = STATE(1792),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3630),
    [anon_sym_RPAREN] = ACTIONS(3632),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1793] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18090),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1793),
    [sym_block_comment] = STATE(1793),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3634),
    [anon_sym_RPAREN] = ACTIONS(3636),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1794] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18352),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1794),
    [sym_block_comment] = STATE(1794),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3638),
    [anon_sym_RPAREN] = ACTIONS(3640),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1795] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18381),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1795),
    [sym_block_comment] = STATE(1795),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3642),
    [anon_sym_RPAREN] = ACTIONS(3644),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1796] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17799),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1796),
    [sym_block_comment] = STATE(1796),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3646),
    [anon_sym_RPAREN] = ACTIONS(3648),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1797] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18113),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1797),
    [sym_block_comment] = STATE(1797),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3650),
    [anon_sym_RPAREN] = ACTIONS(3652),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1798] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16899),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1798),
    [sym_block_comment] = STATE(1798),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3654),
    [anon_sym_RPAREN] = ACTIONS(3656),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1799] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(16271),
    [sym__simple_expression] = STATE(5452),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16847),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9035),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(4951),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(6940),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1799),
    [sym_block_comment] = STATE(1799),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_COLON] = ACTIONS(1226),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1248),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1800] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18100),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1800),
    [sym_block_comment] = STATE(1800),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3658),
    [anon_sym_RPAREN] = ACTIONS(3660),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1801] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17486),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1801),
    [sym_block_comment] = STATE(1801),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3662),
    [anon_sym_RPAREN] = ACTIONS(3664),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1802] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17284),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1802),
    [sym_block_comment] = STATE(1802),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3666),
    [anon_sym_RPAREN] = ACTIONS(3668),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1803] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(16084),
    [sym__simple_expression] = STATE(5931),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17027),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9660),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5338),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(7797),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1803),
    [sym_block_comment] = STATE(1803),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_COLON] = ACTIONS(1676),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(1698),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1804] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17921),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1804),
    [sym_block_comment] = STATE(1804),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3670),
    [anon_sym_RPAREN] = ACTIONS(3672),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1805] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18093),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1805),
    [sym_block_comment] = STATE(1805),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3674),
    [anon_sym_RPAREN] = ACTIONS(3676),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1806] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18080),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1806),
    [sym_block_comment] = STATE(1806),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3678),
    [anon_sym_RPAREN] = ACTIONS(3680),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1807] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17534),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1807),
    [sym_block_comment] = STATE(1807),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3682),
    [anon_sym_RPAREN] = ACTIONS(3684),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1808] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18072),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1808),
    [sym_block_comment] = STATE(1808),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3686),
    [anon_sym_RPAREN] = ACTIONS(3688),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1809] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18487),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1809),
    [sym_block_comment] = STATE(1809),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3690),
    [anon_sym_RPAREN] = ACTIONS(3692),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1810] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16702),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1810),
    [sym_block_comment] = STATE(1810),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3694),
    [anon_sym_RPAREN] = ACTIONS(3696),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1811] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18486),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1811),
    [sym_block_comment] = STATE(1811),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3698),
    [anon_sym_RPAREN] = ACTIONS(3700),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1812] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18074),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1812),
    [sym_block_comment] = STATE(1812),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3702),
    [anon_sym_RPAREN] = ACTIONS(3704),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1813] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(16112),
    [sym__simple_expression] = STATE(5042),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17154),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8303),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4750),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6445),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1813),
    [sym_block_comment] = STATE(1813),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_COLON] = ACTIONS(1130),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1152),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1814] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17329),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1814),
    [sym_block_comment] = STATE(1814),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3706),
    [anon_sym_RPAREN] = ACTIONS(3708),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1815] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17933),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1815),
    [sym_block_comment] = STATE(1815),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3710),
    [anon_sym_RPAREN] = ACTIONS(3712),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1816] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18502),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1816),
    [sym_block_comment] = STATE(1816),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3714),
    [anon_sym_RPAREN] = ACTIONS(3716),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1817] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18063),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1817),
    [sym_block_comment] = STATE(1817),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3718),
    [anon_sym_RPAREN] = ACTIONS(3720),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1818] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18055),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1818),
    [sym_block_comment] = STATE(1818),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3722),
    [anon_sym_RPAREN] = ACTIONS(3724),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1819] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(16244),
    [sym__simple_expression] = STATE(5300),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16742),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9250),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(4907),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(7410),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1819),
    [sym_block_comment] = STATE(1819),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_COLON] = ACTIONS(1570),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1592),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1820] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18045),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1820),
    [sym_block_comment] = STATE(1820),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3726),
    [anon_sym_RPAREN] = ACTIONS(3728),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1821] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17596),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1821),
    [sym_block_comment] = STATE(1821),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3730),
    [anon_sym_RPAREN] = ACTIONS(3732),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1822] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18052),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1822),
    [sym_block_comment] = STATE(1822),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3734),
    [anon_sym_RPAREN] = ACTIONS(3736),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1823] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17377),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1823),
    [sym_block_comment] = STATE(1823),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3738),
    [anon_sym_RPAREN] = ACTIONS(3740),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1824] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18501),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1824),
    [sym_block_comment] = STATE(1824),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3742),
    [anon_sym_RPAREN] = ACTIONS(3744),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1825] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17674),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1825),
    [sym_block_comment] = STATE(1825),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3746),
    [anon_sym_RPAREN] = ACTIONS(3748),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1826] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18036),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1826),
    [sym_block_comment] = STATE(1826),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3750),
    [anon_sym_RPAREN] = ACTIONS(3752),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1827] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18028),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1827),
    [sym_block_comment] = STATE(1827),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3754),
    [anon_sym_RPAREN] = ACTIONS(3756),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1828] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9899),
    [sym_expression] = STATE(15993),
    [sym__simple_expression] = STATE(6676),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17307),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10335),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5779),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8461),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1828),
    [sym_block_comment] = STATE(1828),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_COLON] = ACTIONS(1640),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1662),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [1829] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18030),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1829),
    [sym_block_comment] = STATE(1829),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3758),
    [anon_sym_RPAREN] = ACTIONS(3760),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1830] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17647),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1830),
    [sym_block_comment] = STATE(1830),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3762),
    [anon_sym_RPAREN] = ACTIONS(3764),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1831] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18021),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1831),
    [sym_block_comment] = STATE(1831),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3766),
    [anon_sym_RPAREN] = ACTIONS(3768),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1832] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17421),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1832),
    [sym_block_comment] = STATE(1832),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3770),
    [anon_sym_RPAREN] = ACTIONS(3772),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1833] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17944),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1833),
    [sym_block_comment] = STATE(1833),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3774),
    [anon_sym_RPAREN] = ACTIONS(3776),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1834] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18016),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1834),
    [sym_block_comment] = STATE(1834),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3778),
    [anon_sym_RPAREN] = ACTIONS(3780),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1835] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(16217),
    [sym__simple_expression] = STATE(4806),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16744),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(7870),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(4607),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(6041),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1835),
    [sym_block_comment] = STATE(1835),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_COLON] = ACTIONS(1058),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1080),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1836] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18004),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1836),
    [sym_block_comment] = STATE(1836),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3782),
    [anon_sym_RPAREN] = ACTIONS(3784),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1837] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16864),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1837),
    [sym_block_comment] = STATE(1837),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3786),
    [anon_sym_RPAREN] = ACTIONS(3788),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1838] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18006),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1838),
    [sym_block_comment] = STATE(1838),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3790),
    [anon_sym_RPAREN] = ACTIONS(3792),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1839] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16865),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1839),
    [sym_block_comment] = STATE(1839),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3794),
    [anon_sym_RPAREN] = ACTIONS(3796),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1840] = {
    [sym_inline_modifier] = STATE(2119),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(14021),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1840),
    [sym_block_comment] = STATE(1840),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_finally] = ACTIONS(1200),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(1200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1841] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17673),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1841),
    [sym_block_comment] = STATE(1841),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3798),
    [anon_sym_RPAREN] = ACTIONS(3800),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1842] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17469),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1842),
    [sym_block_comment] = STATE(1842),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3802),
    [anon_sym_RPAREN] = ACTIONS(3804),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1843] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17775),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1843),
    [sym_block_comment] = STATE(1843),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3806),
    [anon_sym_RPAREN] = ACTIONS(3808),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1844] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17231),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1844),
    [sym_block_comment] = STATE(1844),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3810),
    [anon_sym_RPAREN] = ACTIONS(3812),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1845] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17979),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1845),
    [sym_block_comment] = STATE(1845),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3814),
    [anon_sym_RPAREN] = ACTIONS(3816),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1846] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17522),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1846),
    [sym_block_comment] = STATE(1846),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3818),
    [anon_sym_RPAREN] = ACTIONS(3820),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1847] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(16126),
    [sym__simple_expression] = STATE(6150),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17012),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10069),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(5723),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(8607),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1847),
    [sym_block_comment] = STATE(1847),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(2060),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2064),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1848] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17712),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1848),
    [sym_block_comment] = STATE(1848),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3822),
    [anon_sym_RPAREN] = ACTIONS(3824),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1849] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17969),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1849),
    [sym_block_comment] = STATE(1849),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3826),
    [anon_sym_RPAREN] = ACTIONS(3828),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1850] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17575),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1850),
    [sym_block_comment] = STATE(1850),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3830),
    [anon_sym_RPAREN] = ACTIONS(3832),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1851] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17938),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1851),
    [sym_block_comment] = STATE(1851),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3834),
    [anon_sym_RPAREN] = ACTIONS(3836),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1852] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10013),
    [sym_expression] = STATE(16158),
    [sym__simple_expression] = STATE(7278),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16888),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10484),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6751),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(9367),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1852),
    [sym_block_comment] = STATE(1852),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_COLON] = ACTIONS(1816),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_match] = ACTIONS(912),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(1838),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1853] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17742),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1853),
    [sym_block_comment] = STATE(1853),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3838),
    [anon_sym_RPAREN] = ACTIONS(3840),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1854] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17633),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1854),
    [sym_block_comment] = STATE(1854),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3842),
    [anon_sym_RPAREN] = ACTIONS(3844),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1855] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17901),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1855),
    [sym_block_comment] = STATE(1855),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3846),
    [anon_sym_RPAREN] = ACTIONS(3848),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1856] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16764),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1856),
    [sym_block_comment] = STATE(1856),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_using] = ACTIONS(3850),
    [anon_sym_RPAREN] = ACTIONS(3852),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1857] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14441),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1857),
    [sym_block_comment] = STATE(1857),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3854),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1858] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14515),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1858),
    [sym_block_comment] = STATE(1858),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3858),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1859] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14572),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1859),
    [sym_block_comment] = STATE(1859),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3860),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1860] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14436),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1860),
    [sym_block_comment] = STATE(1860),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3862),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1861] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14453),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1861),
    [sym_block_comment] = STATE(1861),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3864),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1862] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14579),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1862),
    [sym_block_comment] = STATE(1862),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3866),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1863] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14552),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1863),
    [sym_block_comment] = STATE(1863),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1864] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14528),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1864),
    [sym_block_comment] = STATE(1864),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3870),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1865] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14445),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1865),
    [sym_block_comment] = STATE(1865),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3872),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1866] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14510),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1866),
    [sym_block_comment] = STATE(1866),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3874),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1867] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14566),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1867),
    [sym_block_comment] = STATE(1867),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3876),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1868] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14567),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1868),
    [sym_block_comment] = STATE(1868),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3878),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1869] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14597),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1869),
    [sym_block_comment] = STATE(1869),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3880),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1870] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14560),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1870),
    [sym_block_comment] = STATE(1870),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3882),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1871] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14518),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1871),
    [sym_block_comment] = STATE(1871),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3884),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1872] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14519),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1872),
    [sym_block_comment] = STATE(1872),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3886),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1873] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14446),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1873),
    [sym_block_comment] = STATE(1873),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3864),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1874] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14472),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1874),
    [sym_block_comment] = STATE(1874),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3888),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1875] = {
    [sym_inline_modifier] = STATE(2181),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14157),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1875),
    [sym_block_comment] = STATE(1875),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(1200),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1876] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14509),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1876),
    [sym_block_comment] = STATE(1876),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3890),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1877] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14533),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1877),
    [sym_block_comment] = STATE(1877),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3892),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1878] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14504),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1878),
    [sym_block_comment] = STATE(1878),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3894),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1879] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14460),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1879),
    [sym_block_comment] = STATE(1879),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3896),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1880] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14508),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1880),
    [sym_block_comment] = STATE(1880),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3864),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1881] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14456),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1881),
    [sym_block_comment] = STATE(1881),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3898),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1882] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14157),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1882),
    [sym_block_comment] = STATE(1882),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_LBRACK] = ACTIONS(1202),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(1200),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_match] = ACTIONS(1200),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1883] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14583),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1883),
    [sym_block_comment] = STATE(1883),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3900),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1884] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14523),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1884),
    [sym_block_comment] = STATE(1884),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3902),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1885] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14511),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_binding] = STATE(15220),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(7942),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10272),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1885),
    [sym_block_comment] = STATE(1885),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3904),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3856),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1886] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18083),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1886),
    [sym_block_comment] = STATE(1886),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1887] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18321),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1887),
    [sym_block_comment] = STATE(1887),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1888] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17305),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1888),
    [sym_block_comment] = STATE(1888),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1889] = {
    [sym_inline_modifier] = STATE(2361),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12404),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1889),
    [sym_block_comment] = STATE(1889),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_yield] = ACTIONS(3906),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1890] = {
    [sym_inline_modifier] = STATE(2208),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(13894),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1890),
    [sym_block_comment] = STATE(1890),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_yield] = ACTIONS(3908),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1891] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17026),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1891),
    [sym_block_comment] = STATE(1891),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1892] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17408),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1892),
    [sym_block_comment] = STATE(1892),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1893] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1893),
    [sym_block_comment] = STATE(1893),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3910),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1894] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18245),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1894),
    [sym_block_comment] = STATE(1894),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1895] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17132),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1895),
    [sym_block_comment] = STATE(1895),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1896] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17352),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1896),
    [sym_block_comment] = STATE(1896),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1897] = {
    [sym_inline_modifier] = STATE(2280),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12661),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1897),
    [sym_block_comment] = STATE(1897),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_yield] = ACTIONS(3912),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1898] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17914),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1898),
    [sym_block_comment] = STATE(1898),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1899] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18257),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1899),
    [sym_block_comment] = STATE(1899),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1900] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17402),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1900),
    [sym_block_comment] = STATE(1900),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1901] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1901),
    [sym_block_comment] = STATE(1901),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3914),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1902] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18271),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1902),
    [sym_block_comment] = STATE(1902),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1903] = {
    [sym_inline_modifier] = STATE(2186),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13599),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1903),
    [sym_block_comment] = STATE(1903),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_yield] = ACTIONS(3916),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1904] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17456),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1904),
    [sym_block_comment] = STATE(1904),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1905] = {
    [sym_inline_modifier] = STATE(2395),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(13637),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(1905),
    [sym_block_comment] = STATE(1905),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_yield] = ACTIONS(3918),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [1906] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18283),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1906),
    [sym_block_comment] = STATE(1906),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1907] = {
    [sym_inline_modifier] = STATE(2266),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(12975),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(1907),
    [sym_block_comment] = STATE(1907),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_yield] = ACTIONS(3920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [1908] = {
    [sym_inline_modifier] = STATE(2338),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12386),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1908),
    [sym_block_comment] = STATE(1908),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_yield] = ACTIONS(3922),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1909] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1909),
    [sym_block_comment] = STATE(1909),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3924),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1910] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17455),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1910),
    [sym_block_comment] = STATE(1910),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1911] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1911),
    [sym_block_comment] = STATE(1911),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3926),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1912] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18215),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1912),
    [sym_block_comment] = STATE(1912),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1913] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17223),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1913),
    [sym_block_comment] = STATE(1913),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1914] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17510),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1914),
    [sym_block_comment] = STATE(1914),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1915] = {
    [sym_inline_modifier] = STATE(2257),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13114),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1915),
    [sym_block_comment] = STATE(1915),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_yield] = ACTIONS(3928),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1916] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18298),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1916),
    [sym_block_comment] = STATE(1916),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1917] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18256),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1917),
    [sym_block_comment] = STATE(1917),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1918] = {
    [sym_inline_modifier] = STATE(2352),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13114),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1918),
    [sym_block_comment] = STATE(1918),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_yield] = ACTIONS(3930),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [1919] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18199),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1919),
    [sym_block_comment] = STATE(1919),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1920] = {
    [sym_inline_modifier] = STATE(2155),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(13975),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1920),
    [sym_block_comment] = STATE(1920),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_yield] = ACTIONS(3932),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1921] = {
    [sym_inline_modifier] = STATE(2274),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12386),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(1921),
    [sym_block_comment] = STATE(1921),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_yield] = ACTIONS(3934),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [1922] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17548),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1922),
    [sym_block_comment] = STATE(1922),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1923] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17509),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1923),
    [sym_block_comment] = STATE(1923),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1924] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16976),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1924),
    [sym_block_comment] = STATE(1924),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1925] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17174),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1925),
    [sym_block_comment] = STATE(1925),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1926] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17365),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1926),
    [sym_block_comment] = STATE(1926),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1927] = {
    [sym_inline_modifier] = STATE(2273),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14271),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1927),
    [sym_block_comment] = STATE(1927),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_yield] = ACTIONS(3936),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1928] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1928),
    [sym_block_comment] = STATE(1928),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3938),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1929] = {
    [sym_inline_modifier] = STATE(2372),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12404),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1929),
    [sym_block_comment] = STATE(1929),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_yield] = ACTIONS(3940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [1930] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1930),
    [sym_block_comment] = STATE(1930),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3942),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1931] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18311),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1931),
    [sym_block_comment] = STATE(1931),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1932] = {
    [sym_inline_modifier] = STATE(2289),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(13686),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(1932),
    [sym_block_comment] = STATE(1932),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_yield] = ACTIONS(3944),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [1933] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17600),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1933),
    [sym_block_comment] = STATE(1933),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1934] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17120),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1934),
    [sym_block_comment] = STATE(1934),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1935] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18323),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1935),
    [sym_block_comment] = STATE(1935),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1936] = {
    [sym_inline_modifier] = STATE(2119),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(13894),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1936),
    [sym_block_comment] = STATE(1936),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_yield] = ACTIONS(3946),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1937] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17652),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1937),
    [sym_block_comment] = STATE(1937),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1938] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17562),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1938),
    [sym_block_comment] = STATE(1938),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1939] = {
    [sym_inline_modifier] = STATE(2168),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13172),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(1939),
    [sym_block_comment] = STATE(1939),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_yield] = ACTIONS(3948),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [1940] = {
    [sym_inline_modifier] = STATE(2244),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14271),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1940),
    [sym_block_comment] = STATE(1940),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_yield] = ACTIONS(3950),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1941] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1941),
    [sym_block_comment] = STATE(1941),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3952),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1942] = {
    [sym_inline_modifier] = STATE(2174),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12492),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1942),
    [sym_block_comment] = STATE(1942),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_yield] = ACTIONS(3954),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [1943] = {
    [sym_inline_modifier] = STATE(2182),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12661),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1943),
    [sym_block_comment] = STATE(1943),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_yield] = ACTIONS(3956),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1944] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17676),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1944),
    [sym_block_comment] = STATE(1944),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1945] = {
    [sym_inline_modifier] = STATE(2149),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(13850),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1945),
    [sym_block_comment] = STATE(1945),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_yield] = ACTIONS(3958),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1946] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18187),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1946),
    [sym_block_comment] = STATE(1946),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1947] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17068),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1947),
    [sym_block_comment] = STATE(1947),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1948] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17717),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1948),
    [sym_block_comment] = STATE(1948),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1949] = {
    [sym_inline_modifier] = STATE(2373),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12497),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1949),
    [sym_block_comment] = STATE(1949),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_yield] = ACTIONS(3960),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1950] = {
    [sym_inline_modifier] = STATE(2161),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(13975),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(1950),
    [sym_block_comment] = STATE(1950),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_yield] = ACTIONS(3962),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [1951] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17620),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1951),
    [sym_block_comment] = STATE(1951),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1952] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1952),
    [sym_block_comment] = STATE(1952),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3964),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1953] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18341),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1953),
    [sym_block_comment] = STATE(1953),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1954] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18173),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1954),
    [sym_block_comment] = STATE(1954),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1955] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17754),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1955),
    [sym_block_comment] = STATE(1955),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1956] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17013),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1956),
    [sym_block_comment] = STATE(1956),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1957] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1957),
    [sym_block_comment] = STATE(1957),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3966),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1958] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17784),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1958),
    [sym_block_comment] = STATE(1958),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1959] = {
    [sym_inline_modifier] = STATE(2127),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14271),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(1959),
    [sym_block_comment] = STATE(1959),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_yield] = ACTIONS(3968),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [1960] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17320),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1960),
    [sym_block_comment] = STATE(1960),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1961] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17806),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1961),
    [sym_block_comment] = STATE(1961),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1962] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16975),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1962),
    [sym_block_comment] = STATE(1962),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1963] = {
    [sym_inline_modifier] = STATE(2104),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(13894),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(1963),
    [sym_block_comment] = STATE(1963),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_yield] = ACTIONS(3970),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [1964] = {
    [sym_inline_modifier] = STATE(2379),
    [sym_block] = STATE(10013),
    [sym_expression] = STATE(14413),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(1964),
    [sym_block_comment] = STATE(1964),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_yield] = ACTIONS(3972),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [1965] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1965),
    [sym_block_comment] = STATE(1965),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3974),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1966] = {
    [sym_inline_modifier] = STATE(2215),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13433),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(1966),
    [sym_block_comment] = STATE(1966),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_yield] = ACTIONS(3976),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [1967] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17833),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1967),
    [sym_block_comment] = STATE(1967),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1968] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18232),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1968),
    [sym_block_comment] = STATE(1968),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1969] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14166),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1969),
    [sym_block_comment] = STATE(1969),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_yield] = ACTIONS(3978),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1970] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17663),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1970),
    [sym_block_comment] = STATE(1970),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1971] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1971),
    [sym_block_comment] = STATE(1971),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3980),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1972] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16923),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1972),
    [sym_block_comment] = STATE(1972),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1973] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17851),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1973),
    [sym_block_comment] = STATE(1973),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1974] = {
    [sym_inline_modifier] = STATE(2108),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12661),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(1974),
    [sym_block_comment] = STATE(1974),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_yield] = ACTIONS(3982),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [1975] = {
    [sym_inline_modifier] = STATE(2394),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11723),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1975),
    [sym_block_comment] = STATE(1975),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_yield] = ACTIONS(3984),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1976] = {
    [sym_inline_modifier] = STATE(2304),
    [sym_block] = STATE(9672),
    [sym_expression] = STATE(14059),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(1976),
    [sym_block_comment] = STATE(1976),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_yield] = ACTIONS(3986),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [1977] = {
    [sym_inline_modifier] = STATE(2122),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12497),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(1977),
    [sym_block_comment] = STATE(1977),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_yield] = ACTIONS(3988),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [1978] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17074),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1978),
    [sym_block_comment] = STATE(1978),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1979] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16929),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1979),
    [sym_block_comment] = STATE(1979),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1980] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17269),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1980),
    [sym_block_comment] = STATE(1980),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1981] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1981),
    [sym_block_comment] = STATE(1981),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3990),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1982] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17886),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1982),
    [sym_block_comment] = STATE(1982),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1983] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16825),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1983),
    [sym_block_comment] = STATE(1983),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1984] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17910),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1984),
    [sym_block_comment] = STATE(1984),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1985] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17705),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1985),
    [sym_block_comment] = STATE(1985),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1986] = {
    [sym_inline_modifier] = STATE(2126),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11723),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(1986),
    [sym_block_comment] = STATE(1986),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_yield] = ACTIONS(3992),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [1987] = {
    [sym_inline_modifier] = STATE(2326),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(14595),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(1987),
    [sym_block_comment] = STATE(1987),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_yield] = ACTIONS(3994),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [1988] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18361),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1988),
    [sym_block_comment] = STATE(1988),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1989] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16826),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1989),
    [sym_block_comment] = STATE(1989),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1990] = {
    [sym_inline_modifier] = STATE(2410),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(13850),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(1990),
    [sym_block_comment] = STATE(1990),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_yield] = ACTIONS(3996),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [1991] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18160),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1991),
    [sym_block_comment] = STATE(1991),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1992] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17924),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1992),
    [sym_block_comment] = STATE(1992),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1993] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18148),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1993),
    [sym_block_comment] = STATE(1993),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1994] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18374),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1994),
    [sym_block_comment] = STATE(1994),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1995] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1995),
    [sym_block_comment] = STATE(1995),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(3998),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1996] = {
    [sym_inline_modifier] = STATE(2301),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13599),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(1996),
    [sym_block_comment] = STATE(1996),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_yield] = ACTIONS(4000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [1997] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1997),
    [sym_block_comment] = STATE(1997),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4002),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1998] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17937),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1998),
    [sym_block_comment] = STATE(1998),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [1999] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17957),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(1999),
    [sym_block_comment] = STATE(1999),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2000] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18389),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2000),
    [sym_block_comment] = STATE(2000),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2001] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17964),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2001),
    [sym_block_comment] = STATE(2001),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2002] = {
    [sym_inline_modifier] = STATE(2138),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13433),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(2002),
    [sym_block_comment] = STATE(2002),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_yield] = ACTIONS(4004),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2003] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18136),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2003),
    [sym_block_comment] = STATE(2003),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2004] = {
    [sym_inline_modifier] = STATE(2400),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(13686),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(2004),
    [sym_block_comment] = STATE(2004),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_yield] = ACTIONS(4006),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [2005] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17971),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2005),
    [sym_block_comment] = STATE(2005),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2006] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16778),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2006),
    [sym_block_comment] = STATE(2006),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2007] = {
    [sym_inline_modifier] = STATE(2404),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(12975),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(2007),
    [sym_block_comment] = STATE(2007),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_yield] = ACTIONS(4008),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [2008] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18404),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2008),
    [sym_block_comment] = STATE(2008),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2009] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2009),
    [sym_block_comment] = STATE(2009),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4010),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2010] = {
    [sym_inline_modifier] = STATE(2148),
    [sym_block] = STATE(10196),
    [sym_expression] = STATE(14301),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2010),
    [sym_block_comment] = STATE(2010),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_yield] = ACTIONS(4012),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [2011] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18120),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2011),
    [sym_block_comment] = STATE(2011),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2012] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18107),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2012),
    [sym_block_comment] = STATE(2012),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2013] = {
    [sym_inline_modifier] = STATE(2218),
    [sym_block] = STATE(8958),
    [sym_expression] = STATE(13916),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2013),
    [sym_block_comment] = STATE(2013),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_yield] = ACTIONS(4014),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [2014] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17990),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2014),
    [sym_block_comment] = STATE(2014),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2015] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18017),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2015),
    [sym_block_comment] = STATE(2015),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2016] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17222),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2016),
    [sym_block_comment] = STATE(2016),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2017] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18482),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2017),
    [sym_block_comment] = STATE(2017),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2018] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18496),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2018),
    [sym_block_comment] = STATE(2018),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2019] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16883),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2019),
    [sym_block_comment] = STATE(2019),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2020] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18097),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2020),
    [sym_block_comment] = STATE(2020),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2021] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2021),
    [sym_block_comment] = STATE(2021),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4016),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2022] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16692),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2022),
    [sym_block_comment] = STATE(2022),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2023] = {
    [sym_inline_modifier] = STATE(2181),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14166),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2023),
    [sym_block_comment] = STATE(2023),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_yield] = ACTIONS(4018),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2024] = {
    [sym_inline_modifier] = STATE(2226),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13172),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(2024),
    [sym_block_comment] = STATE(2024),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_yield] = ACTIONS(4020),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2025] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18038),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2025),
    [sym_block_comment] = STATE(2025),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2026] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18513),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2026),
    [sym_block_comment] = STATE(2026),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2027] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17760),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2027),
    [sym_block_comment] = STATE(2027),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2028] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2028),
    [sym_block_comment] = STATE(2028),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4022),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2029] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2029),
    [sym_block_comment] = STATE(2029),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4024),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2030] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18060),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2030),
    [sym_block_comment] = STATE(2030),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2031] = {
    [sym_inline_modifier] = STATE(2356),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12386),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2031),
    [sym_block_comment] = STATE(2031),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_yield] = ACTIONS(4026),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [2032] = {
    [sym_inline_modifier] = STATE(2272),
    [sym_block] = STATE(9899),
    [sym_expression] = STATE(14172),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2032),
    [sym_block_comment] = STATE(2032),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_yield] = ACTIONS(4028),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [2033] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2033),
    [sym_block_comment] = STATE(2033),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4030),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2034] = {
    [sym_inline_modifier] = STATE(2162),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13114),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2034),
    [sym_block_comment] = STATE(2034),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_yield] = ACTIONS(4032),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2035] = {
    [sym_inline_modifier] = STATE(2180),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11723),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2035),
    [sym_block_comment] = STATE(2035),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_yield] = ACTIONS(4034),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [2036] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18086),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2036),
    [sym_block_comment] = STATE(2036),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2037] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18526),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2037),
    [sym_block_comment] = STATE(2037),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2038] = {
    [sym_inline_modifier] = STATE(2260),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13599),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(2038),
    [sym_block_comment] = STATE(2038),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_yield] = ACTIONS(4036),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [2039] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18078),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2039),
    [sym_block_comment] = STATE(2039),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2040] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18238),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2040),
    [sym_block_comment] = STATE(2040),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2041] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2041),
    [sym_block_comment] = STATE(2041),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4038),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2042] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18102),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2042),
    [sym_block_comment] = STATE(2042),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2043] = {
    [sym_inline_modifier] = STATE(2133),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12492),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(2043),
    [sym_block_comment] = STATE(2043),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_yield] = ACTIONS(4040),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [2044] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18117),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2044),
    [sym_block_comment] = STATE(2044),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2045] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18069),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2045),
    [sym_block_comment] = STATE(2045),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2046] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16718),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2046),
    [sym_block_comment] = STATE(2046),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2047] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18059),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2047),
    [sym_block_comment] = STATE(2047),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2048] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18051),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2048),
    [sym_block_comment] = STATE(2048),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2049] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18507),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2049),
    [sym_block_comment] = STATE(2049),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2050] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18131),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2050),
    [sym_block_comment] = STATE(2050),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2051] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17121),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2051),
    [sym_block_comment] = STATE(2051),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2052] = {
    [sym_inline_modifier] = STATE(2380),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(13637),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(2052),
    [sym_block_comment] = STATE(2052),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [2053] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18145),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2053),
    [sym_block_comment] = STATE(2053),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2054] = {
    [sym_inline_modifier] = STATE(2328),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12492),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(2054),
    [sym_block_comment] = STATE(2054),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_yield] = ACTIONS(4044),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [2055] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2055),
    [sym_block_comment] = STATE(2055),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4046),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2056] = {
    [sym_inline_modifier] = STATE(2200),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13433),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(2056),
    [sym_block_comment] = STATE(2056),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_yield] = ACTIONS(4048),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2057] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16836),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2057),
    [sym_block_comment] = STATE(2057),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2058] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2058),
    [sym_block_comment] = STATE(2058),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4050),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2059] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2059),
    [sym_block_comment] = STATE(2059),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4052),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2060] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18157),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2060),
    [sym_block_comment] = STATE(2060),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2061] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18042),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2061),
    [sym_block_comment] = STATE(2061),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2062] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2062),
    [sym_block_comment] = STATE(2062),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4054),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2063] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18171),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2063),
    [sym_block_comment] = STATE(2063),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2064] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18185),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2064),
    [sym_block_comment] = STATE(2064),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2065] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18197),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2065),
    [sym_block_comment] = STATE(2065),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2066] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18492),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2066),
    [sym_block_comment] = STATE(2066),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2067] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16748),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2067),
    [sym_block_comment] = STATE(2067),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2068] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18480),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2068),
    [sym_block_comment] = STATE(2068),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2069] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18034),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2069),
    [sym_block_comment] = STATE(2069),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2070] = {
    [sym_inline_modifier] = STATE(2360),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13172),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(2070),
    [sym_block_comment] = STATE(2070),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_yield] = ACTIONS(4056),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2071] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18399),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2071),
    [sym_block_comment] = STATE(2071),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2072] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18210),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2072),
    [sym_block_comment] = STATE(2072),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2073] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18228),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2073),
    [sym_block_comment] = STATE(2073),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2074] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18024),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2074),
    [sym_block_comment] = STATE(2074),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2075] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18309),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2075),
    [sym_block_comment] = STATE(2075),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2076] = {
    [sym_inline_modifier] = STATE(2276),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12404),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2076),
    [sym_block_comment] = STATE(2076),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_yield] = ACTIONS(4058),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [2077] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18243),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2077),
    [sym_block_comment] = STATE(2077),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2078] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18018),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2078),
    [sym_block_comment] = STATE(2078),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2079] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2079),
    [sym_block_comment] = STATE(2079),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4060),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2080] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14166),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2080),
    [sym_block_comment] = STATE(2080),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_yield] = ACTIONS(4062),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2081] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18386),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2081),
    [sym_block_comment] = STATE(2081),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2082] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18295),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2082),
    [sym_block_comment] = STATE(2082),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2083] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18269),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2083),
    [sym_block_comment] = STATE(2083),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2084] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18371),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2084),
    [sym_block_comment] = STATE(2084),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2085] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18356),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2085),
    [sym_block_comment] = STATE(2085),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2086] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18014),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2086),
    [sym_block_comment] = STATE(2086),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2087] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2087),
    [sym_block_comment] = STATE(2087),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4064),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2088] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(16789),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2088),
    [sym_block_comment] = STATE(2088),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2089] = {
    [sym_inline_modifier] = STATE(2132),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13114),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2089),
    [sym_block_comment] = STATE(2089),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_yield] = ACTIONS(4066),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2090] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2090),
    [sym_block_comment] = STATE(2090),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_RPAREN] = ACTIONS(4068),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2091] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18281),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2091),
    [sym_block_comment] = STATE(2091),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2092] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17173),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2092),
    [sym_block_comment] = STATE(2092),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2093] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18339),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2093),
    [sym_block_comment] = STATE(2093),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2094] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17826),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2094),
    [sym_block_comment] = STATE(2094),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2095] = {
    [sym_inline_modifier] = STATE(2196),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12497),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2095),
    [sym_block_comment] = STATE(2095),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_yield] = ACTIONS(4070),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [2096] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(18253),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2096),
    [sym_block_comment] = STATE(2096),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2097] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14571),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym__exprs_in_parens] = STATE(17999),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2097),
    [sym_block_comment] = STATE(2097),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2098] = {
    [sym_inline_modifier] = STATE(2356),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12372),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2098),
    [sym_block_comment] = STATE(2098),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [2099] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15050),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2099),
    [sym_block_comment] = STATE(2099),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2100] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15076),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2100),
    [sym_block_comment] = STATE(2100),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2101] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14753),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2101),
    [sym_block_comment] = STATE(2101),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2102] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14835),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2102),
    [sym_block_comment] = STATE(2102),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2103] = {
    [sym_inline_modifier] = STATE(2196),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12494),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2103),
    [sym_block_comment] = STATE(2103),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [2104] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16375),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2104),
    [sym_block_comment] = STATE(2104),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4072),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2105] = {
    [sym_inline_modifier] = STATE(2226),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13113),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(2105),
    [sym_block_comment] = STATE(2105),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2106] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15000),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2106),
    [sym_block_comment] = STATE(2106),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2107] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9672),
    [sym_expression] = STATE(15936),
    [sym__simple_expression] = STATE(6311),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10487),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17196),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10121),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5655),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8866),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2107),
    [sym_block_comment] = STATE(2107),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(1536),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [2108] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16342),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2108),
    [sym_block_comment] = STATE(2108),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4074),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2109] = {
    [sym_inline_modifier] = STATE(2133),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12519),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(2109),
    [sym_block_comment] = STATE(2109),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [2110] = {
    [sym_inline_modifier] = STATE(2273),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14258),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(2110),
    [sym_block_comment] = STATE(2110),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2111] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(16112),
    [sym__simple_expression] = STATE(5093),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17154),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4750),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6445),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2111),
    [sym_block_comment] = STATE(2111),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1152),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [2112] = {
    [sym_inline_modifier] = STATE(2272),
    [sym_block] = STATE(9899),
    [sym_expression] = STATE(14070),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2112),
    [sym_block_comment] = STATE(2112),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [2113] = {
    [sym_inline_modifier] = STATE(2186),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13411),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(2113),
    [sym_block_comment] = STATE(2113),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [2114] = {
    [sym_inline_modifier] = STATE(2200),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13537),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(2114),
    [sym_block_comment] = STATE(2114),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2115] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10013),
    [sym_expression] = STATE(16158),
    [sym__simple_expression] = STATE(7304),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16888),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6751),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(9367),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2115),
    [sym_block_comment] = STATE(2115),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(1838),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [2116] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(16244),
    [sym__simple_expression] = STATE(5402),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(9590),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16742),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9316),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(4907),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(7410),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2116),
    [sym_block_comment] = STATE(2116),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1592),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2117] = {
    [sym_inline_modifier] = STATE(2266),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(13009),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(2117),
    [sym_block_comment] = STATE(2117),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [2118] = {
    [sym_inline_modifier] = STATE(2226),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13181),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(2118),
    [sym_block_comment] = STATE(2118),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2119] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16375),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2119),
    [sym_block_comment] = STATE(2119),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4076),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2120] = {
    [sym_inline_modifier] = STATE(2186),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13444),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(2120),
    [sym_block_comment] = STATE(2120),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [2121] = {
    [sym_inline_modifier] = STATE(2168),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13403),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(2121),
    [sym_block_comment] = STATE(2121),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2122] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16309),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2122),
    [sym_block_comment] = STATE(2122),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4078),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2123] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15054),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2123),
    [sym_block_comment] = STATE(2123),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2124] = {
    [sym_inline_modifier] = STATE(2266),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(12997),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(2124),
    [sym_block_comment] = STATE(2124),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [2125] = {
    [sym_inline_modifier] = STATE(2208),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(13729),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(2125),
    [sym_block_comment] = STATE(2125),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [2126] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16276),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2126),
    [sym_block_comment] = STATE(2126),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4080),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2127] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16131),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2127),
    [sym_block_comment] = STATE(2127),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(858),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2128] = {
    [sym_inline_modifier] = STATE(2208),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(14026),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(2128),
    [sym_block_comment] = STATE(2128),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [2129] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10947),
    [sym_expression] = STATE(16186),
    [sym__simple_expression] = STATE(9574),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10947),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10947),
    [sym_call_expression] = STATE(10947),
    [sym_field_expression] = STATE(10947),
    [sym_instance_expression] = STATE(10947),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16917),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(10947),
    [sym_parenthesized_expression] = STATE(10947),
    [sym_splice_expression] = STATE(10947),
    [sym_quote_expression] = STATE(10947),
    [sym_identifier] = STATE(9570),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10882),
    [sym__non_null_literal] = STATE(10947),
    [sym_boolean_literal] = STATE(11114),
    [sym_interpolated_string_expression] = STATE(10947),
    [sym_string] = STATE(11114),
    [sym_unit] = STATE(10947),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2129),
    [sym_block_comment] = STATE(2129),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(3312),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(3316),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3318),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(3320),
    [anon_sym_SQUOTE] = ACTIONS(3322),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3324),
    [sym_integer_literal] = ACTIONS(3326),
    [sym_floating_point_literal] = ACTIONS(3328),
    [anon_sym_true] = ACTIONS(3330),
    [anon_sym_false] = ACTIONS(3330),
    [sym_character_literal] = ACTIONS(3328),
    [sym_null_literal] = ACTIONS(3332),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(3334),
    [sym__simple_string] = ACTIONS(3334),
  },
  [2130] = {
    [sym_inline_modifier] = STATE(2155),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(14023),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(2130),
    [sym_block_comment] = STATE(2130),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [2131] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(16045),
    [sym__simple_expression] = STATE(4593),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(7586),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17201),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(7412),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4460),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(5146),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2131),
    [sym_block_comment] = STATE(2131),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1008),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [2132] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15227),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2132),
    [sym_block_comment] = STATE(2132),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(896),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2133] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16172),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2133),
    [sym_block_comment] = STATE(2133),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4082),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2134] = {
    [sym_inline_modifier] = STATE(2272),
    [sym_block] = STATE(9899),
    [sym_expression] = STATE(14128),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2134),
    [sym_block_comment] = STATE(2134),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [2135] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15877),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2135),
    [sym_block_comment] = STATE(2135),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4084),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2136] = {
    [sym_inline_modifier] = STATE(2395),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(13421),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(2136),
    [sym_block_comment] = STATE(2136),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [2137] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14864),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2137),
    [sym_block_comment] = STATE(2137),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2138] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16207),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2138),
    [sym_block_comment] = STATE(2138),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4086),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2139] = {
    [sym_inline_modifier] = STATE(2360),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13181),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(2139),
    [sym_block_comment] = STATE(2139),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2140] = {
    [sym_inline_modifier] = STATE(2361),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12436),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2140),
    [sym_block_comment] = STATE(2140),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [2141] = {
    [sym_inline_modifier] = STATE(2208),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(13947),
    [sym__simple_expression] = STATE(8295),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16484),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11167),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8270),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10020),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(2141),
    [sym_block_comment] = STATE(2141),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2350),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2354),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2358),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2360),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2362),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [2142] = {
    [sym_inline_modifier] = STATE(2215),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13694),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(2142),
    [sym_block_comment] = STATE(2142),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2143] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(16217),
    [sym__simple_expression] = STATE(4749),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16744),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(4607),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(6041),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2143),
    [sym_block_comment] = STATE(2143),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1080),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [2144] = {
    [sym_inline_modifier] = STATE(2360),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13113),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(2144),
    [sym_block_comment] = STATE(2144),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2145] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(16271),
    [sym__simple_expression] = STATE(5423),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(9922),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16847),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9102),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(4951),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(6940),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2145),
    [sym_block_comment] = STATE(2145),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1248),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [2146] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9899),
    [sym_expression] = STATE(15993),
    [sym__simple_expression] = STATE(6753),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17307),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5779),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8461),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2146),
    [sym_block_comment] = STATE(2146),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1662),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [2147] = {
    [sym_inline_modifier] = STATE(2289),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(13588),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(2147),
    [sym_block_comment] = STATE(2147),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [2148] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16309),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2148),
    [sym_block_comment] = STATE(2148),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4088),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2149] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16159),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2149),
    [sym_block_comment] = STATE(2149),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4090),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2150] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15064),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2150),
    [sym_block_comment] = STATE(2150),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2151] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14853),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2151),
    [sym_block_comment] = STATE(2151),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2152] = {
    [sym_inline_modifier] = STATE(2280),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12769),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(2152),
    [sym_block_comment] = STATE(2152),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [2153] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14958),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2153),
    [sym_block_comment] = STATE(2153),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2154] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14778),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2154),
    [sym_block_comment] = STATE(2154),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2155] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16322),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2155),
    [sym_block_comment] = STATE(2155),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4092),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2156] = {
    [sym_inline_modifier] = STATE(2352),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13080),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2156),
    [sym_block_comment] = STATE(2156),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2157] = {
    [sym_inline_modifier] = STATE(2133),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12502),
    [sym__simple_expression] = STATE(6640),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16407),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10347),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5614),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8667),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(2157),
    [sym_block_comment] = STATE(2157),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(1922),
    [anon_sym_while] = ACTIONS(1924),
    [anon_sym_for] = ACTIONS(1926),
    [anon_sym_try] = ACTIONS(1928),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(1930),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1934),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(1936),
    [anon_sym_throw] = ACTIONS(1938),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [2158] = {
    [sym_inline_modifier] = STATE(2361),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12419),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2158),
    [sym_block_comment] = STATE(2158),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [2159] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9899),
    [sym_expression] = STATE(15993),
    [sym__simple_expression] = STATE(6718),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10497),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17307),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10318),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5779),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8461),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2159),
    [sym_block_comment] = STATE(2159),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(1662),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [2160] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(15795),
    [sym__simple_expression] = STATE(5392),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(9722),
    [sym_postfix_expression] = STATE(13707),
    [sym__postfix_expression_choice] = STATE(14072),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9427),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(4736),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(6646),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2160),
    [sym_block_comment] = STATE(2160),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1726),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2161] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16322),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2161),
    [sym_block_comment] = STATE(2161),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4094),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2162] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15227),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2162),
    [sym_block_comment] = STATE(2162),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4096),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2163] = {
    [sym_inline_modifier] = STATE(2410),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(13718),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(2163),
    [sym_block_comment] = STATE(2163),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [2164] = {
    [sym_inline_modifier] = STATE(2132),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13183),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2164),
    [sym_block_comment] = STATE(2164),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2165] = {
    [sym_inline_modifier] = STATE(2276),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12436),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2165),
    [sym_block_comment] = STATE(2165),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [2166] = {
    [sym_inline_modifier] = STATE(2280),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12823),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(2166),
    [sym_block_comment] = STATE(2166),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [2167] = {
    [sym_inline_modifier] = STATE(2352),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13188),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2167),
    [sym_block_comment] = STATE(2167),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2168] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15942),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2168),
    [sym_block_comment] = STATE(2168),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4098),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2169] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(16016),
    [sym__simple_expression] = STATE(6083),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10036),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17175),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9994),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5189),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(7901),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2169),
    [sym_block_comment] = STATE(2169),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1768),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [2170] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14956),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2170),
    [sym_block_comment] = STATE(2170),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2171] = {
    [sym_inline_modifier] = STATE(2272),
    [sym_block] = STATE(9899),
    [sym_expression] = STATE(14202),
    [sym__simple_expression] = STATE(6767),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16510),
    [sym_case_block] = STATE(9899),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(9899),
    [sym_call_expression] = STATE(9899),
    [sym_field_expression] = STATE(9899),
    [sym_instance_expression] = STATE(9899),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(10541),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17671),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(10301),
    [sym_tuple_expression] = STATE(9899),
    [sym_parenthesized_expression] = STATE(9899),
    [sym_splice_expression] = STATE(9899),
    [sym_quote_expression] = STATE(9899),
    [sym_identifier] = STATE(5506),
    [sym__soft_identifier] = STATE(4574),
    [sym_wildcard] = STATE(8812),
    [sym__non_null_literal] = STATE(9899),
    [sym_boolean_literal] = STATE(5668),
    [sym_interpolated_string_expression] = STATE(9899),
    [sym_string] = STATE(5668),
    [sym_unit] = STATE(9899),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2171),
    [sym_block_comment] = STATE(2171),
    [sym__alpha_identifier] = ACTIONS(1638),
    [anon_sym_LBRACE] = ACTIONS(1642),
    [anon_sym__] = ACTIONS(1644),
    [anon_sym_PLUS] = ACTIONS(1646),
    [anon_sym_DASH] = ACTIONS(1646),
    [anon_sym_end] = ACTIONS(1648),
    [anon_sym_if] = ACTIONS(2010),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2014),
    [anon_sym_try] = ACTIONS(2016),
    [anon_sym_new] = ACTIONS(1650),
    [anon_sym_opaque] = ACTIONS(1648),
    [anon_sym_implicit] = ACTIONS(2018),
    [anon_sym_inline] = ACTIONS(1652),
    [anon_sym_infix] = ACTIONS(1648),
    [anon_sym_open] = ACTIONS(1648),
    [anon_sym_transparent] = ACTIONS(1648),
    [anon_sym_LPAREN] = ACTIONS(1654),
    [anon_sym_macro] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(1646),
    [anon_sym_TILDE] = ACTIONS(1646),
    [anon_sym_DOLLAR] = ACTIONS(1656),
    [anon_sym_SQUOTE] = ACTIONS(1658),
    [sym__backquoted_id] = ACTIONS(1660),
    [sym_operator_identifier] = ACTIONS(2022),
    [sym_integer_literal] = ACTIONS(1664),
    [sym_floating_point_literal] = ACTIONS(1666),
    [anon_sym_true] = ACTIONS(1668),
    [anon_sym_false] = ACTIONS(1668),
    [sym_character_literal] = ACTIONS(1666),
    [sym_null_literal] = ACTIONS(1670),
    [anon_sym_return] = ACTIONS(2024),
    [anon_sym_throw] = ACTIONS(2026),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1672),
    [sym__simple_string] = ACTIONS(1672),
  },
  [2172] = {
    [sym_inline_modifier] = STATE(2196),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12619),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2172),
    [sym_block_comment] = STATE(2172),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [2173] = {
    [sym_inline_modifier] = STATE(2200),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13694),
    [sym__simple_expression] = STATE(8037),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16437),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10834),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6981),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9843),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(2173),
    [sym_block_comment] = STATE(2173),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2737),
    [anon_sym_while] = ACTIONS(2739),
    [anon_sym_for] = ACTIONS(2741),
    [anon_sym_try] = ACTIONS(2743),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2745),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3302),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2750),
    [anon_sym_throw] = ACTIONS(2752),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2174] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16172),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2174),
    [sym_block_comment] = STATE(2174),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4100),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2175] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15167),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2175),
    [sym_block_comment] = STATE(2175),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2176] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(16126),
    [sym__simple_expression] = STATE(6897),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10843),
    [sym_postfix_expression] = STATE(14282),
    [sym__postfix_expression_choice] = STATE(14760),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10492),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(5723),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(8607),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2176),
    [sym_block_comment] = STATE(2176),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2064),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2177] = {
    [sym_inline_modifier] = STATE(2276),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12419),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2177),
    [sym_block_comment] = STATE(2177),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [2178] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(16084),
    [sym__simple_expression] = STATE(5866),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17027),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5338),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(7797),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2178),
    [sym_block_comment] = STATE(2178),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(1698),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [2179] = {
    [sym_inline_modifier] = STATE(2372),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12452),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2179),
    [sym_block_comment] = STATE(2179),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [2180] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16276),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2180),
    [sym_block_comment] = STATE(2180),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4102),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2181] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15877),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2181),
    [sym_block_comment] = STATE(2181),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4104),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2182] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16342),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2182),
    [sym_block_comment] = STATE(2182),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4106),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2183] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15020),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2183),
    [sym_block_comment] = STATE(2183),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2184] = {
    [sym_inline_modifier] = STATE(2266),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(13051),
    [sym__simple_expression] = STATE(5415),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16460),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9489),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(5043),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(7348),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(2184),
    [sym_block_comment] = STATE(2184),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(1204),
    [anon_sym_while] = ACTIONS(1206),
    [anon_sym_for] = ACTIONS(1208),
    [anon_sym_try] = ACTIONS(1210),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1212),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1216),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1218),
    [anon_sym_throw] = ACTIONS(1220),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [2185] = {
    [sym_inline_modifier] = STATE(2218),
    [sym_block] = STATE(8958),
    [sym_expression] = STATE(13928),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2185),
    [sym_block_comment] = STATE(2185),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [2186] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16080),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2186),
    [sym_block_comment] = STATE(2186),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4108),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2187] = {
    [sym_inline_modifier] = STATE(2380),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(13480),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(2187),
    [sym_block_comment] = STATE(2187),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [2188] = {
    [sym_inline_modifier] = STATE(2181),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14161),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2188),
    [sym_block_comment] = STATE(2188),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2189] = {
    [sym_inline_modifier] = STATE(2380),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(13542),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(2189),
    [sym_block_comment] = STATE(2189),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [2190] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(16016),
    [sym__simple_expression] = STATE(5916),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17175),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5189),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(7901),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2190),
    [sym_block_comment] = STATE(2190),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1768),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [2191] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14909),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2191),
    [sym_block_comment] = STATE(2191),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2192] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(15815),
    [sym__simple_expression] = STATE(4550),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(7516),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17217),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(7494),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4479),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(5143),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2192),
    [sym_block_comment] = STATE(2192),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(972),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [2193] = {
    [sym_inline_modifier] = STATE(2132),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13225),
    [sym__simple_expression] = STATE(7035),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16418),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10719),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10640),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6711),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9196),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2193),
    [sym_block_comment] = STATE(2193),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(597),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(601),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(609),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(611),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(613),
    [anon_sym_throw] = ACTIONS(615),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2194] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14991),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2194),
    [sym_block_comment] = STATE(2194),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2195] = {
    [sym_inline_modifier] = STATE(2274),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12442),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2195),
    [sym_block_comment] = STATE(2195),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [2196] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16309),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2196),
    [sym_block_comment] = STATE(2196),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4110),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2197] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(16217),
    [sym__simple_expression] = STATE(4776),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(8530),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16744),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(7801),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(4607),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(6041),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2197),
    [sym_block_comment] = STATE(2197),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(1080),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [2198] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(16244),
    [sym__simple_expression] = STATE(5433),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16742),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(4907),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(7410),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2198),
    [sym_block_comment] = STATE(2198),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1592),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2199] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8958),
    [sym_expression] = STATE(16299),
    [sym__simple_expression] = STATE(6075),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10229),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16871),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9983),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5485),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8150),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2199),
    [sym_block_comment] = STATE(2199),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1304),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [2200] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16207),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2200),
    [sym_block_comment] = STATE(2200),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4112),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2201] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15075),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2201),
    [sym_block_comment] = STATE(2201),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2202] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15135),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2202),
    [sym_block_comment] = STATE(2202),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2203] = {
    [sym_inline_modifier] = STATE(2162),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13080),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2203),
    [sym_block_comment] = STATE(2203),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2204] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14789),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2204),
    [sym_block_comment] = STATE(2204),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2205] = {
    [sym_inline_modifier] = STATE(2338),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12372),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2205),
    [sym_block_comment] = STATE(2205),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [2206] = {
    [sym_inline_modifier] = STATE(2338),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12363),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2206),
    [sym_block_comment] = STATE(2206),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [2207] = {
    [sym_inline_modifier] = STATE(2328),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12502),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(2207),
    [sym_block_comment] = STATE(2207),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [2208] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16375),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2208),
    [sym_block_comment] = STATE(2208),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4114),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2209] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(16126),
    [sym__simple_expression] = STATE(6197),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17012),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(5723),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(8607),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2209),
    [sym_block_comment] = STATE(2209),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2064),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2210] = {
    [sym_inline_modifier] = STATE(2244),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14175),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(2210),
    [sym_block_comment] = STATE(2210),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2211] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14831),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2211),
    [sym_block_comment] = STATE(2211),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2212] = {
    [sym_inline_modifier] = STATE(2162),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13225),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2212),
    [sym_block_comment] = STATE(2212),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2213] = {
    [sym_inline_modifier] = STATE(2395),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(13542),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(2213),
    [sym_block_comment] = STATE(2213),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [2214] = {
    [sym_inline_modifier] = STATE(2328),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12519),
    [sym__simple_expression] = STATE(5569),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16440),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9847),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5136),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8036),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(2214),
    [sym_block_comment] = STATE(2214),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2894),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2210),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2214),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2216),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2218),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [2215] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16207),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2215),
    [sym_block_comment] = STATE(2215),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4116),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2216] = {
    [sym_inline_modifier] = STATE(2162),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13183),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2216),
    [sym_block_comment] = STATE(2216),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2217] = {
    [sym_inline_modifier] = STATE(2196),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12479),
    [sym__simple_expression] = STATE(5556),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16482),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9807),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5127),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8061),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2217),
    [sym_block_comment] = STATE(2217),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2368),
    [anon_sym_while] = ACTIONS(2370),
    [anon_sym_for] = ACTIONS(2372),
    [anon_sym_try] = ACTIONS(2374),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(2376),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(2378),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(2380),
    [anon_sym_throw] = ACTIONS(2382),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [2218] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16276),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2218),
    [sym_block_comment] = STATE(2218),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4118),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2219] = {
    [sym_inline_modifier] = STATE(2395),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(13480),
    [sym__simple_expression] = STATE(5544),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16552),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9794),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5112),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8082),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(2219),
    [sym_block_comment] = STATE(2219),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(1800),
    [anon_sym_for] = ACTIONS(1802),
    [anon_sym_try] = ACTIONS(1804),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1806),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1808),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1810),
    [anon_sym_throw] = ACTIONS(1812),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [2220] = {
    [sym_inline_modifier] = STATE(2289),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(13539),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(2220),
    [sym_block_comment] = STATE(2220),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [2221] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15185),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2221),
    [sym_block_comment] = STATE(2221),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2222] = {
    [sym_inline_modifier] = STATE(2119),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(13947),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(2222),
    [sym_block_comment] = STATE(2222),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [2223] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14979),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2223),
    [sym_block_comment] = STATE(2223),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2224] = {
    [sym_inline_modifier] = STATE(2352),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13183),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2224),
    [sym_block_comment] = STATE(2224),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2225] = {
    [sym_inline_modifier] = STATE(2155),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(14049),
    [sym__simple_expression] = STATE(6706),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16453),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10168),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5545),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8695),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(2225),
    [sym_block_comment] = STATE(2225),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(3206),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2286),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2290),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2292),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2294),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [2226] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15942),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2226),
    [sym_block_comment] = STATE(2226),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4120),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2227] = {
    [sym_inline_modifier] = STATE(2361),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12452),
    [sym__simple_expression] = STATE(5103),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16555),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(8943),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4893),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6781),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2227),
    [sym_block_comment] = STATE(2227),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(1604),
    [anon_sym_for] = ACTIONS(1606),
    [anon_sym_try] = ACTIONS(1608),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1610),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1612),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1614),
    [anon_sym_throw] = ACTIONS(1616),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [2228] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(15210),
    [sym__simple_expression] = STATE(8031),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(7123),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9805),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2228),
    [sym_block_comment] = STATE(2228),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(2248),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [2229] = {
    [sym_inline_modifier] = STATE(2404),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(13009),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(2229),
    [sym_block_comment] = STATE(2229),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [2230] = {
    [sym_inline_modifier] = STATE(2186),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13645),
    [sym__simple_expression] = STATE(6345),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16459),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10216),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5855),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(8486),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(2230),
    [sym_block_comment] = STATE(2230),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(1902),
    [anon_sym_while] = ACTIONS(1904),
    [anon_sym_for] = ACTIONS(1906),
    [anon_sym_try] = ACTIONS(1908),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(1910),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1914),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(1916),
    [anon_sym_throw] = ACTIONS(1918),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [2231] = {
    [sym_inline_modifier] = STATE(2352),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13225),
    [sym__simple_expression] = STATE(6545),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16568),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10091),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5724),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8623),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2231),
    [sym_block_comment] = STATE(2231),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(3174),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2318),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2322),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2324),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2326),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2232] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(16271),
    [sym__simple_expression] = STATE(5492),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16847),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(4951),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(6940),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2232),
    [sym_block_comment] = STATE(2232),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1248),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [2233] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(16112),
    [sym__simple_expression] = STATE(4988),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(9564),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17154),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8556),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4750),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6445),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2233),
    [sym_block_comment] = STATE(2233),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1152),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [2234] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10196),
    [sym_expression] = STATE(16326),
    [sym__simple_expression] = STATE(6985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10835),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16895),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10511),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6685),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9359),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2234),
    [sym_block_comment] = STATE(2234),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2104),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [2235] = {
    [sym_inline_modifier] = STATE(2338),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12442),
    [sym__simple_expression] = STATE(5138),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16539),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9149),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4915),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7011),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2235),
    [sym_block_comment] = STATE(2235),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(1958),
    [anon_sym_for] = ACTIONS(1960),
    [anon_sym_try] = ACTIONS(1962),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1964),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1966),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1968),
    [anon_sym_throw] = ACTIONS(1970),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [2236] = {
    [sym_inline_modifier] = STATE(2149),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(13933),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(2236),
    [sym_block_comment] = STATE(2236),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [2237] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14219),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2237),
    [sym_block_comment] = STATE(2237),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2238] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(16126),
    [sym__simple_expression] = STATE(6197),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17012),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(5723),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(8607),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2238),
    [sym_block_comment] = STATE(2238),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2064),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2239] = {
    [sym_inline_modifier] = STATE(2244),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14204),
    [sym__simple_expression] = STATE(7602),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16465),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10860),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(7395),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9855),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(2239),
    [sym_block_comment] = STATE(2239),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(515),
    [anon_sym_while] = ACTIONS(517),
    [anon_sym_for] = ACTIONS(519),
    [anon_sym_try] = ACTIONS(521),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(3268),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(555),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(565),
    [anon_sym_throw] = ACTIONS(567),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2240] = {
    [sym_inline_modifier] = STATE(2273),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14241),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(2240),
    [sym_block_comment] = STATE(2240),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2241] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14804),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2241),
    [sym_block_comment] = STATE(2241),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2242] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15094),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2242),
    [sym_block_comment] = STATE(2242),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2243] = {
    [sym_inline_modifier] = STATE(2289),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(13712),
    [sym__simple_expression] = STATE(5909),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16384),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(10008),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5169),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8193),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(2243),
    [sym_block_comment] = STATE(2243),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(1404),
    [anon_sym_while] = ACTIONS(1406),
    [anon_sym_for] = ACTIONS(1408),
    [anon_sym_try] = ACTIONS(1410),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(1412),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(1416),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(1418),
    [anon_sym_throw] = ACTIONS(1420),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [2244] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16131),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2244),
    [sym_block_comment] = STATE(2244),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(902),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2245] = {
    [sym_inline_modifier] = STATE(2148),
    [sym_block] = STATE(10196),
    [sym_expression] = STATE(14349),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2245),
    [sym_block_comment] = STATE(2245),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [2246] = {
    [sym_inline_modifier] = STATE(2174),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12519),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(2246),
    [sym_block_comment] = STATE(2246),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [2247] = {
    [sym_inline_modifier] = STATE(2148),
    [sym_block] = STATE(10196),
    [sym_expression] = STATE(14325),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2247),
    [sym_block_comment] = STATE(2247),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [2248] = {
    [sym_inline_modifier] = STATE(2182),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12887),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(2248),
    [sym_block_comment] = STATE(2248),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [2249] = {
    [sym_inline_modifier] = STATE(2404),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(12997),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(2249),
    [sym_block_comment] = STATE(2249),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [2250] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15173),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2250),
    [sym_block_comment] = STATE(2250),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2251] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14911),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2251),
    [sym_block_comment] = STATE(2251),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2252] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15088),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2252),
    [sym_block_comment] = STATE(2252),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2253] = {
    [sym_inline_modifier] = STATE(2149),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(13817),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(2253),
    [sym_block_comment] = STATE(2253),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [2254] = {
    [sym_inline_modifier] = STATE(2360),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13403),
    [sym__simple_expression] = STATE(6782),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16496),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10368),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6644),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9097),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(2254),
    [sym_block_comment] = STATE(2254),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2334),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2338),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2342),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2346),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2255] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15118),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2255),
    [sym_block_comment] = STATE(2255),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2256] = {
    [sym_inline_modifier] = STATE(2104),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(13947),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(2256),
    [sym_block_comment] = STATE(2256),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [2257] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15227),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2257),
    [sym_block_comment] = STATE(2257),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(898),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2258] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14912),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2258),
    [sym_block_comment] = STATE(2258),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2259] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14779),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2259),
    [sym_block_comment] = STATE(2259),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2260] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16080),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2260),
    [sym_block_comment] = STATE(2260),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4122),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2261] = {
    [sym_inline_modifier] = STATE(2260),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13411),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(2261),
    [sym_block_comment] = STATE(2261),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [2262] = {
    [sym_inline_modifier] = STATE(2273),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14204),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(2262),
    [sym_block_comment] = STATE(2262),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2263] = {
    [sym_inline_modifier] = STATE(2148),
    [sym_block] = STATE(10196),
    [sym_expression] = STATE(14318),
    [sym__simple_expression] = STATE(6827),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16489),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(10712),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16791),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10412),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6523),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9076),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2263),
    [sym_block_comment] = STATE(2263),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(2088),
    [anon_sym_DASH] = ACTIONS(2088),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2266),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2270),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(2274),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(2276),
    [anon_sym_BANG] = ACTIONS(2088),
    [anon_sym_TILDE] = ACTIONS(2088),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2278),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2282),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [2264] = {
    [sym_inline_modifier] = STATE(2273),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14175),
    [sym__simple_expression] = STATE(6814),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16596),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10867),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10403),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6680),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9054),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(2264),
    [sym_block_comment] = STATE(2264),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(3118),
    [anon_sym_while] = ACTIONS(2925),
    [anon_sym_for] = ACTIONS(2927),
    [anon_sym_try] = ACTIONS(2929),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2931),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(547),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2933),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(2935),
    [anon_sym_throw] = ACTIONS(2937),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2265] = {
    [sym_inline_modifier] = STATE(2174),
    [sym_block] = STATE(7233),
    [sym_expression] = STATE(12502),
    [sym__simple_expression] = STATE(5578),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16467),
    [sym_case_block] = STATE(7233),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(7233),
    [sym_call_expression] = STATE(7233),
    [sym_field_expression] = STATE(7233),
    [sym_instance_expression] = STATE(7233),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(8685),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17252),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(9966),
    [sym_tuple_expression] = STATE(7233),
    [sym_parenthesized_expression] = STATE(7233),
    [sym_splice_expression] = STATE(7233),
    [sym_quote_expression] = STATE(7233),
    [sym_identifier] = STATE(5140),
    [sym__soft_identifier] = STATE(5063),
    [sym_wildcard] = STATE(8213),
    [sym__non_null_literal] = STATE(7233),
    [sym_boolean_literal] = STATE(6900),
    [sym_interpolated_string_expression] = STATE(7233),
    [sym_string] = STATE(6900),
    [sym_unit] = STATE(7233),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(2265),
    [sym_block_comment] = STATE(2265),
    [sym__alpha_identifier] = ACTIONS(1056),
    [anon_sym_LBRACE] = ACTIONS(1060),
    [anon_sym__] = ACTIONS(1062),
    [anon_sym_PLUS] = ACTIONS(1064),
    [anon_sym_DASH] = ACTIONS(1064),
    [anon_sym_end] = ACTIONS(1066),
    [anon_sym_if] = ACTIONS(2720),
    [anon_sym_while] = ACTIONS(2028),
    [anon_sym_for] = ACTIONS(2030),
    [anon_sym_try] = ACTIONS(2032),
    [anon_sym_new] = ACTIONS(1068),
    [anon_sym_opaque] = ACTIONS(1066),
    [anon_sym_implicit] = ACTIONS(2034),
    [anon_sym_inline] = ACTIONS(1070),
    [anon_sym_infix] = ACTIONS(1066),
    [anon_sym_open] = ACTIONS(1066),
    [anon_sym_transparent] = ACTIONS(1066),
    [anon_sym_LPAREN] = ACTIONS(1072),
    [anon_sym_macro] = ACTIONS(1932),
    [anon_sym_BANG] = ACTIONS(1064),
    [anon_sym_TILDE] = ACTIONS(1064),
    [anon_sym_DOLLAR] = ACTIONS(1074),
    [anon_sym_SQUOTE] = ACTIONS(1076),
    [sym__backquoted_id] = ACTIONS(1078),
    [sym_operator_identifier] = ACTIONS(2036),
    [sym_integer_literal] = ACTIONS(1082),
    [sym_floating_point_literal] = ACTIONS(1084),
    [anon_sym_true] = ACTIONS(1086),
    [anon_sym_false] = ACTIONS(1086),
    [sym_character_literal] = ACTIONS(1084),
    [sym_null_literal] = ACTIONS(1088),
    [anon_sym_return] = ACTIONS(2038),
    [anon_sym_throw] = ACTIONS(2040),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1090),
    [sym__simple_string] = ACTIONS(1090),
  },
  [2266] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16238),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2266),
    [sym_block_comment] = STATE(2266),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4124),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2267] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9672),
    [sym_expression] = STATE(15936),
    [sym__simple_expression] = STATE(6533),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17196),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5655),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8866),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2267),
    [sym_block_comment] = STATE(2267),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(1536),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [2268] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(15745),
    [sym__simple_expression] = STATE(4928),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(9488),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17238),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8629),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(4744),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(6749),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2268),
    [sym_block_comment] = STATE(2268),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1188),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2269] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(15210),
    [sym__simple_expression] = STATE(7936),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10921),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17817),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10851),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(7123),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9805),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2269),
    [sym_block_comment] = STATE(2269),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(2248),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [2270] = {
    [sym_inline_modifier] = STATE(2119),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(13729),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(2270),
    [sym_block_comment] = STATE(2270),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [2271] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14810),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2271),
    [sym_block_comment] = STATE(2271),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2272] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16012),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2272),
    [sym_block_comment] = STATE(2272),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4126),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2273] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16131),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2273),
    [sym_block_comment] = STATE(2273),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4128),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2274] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16012),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2274),
    [sym_block_comment] = STATE(2274),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4130),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2275] = {
    [sym_inline_modifier] = STATE(2119),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(14026),
    [sym__simple_expression] = STATE(8712),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16630),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(11037),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(8072),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(10161),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(2275),
    [sym_block_comment] = STATE(2275),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2406),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2410),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2414),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2416),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2418),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [2276] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16046),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2276),
    [sym_block_comment] = STATE(2276),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4132),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2277] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15087),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2277),
    [sym_block_comment] = STATE(2277),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2278] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14875),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2278),
    [sym_block_comment] = STATE(2278),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2279] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15877),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2279),
    [sym_block_comment] = STATE(2279),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4134),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2280] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16342),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2280),
    [sym_block_comment] = STATE(2280),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4136),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2281] = {
    [sym_inline_modifier] = STATE(2356),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12363),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2281),
    [sym_block_comment] = STATE(2281),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [2282] = {
    [sym_inline_modifier] = STATE(2372),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12436),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2282),
    [sym_block_comment] = STATE(2282),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [2283] = {
    [sym_inline_modifier] = STATE(2373),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12619),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2283),
    [sym_block_comment] = STATE(2283),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [2284] = {
    [sym_inline_modifier] = STATE(2274),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12372),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2284),
    [sym_block_comment] = STATE(2284),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [2285] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(16084),
    [sym__simple_expression] = STATE(5719),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10300),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17027),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9901),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(5338),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(7797),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2285),
    [sym_block_comment] = STATE(2285),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(1698),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [2286] = {
    [sym_inline_modifier] = STATE(2138),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13694),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(2286),
    [sym_block_comment] = STATE(2286),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2287] = {
    [sym_inline_modifier] = STATE(2260),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13444),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(2287),
    [sym_block_comment] = STATE(2287),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [2288] = {
    [sym_inline_modifier] = STATE(2149),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(13718),
    [sym__simple_expression] = STATE(6765),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16433),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10327),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(6067),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8560),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(2288),
    [sym_block_comment] = STATE(2288),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(1882),
    [anon_sym_while] = ACTIONS(1884),
    [anon_sym_for] = ACTIONS(1886),
    [anon_sym_try] = ACTIONS(1888),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(1890),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(1894),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(1896),
    [anon_sym_throw] = ACTIONS(1898),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [2289] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16242),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2289),
    [sym_block_comment] = STATE(2289),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4138),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2290] = {
    [sym_inline_modifier] = STATE(2326),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(14570),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2290),
    [sym_block_comment] = STATE(2290),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [2291] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(16246),
    [sym__simple_expression] = STATE(5716),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17005),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(5368),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(7971),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2291),
    [sym_block_comment] = STATE(2291),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(1998),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [2292] = {
    [sym_inline_modifier] = STATE(2226),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13403),
    [sym__simple_expression] = STATE(6031),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16428),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(9956),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(5224),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(7731),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(2292),
    [sym_block_comment] = STATE(2292),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(1548),
    [anon_sym_while] = ACTIONS(1550),
    [anon_sym_for] = ACTIONS(1552),
    [anon_sym_try] = ACTIONS(1554),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(1556),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1560),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(1562),
    [anon_sym_throw] = ACTIONS(1564),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2293] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8958),
    [sym_expression] = STATE(16299),
    [sym__simple_expression] = STATE(5966),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16871),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5485),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8150),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2293),
    [sym_block_comment] = STATE(2293),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1304),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [2294] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(16355),
    [sym__simple_expression] = STATE(4504),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(6879),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16939),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(6500),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4434),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(4827),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2294),
    [sym_block_comment] = STATE(2294),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(936),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [2295] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14818),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2295),
    [sym_block_comment] = STATE(2295),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2296] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14869),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2296),
    [sym_block_comment] = STATE(2296),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2297] = {
    [sym_inline_modifier] = STATE(2138),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13537),
    [sym__simple_expression] = STATE(8222),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16560),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10686),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(6801),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(9971),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(2297),
    [sym_block_comment] = STATE(2297),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(2660),
    [anon_sym_while] = ACTIONS(2662),
    [anon_sym_for] = ACTIONS(2664),
    [anon_sym_try] = ACTIONS(2666),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(2668),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(3308),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(2682),
    [anon_sym_throw] = ACTIONS(2684),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2298] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14866),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2298),
    [sym_block_comment] = STATE(2298),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2299] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14820),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2299),
    [sym_block_comment] = STATE(2299),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2300] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(16086),
    [sym__simple_expression] = STATE(5236),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(9759),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17078),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9376),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5073),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(6993),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2300),
    [sym_block_comment] = STATE(2300),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1448),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [2301] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16080),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2301),
    [sym_block_comment] = STATE(2301),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4140),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2302] = {
    [sym_inline_modifier] = STATE(2410),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(13933),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(2302),
    [sym_block_comment] = STATE(2302),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [2303] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15149),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2303),
    [sym_block_comment] = STATE(2303),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2304] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16046),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2304),
    [sym_block_comment] = STATE(2304),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4142),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2305] = {
    [sym_inline_modifier] = STATE(2372),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12419),
    [sym__simple_expression] = STATE(5118),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16543),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9327),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4971),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(6937),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2305),
    [sym_block_comment] = STATE(2305),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(2426),
    [anon_sym_while] = ACTIONS(1850),
    [anon_sym_for] = ACTIONS(1852),
    [anon_sym_try] = ACTIONS(1854),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1856),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1858),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1860),
    [anon_sym_throw] = ACTIONS(1862),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [2306] = {
    [sym_inline_modifier] = STATE(2180),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11725),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2306),
    [sym_block_comment] = STATE(2306),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [2307] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14161),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2307),
    [sym_block_comment] = STATE(2307),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2308] = {
    [sym_inline_modifier] = STATE(2410),
    [sym_block] = STATE(9117),
    [sym_expression] = STATE(13817),
    [sym__simple_expression] = STATE(6710),
    [sym_lambda_expression] = STATE(14137),
    [sym_if_expression] = STATE(14137),
    [sym_match_expression] = STATE(14137),
    [sym_try_expression] = STATE(14137),
    [sym_bindings] = STATE(16521),
    [sym_case_block] = STATE(9117),
    [sym_assignment_expression] = STATE(14137),
    [sym_generic_function] = STATE(9117),
    [sym_call_expression] = STATE(9117),
    [sym_field_expression] = STATE(9117),
    [sym_instance_expression] = STATE(9117),
    [sym_ascription_expression] = STATE(14137),
    [sym_infix_expression] = STATE(10325),
    [sym_postfix_expression] = STATE(13885),
    [sym__postfix_expression_choice] = STATE(17070),
    [sym_macro_body] = STATE(14137),
    [sym_prefix_expression] = STATE(10162),
    [sym_tuple_expression] = STATE(9117),
    [sym_parenthesized_expression] = STATE(9117),
    [sym_splice_expression] = STATE(9117),
    [sym_quote_expression] = STATE(9117),
    [sym_identifier] = STATE(5543),
    [sym__soft_identifier] = STATE(6200),
    [sym_wildcard] = STATE(8682),
    [sym__non_null_literal] = STATE(9117),
    [sym_boolean_literal] = STATE(9101),
    [sym_interpolated_string_expression] = STATE(9117),
    [sym_string] = STATE(9101),
    [sym_unit] = STATE(9117),
    [sym_return_expression] = STATE(14137),
    [sym_throw_expression] = STATE(14137),
    [sym_while_expression] = STATE(14137),
    [sym_do_while_expression] = STATE(14137),
    [sym_for_expression] = STATE(14137),
    [sym_comment] = STATE(2308),
    [sym_block_comment] = STATE(2308),
    [sym__alpha_identifier] = ACTIONS(1744),
    [anon_sym_LBRACE] = ACTIONS(1748),
    [anon_sym__] = ACTIONS(1750),
    [anon_sym_PLUS] = ACTIONS(1752),
    [anon_sym_DASH] = ACTIONS(1752),
    [anon_sym_end] = ACTIONS(1754),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2192),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(1756),
    [anon_sym_opaque] = ACTIONS(1754),
    [anon_sym_implicit] = ACTIONS(2196),
    [anon_sym_inline] = ACTIONS(1758),
    [anon_sym_infix] = ACTIONS(1754),
    [anon_sym_open] = ACTIONS(1754),
    [anon_sym_transparent] = ACTIONS(1754),
    [anon_sym_LPAREN] = ACTIONS(1760),
    [anon_sym_macro] = ACTIONS(1892),
    [anon_sym_BANG] = ACTIONS(1752),
    [anon_sym_TILDE] = ACTIONS(1752),
    [anon_sym_DOLLAR] = ACTIONS(1762),
    [anon_sym_SQUOTE] = ACTIONS(1764),
    [sym__backquoted_id] = ACTIONS(1766),
    [sym_operator_identifier] = ACTIONS(2198),
    [sym_integer_literal] = ACTIONS(1770),
    [sym_floating_point_literal] = ACTIONS(1772),
    [anon_sym_true] = ACTIONS(1774),
    [anon_sym_false] = ACTIONS(1774),
    [sym_character_literal] = ACTIONS(1772),
    [sym_null_literal] = ACTIONS(1776),
    [anon_sym_return] = ACTIONS(2200),
    [anon_sym_throw] = ACTIONS(2202),
    [anon_sym_do] = ACTIONS(1900),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1778),
    [sym__simple_string] = ACTIONS(1778),
  },
  [2309] = {
    [sym_inline_modifier] = STATE(2182),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12769),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(2309),
    [sym_block_comment] = STATE(2309),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [2310] = {
    [sym_inline_modifier] = STATE(2400),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(13712),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(2310),
    [sym_block_comment] = STATE(2310),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [2311] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(15610),
    [sym__simple_expression] = STATE(5171),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17280),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(4921),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(6901),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2311),
    [sym_block_comment] = STATE(2311),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1360),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [2312] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14821),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2312),
    [sym_block_comment] = STATE(2312),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2313] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15019),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2313),
    [sym_block_comment] = STATE(2313),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2314] = {
    [sym_inline_modifier] = STATE(2394),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11725),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2314),
    [sym_block_comment] = STATE(2314),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [2315] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(15795),
    [sym__simple_expression] = STATE(4920),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17619),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(4736),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(6646),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2315),
    [sym_block_comment] = STATE(2315),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1726),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2316] = {
    [sym_inline_modifier] = STATE(2356),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12442),
    [sym__simple_expression] = STATE(5133),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16397),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9148),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4919),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(6826),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2316),
    [sym_block_comment] = STATE(2316),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(1386),
    [anon_sym_for] = ACTIONS(1388),
    [anon_sym_try] = ACTIONS(1390),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1392),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1396),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1398),
    [anon_sym_throw] = ACTIONS(1400),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [2317] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10947),
    [sym_expression] = STATE(16186),
    [sym__simple_expression] = STATE(9381),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10947),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10947),
    [sym_call_expression] = STATE(10947),
    [sym_field_expression] = STATE(10947),
    [sym_instance_expression] = STATE(10947),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(11521),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16600),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11322),
    [sym_tuple_expression] = STATE(10947),
    [sym_parenthesized_expression] = STATE(10947),
    [sym_splice_expression] = STATE(10947),
    [sym_quote_expression] = STATE(10947),
    [sym_identifier] = STATE(9570),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10882),
    [sym__non_null_literal] = STATE(10947),
    [sym_boolean_literal] = STATE(11114),
    [sym_interpolated_string_expression] = STATE(10947),
    [sym_string] = STATE(11114),
    [sym_unit] = STATE(10947),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2317),
    [sym_block_comment] = STATE(2317),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(3312),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(3314),
    [anon_sym_DASH] = ACTIONS(3314),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(3316),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(3318),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(3314),
    [anon_sym_TILDE] = ACTIONS(3314),
    [anon_sym_DOLLAR] = ACTIONS(3320),
    [anon_sym_SQUOTE] = ACTIONS(3322),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3324),
    [sym_integer_literal] = ACTIONS(3326),
    [sym_floating_point_literal] = ACTIONS(3328),
    [anon_sym_true] = ACTIONS(3330),
    [anon_sym_false] = ACTIONS(3330),
    [sym_character_literal] = ACTIONS(3328),
    [sym_null_literal] = ACTIONS(3332),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(3334),
    [sym__simple_string] = ACTIONS(3334),
  },
  [2318] = {
    [sym_inline_modifier] = STATE(2182),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12823),
    [sym__simple_expression] = STATE(6703),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16664),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10171),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5547),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8701),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(2318),
    [sym_block_comment] = STATE(2318),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2430),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2434),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2438),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2440),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2442),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [2319] = {
    [sym_inline_modifier] = STATE(2379),
    [sym_block] = STATE(10013),
    [sym_expression] = STATE(14290),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(2319),
    [sym_block_comment] = STATE(2319),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [2320] = {
    [sym_inline_modifier] = STATE(2380),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(13421),
    [sym__simple_expression] = STATE(5847),
    [sym_lambda_expression] = STATE(13759),
    [sym_if_expression] = STATE(13759),
    [sym_match_expression] = STATE(13759),
    [sym_try_expression] = STATE(13759),
    [sym_bindings] = STATE(16528),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(13759),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(13759),
    [sym_infix_expression] = STATE(9791),
    [sym_postfix_expression] = STATE(13617),
    [sym__postfix_expression_choice] = STATE(17259),
    [sym_macro_body] = STATE(13759),
    [sym_prefix_expression] = STATE(9789),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(5106),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(8196),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(13759),
    [sym_throw_expression] = STATE(13759),
    [sym_while_expression] = STATE(13759),
    [sym_do_while_expression] = STATE(13759),
    [sym_for_expression] = STATE(13759),
    [sym_comment] = STATE(2320),
    [sym_block_comment] = STATE(2320),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(1618),
    [anon_sym_while] = ACTIONS(1620),
    [anon_sym_for] = ACTIONS(1622),
    [anon_sym_try] = ACTIONS(1624),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(1626),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(1628),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1630),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(1632),
    [anon_sym_throw] = ACTIONS(1634),
    [anon_sym_do] = ACTIONS(1636),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [2321] = {
    [sym_inline_modifier] = STATE(2122),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12619),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2321),
    [sym_block_comment] = STATE(2321),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [2322] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14928),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2322),
    [sym_block_comment] = STATE(2322),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2323] = {
    [sym_inline_modifier] = STATE(2181),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14219),
    [sym__simple_expression] = STATE(9037),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16517),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11271),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8878),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10627),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2323),
    [sym_block_comment] = STATE(2323),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(3020),
    [anon_sym_while] = ACTIONS(3022),
    [anon_sym_for] = ACTIONS(3024),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(3028),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3306),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(3033),
    [anon_sym_throw] = ACTIONS(3035),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2324] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(15795),
    [sym__simple_expression] = STATE(5149),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(9975),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17619),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9025),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(4736),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(6646),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2324),
    [sym_block_comment] = STATE(2324),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1726),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2325] = {
    [sym_inline_modifier] = STATE(2215),
    [sym_block] = STATE(8679),
    [sym_expression] = STATE(13537),
    [sym__simple_expression] = STATE(6269),
    [sym_lambda_expression] = STATE(13774),
    [sym_if_expression] = STATE(13774),
    [sym_match_expression] = STATE(13774),
    [sym_try_expression] = STATE(13774),
    [sym_bindings] = STATE(16394),
    [sym_case_block] = STATE(8679),
    [sym_assignment_expression] = STATE(13774),
    [sym_generic_function] = STATE(8679),
    [sym_call_expression] = STATE(8679),
    [sym_field_expression] = STATE(8679),
    [sym_instance_expression] = STATE(8679),
    [sym_ascription_expression] = STATE(13774),
    [sym_infix_expression] = STATE(9896),
    [sym_postfix_expression] = STATE(13493),
    [sym__postfix_expression_choice] = STATE(17135),
    [sym_macro_body] = STATE(13774),
    [sym_prefix_expression] = STATE(10257),
    [sym_tuple_expression] = STATE(8679),
    [sym_parenthesized_expression] = STATE(8679),
    [sym_splice_expression] = STATE(8679),
    [sym_quote_expression] = STATE(8679),
    [sym_identifier] = STATE(5933),
    [sym__soft_identifier] = STATE(5783),
    [sym_wildcard] = STATE(8934),
    [sym__non_null_literal] = STATE(8679),
    [sym_boolean_literal] = STATE(8446),
    [sym_interpolated_string_expression] = STATE(8679),
    [sym_string] = STATE(8446),
    [sym_unit] = STATE(8679),
    [sym_return_expression] = STATE(13774),
    [sym_throw_expression] = STATE(13774),
    [sym_while_expression] = STATE(13774),
    [sym_do_while_expression] = STATE(13774),
    [sym_for_expression] = STATE(13774),
    [sym_comment] = STATE(2325),
    [sym_block_comment] = STATE(2325),
    [sym__alpha_identifier] = ACTIONS(1568),
    [anon_sym_LBRACE] = ACTIONS(1572),
    [anon_sym__] = ACTIONS(1574),
    [anon_sym_PLUS] = ACTIONS(1576),
    [anon_sym_DASH] = ACTIONS(1576),
    [anon_sym_end] = ACTIONS(1578),
    [anon_sym_if] = ACTIONS(1780),
    [anon_sym_while] = ACTIONS(1782),
    [anon_sym_for] = ACTIONS(1784),
    [anon_sym_try] = ACTIONS(1786),
    [anon_sym_new] = ACTIONS(1580),
    [anon_sym_opaque] = ACTIONS(1578),
    [anon_sym_implicit] = ACTIONS(1788),
    [anon_sym_inline] = ACTIONS(1582),
    [anon_sym_infix] = ACTIONS(1578),
    [anon_sym_open] = ACTIONS(1578),
    [anon_sym_transparent] = ACTIONS(1578),
    [anon_sym_LPAREN] = ACTIONS(1584),
    [anon_sym_macro] = ACTIONS(1790),
    [anon_sym_BANG] = ACTIONS(1576),
    [anon_sym_TILDE] = ACTIONS(1576),
    [anon_sym_DOLLAR] = ACTIONS(1586),
    [anon_sym_SQUOTE] = ACTIONS(1588),
    [sym__backquoted_id] = ACTIONS(1590),
    [sym_operator_identifier] = ACTIONS(1792),
    [sym_integer_literal] = ACTIONS(1594),
    [sym_floating_point_literal] = ACTIONS(1596),
    [anon_sym_true] = ACTIONS(1598),
    [anon_sym_false] = ACTIONS(1598),
    [sym_character_literal] = ACTIONS(1596),
    [sym_null_literal] = ACTIONS(1600),
    [anon_sym_return] = ACTIONS(1794),
    [anon_sym_throw] = ACTIONS(1796),
    [anon_sym_do] = ACTIONS(1798),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1602),
    [sym__simple_string] = ACTIONS(1602),
  },
  [2326] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15227),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2326),
    [sym_block_comment] = STATE(2326),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(900),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2327] = {
    [sym_inline_modifier] = STATE(2257),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13225),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2327),
    [sym_block_comment] = STATE(2327),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2328] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16172),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2328),
    [sym_block_comment] = STATE(2328),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4144),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2329] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14161),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2329),
    [sym_block_comment] = STATE(2329),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2330] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(16126),
    [sym__simple_expression] = STATE(6994),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10805),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17012),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10590),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(5723),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(8607),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2330),
    [sym_block_comment] = STATE(2330),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2064),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2331] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15177),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2331),
    [sym_block_comment] = STATE(2331),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2332] = {
    [sym_inline_modifier] = STATE(2274),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(12363),
    [sym__simple_expression] = STATE(5671),
    [sym_lambda_expression] = STATE(12443),
    [sym_if_expression] = STATE(12443),
    [sym_match_expression] = STATE(12443),
    [sym_try_expression] = STATE(12443),
    [sym_bindings] = STATE(16487),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(12443),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(12443),
    [sym_infix_expression] = STATE(7604),
    [sym_postfix_expression] = STATE(11738),
    [sym__postfix_expression_choice] = STATE(17546),
    [sym_macro_body] = STATE(12443),
    [sym_prefix_expression] = STATE(9670),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(5177),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(7609),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(12443),
    [sym_throw_expression] = STATE(12443),
    [sym_while_expression] = STATE(12443),
    [sym_do_while_expression] = STATE(12443),
    [sym_for_expression] = STATE(12443),
    [sym_comment] = STATE(2332),
    [sym_block_comment] = STATE(2332),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(992),
    [anon_sym_DASH] = ACTIONS(992),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(1728),
    [anon_sym_while] = ACTIONS(1730),
    [anon_sym_for] = ACTIONS(1732),
    [anon_sym_try] = ACTIONS(1734),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(1736),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(1394),
    [anon_sym_BANG] = ACTIONS(992),
    [anon_sym_TILDE] = ACTIONS(992),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1738),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(1740),
    [anon_sym_throw] = ACTIONS(1742),
    [anon_sym_do] = ACTIONS(1402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [2333] = {
    [sym_inline_modifier] = STATE(2126),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11717),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2333),
    [sym_block_comment] = STATE(2333),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [2334] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(16300),
    [sym__simple_expression] = STATE(4735),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16983),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(4598),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(5819),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2334),
    [sym_block_comment] = STATE(2334),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1116),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [2335] = {
    [sym_inline_modifier] = STATE(2180),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11720),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2335),
    [sym_block_comment] = STATE(2335),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [2336] = {
    [sym_inline_modifier] = STATE(2304),
    [sym_block] = STATE(9672),
    [sym_expression] = STATE(14153),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2336),
    [sym_block_comment] = STATE(2336),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [2337] = {
    [sym_inline_modifier] = STATE(2161),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(14023),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(2337),
    [sym_block_comment] = STATE(2337),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [2338] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16012),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2338),
    [sym_block_comment] = STATE(2338),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4146),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2339] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10196),
    [sym_expression] = STATE(16326),
    [sym__simple_expression] = STATE(6986),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10196),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10196),
    [sym_call_expression] = STATE(10196),
    [sym_field_expression] = STATE(10196),
    [sym_instance_expression] = STATE(10196),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16895),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(10196),
    [sym_parenthesized_expression] = STATE(10196),
    [sym_splice_expression] = STATE(10196),
    [sym_quote_expression] = STATE(10196),
    [sym_identifier] = STATE(6685),
    [sym__soft_identifier] = STATE(4671),
    [sym_wildcard] = STATE(9359),
    [sym__non_null_literal] = STATE(10196),
    [sym_boolean_literal] = STATE(6362),
    [sym_interpolated_string_expression] = STATE(10196),
    [sym_string] = STATE(6362),
    [sym_unit] = STATE(10196),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2339),
    [sym_block_comment] = STATE(2339),
    [sym__alpha_identifier] = ACTIONS(2080),
    [anon_sym_LBRACE] = ACTIONS(2084),
    [anon_sym__] = ACTIONS(2086),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(2092),
    [anon_sym_opaque] = ACTIONS(2090),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym_infix] = ACTIONS(2090),
    [anon_sym_open] = ACTIONS(2090),
    [anon_sym_transparent] = ACTIONS(2090),
    [anon_sym_LPAREN] = ACTIONS(2096),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(2098),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [sym__backquoted_id] = ACTIONS(2102),
    [sym_operator_identifier] = ACTIONS(2104),
    [sym_integer_literal] = ACTIONS(2106),
    [sym_floating_point_literal] = ACTIONS(2108),
    [anon_sym_true] = ACTIONS(2110),
    [anon_sym_false] = ACTIONS(2110),
    [sym_character_literal] = ACTIONS(2108),
    [sym_null_literal] = ACTIONS(2112),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2114),
    [sym__simple_string] = ACTIONS(2114),
  },
  [2340] = {
    [sym_inline_modifier] = STATE(2218),
    [sym_block] = STATE(8958),
    [sym_expression] = STATE(13828),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2340),
    [sym_block_comment] = STATE(2340),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [2341] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(16376),
    [sym__simple_expression] = STATE(4804),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(8336),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16961),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8207),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(4568),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(5737),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2341),
    [sym_block_comment] = STATE(2341),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1044),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [2342] = {
    [sym_inline_modifier] = STATE(2162),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13188),
    [sym__simple_expression] = STATE(6722),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16464),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10050),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(5687),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(8481),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2342),
    [sym_block_comment] = STATE(2342),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(2689),
    [anon_sym_while] = ACTIONS(2691),
    [anon_sym_for] = ACTIONS(2693),
    [anon_sym_try] = ACTIONS(2695),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2697),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(2709),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(2705),
    [anon_sym_throw] = ACTIONS(2707),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2343] = {
    [sym_inline_modifier] = STATE(2276),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(12452),
    [sym__simple_expression] = STATE(5609),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16417),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(7796),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17112),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(9928),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(5245),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(7647),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2343),
    [sym_block_comment] = STATE(2343),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(956),
    [anon_sym_DASH] = ACTIONS(956),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(1460),
    [anon_sym_while] = ACTIONS(1462),
    [anon_sym_for] = ACTIONS(1464),
    [anon_sym_try] = ACTIONS(1466),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(1468),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(1470),
    [anon_sym_BANG] = ACTIONS(956),
    [anon_sym_TILDE] = ACTIONS(956),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(1472),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(1474),
    [anon_sym_throw] = ACTIONS(1476),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [2344] = {
    [sym_inline_modifier] = STATE(2400),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(13588),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(2344),
    [sym_block_comment] = STATE(2344),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [2345] = {
    [sym_inline_modifier] = STATE(2126),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11720),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2345),
    [sym_block_comment] = STATE(2345),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [2346] = {
    [sym_inline_modifier] = STATE(2168),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13181),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(2346),
    [sym_block_comment] = STATE(2346),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2347] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14219),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2347),
    [sym_block_comment] = STATE(2347),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2348] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(15795),
    [sym__simple_expression] = STATE(7032),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10727),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17619),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10635),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(4736),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(6646),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2348),
    [sym_block_comment] = STATE(2348),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(593),
    [anon_sym_DASH] = ACTIONS(593),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(593),
    [anon_sym_TILDE] = ACTIONS(593),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1726),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2349] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15914),
    [sym__simple_expression] = STATE(6405),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10622),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10215),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2349),
    [sym_block_comment] = STATE(2349),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2350] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(16086),
    [sym__simple_expression] = STATE(5232),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17078),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(5073),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(6993),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2350),
    [sym_block_comment] = STATE(2350),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(1448),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [2351] = {
    [sym_inline_modifier] = STATE(2126),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11725),
    [sym__simple_expression] = STATE(5144),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16541),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9070),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4999),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(7371),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2351),
    [sym_block_comment] = STATE(2351),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(1316),
    [anon_sym_while] = ACTIONS(1318),
    [anon_sym_for] = ACTIONS(1320),
    [anon_sym_try] = ACTIONS(1322),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1324),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1328),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1330),
    [anon_sym_throw] = ACTIONS(1332),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [2352] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15227),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2352),
    [sym_block_comment] = STATE(2352),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4148),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2353] = {
    [sym_inline_modifier] = STATE(2400),
    [sym_block] = STATE(8806),
    [sym_expression] = STATE(13539),
    [sym__simple_expression] = STATE(5566),
    [sym_lambda_expression] = STATE(13818),
    [sym_if_expression] = STATE(13818),
    [sym_match_expression] = STATE(13818),
    [sym_try_expression] = STATE(13818),
    [sym_bindings] = STATE(16386),
    [sym_case_block] = STATE(8806),
    [sym_assignment_expression] = STATE(13818),
    [sym_generic_function] = STATE(8806),
    [sym_call_expression] = STATE(8806),
    [sym_field_expression] = STATE(8806),
    [sym_instance_expression] = STATE(8806),
    [sym_ascription_expression] = STATE(13818),
    [sym_infix_expression] = STATE(10007),
    [sym_postfix_expression] = STATE(13679),
    [sym__postfix_expression_choice] = STATE(16959),
    [sym_macro_body] = STATE(13818),
    [sym_prefix_expression] = STATE(9838),
    [sym_tuple_expression] = STATE(8806),
    [sym_parenthesized_expression] = STATE(8806),
    [sym_splice_expression] = STATE(8806),
    [sym_quote_expression] = STATE(8806),
    [sym_identifier] = STATE(5135),
    [sym__soft_identifier] = STATE(6072),
    [sym_wildcard] = STATE(8046),
    [sym__non_null_literal] = STATE(8806),
    [sym_boolean_literal] = STATE(8833),
    [sym_interpolated_string_expression] = STATE(8806),
    [sym_string] = STATE(8833),
    [sym_unit] = STATE(8806),
    [sym_return_expression] = STATE(13818),
    [sym_throw_expression] = STATE(13818),
    [sym_while_expression] = STATE(13818),
    [sym_do_while_expression] = STATE(13818),
    [sym_for_expression] = STATE(13818),
    [sym_comment] = STATE(2353),
    [sym_block_comment] = STATE(2353),
    [sym__alpha_identifier] = ACTIONS(1224),
    [anon_sym_LBRACE] = ACTIONS(1228),
    [anon_sym__] = ACTIONS(1230),
    [anon_sym_PLUS] = ACTIONS(1232),
    [anon_sym_DASH] = ACTIONS(1232),
    [anon_sym_end] = ACTIONS(1234),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2066),
    [anon_sym_for] = ACTIONS(2068),
    [anon_sym_try] = ACTIONS(2070),
    [anon_sym_new] = ACTIONS(1236),
    [anon_sym_opaque] = ACTIONS(1234),
    [anon_sym_implicit] = ACTIONS(2072),
    [anon_sym_inline] = ACTIONS(1238),
    [anon_sym_infix] = ACTIONS(1234),
    [anon_sym_open] = ACTIONS(1234),
    [anon_sym_transparent] = ACTIONS(1234),
    [anon_sym_LPAREN] = ACTIONS(1240),
    [anon_sym_macro] = ACTIONS(1414),
    [anon_sym_BANG] = ACTIONS(1232),
    [anon_sym_TILDE] = ACTIONS(1232),
    [anon_sym_DOLLAR] = ACTIONS(1242),
    [anon_sym_SQUOTE] = ACTIONS(1244),
    [sym__backquoted_id] = ACTIONS(1246),
    [sym_operator_identifier] = ACTIONS(2074),
    [sym_integer_literal] = ACTIONS(1250),
    [sym_floating_point_literal] = ACTIONS(1252),
    [anon_sym_true] = ACTIONS(1254),
    [anon_sym_false] = ACTIONS(1254),
    [sym_character_literal] = ACTIONS(1252),
    [sym_null_literal] = ACTIONS(1256),
    [anon_sym_return] = ACTIONS(2076),
    [anon_sym_throw] = ACTIONS(2078),
    [anon_sym_do] = ACTIONS(1422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1258),
    [sym__simple_string] = ACTIONS(1258),
  },
  [2354] = {
    [sym_inline_modifier] = STATE(2161),
    [sym_block] = STATE(9544),
    [sym_expression] = STATE(14049),
    [sym__simple_expression] = STATE(6274),
    [sym_lambda_expression] = STATE(14110),
    [sym_if_expression] = STATE(14110),
    [sym_match_expression] = STATE(14110),
    [sym_try_expression] = STATE(14110),
    [sym_bindings] = STATE(16683),
    [sym_case_block] = STATE(9544),
    [sym_assignment_expression] = STATE(14110),
    [sym_generic_function] = STATE(9544),
    [sym_call_expression] = STATE(9544),
    [sym_field_expression] = STATE(9544),
    [sym_instance_expression] = STATE(9544),
    [sym_ascription_expression] = STATE(14110),
    [sym_infix_expression] = STATE(10094),
    [sym_postfix_expression] = STATE(13979),
    [sym__postfix_expression_choice] = STATE(16822),
    [sym_macro_body] = STATE(14110),
    [sym_prefix_expression] = STATE(10095),
    [sym_tuple_expression] = STATE(9544),
    [sym_parenthesized_expression] = STATE(9544),
    [sym_splice_expression] = STATE(9544),
    [sym_quote_expression] = STATE(9544),
    [sym_identifier] = STATE(6036),
    [sym__soft_identifier] = STATE(6717),
    [sym_wildcard] = STATE(8884),
    [sym__non_null_literal] = STATE(9544),
    [sym_boolean_literal] = STATE(9358),
    [sym_interpolated_string_expression] = STATE(9544),
    [sym_string] = STATE(9358),
    [sym_unit] = STATE(9544),
    [sym_return_expression] = STATE(14110),
    [sym_throw_expression] = STATE(14110),
    [sym_while_expression] = STATE(14110),
    [sym_do_while_expression] = STATE(14110),
    [sym_for_expression] = STATE(14110),
    [sym_comment] = STATE(2354),
    [sym_block_comment] = STATE(2354),
    [sym__alpha_identifier] = ACTIONS(1674),
    [anon_sym_LBRACE] = ACTIONS(1678),
    [anon_sym__] = ACTIONS(1680),
    [anon_sym_PLUS] = ACTIONS(1682),
    [anon_sym_DASH] = ACTIONS(1682),
    [anon_sym_end] = ACTIONS(1684),
    [anon_sym_if] = ACTIONS(2116),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2120),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(1686),
    [anon_sym_opaque] = ACTIONS(1684),
    [anon_sym_implicit] = ACTIONS(2124),
    [anon_sym_inline] = ACTIONS(1688),
    [anon_sym_infix] = ACTIONS(1684),
    [anon_sym_open] = ACTIONS(1684),
    [anon_sym_transparent] = ACTIONS(1684),
    [anon_sym_LPAREN] = ACTIONS(1690),
    [anon_sym_macro] = ACTIONS(2126),
    [anon_sym_BANG] = ACTIONS(1682),
    [anon_sym_TILDE] = ACTIONS(1682),
    [anon_sym_DOLLAR] = ACTIONS(1692),
    [anon_sym_SQUOTE] = ACTIONS(1694),
    [sym__backquoted_id] = ACTIONS(1696),
    [sym_operator_identifier] = ACTIONS(2128),
    [sym_integer_literal] = ACTIONS(1700),
    [sym_floating_point_literal] = ACTIONS(1702),
    [anon_sym_true] = ACTIONS(1704),
    [anon_sym_false] = ACTIONS(1704),
    [sym_character_literal] = ACTIONS(1702),
    [sym_null_literal] = ACTIONS(1706),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2132),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1708),
    [sym__simple_string] = ACTIONS(1708),
  },
  [2355] = {
    [sym_inline_modifier] = STATE(2379),
    [sym_block] = STATE(10013),
    [sym_expression] = STATE(14320),
    [sym__simple_expression] = STATE(7329),
    [sym_lambda_expression] = STATE(12755),
    [sym_if_expression] = STATE(12755),
    [sym_match_expression] = STATE(12755),
    [sym_try_expression] = STATE(12755),
    [sym_bindings] = STATE(16450),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(12755),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(12755),
    [sym_infix_expression] = STATE(10672),
    [sym_postfix_expression] = STATE(12146),
    [sym__postfix_expression_choice] = STATE(17366),
    [sym_macro_body] = STATE(12755),
    [sym_prefix_expression] = STATE(10369),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6149),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(8953),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(12755),
    [sym_throw_expression] = STATE(12755),
    [sym_while_expression] = STATE(12755),
    [sym_do_while_expression] = STATE(12755),
    [sym_for_expression] = STATE(12755),
    [sym_comment] = STATE(2355),
    [sym_block_comment] = STATE(2355),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(2298),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2302),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(2306),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(2308),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(2310),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2314),
    [anon_sym_do] = ACTIONS(1940),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [2356] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16012),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2356),
    [sym_block_comment] = STATE(2356),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4150),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2357] = {
    [sym_inline_modifier] = STATE(2394),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11717),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2357),
    [sym_block_comment] = STATE(2357),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [2358] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14984),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2358),
    [sym_block_comment] = STATE(2358),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2359] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(16126),
    [sym__simple_expression] = STATE(7374),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10735),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17012),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10442),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(5723),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(8607),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2359),
    [sym_block_comment] = STATE(2359),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(511),
    [anon_sym_DASH] = ACTIONS(511),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(535),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(511),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(2064),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2360] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15942),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2360),
    [sym_block_comment] = STATE(2360),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4152),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2361] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16046),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2361),
    [sym_block_comment] = STATE(2361),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4154),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2362] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(6762),
    [sym_expression] = STATE(15815),
    [sym__simple_expression] = STATE(4599),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(6762),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(6762),
    [sym_call_expression] = STATE(6762),
    [sym_field_expression] = STATE(6762),
    [sym_instance_expression] = STATE(6762),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17217),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(6762),
    [sym_parenthesized_expression] = STATE(6762),
    [sym_splice_expression] = STATE(6762),
    [sym_quote_expression] = STATE(6762),
    [sym_identifier] = STATE(4479),
    [sym__soft_identifier] = STATE(4702),
    [sym_wildcard] = STATE(5143),
    [sym__non_null_literal] = STATE(6762),
    [sym_boolean_literal] = STATE(6446),
    [sym_interpolated_string_expression] = STATE(6762),
    [sym_string] = STATE(6446),
    [sym_unit] = STATE(6762),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2362),
    [sym_block_comment] = STATE(2362),
    [sym__alpha_identifier] = ACTIONS(948),
    [anon_sym_LBRACE] = ACTIONS(952),
    [anon_sym__] = ACTIONS(954),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(958),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(960),
    [anon_sym_opaque] = ACTIONS(958),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(962),
    [anon_sym_infix] = ACTIONS(958),
    [anon_sym_open] = ACTIONS(958),
    [anon_sym_transparent] = ACTIONS(958),
    [anon_sym_LPAREN] = ACTIONS(964),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(966),
    [anon_sym_SQUOTE] = ACTIONS(968),
    [sym__backquoted_id] = ACTIONS(970),
    [sym_operator_identifier] = ACTIONS(972),
    [sym_integer_literal] = ACTIONS(974),
    [sym_floating_point_literal] = ACTIONS(976),
    [anon_sym_true] = ACTIONS(978),
    [anon_sym_false] = ACTIONS(978),
    [sym_character_literal] = ACTIONS(976),
    [sym_null_literal] = ACTIONS(980),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(982),
    [sym__simple_string] = ACTIONS(982),
  },
  [2363] = {
    [sym_inline_modifier] = STATE(2122),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12479),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2363),
    [sym_block_comment] = STATE(2363),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [2364] = {
    [sym_inline_modifier] = STATE(2394),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11720),
    [sym__simple_expression] = STATE(4902),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16531),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8298),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4730),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6669),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2364),
    [sym_block_comment] = STATE(2364),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2242),
    [anon_sym_while] = ACTIONS(1372),
    [anon_sym_for] = ACTIONS(1374),
    [anon_sym_try] = ACTIONS(1376),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1378),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1380),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1382),
    [anon_sym_throw] = ACTIONS(1384),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [2365] = {
    [sym_inline_modifier] = STATE(2301),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13411),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(2365),
    [sym_block_comment] = STATE(2365),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [2366] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15914),
    [sym__simple_expression] = STATE(6377),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2366),
    [sym_block_comment] = STATE(2366),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2367] = {
    [sym_inline_modifier] = STATE(2168),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(13113),
    [sym__simple_expression] = STATE(6946),
    [sym_lambda_expression] = STATE(13468),
    [sym_if_expression] = STATE(13468),
    [sym_match_expression] = STATE(13468),
    [sym_try_expression] = STATE(13468),
    [sym_bindings] = STATE(16446),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(13468),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(13468),
    [sym_infix_expression] = STATE(9044),
    [sym_postfix_expression] = STATE(13289),
    [sym__postfix_expression_choice] = STATE(17133),
    [sym_macro_body] = STATE(13468),
    [sym_prefix_expression] = STATE(10536),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(6726),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(9363),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(13468),
    [sym_throw_expression] = STATE(13468),
    [sym_while_expression] = STATE(13468),
    [sym_do_while_expression] = STATE(13468),
    [sym_for_expression] = STATE(13468),
    [sym_comment] = STATE(2367),
    [sym_block_comment] = STATE(2367),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(1172),
    [anon_sym_DASH] = ACTIONS(1172),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2504),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2508),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(1558),
    [anon_sym_BANG] = ACTIONS(1172),
    [anon_sym_TILDE] = ACTIONS(1172),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(2512),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(2514),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(1566),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2368] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(15795),
    [sym__simple_expression] = STATE(4920),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17619),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(4736),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(6646),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2368),
    [sym_block_comment] = STATE(2368),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1972),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(1726),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2369] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(8837),
    [sym_expression] = STATE(15610),
    [sym__simple_expression] = STATE(5204),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(8837),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(8837),
    [sym_call_expression] = STATE(8837),
    [sym_field_expression] = STATE(8837),
    [sym_instance_expression] = STATE(8837),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(9813),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17280),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(9281),
    [sym_tuple_expression] = STATE(8837),
    [sym_parenthesized_expression] = STATE(8837),
    [sym_splice_expression] = STATE(8837),
    [sym_quote_expression] = STATE(8837),
    [sym_identifier] = STATE(4921),
    [sym__soft_identifier] = STATE(5824),
    [sym_wildcard] = STATE(6901),
    [sym__non_null_literal] = STATE(8837),
    [sym_boolean_literal] = STATE(8349),
    [sym_interpolated_string_expression] = STATE(8837),
    [sym_string] = STATE(8349),
    [sym_unit] = STATE(8837),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2369),
    [sym_block_comment] = STATE(2369),
    [sym__alpha_identifier] = ACTIONS(1336),
    [anon_sym_LBRACE] = ACTIONS(1340),
    [anon_sym__] = ACTIONS(1342),
    [anon_sym_PLUS] = ACTIONS(1344),
    [anon_sym_DASH] = ACTIONS(1344),
    [anon_sym_end] = ACTIONS(1346),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1348),
    [anon_sym_opaque] = ACTIONS(1346),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1350),
    [anon_sym_infix] = ACTIONS(1346),
    [anon_sym_open] = ACTIONS(1346),
    [anon_sym_transparent] = ACTIONS(1346),
    [anon_sym_LPAREN] = ACTIONS(1352),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1344),
    [anon_sym_TILDE] = ACTIONS(1344),
    [anon_sym_DOLLAR] = ACTIONS(1354),
    [anon_sym_SQUOTE] = ACTIONS(1356),
    [sym__backquoted_id] = ACTIONS(1358),
    [sym_operator_identifier] = ACTIONS(1360),
    [sym_integer_literal] = ACTIONS(1362),
    [sym_floating_point_literal] = ACTIONS(1364),
    [anon_sym_true] = ACTIONS(1366),
    [anon_sym_false] = ACTIONS(1366),
    [sym_character_literal] = ACTIONS(1364),
    [sym_null_literal] = ACTIONS(1368),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1370),
    [sym__simple_string] = ACTIONS(1370),
  },
  [2370] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15162),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2370),
    [sym_block_comment] = STATE(2370),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2371] = {
    [sym_inline_modifier] = STATE(2326),
    [sym_block] = STATE(10468),
    [sym_expression] = STATE(14541),
    [sym__simple_expression] = STATE(8121),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16686),
    [sym_case_block] = STATE(10468),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(10468),
    [sym_call_expression] = STATE(10468),
    [sym_field_expression] = STATE(10468),
    [sym_instance_expression] = STATE(10468),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(10945),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(18531),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10800),
    [sym_tuple_expression] = STATE(10468),
    [sym_parenthesized_expression] = STATE(10468),
    [sym_splice_expression] = STATE(10468),
    [sym_quote_expression] = STATE(10468),
    [sym_identifier] = STATE(6922),
    [sym__soft_identifier] = STATE(4608),
    [sym_wildcard] = STATE(9679),
    [sym__non_null_literal] = STATE(10468),
    [sym_boolean_literal] = STATE(6859),
    [sym_interpolated_string_expression] = STATE(10468),
    [sym_string] = STATE(6859),
    [sym_unit] = STATE(10468),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2371),
    [sym_block_comment] = STATE(2371),
    [sym__alpha_identifier] = ACTIONS(9),
    [anon_sym_LBRACE] = ACTIONS(13),
    [anon_sym__] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(33),
    [anon_sym_DASH] = ACTIONS(33),
    [anon_sym_end] = ACTIONS(2246),
    [anon_sym_if] = ACTIONS(37),
    [anon_sym_while] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_new] = ACTIONS(45),
    [anon_sym_opaque] = ACTIONS(2246),
    [anon_sym_implicit] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(67),
    [anon_sym_infix] = ACTIONS(2246),
    [anon_sym_open] = ACTIONS(2246),
    [anon_sym_transparent] = ACTIONS(2246),
    [anon_sym_LPAREN] = ACTIONS(75),
    [anon_sym_macro] = ACTIONS(77),
    [anon_sym_BANG] = ACTIONS(33),
    [anon_sym_TILDE] = ACTIONS(33),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [anon_sym_SQUOTE] = ACTIONS(81),
    [sym__backquoted_id] = ACTIONS(83),
    [sym_operator_identifier] = ACTIONS(85),
    [sym_integer_literal] = ACTIONS(87),
    [sym_floating_point_literal] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(91),
    [anon_sym_false] = ACTIONS(91),
    [sym_character_literal] = ACTIONS(89),
    [sym_null_literal] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(95),
    [anon_sym_throw] = ACTIONS(97),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(103),
    [sym__simple_string] = ACTIONS(103),
  },
  [2372] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16046),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2372),
    [sym_block_comment] = STATE(2372),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4156),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2373] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16309),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2373),
    [sym_block_comment] = STATE(2373),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4158),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2374] = {
    [sym_inline_modifier] = STATE(2304),
    [sym_block] = STATE(9672),
    [sym_expression] = STATE(14220),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2374),
    [sym_block_comment] = STATE(2374),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [2375] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(6583),
    [sym_expression] = STATE(16045),
    [sym__simple_expression] = STATE(4569),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(6583),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(6583),
    [sym_call_expression] = STATE(6583),
    [sym_field_expression] = STATE(6583),
    [sym_instance_expression] = STATE(6583),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17201),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(6583),
    [sym_parenthesized_expression] = STATE(6583),
    [sym_splice_expression] = STATE(6583),
    [sym_quote_expression] = STATE(6583),
    [sym_identifier] = STATE(4460),
    [sym__soft_identifier] = STATE(4771),
    [sym_wildcard] = STATE(5146),
    [sym__non_null_literal] = STATE(6583),
    [sym_boolean_literal] = STATE(6137),
    [sym_interpolated_string_expression] = STATE(6583),
    [sym_string] = STATE(6137),
    [sym_unit] = STATE(6583),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2375),
    [sym_block_comment] = STATE(2375),
    [sym__alpha_identifier] = ACTIONS(984),
    [anon_sym_LBRACE] = ACTIONS(988),
    [anon_sym__] = ACTIONS(990),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(994),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(996),
    [anon_sym_opaque] = ACTIONS(994),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(998),
    [anon_sym_infix] = ACTIONS(994),
    [anon_sym_open] = ACTIONS(994),
    [anon_sym_transparent] = ACTIONS(994),
    [anon_sym_LPAREN] = ACTIONS(1000),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1002),
    [anon_sym_SQUOTE] = ACTIONS(1004),
    [sym__backquoted_id] = ACTIONS(1006),
    [sym_operator_identifier] = ACTIONS(1008),
    [sym_integer_literal] = ACTIONS(1010),
    [sym_floating_point_literal] = ACTIONS(1012),
    [anon_sym_true] = ACTIONS(1014),
    [anon_sym_false] = ACTIONS(1014),
    [sym_character_literal] = ACTIONS(1012),
    [sym_null_literal] = ACTIONS(1016),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1018),
    [sym__simple_string] = ACTIONS(1018),
  },
  [2376] = {
    [sym_inline_modifier] = STATE(2122),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12494),
    [sym__simple_expression] = STATE(6526),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16564),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(10286),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5720),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8502),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2376),
    [sym_block_comment] = STATE(2376),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(1942),
    [anon_sym_while] = ACTIONS(1944),
    [anon_sym_for] = ACTIONS(1946),
    [anon_sym_try] = ACTIONS(1948),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1950),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1952),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1954),
    [anon_sym_throw] = ACTIONS(1956),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [2377] = {
    [sym_inline_modifier] = STATE(2373),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12494),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2377),
    [sym_block_comment] = STATE(2377),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [2378] = {
    [sym_inline_modifier] = STATE(2301),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13645),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(2378),
    [sym_block_comment] = STATE(2378),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [2379] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16172),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2379),
    [sym_block_comment] = STATE(2379),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4160),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2380] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15805),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2380),
    [sym_block_comment] = STATE(2380),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4162),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2381] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(16355),
    [sym__simple_expression] = STATE(4485),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16939),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4434),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(4827),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2381),
    [sym_block_comment] = STATE(2381),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(936),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [2382] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(16300),
    [sym__simple_expression] = STATE(4779),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(8500),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16983),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(8168),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(4598),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(5819),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2382),
    [sym_block_comment] = STATE(2382),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1116),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [2383] = {
    [sym_inline_modifier] = STATE(2127),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14204),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(2383),
    [sym_block_comment] = STATE(2383),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2384] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(10013),
    [sym_expression] = STATE(16158),
    [sym__simple_expression] = STATE(7294),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(10013),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(10013),
    [sym_call_expression] = STATE(10013),
    [sym_field_expression] = STATE(10013),
    [sym_instance_expression] = STATE(10013),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10747),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16888),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10513),
    [sym_tuple_expression] = STATE(10013),
    [sym_parenthesized_expression] = STATE(10013),
    [sym_splice_expression] = STATE(10013),
    [sym_quote_expression] = STATE(10013),
    [sym_identifier] = STATE(6751),
    [sym__soft_identifier] = STATE(4680),
    [sym_wildcard] = STATE(9367),
    [sym__non_null_literal] = STATE(10013),
    [sym_boolean_literal] = STATE(6406),
    [sym_interpolated_string_expression] = STATE(10013),
    [sym_string] = STATE(6406),
    [sym_unit] = STATE(10013),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2384),
    [sym_block_comment] = STATE(2384),
    [sym__alpha_identifier] = ACTIONS(1814),
    [anon_sym_LBRACE] = ACTIONS(1818),
    [anon_sym__] = ACTIONS(1820),
    [anon_sym_PLUS] = ACTIONS(1822),
    [anon_sym_DASH] = ACTIONS(1822),
    [anon_sym_end] = ACTIONS(1824),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1826),
    [anon_sym_opaque] = ACTIONS(1824),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1828),
    [anon_sym_infix] = ACTIONS(1824),
    [anon_sym_open] = ACTIONS(1824),
    [anon_sym_transparent] = ACTIONS(1824),
    [anon_sym_LPAREN] = ACTIONS(1830),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1822),
    [anon_sym_TILDE] = ACTIONS(1822),
    [anon_sym_DOLLAR] = ACTIONS(1832),
    [anon_sym_SQUOTE] = ACTIONS(1834),
    [sym__backquoted_id] = ACTIONS(1836),
    [sym_operator_identifier] = ACTIONS(1838),
    [sym_integer_literal] = ACTIONS(1840),
    [sym_floating_point_literal] = ACTIONS(1842),
    [anon_sym_true] = ACTIONS(1844),
    [anon_sym_false] = ACTIONS(1844),
    [sym_character_literal] = ACTIONS(1842),
    [sym_null_literal] = ACTIONS(1846),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1848),
    [sym__simple_string] = ACTIONS(1848),
  },
  [2385] = {
    [sym_inline_modifier] = STATE(2180),
    [sym_block] = STATE(5679),
    [sym_expression] = STATE(11717),
    [sym__simple_expression] = STATE(4927),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16490),
    [sym_case_block] = STATE(5679),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(5679),
    [sym_call_expression] = STATE(5679),
    [sym_field_expression] = STATE(5679),
    [sym_instance_expression] = STATE(5679),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(7019),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16700),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(8716),
    [sym_tuple_expression] = STATE(5679),
    [sym_parenthesized_expression] = STATE(5679),
    [sym_splice_expression] = STATE(5679),
    [sym_quote_expression] = STATE(5679),
    [sym_identifier] = STATE(4697),
    [sym__soft_identifier] = STATE(4567),
    [sym_wildcard] = STATE(6704),
    [sym__non_null_literal] = STATE(5679),
    [sym_boolean_literal] = STATE(5516),
    [sym_interpolated_string_expression] = STATE(5679),
    [sym_string] = STATE(5516),
    [sym_unit] = STATE(5679),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2385),
    [sym_block_comment] = STATE(2385),
    [sym__alpha_identifier] = ACTIONS(904),
    [anon_sym_LBRACE] = ACTIONS(908),
    [anon_sym__] = ACTIONS(914),
    [anon_sym_PLUS] = ACTIONS(916),
    [anon_sym_DASH] = ACTIONS(916),
    [anon_sym_end] = ACTIONS(918),
    [anon_sym_if] = ACTIONS(2262),
    [anon_sym_while] = ACTIONS(1498),
    [anon_sym_for] = ACTIONS(1500),
    [anon_sym_try] = ACTIONS(1502),
    [anon_sym_new] = ACTIONS(922),
    [anon_sym_opaque] = ACTIONS(918),
    [anon_sym_implicit] = ACTIONS(1504),
    [anon_sym_inline] = ACTIONS(926),
    [anon_sym_infix] = ACTIONS(918),
    [anon_sym_open] = ACTIONS(918),
    [anon_sym_transparent] = ACTIONS(918),
    [anon_sym_LPAREN] = ACTIONS(928),
    [anon_sym_macro] = ACTIONS(1326),
    [anon_sym_BANG] = ACTIONS(916),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_DOLLAR] = ACTIONS(930),
    [anon_sym_SQUOTE] = ACTIONS(932),
    [sym__backquoted_id] = ACTIONS(934),
    [sym_operator_identifier] = ACTIONS(1506),
    [sym_integer_literal] = ACTIONS(938),
    [sym_floating_point_literal] = ACTIONS(940),
    [anon_sym_true] = ACTIONS(942),
    [anon_sym_false] = ACTIONS(942),
    [sym_character_literal] = ACTIONS(940),
    [sym_null_literal] = ACTIONS(944),
    [anon_sym_return] = ACTIONS(1508),
    [anon_sym_throw] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(946),
    [sym__simple_string] = ACTIONS(946),
  },
  [2386] = {
    [sym_inline_modifier] = STATE(2108),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12823),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(2386),
    [sym_block_comment] = STATE(2386),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [2387] = {
    [sym_inline_modifier] = STATE(2301),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13444),
    [sym__simple_expression] = STATE(8014),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16423),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10787),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(7005),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9892),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(2387),
    [sym_block_comment] = STATE(2387),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2476),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2480),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2484),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2488),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [2388] = {
    [sym_inline_modifier] = STATE(2108),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12769),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(2388),
    [sym_block_comment] = STATE(2388),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [2389] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(7676),
    [sym_expression] = STATE(15745),
    [sym__simple_expression] = STATE(5044),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(7676),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(7676),
    [sym_call_expression] = STATE(7676),
    [sym_field_expression] = STATE(7676),
    [sym_instance_expression] = STATE(7676),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17238),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(7676),
    [sym_parenthesized_expression] = STATE(7676),
    [sym_splice_expression] = STATE(7676),
    [sym_quote_expression] = STATE(7676),
    [sym_identifier] = STATE(4744),
    [sym__soft_identifier] = STATE(5247),
    [sym_wildcard] = STATE(6749),
    [sym__non_null_literal] = STATE(7676),
    [sym_boolean_literal] = STATE(7888),
    [sym_interpolated_string_expression] = STATE(7676),
    [sym_string] = STATE(7888),
    [sym_unit] = STATE(7676),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2389),
    [sym_block_comment] = STATE(2389),
    [sym__alpha_identifier] = ACTIONS(1164),
    [anon_sym_LBRACE] = ACTIONS(1168),
    [anon_sym__] = ACTIONS(1170),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1174),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1176),
    [anon_sym_opaque] = ACTIONS(1174),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1178),
    [anon_sym_infix] = ACTIONS(1174),
    [anon_sym_open] = ACTIONS(1174),
    [anon_sym_transparent] = ACTIONS(1174),
    [anon_sym_LPAREN] = ACTIONS(1180),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1182),
    [anon_sym_SQUOTE] = ACTIONS(1184),
    [sym__backquoted_id] = ACTIONS(1186),
    [sym_operator_identifier] = ACTIONS(1188),
    [sym_integer_literal] = ACTIONS(1190),
    [sym_floating_point_literal] = ACTIONS(1192),
    [anon_sym_true] = ACTIONS(1194),
    [anon_sym_false] = ACTIONS(1194),
    [sym_character_literal] = ACTIONS(1192),
    [sym_null_literal] = ACTIONS(1196),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1198),
    [sym__simple_string] = ACTIONS(1198),
  },
  [2390] = {
    [sym_inline_modifier] = STATE(2304),
    [sym_block] = STATE(9672),
    [sym_expression] = STATE(14191),
    [sym__simple_expression] = STATE(6273),
    [sym_lambda_expression] = STATE(12174),
    [sym_if_expression] = STATE(12174),
    [sym_match_expression] = STATE(12174),
    [sym_try_expression] = STATE(12174),
    [sym_bindings] = STATE(16392),
    [sym_case_block] = STATE(9672),
    [sym_assignment_expression] = STATE(12174),
    [sym_generic_function] = STATE(9672),
    [sym_call_expression] = STATE(9672),
    [sym_field_expression] = STATE(9672),
    [sym_instance_expression] = STATE(9672),
    [sym_ascription_expression] = STATE(12174),
    [sym_infix_expression] = STATE(10429),
    [sym_postfix_expression] = STATE(11969),
    [sym__postfix_expression_choice] = STATE(17091),
    [sym_macro_body] = STATE(12174),
    [sym_prefix_expression] = STATE(10343),
    [sym_tuple_expression] = STATE(9672),
    [sym_parenthesized_expression] = STATE(9672),
    [sym_splice_expression] = STATE(9672),
    [sym_quote_expression] = STATE(9672),
    [sym_identifier] = STATE(5989),
    [sym__soft_identifier] = STATE(4581),
    [sym_wildcard] = STATE(8409),
    [sym__non_null_literal] = STATE(9672),
    [sym_boolean_literal] = STATE(5996),
    [sym_interpolated_string_expression] = STATE(9672),
    [sym_string] = STATE(5996),
    [sym_unit] = STATE(9672),
    [sym_return_expression] = STATE(12174),
    [sym_throw_expression] = STATE(12174),
    [sym_while_expression] = STATE(12174),
    [sym_do_while_expression] = STATE(12174),
    [sym_for_expression] = STATE(12174),
    [sym_comment] = STATE(2390),
    [sym_block_comment] = STATE(2390),
    [sym__alpha_identifier] = ACTIONS(1512),
    [anon_sym_LBRACE] = ACTIONS(1516),
    [anon_sym__] = ACTIONS(1518),
    [anon_sym_PLUS] = ACTIONS(1520),
    [anon_sym_DASH] = ACTIONS(1520),
    [anon_sym_end] = ACTIONS(1522),
    [anon_sym_if] = ACTIONS(2042),
    [anon_sym_while] = ACTIONS(2044),
    [anon_sym_for] = ACTIONS(2046),
    [anon_sym_try] = ACTIONS(2048),
    [anon_sym_new] = ACTIONS(1524),
    [anon_sym_opaque] = ACTIONS(1522),
    [anon_sym_implicit] = ACTIONS(2050),
    [anon_sym_inline] = ACTIONS(1526),
    [anon_sym_infix] = ACTIONS(1522),
    [anon_sym_open] = ACTIONS(1522),
    [anon_sym_transparent] = ACTIONS(1522),
    [anon_sym_LPAREN] = ACTIONS(1528),
    [anon_sym_macro] = ACTIONS(2052),
    [anon_sym_BANG] = ACTIONS(1520),
    [anon_sym_TILDE] = ACTIONS(1520),
    [anon_sym_DOLLAR] = ACTIONS(1530),
    [anon_sym_SQUOTE] = ACTIONS(1532),
    [sym__backquoted_id] = ACTIONS(1534),
    [sym_operator_identifier] = ACTIONS(2054),
    [sym_integer_literal] = ACTIONS(1538),
    [sym_floating_point_literal] = ACTIONS(1540),
    [anon_sym_true] = ACTIONS(1542),
    [anon_sym_false] = ACTIONS(1542),
    [sym_character_literal] = ACTIONS(1540),
    [sym_null_literal] = ACTIONS(1544),
    [anon_sym_return] = ACTIONS(2056),
    [anon_sym_throw] = ACTIONS(2058),
    [anon_sym_do] = ACTIONS(1478),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1546),
    [sym__simple_string] = ACTIONS(1546),
  },
  [2391] = {
    [sym_inline_modifier] = STATE(2127),
    [sym_block] = STATE(9857),
    [sym_expression] = STATE(14175),
    [sym__simple_expression] = STATE(6996),
    [sym_lambda_expression] = STATE(14406),
    [sym_if_expression] = STATE(14406),
    [sym_match_expression] = STATE(14406),
    [sym_try_expression] = STATE(14406),
    [sym_bindings] = STATE(16651),
    [sym_case_block] = STATE(9857),
    [sym_assignment_expression] = STATE(14406),
    [sym_generic_function] = STATE(9857),
    [sym_call_expression] = STATE(9857),
    [sym_field_expression] = STATE(9857),
    [sym_instance_expression] = STATE(9857),
    [sym_ascription_expression] = STATE(14406),
    [sym_infix_expression] = STATE(10801),
    [sym_postfix_expression] = STATE(14230),
    [sym__postfix_expression_choice] = STATE(17419),
    [sym_macro_body] = STATE(14406),
    [sym_prefix_expression] = STATE(10591),
    [sym_tuple_expression] = STATE(9857),
    [sym_parenthesized_expression] = STATE(9857),
    [sym_splice_expression] = STATE(9857),
    [sym_quote_expression] = STATE(9857),
    [sym_identifier] = STATE(6687),
    [sym__soft_identifier] = STATE(5518),
    [sym_wildcard] = STATE(9197),
    [sym__non_null_literal] = STATE(9857),
    [sym_boolean_literal] = STATE(9763),
    [sym_interpolated_string_expression] = STATE(9857),
    [sym_string] = STATE(9763),
    [sym_unit] = STATE(9857),
    [sym_return_expression] = STATE(14406),
    [sym_throw_expression] = STATE(14406),
    [sym_while_expression] = STATE(14406),
    [sym_do_while_expression] = STATE(14406),
    [sym_for_expression] = STATE(14406),
    [sym_comment] = STATE(2391),
    [sym_block_comment] = STATE(2391),
    [sym__alpha_identifier] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym__] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(627),
    [anon_sym_end] = ACTIONS(677),
    [anon_sym_if] = ACTIONS(629),
    [anon_sym_while] = ACTIONS(631),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(635),
    [anon_sym_new] = ACTIONS(523),
    [anon_sym_opaque] = ACTIONS(677),
    [anon_sym_implicit] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2062),
    [anon_sym_infix] = ACTIONS(677),
    [anon_sym_open] = ACTIONS(677),
    [anon_sym_transparent] = ACTIONS(677),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_macro] = ACTIONS(643),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(549),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [sym__backquoted_id] = ACTIONS(553),
    [sym_operator_identifier] = ACTIONS(645),
    [sym_integer_literal] = ACTIONS(557),
    [sym_floating_point_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [sym_character_literal] = ACTIONS(559),
    [sym_null_literal] = ACTIONS(563),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_do] = ACTIONS(569),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(571),
    [sym__simple_string] = ACTIONS(571),
  },
  [2392] = {
    [sym_inline_modifier] = STATE(2373),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(12479),
    [sym__simple_expression] = STATE(5580),
    [sym_lambda_expression] = STATE(12798),
    [sym_if_expression] = STATE(12798),
    [sym_match_expression] = STATE(12798),
    [sym_try_expression] = STATE(12798),
    [sym_bindings] = STATE(16534),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(12798),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(12798),
    [sym_infix_expression] = STATE(8838),
    [sym_postfix_expression] = STATE(12321),
    [sym__postfix_expression_choice] = STATE(16719),
    [sym_macro_body] = STATE(12798),
    [sym_prefix_expression] = STATE(9993),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(5150),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(8241),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(12798),
    [sym_throw_expression] = STATE(12798),
    [sym_while_expression] = STATE(12798),
    [sym_do_while_expression] = STATE(12798),
    [sym_for_expression] = STATE(12798),
    [sym_comment] = STATE(2392),
    [sym_block_comment] = STATE(2392),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(1028),
    [anon_sym_DASH] = ACTIONS(1028),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(2386),
    [anon_sym_while] = ACTIONS(1864),
    [anon_sym_for] = ACTIONS(1866),
    [anon_sym_try] = ACTIONS(1868),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(1870),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(1872),
    [anon_sym_BANG] = ACTIONS(1028),
    [anon_sym_TILDE] = ACTIONS(1028),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1874),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(1876),
    [anon_sym_throw] = ACTIONS(1878),
    [anon_sym_do] = ACTIONS(1880),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [2393] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14983),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2393),
    [sym_block_comment] = STATE(2393),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2394] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16276),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2394),
    [sym_block_comment] = STATE(2394),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4164),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2395] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15805),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2395),
    [sym_block_comment] = STATE(2395),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4166),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2396] = {
    [sym_inline_modifier] = STATE(2104),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(14026),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(2396),
    [sym_block_comment] = STATE(2396),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [2397] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(16246),
    [sym__simple_expression] = STATE(5625),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10232),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17005),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10004),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(5368),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(7971),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2397),
    [sym_block_comment] = STATE(2397),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(1998),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [2398] = {
    [sym_inline_modifier] = STATE(2108),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12887),
    [sym__simple_expression] = STATE(5226),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16592),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(9559),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5034),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(7323),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(2398),
    [sym_block_comment] = STATE(2398),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(1260),
    [anon_sym_while] = ACTIONS(1262),
    [anon_sym_for] = ACTIONS(1264),
    [anon_sym_try] = ACTIONS(1266),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(1268),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(1272),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(1274),
    [anon_sym_throw] = ACTIONS(1276),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [2399] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(6845),
    [sym_expression] = STATE(16376),
    [sym__simple_expression] = STATE(4746),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(6845),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(6845),
    [sym_call_expression] = STATE(6845),
    [sym_field_expression] = STATE(6845),
    [sym_instance_expression] = STATE(6845),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(16961),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(6845),
    [sym_parenthesized_expression] = STATE(6845),
    [sym_splice_expression] = STATE(6845),
    [sym_quote_expression] = STATE(6845),
    [sym_identifier] = STATE(4568),
    [sym__soft_identifier] = STATE(4918),
    [sym_wildcard] = STATE(5737),
    [sym__non_null_literal] = STATE(6845),
    [sym_boolean_literal] = STATE(7320),
    [sym_interpolated_string_expression] = STATE(6845),
    [sym_string] = STATE(7320),
    [sym_unit] = STATE(6845),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2399),
    [sym_block_comment] = STATE(2399),
    [sym__alpha_identifier] = ACTIONS(1020),
    [anon_sym_LBRACE] = ACTIONS(1024),
    [anon_sym__] = ACTIONS(1026),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(1030),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(1032),
    [anon_sym_opaque] = ACTIONS(1030),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(1034),
    [anon_sym_infix] = ACTIONS(1030),
    [anon_sym_open] = ACTIONS(1030),
    [anon_sym_transparent] = ACTIONS(1030),
    [anon_sym_LPAREN] = ACTIONS(1036),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(1038),
    [anon_sym_SQUOTE] = ACTIONS(1040),
    [sym__backquoted_id] = ACTIONS(1042),
    [sym_operator_identifier] = ACTIONS(1044),
    [sym_integer_literal] = ACTIONS(1046),
    [sym_floating_point_literal] = ACTIONS(1048),
    [anon_sym_true] = ACTIONS(1050),
    [anon_sym_false] = ACTIONS(1050),
    [sym_character_literal] = ACTIONS(1048),
    [sym_null_literal] = ACTIONS(1052),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1054),
    [sym__simple_string] = ACTIONS(1054),
  },
  [2400] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16242),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2400),
    [sym_block_comment] = STATE(2400),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4168),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2401] = {
    [sym_inline_modifier] = STATE(2279),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14972),
    [sym__simple_expression] = STATE(9183),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16500),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(11260),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(8366),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(10418),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2401),
    [sym_block_comment] = STATE(2401),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(2841),
    [anon_sym_while] = ACTIONS(2843),
    [anon_sym_for] = ACTIONS(2845),
    [anon_sym_try] = ACTIONS(2847),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(3336),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(2863),
    [anon_sym_throw] = ACTIONS(2865),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2402] = {
    [sym_inline_modifier] = STATE(2260),
    [sym_block] = STATE(8484),
    [sym_expression] = STATE(13645),
    [sym__simple_expression] = STATE(8203),
    [sym_lambda_expression] = STATE(13790),
    [sym_if_expression] = STATE(13790),
    [sym_match_expression] = STATE(13790),
    [sym_try_expression] = STATE(13790),
    [sym_bindings] = STATE(16427),
    [sym_case_block] = STATE(8484),
    [sym_assignment_expression] = STATE(13790),
    [sym_generic_function] = STATE(8484),
    [sym_call_expression] = STATE(8484),
    [sym_field_expression] = STATE(8484),
    [sym_instance_expression] = STATE(8484),
    [sym_ascription_expression] = STATE(13790),
    [sym_infix_expression] = STATE(9708),
    [sym_postfix_expression] = STATE(13471),
    [sym__postfix_expression_choice] = STATE(17485),
    [sym_macro_body] = STATE(13790),
    [sym_prefix_expression] = STATE(10702),
    [sym_tuple_expression] = STATE(8484),
    [sym_parenthesized_expression] = STATE(8484),
    [sym_splice_expression] = STATE(8484),
    [sym_quote_expression] = STATE(8484),
    [sym_identifier] = STATE(6821),
    [sym__soft_identifier] = STATE(5939),
    [sym_wildcard] = STATE(9921),
    [sym__non_null_literal] = STATE(8484),
    [sym_boolean_literal] = STATE(8462),
    [sym_interpolated_string_expression] = STATE(8484),
    [sym_string] = STATE(8462),
    [sym_unit] = STATE(8484),
    [sym_return_expression] = STATE(13790),
    [sym_throw_expression] = STATE(13790),
    [sym_while_expression] = STATE(13790),
    [sym_do_while_expression] = STATE(13790),
    [sym_for_expression] = STATE(13790),
    [sym_comment] = STATE(2402),
    [sym_block_comment] = STATE(2402),
    [sym__alpha_identifier] = ACTIONS(1424),
    [anon_sym_LBRACE] = ACTIONS(1428),
    [anon_sym__] = ACTIONS(1430),
    [anon_sym_PLUS] = ACTIONS(1432),
    [anon_sym_DASH] = ACTIONS(1432),
    [anon_sym_end] = ACTIONS(1434),
    [anon_sym_if] = ACTIONS(2450),
    [anon_sym_while] = ACTIONS(2452),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2456),
    [anon_sym_new] = ACTIONS(1436),
    [anon_sym_opaque] = ACTIONS(1434),
    [anon_sym_implicit] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(1438),
    [anon_sym_infix] = ACTIONS(1434),
    [anon_sym_open] = ACTIONS(1434),
    [anon_sym_transparent] = ACTIONS(1434),
    [anon_sym_LPAREN] = ACTIONS(1440),
    [anon_sym_macro] = ACTIONS(1912),
    [anon_sym_BANG] = ACTIONS(1432),
    [anon_sym_TILDE] = ACTIONS(1432),
    [anon_sym_DOLLAR] = ACTIONS(1442),
    [anon_sym_SQUOTE] = ACTIONS(1444),
    [sym__backquoted_id] = ACTIONS(1446),
    [sym_operator_identifier] = ACTIONS(2460),
    [sym_integer_literal] = ACTIONS(1450),
    [sym_floating_point_literal] = ACTIONS(1452),
    [anon_sym_true] = ACTIONS(1454),
    [anon_sym_false] = ACTIONS(1454),
    [sym_character_literal] = ACTIONS(1452),
    [sym_null_literal] = ACTIONS(1456),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2464),
    [anon_sym_do] = ACTIONS(1920),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1458),
    [sym__simple_string] = ACTIONS(1458),
  },
  [2403] = {
    [sym_inline_modifier] = STATE(2404),
    [sym_block] = STATE(7727),
    [sym_expression] = STATE(13051),
    [sym__simple_expression] = STATE(5129),
    [sym_lambda_expression] = STATE(13611),
    [sym_if_expression] = STATE(13611),
    [sym_match_expression] = STATE(13611),
    [sym_try_expression] = STATE(13611),
    [sym_bindings] = STATE(16512),
    [sym_case_block] = STATE(7727),
    [sym_assignment_expression] = STATE(13611),
    [sym_generic_function] = STATE(7727),
    [sym_call_expression] = STATE(7727),
    [sym_field_expression] = STATE(7727),
    [sym_instance_expression] = STATE(7727),
    [sym_ascription_expression] = STATE(13611),
    [sym_infix_expression] = STATE(9481),
    [sym_postfix_expression] = STATE(12982),
    [sym__postfix_expression_choice] = STATE(17049),
    [sym_macro_body] = STATE(13611),
    [sym_prefix_expression] = STATE(9312),
    [sym_tuple_expression] = STATE(7727),
    [sym_parenthesized_expression] = STATE(7727),
    [sym_splice_expression] = STATE(7727),
    [sym_quote_expression] = STATE(7727),
    [sym_identifier] = STATE(4961),
    [sym__soft_identifier] = STATE(5283),
    [sym_wildcard] = STATE(6939),
    [sym__non_null_literal] = STATE(7727),
    [sym_boolean_literal] = STATE(7970),
    [sym_interpolated_string_expression] = STATE(7727),
    [sym_string] = STATE(7970),
    [sym_unit] = STATE(7727),
    [sym_return_expression] = STATE(13611),
    [sym_throw_expression] = STATE(13611),
    [sym_while_expression] = STATE(13611),
    [sym_do_while_expression] = STATE(13611),
    [sym_for_expression] = STATE(13611),
    [sym_comment] = STATE(2403),
    [sym_block_comment] = STATE(2403),
    [sym__alpha_identifier] = ACTIONS(1128),
    [anon_sym_LBRACE] = ACTIONS(1132),
    [anon_sym__] = ACTIONS(1134),
    [anon_sym_PLUS] = ACTIONS(1136),
    [anon_sym_DASH] = ACTIONS(1136),
    [anon_sym_end] = ACTIONS(1138),
    [anon_sym_if] = ACTIONS(2496),
    [anon_sym_while] = ACTIONS(1710),
    [anon_sym_for] = ACTIONS(1712),
    [anon_sym_try] = ACTIONS(1714),
    [anon_sym_new] = ACTIONS(1140),
    [anon_sym_opaque] = ACTIONS(1138),
    [anon_sym_implicit] = ACTIONS(1716),
    [anon_sym_inline] = ACTIONS(1142),
    [anon_sym_infix] = ACTIONS(1138),
    [anon_sym_open] = ACTIONS(1138),
    [anon_sym_transparent] = ACTIONS(1138),
    [anon_sym_LPAREN] = ACTIONS(1144),
    [anon_sym_macro] = ACTIONS(1214),
    [anon_sym_BANG] = ACTIONS(1136),
    [anon_sym_TILDE] = ACTIONS(1136),
    [anon_sym_DOLLAR] = ACTIONS(1146),
    [anon_sym_SQUOTE] = ACTIONS(1148),
    [sym__backquoted_id] = ACTIONS(1150),
    [sym_operator_identifier] = ACTIONS(1718),
    [sym_integer_literal] = ACTIONS(1154),
    [sym_floating_point_literal] = ACTIONS(1156),
    [anon_sym_true] = ACTIONS(1158),
    [anon_sym_false] = ACTIONS(1158),
    [sym_character_literal] = ACTIONS(1156),
    [sym_null_literal] = ACTIONS(1160),
    [anon_sym_return] = ACTIONS(1720),
    [anon_sym_throw] = ACTIONS(1722),
    [anon_sym_do] = ACTIONS(1222),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1162),
    [sym__simple_string] = ACTIONS(1162),
  },
  [2404] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16238),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2404),
    [sym_block_comment] = STATE(2404),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4170),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2405] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(15071),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2405),
    [sym_block_comment] = STATE(2405),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2406] = {
    [sym_inline_modifier] = STATE(2218),
    [sym_block] = STATE(8958),
    [sym_expression] = STATE(13773),
    [sym__simple_expression] = STATE(5771),
    [sym_lambda_expression] = STATE(11791),
    [sym_if_expression] = STATE(11791),
    [sym_match_expression] = STATE(11791),
    [sym_try_expression] = STATE(11791),
    [sym_bindings] = STATE(16411),
    [sym_case_block] = STATE(8958),
    [sym_assignment_expression] = STATE(11791),
    [sym_generic_function] = STATE(8958),
    [sym_call_expression] = STATE(8958),
    [sym_field_expression] = STATE(8958),
    [sym_instance_expression] = STATE(8958),
    [sym_ascription_expression] = STATE(11791),
    [sym_infix_expression] = STATE(10194),
    [sym_postfix_expression] = STATE(11510),
    [sym__postfix_expression_choice] = STATE(16835),
    [sym_macro_body] = STATE(11791),
    [sym_prefix_expression] = STATE(9862),
    [sym_tuple_expression] = STATE(8958),
    [sym_parenthesized_expression] = STATE(8958),
    [sym_splice_expression] = STATE(8958),
    [sym_quote_expression] = STATE(8958),
    [sym_identifier] = STATE(5148),
    [sym__soft_identifier] = STATE(4522),
    [sym_wildcard] = STATE(8004),
    [sym__non_null_literal] = STATE(8958),
    [sym_boolean_literal] = STATE(5184),
    [sym_interpolated_string_expression] = STATE(8958),
    [sym_string] = STATE(5184),
    [sym_unit] = STATE(8958),
    [sym_return_expression] = STATE(11791),
    [sym_throw_expression] = STATE(11791),
    [sym_while_expression] = STATE(11791),
    [sym_do_while_expression] = STATE(11791),
    [sym_for_expression] = STATE(11791),
    [sym_comment] = STATE(2406),
    [sym_block_comment] = STATE(2406),
    [sym__alpha_identifier] = ACTIONS(1280),
    [anon_sym_LBRACE] = ACTIONS(1284),
    [anon_sym__] = ACTIONS(1286),
    [anon_sym_PLUS] = ACTIONS(1288),
    [anon_sym_DASH] = ACTIONS(1288),
    [anon_sym_end] = ACTIONS(1290),
    [anon_sym_if] = ACTIONS(1480),
    [anon_sym_while] = ACTIONS(1482),
    [anon_sym_for] = ACTIONS(1484),
    [anon_sym_try] = ACTIONS(1486),
    [anon_sym_new] = ACTIONS(1292),
    [anon_sym_opaque] = ACTIONS(1290),
    [anon_sym_implicit] = ACTIONS(1488),
    [anon_sym_inline] = ACTIONS(1294),
    [anon_sym_infix] = ACTIONS(1290),
    [anon_sym_open] = ACTIONS(1290),
    [anon_sym_transparent] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1296),
    [anon_sym_macro] = ACTIONS(1490),
    [anon_sym_BANG] = ACTIONS(1288),
    [anon_sym_TILDE] = ACTIONS(1288),
    [anon_sym_DOLLAR] = ACTIONS(1298),
    [anon_sym_SQUOTE] = ACTIONS(1300),
    [sym__backquoted_id] = ACTIONS(1302),
    [sym_operator_identifier] = ACTIONS(1492),
    [sym_integer_literal] = ACTIONS(1306),
    [sym_floating_point_literal] = ACTIONS(1308),
    [anon_sym_true] = ACTIONS(1310),
    [anon_sym_false] = ACTIONS(1310),
    [sym_character_literal] = ACTIONS(1308),
    [sym_null_literal] = ACTIONS(1312),
    [anon_sym_return] = ACTIONS(1494),
    [anon_sym_throw] = ACTIONS(1496),
    [anon_sym_do] = ACTIONS(1334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1314),
    [sym__simple_string] = ACTIONS(1314),
  },
  [2407] = {
    [sym_inline_modifier] = STATE(2104),
    [sym_block] = STATE(9084),
    [sym_expression] = STATE(13729),
    [sym__simple_expression] = STATE(7260),
    [sym_lambda_expression] = STATE(14183),
    [sym_if_expression] = STATE(14183),
    [sym_match_expression] = STATE(14183),
    [sym_try_expression] = STATE(14183),
    [sym_bindings] = STATE(16623),
    [sym_case_block] = STATE(9084),
    [sym_assignment_expression] = STATE(14183),
    [sym_generic_function] = STATE(9084),
    [sym_call_expression] = STATE(9084),
    [sym_field_expression] = STATE(9084),
    [sym_instance_expression] = STATE(9084),
    [sym_ascription_expression] = STATE(14183),
    [sym_infix_expression] = STATE(10135),
    [sym_postfix_expression] = STATE(13906),
    [sym__postfix_expression_choice] = STATE(16797),
    [sym_macro_body] = STATE(14183),
    [sym_prefix_expression] = STATE(10498),
    [sym_tuple_expression] = STATE(9084),
    [sym_parenthesized_expression] = STATE(9084),
    [sym_splice_expression] = STATE(9084),
    [sym_quote_expression] = STATE(9084),
    [sym_identifier] = STATE(6626),
    [sym__soft_identifier] = STATE(6575),
    [sym_wildcard] = STATE(9106),
    [sym__non_null_literal] = STATE(9084),
    [sym_boolean_literal] = STATE(9333),
    [sym_interpolated_string_expression] = STATE(9084),
    [sym_string] = STATE(9333),
    [sym_unit] = STATE(9084),
    [sym_return_expression] = STATE(14183),
    [sym_throw_expression] = STATE(14183),
    [sym_while_expression] = STATE(14183),
    [sym_do_while_expression] = STATE(14183),
    [sym_for_expression] = STATE(14183),
    [sym_comment] = STATE(2407),
    [sym_block_comment] = STATE(2407),
    [sym__alpha_identifier] = ACTIONS(1974),
    [anon_sym_LBRACE] = ACTIONS(1978),
    [anon_sym__] = ACTIONS(1980),
    [anon_sym_PLUS] = ACTIONS(1982),
    [anon_sym_DASH] = ACTIONS(1982),
    [anon_sym_end] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(2136),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2140),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(1986),
    [anon_sym_opaque] = ACTIONS(1984),
    [anon_sym_implicit] = ACTIONS(2144),
    [anon_sym_inline] = ACTIONS(1988),
    [anon_sym_infix] = ACTIONS(1984),
    [anon_sym_open] = ACTIONS(1984),
    [anon_sym_transparent] = ACTIONS(1984),
    [anon_sym_LPAREN] = ACTIONS(1990),
    [anon_sym_macro] = ACTIONS(2146),
    [anon_sym_BANG] = ACTIONS(1982),
    [anon_sym_TILDE] = ACTIONS(1982),
    [anon_sym_DOLLAR] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1994),
    [sym__backquoted_id] = ACTIONS(1996),
    [sym_operator_identifier] = ACTIONS(2148),
    [sym_integer_literal] = ACTIONS(2000),
    [sym_floating_point_literal] = ACTIONS(2002),
    [anon_sym_true] = ACTIONS(2004),
    [anon_sym_false] = ACTIONS(2004),
    [sym_character_literal] = ACTIONS(2002),
    [sym_null_literal] = ACTIONS(2006),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2152),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(2008),
    [sym__simple_string] = ACTIONS(2008),
  },
  [2408] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(14654),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2408),
    [sym_block_comment] = STATE(2408),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(920),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2409] = {
    [sym_inline_modifier] = STATE(2257),
    [sym_block] = STATE(8208),
    [sym_expression] = STATE(13183),
    [sym__simple_expression] = STATE(8214),
    [sym_lambda_expression] = STATE(12960),
    [sym_if_expression] = STATE(12960),
    [sym_match_expression] = STATE(12960),
    [sym_try_expression] = STATE(12960),
    [sym_bindings] = STATE(16575),
    [sym_case_block] = STATE(8208),
    [sym_assignment_expression] = STATE(12960),
    [sym_generic_function] = STATE(8208),
    [sym_call_expression] = STATE(8208),
    [sym_field_expression] = STATE(8208),
    [sym_instance_expression] = STATE(8208),
    [sym_ascription_expression] = STATE(12960),
    [sym_infix_expression] = STATE(9780),
    [sym_postfix_expression] = STATE(12879),
    [sym__postfix_expression_choice] = STATE(17945),
    [sym_macro_body] = STATE(12960),
    [sym_prefix_expression] = STATE(10741),
    [sym_tuple_expression] = STATE(8208),
    [sym_parenthesized_expression] = STATE(8208),
    [sym_splice_expression] = STATE(8208),
    [sym_quote_expression] = STATE(8208),
    [sym_identifier] = STATE(6806),
    [sym__soft_identifier] = STATE(5241),
    [sym_wildcard] = STATE(9753),
    [sym__non_null_literal] = STATE(8208),
    [sym_boolean_literal] = STATE(8201),
    [sym_interpolated_string_expression] = STATE(8208),
    [sym_string] = STATE(8201),
    [sym_unit] = STATE(8208),
    [sym_return_expression] = STATE(12960),
    [sym_throw_expression] = STATE(12960),
    [sym_while_expression] = STATE(12960),
    [sym_do_while_expression] = STATE(12960),
    [sym_for_expression] = STATE(12960),
    [sym_comment] = STATE(2409),
    [sym_block_comment] = STATE(2409),
    [sym__alpha_identifier] = ACTIONS(105),
    [anon_sym_LBRACE] = ACTIONS(107),
    [anon_sym__] = ACTIONS(111),
    [anon_sym_PLUS] = ACTIONS(115),
    [anon_sym_DASH] = ACTIONS(115),
    [anon_sym_end] = ACTIONS(657),
    [anon_sym_if] = ACTIONS(119),
    [anon_sym_while] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(123),
    [anon_sym_try] = ACTIONS(125),
    [anon_sym_new] = ACTIONS(127),
    [anon_sym_opaque] = ACTIONS(657),
    [anon_sym_implicit] = ACTIONS(2923),
    [anon_sym_inline] = ACTIONS(139),
    [anon_sym_infix] = ACTIONS(657),
    [anon_sym_open] = ACTIONS(657),
    [anon_sym_transparent] = ACTIONS(657),
    [anon_sym_LPAREN] = ACTIONS(147),
    [anon_sym_macro] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_DOLLAR] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [sym__backquoted_id] = ACTIONS(157),
    [sym_operator_identifier] = ACTIONS(431),
    [sym_integer_literal] = ACTIONS(161),
    [sym_floating_point_literal] = ACTIONS(163),
    [anon_sym_true] = ACTIONS(165),
    [anon_sym_false] = ACTIONS(165),
    [sym_character_literal] = ACTIONS(163),
    [sym_null_literal] = ACTIONS(167),
    [anon_sym_return] = ACTIONS(169),
    [anon_sym_throw] = ACTIONS(171),
    [anon_sym_do] = ACTIONS(99),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(175),
    [sym__simple_string] = ACTIONS(175),
  },
  [2410] = {
    [sym_inline_modifier] = STATE(2135),
    [sym_block] = STATE(9879),
    [sym_expression] = STATE(16159),
    [sym__simple_expression] = STATE(7985),
    [sym_lambda_expression] = STATE(14347),
    [sym_if_expression] = STATE(14347),
    [sym_match_expression] = STATE(14347),
    [sym_try_expression] = STATE(14347),
    [sym_bindings] = STATE(16540),
    [sym_case_block] = STATE(9879),
    [sym_assignment_expression] = STATE(14347),
    [sym_generic_function] = STATE(9879),
    [sym_call_expression] = STATE(9879),
    [sym_field_expression] = STATE(9879),
    [sym_instance_expression] = STATE(9879),
    [sym_ascription_expression] = STATE(14347),
    [sym_infix_expression] = STATE(10592),
    [sym_postfix_expression] = STATE(13995),
    [sym__postfix_expression_choice] = STATE(17736),
    [sym_macro_body] = STATE(14347),
    [sym_prefix_expression] = STATE(10714),
    [sym_tuple_expression] = STATE(9879),
    [sym_parenthesized_expression] = STATE(9879),
    [sym_splice_expression] = STATE(9879),
    [sym_quote_expression] = STATE(9879),
    [sym_identifier] = STATE(5849),
    [sym__soft_identifier] = STATE(5497),
    [sym_wildcard] = STATE(8785),
    [sym__non_null_literal] = STATE(9879),
    [sym_boolean_literal] = STATE(8787),
    [sym_interpolated_string_expression] = STATE(9879),
    [sym_string] = STATE(8787),
    [sym_unit] = STATE(9879),
    [sym_return_expression] = STATE(14347),
    [sym_throw_expression] = STATE(14347),
    [sym_while_expression] = STATE(14347),
    [sym_do_while_expression] = STATE(14347),
    [sym_for_expression] = STATE(14347),
    [sym_comment] = STATE(2410),
    [sym_block_comment] = STATE(2410),
    [sym__alpha_identifier] = ACTIONS(846),
    [anon_sym_LBRACE] = ACTIONS(848),
    [anon_sym__] = ACTIONS(852),
    [anon_sym_PLUS] = ACTIONS(854),
    [anon_sym_DASH] = ACTIONS(854),
    [anon_sym_end] = ACTIONS(856),
    [anon_sym_if] = ACTIONS(4172),
    [anon_sym_while] = ACTIONS(860),
    [anon_sym_for] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(864),
    [anon_sym_new] = ACTIONS(866),
    [anon_sym_opaque] = ACTIONS(856),
    [anon_sym_implicit] = ACTIONS(924),
    [anon_sym_inline] = ACTIONS(2492),
    [anon_sym_infix] = ACTIONS(856),
    [anon_sym_open] = ACTIONS(856),
    [anon_sym_transparent] = ACTIONS(856),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_macro] = ACTIONS(870),
    [anon_sym_BANG] = ACTIONS(854),
    [anon_sym_TILDE] = ACTIONS(854),
    [anon_sym_DOLLAR] = ACTIONS(872),
    [anon_sym_SQUOTE] = ACTIONS(874),
    [sym__backquoted_id] = ACTIONS(876),
    [sym_operator_identifier] = ACTIONS(878),
    [sym_integer_literal] = ACTIONS(880),
    [sym_floating_point_literal] = ACTIONS(882),
    [anon_sym_true] = ACTIONS(884),
    [anon_sym_false] = ACTIONS(884),
    [sym_character_literal] = ACTIONS(882),
    [sym_null_literal] = ACTIONS(886),
    [anon_sym_return] = ACTIONS(888),
    [anon_sym_throw] = ACTIONS(890),
    [anon_sym_do] = ACTIONS(892),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(894),
    [sym__simple_string] = ACTIONS(894),
  },
  [2411] = {
    [sym_inline_modifier] = STATE(2280),
    [sym_block] = STATE(7018),
    [sym_expression] = STATE(12887),
    [sym__simple_expression] = STATE(6675),
    [sym_lambda_expression] = STATE(13189),
    [sym_if_expression] = STATE(13189),
    [sym_match_expression] = STATE(13189),
    [sym_try_expression] = STATE(13189),
    [sym_bindings] = STATE(16511),
    [sym_case_block] = STATE(7018),
    [sym_assignment_expression] = STATE(13189),
    [sym_generic_function] = STATE(7018),
    [sym_call_expression] = STATE(7018),
    [sym_field_expression] = STATE(7018),
    [sym_instance_expression] = STATE(7018),
    [sym_ascription_expression] = STATE(13189),
    [sym_infix_expression] = STATE(8589),
    [sym_postfix_expression] = STATE(12472),
    [sym__postfix_expression_choice] = STATE(16770),
    [sym_macro_body] = STATE(13189),
    [sym_prefix_expression] = STATE(10024),
    [sym_tuple_expression] = STATE(7018),
    [sym_parenthesized_expression] = STATE(7018),
    [sym_splice_expression] = STATE(7018),
    [sym_quote_expression] = STATE(7018),
    [sym_identifier] = STATE(5627),
    [sym__soft_identifier] = STATE(5026),
    [sym_wildcard] = STATE(8288),
    [sym__non_null_literal] = STATE(7018),
    [sym_boolean_literal] = STATE(7087),
    [sym_interpolated_string_expression] = STATE(7018),
    [sym_string] = STATE(7087),
    [sym_unit] = STATE(7018),
    [sym_return_expression] = STATE(13189),
    [sym_throw_expression] = STATE(13189),
    [sym_while_expression] = STATE(13189),
    [sym_do_while_expression] = STATE(13189),
    [sym_for_expression] = STATE(13189),
    [sym_comment] = STATE(2411),
    [sym_block_comment] = STATE(2411),
    [sym__alpha_identifier] = ACTIONS(1092),
    [anon_sym_LBRACE] = ACTIONS(1096),
    [anon_sym__] = ACTIONS(1098),
    [anon_sym_PLUS] = ACTIONS(1100),
    [anon_sym_DASH] = ACTIONS(1100),
    [anon_sym_end] = ACTIONS(1102),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2160),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2164),
    [anon_sym_new] = ACTIONS(1104),
    [anon_sym_opaque] = ACTIONS(1102),
    [anon_sym_implicit] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(1106),
    [anon_sym_infix] = ACTIONS(1102),
    [anon_sym_open] = ACTIONS(1102),
    [anon_sym_transparent] = ACTIONS(1102),
    [anon_sym_LPAREN] = ACTIONS(1108),
    [anon_sym_macro] = ACTIONS(1270),
    [anon_sym_BANG] = ACTIONS(1100),
    [anon_sym_TILDE] = ACTIONS(1100),
    [anon_sym_DOLLAR] = ACTIONS(1110),
    [anon_sym_SQUOTE] = ACTIONS(1112),
    [sym__backquoted_id] = ACTIONS(1114),
    [sym_operator_identifier] = ACTIONS(2168),
    [sym_integer_literal] = ACTIONS(1118),
    [sym_floating_point_literal] = ACTIONS(1120),
    [anon_sym_true] = ACTIONS(1122),
    [anon_sym_false] = ACTIONS(1122),
    [sym_character_literal] = ACTIONS(1120),
    [sym_null_literal] = ACTIONS(1124),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2172),
    [anon_sym_do] = ACTIONS(1278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__simple_multiline_string] = ACTIONS(1126),
    [sym__simple_string] = ACTIONS(1126),
  },
  [2412] = {
    [sym_comment] = STATE(2412),
    [sym_block_comment] = STATE(2412),
    [sym__alpha_identifier] = ACTIONS(4174),
    [anon_sym_COLON] = ACTIONS(4176),
    [anon_sym_LBRACE] = ACTIONS(4178),
    [anon_sym_RBRACE] = ACTIONS(4180),
    [anon_sym_case] = ACTIONS(4174),
    [anon_sym_DOT] = ACTIONS(4176),
    [anon_sym_object] = ACTIONS(4174),
    [anon_sym__] = ACTIONS(4174),
    [anon_sym_given] = ACTIONS(4174),
    [anon_sym_EQ_GT] = ACTIONS(4176),
    [anon_sym_class] = ACTIONS(4174),
    [anon_sym_trait] = ACTIONS(4174),
    [anon_sym_LBRACK] = ACTIONS(4180),
    [anon_sym_PLUS] = ACTIONS(4174),
    [anon_sym_DASH] = ACTIONS(4174),
    [anon_sym_end] = ACTIONS(4174),
    [anon_sym_if] = ACTIONS(4174),
    [anon_sym_while] = ACTIONS(4174),
    [anon_sym_for] = ACTIONS(4174),
    [anon_sym_match] = ACTIONS(4176),
    [anon_sym_try] = ACTIONS(4174),
    [anon_sym_new] = ACTIONS(4174),
    [anon_sym_val] = ACTIONS(4174),
    [anon_sym_EQ] = ACTIONS(4176),
    [anon_sym_var] = ACTIONS(4174),
    [anon_sym_type] = ACTIONS(4174),
    [anon_sym_def] = ACTIONS(4174),
    [anon_sym_opaque] = ACTIONS(4174),
    [anon_sym_abstract] = ACTIONS(4174),
    [anon_sym_final] = ACTIONS(4174),
    [anon_sym_sealed] = ACTIONS(4174),
    [anon_sym_implicit] = ACTIONS(4174),
    [anon_sym_lazy] = ACTIONS(4174),
    [anon_sym_override] = ACTIONS(4174),
    [anon_sym_private] = ACTIONS(4174),
    [anon_sym_protected] = ACTIONS(4174),
    [anon_sym_inline] = ACTIONS(4174),
    [anon_sym_infix] = ACTIONS(4174),
    [anon_sym_open] = ACTIONS(4174),
    [anon_sym_transparent] = ACTIONS(4174),
    [anon_sym_LPAREN] = ACTIONS(4178),
    [anon_sym_RPAREN] = ACTIONS(4180),
    [anon_sym_SEMI] = ACTIONS(4180),
    [anon_sym_QMARK_EQ_GT] = ACTIONS(4176),
    [anon_sym_macro] = ACTIONS(4174),
    [anon_sym_BANG] = ACTIONS(4174),
    [anon_sym_TILDE] = ACTIONS(4174),
    [anon_sym_DOLLAR] = ACTIONS(4174),
    [anon_sym_SQUOTE] = ACTIONS(4174),
    [sym__backquoted_id] = ACTIONS(4178),
    [sym_operator_identifier] = ACTIONS(4174),
    [sym_integer_literal] = ACTIONS(4174),
    [sym_floating_point_literal] = ACTIONS(4178),
    [anon_sym_true] = ACTIONS(4174),
    [anon_sym_false] = ACTIONS(4174),
    [sym_character_literal] = ACTIONS(4178),
    [anon_sym_DQUOTE] = ACTIONS(4176),
    [sym__interpolated_multiline_string_start] = ACTIONS(4180),
    [sym_null_literal] = ACTIONS(4174),
    [anon_sym_return] = ACTIONS(4174),
    [anon_sym_throw] = ACTIONS(4174),
    [anon_sym_do] = ACTIONS(4174),
    [anon_sym_yield] = ACTIONS(4176),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(4180),
    [sym__simple_multiline_string] = ACTIONS(4178),
    [sym__simple_string] = ACTIONS(4178),
  },
  [2413] = {
    [sym_comment] = STATE(2413),
    [sym_block_comment] = STATE(2413),
    [sym__alpha_identifier] = ACTIONS(4174),
    [anon_sym_COLON] = ACTIONS(4176),
    [anon_sym_LBRACE] = ACTIONS(4178),
    [anon_sym_case] = ACTIONS(4174),
    [anon_sym_DOT] = ACTIONS(4176),
    [anon_sym_object] = ACTIONS(4174),
    [anon_sym__] = ACTIONS(4174),
    [anon_sym_given] = ACTIONS(4174),
    [anon_sym_EQ_GT] = ACTIONS(4176),
    [anon_sym_class] = ACTIONS(4174),
    [anon_sym_trait] = ACTIONS(4174),
    [anon_sym_LBRACK] = ACTIONS(4180),
    [anon_sym_PLUS] = ACTIONS(4174),
    [anon_sym_DASH] = ACTIONS(4174),
    [anon_sym_end] = ACTIONS(4174),
    [anon_sym_if] = ACTIONS(4174),
    [anon_sym_while] = ACTIONS(4174),
    [anon_sym_for] = ACTIONS(4174),
    [anon_sym_match] = ACTIONS(4176),
    [anon_sym_try] = ACTIONS(4174),
    [anon_sym_new] = ACTIONS(4174),
    [anon_sym_val] = ACTIONS(4174),
    [anon_sym_EQ] = ACTIONS(4176),
    [anon_sym_var] = ACTIONS(4174),
    [anon_sym_type] = ACTIONS(4174),
    [anon_sym_def] = ACTIONS(4174),
    [anon_sym_opaque] = ACTIONS(4174),
    [anon_sym_abstract] = ACTIONS(4174),
    [anon_sym_final] = ACTIONS(4174),
    [anon_sym_sealed] = ACTIONS(4174),
    [anon_sym_implicit] = ACTIONS(4174),
    [anon_sym_lazy] = ACTIONS(4174),
    [anon_sym_override] = ACTIONS(4174),
    [anon_sym_private] = ACTIONS(4174),
    [anon_sym_protected] = ACTIONS(4174),
    [anon_sym_inline] = ACTIONS(4174),
    [anon_sym_infix] = ACTIONS(4174),
    [anon_sym_open] = ACTIONS(4174),
    [anon_sym_transparent] = ACTIONS(4174),
    [anon_sym_LPAREN] = ACTIONS(4178),
    [anon_sym_SEMI] = ACTIONS(4180),
    [anon_sym_QMARK_EQ_GT] = ACTIONS(4176),
    [anon_sym_macro] = ACTIONS(4174),
    [anon_sym_BANG] = ACTIONS(4174),
    [anon_sym_TILDE] = ACTIONS(4174),
    [anon_sym_DOLLAR] = ACTIONS(4174),
    [anon_sym_SQUOTE] = ACTIONS(4174),
    [sym__backquoted_id] = ACTIONS(4178),
    [sym_operator_identifier] = ACTIONS(4174),
    [sym_integer_literal] = ACTIONS(4174),
    [sym_floating_point_literal] = ACTIONS(4178),
    [anon_sym_true] = ACTIONS(4174),
    [anon_sym_false] = ACTIONS(4174),
    [sym_character_literal] = ACTIONS(4178),
    [anon_sym_DQUOTE] = ACTIONS(4176),
    [sym__interpolated_multiline_string_start] = ACTIONS(4180),
    [sym_null_literal] = ACTIONS(4174),
    [anon_sym_return] = ACTIONS(4174),
    [anon_sym_throw] = ACTIONS(4174),
    [anon_sym_do] = ACTIONS(4174),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(4180),
    [sym__outdent] = ACTIONS(4180),
    [sym__simple_multiline_string] = ACTIONS(4178),
    [sym__simple_string] = ACTIONS(4178),
  },
  [2414] = {
    [sym_comment] = STATE(2414),
    [sym_block_comment] = STATE(2414),
    [ts_builtin_sym_end] = ACTIONS(4180),
    [sym__alpha_identifier] = ACTIONS(4174),
    [anon_sym_COLON] = ACTIONS(4176),
    [anon_sym_LBRACE] = ACTIONS(4178),
    [anon_sym_case] = ACTIONS(4174),
    [anon_sym_DOT] = ACTIONS(4176),
    [anon_sym_object] = ACTIONS(4174),
    [anon_sym__] = ACTIONS(4174),
    [anon_sym_given] = ACTIONS(4174),
    [anon_sym_EQ_GT] = ACTIONS(4176),
    [anon_sym_class] = ACTIONS(4174),
    [anon_sym_trait] = ACTIONS(4174),
    [anon_sym_LBRACK] = ACTIONS(4180),
    [anon_sym_PLUS] = ACTIONS(4174),
    [anon_sym_DASH] = ACTIONS(4174),
    [anon_sym_end] = ACTIONS(4174),
    [anon_sym_if] = ACTIONS(4174),
    [anon_sym_while] = ACTIONS(4174),
    [anon_sym_for] = ACTIONS(4174),
    [anon_sym_match] = ACTIONS(4176),
    [anon_sym_try] = ACTIONS(4174),
    [anon_sym_new] = ACTIONS(4174),
    [anon_sym_val] = ACTIONS(4174),
    [anon_sym_EQ] = ACTIONS(4176),
    [anon_sym_var] = ACTIONS(4174),
    [anon_sym_type] = ACTIONS(4174),
    [anon_sym_def] = ACTIONS(4174),
    [anon_sym_opaque] = ACTIONS(4174),
    [anon_sym_abstract] = ACTIONS(4174),
    [anon_sym_final] = ACTIONS(4174),
    [anon_sym_sealed] = ACTIONS(4174),
    [anon_sym_implicit] = ACTIONS(4174),
    [anon_sym_lazy] = ACTIONS(4174),
    [anon_sym_override] = ACTIONS(4174),
    [anon_sym_private] = ACTIONS(4174),
    [anon_sym_protected] = ACTIONS(4174),
    [anon_sym_inline] = ACTIONS(4174),
    [anon_sym_infix] = ACTIONS(4174),
    [anon_sym_open] = ACTIONS(4174),
    [anon_sym_transparent] = ACTIONS(4174),
    [anon_sym_LPAREN] = ACTIONS(4178),
    [anon_sym_SEMI] = ACTIONS(4180),
    [anon_sym_QMARK_EQ_GT] = ACTIONS(4176),
    [anon_sym_macro] = ACTIONS(4174),
    [anon_sym_BANG] = ACTIONS(4174),
    [anon_sym_TILDE] = ACTIONS(4174),
    [anon_sym_DOLLAR] = ACTIONS(4174),
    [anon_sym_SQUOTE] = ACTIONS(4174),
    [sym__backquoted_id] = ACTIONS(4178),
    [sym_operator_identifier] = ACTIONS(4174),
    [sym_integer_literal] = ACTIONS(4174),
    [sym_floating_point_literal] = ACTIONS(4178),
    [anon_sym_true] = ACTIONS(4174),
    [anon_sym_false] = ACTIONS(4174),
    [sym_character_literal] = ACTIONS(4178),
    [anon_sym_DQUOTE] = ACTIONS(4176),
    [sym__interpolated_multiline_string_start] = ACTIONS(4180),
    [sym_null_literal] = ACTIONS(4174),
    [anon_sym_return] = ACTIONS(4174),
    [anon_sym_throw] = ACTIONS(4174),
    [anon_sym_do] = ACTIONS(4174),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [sym__automatic_semicolon] = ACTIONS(4180),
    [sym__simple_multiline_string] = ACTIONS(4178),
    [sym__simple_string] = ACTIONS(4178),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4182), 1,
      sym__alpha_identifier,
    ACTIONS(4184), 1,
      anon_sym_COLON,
    ACTIONS(4186), 1,
      anon_sym_LBRACE,
    ACTIONS(4188), 1,
      anon_sym__,
    ACTIONS(4190), 1,
      anon_sym_EQ_GT,
    ACTIONS(4192), 1,
      anon_sym_LBRACK,
    ACTIONS(4196), 1,
      anon_sym_AT,
    ACTIONS(4198), 1,
      anon_sym_LPAREN,
    ACTIONS(4200), 1,
      sym__backquoted_id,
    ACTIONS(4202), 1,
      sym_operator_identifier,
    ACTIONS(4204), 1,
      sym_integer_literal,
    ACTIONS(4210), 1,
      sym__indent,
    STATE(4560), 1,
      sym__simple_type,
    STATE(4566), 1,
      sym__annotated_type,
    STATE(4657), 1,
      sym__soft_identifier,
    STATE(5060), 1,
      sym_identifier,
    STATE(5098), 1,
      sym_wildcard,
    STATE(6338), 1,
      sym_annotated_type,
    STATE(7057), 1,
      sym_colon_argument,
    STATE(12645), 1,
      sym_template_body,
    STATE(12687), 1,
      sym__type,
    STATE(12704), 1,
      sym__non_null_literal,
    STATE(12779), 1,
      sym__infix_type_choice,
    STATE(15998), 1,
      sym_parameter_types,
    STATE(16812), 1,
      sym_bindings,
    STATE(17648), 1,
      sym_stable_identifier,
    ACTIONS(4206), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4208), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4212), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2415), 2,
      sym_comment,
      sym_block_comment,
    STATE(7015), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(8704), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12525), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12788), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13149), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(12703), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4194), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4885), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [145] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4214), 1,
      sym__alpha_identifier,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4220), 1,
      anon_sym__,
    ACTIONS(4222), 1,
      anon_sym_EQ_GT,
    ACTIONS(4224), 1,
      anon_sym_LBRACK,
    ACTIONS(4228), 1,
      anon_sym_AT,
    ACTIONS(4230), 1,
      anon_sym_LPAREN,
    ACTIONS(4232), 1,
      sym__backquoted_id,
    ACTIONS(4234), 1,
      sym_operator_identifier,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(4242), 1,
      sym__indent,
    STATE(4653), 1,
      sym__simple_type,
    STATE(4660), 1,
      sym__annotated_type,
    STATE(5031), 1,
      sym__soft_identifier,
    STATE(5494), 1,
      sym_identifier,
    STATE(5575), 1,
      sym_wildcard,
    STATE(6990), 1,
      sym_annotated_type,
    STATE(8163), 1,
      sym_colon_argument,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12467), 1,
      sym__infix_type_choice,
    STATE(12522), 1,
      sym__type,
    STATE(15959), 1,
      sym_parameter_types,
    STATE(17054), 1,
      sym_stable_identifier,
    STATE(17891), 1,
      sym_bindings,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2416), 2,
      sym_comment,
      sym_block_comment,
    STATE(8164), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13058), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4226), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5167), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [290] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4246), 1,
      sym__alpha_identifier,
    ACTIONS(4248), 1,
      anon_sym_COLON,
    ACTIONS(4250), 1,
      anon_sym_LBRACE,
    ACTIONS(4252), 1,
      anon_sym__,
    ACTIONS(4254), 1,
      anon_sym_EQ_GT,
    ACTIONS(4256), 1,
      anon_sym_LBRACK,
    ACTIONS(4260), 1,
      anon_sym_AT,
    ACTIONS(4262), 1,
      anon_sym_LPAREN,
    ACTIONS(4264), 1,
      sym__backquoted_id,
    ACTIONS(4266), 1,
      sym_operator_identifier,
    ACTIONS(4268), 1,
      sym_integer_literal,
    ACTIONS(4274), 1,
      sym__indent,
    STATE(4954), 1,
      sym__annotated_type,
    STATE(5071), 1,
      sym__simple_type,
    STATE(5208), 1,
      sym__soft_identifier,
    STATE(5511), 1,
      sym_identifier,
    STATE(6760), 1,
      sym_wildcard,
    STATE(7704), 1,
      sym_annotated_type,
    STATE(8909), 1,
      sym_colon_argument,
    STATE(12480), 1,
      sym__infix_type_choice,
    STATE(13419), 1,
      sym__non_null_literal,
    STATE(13554), 1,
      sym__type,
    STATE(13569), 1,
      sym_template_body,
    STATE(15629), 1,
      sym_parameter_types,
    STATE(17313), 1,
      sym_bindings,
    STATE(17894), 1,
      sym_stable_identifier,
    ACTIONS(4270), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4272), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2417), 2,
      sym_comment,
      sym_block_comment,
    STATE(8574), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9633), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13603), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13681), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(14042), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13410), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4258), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5976), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [435] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4278), 1,
      sym__alpha_identifier,
    ACTIONS(4280), 1,
      anon_sym_COLON,
    ACTIONS(4282), 1,
      anon_sym_LBRACE,
    ACTIONS(4284), 1,
      anon_sym__,
    ACTIONS(4286), 1,
      anon_sym_EQ_GT,
    ACTIONS(4288), 1,
      anon_sym_LBRACK,
    ACTIONS(4292), 1,
      anon_sym_AT,
    ACTIONS(4294), 1,
      anon_sym_LPAREN,
    ACTIONS(4296), 1,
      sym__backquoted_id,
    ACTIONS(4298), 1,
      sym_operator_identifier,
    ACTIONS(4300), 1,
      sym_integer_literal,
    ACTIONS(4306), 1,
      sym__indent,
    STATE(6656), 1,
      sym__annotated_type,
    STATE(6764), 1,
      sym__simple_type,
    STATE(7385), 1,
      sym__soft_identifier,
    STATE(7713), 1,
      sym_identifier,
    STATE(8376), 1,
      sym_wildcard,
    STATE(9756), 1,
      sym_annotated_type,
    STATE(10123), 1,
      sym_colon_argument,
    STATE(12120), 1,
      sym_template_body,
    STATE(12197), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12805), 1,
      sym__infix_type_choice,
    STATE(16363), 1,
      sym_parameter_types,
    STATE(17176), 1,
      sym_stable_identifier,
    STATE(17273), 1,
      sym_bindings,
    ACTIONS(4302), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4304), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4308), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2418), 2,
      sym_comment,
      sym_block_comment,
    STATE(10258), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10874), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12093), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12126), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12701), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4290), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8228), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [580] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4310), 1,
      sym__alpha_identifier,
    ACTIONS(4312), 1,
      anon_sym_COLON,
    ACTIONS(4314), 1,
      anon_sym_LBRACE,
    ACTIONS(4316), 1,
      anon_sym__,
    ACTIONS(4318), 1,
      anon_sym_EQ_GT,
    ACTIONS(4320), 1,
      anon_sym_LBRACK,
    ACTIONS(4324), 1,
      anon_sym_AT,
    ACTIONS(4326), 1,
      anon_sym_LPAREN,
    ACTIONS(4328), 1,
      sym__backquoted_id,
    ACTIONS(4330), 1,
      sym_operator_identifier,
    ACTIONS(4332), 1,
      sym_integer_literal,
    ACTIONS(4338), 1,
      sym__indent,
    STATE(4681), 1,
      sym__annotated_type,
    STATE(4737), 1,
      sym__simple_type,
    STATE(5094), 1,
      sym__soft_identifier,
    STATE(5257), 1,
      sym_identifier,
    STATE(5948), 1,
      sym_wildcard,
    STATE(6999), 1,
      sym_annotated_type,
    STATE(7644), 1,
      sym_colon_argument,
    STATE(12671), 1,
      sym__infix_type_choice,
    STATE(12989), 1,
      sym__type,
    STATE(13093), 1,
      sym__non_null_literal,
    STATE(13398), 1,
      sym_template_body,
    STATE(15716), 1,
      sym_parameter_types,
    STATE(17083), 1,
      sym_bindings,
    STATE(17786), 1,
      sym_stable_identifier,
    ACTIONS(4334), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4336), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4340), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2419), 2,
      sym_comment,
      sym_block_comment,
    STATE(7681), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9572), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12958), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13360), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13688), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13091), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5293), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [725] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4228), 1,
      anon_sym_AT,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(4342), 1,
      sym__alpha_identifier,
    ACTIONS(4344), 1,
      anon_sym__,
    ACTIONS(4346), 1,
      anon_sym_EQ_GT,
    ACTIONS(4348), 1,
      anon_sym_LBRACK,
    ACTIONS(4352), 1,
      anon_sym_LPAREN,
    ACTIONS(4354), 1,
      sym__backquoted_id,
    ACTIONS(4356), 1,
      sym_operator_identifier,
    ACTIONS(4358), 1,
      sym__indent,
    STATE(7248), 1,
      sym__annotated_type,
    STATE(7255), 1,
      sym__simple_type,
    STATE(7539), 1,
      sym__soft_identifier,
    STATE(8494), 1,
      sym_identifier,
    STATE(9533), 1,
      sym_wildcard,
    STATE(10219), 1,
      sym_annotated_type,
    STATE(10527), 1,
      sym_colon_argument,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12522), 1,
      sym__type,
    STATE(12872), 1,
      sym__infix_type_choice,
    STATE(15934), 1,
      sym_parameter_types,
    STATE(17364), 1,
      sym_stable_identifier,
    STATE(18375), 1,
      sym_bindings,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2420), 2,
      sym_comment,
      sym_block_comment,
    STATE(10645), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10976), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13058), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4350), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8693), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [870] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__indent,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4380), 1,
      sym_operator_identifier,
    ACTIONS(4382), 1,
      sym_integer_literal,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(7057), 1,
      sym_colon_argument,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10225), 1,
      sym_identifier,
    STATE(10630), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16812), 1,
      sym_bindings,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2421), 2,
      sym_comment,
      sym_block_comment,
    STATE(7015), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1015] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4390), 1,
      sym__alpha_identifier,
    ACTIONS(4392), 1,
      anon_sym_COLON,
    ACTIONS(4394), 1,
      anon_sym_LBRACE,
    ACTIONS(4396), 1,
      anon_sym__,
    ACTIONS(4398), 1,
      anon_sym_EQ_GT,
    ACTIONS(4400), 1,
      anon_sym_LBRACK,
    ACTIONS(4404), 1,
      anon_sym_AT,
    ACTIONS(4406), 1,
      anon_sym_LPAREN,
    ACTIONS(4408), 1,
      sym__backquoted_id,
    ACTIONS(4410), 1,
      sym_operator_identifier,
    ACTIONS(4412), 1,
      sym_integer_literal,
    ACTIONS(4418), 1,
      sym__indent,
    STATE(6561), 1,
      sym__simple_type,
    STATE(6771), 1,
      sym__annotated_type,
    STATE(7208), 1,
      sym__soft_identifier,
    STATE(8054), 1,
      sym_identifier,
    STATE(8711), 1,
      sym_wildcard,
    STATE(9943), 1,
      sym_annotated_type,
    STATE(10173), 1,
      sym_colon_argument,
    STATE(12079), 1,
      sym__type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12623), 1,
      sym__infix_type_choice,
    STATE(16087), 1,
      sym_parameter_types,
    STATE(16693), 1,
      sym_bindings,
    STATE(17606), 1,
      sym_stable_identifier,
    ACTIONS(4414), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4416), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2422), 2,
      sym_comment,
      sym_block_comment,
    STATE(10160), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10756), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12316), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12382), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12896), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4402), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8276), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1160] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4422), 1,
      sym__alpha_identifier,
    ACTIONS(4424), 1,
      anon_sym_COLON,
    ACTIONS(4426), 1,
      anon_sym_LBRACE,
    ACTIONS(4428), 1,
      anon_sym__,
    ACTIONS(4430), 1,
      anon_sym_EQ_GT,
    ACTIONS(4432), 1,
      anon_sym_LBRACK,
    ACTIONS(4436), 1,
      anon_sym_AT,
    ACTIONS(4438), 1,
      anon_sym_LPAREN,
    ACTIONS(4440), 1,
      sym__backquoted_id,
    ACTIONS(4442), 1,
      sym_operator_identifier,
    ACTIONS(4444), 1,
      sym_integer_literal,
    ACTIONS(4450), 1,
      sym__indent,
    STATE(5648), 1,
      sym__simple_type,
    STATE(5924), 1,
      sym__annotated_type,
    STATE(6399), 1,
      sym__soft_identifier,
    STATE(7420), 1,
      sym_identifier,
    STATE(7534), 1,
      sym_wildcard,
    STATE(9039), 1,
      sym_annotated_type,
    STATE(9886), 1,
      sym_colon_argument,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(11905), 1,
      sym__type,
    STATE(12603), 1,
      sym__infix_type_choice,
    STATE(15199), 1,
      sym_parameter_types,
    STATE(17146), 1,
      sym_bindings,
    STATE(17810), 1,
      sym_stable_identifier,
    ACTIONS(4446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4452), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2423), 2,
      sym_comment,
      sym_block_comment,
    STATE(9960), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10474), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11978), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12261), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4434), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7419), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1305] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4454), 1,
      sym_operator_identifier,
    ACTIONS(4456), 1,
      sym__indent,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9272), 1,
      sym_colon_argument,
    STATE(10289), 1,
      sym_identifier,
    STATE(10559), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17125), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2424), 2,
      sym_comment,
      sym_block_comment,
    STATE(9546), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1450] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4458), 1,
      sym_operator_identifier,
    ACTIONS(4460), 1,
      sym__indent,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(8881), 1,
      sym_colon_argument,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10120), 1,
      sym_identifier,
    STATE(10493), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(16920), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2425), 2,
      sym_comment,
      sym_block_comment,
    STATE(8908), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1595] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__alpha_identifier,
    ACTIONS(4464), 1,
      anon_sym_COLON,
    ACTIONS(4466), 1,
      anon_sym_LBRACE,
    ACTIONS(4468), 1,
      anon_sym__,
    ACTIONS(4470), 1,
      anon_sym_EQ_GT,
    ACTIONS(4472), 1,
      anon_sym_LBRACK,
    ACTIONS(4476), 1,
      anon_sym_AT,
    ACTIONS(4478), 1,
      anon_sym_LPAREN,
    ACTIONS(4480), 1,
      sym__backquoted_id,
    ACTIONS(4482), 1,
      sym_operator_identifier,
    ACTIONS(4484), 1,
      sym_integer_literal,
    ACTIONS(4490), 1,
      sym__indent,
    STATE(5016), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym__annotated_type,
    STATE(5328), 1,
      sym__soft_identifier,
    STATE(6086), 1,
      sym_identifier,
    STATE(6201), 1,
      sym_wildcard,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(8751), 1,
      sym_colon_argument,
    STATE(12644), 1,
      sym__infix_type_choice,
    STATE(13484), 1,
      sym__type,
    STATE(13626), 1,
      sym_template_body,
    STATE(13664), 1,
      sym__non_null_literal,
    STATE(16353), 1,
      sym_parameter_types,
    STATE(17035), 1,
      sym_bindings,
    STATE(17379), 1,
      sym_stable_identifier,
    ACTIONS(4486), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4488), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4492), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2426), 2,
      sym_comment,
      sym_block_comment,
    STATE(8306), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9743), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13536), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13680), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13920), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13674), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6029), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1740] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4494), 1,
      sym_operator_identifier,
    ACTIONS(4496), 1,
      sym__indent,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6241), 1,
      sym_colon_argument,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10329), 1,
      sym_identifier,
    STATE(10472), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17167), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2427), 2,
      sym_comment,
      sym_block_comment,
    STATE(6635), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [1885] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4338), 1,
      sym__indent,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4498), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(7644), 1,
      sym_colon_argument,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10278), 1,
      sym_identifier,
    STATE(10579), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17083), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2428), 2,
      sym_comment,
      sym_block_comment,
    STATE(7681), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2030] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4242), 1,
      sym__indent,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4500), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(8163), 1,
      sym_colon_argument,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10044), 1,
      sym_identifier,
    STATE(10413), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17891), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2429), 2,
      sym_comment,
      sym_block_comment,
    STATE(8164), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2175] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4502), 1,
      sym_operator_identifier,
    ACTIONS(4504), 1,
      sym__indent,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(8420), 1,
      sym_colon_argument,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10096), 1,
      sym_identifier,
    STATE(10457), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17442), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2430), 2,
      sym_comment,
      sym_block_comment,
    STATE(8373), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2320] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4506), 1,
      sym_operator_identifier,
    ACTIONS(4508), 1,
      sym__indent,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10060), 1,
      sym_identifier,
    STATE(10432), 1,
      sym_wildcard,
    STATE(11040), 1,
      sym_colon_argument,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16711), 1,
      sym_bindings,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2431), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10948), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2465] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4490), 1,
      sym__indent,
    ACTIONS(4510), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(8751), 1,
      sym_colon_argument,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10114), 1,
      sym_identifier,
    STATE(10483), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17035), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2432), 2,
      sym_comment,
      sym_block_comment,
    STATE(8306), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2610] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4280), 1,
      anon_sym_COLON,
    ACTIONS(4282), 1,
      anon_sym_LBRACE,
    ACTIONS(4292), 1,
      anon_sym_AT,
    ACTIONS(4300), 1,
      sym_integer_literal,
    ACTIONS(4512), 1,
      sym__alpha_identifier,
    ACTIONS(4514), 1,
      anon_sym__,
    ACTIONS(4516), 1,
      anon_sym_EQ_GT,
    ACTIONS(4518), 1,
      anon_sym_LBRACK,
    ACTIONS(4522), 1,
      anon_sym_LPAREN,
    ACTIONS(4524), 1,
      sym__backquoted_id,
    ACTIONS(4526), 1,
      sym_operator_identifier,
    ACTIONS(4528), 1,
      sym__indent,
    STATE(4600), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__simple_type,
    STATE(4696), 1,
      sym__soft_identifier,
    STATE(4828), 1,
      sym_identifier,
    STATE(5453), 1,
      sym_wildcard,
    STATE(6758), 1,
      sym_annotated_type,
    STATE(7145), 1,
      sym_colon_argument,
    STATE(12120), 1,
      sym_template_body,
    STATE(12197), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12714), 1,
      sym__infix_type_choice,
    STATE(15966), 1,
      sym_parameter_types,
    STATE(17160), 1,
      sym_bindings,
    STATE(17301), 1,
      sym_stable_identifier,
    ACTIONS(4302), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4304), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4308), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2433), 2,
      sym_comment,
      sym_block_comment,
    STATE(6960), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(8405), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12093), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12126), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12701), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4520), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5076), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2755] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4530), 1,
      sym__alpha_identifier,
    ACTIONS(4532), 1,
      anon_sym_COLON,
    ACTIONS(4534), 1,
      anon_sym_LBRACE,
    ACTIONS(4536), 1,
      anon_sym__,
    ACTIONS(4538), 1,
      anon_sym_EQ_GT,
    ACTIONS(4540), 1,
      anon_sym_LBRACK,
    ACTIONS(4544), 1,
      anon_sym_AT,
    ACTIONS(4546), 1,
      anon_sym_LPAREN,
    ACTIONS(4548), 1,
      sym__backquoted_id,
    ACTIONS(4550), 1,
      sym_operator_identifier,
    ACTIONS(4552), 1,
      sym_integer_literal,
    ACTIONS(4558), 1,
      sym__indent,
    STATE(5220), 1,
      sym__annotated_type,
    STATE(5311), 1,
      sym__simple_type,
    STATE(5882), 1,
      sym__soft_identifier,
    STATE(6597), 1,
      sym_identifier,
    STATE(7059), 1,
      sym_wildcard,
    STATE(8575), 1,
      sym_annotated_type,
    STATE(9267), 1,
      sym_colon_argument,
    STATE(12867), 1,
      sym__infix_type_choice,
    STATE(13752), 1,
      sym__type,
    STATE(13856), 1,
      sym_template_body,
    STATE(13862), 1,
      sym__non_null_literal,
    STATE(15903), 1,
      sym_parameter_types,
    STATE(16862), 1,
      sym_bindings,
    STATE(17666), 1,
      sym_stable_identifier,
    ACTIONS(4554), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4556), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4560), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2434), 2,
      sym_comment,
      sym_block_comment,
    STATE(9467), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10142), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13890), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13946), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14266), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13863), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4542), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6618), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [2900] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4562), 1,
      sym__alpha_identifier,
    ACTIONS(4564), 1,
      anon_sym_COLON,
    ACTIONS(4566), 1,
      anon_sym_LBRACE,
    ACTIONS(4568), 1,
      anon_sym__,
    ACTIONS(4570), 1,
      anon_sym_EQ_GT,
    ACTIONS(4572), 1,
      anon_sym_LBRACK,
    ACTIONS(4576), 1,
      anon_sym_AT,
    ACTIONS(4578), 1,
      anon_sym_LPAREN,
    ACTIONS(4580), 1,
      sym__backquoted_id,
    ACTIONS(4582), 1,
      sym_operator_identifier,
    ACTIONS(4584), 1,
      sym_integer_literal,
    ACTIONS(4590), 1,
      sym__indent,
    STATE(5229), 1,
      sym__annotated_type,
    STATE(5319), 1,
      sym__simple_type,
    STATE(5868), 1,
      sym__soft_identifier,
    STATE(6450), 1,
      sym_identifier,
    STATE(7113), 1,
      sym_wildcard,
    STATE(8394), 1,
      sym_annotated_type,
    STATE(9494), 1,
      sym_colon_argument,
    STATE(12897), 1,
      sym__infix_type_choice,
    STATE(13794), 1,
      sym__non_null_literal,
    STATE(14022), 1,
      sym_template_body,
    STATE(14027), 1,
      sym__type,
    STATE(15778), 1,
      sym_parameter_types,
    STATE(16886), 1,
      sym_bindings,
    STATE(17678), 1,
      sym_stable_identifier,
    ACTIONS(4586), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4588), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4592), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2435), 2,
      sym_comment,
      sym_block_comment,
    STATE(9219), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10204), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13758), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13993), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(14081), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13825), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4574), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6389), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3045] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4460), 1,
      sym__indent,
    ACTIONS(4594), 1,
      sym__alpha_identifier,
    ACTIONS(4596), 1,
      anon_sym_COLON,
    ACTIONS(4598), 1,
      anon_sym_LBRACE,
    ACTIONS(4600), 1,
      anon_sym__,
    ACTIONS(4602), 1,
      anon_sym_EQ_GT,
    ACTIONS(4604), 1,
      anon_sym_LBRACK,
    ACTIONS(4608), 1,
      anon_sym_AT,
    ACTIONS(4610), 1,
      anon_sym_LPAREN,
    ACTIONS(4612), 1,
      sym__backquoted_id,
    ACTIONS(4614), 1,
      sym_operator_identifier,
    ACTIONS(4616), 1,
      sym_integer_literal,
    STATE(5023), 1,
      sym__annotated_type,
    STATE(5090), 1,
      sym__simple_type,
    STATE(5264), 1,
      sym__soft_identifier,
    STATE(5634), 1,
      sym_identifier,
    STATE(6598), 1,
      sym_wildcard,
    STATE(7582), 1,
      sym_annotated_type,
    STATE(8881), 1,
      sym_colon_argument,
    STATE(12573), 1,
      sym__infix_type_choice,
    STATE(13562), 1,
      sym__non_null_literal,
    STATE(13613), 1,
      sym__type,
    STATE(13691), 1,
      sym_template_body,
    STATE(16287), 1,
      sym_parameter_types,
    STATE(16920), 1,
      sym_bindings,
    STATE(17492), 1,
      sym_stable_identifier,
    ACTIONS(4618), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4620), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4622), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2436), 2,
      sym_comment,
      sym_block_comment,
    STATE(8908), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9982), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13453), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13524), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13924), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13531), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5951), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3190] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4624), 1,
      sym__alpha_identifier,
    ACTIONS(4626), 1,
      anon_sym_COLON,
    ACTIONS(4628), 1,
      anon_sym_LBRACE,
    ACTIONS(4630), 1,
      anon_sym__,
    ACTIONS(4632), 1,
      anon_sym_EQ_GT,
    ACTIONS(4634), 1,
      anon_sym_LBRACK,
    ACTIONS(4638), 1,
      anon_sym_AT,
    ACTIONS(4640), 1,
      anon_sym_LPAREN,
    ACTIONS(4642), 1,
      sym__backquoted_id,
    ACTIONS(4644), 1,
      sym_operator_identifier,
    ACTIONS(4646), 1,
      sym_integer_literal,
    ACTIONS(4652), 1,
      sym__indent,
    STATE(4397), 1,
      sym__annotated_type,
    STATE(4437), 1,
      sym__simple_type,
    STATE(4445), 1,
      sym__soft_identifier,
    STATE(4595), 1,
      sym_identifier,
    STATE(4721), 1,
      sym_wildcard,
    STATE(5361), 1,
      sym_annotated_type,
    STATE(5611), 1,
      sym_colon_argument,
    STATE(11448), 1,
      sym__type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(12672), 1,
      sym__infix_type_choice,
    STATE(15969), 1,
      sym_parameter_types,
    STATE(16730), 1,
      sym_bindings,
    STATE(17628), 1,
      sym_stable_identifier,
    ACTIONS(4648), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4650), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4654), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2437), 2,
      sym_comment,
      sym_block_comment,
    STATE(5884), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(7102), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11482), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11561), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11864), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4542), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3335] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4358), 1,
      sym__indent,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4656), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10233), 1,
      sym_identifier,
    STATE(10527), 1,
      sym_colon_argument,
    STATE(10652), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(18375), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2438), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10645), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3480] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4652), 1,
      sym__indent,
    ACTIONS(4658), 1,
      sym_operator_identifier,
    STATE(5611), 1,
      sym_colon_argument,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10179), 1,
      sym_identifier,
    STATE(10565), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16730), 1,
      sym_bindings,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2439), 2,
      sym_comment,
      sym_block_comment,
    STATE(5884), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3625] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4660), 1,
      sym__alpha_identifier,
    ACTIONS(4662), 1,
      anon_sym_COLON,
    ACTIONS(4664), 1,
      anon_sym_LBRACE,
    ACTIONS(4666), 1,
      anon_sym__,
    ACTIONS(4668), 1,
      anon_sym_EQ_GT,
    ACTIONS(4670), 1,
      anon_sym_LBRACK,
    ACTIONS(4674), 1,
      anon_sym_AT,
    ACTIONS(4676), 1,
      anon_sym_LPAREN,
    ACTIONS(4678), 1,
      sym__backquoted_id,
    ACTIONS(4680), 1,
      sym_operator_identifier,
    ACTIONS(4682), 1,
      sym_integer_literal,
    ACTIONS(4688), 1,
      sym__indent,
    STATE(4446), 1,
      sym__simple_type,
    STATE(4469), 1,
      sym__annotated_type,
    STATE(4601), 1,
      sym__soft_identifier,
    STATE(4707), 1,
      sym_identifier,
    STATE(5045), 1,
      sym_wildcard,
    STATE(6053), 1,
      sym_annotated_type,
    STATE(6453), 1,
      sym_colon_argument,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11772), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12559), 1,
      sym__infix_type_choice,
    STATE(15963), 1,
      sym_parameter_types,
    STATE(16896), 1,
      sym_stable_identifier,
    STATE(17571), 1,
      sym_bindings,
    ACTIONS(4684), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4686), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2440), 2,
      sym_comment,
      sym_block_comment,
    STATE(6262), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(8221), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11722), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11743), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12389), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4672), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4757), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3770] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4424), 1,
      anon_sym_COLON,
    ACTIONS(4426), 1,
      anon_sym_LBRACE,
    ACTIONS(4436), 1,
      anon_sym_AT,
    ACTIONS(4444), 1,
      sym_integer_literal,
    ACTIONS(4496), 1,
      sym__indent,
    ACTIONS(4692), 1,
      sym__alpha_identifier,
    ACTIONS(4694), 1,
      anon_sym__,
    ACTIONS(4696), 1,
      anon_sym_EQ_GT,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    ACTIONS(4702), 1,
      anon_sym_LPAREN,
    ACTIONS(4704), 1,
      sym__backquoted_id,
    ACTIONS(4706), 1,
      sym_operator_identifier,
    STATE(4470), 1,
      sym__simple_type,
    STATE(4509), 1,
      sym__annotated_type,
    STATE(4547), 1,
      sym__soft_identifier,
    STATE(4786), 1,
      sym_identifier,
    STATE(4843), 1,
      sym_wildcard,
    STATE(5917), 1,
      sym_annotated_type,
    STATE(6241), 1,
      sym_colon_argument,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(11905), 1,
      sym__type,
    STATE(12585), 1,
      sym__infix_type_choice,
    STATE(15976), 1,
      sym_parameter_types,
    STATE(17167), 1,
      sym_bindings,
    STATE(17816), 1,
      sym_stable_identifier,
    ACTIONS(4446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4452), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2441), 2,
      sym_comment,
      sym_block_comment,
    STATE(6635), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(7772), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11978), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12261), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4739), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [3915] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4688), 1,
      sym__indent,
    ACTIONS(4708), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6453), 1,
      sym_colon_argument,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10129), 1,
      sym_identifier,
    STATE(10504), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17571), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2442), 2,
      sym_comment,
      sym_block_comment,
    STATE(6262), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4060] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4590), 1,
      sym__indent,
    ACTIONS(4710), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9494), 1,
      sym_colon_argument,
    STATE(10265), 1,
      sym_identifier,
    STATE(10611), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16886), 1,
      sym_bindings,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2443), 2,
      sym_comment,
      sym_block_comment,
    STATE(9219), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4205] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4712), 1,
      sym__alpha_identifier,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4718), 1,
      anon_sym__,
    ACTIONS(4720), 1,
      anon_sym_EQ_GT,
    ACTIONS(4722), 1,
      anon_sym_LBRACK,
    ACTIONS(4726), 1,
      anon_sym_AT,
    ACTIONS(4728), 1,
      anon_sym_LPAREN,
    ACTIONS(4730), 1,
      sym__backquoted_id,
    ACTIONS(4732), 1,
      sym_operator_identifier,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(4740), 1,
      sym__indent,
    STATE(5508), 1,
      sym__annotated_type,
    STATE(6100), 1,
      sym__simple_type,
    STATE(6328), 1,
      sym__soft_identifier,
    STATE(7367), 1,
      sym_identifier,
    STATE(7632), 1,
      sym_wildcard,
    STATE(9270), 1,
      sym_annotated_type,
    STATE(9950), 1,
      sym_colon_argument,
    STATE(12148), 1,
      sym_template_body,
    STATE(12853), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(14194), 1,
      sym__type,
    STATE(16335), 1,
      sym_parameter_types,
    STATE(17134), 1,
      sym_stable_identifier,
    STATE(17330), 1,
      sym_bindings,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2444), 2,
      sym_comment,
      sym_block_comment,
    STATE(9829), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10600), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14389), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4724), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7010), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4350] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4274), 1,
      sym__indent,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4744), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(8909), 1,
      sym_colon_argument,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10361), 1,
      sym_identifier,
    STATE(10386), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17313), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2445), 2,
      sym_comment,
      sym_block_comment,
    STATE(8574), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4495] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4746), 1,
      sym_operator_identifier,
    ACTIONS(4748), 1,
      sym__indent,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(7022), 1,
      sym_identifier,
    STATE(8001), 1,
      sym_wildcard,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9997), 1,
      sym_colon_argument,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17765), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2446), 2,
      sym_comment,
      sym_block_comment,
    STATE(10000), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4640] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4392), 1,
      anon_sym_COLON,
    ACTIONS(4394), 1,
      anon_sym_LBRACE,
    ACTIONS(4404), 1,
      anon_sym_AT,
    ACTIONS(4412), 1,
      sym_integer_literal,
    ACTIONS(4750), 1,
      sym__alpha_identifier,
    ACTIONS(4752), 1,
      anon_sym__,
    ACTIONS(4754), 1,
      anon_sym_EQ_GT,
    ACTIONS(4756), 1,
      anon_sym_LBRACK,
    ACTIONS(4760), 1,
      anon_sym_LPAREN,
    ACTIONS(4762), 1,
      sym__backquoted_id,
    ACTIONS(4764), 1,
      sym_operator_identifier,
    ACTIONS(4766), 1,
      sym__indent,
    STATE(4572), 1,
      sym__annotated_type,
    STATE(4614), 1,
      sym__simple_type,
    STATE(4635), 1,
      sym__soft_identifier,
    STATE(4838), 1,
      sym_identifier,
    STATE(5157), 1,
      sym_wildcard,
    STATE(6307), 1,
      sym_annotated_type,
    STATE(6883), 1,
      sym_colon_argument,
    STATE(12079), 1,
      sym__type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12751), 1,
      sym__infix_type_choice,
    STATE(15970), 1,
      sym_parameter_types,
    STATE(16787), 1,
      sym_bindings,
    STATE(17642), 1,
      sym_stable_identifier,
    ACTIONS(4414), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4416), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2447), 2,
      sym_comment,
      sym_block_comment,
    STATE(7149), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(8596), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12316), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12382), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12896), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4758), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4869), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4785] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4766), 1,
      sym__indent,
    ACTIONS(4768), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6883), 1,
      sym_colon_argument,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10188), 1,
      sym_identifier,
    STATE(10578), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16787), 1,
      sym_bindings,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2448), 2,
      sym_comment,
      sym_block_comment,
    STATE(7149), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [4930] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4770), 1,
      sym_operator_identifier,
    ACTIONS(4772), 1,
      sym__indent,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9086), 1,
      sym_colon_argument,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10136), 1,
      sym_identifier,
    STATE(10509), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16810), 1,
      sym_bindings,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2449), 2,
      sym_comment,
      sym_block_comment,
    STATE(9496), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5075] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4456), 1,
      sym__indent,
    ACTIONS(4774), 1,
      sym__alpha_identifier,
    ACTIONS(4776), 1,
      anon_sym_COLON,
    ACTIONS(4778), 1,
      anon_sym_LBRACE,
    ACTIONS(4780), 1,
      anon_sym__,
    ACTIONS(4782), 1,
      anon_sym_EQ_GT,
    ACTIONS(4784), 1,
      anon_sym_LBRACK,
    ACTIONS(4788), 1,
      anon_sym_AT,
    ACTIONS(4790), 1,
      anon_sym_LPAREN,
    ACTIONS(4792), 1,
      sym__backquoted_id,
    ACTIONS(4794), 1,
      sym_operator_identifier,
    ACTIONS(4796), 1,
      sym_integer_literal,
    STATE(5356), 1,
      sym__annotated_type,
    STATE(5471), 1,
      sym__simple_type,
    STATE(5800), 1,
      sym__soft_identifier,
    STATE(6148), 1,
      sym_identifier,
    STATE(7352), 1,
      sym_wildcard,
    STATE(8839), 1,
      sym_annotated_type,
    STATE(9272), 1,
      sym_colon_argument,
    STATE(12611), 1,
      sym__infix_type_choice,
    STATE(13874), 1,
      sym__non_null_literal,
    STATE(13912), 1,
      sym_template_body,
    STATE(14040), 1,
      sym__type,
    STATE(15526), 1,
      sym_parameter_types,
    STATE(17125), 1,
      sym_bindings,
    STATE(17804), 1,
      sym_stable_identifier,
    ACTIONS(4798), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4800), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4802), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2450), 2,
      sym_comment,
      sym_block_comment,
    STATE(9546), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10348), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13757), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13936), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(14084), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13869), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4786), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6677), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5220] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4450), 1,
      sym__indent,
    ACTIONS(4804), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9886), 1,
      sym_colon_argument,
    STATE(10310), 1,
      sym_identifier,
    STATE(10520), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17146), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2451), 2,
      sym_comment,
      sym_block_comment,
    STATE(9960), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5365] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4528), 1,
      sym__indent,
    ACTIONS(4806), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(7145), 1,
      sym_colon_argument,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10093), 1,
      sym_identifier,
    STATE(10462), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17160), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2452), 2,
      sym_comment,
      sym_block_comment,
    STATE(6960), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5510] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4558), 1,
      sym__indent,
    ACTIONS(4808), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9267), 1,
      sym_colon_argument,
    STATE(10238), 1,
      sym_identifier,
    STATE(10654), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16862), 1,
      sym_bindings,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2453), 2,
      sym_comment,
      sym_block_comment,
    STATE(9467), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5655] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4306), 1,
      sym__indent,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4810), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10040), 1,
      sym_identifier,
    STATE(10123), 1,
      sym_colon_argument,
    STATE(10407), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17273), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2454), 2,
      sym_comment,
      sym_block_comment,
    STATE(10258), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5800] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4662), 1,
      anon_sym_COLON,
    ACTIONS(4664), 1,
      anon_sym_LBRACE,
    ACTIONS(4674), 1,
      anon_sym_AT,
    ACTIONS(4682), 1,
      sym_integer_literal,
    ACTIONS(4812), 1,
      sym__alpha_identifier,
    ACTIONS(4814), 1,
      anon_sym__,
    ACTIONS(4816), 1,
      anon_sym_EQ_GT,
    ACTIONS(4818), 1,
      anon_sym_LBRACK,
    ACTIONS(4822), 1,
      anon_sym_LPAREN,
    ACTIONS(4824), 1,
      sym__backquoted_id,
    ACTIONS(4826), 1,
      sym_operator_identifier,
    ACTIONS(4828), 1,
      sym__indent,
    STATE(5711), 1,
      sym__simple_type,
    STATE(6017), 1,
      sym__annotated_type,
    STATE(6330), 1,
      sym__soft_identifier,
    STATE(7283), 1,
      sym_identifier,
    STATE(7698), 1,
      sym_wildcard,
    STATE(9582), 1,
      sym_annotated_type,
    STATE(9812), 1,
      sym_colon_argument,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11772), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12677), 1,
      sym__infix_type_choice,
    STATE(16098), 1,
      sym_parameter_types,
    STATE(16701), 1,
      sym_stable_identifier,
    STATE(17695), 1,
      sym_bindings,
    ACTIONS(4684), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4686), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2455), 2,
      sym_comment,
      sym_block_comment,
    STATE(9815), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10456), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11722), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11743), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12389), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4820), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7403), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [5945] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4504), 1,
      sym__indent,
    ACTIONS(4830), 1,
      sym__alpha_identifier,
    ACTIONS(4832), 1,
      anon_sym_COLON,
    ACTIONS(4834), 1,
      anon_sym_LBRACE,
    ACTIONS(4836), 1,
      anon_sym__,
    ACTIONS(4838), 1,
      anon_sym_EQ_GT,
    ACTIONS(4840), 1,
      anon_sym_LBRACK,
    ACTIONS(4844), 1,
      anon_sym_AT,
    ACTIONS(4846), 1,
      anon_sym_LPAREN,
    ACTIONS(4848), 1,
      sym__backquoted_id,
    ACTIONS(4850), 1,
      sym_operator_identifier,
    ACTIONS(4852), 1,
      sym_integer_literal,
    STATE(4938), 1,
      sym__annotated_type,
    STATE(5061), 1,
      sym__simple_type,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5935), 1,
      sym_identifier,
    STATE(6263), 1,
      sym_wildcard,
    STATE(7629), 1,
      sym_annotated_type,
    STATE(8420), 1,
      sym_colon_argument,
    STATE(12880), 1,
      sym__infix_type_choice,
    STATE(13409), 1,
      sym__type,
    STATE(13507), 1,
      sym__non_null_literal,
    STATE(13683), 1,
      sym_template_body,
    STATE(16310), 1,
      sym_parameter_types,
    STATE(17092), 1,
      sym_stable_identifier,
    STATE(17442), 1,
      sym_bindings,
    ACTIONS(4854), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4856), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4858), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2456), 2,
      sym_comment,
      sym_block_comment,
    STATE(8373), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(9961), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13549), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13687), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13725), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13506), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4842), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5759), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6090] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4740), 1,
      sym__indent,
    ACTIONS(4860), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9950), 1,
      sym_colon_argument,
    STATE(10039), 1,
      sym_identifier,
    STATE(10404), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17330), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2457), 2,
      sym_comment,
      sym_block_comment,
    STATE(9829), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6235] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4862), 1,
      sym_operator_identifier,
    ACTIONS(4864), 1,
      sym__indent,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(7739), 1,
      sym_colon_argument,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10355), 1,
      sym_identifier,
    STATE(10399), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17188), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2458), 2,
      sym_comment,
      sym_block_comment,
    STATE(8110), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6380] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4418), 1,
      sym__indent,
    ACTIONS(4866), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10156), 1,
      sym_identifier,
    STATE(10173), 1,
      sym_colon_argument,
    STATE(10540), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16693), 1,
      sym_bindings,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2459), 2,
      sym_comment,
      sym_block_comment,
    STATE(10160), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6525] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4626), 1,
      anon_sym_COLON,
    ACTIONS(4628), 1,
      anon_sym_LBRACE,
    ACTIONS(4638), 1,
      anon_sym_AT,
    ACTIONS(4646), 1,
      sym_integer_literal,
    ACTIONS(4772), 1,
      sym__indent,
    ACTIONS(4868), 1,
      sym__alpha_identifier,
    ACTIONS(4870), 1,
      anon_sym__,
    ACTIONS(4872), 1,
      anon_sym_EQ_GT,
    ACTIONS(4874), 1,
      anon_sym_LBRACK,
    ACTIONS(4878), 1,
      anon_sym_LPAREN,
    ACTIONS(4880), 1,
      sym__backquoted_id,
    ACTIONS(4882), 1,
      sym_operator_identifier,
    STATE(5113), 1,
      sym__simple_type,
    STATE(5161), 1,
      sym__annotated_type,
    STATE(5967), 1,
      sym__soft_identifier,
    STATE(6191), 1,
      sym_identifier,
    STATE(7016), 1,
      sym_wildcard,
    STATE(8739), 1,
      sym_annotated_type,
    STATE(9086), 1,
      sym_colon_argument,
    STATE(11448), 1,
      sym__type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(12584), 1,
      sym__infix_type_choice,
    STATE(16152), 1,
      sym_parameter_types,
    STATE(16810), 1,
      sym_bindings,
    STATE(17570), 1,
      sym_stable_identifier,
    ACTIONS(4648), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4650), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4654), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2460), 2,
      sym_comment,
      sym_block_comment,
    STATE(9496), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10017), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11482), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11561), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11864), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6401), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6670] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4374), 1,
      anon_sym_AT,
    ACTIONS(4376), 1,
      anon_sym_LPAREN,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4828), 1,
      sym__indent,
    ACTIONS(4884), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9812), 1,
      sym_colon_argument,
    STATE(10197), 1,
      sym_identifier,
    STATE(10589), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14224), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(17695), 1,
      sym_bindings,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2461), 2,
      sym_comment,
      sym_block_comment,
    STATE(9815), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(14399), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6815] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4864), 1,
      sym__indent,
    ACTIONS(4886), 1,
      sym__alpha_identifier,
    ACTIONS(4888), 1,
      anon_sym_COLON,
    ACTIONS(4890), 1,
      anon_sym_LBRACE,
    ACTIONS(4892), 1,
      anon_sym__,
    ACTIONS(4894), 1,
      anon_sym_EQ_GT,
    ACTIONS(4896), 1,
      anon_sym_LBRACK,
    ACTIONS(4900), 1,
      anon_sym_AT,
    ACTIONS(4902), 1,
      anon_sym_LPAREN,
    ACTIONS(4904), 1,
      sym__backquoted_id,
    ACTIONS(4906), 1,
      sym_operator_identifier,
    ACTIONS(4908), 1,
      sym_integer_literal,
    STATE(4668), 1,
      sym__simple_type,
    STATE(4690), 1,
      sym__annotated_type,
    STATE(5087), 1,
      sym__soft_identifier,
    STATE(5355), 1,
      sym_identifier,
    STATE(5971), 1,
      sym_wildcard,
    STATE(7155), 1,
      sym_annotated_type,
    STATE(7739), 1,
      sym_colon_argument,
    STATE(12544), 1,
      sym__infix_type_choice,
    STATE(13118), 1,
      sym__type,
    STATE(13245), 1,
      sym_template_body,
    STATE(13295), 1,
      sym__non_null_literal,
    STATE(15364), 1,
      sym_parameter_types,
    STATE(17188), 1,
      sym_bindings,
    STATE(17828), 1,
      sym_stable_identifier,
    ACTIONS(4910), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4912), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4914), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2462), 2,
      sym_comment,
      sym_block_comment,
    STATE(8110), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(8990), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12950), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13007), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13408), 3,
      sym_annotation,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(13299), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5448), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [6960] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4918), 9,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4916), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4922), 9,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4920), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4924), 8,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4926), 51,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_package,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7182] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4922), 9,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4920), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7256] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4930), 9,
      sym__indent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4928), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7330] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4930), 9,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4928), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7404] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4918), 9,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4916), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7478] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(4934), 1,
      anon_sym_inline,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4938), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9179), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(14964), 1,
      sym__type,
    STATE(15946), 1,
      sym_parameter,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2470), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15948), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    ACTIONS(4372), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [7621] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(4934), 1,
      anon_sym_inline,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4938), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9179), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(15117), 1,
      sym__type,
    STATE(15387), 1,
      sym_parameter,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2471), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15389), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    ACTIONS(4372), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [7764] = 41,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4952), 1,
      anon_sym_implicit,
    ACTIONS(4954), 1,
      anon_sym_inline,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4958), 1,
      anon_sym_using,
    ACTIONS(4960), 1,
      anon_sym_RPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(4964), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(9988), 1,
      sym_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(15251), 1,
      sym_parameter,
    STATE(15252), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2472), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4950), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [7909] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4930), 8,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4928), 50,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_import,
      anon_sym_export,
      anon_sym__,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_extension,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [7982] = 40,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(4934), 1,
      anon_sym_inline,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4938), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9179), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(15121), 1,
      sym__type,
    STATE(15864), 1,
      sym_parameter,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2474), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15865), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    ACTIONS(4372), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [8125] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14722), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2475), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [8259] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14811), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2476), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [8393] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14841), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2477), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [8527] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14757), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2478), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [8661] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14754), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2479), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [8795] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14842), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2480), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [8929] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14794), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2481), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9063] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14640), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2482), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9197] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14607), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2483), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9331] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14638), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2484), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9465] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14765), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2485), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9599] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14668), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2486), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9733] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14699), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2487), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [9867] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14817), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2488), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10001] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14663), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2489), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10135] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14752), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2490), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10269] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14602), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2491), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10403] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14617), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2492), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10537] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14627), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2493), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10671] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14619), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2494), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10805] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14800), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2495), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [10939] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14611), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2496), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [11073] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14613), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2497), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [11207] = 37,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4966), 1,
      anon_sym_RPAREN,
    ACTIONS(4968), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(9100), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9936), 1,
      sym_wildcard,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14631), 1,
      sym__type,
    STATE(15220), 1,
      sym_binding,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2498), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 6,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
  [11341] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14794), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2499), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [11470] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4974), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2500), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [11599] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4976), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2501), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [11728] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4978), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2502), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [11857] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4980), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2503), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [11986] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14619), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2504), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12115] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14617), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2505), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12244] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14842), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2506), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12373] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14611), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2507), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12502] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4982), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15637), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2508), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12631] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4984), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2509), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12760] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4986), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2510), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [12889] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4988), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2511), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13018] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4990), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2512), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13147] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14602), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2513), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13276] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4992), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2514), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13405] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4994), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15637), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2515), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13534] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14668), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2516), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13663] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4996), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2517), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13792] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(4998), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2518), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [13921] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14646), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2519), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14050] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14834), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2520), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14179] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5000), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2521), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14308] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14640), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2522), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14437] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5002), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2523), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14566] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5004), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2524), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14695] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5006), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2525), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14824] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14765), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2526), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [14953] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14719), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2527), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15082] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14599), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2528), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15211] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14776), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2529), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15340] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5008), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2530), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15469] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14757), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2531), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15598] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5010), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2532), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15727] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14796), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2533), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15856] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5012), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2534), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [15985] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14754), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2535), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16114] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14663), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2536), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16243] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5014), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2537), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16372] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14841), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2538), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16501] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14621), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2539), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16630] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5016), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15637), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2540), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16759] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5018), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2541), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [16888] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14752), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2542), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17017] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14708), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2543), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17146] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5020), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2544), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17275] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5022), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2545), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17404] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14689), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2546), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17533] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14624), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2547), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17662] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5024), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2548), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17791] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5026), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2549), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [17920] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5028), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2550), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18049] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14641), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2551), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18178] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5030), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15637), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2552), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18307] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14607), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2553), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18436] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14755), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2554), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18565] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5032), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2555), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18694] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5034), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2556), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18823] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5036), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2557), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [18952] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14792), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2558), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19081] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5038), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2559), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19210] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14690), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2560), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19339] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14652), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2561), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19468] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5040), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2562), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19597] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14631), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2563), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19726] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14613), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2564), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19855] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5042), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2565), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [19984] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5044), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15637), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2566), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20113] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5046), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2567), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20242] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5048), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15637), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2568), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20371] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5050), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2569), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20500] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5052), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2570), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20629] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14628), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2571), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20758] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14730), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2572), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [20887] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14722), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2573), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21016] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14829), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2574), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21145] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5054), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2575), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21274] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5056), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2576), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21403] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14837), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2577), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21532] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5058), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2578), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21661] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5060), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2579), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21790] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5062), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2580), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [21919] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5064), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2581), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22048] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14807), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2582), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22177] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5066), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2583), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22306] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14651), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2584), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22435] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14846), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2585), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22564] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14773), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2586), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22693] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14669), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2587), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22822] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14825), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2588), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [22951] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5068), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2589), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23080] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14795), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2590), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23209] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5070), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2591), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23338] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
      anon_sym_yield,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [23411] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5072), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2593), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23540] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5074), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2594), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23669] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14666), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2595), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23798] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14817), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2596), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [23927] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5076), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2597), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24056] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5078), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2598), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24185] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5080), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2599), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24314] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14638), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2600), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24443] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14836), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2601), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24572] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5082), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2602), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24701] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14768), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2603), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24830] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14800), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2604), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [24959] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14806), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2605), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25088] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5084), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2606), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25217] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5086), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2607), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25346] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5088), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2608), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25475] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14814), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2609), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25604] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5090), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2610), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25733] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14830), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2611), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25862] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14678), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2612), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [25991] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5092), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2613), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26120] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14699), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2614), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26249] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5094), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15637), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2615), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26378] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14695), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2616), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26507] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5096), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2617), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26636] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5098), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2618), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26765] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14684), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2619), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [26894] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14694), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2620), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27023] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5100), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15637), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2621), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27152] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5102), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2622), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27281] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5104), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2623), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27410] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5106), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2624), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27539] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14775), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2625), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27668] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14811), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2626), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27797] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14718), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2627), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [27926] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14767), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2628), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28055] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5108), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2629), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28184] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5110), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2630), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28313] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14813), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2631), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28442] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14627), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2632), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28571] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5112), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2633), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28700] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4970), 1,
      anon_sym_RPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(14726), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2634), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15384), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28829] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5114), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2635), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [28958] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5116), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2636), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [29087] = 35,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(5118), 1,
      anon_sym_RPAREN,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15626), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2637), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [29216] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5124), 1,
      anon_sym_EQ_GT,
    ACTIONS(5126), 1,
      anon_sym_LBRACK,
    ACTIONS(5130), 1,
      anon_sym_LPAREN,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(7980), 1,
      sym__annotated_type,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12926), 1,
      sym__infix_type_choice,
    STATE(15092), 1,
      sym__type,
    STATE(16191), 1,
      sym_parameter_types,
    STATE(17050), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2638), 2,
      sym_comment,
      sym_block_comment,
    STATE(11247), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15533), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [29342] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15436), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2639), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16643), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [29468] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 11,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
      anon_sym_yield,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [29540] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5124), 1,
      anon_sym_EQ_GT,
    ACTIONS(5126), 1,
      anon_sym_LBRACK,
    ACTIONS(5130), 1,
      anon_sym_LPAREN,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(7980), 1,
      sym__annotated_type,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12926), 1,
      sym__infix_type_choice,
    STATE(14916), 1,
      sym__type,
    STATE(16191), 1,
      sym_parameter_types,
    STATE(17050), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2641), 2,
      sym_comment,
      sym_block_comment,
    STATE(11247), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15671), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [29666] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5124), 1,
      anon_sym_EQ_GT,
    ACTIONS(5126), 1,
      anon_sym_LBRACK,
    ACTIONS(5130), 1,
      anon_sym_LPAREN,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(7980), 1,
      sym__annotated_type,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12926), 1,
      sym__infix_type_choice,
    STATE(14907), 1,
      sym__type,
    STATE(16191), 1,
      sym_parameter_types,
    STATE(17050), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2642), 2,
      sym_comment,
      sym_block_comment,
    STATE(11247), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15676), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [29792] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15637), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2643), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16620), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [29918] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5124), 1,
      anon_sym_EQ_GT,
    ACTIONS(5126), 1,
      anon_sym_LBRACK,
    ACTIONS(5130), 1,
      anon_sym_LPAREN,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(7980), 1,
      sym__annotated_type,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12926), 1,
      sym__infix_type_choice,
    STATE(14898), 1,
      sym__type,
    STATE(16191), 1,
      sym_parameter_types,
    STATE(17050), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2644), 2,
      sym_comment,
      sym_block_comment,
    STATE(11247), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15682), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30044] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4368), 1,
      anon_sym_EQ_GT,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(15418), 1,
      sym__type,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2645), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16646), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30170] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5124), 1,
      anon_sym_EQ_GT,
    ACTIONS(5126), 1,
      anon_sym_LBRACK,
    ACTIONS(5130), 1,
      anon_sym_LPAREN,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(7980), 1,
      sym__annotated_type,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12926), 1,
      sym__infix_type_choice,
    STATE(14947), 1,
      sym__type,
    STATE(16191), 1,
      sym_parameter_types,
    STATE(17050), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2646), 2,
      sym_comment,
      sym_block_comment,
    STATE(11247), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15655), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30296] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 11,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_DQUOTE,
      anon_sym_yield,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [30368] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5124), 1,
      anon_sym_EQ_GT,
    ACTIONS(5126), 1,
      anon_sym_LBRACK,
    ACTIONS(5130), 1,
      anon_sym_LPAREN,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(7980), 1,
      sym__annotated_type,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12926), 1,
      sym__infix_type_choice,
    STATE(15026), 1,
      sym__type,
    STATE(16191), 1,
      sym_parameter_types,
    STATE(17050), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2648), 2,
      sym_comment,
      sym_block_comment,
    STATE(11247), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15649), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30494] = 34,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5124), 1,
      anon_sym_EQ_GT,
    ACTIONS(5126), 1,
      anon_sym_LBRACK,
    ACTIONS(5130), 1,
      anon_sym_LPAREN,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(7980), 1,
      sym__annotated_type,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12926), 1,
      sym__infix_type_choice,
    STATE(14974), 1,
      sym__type,
    STATE(16191), 1,
      sym_parameter_types,
    STATE(17050), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2649), 2,
      sym_comment,
      sym_block_comment,
    STATE(11247), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(15640), 2,
      sym_lazy_parameter_type,
      sym_repeated_parameter_type,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30620] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 11,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [30691] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16624), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    ACTIONS(5136), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(2651), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [30814] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 10,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      anon_sym_DQUOTE,
      anon_sym_yield,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [30885] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 11,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [30956] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 10,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_DQUOTE,
      anon_sym_yield,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [31027] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5140), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2655), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31149] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5142), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2656), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31271] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5144), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2657), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31393] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5146), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2658), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31515] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5148), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2659), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31637] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5150), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2660), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31759] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5152), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2661), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [31881] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5154), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2662), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32003] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5156), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2663), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32125] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5158), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2664), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32247] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5160), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2665), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32369] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5162), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2666), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32491] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5164), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2667), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32613] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5166), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2668), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32735] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5168), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2669), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32857] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5170), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2670), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [32979] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5172), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2671), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33101] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5174), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2672), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33223] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5176), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2673), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33345] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5178), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2674), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33467] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5180), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2675), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33589] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5182), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2676), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33711] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5184), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2677), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33833] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5186), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2678), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [33955] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5188), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2679), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34077] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5190), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2680), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34199] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5192), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2681), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34321] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5194), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2682), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34443] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5196), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2683), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34565] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5198), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2684), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34687] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5200), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2685), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34809] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5202), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2686), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [34931] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5204), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2687), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35053] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 10,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [35123] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5206), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2689), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35245] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5208), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2690), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35367] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5210), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2691), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35489] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5212), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2692), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35611] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5214), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2693), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35733] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5216), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2694), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35855] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5218), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2695), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [35977] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5220), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2696), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36099] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5222), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2697), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36221] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5224), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2698), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36343] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5226), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2699), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36465] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5228), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2700), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36587] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5230), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2701), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36709] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5232), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2702), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36831] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5234), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2703), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [36953] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5236), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2704), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37075] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5238), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2705), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37197] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5240), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2706), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37319] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5242), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2707), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37441] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5244), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2708), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37563] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5246), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2709), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37685] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5248), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2710), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37807] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5250), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2711), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [37929] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5252), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2712), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38051] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5254), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2713), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38173] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5256), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2714), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38295] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5258), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2715), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38417] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5260), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2716), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38539] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5262), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2717), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38661] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5264), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2718), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38783] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5266), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2719), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [38905] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5268), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2720), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39027] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5270), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2721), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39149] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5272), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2722), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39271] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5274), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2723), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39393] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5276), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2724), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39515] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5278), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2725), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39637] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5280), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2726), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39759] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5282), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2727), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [39881] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5284), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2728), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40003] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5286), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2729), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40125] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5288), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2730), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40247] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5290), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2731), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40369] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5292), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2732), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40491] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5294), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2733), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40613] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5296), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2734), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40735] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5298), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2735), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40857] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5300), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2736), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [40979] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5302), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2737), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41101] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5304), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2738), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41223] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5306), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2739), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41345] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5308), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2740), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41467] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5310), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2741), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41589] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5312), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2742), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41711] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5314), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2743), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41833] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5316), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2744), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [41955] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5318), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2745), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42077] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5320), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2746), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42199] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5322), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2747), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42321] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5324), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2748), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42443] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5326), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2749), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42565] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5328), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2750), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42687] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5330), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2751), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42809] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5332), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2752), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [42931] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5334), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2753), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43053] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5336), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2754), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43175] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5338), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2755), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43297] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5340), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2756), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43419] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5342), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2757), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43541] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5344), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2758), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43663] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5346), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2759), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43785] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5348), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2760), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [43907] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5350), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2761), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44029] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5352), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2762), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44151] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5354), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2763), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44273] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5356), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2764), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44395] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5358), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2765), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44517] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5360), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2766), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44639] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5362), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2767), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44761] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5364), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2768), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [44883] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5366), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2769), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45005] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 10,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [45075] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5368), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2771), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45197] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5370), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2772), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45319] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5372), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2773), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45441] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5374), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2774), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45563] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5376), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2775), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45685] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5378), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2776), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45807] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5380), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2777), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [45929] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5382), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2778), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46051] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5384), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2779), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46173] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5386), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2780), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46295] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5388), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2781), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46417] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5390), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2782), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46539] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5392), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2783), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46661] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5394), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2784), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46783] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5396), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2785), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [46905] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5398), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2786), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47027] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5400), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2787), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47149] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5402), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2788), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47271] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5404), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2789), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47393] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5406), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2790), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47515] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5408), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2791), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47637] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5410), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2792), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47759] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5412), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2793), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [47881] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5414), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2794), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48003] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5416), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2795), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48125] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5418), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2796), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48247] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5420), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2797), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48369] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5422), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2798), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48491] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5424), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2799), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48613] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5426), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2800), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48735] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5428), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2801), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48857] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5430), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2802), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [48979] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5432), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2803), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49101] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5434), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2804), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49223] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5436), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2805), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49345] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5438), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2806), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49467] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5440), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2807), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49589] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5442), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2808), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49711] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5444), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2809), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49833] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5446), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2810), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [49955] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5448), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2811), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50077] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5450), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2812), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50199] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5452), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2813), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50321] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5454), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2814), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50443] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5456), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2815), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50565] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5458), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2816), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50687] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5460), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2817), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50809] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5462), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2818), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [50931] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5464), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2819), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51053] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5466), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2820), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51175] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5468), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2821), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51297] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5470), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2822), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51419] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5472), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2823), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51541] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5474), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2824), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51663] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5476), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2825), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51785] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5478), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2826), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [51907] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5480), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2827), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52029] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5482), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2828), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52151] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5484), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2829), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52273] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5486), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2830), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52395] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5488), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2831), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52517] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5490), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2832), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52639] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5492), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2833), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52761] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5494), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2834), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [52883] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5496), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2835), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53005] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5498), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2836), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53127] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5500), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2837), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53249] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5502), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2838), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53371] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5504), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2839), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53493] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5506), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2840), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53615] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5508), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2841), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53737] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5510), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2842), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53859] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5512), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2843), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [53981] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5514), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2844), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54103] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5516), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2845), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54225] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5518), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2846), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54347] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5520), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2847), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54469] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5522), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2848), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54591] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5524), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2849), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54713] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5526), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2850), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54835] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5528), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2851), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [54957] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5530), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2852), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55079] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5532), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2853), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55201] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5534), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2854), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55323] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5536), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2855), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55445] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5538), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2856), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55567] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5540), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2857), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55689] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5542), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2858), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55811] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5544), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2859), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [55933] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5546), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2860), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56055] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5548), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2861), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56177] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5550), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2862), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56299] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5552), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2863), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56421] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5554), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2864), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56543] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5556), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2865), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56665] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5558), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2866), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56787] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5560), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2867), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [56909] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5562), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2868), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57031] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5564), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2869), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57153] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5566), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2870), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57275] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5568), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2871), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57397] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5570), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2872), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57519] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5572), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2873), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57641] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5574), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2874), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57763] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 10,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [57833] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5576), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2876), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [57955] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5578), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2877), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58077] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5580), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2878), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58199] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5582), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2879), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58321] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5584), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2880), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58443] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5586), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2881), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58565] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5588), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2882), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58687] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5590), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2883), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58809] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5592), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2884), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [58931] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5594), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2885), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59053] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5596), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2886), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59175] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5598), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2887), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59297] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5600), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2888), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59419] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5602), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2889), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59541] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5604), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2890), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59663] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5606), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2891), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59785] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5608), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2892), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [59907] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5610), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2893), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60029] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5612), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2894), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60151] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5614), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2895), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60273] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5616), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2896), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60395] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5618), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2897), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60517] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5620), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2898), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60639] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5622), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2899), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60761] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5624), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2900), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [60883] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5626), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2901), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61005] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5628), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2902), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61127] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5630), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2903), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61249] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(2904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 10,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [61319] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5632), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2905), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61441] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5634), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2906), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61563] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5636), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2907), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61685] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5638), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2908), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61807] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5640), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2909), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [61929] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5642), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2910), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62051] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5644), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2911), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62173] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5646), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2912), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62295] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5648), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2913), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62417] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5650), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2914), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62539] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5652), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2915), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62661] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5654), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2916), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62783] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5656), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2917), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [62905] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5658), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2918), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63027] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5660), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2919), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63149] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5662), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2920), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63271] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5664), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2921), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63393] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5666), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2922), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63515] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5668), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2923), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63637] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5670), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2924), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63759] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5672), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2925), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [63881] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5674), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2926), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64003] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5676), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2927), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64125] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5678), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2928), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64247] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5680), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2929), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64369] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5682), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2930), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64491] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5684), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2931), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64613] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5686), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2932), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64735] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5688), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2933), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64857] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5690), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2934), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [64979] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5692), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2935), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65101] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5694), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2936), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65223] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5696), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2937), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65345] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5698), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2938), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65467] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5700), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2939), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65589] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5702), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2940), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65711] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5704), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2941), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65833] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5706), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2942), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [65955] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5708), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2943), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66077] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5710), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2944), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66199] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5712), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2945), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66321] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5714), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2946), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66443] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5716), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2947), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66565] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5718), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2948), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66687] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5720), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2949), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66809] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5722), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2950), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [66931] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5724), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2951), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67053] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5726), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2952), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67175] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5728), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2953), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67297] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5730), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2954), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67419] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5732), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2955), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67541] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5734), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2956), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67663] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5736), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2957), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67785] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5738), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2958), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [67907] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5740), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2959), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68029] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5742), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2960), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68151] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5744), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2961), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68273] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5746), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2962), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68395] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5748), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2963), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68517] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5750), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2964), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68639] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5752), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2965), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68761] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5754), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2966), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [68883] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5756), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2967), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69005] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5758), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2968), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69127] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5760), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2969), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69249] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5762), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2970), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69371] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5764), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2971), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69493] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5766), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2972), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69615] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5768), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2973), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69737] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5770), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2974), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69859] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5772), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2975), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [69981] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5774), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2976), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70103] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5776), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2977), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70225] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5778), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2978), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70347] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5780), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2979), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70469] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5782), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2980), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70591] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5784), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2981), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70713] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5786), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2982), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70835] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5788), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2983), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [70957] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5790), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2984), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71079] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5792), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2985), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71201] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5794), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2986), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71323] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5796), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2987), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71445] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5798), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2988), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71567] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5800), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2989), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71689] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5802), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2990), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71811] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5804), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2991), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [71933] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5806), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2992), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72055] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5808), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2993), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72177] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5810), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2994), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72299] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5812), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2995), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72421] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5814), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2996), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72543] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5816), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2997), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72665] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5818), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2998), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72787] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5820), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(2999), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [72909] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5822), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3000), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73031] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5824), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3001), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73153] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5826), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3002), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73275] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5828), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3003), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73397] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5830), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3004), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73519] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5832), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3005), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73641] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5834), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3006), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73763] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5836), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3007), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [73885] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5838), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3008), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74007] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5840), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3009), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74129] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5842), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3010), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74251] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5844), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3011), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74373] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5846), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3012), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74495] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5848), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3013), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74617] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5850), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3014), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74739] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5852), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3015), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74861] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5854), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3016), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [74983] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5856), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3017), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75105] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5858), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3018), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75227] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5860), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3019), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75349] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5862), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3020), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75471] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5864), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3021), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75593] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5866), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3022), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75715] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5868), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3023), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75837] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5870), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3024), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [75959] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5872), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3025), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76081] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5874), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3026), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76203] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5876), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3027), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76325] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5878), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3028), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76447] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5880), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3029), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76569] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5882), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3030), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76691] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5884), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3031), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76813] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5886), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3032), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [76935] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5888), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3033), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77057] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5890), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3034), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77179] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5892), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3035), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77301] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5894), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3036), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77423] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5896), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3037), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77545] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5898), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3038), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77667] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5900), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3039), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77789] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5902), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3040), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [77911] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5904), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3041), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78033] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5906), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3042), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78155] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5908), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3043), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78277] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5910), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3044), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78399] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5912), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3045), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78521] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5914), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3046), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78643] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5916), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3047), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78765] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5918), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3048), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [78887] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5920), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3049), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79009] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5922), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3050), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79131] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5924), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3051), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79253] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5926), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3052), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79375] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5928), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3053), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79497] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5930), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3054), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79619] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5932), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3055), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79741] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5934), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3056), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79863] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5936), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3057), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [79985] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5938), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3058), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80107] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5940), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3059), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80229] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5942), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3060), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80351] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5944), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3061), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80473] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5946), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3062), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80595] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5948), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3063), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80717] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5950), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3064), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80839] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5952), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3065), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [80961] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5954), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3066), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81083] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5956), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3067), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81205] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5958), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3068), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81327] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5960), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3069), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81449] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5962), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3070), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81571] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5964), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3071), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81693] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5966), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3072), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81815] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5968), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3073), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [81937] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5970), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3074), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82059] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5972), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3075), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82181] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5974), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3076), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82303] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5976), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3077), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82425] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5978), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3078), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82547] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5980), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3079), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82669] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5982), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3080), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82791] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5984), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3081), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [82913] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5986), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3082), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83035] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5988), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3083), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83157] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5990), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3084), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83279] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5992), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3085), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83401] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5994), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3086), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83523] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5996), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3087), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83645] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(5998), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3088), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83767] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6000), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3089), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [83889] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6002), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3090), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84011] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6004), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3091), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84133] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6006), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3092), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84255] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6008), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3093), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84377] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6010), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3094), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84499] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6012), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3095), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84621] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6014), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3096), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84743] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6016), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3097), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84865] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6018), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3098), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [84987] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6020), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3099), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85109] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6022), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3100), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85231] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6024), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3101), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85353] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6026), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3102), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85475] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6028), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3103), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85597] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6030), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3104), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85719] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6032), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3105), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85841] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6034), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3106), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [85963] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6036), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3107), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86085] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6038), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3108), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86207] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6040), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3109), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86329] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6042), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3110), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86451] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6044), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3111), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86573] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6046), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3112), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86695] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6048), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3113), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86817] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6050), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3114), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [86939] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6052), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3115), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87061] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6054), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3116), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87183] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6056), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3117), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87305] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6058), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3118), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87427] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6060), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3119), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87549] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6062), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3120), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87671] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6064), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3121), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87793] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6066), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3122), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [87915] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6068), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3123), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88037] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6070), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3124), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88159] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6072), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3125), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88281] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6074), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3126), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88403] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6076), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3127), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88525] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6078), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3128), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88647] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6080), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3129), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88769] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6082), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3130), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [88891] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6084), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3131), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89013] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6086), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3132), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89135] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6088), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3133), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89257] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6090), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3134), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89379] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6092), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3135), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89501] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6094), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3136), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89623] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6096), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3137), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89745] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6098), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3138), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89867] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6100), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3139), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [89989] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6102), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3140), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90111] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6104), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3141), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90233] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6106), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3142), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90355] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6108), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3143), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90477] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6110), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3144), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90599] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6112), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3145), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90721] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6114), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3146), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90843] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6116), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3147), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [90965] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6118), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3148), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91087] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6120), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3149), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91209] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6122), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3150), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91331] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6124), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3151), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91453] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6126), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3152), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91575] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6128), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3153), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91697] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6130), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3154), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91819] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6132), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3155), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [91941] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6134), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3156), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92063] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6136), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3157), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92185] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6138), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3158), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92307] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6140), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3159), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92429] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6142), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3160), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92551] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6144), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3161), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92673] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6146), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3162), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92795] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6148), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3163), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [92917] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6150), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3164), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93039] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6152), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3165), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93161] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6154), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3166), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93283] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6156), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3167), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93405] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6158), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3168), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93527] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6160), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3169), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93649] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6162), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3170), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93771] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6164), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3171), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [93893] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6166), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3172), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94015] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6168), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3173), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94137] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6170), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3174), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94259] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6172), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3175), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94381] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6174), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3176), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94503] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6176), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3177), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94625] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6178), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3178), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94747] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6180), 1,
      anon_sym_RPAREN,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3179), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94869] = 33,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6182), 1,
      anon_sym_RBRACK,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3180), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [94991] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15202), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3181), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95110] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16194), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3182), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95229] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(17709), 1,
      sym__type,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3183), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95348] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15775), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3184), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95467] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4422), 1,
      sym__alpha_identifier,
    ACTIONS(4424), 1,
      anon_sym_COLON,
    ACTIONS(4426), 1,
      anon_sym_LBRACE,
    ACTIONS(4428), 1,
      anon_sym__,
    ACTIONS(4432), 1,
      anon_sym_LBRACK,
    ACTIONS(4440), 1,
      sym__backquoted_id,
    ACTIONS(4444), 1,
      sym_integer_literal,
    ACTIONS(6198), 1,
      anon_sym_LPAREN,
    ACTIONS(6200), 1,
      sym_operator_identifier,
    STATE(5648), 1,
      sym__simple_type,
    STATE(5924), 1,
      sym__annotated_type,
    STATE(6343), 1,
      sym_identifier,
    STATE(6399), 1,
      sym__soft_identifier,
    STATE(9039), 1,
      sym_annotated_type,
    STATE(11750), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12603), 1,
      sym__infix_type_choice,
    STATE(15199), 1,
      sym_parameter_types,
    STATE(17810), 1,
      sym_stable_identifier,
    ACTIONS(4446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4452), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3185), 2,
      sym_comment,
      sym_block_comment,
    STATE(10474), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11978), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4434), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7419), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95586] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4422), 1,
      sym__alpha_identifier,
    ACTIONS(4424), 1,
      anon_sym_COLON,
    ACTIONS(4426), 1,
      anon_sym_LBRACE,
    ACTIONS(4428), 1,
      anon_sym__,
    ACTIONS(4432), 1,
      anon_sym_LBRACK,
    ACTIONS(4440), 1,
      sym__backquoted_id,
    ACTIONS(4444), 1,
      sym_integer_literal,
    ACTIONS(6198), 1,
      anon_sym_LPAREN,
    ACTIONS(6200), 1,
      sym_operator_identifier,
    STATE(5648), 1,
      sym__simple_type,
    STATE(5924), 1,
      sym__annotated_type,
    STATE(6343), 1,
      sym_identifier,
    STATE(6399), 1,
      sym__soft_identifier,
    STATE(9039), 1,
      sym_annotated_type,
    STATE(11752), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12603), 1,
      sym__infix_type_choice,
    STATE(15199), 1,
      sym_parameter_types,
    STATE(17810), 1,
      sym_stable_identifier,
    ACTIONS(4446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4452), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3186), 2,
      sym_comment,
      sym_block_comment,
    STATE(10474), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11978), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4434), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7419), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95705] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15892), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3187), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95824] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15899), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3188), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [95943] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15876), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3189), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96062] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15747), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3190), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96181] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4422), 1,
      sym__alpha_identifier,
    ACTIONS(4424), 1,
      anon_sym_COLON,
    ACTIONS(4426), 1,
      anon_sym_LBRACE,
    ACTIONS(4428), 1,
      anon_sym__,
    ACTIONS(4432), 1,
      anon_sym_LBRACK,
    ACTIONS(4440), 1,
      sym__backquoted_id,
    ACTIONS(4444), 1,
      sym_integer_literal,
    ACTIONS(6198), 1,
      anon_sym_LPAREN,
    ACTIONS(6200), 1,
      sym_operator_identifier,
    STATE(5648), 1,
      sym__simple_type,
    STATE(5924), 1,
      sym__annotated_type,
    STATE(6343), 1,
      sym_identifier,
    STATE(6399), 1,
      sym__soft_identifier,
    STATE(9039), 1,
      sym_annotated_type,
    STATE(11755), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12603), 1,
      sym__infix_type_choice,
    STATE(15199), 1,
      sym_parameter_types,
    STATE(17810), 1,
      sym_stable_identifier,
    ACTIONS(4446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4452), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3191), 2,
      sym_comment,
      sym_block_comment,
    STATE(10474), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11978), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4434), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7419), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96300] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15872), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3192), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96419] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6202), 1,
      sym__alpha_identifier,
    ACTIONS(6204), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(6208), 1,
      anon_sym__,
    ACTIONS(6210), 1,
      anon_sym_LBRACK,
    ACTIONS(6214), 1,
      anon_sym_LPAREN,
    ACTIONS(6216), 1,
      sym__backquoted_id,
    ACTIONS(6218), 1,
      sym_operator_identifier,
    ACTIONS(6220), 1,
      sym_integer_literal,
    STATE(8726), 1,
      sym__simple_type,
    STATE(9220), 1,
      sym__annotated_type,
    STATE(9360), 1,
      sym_identifier,
    STATE(9455), 1,
      sym__soft_identifier,
    STATE(11142), 1,
      sym_annotated_type,
    STATE(12580), 1,
      sym__infix_type_choice,
    STATE(15262), 1,
      sym_parameter_types,
    STATE(16579), 1,
      sym_template_body,
    STATE(16590), 1,
      sym__non_null_literal,
    STATE(16598), 1,
      sym__type,
    STATE(17822), 1,
      sym_stable_identifier,
    ACTIONS(6222), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6224), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6226), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3193), 2,
      sym_comment,
      sym_block_comment,
    STATE(11894), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11933), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16578), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16593), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6212), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9589), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96538] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(17707), 1,
      sym__type,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3194), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96657] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16071), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3195), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96776] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11611), 1,
      sym__type,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3196), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [96895] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [96964] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17722), 1,
      sym__type,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3198), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97083] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4392), 1,
      anon_sym_COLON,
    ACTIONS(4394), 1,
      anon_sym_LBRACE,
    ACTIONS(4412), 1,
      sym_integer_literal,
    ACTIONS(4750), 1,
      sym__alpha_identifier,
    ACTIONS(4752), 1,
      anon_sym__,
    ACTIONS(4756), 1,
      anon_sym_LBRACK,
    ACTIONS(4762), 1,
      sym__backquoted_id,
    ACTIONS(6246), 1,
      anon_sym_LPAREN,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    STATE(4572), 1,
      sym__annotated_type,
    STATE(4614), 1,
      sym__simple_type,
    STATE(4635), 1,
      sym__soft_identifier,
    STATE(4732), 1,
      sym_identifier,
    STATE(6307), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12310), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12751), 1,
      sym__infix_type_choice,
    STATE(15970), 1,
      sym_parameter_types,
    STATE(17642), 1,
      sym_stable_identifier,
    ACTIONS(4414), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4416), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3199), 2,
      sym_comment,
      sym_block_comment,
    STATE(8596), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12316), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12382), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4758), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4869), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97202] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4392), 1,
      anon_sym_COLON,
    ACTIONS(4394), 1,
      anon_sym_LBRACE,
    ACTIONS(4412), 1,
      sym_integer_literal,
    ACTIONS(4750), 1,
      sym__alpha_identifier,
    ACTIONS(4752), 1,
      anon_sym__,
    ACTIONS(4756), 1,
      anon_sym_LBRACK,
    ACTIONS(4762), 1,
      sym__backquoted_id,
    ACTIONS(6246), 1,
      anon_sym_LPAREN,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    STATE(4572), 1,
      sym__annotated_type,
    STATE(4614), 1,
      sym__simple_type,
    STATE(4635), 1,
      sym__soft_identifier,
    STATE(4732), 1,
      sym_identifier,
    STATE(6307), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12314), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12751), 1,
      sym__infix_type_choice,
    STATE(15970), 1,
      sym_parameter_types,
    STATE(17642), 1,
      sym_stable_identifier,
    ACTIONS(4414), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4416), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3200), 2,
      sym_comment,
      sym_block_comment,
    STATE(8596), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12316), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12382), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4758), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4869), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97321] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4594), 1,
      sym__alpha_identifier,
    ACTIONS(4596), 1,
      anon_sym_COLON,
    ACTIONS(4598), 1,
      anon_sym_LBRACE,
    ACTIONS(4600), 1,
      anon_sym__,
    ACTIONS(4604), 1,
      anon_sym_LBRACK,
    ACTIONS(4612), 1,
      sym__backquoted_id,
    ACTIONS(4616), 1,
      sym_integer_literal,
    ACTIONS(6250), 1,
      anon_sym_LPAREN,
    ACTIONS(6252), 1,
      sym_operator_identifier,
    STATE(5023), 1,
      sym__annotated_type,
    STATE(5090), 1,
      sym__simple_type,
    STATE(5125), 1,
      sym_identifier,
    STATE(5264), 1,
      sym__soft_identifier,
    STATE(7582), 1,
      sym_annotated_type,
    STATE(12573), 1,
      sym__infix_type_choice,
    STATE(13483), 1,
      sym__type,
    STATE(13562), 1,
      sym__non_null_literal,
    STATE(13691), 1,
      sym_template_body,
    STATE(16287), 1,
      sym_parameter_types,
    STATE(17492), 1,
      sym_stable_identifier,
    ACTIONS(4618), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4620), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4622), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3201), 2,
      sym_comment,
      sym_block_comment,
    STATE(9982), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13453), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13524), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13531), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5951), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97440] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4392), 1,
      anon_sym_COLON,
    ACTIONS(4394), 1,
      anon_sym_LBRACE,
    ACTIONS(4412), 1,
      sym_integer_literal,
    ACTIONS(4750), 1,
      sym__alpha_identifier,
    ACTIONS(4752), 1,
      anon_sym__,
    ACTIONS(4756), 1,
      anon_sym_LBRACK,
    ACTIONS(4762), 1,
      sym__backquoted_id,
    ACTIONS(6246), 1,
      anon_sym_LPAREN,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    STATE(4572), 1,
      sym__annotated_type,
    STATE(4614), 1,
      sym__simple_type,
    STATE(4635), 1,
      sym__soft_identifier,
    STATE(4732), 1,
      sym_identifier,
    STATE(6307), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12315), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12751), 1,
      sym__infix_type_choice,
    STATE(15970), 1,
      sym_parameter_types,
    STATE(17642), 1,
      sym_stable_identifier,
    ACTIONS(4414), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4416), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3202), 2,
      sym_comment,
      sym_block_comment,
    STATE(8596), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12316), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12382), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4758), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4869), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97559] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6258), 1,
      anon_sym_LBRACK,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(8011), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11699), 1,
      sym__type,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(16153), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3203), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97678] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4594), 1,
      sym__alpha_identifier,
    ACTIONS(4596), 1,
      anon_sym_COLON,
    ACTIONS(4598), 1,
      anon_sym_LBRACE,
    ACTIONS(4600), 1,
      anon_sym__,
    ACTIONS(4604), 1,
      anon_sym_LBRACK,
    ACTIONS(4612), 1,
      sym__backquoted_id,
    ACTIONS(4616), 1,
      sym_integer_literal,
    ACTIONS(6250), 1,
      anon_sym_LPAREN,
    ACTIONS(6252), 1,
      sym_operator_identifier,
    STATE(5023), 1,
      sym__annotated_type,
    STATE(5090), 1,
      sym__simple_type,
    STATE(5125), 1,
      sym_identifier,
    STATE(5264), 1,
      sym__soft_identifier,
    STATE(7582), 1,
      sym_annotated_type,
    STATE(12573), 1,
      sym__infix_type_choice,
    STATE(13485), 1,
      sym__type,
    STATE(13562), 1,
      sym__non_null_literal,
    STATE(13691), 1,
      sym_template_body,
    STATE(16287), 1,
      sym_parameter_types,
    STATE(17492), 1,
      sym_stable_identifier,
    ACTIONS(4618), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4620), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4622), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3204), 2,
      sym_comment,
      sym_block_comment,
    STATE(9982), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13453), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13524), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13531), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5951), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97797] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4392), 1,
      anon_sym_COLON,
    ACTIONS(4394), 1,
      anon_sym_LBRACE,
    ACTIONS(4412), 1,
      sym_integer_literal,
    ACTIONS(4750), 1,
      sym__alpha_identifier,
    ACTIONS(4752), 1,
      anon_sym__,
    ACTIONS(4756), 1,
      anon_sym_LBRACK,
    ACTIONS(4762), 1,
      sym__backquoted_id,
    ACTIONS(6246), 1,
      anon_sym_LPAREN,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    STATE(4572), 1,
      sym__annotated_type,
    STATE(4614), 1,
      sym__simple_type,
    STATE(4635), 1,
      sym__soft_identifier,
    STATE(4732), 1,
      sym_identifier,
    STATE(6307), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12325), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12751), 1,
      sym__infix_type_choice,
    STATE(15970), 1,
      sym_parameter_types,
    STATE(17642), 1,
      sym_stable_identifier,
    ACTIONS(4414), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4416), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3205), 2,
      sym_comment,
      sym_block_comment,
    STATE(8596), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12316), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12382), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4758), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4869), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [97916] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4594), 1,
      sym__alpha_identifier,
    ACTIONS(4596), 1,
      anon_sym_COLON,
    ACTIONS(4598), 1,
      anon_sym_LBRACE,
    ACTIONS(4600), 1,
      anon_sym__,
    ACTIONS(4604), 1,
      anon_sym_LBRACK,
    ACTIONS(4612), 1,
      sym__backquoted_id,
    ACTIONS(4616), 1,
      sym_integer_literal,
    ACTIONS(6250), 1,
      anon_sym_LPAREN,
    ACTIONS(6252), 1,
      sym_operator_identifier,
    STATE(5023), 1,
      sym__annotated_type,
    STATE(5090), 1,
      sym__simple_type,
    STATE(5125), 1,
      sym_identifier,
    STATE(5264), 1,
      sym__soft_identifier,
    STATE(7582), 1,
      sym_annotated_type,
    STATE(12573), 1,
      sym__infix_type_choice,
    STATE(13490), 1,
      sym__type,
    STATE(13562), 1,
      sym__non_null_literal,
    STATE(13691), 1,
      sym_template_body,
    STATE(16287), 1,
      sym_parameter_types,
    STATE(17492), 1,
      sym_stable_identifier,
    ACTIONS(4618), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4620), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4622), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3206), 2,
      sym_comment,
      sym_block_comment,
    STATE(9982), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13453), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13524), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13531), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5951), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98035] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1250), 1,
      sym_integer_literal,
    ACTIONS(6268), 1,
      sym__alpha_identifier,
    ACTIONS(6270), 1,
      anon_sym_COLON,
    ACTIONS(6272), 1,
      anon_sym_LBRACE,
    ACTIONS(6274), 1,
      anon_sym__,
    ACTIONS(6276), 1,
      anon_sym_LBRACK,
    ACTIONS(6280), 1,
      anon_sym_LPAREN,
    ACTIONS(6282), 1,
      sym__backquoted_id,
    ACTIONS(6284), 1,
      sym_operator_identifier,
    STATE(5253), 1,
      sym__annotated_type,
    STATE(5337), 1,
      sym__simple_type,
    STATE(5695), 1,
      sym_identifier,
    STATE(5862), 1,
      sym__soft_identifier,
    STATE(8317), 1,
      sym_annotated_type,
    STATE(12917), 1,
      sym__infix_type_choice,
    STATE(13562), 1,
      sym__non_null_literal,
    STATE(13691), 1,
      sym_template_body,
    STATE(13722), 1,
      sym__type,
    STATE(15968), 1,
      sym_parameter_types,
    STATE(17690), 1,
      sym_stable_identifier,
    ACTIONS(1252), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1254), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1258), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3207), 2,
      sym_comment,
      sym_block_comment,
    STATE(8352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8833), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10259), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13531), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6278), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6225), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98154] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6286), 1,
      sym__alpha_identifier,
    ACTIONS(6288), 1,
      anon_sym__,
    ACTIONS(6290), 1,
      anon_sym_LBRACK,
    ACTIONS(6294), 1,
      anon_sym_LPAREN,
    ACTIONS(6296), 1,
      sym__backquoted_id,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    STATE(6470), 1,
      sym__simple_type,
    STATE(6838), 1,
      sym__soft_identifier,
    STATE(7088), 1,
      sym__annotated_type,
    STATE(7402), 1,
      sym_identifier,
    STATE(10239), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11611), 1,
      sym__type,
    STATE(12575), 1,
      sym__infix_type_choice,
    STATE(16104), 1,
      sym_parameter_types,
    STATE(16771), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3208), 2,
      sym_comment,
      sym_block_comment,
    STATE(10977), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6292), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7941), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98273] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6286), 1,
      sym__alpha_identifier,
    ACTIONS(6288), 1,
      anon_sym__,
    ACTIONS(6290), 1,
      anon_sym_LBRACK,
    ACTIONS(6294), 1,
      anon_sym_LPAREN,
    ACTIONS(6296), 1,
      sym__backquoted_id,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    STATE(6470), 1,
      sym__simple_type,
    STATE(6838), 1,
      sym__soft_identifier,
    STATE(7088), 1,
      sym__annotated_type,
    STATE(7402), 1,
      sym_identifier,
    STATE(10239), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11613), 1,
      sym__type,
    STATE(12575), 1,
      sym__infix_type_choice,
    STATE(16104), 1,
      sym_parameter_types,
    STATE(16771), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3209), 2,
      sym_comment,
      sym_block_comment,
    STATE(10977), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6292), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7941), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98392] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6286), 1,
      sym__alpha_identifier,
    ACTIONS(6288), 1,
      anon_sym__,
    ACTIONS(6290), 1,
      anon_sym_LBRACK,
    ACTIONS(6294), 1,
      anon_sym_LPAREN,
    ACTIONS(6296), 1,
      sym__backquoted_id,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    STATE(6470), 1,
      sym__simple_type,
    STATE(6838), 1,
      sym__soft_identifier,
    STATE(7088), 1,
      sym__annotated_type,
    STATE(7402), 1,
      sym_identifier,
    STATE(10239), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11623), 1,
      sym__type,
    STATE(12575), 1,
      sym__infix_type_choice,
    STATE(16104), 1,
      sym_parameter_types,
    STATE(16771), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3210), 2,
      sym_comment,
      sym_block_comment,
    STATE(10977), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6292), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7941), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98511] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6286), 1,
      sym__alpha_identifier,
    ACTIONS(6288), 1,
      anon_sym__,
    ACTIONS(6290), 1,
      anon_sym_LBRACK,
    ACTIONS(6294), 1,
      anon_sym_LPAREN,
    ACTIONS(6296), 1,
      sym__backquoted_id,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    STATE(6470), 1,
      sym__simple_type,
    STATE(6838), 1,
      sym__soft_identifier,
    STATE(7088), 1,
      sym__annotated_type,
    STATE(7402), 1,
      sym_identifier,
    STATE(10239), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11637), 1,
      sym__type,
    STATE(12575), 1,
      sym__infix_type_choice,
    STATE(16104), 1,
      sym_parameter_types,
    STATE(16771), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3211), 2,
      sym_comment,
      sym_block_comment,
    STATE(10977), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6292), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7941), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98630] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16059), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3212), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98749] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16339), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3213), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98868] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    STATE(7533), 1,
      sym__simple_type,
    STATE(8692), 1,
      sym_identifier,
    STATE(8750), 1,
      sym__annotated_type,
    STATE(8795), 1,
      sym__soft_identifier,
    STATE(10744), 1,
      sym_annotated_type,
    STATE(11762), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12927), 1,
      sym__infix_type_choice,
    STATE(16105), 1,
      sym_parameter_types,
    STATE(17006), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3214), 2,
      sym_comment,
      sym_block_comment,
    STATE(11242), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [98987] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15919), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3215), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99106] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15823), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3216), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99225] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4422), 1,
      sym__alpha_identifier,
    ACTIONS(4424), 1,
      anon_sym_COLON,
    ACTIONS(4426), 1,
      anon_sym_LBRACE,
    ACTIONS(4428), 1,
      anon_sym__,
    ACTIONS(4432), 1,
      anon_sym_LBRACK,
    ACTIONS(4440), 1,
      sym__backquoted_id,
    ACTIONS(4444), 1,
      sym_integer_literal,
    ACTIONS(6198), 1,
      anon_sym_LPAREN,
    ACTIONS(6200), 1,
      sym_operator_identifier,
    STATE(5648), 1,
      sym__simple_type,
    STATE(5924), 1,
      sym__annotated_type,
    STATE(6343), 1,
      sym_identifier,
    STATE(6399), 1,
      sym__soft_identifier,
    STATE(9039), 1,
      sym_annotated_type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11833), 1,
      sym__type,
    STATE(11834), 1,
      sym_template_body,
    STATE(12603), 1,
      sym__infix_type_choice,
    STATE(15199), 1,
      sym_parameter_types,
    STATE(17810), 1,
      sym_stable_identifier,
    ACTIONS(4446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4452), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3217), 2,
      sym_comment,
      sym_block_comment,
    STATE(10474), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11978), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4434), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7419), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99344] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4182), 1,
      sym__alpha_identifier,
    ACTIONS(4184), 1,
      anon_sym_COLON,
    ACTIONS(4186), 1,
      anon_sym_LBRACE,
    ACTIONS(4188), 1,
      anon_sym__,
    ACTIONS(4192), 1,
      anon_sym_LBRACK,
    ACTIONS(4200), 1,
      sym__backquoted_id,
    ACTIONS(4204), 1,
      sym_integer_literal,
    ACTIONS(6314), 1,
      anon_sym_LPAREN,
    ACTIONS(6316), 1,
      sym_operator_identifier,
    STATE(4560), 1,
      sym__simple_type,
    STATE(4566), 1,
      sym__annotated_type,
    STATE(4657), 1,
      sym__soft_identifier,
    STATE(4661), 1,
      sym_identifier,
    STATE(6338), 1,
      sym_annotated_type,
    STATE(12645), 1,
      sym_template_body,
    STATE(12704), 1,
      sym__non_null_literal,
    STATE(12779), 1,
      sym__infix_type_choice,
    STATE(12817), 1,
      sym__type,
    STATE(15998), 1,
      sym_parameter_types,
    STATE(17648), 1,
      sym_stable_identifier,
    ACTIONS(4206), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4208), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4212), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3218), 2,
      sym_comment,
      sym_block_comment,
    STATE(8704), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12525), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12788), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12703), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4194), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4885), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99463] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4182), 1,
      sym__alpha_identifier,
    ACTIONS(4184), 1,
      anon_sym_COLON,
    ACTIONS(4186), 1,
      anon_sym_LBRACE,
    ACTIONS(4188), 1,
      anon_sym__,
    ACTIONS(4192), 1,
      anon_sym_LBRACK,
    ACTIONS(4200), 1,
      sym__backquoted_id,
    ACTIONS(4204), 1,
      sym_integer_literal,
    ACTIONS(6314), 1,
      anon_sym_LPAREN,
    ACTIONS(6316), 1,
      sym_operator_identifier,
    STATE(4560), 1,
      sym__simple_type,
    STATE(4566), 1,
      sym__annotated_type,
    STATE(4657), 1,
      sym__soft_identifier,
    STATE(4661), 1,
      sym_identifier,
    STATE(6338), 1,
      sym_annotated_type,
    STATE(12645), 1,
      sym_template_body,
    STATE(12704), 1,
      sym__non_null_literal,
    STATE(12779), 1,
      sym__infix_type_choice,
    STATE(12832), 1,
      sym__type,
    STATE(15998), 1,
      sym_parameter_types,
    STATE(17648), 1,
      sym_stable_identifier,
    ACTIONS(4206), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4208), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4212), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3219), 2,
      sym_comment,
      sym_block_comment,
    STATE(8704), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12525), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12788), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12703), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4194), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4885), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99582] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6258), 1,
      anon_sym_LBRACK,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(8011), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11637), 1,
      sym__type,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(16153), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3220), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99701] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4182), 1,
      sym__alpha_identifier,
    ACTIONS(4184), 1,
      anon_sym_COLON,
    ACTIONS(4186), 1,
      anon_sym_LBRACE,
    ACTIONS(4188), 1,
      anon_sym__,
    ACTIONS(4192), 1,
      anon_sym_LBRACK,
    ACTIONS(4200), 1,
      sym__backquoted_id,
    ACTIONS(4204), 1,
      sym_integer_literal,
    ACTIONS(6314), 1,
      anon_sym_LPAREN,
    ACTIONS(6316), 1,
      sym_operator_identifier,
    STATE(4560), 1,
      sym__simple_type,
    STATE(4566), 1,
      sym__annotated_type,
    STATE(4657), 1,
      sym__soft_identifier,
    STATE(4661), 1,
      sym_identifier,
    STATE(6338), 1,
      sym_annotated_type,
    STATE(12645), 1,
      sym_template_body,
    STATE(12704), 1,
      sym__non_null_literal,
    STATE(12779), 1,
      sym__infix_type_choice,
    STATE(12833), 1,
      sym__type,
    STATE(15998), 1,
      sym_parameter_types,
    STATE(17648), 1,
      sym_stable_identifier,
    ACTIONS(4206), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4208), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4212), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3221), 2,
      sym_comment,
      sym_block_comment,
    STATE(8704), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12525), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12788), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12703), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4194), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4885), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99820] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15862), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3222), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [99939] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15860), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3223), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100058] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6258), 1,
      anon_sym_LBRACK,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(8011), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11623), 1,
      sym__type,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(16153), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3224), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100177] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13401), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3225), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100296] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6258), 1,
      anon_sym_LBRACK,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(8011), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11613), 1,
      sym__type,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(16153), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3226), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100415] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4594), 1,
      sym__alpha_identifier,
    ACTIONS(4596), 1,
      anon_sym_COLON,
    ACTIONS(4598), 1,
      anon_sym_LBRACE,
    ACTIONS(4600), 1,
      anon_sym__,
    ACTIONS(4604), 1,
      anon_sym_LBRACK,
    ACTIONS(4612), 1,
      sym__backquoted_id,
    ACTIONS(4616), 1,
      sym_integer_literal,
    ACTIONS(6250), 1,
      anon_sym_LPAREN,
    ACTIONS(6252), 1,
      sym_operator_identifier,
    STATE(5023), 1,
      sym__annotated_type,
    STATE(5090), 1,
      sym__simple_type,
    STATE(5125), 1,
      sym_identifier,
    STATE(5264), 1,
      sym__soft_identifier,
    STATE(7582), 1,
      sym_annotated_type,
    STATE(12573), 1,
      sym__infix_type_choice,
    STATE(13496), 1,
      sym__type,
    STATE(13562), 1,
      sym__non_null_literal,
    STATE(13691), 1,
      sym_template_body,
    STATE(16287), 1,
      sym_parameter_types,
    STATE(17492), 1,
      sym_stable_identifier,
    ACTIONS(4618), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4620), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4622), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3227), 2,
      sym_comment,
      sym_block_comment,
    STATE(9982), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13453), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13524), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13531), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5951), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100534] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6286), 1,
      sym__alpha_identifier,
    ACTIONS(6288), 1,
      anon_sym__,
    ACTIONS(6290), 1,
      anon_sym_LBRACK,
    ACTIONS(6294), 1,
      anon_sym_LPAREN,
    ACTIONS(6296), 1,
      sym__backquoted_id,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    STATE(6470), 1,
      sym__simple_type,
    STATE(6838), 1,
      sym__soft_identifier,
    STATE(7088), 1,
      sym__annotated_type,
    STATE(7402), 1,
      sym_identifier,
    STATE(10239), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11699), 1,
      sym__type,
    STATE(12575), 1,
      sym__infix_type_choice,
    STATE(16104), 1,
      sym_parameter_types,
    STATE(16771), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3228), 2,
      sym_comment,
      sym_block_comment,
    STATE(10977), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6292), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7941), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100653] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6258), 1,
      anon_sym_LBRACK,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(8011), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11611), 1,
      sym__type,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(16153), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3229), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100772] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15706), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3230), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [100891] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1306), 1,
      sym_integer_literal,
    ACTIONS(6336), 1,
      sym__alpha_identifier,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(6342), 1,
      anon_sym__,
    ACTIONS(6344), 1,
      anon_sym_LBRACK,
    ACTIONS(6348), 1,
      anon_sym_LPAREN,
    ACTIONS(6350), 1,
      sym__backquoted_id,
    ACTIONS(6352), 1,
      sym_operator_identifier,
    STATE(5944), 1,
      sym__simple_type,
    STATE(5985), 1,
      sym__annotated_type,
    STATE(6347), 1,
      sym__soft_identifier,
    STATE(6696), 1,
      sym_identifier,
    STATE(9248), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11901), 1,
      sym__type,
    STATE(12891), 1,
      sym__infix_type_choice,
    STATE(16056), 1,
      sym_parameter_types,
    STATE(17708), 1,
      sym_stable_identifier,
    ACTIONS(1308), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1310), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1314), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3231), 2,
      sym_comment,
      sym_block_comment,
    STATE(5184), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10495), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6346), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7084), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101010] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17287), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3232), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101129] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4182), 1,
      sym__alpha_identifier,
    ACTIONS(4184), 1,
      anon_sym_COLON,
    ACTIONS(4186), 1,
      anon_sym_LBRACE,
    ACTIONS(4188), 1,
      anon_sym__,
    ACTIONS(4192), 1,
      anon_sym_LBRACK,
    ACTIONS(4200), 1,
      sym__backquoted_id,
    ACTIONS(4204), 1,
      sym_integer_literal,
    ACTIONS(6314), 1,
      anon_sym_LPAREN,
    ACTIONS(6316), 1,
      sym_operator_identifier,
    STATE(4560), 1,
      sym__simple_type,
    STATE(4566), 1,
      sym__annotated_type,
    STATE(4657), 1,
      sym__soft_identifier,
    STATE(4661), 1,
      sym_identifier,
    STATE(6338), 1,
      sym_annotated_type,
    STATE(12645), 1,
      sym_template_body,
    STATE(12704), 1,
      sym__non_null_literal,
    STATE(12779), 1,
      sym__infix_type_choice,
    STATE(12839), 1,
      sym__type,
    STATE(15998), 1,
      sym_parameter_types,
    STATE(17648), 1,
      sym_stable_identifier,
    ACTIONS(4206), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4208), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4212), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3233), 2,
      sym_comment,
      sym_block_comment,
    STATE(8704), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12525), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12788), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12703), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4194), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4885), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101248] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17724), 1,
      sym__type,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3234), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101367] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15851), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3235), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101486] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15847), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3236), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101605] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    ACTIONS(6354), 1,
      anon_sym_LBRACK,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(7900), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12593), 1,
      sym__infix_type_choice,
    STATE(14470), 1,
      sym__type,
    STATE(16051), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3237), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101724] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15483), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3238), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101843] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11613), 1,
      sym__type,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3239), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [101962] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15923), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3240), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102081] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4424), 1,
      anon_sym_COLON,
    ACTIONS(4426), 1,
      anon_sym_LBRACE,
    ACTIONS(4444), 1,
      sym_integer_literal,
    ACTIONS(4692), 1,
      sym__alpha_identifier,
    ACTIONS(4694), 1,
      anon_sym__,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    ACTIONS(4704), 1,
      sym__backquoted_id,
    ACTIONS(6356), 1,
      anon_sym_LPAREN,
    ACTIONS(6358), 1,
      sym_operator_identifier,
    STATE(4470), 1,
      sym__simple_type,
    STATE(4509), 1,
      sym__annotated_type,
    STATE(4547), 1,
      sym__soft_identifier,
    STATE(4621), 1,
      sym_identifier,
    STATE(5917), 1,
      sym_annotated_type,
    STATE(11755), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12585), 1,
      sym__infix_type_choice,
    STATE(15976), 1,
      sym_parameter_types,
    STATE(17816), 1,
      sym_stable_identifier,
    ACTIONS(4446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4452), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3241), 2,
      sym_comment,
      sym_block_comment,
    STATE(7772), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11978), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4739), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102200] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1538), 1,
      sym_integer_literal,
    ACTIONS(6360), 1,
      sym__alpha_identifier,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(6366), 1,
      anon_sym__,
    ACTIONS(6368), 1,
      anon_sym_LBRACK,
    ACTIONS(6372), 1,
      anon_sym_LPAREN,
    ACTIONS(6374), 1,
      sym__backquoted_id,
    ACTIONS(6376), 1,
      sym_operator_identifier,
    STATE(4549), 1,
      sym__simple_type,
    STATE(4564), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym_identifier,
    STATE(4788), 1,
      sym__soft_identifier,
    STATE(6732), 1,
      sym_annotated_type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12369), 1,
      sym__type,
    STATE(12476), 1,
      sym__infix_type_choice,
    STATE(16111), 1,
      sym_parameter_types,
    STATE(17876), 1,
      sym_stable_identifier,
    ACTIONS(1540), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1542), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1546), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3242), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5996), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8705), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4936), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102319] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16816), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3243), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102438] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15838), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3244), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102557] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15836), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3245), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102676] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4424), 1,
      anon_sym_COLON,
    ACTIONS(4426), 1,
      anon_sym_LBRACE,
    ACTIONS(4444), 1,
      sym_integer_literal,
    ACTIONS(4692), 1,
      sym__alpha_identifier,
    ACTIONS(4694), 1,
      anon_sym__,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    ACTIONS(4704), 1,
      sym__backquoted_id,
    ACTIONS(6356), 1,
      anon_sym_LPAREN,
    ACTIONS(6358), 1,
      sym_operator_identifier,
    STATE(4470), 1,
      sym__simple_type,
    STATE(4509), 1,
      sym__annotated_type,
    STATE(4547), 1,
      sym__soft_identifier,
    STATE(4621), 1,
      sym_identifier,
    STATE(5917), 1,
      sym_annotated_type,
    STATE(11752), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12585), 1,
      sym__infix_type_choice,
    STATE(15976), 1,
      sym_parameter_types,
    STATE(17816), 1,
      sym_stable_identifier,
    ACTIONS(4446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4452), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3246), 2,
      sym_comment,
      sym_block_comment,
    STATE(7772), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11978), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4739), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102795] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4424), 1,
      anon_sym_COLON,
    ACTIONS(4426), 1,
      anon_sym_LBRACE,
    ACTIONS(4444), 1,
      sym_integer_literal,
    ACTIONS(4692), 1,
      sym__alpha_identifier,
    ACTIONS(4694), 1,
      anon_sym__,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    ACTIONS(4704), 1,
      sym__backquoted_id,
    ACTIONS(6356), 1,
      anon_sym_LPAREN,
    ACTIONS(6358), 1,
      sym_operator_identifier,
    STATE(4470), 1,
      sym__simple_type,
    STATE(4509), 1,
      sym__annotated_type,
    STATE(4547), 1,
      sym__soft_identifier,
    STATE(4621), 1,
      sym_identifier,
    STATE(5917), 1,
      sym_annotated_type,
    STATE(11750), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12585), 1,
      sym__infix_type_choice,
    STATE(15976), 1,
      sym_parameter_types,
    STATE(17816), 1,
      sym_stable_identifier,
    ACTIONS(4446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4452), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3247), 2,
      sym_comment,
      sym_block_comment,
    STATE(7772), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11978), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4739), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [102914] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    STATE(7533), 1,
      sym__simple_type,
    STATE(8692), 1,
      sym_identifier,
    STATE(8750), 1,
      sym__annotated_type,
    STATE(8795), 1,
      sym__soft_identifier,
    STATE(10744), 1,
      sym_annotated_type,
    STATE(11760), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12927), 1,
      sym__infix_type_choice,
    STATE(16105), 1,
      sym_parameter_types,
    STATE(17006), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3248), 2,
      sym_comment,
      sym_block_comment,
    STATE(11242), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103033] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4424), 1,
      anon_sym_COLON,
    ACTIONS(4426), 1,
      anon_sym_LBRACE,
    ACTIONS(4444), 1,
      sym_integer_literal,
    ACTIONS(4692), 1,
      sym__alpha_identifier,
    ACTIONS(4694), 1,
      anon_sym__,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    ACTIONS(4704), 1,
      sym__backquoted_id,
    ACTIONS(6356), 1,
      anon_sym_LPAREN,
    ACTIONS(6358), 1,
      sym_operator_identifier,
    STATE(4470), 1,
      sym__simple_type,
    STATE(4509), 1,
      sym__annotated_type,
    STATE(4547), 1,
      sym__soft_identifier,
    STATE(4621), 1,
      sym_identifier,
    STATE(5917), 1,
      sym_annotated_type,
    STATE(11749), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12585), 1,
      sym__infix_type_choice,
    STATE(15976), 1,
      sym_parameter_types,
    STATE(17816), 1,
      sym_stable_identifier,
    ACTIONS(4446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4452), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3249), 2,
      sym_comment,
      sym_block_comment,
    STATE(7772), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11978), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4739), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103152] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    STATE(7533), 1,
      sym__simple_type,
    STATE(8692), 1,
      sym_identifier,
    STATE(8750), 1,
      sym__annotated_type,
    STATE(8795), 1,
      sym__soft_identifier,
    STATE(10744), 1,
      sym_annotated_type,
    STATE(11757), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12927), 1,
      sym__infix_type_choice,
    STATE(16105), 1,
      sym_parameter_types,
    STATE(17006), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3250), 2,
      sym_comment,
      sym_block_comment,
    STATE(11242), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103271] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    STATE(7533), 1,
      sym__simple_type,
    STATE(8692), 1,
      sym_identifier,
    STATE(8750), 1,
      sym__annotated_type,
    STATE(8795), 1,
      sym__soft_identifier,
    STATE(10744), 1,
      sym_annotated_type,
    STATE(11754), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12927), 1,
      sym__infix_type_choice,
    STATE(16105), 1,
      sym_parameter_types,
    STATE(17006), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3251), 2,
      sym_comment,
      sym_block_comment,
    STATE(11242), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103390] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16066), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3252), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103509] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4422), 1,
      sym__alpha_identifier,
    ACTIONS(4424), 1,
      anon_sym_COLON,
    ACTIONS(4426), 1,
      anon_sym_LBRACE,
    ACTIONS(4428), 1,
      anon_sym__,
    ACTIONS(4432), 1,
      anon_sym_LBRACK,
    ACTIONS(4440), 1,
      sym__backquoted_id,
    ACTIONS(4444), 1,
      sym_integer_literal,
    ACTIONS(6198), 1,
      anon_sym_LPAREN,
    ACTIONS(6200), 1,
      sym_operator_identifier,
    STATE(5648), 1,
      sym__simple_type,
    STATE(5924), 1,
      sym__annotated_type,
    STATE(6343), 1,
      sym_identifier,
    STATE(6399), 1,
      sym__soft_identifier,
    STATE(9039), 1,
      sym_annotated_type,
    STATE(11749), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12603), 1,
      sym__infix_type_choice,
    STATE(15199), 1,
      sym_parameter_types,
    STATE(17810), 1,
      sym_stable_identifier,
    ACTIONS(4446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4452), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3253), 2,
      sym_comment,
      sym_block_comment,
    STATE(10474), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11978), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4434), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7419), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103628] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(8865), 1,
      sym__type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3254), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103747] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    STATE(7533), 1,
      sym__simple_type,
    STATE(8692), 1,
      sym_identifier,
    STATE(8750), 1,
      sym__annotated_type,
    STATE(8795), 1,
      sym__soft_identifier,
    STATE(10744), 1,
      sym_annotated_type,
    STATE(11746), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12927), 1,
      sym__infix_type_choice,
    STATE(16105), 1,
      sym_parameter_types,
    STATE(17006), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3255), 2,
      sym_comment,
      sym_block_comment,
    STATE(11242), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103866] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1190), 1,
      sym_integer_literal,
    ACTIONS(6378), 1,
      sym__alpha_identifier,
    ACTIONS(6380), 1,
      anon_sym_COLON,
    ACTIONS(6382), 1,
      anon_sym_LBRACE,
    ACTIONS(6384), 1,
      anon_sym__,
    ACTIONS(6386), 1,
      anon_sym_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_LPAREN,
    ACTIONS(6392), 1,
      sym__backquoted_id,
    ACTIONS(6394), 1,
      sym_operator_identifier,
    STATE(4833), 1,
      sym__annotated_type,
    STATE(5085), 1,
      sym__simple_type,
    STATE(5211), 1,
      sym__soft_identifier,
    STATE(5401), 1,
      sym_identifier,
    STATE(7726), 1,
      sym_annotated_type,
    STATE(12474), 1,
      sym__infix_type_choice,
    STATE(13245), 1,
      sym_template_body,
    STATE(13295), 1,
      sym__non_null_literal,
    STATE(13420), 1,
      sym__type,
    STATE(15977), 1,
      sym_parameter_types,
    STATE(17882), 1,
      sym_stable_identifier,
    ACTIONS(1192), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1194), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1198), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3256), 2,
      sym_comment,
      sym_block_comment,
    STATE(7888), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8149), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9700), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13299), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5762), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [103985] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15821), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3257), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104104] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15817), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3258), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104223] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4774), 1,
      sym__alpha_identifier,
    ACTIONS(4776), 1,
      anon_sym_COLON,
    ACTIONS(4778), 1,
      anon_sym_LBRACE,
    ACTIONS(4780), 1,
      anon_sym__,
    ACTIONS(4784), 1,
      anon_sym_LBRACK,
    ACTIONS(4792), 1,
      sym__backquoted_id,
    ACTIONS(4796), 1,
      sym_integer_literal,
    ACTIONS(6396), 1,
      anon_sym_LPAREN,
    ACTIONS(6398), 1,
      sym_operator_identifier,
    STATE(5356), 1,
      sym__annotated_type,
    STATE(5471), 1,
      sym__simple_type,
    STATE(5800), 1,
      sym__soft_identifier,
    STATE(5818), 1,
      sym_identifier,
    STATE(8839), 1,
      sym_annotated_type,
    STATE(12611), 1,
      sym__infix_type_choice,
    STATE(13736), 1,
      sym__type,
    STATE(13874), 1,
      sym__non_null_literal,
    STATE(13912), 1,
      sym_template_body,
    STATE(15526), 1,
      sym_parameter_types,
    STATE(17804), 1,
      sym_stable_identifier,
    ACTIONS(4798), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4800), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4802), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3259), 2,
      sym_comment,
      sym_block_comment,
    STATE(10348), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13757), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13936), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13869), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4786), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6677), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104342] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6400), 1,
      anon_sym_LBRACK,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(9474), 1,
      sym__annotated_type,
    STATE(11746), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12902), 1,
      sym__infix_type_choice,
    STATE(16052), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3260), 2,
      sym_comment,
      sym_block_comment,
    STATE(11454), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104461] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4392), 1,
      anon_sym_COLON,
    ACTIONS(4394), 1,
      anon_sym_LBRACE,
    ACTIONS(4412), 1,
      sym_integer_literal,
    ACTIONS(4750), 1,
      sym__alpha_identifier,
    ACTIONS(4752), 1,
      anon_sym__,
    ACTIONS(4756), 1,
      anon_sym_LBRACK,
    ACTIONS(4762), 1,
      sym__backquoted_id,
    ACTIONS(6246), 1,
      anon_sym_LPAREN,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    STATE(4572), 1,
      sym__annotated_type,
    STATE(4614), 1,
      sym__simple_type,
    STATE(4635), 1,
      sym__soft_identifier,
    STATE(4732), 1,
      sym_identifier,
    STATE(6307), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12349), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12751), 1,
      sym__infix_type_choice,
    STATE(15970), 1,
      sym_parameter_types,
    STATE(17642), 1,
      sym_stable_identifier,
    ACTIONS(4414), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4416), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3261), 2,
      sym_comment,
      sym_block_comment,
    STATE(8596), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12316), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12382), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4758), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4869), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104580] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6400), 1,
      anon_sym_LBRACK,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(9474), 1,
      sym__annotated_type,
    STATE(11754), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12902), 1,
      sym__infix_type_choice,
    STATE(16052), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3262), 2,
      sym_comment,
      sym_block_comment,
    STATE(11454), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104699] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16096), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3263), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104818] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6400), 1,
      anon_sym_LBRACK,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(9474), 1,
      sym__annotated_type,
    STATE(11757), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12902), 1,
      sym__infix_type_choice,
    STATE(16052), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3264), 2,
      sym_comment,
      sym_block_comment,
    STATE(11454), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [104937] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6400), 1,
      anon_sym_LBRACK,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(9474), 1,
      sym__annotated_type,
    STATE(11760), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12902), 1,
      sym__infix_type_choice,
    STATE(16052), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3265), 2,
      sym_comment,
      sym_block_comment,
    STATE(11454), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105056] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13405), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3266), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105175] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15943), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3267), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105294] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15618), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3268), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105413] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17680), 1,
      sym__type,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3269), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105532] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17677), 1,
      sym__type,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3270), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105651] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16102), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3271), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105770] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1594), 1,
      sym_integer_literal,
    ACTIONS(6402), 1,
      sym__alpha_identifier,
    ACTIONS(6404), 1,
      anon_sym_COLON,
    ACTIONS(6406), 1,
      anon_sym_LBRACE,
    ACTIONS(6408), 1,
      anon_sym__,
    ACTIONS(6410), 1,
      anon_sym_LBRACK,
    ACTIONS(6414), 1,
      anon_sym_LPAREN,
    ACTIONS(6416), 1,
      sym__backquoted_id,
    ACTIONS(6418), 1,
      sym_operator_identifier,
    STATE(5198), 1,
      sym__annotated_type,
    STATE(5296), 1,
      sym__simple_type,
    STATE(5859), 1,
      sym_identifier,
    STATE(5895), 1,
      sym__soft_identifier,
    STATE(8665), 1,
      sym_annotated_type,
    STATE(12841), 1,
      sym__infix_type_choice,
    STATE(13626), 1,
      sym_template_body,
    STATE(13664), 1,
      sym__non_null_literal,
    STATE(13762), 1,
      sym__type,
    STATE(15967), 1,
      sym_parameter_types,
    STATE(17654), 1,
      sym_stable_identifier,
    ACTIONS(1596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1602), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3272), 2,
      sym_comment,
      sym_block_comment,
    STATE(8446), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8569), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10079), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13674), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6775), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [105889] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    ACTIONS(6354), 1,
      anon_sym_LBRACK,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(7900), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11611), 1,
      sym__type,
    STATE(12593), 1,
      sym__infix_type_choice,
    STATE(16051), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3273), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106008] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    ACTIONS(6354), 1,
      anon_sym_LBRACK,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(7900), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11613), 1,
      sym__type,
    STATE(12593), 1,
      sym__infix_type_choice,
    STATE(16051), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3274), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106127] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15947), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3275), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106246] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16362), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3276), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106365] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    ACTIONS(6354), 1,
      anon_sym_LBRACK,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(7900), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11623), 1,
      sym__type,
    STATE(12593), 1,
      sym__infix_type_choice,
    STATE(16051), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3277), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106484] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    ACTIONS(6354), 1,
      anon_sym_LBRACK,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(7900), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11637), 1,
      sym__type,
    STATE(12593), 1,
      sym__infix_type_choice,
    STATE(16051), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3278), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106603] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15879), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3279), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106722] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4594), 1,
      sym__alpha_identifier,
    ACTIONS(4596), 1,
      anon_sym_COLON,
    ACTIONS(4598), 1,
      anon_sym_LBRACE,
    ACTIONS(4600), 1,
      anon_sym__,
    ACTIONS(4604), 1,
      anon_sym_LBRACK,
    ACTIONS(4612), 1,
      sym__backquoted_id,
    ACTIONS(4616), 1,
      sym_integer_literal,
    ACTIONS(6250), 1,
      anon_sym_LPAREN,
    ACTIONS(6252), 1,
      sym_operator_identifier,
    STATE(5023), 1,
      sym__annotated_type,
    STATE(5090), 1,
      sym__simple_type,
    STATE(5125), 1,
      sym_identifier,
    STATE(5264), 1,
      sym__soft_identifier,
    STATE(7582), 1,
      sym_annotated_type,
    STATE(12573), 1,
      sym__infix_type_choice,
    STATE(13509), 1,
      sym__type,
    STATE(13562), 1,
      sym__non_null_literal,
    STATE(13691), 1,
      sym_template_body,
    STATE(16287), 1,
      sym_parameter_types,
    STATE(17492), 1,
      sym_stable_identifier,
    ACTIONS(4618), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4620), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4622), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3280), 2,
      sym_comment,
      sym_block_comment,
    STATE(9982), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13453), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13524), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13531), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5951), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106841] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17289), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3281), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [106960] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16333), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3282), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107079] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6400), 1,
      anon_sym_LBRACK,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(9474), 1,
      sym__annotated_type,
    STATE(11762), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12902), 1,
      sym__infix_type_choice,
    STATE(16052), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3283), 2,
      sym_comment,
      sym_block_comment,
    STATE(11454), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107198] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1840), 1,
      sym_integer_literal,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6428), 1,
      anon_sym_LBRACK,
    ACTIONS(6432), 1,
      anon_sym_LPAREN,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    STATE(4728), 1,
      sym__annotated_type,
    STATE(4796), 1,
      sym__simple_type,
    STATE(4977), 1,
      sym_identifier,
    STATE(5072), 1,
      sym__soft_identifier,
    STATE(7069), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12343), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12702), 1,
      sym__infix_type_choice,
    STATE(16108), 1,
      sym_parameter_types,
    STATE(17635), 1,
      sym_stable_identifier,
    ACTIONS(1842), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1844), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1848), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3284), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6406), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9368), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5463), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107317] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11623), 1,
      sym__type,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3285), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107436] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1840), 1,
      sym_integer_literal,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6428), 1,
      anon_sym_LBRACK,
    ACTIONS(6432), 1,
      anon_sym_LPAREN,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    STATE(4728), 1,
      sym__annotated_type,
    STATE(4796), 1,
      sym__simple_type,
    STATE(4977), 1,
      sym_identifier,
    STATE(5072), 1,
      sym__soft_identifier,
    STATE(7069), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12345), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12702), 1,
      sym__infix_type_choice,
    STATE(16108), 1,
      sym_parameter_types,
    STATE(17635), 1,
      sym_stable_identifier,
    ACTIONS(1842), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1844), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1848), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3286), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6406), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9368), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5463), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107555] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15901), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3287), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107674] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15801), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3288), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107793] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15797), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3289), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [107912] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6456), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8051), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11708), 1,
      sym__type,
    STATE(11736), 1,
      sym__non_null_literal,
    STATE(11748), 1,
      sym_template_body,
    STATE(12496), 1,
      sym__infix_type_choice,
    STATE(16167), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3290), 2,
      sym_comment,
      sym_block_comment,
    STATE(11058), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11804), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11740), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108031] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15298), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3291), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108150] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8482), 1,
      sym__type,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3292), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108269] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1840), 1,
      sym_integer_literal,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6428), 1,
      anon_sym_LBRACK,
    ACTIONS(6432), 1,
      anon_sym_LPAREN,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    STATE(4728), 1,
      sym__annotated_type,
    STATE(4796), 1,
      sym__simple_type,
    STATE(4977), 1,
      sym_identifier,
    STATE(5072), 1,
      sym__soft_identifier,
    STATE(7069), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12347), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12702), 1,
      sym__infix_type_choice,
    STATE(16108), 1,
      sym_parameter_types,
    STATE(17635), 1,
      sym_stable_identifier,
    ACTIONS(1842), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1844), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1848), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3293), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6406), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9368), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5463), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108388] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15952), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3294), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108507] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15983), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3295), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108626] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15402), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3296), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108745] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4424), 1,
      anon_sym_COLON,
    ACTIONS(4426), 1,
      anon_sym_LBRACE,
    ACTIONS(4444), 1,
      sym_integer_literal,
    ACTIONS(4692), 1,
      sym__alpha_identifier,
    ACTIONS(4694), 1,
      anon_sym__,
    ACTIONS(4698), 1,
      anon_sym_LBRACK,
    ACTIONS(4704), 1,
      sym__backquoted_id,
    ACTIONS(6356), 1,
      anon_sym_LPAREN,
    ACTIONS(6358), 1,
      sym_operator_identifier,
    STATE(4470), 1,
      sym__simple_type,
    STATE(4509), 1,
      sym__annotated_type,
    STATE(4547), 1,
      sym__soft_identifier,
    STATE(4621), 1,
      sym_identifier,
    STATE(5917), 1,
      sym_annotated_type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11833), 1,
      sym__type,
    STATE(11834), 1,
      sym_template_body,
    STATE(12585), 1,
      sym__infix_type_choice,
    STATE(15976), 1,
      sym_parameter_types,
    STATE(17816), 1,
      sym_stable_identifier,
    ACTIONS(4446), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4448), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4452), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3297), 2,
      sym_comment,
      sym_block_comment,
    STATE(7772), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11978), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4739), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108864] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17242), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3298), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [108983] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16751), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3299), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109102] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4774), 1,
      sym__alpha_identifier,
    ACTIONS(4776), 1,
      anon_sym_COLON,
    ACTIONS(4778), 1,
      anon_sym_LBRACE,
    ACTIONS(4780), 1,
      anon_sym__,
    ACTIONS(4784), 1,
      anon_sym_LBRACK,
    ACTIONS(4792), 1,
      sym__backquoted_id,
    ACTIONS(4796), 1,
      sym_integer_literal,
    ACTIONS(6396), 1,
      anon_sym_LPAREN,
    ACTIONS(6398), 1,
      sym_operator_identifier,
    STATE(5356), 1,
      sym__annotated_type,
    STATE(5471), 1,
      sym__simple_type,
    STATE(5800), 1,
      sym__soft_identifier,
    STATE(5818), 1,
      sym_identifier,
    STATE(8839), 1,
      sym_annotated_type,
    STATE(12611), 1,
      sym__infix_type_choice,
    STATE(13798), 1,
      sym__type,
    STATE(13874), 1,
      sym__non_null_literal,
    STATE(13912), 1,
      sym_template_body,
    STATE(15526), 1,
      sym_parameter_types,
    STATE(17804), 1,
      sym_stable_identifier,
    ACTIONS(4798), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4800), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4802), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3300), 2,
      sym_comment,
      sym_block_comment,
    STATE(10348), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13757), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13936), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13869), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4786), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6677), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109221] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4774), 1,
      sym__alpha_identifier,
    ACTIONS(4776), 1,
      anon_sym_COLON,
    ACTIONS(4778), 1,
      anon_sym_LBRACE,
    ACTIONS(4780), 1,
      anon_sym__,
    ACTIONS(4784), 1,
      anon_sym_LBRACK,
    ACTIONS(4792), 1,
      sym__backquoted_id,
    ACTIONS(4796), 1,
      sym_integer_literal,
    ACTIONS(6396), 1,
      anon_sym_LPAREN,
    ACTIONS(6398), 1,
      sym_operator_identifier,
    STATE(5356), 1,
      sym__annotated_type,
    STATE(5471), 1,
      sym__simple_type,
    STATE(5800), 1,
      sym__soft_identifier,
    STATE(5818), 1,
      sym_identifier,
    STATE(8839), 1,
      sym_annotated_type,
    STATE(12611), 1,
      sym__infix_type_choice,
    STATE(13799), 1,
      sym__type,
    STATE(13874), 1,
      sym__non_null_literal,
    STATE(13912), 1,
      sym_template_body,
    STATE(15526), 1,
      sym_parameter_types,
    STATE(17804), 1,
      sym_stable_identifier,
    ACTIONS(4798), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4800), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4802), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3301), 2,
      sym_comment,
      sym_block_comment,
    STATE(10348), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13757), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13936), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13869), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4786), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6677), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109340] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4774), 1,
      sym__alpha_identifier,
    ACTIONS(4776), 1,
      anon_sym_COLON,
    ACTIONS(4778), 1,
      anon_sym_LBRACE,
    ACTIONS(4780), 1,
      anon_sym__,
    ACTIONS(4784), 1,
      anon_sym_LBRACK,
    ACTIONS(4792), 1,
      sym__backquoted_id,
    ACTIONS(4796), 1,
      sym_integer_literal,
    ACTIONS(6396), 1,
      anon_sym_LPAREN,
    ACTIONS(6398), 1,
      sym_operator_identifier,
    STATE(5356), 1,
      sym__annotated_type,
    STATE(5471), 1,
      sym__simple_type,
    STATE(5800), 1,
      sym__soft_identifier,
    STATE(5818), 1,
      sym_identifier,
    STATE(8839), 1,
      sym_annotated_type,
    STATE(12611), 1,
      sym__infix_type_choice,
    STATE(13807), 1,
      sym__type,
    STATE(13874), 1,
      sym__non_null_literal,
    STATE(13912), 1,
      sym_template_body,
    STATE(15526), 1,
      sym_parameter_types,
    STATE(17804), 1,
      sym_stable_identifier,
    ACTIONS(4798), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4800), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4802), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3302), 2,
      sym_comment,
      sym_block_comment,
    STATE(10348), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13757), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13936), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13869), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4786), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6677), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109459] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17240), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3303), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109578] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    ACTIONS(6354), 1,
      anon_sym_LBRACK,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(7900), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11699), 1,
      sym__type,
    STATE(12593), 1,
      sym__infix_type_choice,
    STATE(16051), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3304), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109697] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12286), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3305), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109816] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15360), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3306), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [109935] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15985), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3307), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110054] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6456), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8051), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11704), 1,
      sym__type,
    STATE(11736), 1,
      sym__non_null_literal,
    STATE(11748), 1,
      sym_template_body,
    STATE(12496), 1,
      sym__infix_type_choice,
    STATE(16167), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3308), 2,
      sym_comment,
      sym_block_comment,
    STATE(11058), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11804), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11740), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110173] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6456), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8051), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11706), 1,
      sym__type,
    STATE(11736), 1,
      sym__non_null_literal,
    STATE(11748), 1,
      sym_template_body,
    STATE(12496), 1,
      sym__infix_type_choice,
    STATE(16167), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3309), 2,
      sym_comment,
      sym_block_comment,
    STATE(11058), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11804), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11740), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110292] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6456), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8051), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11707), 1,
      sym__type,
    STATE(11736), 1,
      sym__non_null_literal,
    STATE(11748), 1,
      sym_template_body,
    STATE(12496), 1,
      sym__infix_type_choice,
    STATE(16167), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3310), 2,
      sym_comment,
      sym_block_comment,
    STATE(11058), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11804), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11740), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110411] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4182), 1,
      sym__alpha_identifier,
    ACTIONS(4184), 1,
      anon_sym_COLON,
    ACTIONS(4186), 1,
      anon_sym_LBRACE,
    ACTIONS(4188), 1,
      anon_sym__,
    ACTIONS(4192), 1,
      anon_sym_LBRACK,
    ACTIONS(4200), 1,
      sym__backquoted_id,
    ACTIONS(4204), 1,
      sym_integer_literal,
    ACTIONS(6314), 1,
      anon_sym_LPAREN,
    ACTIONS(6316), 1,
      sym_operator_identifier,
    STATE(4560), 1,
      sym__simple_type,
    STATE(4566), 1,
      sym__annotated_type,
    STATE(4657), 1,
      sym__soft_identifier,
    STATE(4661), 1,
      sym_identifier,
    STATE(6338), 1,
      sym_annotated_type,
    STATE(12645), 1,
      sym_template_body,
    STATE(12704), 1,
      sym__non_null_literal,
    STATE(12779), 1,
      sym__infix_type_choice,
    STATE(12807), 1,
      sym__type,
    STATE(15998), 1,
      sym_parameter_types,
    STATE(17648), 1,
      sym_stable_identifier,
    ACTIONS(4206), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4208), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4212), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3311), 2,
      sym_comment,
      sym_block_comment,
    STATE(8704), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12525), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12788), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12703), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4194), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4885), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110530] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13400), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3312), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110649] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6456), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8051), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11712), 1,
      sym__type,
    STATE(11736), 1,
      sym__non_null_literal,
    STATE(11748), 1,
      sym_template_body,
    STATE(12496), 1,
      sym__infix_type_choice,
    STATE(16167), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3313), 2,
      sym_comment,
      sym_block_comment,
    STATE(11058), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11804), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11740), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110768] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15781), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3314), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [110887] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15776), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3315), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111006] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6494), 1,
      anon_sym_LBRACK,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7175), 1,
      sym__annotated_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12512), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13388), 1,
      sym__type,
    STATE(16155), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3316), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111125] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16368), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3317), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111244] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2106), 1,
      sym_integer_literal,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(6510), 1,
      anon_sym__,
    ACTIONS(6512), 1,
      anon_sym_LBRACK,
    ACTIONS(6516), 1,
      anon_sym_LPAREN,
    ACTIONS(6518), 1,
      sym__backquoted_id,
    ACTIONS(6520), 1,
      sym_operator_identifier,
    STATE(7064), 1,
      sym__simple_type,
    STATE(7487), 1,
      sym__annotated_type,
    STATE(7863), 1,
      sym__soft_identifier,
    STATE(8147), 1,
      sym_identifier,
    STATE(10066), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12834), 1,
      sym__infix_type_choice,
    STATE(12921), 1,
      sym__type,
    STATE(16057), 1,
      sym_parameter_types,
    STATE(17720), 1,
      sym_stable_identifier,
    ACTIONS(2108), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2110), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2114), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3318), 2,
      sym_comment,
      sym_block_comment,
    STATE(6362), 2,
      sym_boolean_literal,
      sym_string,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11043), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6514), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111363] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    ACTIONS(6522), 1,
      anon_sym_LBRACK,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7325), 1,
      sym__annotated_type,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12504), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13405), 1,
      sym__type,
    STATE(16054), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3319), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111482] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(15154), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3320), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111601] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13388), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3321), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111720] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1840), 1,
      sym_integer_literal,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6428), 1,
      anon_sym_LBRACK,
    ACTIONS(6432), 1,
      anon_sym_LPAREN,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    STATE(4728), 1,
      sym__annotated_type,
    STATE(4796), 1,
      sym__simple_type,
    STATE(4977), 1,
      sym_identifier,
    STATE(5072), 1,
      sym__soft_identifier,
    STATE(7069), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12367), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12702), 1,
      sym__infix_type_choice,
    STATE(16108), 1,
      sym_parameter_types,
    STATE(17635), 1,
      sym_stable_identifier,
    ACTIONS(1842), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1844), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1848), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3322), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6406), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9368), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5463), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111839] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4530), 1,
      sym__alpha_identifier,
    ACTIONS(4532), 1,
      anon_sym_COLON,
    ACTIONS(4534), 1,
      anon_sym_LBRACE,
    ACTIONS(4536), 1,
      anon_sym__,
    ACTIONS(4540), 1,
      anon_sym_LBRACK,
    ACTIONS(4548), 1,
      sym__backquoted_id,
    ACTIONS(4552), 1,
      sym_integer_literal,
    ACTIONS(6524), 1,
      anon_sym_LPAREN,
    ACTIONS(6526), 1,
      sym_operator_identifier,
    STATE(5220), 1,
      sym__annotated_type,
    STATE(5311), 1,
      sym__simple_type,
    STATE(5882), 1,
      sym__soft_identifier,
    STATE(5987), 1,
      sym_identifier,
    STATE(8575), 1,
      sym_annotated_type,
    STATE(12867), 1,
      sym__infix_type_choice,
    STATE(13747), 1,
      sym__type,
    STATE(13856), 1,
      sym_template_body,
    STATE(13862), 1,
      sym__non_null_literal,
    STATE(15903), 1,
      sym_parameter_types,
    STATE(17666), 1,
      sym_stable_identifier,
    ACTIONS(4554), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4556), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4560), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3323), 2,
      sym_comment,
      sym_block_comment,
    STATE(10142), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13890), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13946), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13863), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4542), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6618), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [111958] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [112027] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15758), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3325), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112146] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16136), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3326), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112265] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15749), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3327), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112384] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13382), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3328), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112503] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6528), 1,
      sym__alpha_identifier,
    ACTIONS(6530), 1,
      anon_sym__,
    ACTIONS(6532), 1,
      anon_sym_LBRACK,
    ACTIONS(6536), 1,
      anon_sym_LPAREN,
    ACTIONS(6538), 1,
      sym__backquoted_id,
    ACTIONS(6540), 1,
      sym_operator_identifier,
    STATE(7390), 1,
      sym__simple_type,
    STATE(7836), 1,
      sym__annotated_type,
    STATE(7921), 1,
      sym_identifier,
    STATE(7952), 1,
      sym__soft_identifier,
    STATE(10528), 1,
      sym_annotated_type,
    STATE(11762), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12942), 1,
      sym__infix_type_choice,
    STATE(16154), 1,
      sym_parameter_types,
    STATE(17028), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3329), 2,
      sym_comment,
      sym_block_comment,
    STATE(11027), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6534), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8432), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112622] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6202), 1,
      sym__alpha_identifier,
    ACTIONS(6204), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(6208), 1,
      anon_sym__,
    ACTIONS(6210), 1,
      anon_sym_LBRACK,
    ACTIONS(6214), 1,
      anon_sym_LPAREN,
    ACTIONS(6216), 1,
      sym__backquoted_id,
    ACTIONS(6218), 1,
      sym_operator_identifier,
    ACTIONS(6220), 1,
      sym_integer_literal,
    STATE(8726), 1,
      sym__simple_type,
    STATE(9220), 1,
      sym__annotated_type,
    STATE(9360), 1,
      sym_identifier,
    STATE(9455), 1,
      sym__soft_identifier,
    STATE(11142), 1,
      sym_annotated_type,
    STATE(12580), 1,
      sym__infix_type_choice,
    STATE(15262), 1,
      sym_parameter_types,
    STATE(16579), 1,
      sym_template_body,
    STATE(16587), 1,
      sym__type,
    STATE(16590), 1,
      sym__non_null_literal,
    STATE(17822), 1,
      sym_stable_identifier,
    ACTIONS(6222), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6224), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6226), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3330), 2,
      sym_comment,
      sym_block_comment,
    STATE(11894), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11933), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16578), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16593), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6212), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9589), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112741] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16079), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3331), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112860] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6202), 1,
      sym__alpha_identifier,
    ACTIONS(6204), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(6208), 1,
      anon_sym__,
    ACTIONS(6210), 1,
      anon_sym_LBRACK,
    ACTIONS(6214), 1,
      anon_sym_LPAREN,
    ACTIONS(6216), 1,
      sym__backquoted_id,
    ACTIONS(6218), 1,
      sym_operator_identifier,
    ACTIONS(6220), 1,
      sym_integer_literal,
    STATE(8726), 1,
      sym__simple_type,
    STATE(9220), 1,
      sym__annotated_type,
    STATE(9360), 1,
      sym_identifier,
    STATE(9455), 1,
      sym__soft_identifier,
    STATE(11142), 1,
      sym_annotated_type,
    STATE(12580), 1,
      sym__infix_type_choice,
    STATE(15262), 1,
      sym_parameter_types,
    STATE(16579), 1,
      sym_template_body,
    STATE(16584), 1,
      sym__type,
    STATE(16590), 1,
      sym__non_null_literal,
    STATE(17822), 1,
      sym_stable_identifier,
    ACTIONS(6222), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6224), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6226), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3332), 2,
      sym_comment,
      sym_block_comment,
    STATE(11894), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11933), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16578), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16593), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6212), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9589), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [112979] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11637), 1,
      sym__type,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3333), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113098] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6202), 1,
      sym__alpha_identifier,
    ACTIONS(6204), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(6208), 1,
      anon_sym__,
    ACTIONS(6210), 1,
      anon_sym_LBRACK,
    ACTIONS(6214), 1,
      anon_sym_LPAREN,
    ACTIONS(6216), 1,
      sym__backquoted_id,
    ACTIONS(6218), 1,
      sym_operator_identifier,
    ACTIONS(6220), 1,
      sym_integer_literal,
    STATE(8726), 1,
      sym__simple_type,
    STATE(9220), 1,
      sym__annotated_type,
    STATE(9360), 1,
      sym_identifier,
    STATE(9455), 1,
      sym__soft_identifier,
    STATE(11142), 1,
      sym_annotated_type,
    STATE(12580), 1,
      sym__infix_type_choice,
    STATE(15262), 1,
      sym_parameter_types,
    STATE(16579), 1,
      sym_template_body,
    STATE(16583), 1,
      sym__type,
    STATE(16590), 1,
      sym__non_null_literal,
    STATE(17822), 1,
      sym_stable_identifier,
    ACTIONS(6222), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6224), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6226), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3334), 2,
      sym_comment,
      sym_block_comment,
    STATE(11894), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11933), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16578), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16593), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6212), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9589), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113217] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16000), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3335), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113336] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6202), 1,
      sym__alpha_identifier,
    ACTIONS(6204), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(6208), 1,
      anon_sym__,
    ACTIONS(6210), 1,
      anon_sym_LBRACK,
    ACTIONS(6214), 1,
      anon_sym_LPAREN,
    ACTIONS(6216), 1,
      sym__backquoted_id,
    ACTIONS(6218), 1,
      sym_operator_identifier,
    ACTIONS(6220), 1,
      sym_integer_literal,
    STATE(8726), 1,
      sym__simple_type,
    STATE(9220), 1,
      sym__annotated_type,
    STATE(9360), 1,
      sym_identifier,
    STATE(9455), 1,
      sym__soft_identifier,
    STATE(11142), 1,
      sym_annotated_type,
    STATE(12580), 1,
      sym__infix_type_choice,
    STATE(15262), 1,
      sym_parameter_types,
    STATE(16579), 1,
      sym_template_body,
    STATE(16582), 1,
      sym__type,
    STATE(16590), 1,
      sym__non_null_literal,
    STATE(17822), 1,
      sym_stable_identifier,
    ACTIONS(6222), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6224), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6226), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3336), 2,
      sym_comment,
      sym_block_comment,
    STATE(11894), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11933), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(16578), 2,
      sym_boolean_literal,
      sym_string,
    STATE(16593), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6212), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9589), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113455] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15727), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3337), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113574] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    ACTIONS(6522), 1,
      anon_sym_LBRACK,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7325), 1,
      sym__annotated_type,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12504), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13400), 1,
      sym__type,
    STATE(16054), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3338), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113693] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    STATE(7533), 1,
      sym__simple_type,
    STATE(8692), 1,
      sym_identifier,
    STATE(8750), 1,
      sym__annotated_type,
    STATE(8795), 1,
      sym__soft_identifier,
    STATE(10744), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12927), 1,
      sym__infix_type_choice,
    STATE(15119), 1,
      sym__type,
    STATE(16105), 1,
      sym_parameter_types,
    STATE(17006), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3339), 2,
      sym_comment,
      sym_block_comment,
    STATE(11242), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113812] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16004), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3340), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [113931] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1594), 1,
      sym_integer_literal,
    ACTIONS(6402), 1,
      sym__alpha_identifier,
    ACTIONS(6404), 1,
      anon_sym_COLON,
    ACTIONS(6406), 1,
      anon_sym_LBRACE,
    ACTIONS(6408), 1,
      anon_sym__,
    ACTIONS(6410), 1,
      anon_sym_LBRACK,
    ACTIONS(6414), 1,
      anon_sym_LPAREN,
    ACTIONS(6416), 1,
      sym__backquoted_id,
    ACTIONS(6418), 1,
      sym_operator_identifier,
    STATE(5198), 1,
      sym__annotated_type,
    STATE(5296), 1,
      sym__simple_type,
    STATE(5859), 1,
      sym_identifier,
    STATE(5895), 1,
      sym__soft_identifier,
    STATE(8665), 1,
      sym_annotated_type,
    STATE(12841), 1,
      sym__infix_type_choice,
    STATE(13563), 1,
      sym__type,
    STATE(13626), 1,
      sym_template_body,
    STATE(13664), 1,
      sym__non_null_literal,
    STATE(15967), 1,
      sym_parameter_types,
    STATE(17654), 1,
      sym_stable_identifier,
    ACTIONS(1596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1602), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3341), 2,
      sym_comment,
      sym_block_comment,
    STATE(8446), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8569), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10079), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13674), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6775), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114050] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1594), 1,
      sym_integer_literal,
    ACTIONS(6402), 1,
      sym__alpha_identifier,
    ACTIONS(6404), 1,
      anon_sym_COLON,
    ACTIONS(6406), 1,
      anon_sym_LBRACE,
    ACTIONS(6408), 1,
      anon_sym__,
    ACTIONS(6410), 1,
      anon_sym_LBRACK,
    ACTIONS(6414), 1,
      anon_sym_LPAREN,
    ACTIONS(6416), 1,
      sym__backquoted_id,
    ACTIONS(6418), 1,
      sym_operator_identifier,
    STATE(5198), 1,
      sym__annotated_type,
    STATE(5296), 1,
      sym__simple_type,
    STATE(5859), 1,
      sym_identifier,
    STATE(5895), 1,
      sym__soft_identifier,
    STATE(8665), 1,
      sym_annotated_type,
    STATE(12841), 1,
      sym__infix_type_choice,
    STATE(13596), 1,
      sym__type,
    STATE(13626), 1,
      sym_template_body,
    STATE(13664), 1,
      sym__non_null_literal,
    STATE(15967), 1,
      sym_parameter_types,
    STATE(17654), 1,
      sym_stable_identifier,
    ACTIONS(1596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1602), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3342), 2,
      sym_comment,
      sym_block_comment,
    STATE(8446), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8569), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10079), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13674), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6775), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114169] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15620), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3343), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114288] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1594), 1,
      sym_integer_literal,
    ACTIONS(6402), 1,
      sym__alpha_identifier,
    ACTIONS(6404), 1,
      anon_sym_COLON,
    ACTIONS(6406), 1,
      anon_sym_LBRACE,
    ACTIONS(6408), 1,
      anon_sym__,
    ACTIONS(6410), 1,
      anon_sym_LBRACK,
    ACTIONS(6414), 1,
      anon_sym_LPAREN,
    ACTIONS(6416), 1,
      sym__backquoted_id,
    ACTIONS(6418), 1,
      sym_operator_identifier,
    STATE(5198), 1,
      sym__annotated_type,
    STATE(5296), 1,
      sym__simple_type,
    STATE(5859), 1,
      sym_identifier,
    STATE(5895), 1,
      sym__soft_identifier,
    STATE(8665), 1,
      sym_annotated_type,
    STATE(12841), 1,
      sym__infix_type_choice,
    STATE(13587), 1,
      sym__type,
    STATE(13626), 1,
      sym_template_body,
    STATE(13664), 1,
      sym__non_null_literal,
    STATE(15967), 1,
      sym_parameter_types,
    STATE(17654), 1,
      sym_stable_identifier,
    ACTIONS(1596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1602), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3344), 2,
      sym_comment,
      sym_block_comment,
    STATE(8446), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8569), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10079), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13674), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6775), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114407] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1594), 1,
      sym_integer_literal,
    ACTIONS(6402), 1,
      sym__alpha_identifier,
    ACTIONS(6404), 1,
      anon_sym_COLON,
    ACTIONS(6406), 1,
      anon_sym_LBRACE,
    ACTIONS(6408), 1,
      anon_sym__,
    ACTIONS(6410), 1,
      anon_sym_LBRACK,
    ACTIONS(6414), 1,
      anon_sym_LPAREN,
    ACTIONS(6416), 1,
      sym__backquoted_id,
    ACTIONS(6418), 1,
      sym_operator_identifier,
    STATE(5198), 1,
      sym__annotated_type,
    STATE(5296), 1,
      sym__simple_type,
    STATE(5859), 1,
      sym_identifier,
    STATE(5895), 1,
      sym__soft_identifier,
    STATE(8665), 1,
      sym_annotated_type,
    STATE(12841), 1,
      sym__infix_type_choice,
    STATE(13584), 1,
      sym__type,
    STATE(13626), 1,
      sym_template_body,
    STATE(13664), 1,
      sym__non_null_literal,
    STATE(15967), 1,
      sym_parameter_types,
    STATE(17654), 1,
      sym_stable_identifier,
    ACTIONS(1596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1602), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3345), 2,
      sym_comment,
      sym_block_comment,
    STATE(8446), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8569), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10079), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13674), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6775), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114526] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6528), 1,
      sym__alpha_identifier,
    ACTIONS(6530), 1,
      anon_sym__,
    ACTIONS(6532), 1,
      anon_sym_LBRACK,
    ACTIONS(6536), 1,
      anon_sym_LPAREN,
    ACTIONS(6538), 1,
      sym__backquoted_id,
    ACTIONS(6540), 1,
      sym_operator_identifier,
    STATE(7390), 1,
      sym__simple_type,
    STATE(7836), 1,
      sym__annotated_type,
    STATE(7921), 1,
      sym_identifier,
    STATE(7952), 1,
      sym__soft_identifier,
    STATE(10528), 1,
      sym_annotated_type,
    STATE(11760), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12942), 1,
      sym__infix_type_choice,
    STATE(16154), 1,
      sym_parameter_types,
    STATE(17028), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3346), 2,
      sym_comment,
      sym_block_comment,
    STATE(11027), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6534), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8432), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114645] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6528), 1,
      sym__alpha_identifier,
    ACTIONS(6530), 1,
      anon_sym__,
    ACTIONS(6532), 1,
      anon_sym_LBRACK,
    ACTIONS(6536), 1,
      anon_sym_LPAREN,
    ACTIONS(6538), 1,
      sym__backquoted_id,
    ACTIONS(6540), 1,
      sym_operator_identifier,
    STATE(7390), 1,
      sym__simple_type,
    STATE(7836), 1,
      sym__annotated_type,
    STATE(7921), 1,
      sym_identifier,
    STATE(7952), 1,
      sym__soft_identifier,
    STATE(10528), 1,
      sym_annotated_type,
    STATE(11757), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12942), 1,
      sym__infix_type_choice,
    STATE(16154), 1,
      sym_parameter_types,
    STATE(17028), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3347), 2,
      sym_comment,
      sym_block_comment,
    STATE(11027), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6534), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8432), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114764] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6528), 1,
      sym__alpha_identifier,
    ACTIONS(6530), 1,
      anon_sym__,
    ACTIONS(6532), 1,
      anon_sym_LBRACK,
    ACTIONS(6536), 1,
      anon_sym_LPAREN,
    ACTIONS(6538), 1,
      sym__backquoted_id,
    ACTIONS(6540), 1,
      sym_operator_identifier,
    STATE(7390), 1,
      sym__simple_type,
    STATE(7836), 1,
      sym__annotated_type,
    STATE(7921), 1,
      sym_identifier,
    STATE(7952), 1,
      sym__soft_identifier,
    STATE(10528), 1,
      sym_annotated_type,
    STATE(11754), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12942), 1,
      sym__infix_type_choice,
    STATE(16154), 1,
      sym_parameter_types,
    STATE(17028), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3348), 2,
      sym_comment,
      sym_block_comment,
    STATE(11027), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6534), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8432), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [114883] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6400), 1,
      anon_sym_LBRACK,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(9474), 1,
      sym__annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12902), 1,
      sym__infix_type_choice,
    STATE(15513), 1,
      sym__type,
    STATE(16052), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3349), 2,
      sym_comment,
      sym_block_comment,
    STATE(11454), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115002] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17639), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3350), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115121] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(17763), 1,
      sym__type,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3351), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115240] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12159), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3352), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115359] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6528), 1,
      sym__alpha_identifier,
    ACTIONS(6530), 1,
      anon_sym__,
    ACTIONS(6532), 1,
      anon_sym_LBRACK,
    ACTIONS(6536), 1,
      anon_sym_LPAREN,
    ACTIONS(6538), 1,
      sym__backquoted_id,
    ACTIONS(6540), 1,
      sym_operator_identifier,
    STATE(7390), 1,
      sym__simple_type,
    STATE(7836), 1,
      sym__annotated_type,
    STATE(7921), 1,
      sym_identifier,
    STATE(7952), 1,
      sym__soft_identifier,
    STATE(10528), 1,
      sym_annotated_type,
    STATE(11746), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12942), 1,
      sym__infix_type_choice,
    STATE(16154), 1,
      sym_parameter_types,
    STATE(17028), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3353), 2,
      sym_comment,
      sym_block_comment,
    STATE(11027), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6534), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8432), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115478] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1362), 1,
      sym_integer_literal,
    ACTIONS(6542), 1,
      sym__alpha_identifier,
    ACTIONS(6544), 1,
      anon_sym_COLON,
    ACTIONS(6546), 1,
      anon_sym_LBRACE,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6550), 1,
      anon_sym_LBRACK,
    ACTIONS(6554), 1,
      anon_sym_LPAREN,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    STATE(5249), 1,
      sym__simple_type,
    STATE(5454), 1,
      sym__annotated_type,
    STATE(5780), 1,
      sym__soft_identifier,
    STATE(5982), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(12495), 1,
      sym__infix_type_choice,
    STATE(13419), 1,
      sym__non_null_literal,
    STATE(13569), 1,
      sym_template_body,
    STATE(13884), 1,
      sym__type,
    STATE(15978), 1,
      sym_parameter_types,
    STATE(17900), 1,
      sym_stable_identifier,
    ACTIONS(1364), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1366), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1370), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3354), 2,
      sym_comment,
      sym_block_comment,
    STATE(8349), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10071), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13410), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6174), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115597] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(17764), 1,
      sym__type,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3355), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115716] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1450), 1,
      sym_integer_literal,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym_COLON,
    ACTIONS(6564), 1,
      anon_sym_LBRACE,
    ACTIONS(6566), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LBRACK,
    ACTIONS(6572), 1,
      anon_sym_LPAREN,
    ACTIONS(6574), 1,
      sym__backquoted_id,
    ACTIONS(6576), 1,
      sym_operator_identifier,
    STATE(5238), 1,
      sym__simple_type,
    STATE(5310), 1,
      sym__annotated_type,
    STATE(5717), 1,
      sym_identifier,
    STATE(6060), 1,
      sym__soft_identifier,
    STATE(8512), 1,
      sym_annotated_type,
    STATE(12617), 1,
      sym__infix_type_choice,
    STATE(13507), 1,
      sym__non_null_literal,
    STATE(13683), 1,
      sym_template_body,
    STATE(13695), 1,
      sym__type,
    STATE(15964), 1,
      sym_parameter_types,
    STATE(17417), 1,
      sym_stable_identifier,
    ACTIONS(1452), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1454), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1458), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3356), 2,
      sym_comment,
      sym_block_comment,
    STATE(8462), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8689), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10158), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13506), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6570), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6110), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115835] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12158), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3357), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [115954] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17637), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3358), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116073] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1450), 1,
      sym_integer_literal,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym_COLON,
    ACTIONS(6564), 1,
      anon_sym_LBRACE,
    ACTIONS(6566), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LBRACK,
    ACTIONS(6572), 1,
      anon_sym_LPAREN,
    ACTIONS(6574), 1,
      sym__backquoted_id,
    ACTIONS(6576), 1,
      sym_operator_identifier,
    STATE(5238), 1,
      sym__simple_type,
    STATE(5310), 1,
      sym__annotated_type,
    STATE(5717), 1,
      sym_identifier,
    STATE(6060), 1,
      sym__soft_identifier,
    STATE(8512), 1,
      sym_annotated_type,
    STATE(12617), 1,
      sym__infix_type_choice,
    STATE(13507), 1,
      sym__non_null_literal,
    STATE(13662), 1,
      sym__type,
    STATE(13683), 1,
      sym_template_body,
    STATE(15964), 1,
      sym_parameter_types,
    STATE(17417), 1,
      sym_stable_identifier,
    ACTIONS(1452), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1454), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1458), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3359), 2,
      sym_comment,
      sym_block_comment,
    STATE(8462), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8689), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10158), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13506), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6570), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6110), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116192] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1700), 1,
      sym_integer_literal,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym_COLON,
    ACTIONS(6582), 1,
      anon_sym_LBRACE,
    ACTIONS(6584), 1,
      anon_sym__,
    ACTIONS(6586), 1,
      anon_sym_LBRACK,
    ACTIONS(6590), 1,
      anon_sym_LPAREN,
    ACTIONS(6592), 1,
      sym__backquoted_id,
    ACTIONS(6594), 1,
      sym_operator_identifier,
    STATE(5523), 1,
      sym__simple_type,
    STATE(5974), 1,
      sym__annotated_type,
    STATE(6385), 1,
      sym__soft_identifier,
    STATE(6582), 1,
      sym_identifier,
    STATE(9185), 1,
      sym_annotated_type,
    STATE(12653), 1,
      sym__infix_type_choice,
    STATE(13794), 1,
      sym__non_null_literal,
    STATE(14022), 1,
      sym_template_body,
    STATE(14028), 1,
      sym__type,
    STATE(15973), 1,
      sym_parameter_types,
    STATE(17792), 1,
      sym_stable_identifier,
    ACTIONS(1702), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1704), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1708), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3360), 2,
      sym_comment,
      sym_block_comment,
    STATE(9188), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9358), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10453), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13825), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6588), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7364), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116311] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1450), 1,
      sym_integer_literal,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym_COLON,
    ACTIONS(6564), 1,
      anon_sym_LBRACE,
    ACTIONS(6566), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LBRACK,
    ACTIONS(6572), 1,
      anon_sym_LPAREN,
    ACTIONS(6574), 1,
      sym__backquoted_id,
    ACTIONS(6576), 1,
      sym_operator_identifier,
    STATE(5238), 1,
      sym__simple_type,
    STATE(5310), 1,
      sym__annotated_type,
    STATE(5717), 1,
      sym_identifier,
    STATE(6060), 1,
      sym__soft_identifier,
    STATE(8512), 1,
      sym_annotated_type,
    STATE(12617), 1,
      sym__infix_type_choice,
    STATE(13507), 1,
      sym__non_null_literal,
    STATE(13661), 1,
      sym__type,
    STATE(13683), 1,
      sym_template_body,
    STATE(15964), 1,
      sym_parameter_types,
    STATE(17417), 1,
      sym_stable_identifier,
    ACTIONS(1452), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1454), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1458), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3361), 2,
      sym_comment,
      sym_block_comment,
    STATE(8462), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8689), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10158), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13506), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6570), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6110), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116430] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1840), 1,
      sym_integer_literal,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6428), 1,
      anon_sym_LBRACK,
    ACTIONS(6432), 1,
      anon_sym_LPAREN,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    STATE(4728), 1,
      sym__annotated_type,
    STATE(4796), 1,
      sym__simple_type,
    STATE(4977), 1,
      sym_identifier,
    STATE(5072), 1,
      sym__soft_identifier,
    STATE(7069), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12702), 1,
      sym__infix_type_choice,
    STATE(12713), 1,
      sym__type,
    STATE(16108), 1,
      sym_parameter_types,
    STATE(17635), 1,
      sym_stable_identifier,
    ACTIONS(1842), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1844), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1848), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3362), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6406), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9368), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5463), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116549] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4662), 1,
      anon_sym_COLON,
    ACTIONS(4664), 1,
      anon_sym_LBRACE,
    ACTIONS(4682), 1,
      sym_integer_literal,
    ACTIONS(4812), 1,
      sym__alpha_identifier,
    ACTIONS(4814), 1,
      anon_sym__,
    ACTIONS(4818), 1,
      anon_sym_LBRACK,
    ACTIONS(4824), 1,
      sym__backquoted_id,
    ACTIONS(6596), 1,
      anon_sym_LPAREN,
    ACTIONS(6598), 1,
      sym_operator_identifier,
    STATE(5711), 1,
      sym__simple_type,
    STATE(6017), 1,
      sym__annotated_type,
    STATE(6255), 1,
      sym_identifier,
    STATE(6330), 1,
      sym__soft_identifier,
    STATE(9582), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11982), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12677), 1,
      sym__infix_type_choice,
    STATE(16098), 1,
      sym_parameter_types,
    STATE(16701), 1,
      sym_stable_identifier,
    ACTIONS(4684), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4686), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3363), 2,
      sym_comment,
      sym_block_comment,
    STATE(10456), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11722), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11743), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4820), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7403), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116668] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4662), 1,
      anon_sym_COLON,
    ACTIONS(4664), 1,
      anon_sym_LBRACE,
    ACTIONS(4682), 1,
      sym_integer_literal,
    ACTIONS(4812), 1,
      sym__alpha_identifier,
    ACTIONS(4814), 1,
      anon_sym__,
    ACTIONS(4818), 1,
      anon_sym_LBRACK,
    ACTIONS(4824), 1,
      sym__backquoted_id,
    ACTIONS(6596), 1,
      anon_sym_LPAREN,
    ACTIONS(6598), 1,
      sym_operator_identifier,
    STATE(5711), 1,
      sym__simple_type,
    STATE(6017), 1,
      sym__annotated_type,
    STATE(6255), 1,
      sym_identifier,
    STATE(6330), 1,
      sym__soft_identifier,
    STATE(9582), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11980), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12677), 1,
      sym__infix_type_choice,
    STATE(16098), 1,
      sym_parameter_types,
    STATE(16701), 1,
      sym_stable_identifier,
    ACTIONS(4684), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4686), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3364), 2,
      sym_comment,
      sym_block_comment,
    STATE(10456), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11722), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11743), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4820), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7403), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116787] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4662), 1,
      anon_sym_COLON,
    ACTIONS(4664), 1,
      anon_sym_LBRACE,
    ACTIONS(4682), 1,
      sym_integer_literal,
    ACTIONS(4812), 1,
      sym__alpha_identifier,
    ACTIONS(4814), 1,
      anon_sym__,
    ACTIONS(4818), 1,
      anon_sym_LBRACK,
    ACTIONS(4824), 1,
      sym__backquoted_id,
    ACTIONS(6596), 1,
      anon_sym_LPAREN,
    ACTIONS(6598), 1,
      sym_operator_identifier,
    STATE(5711), 1,
      sym__simple_type,
    STATE(6017), 1,
      sym__annotated_type,
    STATE(6255), 1,
      sym_identifier,
    STATE(6330), 1,
      sym__soft_identifier,
    STATE(9582), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11974), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12677), 1,
      sym__infix_type_choice,
    STATE(16098), 1,
      sym_parameter_types,
    STATE(16701), 1,
      sym_stable_identifier,
    ACTIONS(4684), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4686), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3365), 2,
      sym_comment,
      sym_block_comment,
    STATE(10456), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11722), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11743), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4820), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7403), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [116906] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4662), 1,
      anon_sym_COLON,
    ACTIONS(4664), 1,
      anon_sym_LBRACE,
    ACTIONS(4682), 1,
      sym_integer_literal,
    ACTIONS(4812), 1,
      sym__alpha_identifier,
    ACTIONS(4814), 1,
      anon_sym__,
    ACTIONS(4818), 1,
      anon_sym_LBRACK,
    ACTIONS(4824), 1,
      sym__backquoted_id,
    ACTIONS(6596), 1,
      anon_sym_LPAREN,
    ACTIONS(6598), 1,
      sym_operator_identifier,
    STATE(5711), 1,
      sym__simple_type,
    STATE(6017), 1,
      sym__annotated_type,
    STATE(6255), 1,
      sym_identifier,
    STATE(6330), 1,
      sym__soft_identifier,
    STATE(9582), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11957), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12677), 1,
      sym__infix_type_choice,
    STATE(16098), 1,
      sym_parameter_types,
    STATE(16701), 1,
      sym_stable_identifier,
    ACTIONS(4684), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4686), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3366), 2,
      sym_comment,
      sym_block_comment,
    STATE(10456), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11722), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11743), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4820), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7403), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117025] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16143), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3367), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117144] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1538), 1,
      sym_integer_literal,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym__,
    ACTIONS(6604), 1,
      anon_sym_LBRACK,
    ACTIONS(6608), 1,
      anon_sym_LPAREN,
    ACTIONS(6610), 1,
      sym__backquoted_id,
    ACTIONS(6612), 1,
      sym_operator_identifier,
    STATE(6433), 1,
      sym__simple_type,
    STATE(6449), 1,
      sym__annotated_type,
    STATE(7134), 1,
      sym__soft_identifier,
    STATE(7495), 1,
      sym_identifier,
    STATE(9897), 1,
      sym_annotated_type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12369), 1,
      sym__type,
    STATE(12501), 1,
      sym__infix_type_choice,
    STATE(16058), 1,
      sym_parameter_types,
    STATE(17864), 1,
      sym_stable_identifier,
    ACTIONS(1540), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1542), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1546), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3368), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5996), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10820), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7557), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117263] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1450), 1,
      sym_integer_literal,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym_COLON,
    ACTIONS(6564), 1,
      anon_sym_LBRACE,
    ACTIONS(6566), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LBRACK,
    ACTIONS(6572), 1,
      anon_sym_LPAREN,
    ACTIONS(6574), 1,
      sym__backquoted_id,
    ACTIONS(6576), 1,
      sym_operator_identifier,
    STATE(5238), 1,
      sym__simple_type,
    STATE(5310), 1,
      sym__annotated_type,
    STATE(5717), 1,
      sym_identifier,
    STATE(6060), 1,
      sym__soft_identifier,
    STATE(8512), 1,
      sym_annotated_type,
    STATE(12617), 1,
      sym__infix_type_choice,
    STATE(13507), 1,
      sym__non_null_literal,
    STATE(13641), 1,
      sym__type,
    STATE(13683), 1,
      sym_template_body,
    STATE(15964), 1,
      sym_parameter_types,
    STATE(17417), 1,
      sym_stable_identifier,
    ACTIONS(1452), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1454), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1458), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3369), 2,
      sym_comment,
      sym_block_comment,
    STATE(8462), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8689), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10158), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13506), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6570), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6110), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117382] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6614), 1,
      anon_sym_COLON,
    ACTIONS(6616), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LBRACK,
    ACTIONS(6620), 1,
      sym_integer_literal,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(10261), 1,
      sym__annotated_type,
    STATE(12878), 1,
      sym__infix_type_choice,
    STATE(16283), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17998), 1,
      sym_template_body,
    STATE(18002), 1,
      sym__type,
    STATE(18015), 1,
      sym__non_null_literal,
    ACTIONS(6622), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6624), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6626), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3370), 2,
      sym_comment,
      sym_block_comment,
    STATE(12520), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(17983), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(17994), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18000), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117501] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4624), 1,
      sym__alpha_identifier,
    ACTIONS(4626), 1,
      anon_sym_COLON,
    ACTIONS(4628), 1,
      anon_sym_LBRACE,
    ACTIONS(4630), 1,
      anon_sym__,
    ACTIONS(4634), 1,
      anon_sym_LBRACK,
    ACTIONS(4642), 1,
      sym__backquoted_id,
    ACTIONS(4646), 1,
      sym_integer_literal,
    ACTIONS(6628), 1,
      anon_sym_LPAREN,
    ACTIONS(6630), 1,
      sym_operator_identifier,
    STATE(4397), 1,
      sym__annotated_type,
    STATE(4437), 1,
      sym__simple_type,
    STATE(4445), 1,
      sym__soft_identifier,
    STATE(4449), 1,
      sym_identifier,
    STATE(5361), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11649), 1,
      sym__type,
    STATE(12672), 1,
      sym__infix_type_choice,
    STATE(15969), 1,
      sym_parameter_types,
    STATE(17628), 1,
      sym_stable_identifier,
    ACTIONS(4648), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4650), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4654), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3371), 2,
      sym_comment,
      sym_block_comment,
    STATE(7102), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11482), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11561), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4542), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117620] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16703), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3372), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117739] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4624), 1,
      sym__alpha_identifier,
    ACTIONS(4626), 1,
      anon_sym_COLON,
    ACTIONS(4628), 1,
      anon_sym_LBRACE,
    ACTIONS(4630), 1,
      anon_sym__,
    ACTIONS(4634), 1,
      anon_sym_LBRACK,
    ACTIONS(4642), 1,
      sym__backquoted_id,
    ACTIONS(4646), 1,
      sym_integer_literal,
    ACTIONS(6628), 1,
      anon_sym_LPAREN,
    ACTIONS(6630), 1,
      sym_operator_identifier,
    STATE(4397), 1,
      sym__annotated_type,
    STATE(4437), 1,
      sym__simple_type,
    STATE(4445), 1,
      sym__soft_identifier,
    STATE(4449), 1,
      sym_identifier,
    STATE(5361), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11650), 1,
      sym__type,
    STATE(12672), 1,
      sym__infix_type_choice,
    STATE(15969), 1,
      sym_parameter_types,
    STATE(17628), 1,
      sym_stable_identifier,
    ACTIONS(4648), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4650), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4654), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3373), 2,
      sym_comment,
      sym_block_comment,
    STATE(7102), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11482), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11561), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4542), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117858] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4774), 1,
      sym__alpha_identifier,
    ACTIONS(4776), 1,
      anon_sym_COLON,
    ACTIONS(4778), 1,
      anon_sym_LBRACE,
    ACTIONS(4780), 1,
      anon_sym__,
    ACTIONS(4784), 1,
      anon_sym_LBRACK,
    ACTIONS(4792), 1,
      sym__backquoted_id,
    ACTIONS(4796), 1,
      sym_integer_literal,
    ACTIONS(6396), 1,
      anon_sym_LPAREN,
    ACTIONS(6398), 1,
      sym_operator_identifier,
    STATE(5356), 1,
      sym__annotated_type,
    STATE(5471), 1,
      sym__simple_type,
    STATE(5800), 1,
      sym__soft_identifier,
    STATE(5818), 1,
      sym_identifier,
    STATE(8839), 1,
      sym_annotated_type,
    STATE(12611), 1,
      sym__infix_type_choice,
    STATE(13821), 1,
      sym__type,
    STATE(13874), 1,
      sym__non_null_literal,
    STATE(13912), 1,
      sym_template_body,
    STATE(15526), 1,
      sym_parameter_types,
    STATE(17804), 1,
      sym_stable_identifier,
    ACTIONS(4798), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4800), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4802), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3374), 2,
      sym_comment,
      sym_block_comment,
    STATE(10348), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13757), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13936), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13869), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4786), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6677), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [117977] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16020), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3375), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118096] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15703), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3376), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118215] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15694), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3377), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118334] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8491), 1,
      sym__type,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3378), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118453] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16022), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3379), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118572] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4624), 1,
      sym__alpha_identifier,
    ACTIONS(4626), 1,
      anon_sym_COLON,
    ACTIONS(4628), 1,
      anon_sym_LBRACE,
    ACTIONS(4630), 1,
      anon_sym__,
    ACTIONS(4634), 1,
      anon_sym_LBRACK,
    ACTIONS(4642), 1,
      sym__backquoted_id,
    ACTIONS(4646), 1,
      sym_integer_literal,
    ACTIONS(6628), 1,
      anon_sym_LPAREN,
    ACTIONS(6630), 1,
      sym_operator_identifier,
    STATE(4397), 1,
      sym__annotated_type,
    STATE(4437), 1,
      sym__simple_type,
    STATE(4445), 1,
      sym__soft_identifier,
    STATE(4449), 1,
      sym_identifier,
    STATE(5361), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11651), 1,
      sym__type,
    STATE(12672), 1,
      sym__infix_type_choice,
    STATE(15969), 1,
      sym_parameter_types,
    STATE(17628), 1,
      sym_stable_identifier,
    ACTIONS(4648), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4650), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4654), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3380), 2,
      sym_comment,
      sym_block_comment,
    STATE(7102), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11482), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11561), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4542), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118691] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15257), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3381), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118810] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16024), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3382), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [118929] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6614), 1,
      anon_sym_COLON,
    ACTIONS(6616), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LBRACK,
    ACTIONS(6620), 1,
      sym_integer_literal,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(10261), 1,
      sym__annotated_type,
    STATE(12878), 1,
      sym__infix_type_choice,
    STATE(16283), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17998), 1,
      sym_template_body,
    STATE(18015), 1,
      sym__non_null_literal,
    STATE(18214), 1,
      sym__type,
    ACTIONS(6622), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6624), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6626), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3383), 2,
      sym_comment,
      sym_block_comment,
    STATE(12520), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(17983), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(17994), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18000), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119048] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [119117] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4662), 1,
      anon_sym_COLON,
    ACTIONS(4664), 1,
      anon_sym_LBRACE,
    ACTIONS(4682), 1,
      sym_integer_literal,
    ACTIONS(4812), 1,
      sym__alpha_identifier,
    ACTIONS(4814), 1,
      anon_sym__,
    ACTIONS(4818), 1,
      anon_sym_LBRACK,
    ACTIONS(4824), 1,
      sym__backquoted_id,
    ACTIONS(6596), 1,
      anon_sym_LPAREN,
    ACTIONS(6598), 1,
      sym_operator_identifier,
    STATE(5711), 1,
      sym__simple_type,
    STATE(6017), 1,
      sym__annotated_type,
    STATE(6255), 1,
      sym_identifier,
    STATE(6330), 1,
      sym__soft_identifier,
    STATE(9582), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11918), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12677), 1,
      sym__infix_type_choice,
    STATE(16098), 1,
      sym_parameter_types,
    STATE(16701), 1,
      sym_stable_identifier,
    ACTIONS(4684), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4686), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3385), 2,
      sym_comment,
      sym_block_comment,
    STATE(10456), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11722), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11743), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4820), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7403), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119236] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4624), 1,
      sym__alpha_identifier,
    ACTIONS(4626), 1,
      anon_sym_COLON,
    ACTIONS(4628), 1,
      anon_sym_LBRACE,
    ACTIONS(4630), 1,
      anon_sym__,
    ACTIONS(4634), 1,
      anon_sym_LBRACK,
    ACTIONS(4642), 1,
      sym__backquoted_id,
    ACTIONS(4646), 1,
      sym_integer_literal,
    ACTIONS(6628), 1,
      anon_sym_LPAREN,
    ACTIONS(6630), 1,
      sym_operator_identifier,
    STATE(4397), 1,
      sym__annotated_type,
    STATE(4437), 1,
      sym__simple_type,
    STATE(4445), 1,
      sym__soft_identifier,
    STATE(4449), 1,
      sym_identifier,
    STATE(5361), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11659), 1,
      sym__type,
    STATE(12672), 1,
      sym__infix_type_choice,
    STATE(15969), 1,
      sym_parameter_types,
    STATE(17628), 1,
      sym_stable_identifier,
    ACTIONS(4648), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4650), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4654), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3386), 2,
      sym_comment,
      sym_block_comment,
    STATE(7102), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11482), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11561), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4542), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119355] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8499), 1,
      sym__type,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3387), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119474] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6614), 1,
      anon_sym_COLON,
    ACTIONS(6616), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LBRACK,
    ACTIONS(6620), 1,
      sym_integer_literal,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(10261), 1,
      sym__annotated_type,
    STATE(12878), 1,
      sym__infix_type_choice,
    STATE(16283), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17998), 1,
      sym_template_body,
    STATE(18003), 1,
      sym__type,
    STATE(18015), 1,
      sym__non_null_literal,
    ACTIONS(6622), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6624), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6626), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3388), 2,
      sym_comment,
      sym_block_comment,
    STATE(12520), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(17983), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(17994), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18000), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119593] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6632), 1,
      sym__alpha_identifier,
    ACTIONS(6634), 1,
      anon_sym_COLON,
    ACTIONS(6636), 1,
      anon_sym_LBRACE,
    ACTIONS(6638), 1,
      anon_sym__,
    ACTIONS(6640), 1,
      anon_sym_LBRACK,
    ACTIONS(6644), 1,
      anon_sym_LPAREN,
    ACTIONS(6646), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(6650), 1,
      sym_integer_literal,
    STATE(5803), 1,
      sym__simple_type,
    STATE(6337), 1,
      sym_identifier,
    STATE(6520), 1,
      sym__annotated_type,
    STATE(6537), 1,
      sym__soft_identifier,
    STATE(9656), 1,
      sym_annotated_type,
    STATE(11205), 1,
      sym__type,
    STATE(11261), 1,
      sym__non_null_literal,
    STATE(11381), 1,
      sym_template_body,
    STATE(12477), 1,
      sym__infix_type_choice,
    STATE(16195), 1,
      sym_parameter_types,
    STATE(16798), 1,
      sym_stable_identifier,
    ACTIONS(6652), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6654), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6656), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3389), 2,
      sym_comment,
      sym_block_comment,
    STATE(10566), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11277), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11388), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11262), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6642), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6924), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119712] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(18400), 1,
      sym__type,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3390), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119831] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15672), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3391), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [119950] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15670), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3392), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120069] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6614), 1,
      anon_sym_COLON,
    ACTIONS(6616), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LBRACK,
    ACTIONS(6620), 1,
      sym_integer_literal,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(10261), 1,
      sym__annotated_type,
    STATE(12878), 1,
      sym__infix_type_choice,
    STATE(16283), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17998), 1,
      sym_template_body,
    STATE(18005), 1,
      sym__type,
    STATE(18015), 1,
      sym__non_null_literal,
    ACTIONS(6622), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6624), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6626), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3393), 2,
      sym_comment,
      sym_block_comment,
    STATE(12520), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(17983), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(17994), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18000), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120188] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6614), 1,
      anon_sym_COLON,
    ACTIONS(6616), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LBRACK,
    ACTIONS(6620), 1,
      sym_integer_literal,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(10261), 1,
      sym__annotated_type,
    STATE(12878), 1,
      sym__infix_type_choice,
    STATE(16283), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17998), 1,
      sym_template_body,
    STATE(18008), 1,
      sym__type,
    STATE(18015), 1,
      sym__non_null_literal,
    ACTIONS(6622), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6624), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6626), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3394), 2,
      sym_comment,
      sym_block_comment,
    STATE(12520), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(17983), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(17994), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18000), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120307] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(18405), 1,
      sym__type,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3395), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120426] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17779), 1,
      sym__type,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3396), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120545] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 10,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [120614] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15653), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3398), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120733] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15647), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3399), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120852] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1594), 1,
      sym_integer_literal,
    ACTIONS(6402), 1,
      sym__alpha_identifier,
    ACTIONS(6404), 1,
      anon_sym_COLON,
    ACTIONS(6406), 1,
      anon_sym_LBRACE,
    ACTIONS(6408), 1,
      anon_sym__,
    ACTIONS(6410), 1,
      anon_sym_LBRACK,
    ACTIONS(6414), 1,
      anon_sym_LPAREN,
    ACTIONS(6416), 1,
      sym__backquoted_id,
    ACTIONS(6418), 1,
      sym_operator_identifier,
    STATE(5198), 1,
      sym__annotated_type,
    STATE(5296), 1,
      sym__simple_type,
    STATE(5859), 1,
      sym_identifier,
    STATE(5895), 1,
      sym__soft_identifier,
    STATE(8665), 1,
      sym_annotated_type,
    STATE(12841), 1,
      sym__infix_type_choice,
    STATE(13608), 1,
      sym__type,
    STATE(13626), 1,
      sym_template_body,
    STATE(13664), 1,
      sym__non_null_literal,
    STATE(15967), 1,
      sym_parameter_types,
    STATE(17654), 1,
      sym_stable_identifier,
    ACTIONS(1596), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1598), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1602), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3400), 2,
      sym_comment,
      sym_block_comment,
    STATE(8446), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8569), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10079), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13674), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6775), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [120971] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    ACTIONS(6522), 1,
      anon_sym_LBRACK,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7325), 1,
      sym__annotated_type,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12504), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13401), 1,
      sym__type,
    STATE(16054), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3401), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121090] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1700), 1,
      sym_integer_literal,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym_COLON,
    ACTIONS(6582), 1,
      anon_sym_LBRACE,
    ACTIONS(6584), 1,
      anon_sym__,
    ACTIONS(6586), 1,
      anon_sym_LBRACK,
    ACTIONS(6590), 1,
      anon_sym_LPAREN,
    ACTIONS(6592), 1,
      sym__backquoted_id,
    ACTIONS(6594), 1,
      sym_operator_identifier,
    STATE(5523), 1,
      sym__simple_type,
    STATE(5974), 1,
      sym__annotated_type,
    STATE(6385), 1,
      sym__soft_identifier,
    STATE(6582), 1,
      sym_identifier,
    STATE(9185), 1,
      sym_annotated_type,
    STATE(12653), 1,
      sym__infix_type_choice,
    STATE(13794), 1,
      sym__non_null_literal,
    STATE(13860), 1,
      sym__type,
    STATE(14022), 1,
      sym_template_body,
    STATE(15973), 1,
      sym_parameter_types,
    STATE(17792), 1,
      sym_stable_identifier,
    ACTIONS(1702), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1704), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1708), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3402), 2,
      sym_comment,
      sym_block_comment,
    STATE(9188), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9358), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10453), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13825), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6588), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7364), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121209] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(6614), 1,
      anon_sym_COLON,
    ACTIONS(6616), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LBRACK,
    ACTIONS(6620), 1,
      sym_integer_literal,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(10261), 1,
      sym__annotated_type,
    STATE(12878), 1,
      sym__infix_type_choice,
    STATE(16283), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17998), 1,
      sym_template_body,
    STATE(18009), 1,
      sym__type,
    STATE(18015), 1,
      sym__non_null_literal,
    ACTIONS(6622), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6624), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6626), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3403), 2,
      sym_comment,
      sym_block_comment,
    STATE(12520), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(17983), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(17994), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18000), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121328] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17782), 1,
      sym__type,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3404), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121447] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15252), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3405), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121566] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15630), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3406), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121685] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15625), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3407), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121804] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1700), 1,
      sym_integer_literal,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym_COLON,
    ACTIONS(6582), 1,
      anon_sym_LBRACE,
    ACTIONS(6584), 1,
      anon_sym__,
    ACTIONS(6586), 1,
      anon_sym_LBRACK,
    ACTIONS(6590), 1,
      anon_sym_LPAREN,
    ACTIONS(6592), 1,
      sym__backquoted_id,
    ACTIONS(6594), 1,
      sym_operator_identifier,
    STATE(5523), 1,
      sym__simple_type,
    STATE(5974), 1,
      sym__annotated_type,
    STATE(6385), 1,
      sym__soft_identifier,
    STATE(6582), 1,
      sym_identifier,
    STATE(9185), 1,
      sym_annotated_type,
    STATE(12653), 1,
      sym__infix_type_choice,
    STATE(13794), 1,
      sym__non_null_literal,
    STATE(13937), 1,
      sym__type,
    STATE(14022), 1,
      sym_template_body,
    STATE(15973), 1,
      sym_parameter_types,
    STATE(17792), 1,
      sym_stable_identifier,
    ACTIONS(1702), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1704), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1708), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3408), 2,
      sym_comment,
      sym_block_comment,
    STATE(9188), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9358), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10453), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13825), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6588), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7364), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [121923] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6632), 1,
      sym__alpha_identifier,
    ACTIONS(6634), 1,
      anon_sym_COLON,
    ACTIONS(6636), 1,
      anon_sym_LBRACE,
    ACTIONS(6638), 1,
      anon_sym__,
    ACTIONS(6640), 1,
      anon_sym_LBRACK,
    ACTIONS(6644), 1,
      anon_sym_LPAREN,
    ACTIONS(6646), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(6650), 1,
      sym_integer_literal,
    STATE(5803), 1,
      sym__simple_type,
    STATE(6337), 1,
      sym_identifier,
    STATE(6520), 1,
      sym__annotated_type,
    STATE(6537), 1,
      sym__soft_identifier,
    STATE(9656), 1,
      sym_annotated_type,
    STATE(11198), 1,
      sym__type,
    STATE(11261), 1,
      sym__non_null_literal,
    STATE(11381), 1,
      sym_template_body,
    STATE(12477), 1,
      sym__infix_type_choice,
    STATE(16195), 1,
      sym_parameter_types,
    STATE(16798), 1,
      sym_stable_identifier,
    ACTIONS(6652), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6654), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6656), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3409), 2,
      sym_comment,
      sym_block_comment,
    STATE(10566), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11277), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11388), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11262), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6642), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6924), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122042] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6632), 1,
      sym__alpha_identifier,
    ACTIONS(6634), 1,
      anon_sym_COLON,
    ACTIONS(6636), 1,
      anon_sym_LBRACE,
    ACTIONS(6638), 1,
      anon_sym__,
    ACTIONS(6640), 1,
      anon_sym_LBRACK,
    ACTIONS(6644), 1,
      anon_sym_LPAREN,
    ACTIONS(6646), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(6650), 1,
      sym_integer_literal,
    STATE(5803), 1,
      sym__simple_type,
    STATE(6337), 1,
      sym_identifier,
    STATE(6520), 1,
      sym__annotated_type,
    STATE(6537), 1,
      sym__soft_identifier,
    STATE(9656), 1,
      sym_annotated_type,
    STATE(11193), 1,
      sym__type,
    STATE(11261), 1,
      sym__non_null_literal,
    STATE(11381), 1,
      sym_template_body,
    STATE(12477), 1,
      sym__infix_type_choice,
    STATE(16195), 1,
      sym_parameter_types,
    STATE(16798), 1,
      sym_stable_identifier,
    ACTIONS(6652), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6654), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6656), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3410), 2,
      sym_comment,
      sym_block_comment,
    STATE(10566), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11277), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11388), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11262), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6642), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6924), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122161] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6632), 1,
      sym__alpha_identifier,
    ACTIONS(6634), 1,
      anon_sym_COLON,
    ACTIONS(6636), 1,
      anon_sym_LBRACE,
    ACTIONS(6638), 1,
      anon_sym__,
    ACTIONS(6640), 1,
      anon_sym_LBRACK,
    ACTIONS(6644), 1,
      anon_sym_LPAREN,
    ACTIONS(6646), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(6650), 1,
      sym_integer_literal,
    STATE(5803), 1,
      sym__simple_type,
    STATE(6337), 1,
      sym_identifier,
    STATE(6520), 1,
      sym__annotated_type,
    STATE(6537), 1,
      sym__soft_identifier,
    STATE(9656), 1,
      sym_annotated_type,
    STATE(11192), 1,
      sym__type,
    STATE(11261), 1,
      sym__non_null_literal,
    STATE(11381), 1,
      sym_template_body,
    STATE(12477), 1,
      sym__infix_type_choice,
    STATE(16195), 1,
      sym_parameter_types,
    STATE(16798), 1,
      sym_stable_identifier,
    ACTIONS(6652), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6654), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6656), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3411), 2,
      sym_comment,
      sym_block_comment,
    STATE(10566), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11277), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11388), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11262), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6642), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6924), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122280] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1450), 1,
      sym_integer_literal,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym_COLON,
    ACTIONS(6564), 1,
      anon_sym_LBRACE,
    ACTIONS(6566), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LBRACK,
    ACTIONS(6572), 1,
      anon_sym_LPAREN,
    ACTIONS(6574), 1,
      sym__backquoted_id,
    ACTIONS(6576), 1,
      sym_operator_identifier,
    STATE(5238), 1,
      sym__simple_type,
    STATE(5310), 1,
      sym__annotated_type,
    STATE(5717), 1,
      sym_identifier,
    STATE(6060), 1,
      sym__soft_identifier,
    STATE(8512), 1,
      sym_annotated_type,
    STATE(12617), 1,
      sym__infix_type_choice,
    STATE(13507), 1,
      sym__non_null_literal,
    STATE(13623), 1,
      sym__type,
    STATE(13683), 1,
      sym_template_body,
    STATE(15964), 1,
      sym_parameter_types,
    STATE(17417), 1,
      sym_stable_identifier,
    ACTIONS(1452), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1454), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1458), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3412), 2,
      sym_comment,
      sym_block_comment,
    STATE(8462), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8689), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10158), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13506), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6570), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6110), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122399] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6632), 1,
      sym__alpha_identifier,
    ACTIONS(6634), 1,
      anon_sym_COLON,
    ACTIONS(6636), 1,
      anon_sym_LBRACE,
    ACTIONS(6638), 1,
      anon_sym__,
    ACTIONS(6640), 1,
      anon_sym_LBRACK,
    ACTIONS(6644), 1,
      anon_sym_LPAREN,
    ACTIONS(6646), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(6650), 1,
      sym_integer_literal,
    STATE(5803), 1,
      sym__simple_type,
    STATE(6337), 1,
      sym_identifier,
    STATE(6520), 1,
      sym__annotated_type,
    STATE(6537), 1,
      sym__soft_identifier,
    STATE(9656), 1,
      sym_annotated_type,
    STATE(11191), 1,
      sym__type,
    STATE(11261), 1,
      sym__non_null_literal,
    STATE(11381), 1,
      sym_template_body,
    STATE(12477), 1,
      sym__infix_type_choice,
    STATE(16195), 1,
      sym_parameter_types,
    STATE(16798), 1,
      sym_stable_identifier,
    ACTIONS(6652), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6654), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6656), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3413), 2,
      sym_comment,
      sym_block_comment,
    STATE(10566), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11277), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11388), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11262), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6642), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6924), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122518] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4886), 1,
      sym__alpha_identifier,
    ACTIONS(4888), 1,
      anon_sym_COLON,
    ACTIONS(4890), 1,
      anon_sym_LBRACE,
    ACTIONS(4892), 1,
      anon_sym__,
    ACTIONS(4896), 1,
      anon_sym_LBRACK,
    ACTIONS(4904), 1,
      sym__backquoted_id,
    ACTIONS(4908), 1,
      sym_integer_literal,
    ACTIONS(6658), 1,
      anon_sym_LPAREN,
    ACTIONS(6660), 1,
      sym_operator_identifier,
    STATE(4668), 1,
      sym__simple_type,
    STATE(4690), 1,
      sym__annotated_type,
    STATE(5003), 1,
      sym_identifier,
    STATE(5087), 1,
      sym__soft_identifier,
    STATE(7155), 1,
      sym_annotated_type,
    STATE(12544), 1,
      sym__infix_type_choice,
    STATE(13171), 1,
      sym__type,
    STATE(13245), 1,
      sym_template_body,
    STATE(13295), 1,
      sym__non_null_literal,
    STATE(15364), 1,
      sym_parameter_types,
    STATE(17828), 1,
      sym_stable_identifier,
    ACTIONS(4910), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4912), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4914), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3414), 2,
      sym_comment,
      sym_block_comment,
    STATE(8990), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12950), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13007), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13299), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5448), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122637] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15608), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3415), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122756] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1700), 1,
      sym_integer_literal,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym_COLON,
    ACTIONS(6582), 1,
      anon_sym_LBRACE,
    ACTIONS(6584), 1,
      anon_sym__,
    ACTIONS(6586), 1,
      anon_sym_LBRACK,
    ACTIONS(6590), 1,
      anon_sym_LPAREN,
    ACTIONS(6592), 1,
      sym__backquoted_id,
    ACTIONS(6594), 1,
      sym_operator_identifier,
    STATE(5523), 1,
      sym__simple_type,
    STATE(5974), 1,
      sym__annotated_type,
    STATE(6385), 1,
      sym__soft_identifier,
    STATE(6582), 1,
      sym_identifier,
    STATE(9185), 1,
      sym_annotated_type,
    STATE(12653), 1,
      sym__infix_type_choice,
    STATE(13794), 1,
      sym__non_null_literal,
    STATE(14004), 1,
      sym__type,
    STATE(14022), 1,
      sym_template_body,
    STATE(15973), 1,
      sym_parameter_types,
    STATE(17792), 1,
      sym_stable_identifier,
    ACTIONS(1702), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1704), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1708), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3416), 2,
      sym_comment,
      sym_block_comment,
    STATE(9188), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9358), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10453), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13825), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6588), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7364), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122875] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1306), 1,
      sym_integer_literal,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(6662), 1,
      sym__alpha_identifier,
    ACTIONS(6664), 1,
      anon_sym__,
    ACTIONS(6666), 1,
      anon_sym_LBRACK,
    ACTIONS(6670), 1,
      anon_sym_LPAREN,
    ACTIONS(6672), 1,
      sym__backquoted_id,
    ACTIONS(6674), 1,
      sym_operator_identifier,
    STATE(4496), 1,
      sym__simple_type,
    STATE(4537), 1,
      sym__annotated_type,
    STATE(4616), 1,
      sym_identifier,
    STATE(4632), 1,
      sym__soft_identifier,
    STATE(5589), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11901), 1,
      sym__type,
    STATE(12793), 1,
      sym__infix_type_choice,
    STATE(16109), 1,
      sym_parameter_types,
    STATE(17744), 1,
      sym_stable_identifier,
    ACTIONS(1308), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1310), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1314), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3417), 2,
      sym_comment,
      sym_block_comment,
    STATE(5184), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7690), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6668), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4799), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [122994] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15607), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3418), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123113] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16315), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3419), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123232] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4624), 1,
      sym__alpha_identifier,
    ACTIONS(4626), 1,
      anon_sym_COLON,
    ACTIONS(4628), 1,
      anon_sym_LBRACE,
    ACTIONS(4630), 1,
      anon_sym__,
    ACTIONS(4634), 1,
      anon_sym_LBRACK,
    ACTIONS(4642), 1,
      sym__backquoted_id,
    ACTIONS(4646), 1,
      sym_integer_literal,
    ACTIONS(6628), 1,
      anon_sym_LPAREN,
    ACTIONS(6630), 1,
      sym_operator_identifier,
    STATE(4397), 1,
      sym__annotated_type,
    STATE(4437), 1,
      sym__simple_type,
    STATE(4445), 1,
      sym__soft_identifier,
    STATE(4449), 1,
      sym_identifier,
    STATE(5361), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11681), 1,
      sym__type,
    STATE(12672), 1,
      sym__infix_type_choice,
    STATE(15969), 1,
      sym_parameter_types,
    STATE(17628), 1,
      sym_stable_identifier,
    ACTIONS(4648), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4650), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4654), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3420), 2,
      sym_comment,
      sym_block_comment,
    STATE(7102), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11482), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11561), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4542), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123351] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15939), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3421), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123470] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1700), 1,
      sym_integer_literal,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym_COLON,
    ACTIONS(6582), 1,
      anon_sym_LBRACE,
    ACTIONS(6584), 1,
      anon_sym__,
    ACTIONS(6586), 1,
      anon_sym_LBRACK,
    ACTIONS(6590), 1,
      anon_sym_LPAREN,
    ACTIONS(6592), 1,
      sym__backquoted_id,
    ACTIONS(6594), 1,
      sym_operator_identifier,
    STATE(5523), 1,
      sym__simple_type,
    STATE(5974), 1,
      sym__annotated_type,
    STATE(6385), 1,
      sym__soft_identifier,
    STATE(6582), 1,
      sym_identifier,
    STATE(9185), 1,
      sym_annotated_type,
    STATE(12653), 1,
      sym__infix_type_choice,
    STATE(13794), 1,
      sym__non_null_literal,
    STATE(14022), 1,
      sym_template_body,
    STATE(14044), 1,
      sym__type,
    STATE(15973), 1,
      sym_parameter_types,
    STATE(17792), 1,
      sym_stable_identifier,
    ACTIONS(1702), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1704), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1708), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3422), 2,
      sym_comment,
      sym_block_comment,
    STATE(9188), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9358), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10453), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13825), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6588), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7364), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123589] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16149), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3423), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123708] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17332), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3424), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123827] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16050), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3425), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [123946] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16170), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3426), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124065] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4530), 1,
      sym__alpha_identifier,
    ACTIONS(4532), 1,
      anon_sym_COLON,
    ACTIONS(4534), 1,
      anon_sym_LBRACE,
    ACTIONS(4536), 1,
      anon_sym__,
    ACTIONS(4540), 1,
      anon_sym_LBRACK,
    ACTIONS(4548), 1,
      sym__backquoted_id,
    ACTIONS(4552), 1,
      sym_integer_literal,
    ACTIONS(6524), 1,
      anon_sym_LPAREN,
    ACTIONS(6526), 1,
      sym_operator_identifier,
    STATE(5220), 1,
      sym__annotated_type,
    STATE(5311), 1,
      sym__simple_type,
    STATE(5882), 1,
      sym__soft_identifier,
    STATE(5987), 1,
      sym_identifier,
    STATE(8575), 1,
      sym_annotated_type,
    STATE(12867), 1,
      sym__infix_type_choice,
    STATE(13727), 1,
      sym__type,
    STATE(13856), 1,
      sym_template_body,
    STATE(13862), 1,
      sym__non_null_literal,
    STATE(15903), 1,
      sym_parameter_types,
    STATE(17666), 1,
      sym_stable_identifier,
    ACTIONS(4554), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4556), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4560), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3427), 2,
      sym_comment,
      sym_block_comment,
    STATE(10142), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13890), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13946), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13863), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4542), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6618), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124184] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4886), 1,
      sym__alpha_identifier,
    ACTIONS(4888), 1,
      anon_sym_COLON,
    ACTIONS(4890), 1,
      anon_sym_LBRACE,
    ACTIONS(4892), 1,
      anon_sym__,
    ACTIONS(4896), 1,
      anon_sym_LBRACK,
    ACTIONS(4904), 1,
      sym__backquoted_id,
    ACTIONS(4908), 1,
      sym_integer_literal,
    ACTIONS(6658), 1,
      anon_sym_LPAREN,
    ACTIONS(6660), 1,
      sym_operator_identifier,
    STATE(4668), 1,
      sym__simple_type,
    STATE(4690), 1,
      sym__annotated_type,
    STATE(5003), 1,
      sym_identifier,
    STATE(5087), 1,
      sym__soft_identifier,
    STATE(7155), 1,
      sym_annotated_type,
    STATE(12544), 1,
      sym__infix_type_choice,
    STATE(13158), 1,
      sym__type,
    STATE(13245), 1,
      sym_template_body,
    STATE(13295), 1,
      sym__non_null_literal,
    STATE(15364), 1,
      sym_parameter_types,
    STATE(17828), 1,
      sym_stable_identifier,
    ACTIONS(4910), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4912), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4914), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3428), 2,
      sym_comment,
      sym_block_comment,
    STATE(8990), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12950), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13007), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13299), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5448), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124303] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(15029), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3429), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124422] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1840), 1,
      sym_integer_literal,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6676), 1,
      sym__alpha_identifier,
    ACTIONS(6678), 1,
      anon_sym__,
    ACTIONS(6680), 1,
      anon_sym_LBRACK,
    ACTIONS(6684), 1,
      anon_sym_LPAREN,
    ACTIONS(6686), 1,
      sym__backquoted_id,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    STATE(6904), 1,
      sym__annotated_type,
    STATE(6998), 1,
      sym__simple_type,
    STATE(7765), 1,
      sym_identifier,
    STATE(7792), 1,
      sym__soft_identifier,
    STATE(10305), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12599), 1,
      sym__infix_type_choice,
    STATE(12713), 1,
      sym__type,
    STATE(16055), 1,
      sym_parameter_types,
    STATE(17582), 1,
      sym_stable_identifier,
    ACTIONS(1842), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1844), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1848), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3430), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6406), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11001), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6682), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8371), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124541] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11746), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3431), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124660] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11754), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3432), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124779] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11757), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3433), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [124898] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11760), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3434), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125017] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16062), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3435), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125136] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4886), 1,
      sym__alpha_identifier,
    ACTIONS(4888), 1,
      anon_sym_COLON,
    ACTIONS(4890), 1,
      anon_sym_LBRACE,
    ACTIONS(4892), 1,
      anon_sym__,
    ACTIONS(4896), 1,
      anon_sym_LBRACK,
    ACTIONS(4904), 1,
      sym__backquoted_id,
    ACTIONS(4908), 1,
      sym_integer_literal,
    ACTIONS(6658), 1,
      anon_sym_LPAREN,
    ACTIONS(6660), 1,
      sym_operator_identifier,
    STATE(4668), 1,
      sym__simple_type,
    STATE(4690), 1,
      sym__annotated_type,
    STATE(5003), 1,
      sym_identifier,
    STATE(5087), 1,
      sym__soft_identifier,
    STATE(7155), 1,
      sym_annotated_type,
    STATE(12544), 1,
      sym__infix_type_choice,
    STATE(13154), 1,
      sym__type,
    STATE(13245), 1,
      sym_template_body,
    STATE(13295), 1,
      sym__non_null_literal,
    STATE(15364), 1,
      sym_parameter_types,
    STATE(17828), 1,
      sym_stable_identifier,
    ACTIONS(4910), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4912), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4914), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3436), 2,
      sym_comment,
      sym_block_comment,
    STATE(8990), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12950), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13007), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13299), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5448), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125255] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16724), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3437), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125374] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1840), 1,
      sym_integer_literal,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6428), 1,
      anon_sym_LBRACK,
    ACTIONS(6432), 1,
      anon_sym_LPAREN,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    STATE(4728), 1,
      sym__annotated_type,
    STATE(4796), 1,
      sym__simple_type,
    STATE(4977), 1,
      sym_identifier,
    STATE(5072), 1,
      sym__soft_identifier,
    STATE(7069), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12351), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12702), 1,
      sym__infix_type_choice,
    STATE(16108), 1,
      sym_parameter_types,
    STATE(17635), 1,
      sym_stable_identifier,
    ACTIONS(1842), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1844), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1848), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3438), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6406), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9368), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5463), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125493] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16364), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3439), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125612] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4886), 1,
      sym__alpha_identifier,
    ACTIONS(4888), 1,
      anon_sym_COLON,
    ACTIONS(4890), 1,
      anon_sym_LBRACE,
    ACTIONS(4892), 1,
      anon_sym__,
    ACTIONS(4896), 1,
      anon_sym_LBRACK,
    ACTIONS(4904), 1,
      sym__backquoted_id,
    ACTIONS(4908), 1,
      sym_integer_literal,
    ACTIONS(6658), 1,
      anon_sym_LPAREN,
    ACTIONS(6660), 1,
      sym_operator_identifier,
    STATE(4668), 1,
      sym__simple_type,
    STATE(4690), 1,
      sym__annotated_type,
    STATE(5003), 1,
      sym_identifier,
    STATE(5087), 1,
      sym__soft_identifier,
    STATE(7155), 1,
      sym_annotated_type,
    STATE(12544), 1,
      sym__infix_type_choice,
    STATE(13059), 1,
      sym__type,
    STATE(13245), 1,
      sym_template_body,
    STATE(13295), 1,
      sym__non_null_literal,
    STATE(15364), 1,
      sym_parameter_types,
    STATE(17828), 1,
      sym_stable_identifier,
    ACTIONS(4910), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4912), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4914), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3440), 2,
      sym_comment,
      sym_block_comment,
    STATE(8990), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12950), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13007), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13299), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5448), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125731] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16165), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3441), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125850] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(14787), 1,
      sym__type,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3442), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [125969] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4530), 1,
      sym__alpha_identifier,
    ACTIONS(4532), 1,
      anon_sym_COLON,
    ACTIONS(4534), 1,
      anon_sym_LBRACE,
    ACTIONS(4536), 1,
      anon_sym__,
    ACTIONS(4540), 1,
      anon_sym_LBRACK,
    ACTIONS(4548), 1,
      sym__backquoted_id,
    ACTIONS(4552), 1,
      sym_integer_literal,
    ACTIONS(6524), 1,
      anon_sym_LPAREN,
    ACTIONS(6526), 1,
      sym_operator_identifier,
    STATE(5220), 1,
      sym__annotated_type,
    STATE(5311), 1,
      sym__simple_type,
    STATE(5882), 1,
      sym__soft_identifier,
    STATE(5987), 1,
      sym_identifier,
    STATE(8575), 1,
      sym_annotated_type,
    STATE(12867), 1,
      sym__infix_type_choice,
    STATE(13853), 1,
      sym__type,
    STATE(13856), 1,
      sym_template_body,
    STATE(13862), 1,
      sym__non_null_literal,
    STATE(15903), 1,
      sym_parameter_types,
    STATE(17666), 1,
      sym_stable_identifier,
    ACTIONS(4554), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4556), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4560), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3443), 2,
      sym_comment,
      sym_block_comment,
    STATE(10142), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13890), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13946), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13863), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4542), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6618), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126088] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17585), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3444), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126207] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15590), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3445), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126326] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4390), 1,
      sym__alpha_identifier,
    ACTIONS(4392), 1,
      anon_sym_COLON,
    ACTIONS(4394), 1,
      anon_sym_LBRACE,
    ACTIONS(4396), 1,
      anon_sym__,
    ACTIONS(4400), 1,
      anon_sym_LBRACK,
    ACTIONS(4408), 1,
      sym__backquoted_id,
    ACTIONS(4412), 1,
      sym_integer_literal,
    ACTIONS(6690), 1,
      anon_sym_LPAREN,
    ACTIONS(6692), 1,
      sym_operator_identifier,
    STATE(6561), 1,
      sym__simple_type,
    STATE(6771), 1,
      sym__annotated_type,
    STATE(7208), 1,
      sym__soft_identifier,
    STATE(7259), 1,
      sym_identifier,
    STATE(9943), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12310), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12623), 1,
      sym__infix_type_choice,
    STATE(16087), 1,
      sym_parameter_types,
    STATE(17606), 1,
      sym_stable_identifier,
    ACTIONS(4414), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4416), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3446), 2,
      sym_comment,
      sym_block_comment,
    STATE(10756), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12316), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12382), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4402), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8276), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126445] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15589), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3447), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126564] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4530), 1,
      sym__alpha_identifier,
    ACTIONS(4532), 1,
      anon_sym_COLON,
    ACTIONS(4534), 1,
      anon_sym_LBRACE,
    ACTIONS(4536), 1,
      anon_sym__,
    ACTIONS(4540), 1,
      anon_sym_LBRACK,
    ACTIONS(4548), 1,
      sym__backquoted_id,
    ACTIONS(4552), 1,
      sym_integer_literal,
    ACTIONS(6524), 1,
      anon_sym_LPAREN,
    ACTIONS(6526), 1,
      sym_operator_identifier,
    STATE(5220), 1,
      sym__annotated_type,
    STATE(5311), 1,
      sym__simple_type,
    STATE(5882), 1,
      sym__soft_identifier,
    STATE(5987), 1,
      sym_identifier,
    STATE(8575), 1,
      sym_annotated_type,
    STATE(12867), 1,
      sym__infix_type_choice,
    STATE(13741), 1,
      sym__type,
    STATE(13856), 1,
      sym_template_body,
    STATE(13862), 1,
      sym__non_null_literal,
    STATE(15903), 1,
      sym_parameter_types,
    STATE(17666), 1,
      sym_stable_identifier,
    ACTIONS(4554), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4556), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4560), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3448), 2,
      sym_comment,
      sym_block_comment,
    STATE(10142), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13890), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13946), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13863), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4542), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6618), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126683] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4886), 1,
      sym__alpha_identifier,
    ACTIONS(4888), 1,
      anon_sym_COLON,
    ACTIONS(4890), 1,
      anon_sym_LBRACE,
    ACTIONS(4892), 1,
      anon_sym__,
    ACTIONS(4896), 1,
      anon_sym_LBRACK,
    ACTIONS(4904), 1,
      sym__backquoted_id,
    ACTIONS(4908), 1,
      sym_integer_literal,
    ACTIONS(6658), 1,
      anon_sym_LPAREN,
    ACTIONS(6660), 1,
      sym_operator_identifier,
    STATE(4668), 1,
      sym__simple_type,
    STATE(4690), 1,
      sym__annotated_type,
    STATE(5003), 1,
      sym_identifier,
    STATE(5087), 1,
      sym__soft_identifier,
    STATE(7155), 1,
      sym_annotated_type,
    STATE(12544), 1,
      sym__infix_type_choice,
    STATE(13143), 1,
      sym__type,
    STATE(13245), 1,
      sym_template_body,
    STATE(13295), 1,
      sym__non_null_literal,
    STATE(15364), 1,
      sym_parameter_types,
    STATE(17828), 1,
      sym_stable_identifier,
    ACTIONS(4910), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4912), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4914), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3449), 2,
      sym_comment,
      sym_block_comment,
    STATE(8990), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12950), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13007), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13299), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5448), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126802] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15250), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3450), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [126921] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17189), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3451), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127040] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4390), 1,
      sym__alpha_identifier,
    ACTIONS(4392), 1,
      anon_sym_COLON,
    ACTIONS(4394), 1,
      anon_sym_LBRACE,
    ACTIONS(4396), 1,
      anon_sym__,
    ACTIONS(4400), 1,
      anon_sym_LBRACK,
    ACTIONS(4408), 1,
      sym__backquoted_id,
    ACTIONS(4412), 1,
      sym_integer_literal,
    ACTIONS(6690), 1,
      anon_sym_LPAREN,
    ACTIONS(6692), 1,
      sym_operator_identifier,
    STATE(6561), 1,
      sym__simple_type,
    STATE(6771), 1,
      sym__annotated_type,
    STATE(7208), 1,
      sym__soft_identifier,
    STATE(7259), 1,
      sym_identifier,
    STATE(9943), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12314), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12623), 1,
      sym__infix_type_choice,
    STATE(16087), 1,
      sym_parameter_types,
    STATE(17606), 1,
      sym_stable_identifier,
    ACTIONS(4414), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4416), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3452), 2,
      sym_comment,
      sym_block_comment,
    STATE(10756), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12316), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12382), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4402), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8276), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127159] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4370), 1,
      anon_sym_LBRACK,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(4936), 1,
      anon_sym_LPAREN,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    STATE(6044), 1,
      sym__annotated_type,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(11762), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12712), 1,
      sym__infix_type_choice,
    STATE(16068), 1,
      sym_parameter_types,
    STATE(16887), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3453), 2,
      sym_comment,
      sym_block_comment,
    STATE(10437), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127278] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4390), 1,
      sym__alpha_identifier,
    ACTIONS(4392), 1,
      anon_sym_COLON,
    ACTIONS(4394), 1,
      anon_sym_LBRACE,
    ACTIONS(4396), 1,
      anon_sym__,
    ACTIONS(4400), 1,
      anon_sym_LBRACK,
    ACTIONS(4408), 1,
      sym__backquoted_id,
    ACTIONS(4412), 1,
      sym_integer_literal,
    ACTIONS(6690), 1,
      anon_sym_LPAREN,
    ACTIONS(6692), 1,
      sym_operator_identifier,
    STATE(6561), 1,
      sym__simple_type,
    STATE(6771), 1,
      sym__annotated_type,
    STATE(7208), 1,
      sym__soft_identifier,
    STATE(7259), 1,
      sym_identifier,
    STATE(9943), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12315), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12623), 1,
      sym__infix_type_choice,
    STATE(16087), 1,
      sym_parameter_types,
    STATE(17606), 1,
      sym_stable_identifier,
    ACTIONS(4414), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4416), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3454), 2,
      sym_comment,
      sym_block_comment,
    STATE(10756), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12316), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12382), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4402), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8276), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127397] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16081), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3455), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127516] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5126), 1,
      anon_sym_LBRACK,
    ACTIONS(5130), 1,
      anon_sym_LPAREN,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(7980), 1,
      sym__annotated_type,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(11762), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12926), 1,
      sym__infix_type_choice,
    STATE(16191), 1,
      sym_parameter_types,
    STATE(17050), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3456), 2,
      sym_comment,
      sym_block_comment,
    STATE(11247), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127635] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17186), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3457), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127754] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4390), 1,
      sym__alpha_identifier,
    ACTIONS(4392), 1,
      anon_sym_COLON,
    ACTIONS(4394), 1,
      anon_sym_LBRACE,
    ACTIONS(4396), 1,
      anon_sym__,
    ACTIONS(4400), 1,
      anon_sym_LBRACK,
    ACTIONS(4408), 1,
      sym__backquoted_id,
    ACTIONS(4412), 1,
      sym_integer_literal,
    ACTIONS(6690), 1,
      anon_sym_LPAREN,
    ACTIONS(6692), 1,
      sym_operator_identifier,
    STATE(6561), 1,
      sym__simple_type,
    STATE(6771), 1,
      sym__annotated_type,
    STATE(7208), 1,
      sym__soft_identifier,
    STATE(7259), 1,
      sym_identifier,
    STATE(9943), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12325), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12623), 1,
      sym__infix_type_choice,
    STATE(16087), 1,
      sym_parameter_types,
    STATE(17606), 1,
      sym_stable_identifier,
    ACTIONS(4414), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4416), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3458), 2,
      sym_comment,
      sym_block_comment,
    STATE(10756), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12316), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12382), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4402), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8276), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127873] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15572), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3459), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [127992] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15571), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3460), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128111] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16085), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3461), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128230] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15837), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3462), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128349] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4310), 1,
      sym__alpha_identifier,
    ACTIONS(4312), 1,
      anon_sym_COLON,
    ACTIONS(4314), 1,
      anon_sym_LBRACE,
    ACTIONS(4316), 1,
      anon_sym__,
    ACTIONS(4320), 1,
      anon_sym_LBRACK,
    ACTIONS(4328), 1,
      sym__backquoted_id,
    ACTIONS(4332), 1,
      sym_integer_literal,
    ACTIONS(6694), 1,
      anon_sym_LPAREN,
    ACTIONS(6696), 1,
      sym_operator_identifier,
    STATE(4681), 1,
      sym__annotated_type,
    STATE(4737), 1,
      sym__simple_type,
    STATE(4906), 1,
      sym_identifier,
    STATE(5094), 1,
      sym__soft_identifier,
    STATE(6999), 1,
      sym_annotated_type,
    STATE(12671), 1,
      sym__infix_type_choice,
    STATE(13093), 1,
      sym__non_null_literal,
    STATE(13267), 1,
      sym__type,
    STATE(13398), 1,
      sym_template_body,
    STATE(15716), 1,
      sym_parameter_types,
    STATE(17786), 1,
      sym_stable_identifier,
    ACTIONS(4334), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4336), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4340), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3463), 2,
      sym_comment,
      sym_block_comment,
    STATE(9572), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12958), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13360), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13091), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5293), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128468] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12241), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3464), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128587] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15554), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3465), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128706] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16122), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3466), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128825] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17583), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3467), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [128944] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15553), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3468), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129063] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16171), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3469), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129182] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15832), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3470), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129301] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1362), 1,
      sym_integer_literal,
    ACTIONS(6542), 1,
      sym__alpha_identifier,
    ACTIONS(6544), 1,
      anon_sym_COLON,
    ACTIONS(6546), 1,
      anon_sym_LBRACE,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6550), 1,
      anon_sym_LBRACK,
    ACTIONS(6554), 1,
      anon_sym_LPAREN,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    STATE(5249), 1,
      sym__simple_type,
    STATE(5454), 1,
      sym__annotated_type,
    STATE(5780), 1,
      sym__soft_identifier,
    STATE(5982), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(12495), 1,
      sym__infix_type_choice,
    STATE(13419), 1,
      sym__non_null_literal,
    STATE(13518), 1,
      sym__type,
    STATE(13569), 1,
      sym_template_body,
    STATE(15978), 1,
      sym_parameter_types,
    STATE(17900), 1,
      sym_stable_identifier,
    ACTIONS(1364), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1366), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1370), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3471), 2,
      sym_comment,
      sym_block_comment,
    STATE(8349), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10071), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13410), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6174), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129420] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11762), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3472), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129539] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16215), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3473), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129658] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15536), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3474), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129777] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15535), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3475), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [129896] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15828), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3476), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130015] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    ACTIONS(6522), 1,
      anon_sym_LBRACK,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7325), 1,
      sym__annotated_type,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12504), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13388), 1,
      sym__type,
    STATE(16054), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3477), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130134] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16348), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3478), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130253] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4530), 1,
      sym__alpha_identifier,
    ACTIONS(4532), 1,
      anon_sym_COLON,
    ACTIONS(4534), 1,
      anon_sym_LBRACE,
    ACTIONS(4536), 1,
      anon_sym__,
    ACTIONS(4540), 1,
      anon_sym_LBRACK,
    ACTIONS(4548), 1,
      sym__backquoted_id,
    ACTIONS(4552), 1,
      sym_integer_literal,
    ACTIONS(6524), 1,
      anon_sym_LPAREN,
    ACTIONS(6526), 1,
      sym_operator_identifier,
    STATE(5220), 1,
      sym__annotated_type,
    STATE(5311), 1,
      sym__simple_type,
    STATE(5882), 1,
      sym__soft_identifier,
    STATE(5987), 1,
      sym_identifier,
    STATE(8575), 1,
      sym_annotated_type,
    STATE(12867), 1,
      sym__infix_type_choice,
    STATE(13856), 1,
      sym_template_body,
    STATE(13862), 1,
      sym__non_null_literal,
    STATE(14016), 1,
      sym__type,
    STATE(15903), 1,
      sym_parameter_types,
    STATE(17666), 1,
      sym_stable_identifier,
    ACTIONS(4554), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4556), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4560), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3479), 2,
      sym_comment,
      sym_block_comment,
    STATE(10142), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13890), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13946), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13863), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4542), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6618), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130372] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15824), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3480), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130491] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15518), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3481), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130610] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15468), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3482), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130729] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16237), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3483), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130848] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(14238), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3484), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [130967] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16116), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3485), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131086] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1154), 1,
      sym_integer_literal,
    ACTIONS(6698), 1,
      sym__alpha_identifier,
    ACTIONS(6700), 1,
      anon_sym_COLON,
    ACTIONS(6702), 1,
      anon_sym_LBRACE,
    ACTIONS(6704), 1,
      anon_sym__,
    ACTIONS(6706), 1,
      anon_sym_LBRACK,
    ACTIONS(6710), 1,
      anon_sym_LPAREN,
    ACTIONS(6712), 1,
      sym__backquoted_id,
    ACTIONS(6714), 1,
      sym_operator_identifier,
    STATE(4911), 1,
      sym__annotated_type,
    STATE(4994), 1,
      sym__simple_type,
    STATE(5215), 1,
      sym__soft_identifier,
    STATE(5482), 1,
      sym_identifier,
    STATE(7805), 1,
      sym_annotated_type,
    STATE(12523), 1,
      sym__infix_type_choice,
    STATE(13093), 1,
      sym__non_null_literal,
    STATE(13267), 1,
      sym__type,
    STATE(13398), 1,
      sym_template_body,
    STATE(15974), 1,
      sym_parameter_types,
    STATE(17840), 1,
      sym_stable_identifier,
    ACTIONS(1156), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1158), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1162), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3486), 2,
      sym_comment,
      sym_block_comment,
    STATE(7810), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7970), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9980), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13091), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6708), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5743), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131205] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15544), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3487), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131324] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    ACTIONS(6522), 1,
      anon_sym_LBRACK,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7325), 1,
      sym__annotated_type,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12504), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13382), 1,
      sym__type,
    STATE(16054), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3488), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131443] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6716), 1,
      sym__alpha_identifier,
    ACTIONS(6718), 1,
      anon_sym_COLON,
    ACTIONS(6720), 1,
      anon_sym_LBRACE,
    ACTIONS(6722), 1,
      anon_sym__,
    ACTIONS(6724), 1,
      anon_sym_LBRACK,
    ACTIONS(6728), 1,
      anon_sym_LPAREN,
    ACTIONS(6730), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6264), 1,
      sym__annotated_type,
    STATE(6329), 1,
      sym_identifier,
    STATE(6457), 1,
      sym__soft_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(9719), 1,
      sym_annotated_type,
    STATE(11246), 1,
      sym__type,
    STATE(12746), 1,
      sym__infix_type_choice,
    STATE(15884), 1,
      sym_parameter_types,
    STATE(17539), 1,
      sym_stable_identifier,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3489), 2,
      sym_comment,
      sym_block_comment,
    STATE(10409), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11285), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6726), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7381), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131562] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17339), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3490), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131681] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15820), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3491), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131800] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15816), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3492), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [131919] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15500), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3493), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132038] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4246), 1,
      sym__alpha_identifier,
    ACTIONS(4248), 1,
      anon_sym_COLON,
    ACTIONS(4250), 1,
      anon_sym_LBRACE,
    ACTIONS(4252), 1,
      anon_sym__,
    ACTIONS(4256), 1,
      anon_sym_LBRACK,
    ACTIONS(4264), 1,
      sym__backquoted_id,
    ACTIONS(4268), 1,
      sym_integer_literal,
    ACTIONS(6742), 1,
      anon_sym_LPAREN,
    ACTIONS(6744), 1,
      sym_operator_identifier,
    STATE(4954), 1,
      sym__annotated_type,
    STATE(5071), 1,
      sym__simple_type,
    STATE(5208), 1,
      sym__soft_identifier,
    STATE(5307), 1,
      sym_identifier,
    STATE(7704), 1,
      sym_annotated_type,
    STATE(12480), 1,
      sym__infix_type_choice,
    STATE(13419), 1,
      sym__non_null_literal,
    STATE(13518), 1,
      sym__type,
    STATE(13569), 1,
      sym_template_body,
    STATE(15629), 1,
      sym_parameter_types,
    STATE(17894), 1,
      sym_stable_identifier,
    ACTIONS(4270), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4272), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3494), 2,
      sym_comment,
      sym_block_comment,
    STATE(9633), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13603), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13681), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13410), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4258), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5976), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132157] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15499), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3495), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132276] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5126), 1,
      anon_sym_LBRACK,
    ACTIONS(5130), 1,
      anon_sym_LPAREN,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(7980), 1,
      sym__annotated_type,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(11760), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12926), 1,
      sym__infix_type_choice,
    STATE(16191), 1,
      sym_parameter_types,
    STATE(17050), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3496), 2,
      sym_comment,
      sym_block_comment,
    STATE(11247), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132395] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5126), 1,
      anon_sym_LBRACK,
    ACTIONS(5130), 1,
      anon_sym_LPAREN,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(7980), 1,
      sym__annotated_type,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(11757), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12926), 1,
      sym__infix_type_choice,
    STATE(16191), 1,
      sym_parameter_types,
    STATE(17050), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3497), 2,
      sym_comment,
      sym_block_comment,
    STATE(11247), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132514] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15812), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3498), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132633] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5126), 1,
      anon_sym_LBRACK,
    ACTIONS(5130), 1,
      anon_sym_LPAREN,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(7980), 1,
      sym__annotated_type,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(11754), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12926), 1,
      sym__infix_type_choice,
    STATE(16191), 1,
      sym_parameter_types,
    STATE(17050), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3499), 2,
      sym_comment,
      sym_block_comment,
    STATE(11247), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132752] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15808), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3500), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132871] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15804), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3501), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [132990] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5126), 1,
      anon_sym_LBRACK,
    ACTIONS(5130), 1,
      anon_sym_LPAREN,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(7980), 1,
      sym__annotated_type,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(11746), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12926), 1,
      sym__infix_type_choice,
    STATE(16191), 1,
      sym_parameter_types,
    STATE(17050), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3502), 2,
      sym_comment,
      sym_block_comment,
    STATE(11247), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133109] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11760), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3503), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133228] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__alpha_identifier,
    ACTIONS(4464), 1,
      anon_sym_COLON,
    ACTIONS(4466), 1,
      anon_sym_LBRACE,
    ACTIONS(4468), 1,
      anon_sym__,
    ACTIONS(4472), 1,
      anon_sym_LBRACK,
    ACTIONS(4480), 1,
      sym__backquoted_id,
    ACTIONS(4484), 1,
      sym_integer_literal,
    ACTIONS(6746), 1,
      anon_sym_LPAREN,
    ACTIONS(6748), 1,
      sym_operator_identifier,
    STATE(5016), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym__annotated_type,
    STATE(5231), 1,
      sym_identifier,
    STATE(5328), 1,
      sym__soft_identifier,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(12644), 1,
      sym__infix_type_choice,
    STATE(13584), 1,
      sym__type,
    STATE(13626), 1,
      sym_template_body,
    STATE(13664), 1,
      sym__non_null_literal,
    STATE(16353), 1,
      sym_parameter_types,
    STATE(17379), 1,
      sym_stable_identifier,
    ACTIONS(4486), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4488), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4492), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3504), 2,
      sym_comment,
      sym_block_comment,
    STATE(9743), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13536), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13680), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13674), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6029), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133347] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11757), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3505), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133466] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11754), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3506), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133585] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__alpha_identifier,
    ACTIONS(4464), 1,
      anon_sym_COLON,
    ACTIONS(4466), 1,
      anon_sym_LBRACE,
    ACTIONS(4468), 1,
      anon_sym__,
    ACTIONS(4472), 1,
      anon_sym_LBRACK,
    ACTIONS(4480), 1,
      sym__backquoted_id,
    ACTIONS(4484), 1,
      sym_integer_literal,
    ACTIONS(6746), 1,
      anon_sym_LPAREN,
    ACTIONS(6748), 1,
      sym_operator_identifier,
    STATE(5016), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym__annotated_type,
    STATE(5231), 1,
      sym_identifier,
    STATE(5328), 1,
      sym__soft_identifier,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(12644), 1,
      sym__infix_type_choice,
    STATE(13587), 1,
      sym__type,
    STATE(13626), 1,
      sym_template_body,
    STATE(13664), 1,
      sym__non_null_literal,
    STATE(16353), 1,
      sym_parameter_types,
    STATE(17379), 1,
      sym_stable_identifier,
    ACTIONS(4486), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4488), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4492), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3507), 2,
      sym_comment,
      sym_block_comment,
    STATE(9743), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13536), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13680), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13674), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6029), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133704] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16292), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3508), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133823] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(14380), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3509), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [133942] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4214), 1,
      sym__alpha_identifier,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4220), 1,
      anon_sym__,
    ACTIONS(4224), 1,
      anon_sym_LBRACK,
    ACTIONS(4232), 1,
      sym__backquoted_id,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6750), 1,
      anon_sym_LPAREN,
    ACTIONS(6752), 1,
      sym_operator_identifier,
    STATE(4653), 1,
      sym__simple_type,
    STATE(4660), 1,
      sym__annotated_type,
    STATE(4914), 1,
      sym_identifier,
    STATE(5031), 1,
      sym__soft_identifier,
    STATE(6990), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11611), 1,
      sym__type,
    STATE(12467), 1,
      sym__infix_type_choice,
    STATE(15959), 1,
      sym_parameter_types,
    STATE(17054), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3510), 2,
      sym_comment,
      sym_block_comment,
    STATE(9362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4226), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5167), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134061] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4214), 1,
      sym__alpha_identifier,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4220), 1,
      anon_sym__,
    ACTIONS(4224), 1,
      anon_sym_LBRACK,
    ACTIONS(4232), 1,
      sym__backquoted_id,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6750), 1,
      anon_sym_LPAREN,
    ACTIONS(6752), 1,
      sym_operator_identifier,
    STATE(4653), 1,
      sym__simple_type,
    STATE(4660), 1,
      sym__annotated_type,
    STATE(4914), 1,
      sym_identifier,
    STATE(5031), 1,
      sym__soft_identifier,
    STATE(6990), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11613), 1,
      sym__type,
    STATE(12467), 1,
      sym__infix_type_choice,
    STATE(15959), 1,
      sym_parameter_types,
    STATE(17054), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3511), 2,
      sym_comment,
      sym_block_comment,
    STATE(9362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4226), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5167), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134180] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11746), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3512), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134299] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4214), 1,
      sym__alpha_identifier,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4220), 1,
      anon_sym__,
    ACTIONS(4224), 1,
      anon_sym_LBRACK,
    ACTIONS(4232), 1,
      sym__backquoted_id,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6750), 1,
      anon_sym_LPAREN,
    ACTIONS(6752), 1,
      sym_operator_identifier,
    STATE(4653), 1,
      sym__simple_type,
    STATE(4660), 1,
      sym__annotated_type,
    STATE(4914), 1,
      sym_identifier,
    STATE(5031), 1,
      sym__soft_identifier,
    STATE(6990), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11623), 1,
      sym__type,
    STATE(12467), 1,
      sym__infix_type_choice,
    STATE(15959), 1,
      sym_parameter_types,
    STATE(17054), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3513), 2,
      sym_comment,
      sym_block_comment,
    STATE(9362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4226), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5167), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134418] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4214), 1,
      sym__alpha_identifier,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4220), 1,
      anon_sym__,
    ACTIONS(4224), 1,
      anon_sym_LBRACK,
    ACTIONS(4232), 1,
      sym__backquoted_id,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6750), 1,
      anon_sym_LPAREN,
    ACTIONS(6752), 1,
      sym_operator_identifier,
    STATE(4653), 1,
      sym__simple_type,
    STATE(4660), 1,
      sym__annotated_type,
    STATE(4914), 1,
      sym_identifier,
    STATE(5031), 1,
      sym__soft_identifier,
    STATE(6990), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11637), 1,
      sym__type,
    STATE(12467), 1,
      sym__infix_type_choice,
    STATE(15959), 1,
      sym_parameter_types,
    STATE(17054), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3514), 2,
      sym_comment,
      sym_block_comment,
    STATE(9362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4226), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5167), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134537] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2106), 1,
      sym_integer_literal,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(6754), 1,
      sym__alpha_identifier,
    ACTIONS(6756), 1,
      anon_sym__,
    ACTIONS(6758), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_LPAREN,
    ACTIONS(6764), 1,
      sym__backquoted_id,
    ACTIONS(6766), 1,
      sym_operator_identifier,
    STATE(4748), 1,
      sym__simple_type,
    STATE(4761), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym_identifier,
    STATE(4998), 1,
      sym__soft_identifier,
    STATE(6891), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12756), 1,
      sym__infix_type_choice,
    STATE(12921), 1,
      sym__type,
    STATE(16110), 1,
      sym_parameter_types,
    STATE(17750), 1,
      sym_stable_identifier,
    ACTIONS(2108), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2110), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2114), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3515), 2,
      sym_comment,
      sym_block_comment,
    STATE(6362), 2,
      sym_boolean_literal,
      sym_string,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9042), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6760), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134656] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16307), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3516), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134775] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1362), 1,
      sym_integer_literal,
    ACTIONS(6542), 1,
      sym__alpha_identifier,
    ACTIONS(6544), 1,
      anon_sym_COLON,
    ACTIONS(6546), 1,
      anon_sym_LBRACE,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6550), 1,
      anon_sym_LBRACK,
    ACTIONS(6554), 1,
      anon_sym_LPAREN,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    STATE(5249), 1,
      sym__simple_type,
    STATE(5454), 1,
      sym__annotated_type,
    STATE(5780), 1,
      sym__soft_identifier,
    STATE(5982), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(12495), 1,
      sym__infix_type_choice,
    STATE(13419), 1,
      sym__non_null_literal,
    STATE(13512), 1,
      sym__type,
    STATE(13569), 1,
      sym_template_body,
    STATE(15978), 1,
      sym_parameter_types,
    STATE(17900), 1,
      sym_stable_identifier,
    ACTIONS(1364), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1366), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1370), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3517), 2,
      sym_comment,
      sym_block_comment,
    STATE(8349), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10071), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13410), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6174), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [134894] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1362), 1,
      sym_integer_literal,
    ACTIONS(6542), 1,
      sym__alpha_identifier,
    ACTIONS(6544), 1,
      anon_sym_COLON,
    ACTIONS(6546), 1,
      anon_sym_LBRACE,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6550), 1,
      anon_sym_LBRACK,
    ACTIONS(6554), 1,
      anon_sym_LPAREN,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    STATE(5249), 1,
      sym__simple_type,
    STATE(5454), 1,
      sym__annotated_type,
    STATE(5780), 1,
      sym__soft_identifier,
    STATE(5982), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(12495), 1,
      sym__infix_type_choice,
    STATE(13419), 1,
      sym__non_null_literal,
    STATE(13503), 1,
      sym__type,
    STATE(13569), 1,
      sym_template_body,
    STATE(15978), 1,
      sym_parameter_types,
    STATE(17900), 1,
      sym_stable_identifier,
    ACTIONS(1364), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1366), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1370), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3518), 2,
      sym_comment,
      sym_block_comment,
    STATE(8349), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10071), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13410), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6174), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135013] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__alpha_identifier,
    ACTIONS(4464), 1,
      anon_sym_COLON,
    ACTIONS(4466), 1,
      anon_sym_LBRACE,
    ACTIONS(4468), 1,
      anon_sym__,
    ACTIONS(4472), 1,
      anon_sym_LBRACK,
    ACTIONS(4480), 1,
      sym__backquoted_id,
    ACTIONS(4484), 1,
      sym_integer_literal,
    ACTIONS(6746), 1,
      anon_sym_LPAREN,
    ACTIONS(6748), 1,
      sym_operator_identifier,
    STATE(5016), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym__annotated_type,
    STATE(5231), 1,
      sym_identifier,
    STATE(5328), 1,
      sym__soft_identifier,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(12644), 1,
      sym__infix_type_choice,
    STATE(13596), 1,
      sym__type,
    STATE(13626), 1,
      sym_template_body,
    STATE(13664), 1,
      sym__non_null_literal,
    STATE(16353), 1,
      sym_parameter_types,
    STATE(17379), 1,
      sym_stable_identifier,
    ACTIONS(4486), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4488), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4492), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3519), 2,
      sym_comment,
      sym_block_comment,
    STATE(9743), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13536), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13680), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13674), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6029), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135132] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4390), 1,
      sym__alpha_identifier,
    ACTIONS(4392), 1,
      anon_sym_COLON,
    ACTIONS(4394), 1,
      anon_sym_LBRACE,
    ACTIONS(4396), 1,
      anon_sym__,
    ACTIONS(4400), 1,
      anon_sym_LBRACK,
    ACTIONS(4408), 1,
      sym__backquoted_id,
    ACTIONS(4412), 1,
      sym_integer_literal,
    ACTIONS(6690), 1,
      anon_sym_LPAREN,
    ACTIONS(6692), 1,
      sym_operator_identifier,
    STATE(6561), 1,
      sym__simple_type,
    STATE(6771), 1,
      sym__annotated_type,
    STATE(7208), 1,
      sym__soft_identifier,
    STATE(7259), 1,
      sym_identifier,
    STATE(9943), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12349), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12623), 1,
      sym__infix_type_choice,
    STATE(16087), 1,
      sym_parameter_types,
    STATE(17606), 1,
      sym_stable_identifier,
    ACTIONS(4414), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4416), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4420), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3520), 2,
      sym_comment,
      sym_block_comment,
    STATE(10756), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12316), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12382), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4402), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8276), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135251] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15482), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3521), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135370] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15481), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3522), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135489] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4562), 1,
      sym__alpha_identifier,
    ACTIONS(4564), 1,
      anon_sym_COLON,
    ACTIONS(4566), 1,
      anon_sym_LBRACE,
    ACTIONS(4568), 1,
      anon_sym__,
    ACTIONS(4572), 1,
      anon_sym_LBRACK,
    ACTIONS(4580), 1,
      sym__backquoted_id,
    ACTIONS(4584), 1,
      sym_integer_literal,
    ACTIONS(6768), 1,
      anon_sym_LPAREN,
    ACTIONS(6770), 1,
      sym_operator_identifier,
    STATE(5229), 1,
      sym__annotated_type,
    STATE(5319), 1,
      sym__simple_type,
    STATE(5571), 1,
      sym_identifier,
    STATE(5868), 1,
      sym__soft_identifier,
    STATE(8394), 1,
      sym_annotated_type,
    STATE(12897), 1,
      sym__infix_type_choice,
    STATE(13794), 1,
      sym__non_null_literal,
    STATE(14022), 1,
      sym_template_body,
    STATE(14044), 1,
      sym__type,
    STATE(15778), 1,
      sym_parameter_types,
    STATE(17678), 1,
      sym_stable_identifier,
    ACTIONS(4586), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4588), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4592), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3523), 2,
      sym_comment,
      sym_block_comment,
    STATE(10204), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13758), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13993), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13825), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4574), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6389), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135608] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1362), 1,
      sym_integer_literal,
    ACTIONS(6542), 1,
      sym__alpha_identifier,
    ACTIONS(6544), 1,
      anon_sym_COLON,
    ACTIONS(6546), 1,
      anon_sym_LBRACE,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6550), 1,
      anon_sym_LBRACK,
    ACTIONS(6554), 1,
      anon_sym_LPAREN,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    STATE(5249), 1,
      sym__simple_type,
    STATE(5454), 1,
      sym__annotated_type,
    STATE(5780), 1,
      sym__soft_identifier,
    STATE(5982), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(12495), 1,
      sym__infix_type_choice,
    STATE(13419), 1,
      sym__non_null_literal,
    STATE(13569), 1,
      sym_template_body,
    STATE(13634), 1,
      sym__type,
    STATE(15978), 1,
      sym_parameter_types,
    STATE(17900), 1,
      sym_stable_identifier,
    ACTIONS(1364), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1366), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1370), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3524), 2,
      sym_comment,
      sym_block_comment,
    STATE(8349), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10071), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13410), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6174), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135727] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15442), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3525), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135846] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__alpha_identifier,
    ACTIONS(4464), 1,
      anon_sym_COLON,
    ACTIONS(4466), 1,
      anon_sym_LBRACE,
    ACTIONS(4468), 1,
      anon_sym__,
    ACTIONS(4472), 1,
      anon_sym_LBRACK,
    ACTIONS(4480), 1,
      sym__backquoted_id,
    ACTIONS(4484), 1,
      sym_integer_literal,
    ACTIONS(6746), 1,
      anon_sym_LPAREN,
    ACTIONS(6748), 1,
      sym_operator_identifier,
    STATE(5016), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym__annotated_type,
    STATE(5231), 1,
      sym_identifier,
    STATE(5328), 1,
      sym__soft_identifier,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(12644), 1,
      sym__infix_type_choice,
    STATE(13563), 1,
      sym__type,
    STATE(13626), 1,
      sym_template_body,
    STATE(13664), 1,
      sym__non_null_literal,
    STATE(16353), 1,
      sym_parameter_types,
    STATE(17379), 1,
      sym_stable_identifier,
    ACTIONS(4486), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4488), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4492), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3526), 2,
      sym_comment,
      sym_block_comment,
    STATE(9743), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13536), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13680), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13674), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6029), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [135965] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(15132), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3527), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136084] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4214), 1,
      sym__alpha_identifier,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4220), 1,
      anon_sym__,
    ACTIONS(4224), 1,
      anon_sym_LBRACK,
    ACTIONS(4232), 1,
      sym__backquoted_id,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6750), 1,
      anon_sym_LPAREN,
    ACTIONS(6752), 1,
      sym_operator_identifier,
    STATE(4653), 1,
      sym__simple_type,
    STATE(4660), 1,
      sym__annotated_type,
    STATE(4914), 1,
      sym_identifier,
    STATE(5031), 1,
      sym__soft_identifier,
    STATE(6990), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11699), 1,
      sym__type,
    STATE(12467), 1,
      sym__infix_type_choice,
    STATE(15959), 1,
      sym_parameter_types,
    STATE(17054), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3528), 2,
      sym_comment,
      sym_block_comment,
    STATE(9362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4226), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5167), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136203] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15800), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3529), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136322] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15796), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3530), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136441] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4562), 1,
      sym__alpha_identifier,
    ACTIONS(4564), 1,
      anon_sym_COLON,
    ACTIONS(4566), 1,
      anon_sym_LBRACE,
    ACTIONS(4568), 1,
      anon_sym__,
    ACTIONS(4572), 1,
      anon_sym_LBRACK,
    ACTIONS(4580), 1,
      sym__backquoted_id,
    ACTIONS(4584), 1,
      sym_integer_literal,
    ACTIONS(6768), 1,
      anon_sym_LPAREN,
    ACTIONS(6770), 1,
      sym_operator_identifier,
    STATE(5229), 1,
      sym__annotated_type,
    STATE(5319), 1,
      sym__simple_type,
    STATE(5571), 1,
      sym_identifier,
    STATE(5868), 1,
      sym__soft_identifier,
    STATE(8394), 1,
      sym_annotated_type,
    STATE(12897), 1,
      sym__infix_type_choice,
    STATE(13794), 1,
      sym__non_null_literal,
    STATE(14004), 1,
      sym__type,
    STATE(14022), 1,
      sym_template_body,
    STATE(15778), 1,
      sym_parameter_types,
    STATE(17678), 1,
      sym_stable_identifier,
    ACTIONS(4586), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4588), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4592), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3531), 2,
      sym_comment,
      sym_block_comment,
    STATE(10204), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13758), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13993), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13825), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4574), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6389), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136560] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15464), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3532), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136679] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1770), 1,
      sym_integer_literal,
    ACTIONS(6772), 1,
      sym__alpha_identifier,
    ACTIONS(6774), 1,
      anon_sym_COLON,
    ACTIONS(6776), 1,
      anon_sym_LBRACE,
    ACTIONS(6778), 1,
      anon_sym__,
    ACTIONS(6780), 1,
      anon_sym_LBRACK,
    ACTIONS(6784), 1,
      anon_sym_LPAREN,
    ACTIONS(6786), 1,
      sym__backquoted_id,
    ACTIONS(6788), 1,
      sym_operator_identifier,
    STATE(5792), 1,
      sym__annotated_type,
    STATE(5904), 1,
      sym__simple_type,
    STATE(6418), 1,
      sym__soft_identifier,
    STATE(6643), 1,
      sym_identifier,
    STATE(9119), 1,
      sym_annotated_type,
    STATE(12514), 1,
      sym__infix_type_choice,
    STATE(13874), 1,
      sym__non_null_literal,
    STATE(13912), 1,
      sym_template_body,
    STATE(14176), 1,
      sym__type,
    STATE(15975), 1,
      sym_parameter_types,
    STATE(17852), 1,
      sym_stable_identifier,
    ACTIONS(1772), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1774), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1778), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3533), 2,
      sym_comment,
      sym_block_comment,
    STATE(8992), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9101), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10612), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13869), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6782), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7485), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136798] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15463), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3534), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [136917] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4562), 1,
      sym__alpha_identifier,
    ACTIONS(4564), 1,
      anon_sym_COLON,
    ACTIONS(4566), 1,
      anon_sym_LBRACE,
    ACTIONS(4568), 1,
      anon_sym__,
    ACTIONS(4572), 1,
      anon_sym_LBRACK,
    ACTIONS(4580), 1,
      sym__backquoted_id,
    ACTIONS(4584), 1,
      sym_integer_literal,
    ACTIONS(6768), 1,
      anon_sym_LPAREN,
    ACTIONS(6770), 1,
      sym_operator_identifier,
    STATE(5229), 1,
      sym__annotated_type,
    STATE(5319), 1,
      sym__simple_type,
    STATE(5571), 1,
      sym_identifier,
    STATE(5868), 1,
      sym__soft_identifier,
    STATE(8394), 1,
      sym_annotated_type,
    STATE(12897), 1,
      sym__infix_type_choice,
    STATE(13794), 1,
      sym__non_null_literal,
    STATE(13937), 1,
      sym__type,
    STATE(14022), 1,
      sym_template_body,
    STATE(15778), 1,
      sym_parameter_types,
    STATE(17678), 1,
      sym_stable_identifier,
    ACTIONS(4586), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4588), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4592), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3535), 2,
      sym_comment,
      sym_block_comment,
    STATE(10204), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13758), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13993), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13825), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4574), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6389), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137036] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15792), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3536), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137155] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16758), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3537), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137274] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4562), 1,
      sym__alpha_identifier,
    ACTIONS(4564), 1,
      anon_sym_COLON,
    ACTIONS(4566), 1,
      anon_sym_LBRACE,
    ACTIONS(4568), 1,
      anon_sym__,
    ACTIONS(4572), 1,
      anon_sym_LBRACK,
    ACTIONS(4580), 1,
      sym__backquoted_id,
    ACTIONS(4584), 1,
      sym_integer_literal,
    ACTIONS(6768), 1,
      anon_sym_LPAREN,
    ACTIONS(6770), 1,
      sym_operator_identifier,
    STATE(5229), 1,
      sym__annotated_type,
    STATE(5319), 1,
      sym__simple_type,
    STATE(5571), 1,
      sym_identifier,
    STATE(5868), 1,
      sym__soft_identifier,
    STATE(8394), 1,
      sym_annotated_type,
    STATE(12897), 1,
      sym__infix_type_choice,
    STATE(13794), 1,
      sym__non_null_literal,
    STATE(13860), 1,
      sym__type,
    STATE(14022), 1,
      sym_template_body,
    STATE(15778), 1,
      sym_parameter_types,
    STATE(17678), 1,
      sym_stable_identifier,
    ACTIONS(4586), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4588), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4592), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3538), 2,
      sym_comment,
      sym_block_comment,
    STATE(10204), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13758), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13993), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13825), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4574), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6389), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137393] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15446), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3539), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137512] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1154), 1,
      sym_integer_literal,
    ACTIONS(6698), 1,
      sym__alpha_identifier,
    ACTIONS(6700), 1,
      anon_sym_COLON,
    ACTIONS(6702), 1,
      anon_sym_LBRACE,
    ACTIONS(6704), 1,
      anon_sym__,
    ACTIONS(6706), 1,
      anon_sym_LBRACK,
    ACTIONS(6710), 1,
      anon_sym_LPAREN,
    ACTIONS(6712), 1,
      sym__backquoted_id,
    ACTIONS(6714), 1,
      sym_operator_identifier,
    STATE(4911), 1,
      sym__annotated_type,
    STATE(4994), 1,
      sym__simple_type,
    STATE(5215), 1,
      sym__soft_identifier,
    STATE(5482), 1,
      sym_identifier,
    STATE(7805), 1,
      sym_annotated_type,
    STATE(12523), 1,
      sym__infix_type_choice,
    STATE(13093), 1,
      sym__non_null_literal,
    STATE(13175), 1,
      sym__type,
    STATE(13398), 1,
      sym_template_body,
    STATE(15974), 1,
      sym_parameter_types,
    STATE(17840), 1,
      sym_stable_identifier,
    ACTIONS(1156), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1158), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1162), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3540), 2,
      sym_comment,
      sym_block_comment,
    STATE(7810), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7970), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9980), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13091), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6708), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5743), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137631] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15445), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3541), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137750] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1154), 1,
      sym_integer_literal,
    ACTIONS(6698), 1,
      sym__alpha_identifier,
    ACTIONS(6700), 1,
      anon_sym_COLON,
    ACTIONS(6702), 1,
      anon_sym_LBRACE,
    ACTIONS(6704), 1,
      anon_sym__,
    ACTIONS(6706), 1,
      anon_sym_LBRACK,
    ACTIONS(6710), 1,
      anon_sym_LPAREN,
    ACTIONS(6712), 1,
      sym__backquoted_id,
    ACTIONS(6714), 1,
      sym_operator_identifier,
    STATE(4911), 1,
      sym__annotated_type,
    STATE(4994), 1,
      sym__simple_type,
    STATE(5215), 1,
      sym__soft_identifier,
    STATE(5482), 1,
      sym_identifier,
    STATE(7805), 1,
      sym_annotated_type,
    STATE(12523), 1,
      sym__infix_type_choice,
    STATE(13093), 1,
      sym__non_null_literal,
    STATE(13177), 1,
      sym__type,
    STATE(13398), 1,
      sym_template_body,
    STATE(15974), 1,
      sym_parameter_types,
    STATE(17840), 1,
      sym_stable_identifier,
    ACTIONS(1156), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1158), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1162), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3542), 2,
      sym_comment,
      sym_block_comment,
    STATE(7810), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7970), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9980), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13091), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6708), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5743), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137869] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15788), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3543), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [137988] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(17829), 1,
      sym__type,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3544), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138107] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1154), 1,
      sym_integer_literal,
    ACTIONS(6698), 1,
      sym__alpha_identifier,
    ACTIONS(6700), 1,
      anon_sym_COLON,
    ACTIONS(6702), 1,
      anon_sym_LBRACE,
    ACTIONS(6704), 1,
      anon_sym__,
    ACTIONS(6706), 1,
      anon_sym_LBRACK,
    ACTIONS(6710), 1,
      anon_sym_LPAREN,
    ACTIONS(6712), 1,
      sym__backquoted_id,
    ACTIONS(6714), 1,
      sym_operator_identifier,
    STATE(4911), 1,
      sym__annotated_type,
    STATE(4994), 1,
      sym__simple_type,
    STATE(5215), 1,
      sym__soft_identifier,
    STATE(5482), 1,
      sym_identifier,
    STATE(7805), 1,
      sym_annotated_type,
    STATE(12523), 1,
      sym__infix_type_choice,
    STATE(13093), 1,
      sym__non_null_literal,
    STATE(13178), 1,
      sym__type,
    STATE(13398), 1,
      sym_template_body,
    STATE(15974), 1,
      sym_parameter_types,
    STATE(17840), 1,
      sym_stable_identifier,
    ACTIONS(1156), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1158), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1162), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3545), 2,
      sym_comment,
      sym_block_comment,
    STATE(7810), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7970), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9980), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13091), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6708), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5743), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138226] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12181), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3546), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138345] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15428), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3547), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138464] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15427), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3548), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138583] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8584), 1,
      sym__type,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3549), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138702] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6792), 1,
      anon_sym_COLON,
    ACTIONS(6794), 1,
      anon_sym_LBRACE,
    ACTIONS(6796), 1,
      anon_sym__,
    ACTIONS(6798), 1,
      anon_sym_LBRACK,
    ACTIONS(6802), 1,
      anon_sym_LPAREN,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(6806), 1,
      sym_operator_identifier,
    ACTIONS(6808), 1,
      sym_integer_literal,
    STATE(5378), 1,
      sym__simple_type,
    STATE(5755), 1,
      sym_identifier,
    STATE(5860), 1,
      sym__annotated_type,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(9021), 1,
      sym_annotated_type,
    STATE(10969), 1,
      sym__non_null_literal,
    STATE(11087), 1,
      sym__type,
    STATE(11155), 1,
      sym_template_body,
    STATE(12851), 1,
      sym__infix_type_choice,
    STATE(16255), 1,
      sym_parameter_types,
    STATE(16984), 1,
      sym_stable_identifier,
    ACTIONS(6810), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6812), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6814), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3550), 2,
      sym_comment,
      sym_block_comment,
    STATE(10256), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10951), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11066), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10978), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138821] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16761), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3551), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [138940] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(17830), 1,
      sym__type,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3552), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139059] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15410), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3553), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139178] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15409), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3554), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139297] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12185), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3555), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139416] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1154), 1,
      sym_integer_literal,
    ACTIONS(6698), 1,
      sym__alpha_identifier,
    ACTIONS(6700), 1,
      anon_sym_COLON,
    ACTIONS(6702), 1,
      anon_sym_LBRACE,
    ACTIONS(6704), 1,
      anon_sym__,
    ACTIONS(6706), 1,
      anon_sym_LBRACK,
    ACTIONS(6710), 1,
      anon_sym_LPAREN,
    ACTIONS(6712), 1,
      sym__backquoted_id,
    ACTIONS(6714), 1,
      sym_operator_identifier,
    STATE(4911), 1,
      sym__annotated_type,
    STATE(4994), 1,
      sym__simple_type,
    STATE(5215), 1,
      sym__soft_identifier,
    STATE(5482), 1,
      sym_identifier,
    STATE(7805), 1,
      sym_annotated_type,
    STATE(12523), 1,
      sym__infix_type_choice,
    STATE(13093), 1,
      sym__non_null_literal,
    STATE(13179), 1,
      sym__type,
    STATE(13398), 1,
      sym_template_body,
    STATE(15974), 1,
      sym_parameter_types,
    STATE(17840), 1,
      sym_stable_identifier,
    ACTIONS(1156), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1158), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1162), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3556), 2,
      sym_comment,
      sym_block_comment,
    STATE(7810), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7970), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9980), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13091), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6708), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5743), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139535] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15539), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3557), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139654] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15784), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3558), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139773] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15392), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3559), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [139892] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15391), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3560), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140011] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1770), 1,
      sym_integer_literal,
    ACTIONS(6772), 1,
      sym__alpha_identifier,
    ACTIONS(6774), 1,
      anon_sym_COLON,
    ACTIONS(6776), 1,
      anon_sym_LBRACE,
    ACTIONS(6778), 1,
      anon_sym__,
    ACTIONS(6780), 1,
      anon_sym_LBRACK,
    ACTIONS(6784), 1,
      anon_sym_LPAREN,
    ACTIONS(6786), 1,
      sym__backquoted_id,
    ACTIONS(6788), 1,
      sym_operator_identifier,
    STATE(5792), 1,
      sym__annotated_type,
    STATE(5904), 1,
      sym__simple_type,
    STATE(6418), 1,
      sym__soft_identifier,
    STATE(6643), 1,
      sym_identifier,
    STATE(9119), 1,
      sym_annotated_type,
    STATE(12514), 1,
      sym__infix_type_choice,
    STATE(13799), 1,
      sym__type,
    STATE(13874), 1,
      sym__non_null_literal,
    STATE(13912), 1,
      sym_template_body,
    STATE(15975), 1,
      sym_parameter_types,
    STATE(17852), 1,
      sym_stable_identifier,
    ACTIONS(1772), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1774), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1778), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3561), 2,
      sym_comment,
      sym_block_comment,
    STATE(8992), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9101), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10612), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13869), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6782), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7485), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140130] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6792), 1,
      anon_sym_COLON,
    ACTIONS(6794), 1,
      anon_sym_LBRACE,
    ACTIONS(6796), 1,
      anon_sym__,
    ACTIONS(6798), 1,
      anon_sym_LBRACK,
    ACTIONS(6802), 1,
      anon_sym_LPAREN,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(6806), 1,
      sym_operator_identifier,
    ACTIONS(6808), 1,
      sym_integer_literal,
    STATE(5378), 1,
      sym__simple_type,
    STATE(5755), 1,
      sym_identifier,
    STATE(5860), 1,
      sym__annotated_type,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(9021), 1,
      sym_annotated_type,
    STATE(10969), 1,
      sym__non_null_literal,
    STATE(11101), 1,
      sym__type,
    STATE(11155), 1,
      sym_template_body,
    STATE(12851), 1,
      sym__infix_type_choice,
    STATE(16255), 1,
      sym_parameter_types,
    STATE(16984), 1,
      sym_stable_identifier,
    ACTIONS(6810), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6812), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6814), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3562), 2,
      sym_comment,
      sym_block_comment,
    STATE(10256), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10951), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11066), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10978), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140249] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6792), 1,
      anon_sym_COLON,
    ACTIONS(6794), 1,
      anon_sym_LBRACE,
    ACTIONS(6796), 1,
      anon_sym__,
    ACTIONS(6798), 1,
      anon_sym_LBRACK,
    ACTIONS(6802), 1,
      anon_sym_LPAREN,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(6806), 1,
      sym_operator_identifier,
    ACTIONS(6808), 1,
      sym_integer_literal,
    STATE(5378), 1,
      sym__simple_type,
    STATE(5755), 1,
      sym_identifier,
    STATE(5860), 1,
      sym__annotated_type,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(9021), 1,
      sym_annotated_type,
    STATE(10969), 1,
      sym__non_null_literal,
    STATE(11129), 1,
      sym__type,
    STATE(11155), 1,
      sym_template_body,
    STATE(12851), 1,
      sym__infix_type_choice,
    STATE(16255), 1,
      sym_parameter_types,
    STATE(16984), 1,
      sym_stable_identifier,
    ACTIONS(6810), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6812), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6814), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3563), 2,
      sym_comment,
      sym_block_comment,
    STATE(10256), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10951), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11066), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10978), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140368] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16138), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3564), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140487] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15780), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3565), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140606] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16144), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3566), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140725] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4562), 1,
      sym__alpha_identifier,
    ACTIONS(4564), 1,
      anon_sym_COLON,
    ACTIONS(4566), 1,
      anon_sym_LBRACE,
    ACTIONS(4568), 1,
      anon_sym__,
    ACTIONS(4572), 1,
      anon_sym_LBRACK,
    ACTIONS(4580), 1,
      sym__backquoted_id,
    ACTIONS(4584), 1,
      sym_integer_literal,
    ACTIONS(6768), 1,
      anon_sym_LPAREN,
    ACTIONS(6770), 1,
      sym_operator_identifier,
    STATE(5229), 1,
      sym__annotated_type,
    STATE(5319), 1,
      sym__simple_type,
    STATE(5571), 1,
      sym_identifier,
    STATE(5868), 1,
      sym__soft_identifier,
    STATE(8394), 1,
      sym_annotated_type,
    STATE(12897), 1,
      sym__infix_type_choice,
    STATE(13794), 1,
      sym__non_null_literal,
    STATE(14022), 1,
      sym_template_body,
    STATE(14028), 1,
      sym__type,
    STATE(15778), 1,
      sym_parameter_types,
    STATE(17678), 1,
      sym_stable_identifier,
    ACTIONS(4586), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4588), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4592), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3567), 2,
      sym_comment,
      sym_block_comment,
    STATE(10204), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13758), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13993), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13825), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4574), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6389), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140844] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15374), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3568), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [140963] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1840), 1,
      sym_integer_literal,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6676), 1,
      sym__alpha_identifier,
    ACTIONS(6678), 1,
      anon_sym__,
    ACTIONS(6680), 1,
      anon_sym_LBRACK,
    ACTIONS(6684), 1,
      anon_sym_LPAREN,
    ACTIONS(6686), 1,
      sym__backquoted_id,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    STATE(6904), 1,
      sym__annotated_type,
    STATE(6998), 1,
      sym__simple_type,
    STATE(7765), 1,
      sym_identifier,
    STATE(7792), 1,
      sym__soft_identifier,
    STATE(10305), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12343), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12599), 1,
      sym__infix_type_choice,
    STATE(16055), 1,
      sym_parameter_types,
    STATE(17582), 1,
      sym_stable_identifier,
    ACTIONS(1842), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1844), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1848), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3569), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6406), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11001), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6682), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8371), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141082] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1840), 1,
      sym_integer_literal,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6676), 1,
      sym__alpha_identifier,
    ACTIONS(6678), 1,
      anon_sym__,
    ACTIONS(6680), 1,
      anon_sym_LBRACK,
    ACTIONS(6684), 1,
      anon_sym_LPAREN,
    ACTIONS(6686), 1,
      sym__backquoted_id,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    STATE(6904), 1,
      sym__annotated_type,
    STATE(6998), 1,
      sym__simple_type,
    STATE(7765), 1,
      sym_identifier,
    STATE(7792), 1,
      sym__soft_identifier,
    STATE(10305), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12345), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12599), 1,
      sym__infix_type_choice,
    STATE(16055), 1,
      sym_parameter_types,
    STATE(17582), 1,
      sym_stable_identifier,
    ACTIONS(1842), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1844), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1848), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3570), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6406), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11001), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6682), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8371), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141201] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15373), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3571), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141320] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__alpha_identifier,
    ACTIONS(4464), 1,
      anon_sym_COLON,
    ACTIONS(4466), 1,
      anon_sym_LBRACE,
    ACTIONS(4468), 1,
      anon_sym__,
    ACTIONS(4472), 1,
      anon_sym_LBRACK,
    ACTIONS(4480), 1,
      sym__backquoted_id,
    ACTIONS(4484), 1,
      sym_integer_literal,
    ACTIONS(6746), 1,
      anon_sym_LPAREN,
    ACTIONS(6748), 1,
      sym_operator_identifier,
    STATE(5016), 1,
      sym__simple_type,
    STATE(5024), 1,
      sym__annotated_type,
    STATE(5231), 1,
      sym_identifier,
    STATE(5328), 1,
      sym__soft_identifier,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(12644), 1,
      sym__infix_type_choice,
    STATE(13608), 1,
      sym__type,
    STATE(13626), 1,
      sym_template_body,
    STATE(13664), 1,
      sym__non_null_literal,
    STATE(16353), 1,
      sym_parameter_types,
    STATE(17379), 1,
      sym_stable_identifier,
    ACTIONS(4486), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4488), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4492), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3572), 2,
      sym_comment,
      sym_block_comment,
    STATE(9743), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13536), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13680), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13674), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6029), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141439] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15937), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3573), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141558] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15774), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3574), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141677] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1840), 1,
      sym_integer_literal,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6676), 1,
      sym__alpha_identifier,
    ACTIONS(6678), 1,
      anon_sym__,
    ACTIONS(6680), 1,
      anon_sym_LBRACK,
    ACTIONS(6684), 1,
      anon_sym_LPAREN,
    ACTIONS(6686), 1,
      sym__backquoted_id,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    STATE(6904), 1,
      sym__annotated_type,
    STATE(6998), 1,
      sym__simple_type,
    STATE(7765), 1,
      sym_identifier,
    STATE(7792), 1,
      sym__soft_identifier,
    STATE(10305), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12347), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12599), 1,
      sym__infix_type_choice,
    STATE(16055), 1,
      sym_parameter_types,
    STATE(17582), 1,
      sym_stable_identifier,
    ACTIONS(1842), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1844), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1848), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3575), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6406), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11001), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6682), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8371), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141796] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6816), 1,
      anon_sym_COLON,
    ACTIONS(6818), 1,
      anon_sym_LBRACE,
    ACTIONS(6820), 1,
      anon_sym_LBRACK,
    ACTIONS(6822), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8571), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11816), 1,
      sym__type,
    STATE(11981), 1,
      sym_template_body,
    STATE(12025), 1,
      sym__non_null_literal,
    STATE(12827), 1,
      sym__infix_type_choice,
    STATE(16010), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3576), 2,
      sym_comment,
      sym_block_comment,
    STATE(11184), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11949), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12026), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [141915] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1362), 1,
      sym_integer_literal,
    ACTIONS(6542), 1,
      sym__alpha_identifier,
    ACTIONS(6544), 1,
      anon_sym_COLON,
    ACTIONS(6546), 1,
      anon_sym_LBRACE,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6550), 1,
      anon_sym_LBRACK,
    ACTIONS(6554), 1,
      anon_sym_LPAREN,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    STATE(5249), 1,
      sym__simple_type,
    STATE(5454), 1,
      sym__annotated_type,
    STATE(5780), 1,
      sym__soft_identifier,
    STATE(5982), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(12495), 1,
      sym__infix_type_choice,
    STATE(13419), 1,
      sym__non_null_literal,
    STATE(13569), 1,
      sym_template_body,
    STATE(13585), 1,
      sym__type,
    STATE(15978), 1,
      sym_parameter_types,
    STATE(17900), 1,
      sym_stable_identifier,
    ACTIONS(1364), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1366), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1370), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3577), 2,
      sym_comment,
      sym_block_comment,
    STATE(8349), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10071), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13410), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6174), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142034] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym__,
    ACTIONS(6834), 1,
      anon_sym_LBRACK,
    ACTIONS(6838), 1,
      anon_sym_LPAREN,
    ACTIONS(6840), 1,
      sym__backquoted_id,
    ACTIONS(6842), 1,
      sym_operator_identifier,
    STATE(5560), 1,
      sym__simple_type,
    STATE(6117), 1,
      sym_identifier,
    STATE(6232), 1,
      sym__soft_identifier,
    STATE(6391), 1,
      sym__annotated_type,
    STATE(9674), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12482), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13401), 1,
      sym__type,
    STATE(16107), 1,
      sym_parameter_types,
    STATE(17531), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3578), 2,
      sym_comment,
      sym_block_comment,
    STATE(10703), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6836), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7013), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142153] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1840), 1,
      sym_integer_literal,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6676), 1,
      sym__alpha_identifier,
    ACTIONS(6678), 1,
      anon_sym__,
    ACTIONS(6680), 1,
      anon_sym_LBRACK,
    ACTIONS(6684), 1,
      anon_sym_LPAREN,
    ACTIONS(6686), 1,
      sym__backquoted_id,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    STATE(6904), 1,
      sym__annotated_type,
    STATE(6998), 1,
      sym__simple_type,
    STATE(7765), 1,
      sym_identifier,
    STATE(7792), 1,
      sym__soft_identifier,
    STATE(10305), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12351), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12599), 1,
      sym__infix_type_choice,
    STATE(16055), 1,
      sym_parameter_types,
    STATE(17582), 1,
      sym_stable_identifier,
    ACTIONS(1842), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1844), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1848), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3579), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6406), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11001), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6682), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8371), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142272] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12289), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3580), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142391] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16169), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3581), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142510] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1450), 1,
      sym_integer_literal,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6562), 1,
      anon_sym_COLON,
    ACTIONS(6564), 1,
      anon_sym_LBRACE,
    ACTIONS(6566), 1,
      anon_sym__,
    ACTIONS(6568), 1,
      anon_sym_LBRACK,
    ACTIONS(6572), 1,
      anon_sym_LPAREN,
    ACTIONS(6574), 1,
      sym__backquoted_id,
    ACTIONS(6576), 1,
      sym_operator_identifier,
    STATE(5238), 1,
      sym__simple_type,
    STATE(5310), 1,
      sym__annotated_type,
    STATE(5717), 1,
      sym_identifier,
    STATE(6060), 1,
      sym__soft_identifier,
    STATE(8512), 1,
      sym_annotated_type,
    STATE(12617), 1,
      sym__infix_type_choice,
    STATE(13507), 1,
      sym__non_null_literal,
    STATE(13683), 1,
      sym_template_body,
    STATE(13887), 1,
      sym__type,
    STATE(15964), 1,
      sym_parameter_types,
    STATE(17417), 1,
      sym_stable_identifier,
    ACTIONS(1452), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1454), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1458), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3582), 2,
      sym_comment,
      sym_block_comment,
    STATE(8462), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8689), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10158), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13506), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6570), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6110), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142629] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1770), 1,
      sym_integer_literal,
    ACTIONS(6772), 1,
      sym__alpha_identifier,
    ACTIONS(6774), 1,
      anon_sym_COLON,
    ACTIONS(6776), 1,
      anon_sym_LBRACE,
    ACTIONS(6778), 1,
      anon_sym__,
    ACTIONS(6780), 1,
      anon_sym_LBRACK,
    ACTIONS(6784), 1,
      anon_sym_LPAREN,
    ACTIONS(6786), 1,
      sym__backquoted_id,
    ACTIONS(6788), 1,
      sym_operator_identifier,
    STATE(5792), 1,
      sym__annotated_type,
    STATE(5904), 1,
      sym__simple_type,
    STATE(6418), 1,
      sym__soft_identifier,
    STATE(6643), 1,
      sym_identifier,
    STATE(9119), 1,
      sym_annotated_type,
    STATE(12514), 1,
      sym__infix_type_choice,
    STATE(13736), 1,
      sym__type,
    STATE(13874), 1,
      sym__non_null_literal,
    STATE(13912), 1,
      sym_template_body,
    STATE(15975), 1,
      sym_parameter_types,
    STATE(17852), 1,
      sym_stable_identifier,
    ACTIONS(1772), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1774), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1778), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3583), 2,
      sym_comment,
      sym_block_comment,
    STATE(8992), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9101), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10612), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13869), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6782), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7485), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142748] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1250), 1,
      sym_integer_literal,
    ACTIONS(6268), 1,
      sym__alpha_identifier,
    ACTIONS(6270), 1,
      anon_sym_COLON,
    ACTIONS(6272), 1,
      anon_sym_LBRACE,
    ACTIONS(6274), 1,
      anon_sym__,
    ACTIONS(6276), 1,
      anon_sym_LBRACK,
    ACTIONS(6280), 1,
      anon_sym_LPAREN,
    ACTIONS(6282), 1,
      sym__backquoted_id,
    ACTIONS(6284), 1,
      sym_operator_identifier,
    STATE(5253), 1,
      sym__annotated_type,
    STATE(5337), 1,
      sym__simple_type,
    STATE(5695), 1,
      sym_identifier,
    STATE(5862), 1,
      sym__soft_identifier,
    STATE(8317), 1,
      sym_annotated_type,
    STATE(12917), 1,
      sym__infix_type_choice,
    STATE(13496), 1,
      sym__type,
    STATE(13562), 1,
      sym__non_null_literal,
    STATE(13691), 1,
      sym_template_body,
    STATE(15968), 1,
      sym_parameter_types,
    STATE(17690), 1,
      sym_stable_identifier,
    ACTIONS(1252), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1254), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1258), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3584), 2,
      sym_comment,
      sym_block_comment,
    STATE(8352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8833), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10259), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13531), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6278), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6225), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142867] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6816), 1,
      anon_sym_COLON,
    ACTIONS(6818), 1,
      anon_sym_LBRACE,
    ACTIONS(6820), 1,
      anon_sym_LBRACK,
    ACTIONS(6822), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8571), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11916), 1,
      sym__type,
    STATE(11981), 1,
      sym_template_body,
    STATE(12025), 1,
      sym__non_null_literal,
    STATE(12827), 1,
      sym__infix_type_choice,
    STATE(16010), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3585), 2,
      sym_comment,
      sym_block_comment,
    STATE(11184), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11949), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12026), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [142986] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6816), 1,
      anon_sym_COLON,
    ACTIONS(6818), 1,
      anon_sym_LBRACE,
    ACTIONS(6820), 1,
      anon_sym_LBRACK,
    ACTIONS(6822), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8571), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11928), 1,
      sym__type,
    STATE(11981), 1,
      sym_template_body,
    STATE(12025), 1,
      sym__non_null_literal,
    STATE(12827), 1,
      sym__infix_type_choice,
    STATE(16010), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3586), 2,
      sym_comment,
      sym_block_comment,
    STATE(11184), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11949), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12026), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143105] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6816), 1,
      anon_sym_COLON,
    ACTIONS(6818), 1,
      anon_sym_LBRACE,
    ACTIONS(6820), 1,
      anon_sym_LBRACK,
    ACTIONS(6822), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8571), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11702), 1,
      sym__type,
    STATE(11981), 1,
      sym_template_body,
    STATE(12025), 1,
      sym__non_null_literal,
    STATE(12827), 1,
      sym__infix_type_choice,
    STATE(16010), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3587), 2,
      sym_comment,
      sym_block_comment,
    STATE(11184), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11949), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12026), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143224] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6816), 1,
      anon_sym_COLON,
    ACTIONS(6818), 1,
      anon_sym_LBRACE,
    ACTIONS(6820), 1,
      anon_sym_LBRACK,
    ACTIONS(6822), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8571), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11939), 1,
      sym__type,
    STATE(11981), 1,
      sym_template_body,
    STATE(12025), 1,
      sym__non_null_literal,
    STATE(12827), 1,
      sym__infix_type_choice,
    STATE(16010), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3588), 2,
      sym_comment,
      sym_block_comment,
    STATE(11184), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11949), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12026), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143343] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4660), 1,
      sym__alpha_identifier,
    ACTIONS(4662), 1,
      anon_sym_COLON,
    ACTIONS(4664), 1,
      anon_sym_LBRACE,
    ACTIONS(4666), 1,
      anon_sym__,
    ACTIONS(4670), 1,
      anon_sym_LBRACK,
    ACTIONS(4678), 1,
      sym__backquoted_id,
    ACTIONS(4682), 1,
      sym_integer_literal,
    ACTIONS(6844), 1,
      anon_sym_LPAREN,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    STATE(4446), 1,
      sym__simple_type,
    STATE(4469), 1,
      sym__annotated_type,
    STATE(4601), 1,
      sym__soft_identifier,
    STATE(4620), 1,
      sym_identifier,
    STATE(6053), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11918), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12559), 1,
      sym__infix_type_choice,
    STATE(15963), 1,
      sym_parameter_types,
    STATE(16896), 1,
      sym_stable_identifier,
    ACTIONS(4684), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4686), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3589), 2,
      sym_comment,
      sym_block_comment,
    STATE(8221), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11722), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11743), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4672), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4757), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143462] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15692), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3590), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143581] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16806), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3591), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143700] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16174), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3592), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143819] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17532), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3593), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [143938] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1250), 1,
      sym_integer_literal,
    ACTIONS(6268), 1,
      sym__alpha_identifier,
    ACTIONS(6270), 1,
      anon_sym_COLON,
    ACTIONS(6272), 1,
      anon_sym_LBRACE,
    ACTIONS(6274), 1,
      anon_sym__,
    ACTIONS(6276), 1,
      anon_sym_LBRACK,
    ACTIONS(6280), 1,
      anon_sym_LPAREN,
    ACTIONS(6282), 1,
      sym__backquoted_id,
    ACTIONS(6284), 1,
      sym_operator_identifier,
    STATE(5253), 1,
      sym__annotated_type,
    STATE(5337), 1,
      sym__simple_type,
    STATE(5695), 1,
      sym_identifier,
    STATE(5862), 1,
      sym__soft_identifier,
    STATE(8317), 1,
      sym_annotated_type,
    STATE(12917), 1,
      sym__infix_type_choice,
    STATE(13490), 1,
      sym__type,
    STATE(13562), 1,
      sym__non_null_literal,
    STATE(13691), 1,
      sym_template_body,
    STATE(15968), 1,
      sym_parameter_types,
    STATE(17690), 1,
      sym_stable_identifier,
    ACTIONS(1252), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1254), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1258), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3594), 2,
      sym_comment,
      sym_block_comment,
    STATE(8352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8833), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10259), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13531), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6278), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6225), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144057] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [144126] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4626), 1,
      anon_sym_COLON,
    ACTIONS(4628), 1,
      anon_sym_LBRACE,
    ACTIONS(4646), 1,
      sym_integer_literal,
    ACTIONS(4868), 1,
      sym__alpha_identifier,
    ACTIONS(4870), 1,
      anon_sym__,
    ACTIONS(4874), 1,
      anon_sym_LBRACK,
    ACTIONS(4880), 1,
      sym__backquoted_id,
    ACTIONS(6848), 1,
      anon_sym_LPAREN,
    ACTIONS(6850), 1,
      sym_operator_identifier,
    STATE(5113), 1,
      sym__simple_type,
    STATE(5161), 1,
      sym__annotated_type,
    STATE(5536), 1,
      sym_identifier,
    STATE(5967), 1,
      sym__soft_identifier,
    STATE(8739), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11659), 1,
      sym__type,
    STATE(12584), 1,
      sym__infix_type_choice,
    STATE(16152), 1,
      sym_parameter_types,
    STATE(17570), 1,
      sym_stable_identifier,
    ACTIONS(4648), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4650), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4654), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3596), 2,
      sym_comment,
      sym_block_comment,
    STATE(10017), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11482), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11561), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6401), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144245] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(14625), 1,
      sym__type,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3597), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144364] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15356), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3598), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144483] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15355), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3599), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144602] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1250), 1,
      sym_integer_literal,
    ACTIONS(6268), 1,
      sym__alpha_identifier,
    ACTIONS(6270), 1,
      anon_sym_COLON,
    ACTIONS(6272), 1,
      anon_sym_LBRACE,
    ACTIONS(6274), 1,
      anon_sym__,
    ACTIONS(6276), 1,
      anon_sym_LBRACK,
    ACTIONS(6280), 1,
      anon_sym_LPAREN,
    ACTIONS(6282), 1,
      sym__backquoted_id,
    ACTIONS(6284), 1,
      sym_operator_identifier,
    STATE(5253), 1,
      sym__annotated_type,
    STATE(5337), 1,
      sym__simple_type,
    STATE(5695), 1,
      sym_identifier,
    STATE(5862), 1,
      sym__soft_identifier,
    STATE(8317), 1,
      sym_annotated_type,
    STATE(12917), 1,
      sym__infix_type_choice,
    STATE(13485), 1,
      sym__type,
    STATE(13562), 1,
      sym__non_null_literal,
    STATE(13691), 1,
      sym_template_body,
    STATE(15968), 1,
      sym_parameter_types,
    STATE(17690), 1,
      sym_stable_identifier,
    ACTIONS(1252), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1254), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1258), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3600), 2,
      sym_comment,
      sym_block_comment,
    STATE(8352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8833), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10259), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13531), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6278), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6225), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144721] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1250), 1,
      sym_integer_literal,
    ACTIONS(6268), 1,
      sym__alpha_identifier,
    ACTIONS(6270), 1,
      anon_sym_COLON,
    ACTIONS(6272), 1,
      anon_sym_LBRACE,
    ACTIONS(6274), 1,
      anon_sym__,
    ACTIONS(6276), 1,
      anon_sym_LBRACK,
    ACTIONS(6280), 1,
      anon_sym_LPAREN,
    ACTIONS(6282), 1,
      sym__backquoted_id,
    ACTIONS(6284), 1,
      sym_operator_identifier,
    STATE(5253), 1,
      sym__annotated_type,
    STATE(5337), 1,
      sym__simple_type,
    STATE(5695), 1,
      sym_identifier,
    STATE(5862), 1,
      sym__soft_identifier,
    STATE(8317), 1,
      sym_annotated_type,
    STATE(12917), 1,
      sym__infix_type_choice,
    STATE(13483), 1,
      sym__type,
    STATE(13562), 1,
      sym__non_null_literal,
    STATE(13691), 1,
      sym_template_body,
    STATE(15968), 1,
      sym_parameter_types,
    STATE(17690), 1,
      sym_stable_identifier,
    ACTIONS(1252), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1254), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1258), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3601), 2,
      sym_comment,
      sym_block_comment,
    STATE(8352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8833), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10259), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13531), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6278), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6225), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144840] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16746), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3602), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [144959] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6792), 1,
      anon_sym_COLON,
    ACTIONS(6794), 1,
      anon_sym_LBRACE,
    ACTIONS(6796), 1,
      anon_sym__,
    ACTIONS(6798), 1,
      anon_sym_LBRACK,
    ACTIONS(6802), 1,
      anon_sym_LPAREN,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(6806), 1,
      sym_operator_identifier,
    ACTIONS(6808), 1,
      sym_integer_literal,
    STATE(5378), 1,
      sym__simple_type,
    STATE(5755), 1,
      sym_identifier,
    STATE(5860), 1,
      sym__annotated_type,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(9021), 1,
      sym_annotated_type,
    STATE(10969), 1,
      sym__non_null_literal,
    STATE(11025), 1,
      sym__type,
    STATE(11155), 1,
      sym_template_body,
    STATE(12851), 1,
      sym__infix_type_choice,
    STATE(16255), 1,
      sym_parameter_types,
    STATE(16984), 1,
      sym_stable_identifier,
    ACTIONS(6810), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6812), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6814), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3603), 2,
      sym_comment,
      sym_block_comment,
    STATE(10256), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10951), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11066), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10978), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145078] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4246), 1,
      sym__alpha_identifier,
    ACTIONS(4248), 1,
      anon_sym_COLON,
    ACTIONS(4250), 1,
      anon_sym_LBRACE,
    ACTIONS(4252), 1,
      anon_sym__,
    ACTIONS(4256), 1,
      anon_sym_LBRACK,
    ACTIONS(4264), 1,
      sym__backquoted_id,
    ACTIONS(4268), 1,
      sym_integer_literal,
    ACTIONS(6742), 1,
      anon_sym_LPAREN,
    ACTIONS(6744), 1,
      sym_operator_identifier,
    STATE(4954), 1,
      sym__annotated_type,
    STATE(5071), 1,
      sym__simple_type,
    STATE(5208), 1,
      sym__soft_identifier,
    STATE(5307), 1,
      sym_identifier,
    STATE(7704), 1,
      sym_annotated_type,
    STATE(12480), 1,
      sym__infix_type_choice,
    STATE(13419), 1,
      sym__non_null_literal,
    STATE(13512), 1,
      sym__type,
    STATE(13569), 1,
      sym_template_body,
    STATE(15629), 1,
      sym_parameter_types,
    STATE(17894), 1,
      sym_stable_identifier,
    ACTIONS(4270), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4272), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3604), 2,
      sym_comment,
      sym_block_comment,
    STATE(9633), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13603), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13681), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13410), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4258), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5976), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145197] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4830), 1,
      sym__alpha_identifier,
    ACTIONS(4832), 1,
      anon_sym_COLON,
    ACTIONS(4834), 1,
      anon_sym_LBRACE,
    ACTIONS(4836), 1,
      anon_sym__,
    ACTIONS(4840), 1,
      anon_sym_LBRACK,
    ACTIONS(4848), 1,
      sym__backquoted_id,
    ACTIONS(4852), 1,
      sym_integer_literal,
    ACTIONS(6852), 1,
      anon_sym_LPAREN,
    ACTIONS(6854), 1,
      sym_operator_identifier,
    STATE(4938), 1,
      sym__annotated_type,
    STATE(5061), 1,
      sym__simple_type,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5395), 1,
      sym_identifier,
    STATE(7629), 1,
      sym_annotated_type,
    STATE(12880), 1,
      sym__infix_type_choice,
    STATE(13507), 1,
      sym__non_null_literal,
    STATE(13623), 1,
      sym__type,
    STATE(13683), 1,
      sym_template_body,
    STATE(16310), 1,
      sym_parameter_types,
    STATE(17092), 1,
      sym_stable_identifier,
    ACTIONS(4854), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4856), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4858), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3605), 2,
      sym_comment,
      sym_block_comment,
    STATE(9961), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13549), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13687), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13506), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4842), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5759), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145316] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17525), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3606), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145435] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(15090), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3607), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145554] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15270), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3608), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145673] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4310), 1,
      sym__alpha_identifier,
    ACTIONS(4312), 1,
      anon_sym_COLON,
    ACTIONS(4314), 1,
      anon_sym_LBRACE,
    ACTIONS(4316), 1,
      anon_sym__,
    ACTIONS(4320), 1,
      anon_sym_LBRACK,
    ACTIONS(4328), 1,
      sym__backquoted_id,
    ACTIONS(4332), 1,
      sym_integer_literal,
    ACTIONS(6694), 1,
      anon_sym_LPAREN,
    ACTIONS(6696), 1,
      sym_operator_identifier,
    STATE(4681), 1,
      sym__annotated_type,
    STATE(4737), 1,
      sym__simple_type,
    STATE(4906), 1,
      sym_identifier,
    STATE(5094), 1,
      sym__soft_identifier,
    STATE(6999), 1,
      sym_annotated_type,
    STATE(12671), 1,
      sym__infix_type_choice,
    STATE(13093), 1,
      sym__non_null_literal,
    STATE(13179), 1,
      sym__type,
    STATE(13398), 1,
      sym_template_body,
    STATE(15716), 1,
      sym_parameter_types,
    STATE(17786), 1,
      sym_stable_identifier,
    ACTIONS(4334), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4336), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4340), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3609), 2,
      sym_comment,
      sym_block_comment,
    STATE(9572), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12958), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13360), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13091), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5293), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145792] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17131), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3610), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [145911] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6816), 1,
      anon_sym_COLON,
    ACTIONS(6818), 1,
      anon_sym_LBRACE,
    ACTIONS(6820), 1,
      anon_sym_LBRACK,
    ACTIONS(6822), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8571), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11981), 1,
      sym_template_body,
    STATE(11988), 1,
      sym__type,
    STATE(12025), 1,
      sym__non_null_literal,
    STATE(12827), 1,
      sym__infix_type_choice,
    STATE(16010), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3611), 2,
      sym_comment,
      sym_block_comment,
    STATE(11184), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11949), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12026), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146030] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15767), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3612), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146149] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15337), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3613), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146268] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17853), 1,
      sym__type,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3614), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146387] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(14816), 1,
      sym__type,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3615), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146506] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4660), 1,
      sym__alpha_identifier,
    ACTIONS(4662), 1,
      anon_sym_COLON,
    ACTIONS(4664), 1,
      anon_sym_LBRACE,
    ACTIONS(4666), 1,
      anon_sym__,
    ACTIONS(4670), 1,
      anon_sym_LBRACK,
    ACTIONS(4678), 1,
      sym__backquoted_id,
    ACTIONS(4682), 1,
      sym_integer_literal,
    ACTIONS(6844), 1,
      anon_sym_LPAREN,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    STATE(4446), 1,
      sym__simple_type,
    STATE(4469), 1,
      sym__annotated_type,
    STATE(4601), 1,
      sym__soft_identifier,
    STATE(4620), 1,
      sym_identifier,
    STATE(6053), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11957), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12559), 1,
      sym__infix_type_choice,
    STATE(15963), 1,
      sym_parameter_types,
    STATE(16896), 1,
      sym_stable_identifier,
    ACTIONS(4684), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4686), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3616), 2,
      sym_comment,
      sym_block_comment,
    STATE(8221), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11722), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11743), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4672), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4757), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146625] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17139), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3617), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146744] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6874), 1,
      anon_sym_LBRACK,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7099), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12674), 1,
      sym__infix_type_choice,
    STATE(14470), 1,
      sym__type,
    STATE(16190), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3618), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146863] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17855), 1,
      sym__type,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3619), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [146982] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15320), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3620), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147101] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15319), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3621), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147220] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4310), 1,
      sym__alpha_identifier,
    ACTIONS(4312), 1,
      anon_sym_COLON,
    ACTIONS(4314), 1,
      anon_sym_LBRACE,
    ACTIONS(4316), 1,
      anon_sym__,
    ACTIONS(4320), 1,
      anon_sym_LBRACK,
    ACTIONS(4328), 1,
      sym__backquoted_id,
    ACTIONS(4332), 1,
      sym_integer_literal,
    ACTIONS(6694), 1,
      anon_sym_LPAREN,
    ACTIONS(6696), 1,
      sym_operator_identifier,
    STATE(4681), 1,
      sym__annotated_type,
    STATE(4737), 1,
      sym__simple_type,
    STATE(4906), 1,
      sym_identifier,
    STATE(5094), 1,
      sym__soft_identifier,
    STATE(6999), 1,
      sym_annotated_type,
    STATE(12671), 1,
      sym__infix_type_choice,
    STATE(13093), 1,
      sym__non_null_literal,
    STATE(13178), 1,
      sym__type,
    STATE(13398), 1,
      sym_template_body,
    STATE(15716), 1,
      sym_parameter_types,
    STATE(17786), 1,
      sym_stable_identifier,
    ACTIONS(4334), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4336), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4340), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3622), 2,
      sym_comment,
      sym_block_comment,
    STATE(9572), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12958), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13360), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13091), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5293), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147339] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4660), 1,
      sym__alpha_identifier,
    ACTIONS(4662), 1,
      anon_sym_COLON,
    ACTIONS(4664), 1,
      anon_sym_LBRACE,
    ACTIONS(4666), 1,
      anon_sym__,
    ACTIONS(4670), 1,
      anon_sym_LBRACK,
    ACTIONS(4678), 1,
      sym__backquoted_id,
    ACTIONS(4682), 1,
      sym_integer_literal,
    ACTIONS(6844), 1,
      anon_sym_LPAREN,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    STATE(4446), 1,
      sym__simple_type,
    STATE(4469), 1,
      sym__annotated_type,
    STATE(4601), 1,
      sym__soft_identifier,
    STATE(4620), 1,
      sym_identifier,
    STATE(6053), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11974), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12559), 1,
      sym__infix_type_choice,
    STATE(15963), 1,
      sym_parameter_types,
    STATE(16896), 1,
      sym_stable_identifier,
    ACTIONS(4684), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4686), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3623), 2,
      sym_comment,
      sym_block_comment,
    STATE(8221), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11722), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11743), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4672), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4757), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147458] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15726), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3624), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147577] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16008), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3625), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147696] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4660), 1,
      sym__alpha_identifier,
    ACTIONS(4662), 1,
      anon_sym_COLON,
    ACTIONS(4664), 1,
      anon_sym_LBRACE,
    ACTIONS(4666), 1,
      anon_sym__,
    ACTIONS(4670), 1,
      anon_sym_LBRACK,
    ACTIONS(4678), 1,
      sym__backquoted_id,
    ACTIONS(4682), 1,
      sym_integer_literal,
    ACTIONS(6844), 1,
      anon_sym_LPAREN,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    STATE(4446), 1,
      sym__simple_type,
    STATE(4469), 1,
      sym__annotated_type,
    STATE(4601), 1,
      sym__soft_identifier,
    STATE(4620), 1,
      sym_identifier,
    STATE(6053), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11980), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12559), 1,
      sym__infix_type_choice,
    STATE(15963), 1,
      sym_parameter_types,
    STATE(16896), 1,
      sym_stable_identifier,
    ACTIONS(4684), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4686), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3626), 2,
      sym_comment,
      sym_block_comment,
    STATE(8221), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11722), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11743), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4672), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4757), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147815] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15302), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3627), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [147934] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6884), 1,
      sym__alpha_identifier,
    ACTIONS(6886), 1,
      anon_sym__,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6892), 1,
      anon_sym_LPAREN,
    ACTIONS(6894), 1,
      sym__backquoted_id,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    STATE(6102), 1,
      sym__simple_type,
    STATE(6268), 1,
      sym__soft_identifier,
    STATE(6295), 1,
      sym__annotated_type,
    STATE(6574), 1,
      sym_identifier,
    STATE(9782), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12747), 1,
      sym__infix_type_choice,
    STATE(14400), 1,
      sym__type,
    STATE(16225), 1,
      sym_parameter_types,
    STATE(16962), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3628), 2,
      sym_comment,
      sym_block_comment,
    STATE(10796), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6890), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7231), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148053] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15301), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3629), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148172] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    ACTIONS(6898), 1,
      anon_sym_LBRACK,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7332), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12809), 1,
      sym__infix_type_choice,
    STATE(14411), 1,
      sym__type,
    STATE(16260), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3630), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148291] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4660), 1,
      sym__alpha_identifier,
    ACTIONS(4662), 1,
      anon_sym_COLON,
    ACTIONS(4664), 1,
      anon_sym_LBRACE,
    ACTIONS(4666), 1,
      anon_sym__,
    ACTIONS(4670), 1,
      anon_sym_LBRACK,
    ACTIONS(4678), 1,
      sym__backquoted_id,
    ACTIONS(4682), 1,
      sym_integer_literal,
    ACTIONS(6844), 1,
      anon_sym_LPAREN,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    STATE(4446), 1,
      sym__simple_type,
    STATE(4469), 1,
      sym__annotated_type,
    STATE(4601), 1,
      sym__soft_identifier,
    STATE(4620), 1,
      sym_identifier,
    STATE(6053), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11982), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12559), 1,
      sym__infix_type_choice,
    STATE(15963), 1,
      sym_parameter_types,
    STATE(16896), 1,
      sym_stable_identifier,
    ACTIONS(4684), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4686), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4690), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3631), 2,
      sym_comment,
      sym_block_comment,
    STATE(8221), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11722), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11743), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4672), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4757), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148410] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1118), 1,
      sym_integer_literal,
    ACTIONS(6900), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_COLON,
    ACTIONS(6904), 1,
      anon_sym_LBRACE,
    ACTIONS(6906), 1,
      anon_sym__,
    ACTIONS(6908), 1,
      anon_sym_LBRACK,
    ACTIONS(6912), 1,
      anon_sym_LPAREN,
    ACTIONS(6914), 1,
      sym__backquoted_id,
    ACTIONS(6916), 1,
      sym_operator_identifier,
    STATE(4708), 1,
      sym__annotated_type,
    STATE(4794), 1,
      sym__simple_type,
    STATE(5011), 1,
      sym_identifier,
    STATE(5013), 1,
      sym__soft_identifier,
    STATE(6935), 1,
      sym_annotated_type,
    STATE(12645), 1,
      sym_template_body,
    STATE(12704), 1,
      sym__non_null_literal,
    STATE(12720), 1,
      sym__infix_type_choice,
    STATE(13125), 1,
      sym__type,
    STATE(15971), 1,
      sym_parameter_types,
    STATE(17762), 1,
      sym_stable_identifier,
    ACTIONS(1120), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1122), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1126), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3632), 2,
      sym_comment,
      sym_block_comment,
    STATE(7087), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7186), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9279), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12703), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6910), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5168), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148529] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6918), 1,
      sym__alpha_identifier,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(6924), 1,
      anon_sym__,
    ACTIONS(6926), 1,
      anon_sym_LBRACK,
    ACTIONS(6930), 1,
      anon_sym_LPAREN,
    ACTIONS(6932), 1,
      sym__backquoted_id,
    ACTIONS(6934), 1,
      sym_operator_identifier,
    STATE(4539), 1,
      sym__annotated_type,
    STATE(4612), 1,
      sym__simple_type,
    STATE(4637), 1,
      sym_identifier,
    STATE(4714), 1,
      sym__soft_identifier,
    STATE(6684), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11982), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12667), 1,
      sym__infix_type_choice,
    STATE(16106), 1,
      sym_parameter_types,
    STATE(17341), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3633), 2,
      sym_comment,
      sym_block_comment,
    STATE(5668), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8299), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6928), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5056), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148648] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15760), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3634), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148767] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4310), 1,
      sym__alpha_identifier,
    ACTIONS(4312), 1,
      anon_sym_COLON,
    ACTIONS(4314), 1,
      anon_sym_LBRACE,
    ACTIONS(4316), 1,
      anon_sym__,
    ACTIONS(4320), 1,
      anon_sym_LBRACK,
    ACTIONS(4328), 1,
      sym__backquoted_id,
    ACTIONS(4332), 1,
      sym_integer_literal,
    ACTIONS(6694), 1,
      anon_sym_LPAREN,
    ACTIONS(6696), 1,
      sym_operator_identifier,
    STATE(4681), 1,
      sym__annotated_type,
    STATE(4737), 1,
      sym__simple_type,
    STATE(4906), 1,
      sym_identifier,
    STATE(5094), 1,
      sym__soft_identifier,
    STATE(6999), 1,
      sym_annotated_type,
    STATE(12671), 1,
      sym__infix_type_choice,
    STATE(13093), 1,
      sym__non_null_literal,
    STATE(13177), 1,
      sym__type,
    STATE(13398), 1,
      sym_template_body,
    STATE(15716), 1,
      sym_parameter_types,
    STATE(17786), 1,
      sym_stable_identifier,
    ACTIONS(4334), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4336), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4340), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3635), 2,
      sym_comment,
      sym_block_comment,
    STATE(9572), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12958), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13360), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13091), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5293), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [148886] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4246), 1,
      sym__alpha_identifier,
    ACTIONS(4248), 1,
      anon_sym_COLON,
    ACTIONS(4250), 1,
      anon_sym_LBRACE,
    ACTIONS(4252), 1,
      anon_sym__,
    ACTIONS(4256), 1,
      anon_sym_LBRACK,
    ACTIONS(4264), 1,
      sym__backquoted_id,
    ACTIONS(4268), 1,
      sym_integer_literal,
    ACTIONS(6742), 1,
      anon_sym_LPAREN,
    ACTIONS(6744), 1,
      sym_operator_identifier,
    STATE(4954), 1,
      sym__annotated_type,
    STATE(5071), 1,
      sym__simple_type,
    STATE(5208), 1,
      sym__soft_identifier,
    STATE(5307), 1,
      sym_identifier,
    STATE(7704), 1,
      sym_annotated_type,
    STATE(12480), 1,
      sym__infix_type_choice,
    STATE(13419), 1,
      sym__non_null_literal,
    STATE(13503), 1,
      sym__type,
    STATE(13569), 1,
      sym_template_body,
    STATE(15629), 1,
      sym_parameter_types,
    STATE(17894), 1,
      sym_stable_identifier,
    ACTIONS(4270), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4272), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3636), 2,
      sym_comment,
      sym_block_comment,
    STATE(9633), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13603), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13681), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13410), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4258), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5976), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149005] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6792), 1,
      anon_sym_COLON,
    ACTIONS(6794), 1,
      anon_sym_LBRACE,
    ACTIONS(6796), 1,
      anon_sym__,
    ACTIONS(6798), 1,
      anon_sym_LBRACK,
    ACTIONS(6802), 1,
      anon_sym_LPAREN,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(6806), 1,
      sym_operator_identifier,
    ACTIONS(6808), 1,
      sym_integer_literal,
    STATE(5378), 1,
      sym__simple_type,
    STATE(5755), 1,
      sym_identifier,
    STATE(5860), 1,
      sym__annotated_type,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(9021), 1,
      sym_annotated_type,
    STATE(10969), 1,
      sym__non_null_literal,
    STATE(11081), 1,
      sym__type,
    STATE(11155), 1,
      sym_template_body,
    STATE(12851), 1,
      sym__infix_type_choice,
    STATE(16255), 1,
      sym_parameter_types,
    STATE(16984), 1,
      sym_stable_identifier,
    ACTIONS(6810), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6812), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6814), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3637), 2,
      sym_comment,
      sym_block_comment,
    STATE(10256), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10951), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11066), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10978), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149124] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15284), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3638), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149243] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15283), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3639), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149362] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(14629), 1,
      sym__type,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3640), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149481] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1840), 1,
      sym_integer_literal,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(6676), 1,
      sym__alpha_identifier,
    ACTIONS(6678), 1,
      anon_sym__,
    ACTIONS(6680), 1,
      anon_sym_LBRACK,
    ACTIONS(6684), 1,
      anon_sym_LPAREN,
    ACTIONS(6686), 1,
      sym__backquoted_id,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    STATE(6904), 1,
      sym__annotated_type,
    STATE(6998), 1,
      sym__simple_type,
    STATE(7765), 1,
      sym_identifier,
    STATE(7792), 1,
      sym__soft_identifier,
    STATE(10305), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12367), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12599), 1,
      sym__infix_type_choice,
    STATE(16055), 1,
      sym_parameter_types,
    STATE(17582), 1,
      sym_stable_identifier,
    ACTIONS(1842), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1844), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1848), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3641), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6406), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11001), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6682), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8371), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149600] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4830), 1,
      sym__alpha_identifier,
    ACTIONS(4832), 1,
      anon_sym_COLON,
    ACTIONS(4834), 1,
      anon_sym_LBRACE,
    ACTIONS(4836), 1,
      anon_sym__,
    ACTIONS(4840), 1,
      anon_sym_LBRACK,
    ACTIONS(4848), 1,
      sym__backquoted_id,
    ACTIONS(4852), 1,
      sym_integer_literal,
    ACTIONS(6852), 1,
      anon_sym_LPAREN,
    ACTIONS(6854), 1,
      sym_operator_identifier,
    STATE(4938), 1,
      sym__annotated_type,
    STATE(5061), 1,
      sym__simple_type,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5395), 1,
      sym_identifier,
    STATE(7629), 1,
      sym_annotated_type,
    STATE(12880), 1,
      sym__infix_type_choice,
    STATE(13507), 1,
      sym__non_null_literal,
    STATE(13641), 1,
      sym__type,
    STATE(13683), 1,
      sym_template_body,
    STATE(16310), 1,
      sym_parameter_types,
    STATE(17092), 1,
      sym_stable_identifier,
    ACTIONS(4854), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4856), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4858), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3642), 2,
      sym_comment,
      sym_block_comment,
    STATE(9961), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13549), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13687), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13506), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4842), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5759), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149719] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4830), 1,
      sym__alpha_identifier,
    ACTIONS(4832), 1,
      anon_sym_COLON,
    ACTIONS(4834), 1,
      anon_sym_LBRACE,
    ACTIONS(4836), 1,
      anon_sym__,
    ACTIONS(4840), 1,
      anon_sym_LBRACK,
    ACTIONS(4848), 1,
      sym__backquoted_id,
    ACTIONS(4852), 1,
      sym_integer_literal,
    ACTIONS(6852), 1,
      anon_sym_LPAREN,
    ACTIONS(6854), 1,
      sym_operator_identifier,
    STATE(4938), 1,
      sym__annotated_type,
    STATE(5061), 1,
      sym__simple_type,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5395), 1,
      sym_identifier,
    STATE(7629), 1,
      sym_annotated_type,
    STATE(12880), 1,
      sym__infix_type_choice,
    STATE(13507), 1,
      sym__non_null_literal,
    STATE(13661), 1,
      sym__type,
    STATE(13683), 1,
      sym_template_body,
    STATE(16310), 1,
      sym_parameter_types,
    STATE(17092), 1,
      sym_stable_identifier,
    ACTIONS(4854), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4856), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4858), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3643), 2,
      sym_comment,
      sym_block_comment,
    STATE(9961), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13549), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13687), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13506), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4842), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5759), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149838] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1250), 1,
      sym_integer_literal,
    ACTIONS(6268), 1,
      sym__alpha_identifier,
    ACTIONS(6270), 1,
      anon_sym_COLON,
    ACTIONS(6272), 1,
      anon_sym_LBRACE,
    ACTIONS(6274), 1,
      anon_sym__,
    ACTIONS(6276), 1,
      anon_sym_LBRACK,
    ACTIONS(6280), 1,
      anon_sym_LPAREN,
    ACTIONS(6282), 1,
      sym__backquoted_id,
    ACTIONS(6284), 1,
      sym_operator_identifier,
    STATE(5253), 1,
      sym__annotated_type,
    STATE(5337), 1,
      sym__simple_type,
    STATE(5695), 1,
      sym_identifier,
    STATE(5862), 1,
      sym__soft_identifier,
    STATE(8317), 1,
      sym_annotated_type,
    STATE(12917), 1,
      sym__infix_type_choice,
    STATE(13509), 1,
      sym__type,
    STATE(13562), 1,
      sym__non_null_literal,
    STATE(13691), 1,
      sym_template_body,
    STATE(15968), 1,
      sym_parameter_types,
    STATE(17690), 1,
      sym_stable_identifier,
    ACTIONS(1252), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1254), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1258), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3644), 2,
      sym_comment,
      sym_block_comment,
    STATE(8352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8833), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10259), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13531), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6278), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6225), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [149957] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15266), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3645), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150076] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15265), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3646), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150195] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15751), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3647), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150314] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1770), 1,
      sym_integer_literal,
    ACTIONS(6772), 1,
      sym__alpha_identifier,
    ACTIONS(6774), 1,
      anon_sym_COLON,
    ACTIONS(6776), 1,
      anon_sym_LBRACE,
    ACTIONS(6778), 1,
      anon_sym__,
    ACTIONS(6780), 1,
      anon_sym_LBRACK,
    ACTIONS(6784), 1,
      anon_sym_LPAREN,
    ACTIONS(6786), 1,
      sym__backquoted_id,
    ACTIONS(6788), 1,
      sym_operator_identifier,
    STATE(5792), 1,
      sym__annotated_type,
    STATE(5904), 1,
      sym__simple_type,
    STATE(6418), 1,
      sym__soft_identifier,
    STATE(6643), 1,
      sym_identifier,
    STATE(9119), 1,
      sym_annotated_type,
    STATE(12514), 1,
      sym__infix_type_choice,
    STATE(13821), 1,
      sym__type,
    STATE(13874), 1,
      sym__non_null_literal,
    STATE(13912), 1,
      sym_template_body,
    STATE(15975), 1,
      sym_parameter_types,
    STATE(17852), 1,
      sym_stable_identifier,
    ACTIONS(1772), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1774), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1778), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3648), 2,
      sym_comment,
      sym_block_comment,
    STATE(8992), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9101), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10612), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13869), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6782), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7485), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150433] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6792), 1,
      anon_sym_COLON,
    ACTIONS(6794), 1,
      anon_sym_LBRACE,
    ACTIONS(6796), 1,
      anon_sym__,
    ACTIONS(6798), 1,
      anon_sym_LBRACK,
    ACTIONS(6802), 1,
      anon_sym_LPAREN,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(6806), 1,
      sym_operator_identifier,
    ACTIONS(6808), 1,
      sym_integer_literal,
    STATE(5378), 1,
      sym__simple_type,
    STATE(5755), 1,
      sym_identifier,
    STATE(5860), 1,
      sym__annotated_type,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(9021), 1,
      sym_annotated_type,
    STATE(10969), 1,
      sym__non_null_literal,
    STATE(11155), 1,
      sym_template_body,
    STATE(11267), 1,
      sym__type,
    STATE(12851), 1,
      sym__infix_type_choice,
    STATE(16255), 1,
      sym_parameter_types,
    STATE(16984), 1,
      sym_stable_identifier,
    ACTIONS(6810), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6812), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6814), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3649), 2,
      sym_comment,
      sym_block_comment,
    STATE(10256), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10951), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11066), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10978), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150552] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4830), 1,
      sym__alpha_identifier,
    ACTIONS(4832), 1,
      anon_sym_COLON,
    ACTIONS(4834), 1,
      anon_sym_LBRACE,
    ACTIONS(4836), 1,
      anon_sym__,
    ACTIONS(4840), 1,
      anon_sym_LBRACK,
    ACTIONS(4848), 1,
      sym__backquoted_id,
    ACTIONS(4852), 1,
      sym_integer_literal,
    ACTIONS(6852), 1,
      anon_sym_LPAREN,
    ACTIONS(6854), 1,
      sym_operator_identifier,
    STATE(4938), 1,
      sym__annotated_type,
    STATE(5061), 1,
      sym__simple_type,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5395), 1,
      sym_identifier,
    STATE(7629), 1,
      sym_annotated_type,
    STATE(12880), 1,
      sym__infix_type_choice,
    STATE(13507), 1,
      sym__non_null_literal,
    STATE(13662), 1,
      sym__type,
    STATE(13683), 1,
      sym_template_body,
    STATE(16310), 1,
      sym_parameter_types,
    STATE(17092), 1,
      sym_stable_identifier,
    ACTIONS(4854), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4856), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4858), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3650), 2,
      sym_comment,
      sym_block_comment,
    STATE(9961), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13549), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13687), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13506), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4842), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5759), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150671] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4830), 1,
      sym__alpha_identifier,
    ACTIONS(4832), 1,
      anon_sym_COLON,
    ACTIONS(4834), 1,
      anon_sym_LBRACE,
    ACTIONS(4836), 1,
      anon_sym__,
    ACTIONS(4840), 1,
      anon_sym_LBRACK,
    ACTIONS(4848), 1,
      sym__backquoted_id,
    ACTIONS(4852), 1,
      sym_integer_literal,
    ACTIONS(6852), 1,
      anon_sym_LPAREN,
    ACTIONS(6854), 1,
      sym_operator_identifier,
    STATE(4938), 1,
      sym__annotated_type,
    STATE(5061), 1,
      sym__simple_type,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5395), 1,
      sym_identifier,
    STATE(7629), 1,
      sym_annotated_type,
    STATE(12880), 1,
      sym__infix_type_choice,
    STATE(13507), 1,
      sym__non_null_literal,
    STATE(13683), 1,
      sym_template_body,
    STATE(13695), 1,
      sym__type,
    STATE(16310), 1,
      sym_parameter_types,
    STATE(17092), 1,
      sym_stable_identifier,
    ACTIONS(4854), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4856), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4858), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3651), 2,
      sym_comment,
      sym_block_comment,
    STATE(9961), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13549), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13687), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13506), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4842), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5759), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150790] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6918), 1,
      sym__alpha_identifier,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(6924), 1,
      anon_sym__,
    ACTIONS(6926), 1,
      anon_sym_LBRACK,
    ACTIONS(6930), 1,
      anon_sym_LPAREN,
    ACTIONS(6932), 1,
      sym__backquoted_id,
    ACTIONS(6934), 1,
      sym_operator_identifier,
    STATE(4539), 1,
      sym__annotated_type,
    STATE(4612), 1,
      sym__simple_type,
    STATE(4637), 1,
      sym_identifier,
    STATE(4714), 1,
      sym__soft_identifier,
    STATE(6684), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11980), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12667), 1,
      sym__infix_type_choice,
    STATE(16106), 1,
      sym_parameter_types,
    STATE(17341), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3652), 2,
      sym_comment,
      sym_block_comment,
    STATE(5668), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8299), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6928), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5056), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [150909] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4310), 1,
      sym__alpha_identifier,
    ACTIONS(4312), 1,
      anon_sym_COLON,
    ACTIONS(4314), 1,
      anon_sym_LBRACE,
    ACTIONS(4316), 1,
      anon_sym__,
    ACTIONS(4320), 1,
      anon_sym_LBRACK,
    ACTIONS(4328), 1,
      sym__backquoted_id,
    ACTIONS(4332), 1,
      sym_integer_literal,
    ACTIONS(6694), 1,
      anon_sym_LPAREN,
    ACTIONS(6696), 1,
      sym_operator_identifier,
    STATE(4681), 1,
      sym__annotated_type,
    STATE(4737), 1,
      sym__simple_type,
    STATE(4906), 1,
      sym_identifier,
    STATE(5094), 1,
      sym__soft_identifier,
    STATE(6999), 1,
      sym_annotated_type,
    STATE(12671), 1,
      sym__infix_type_choice,
    STATE(13093), 1,
      sym__non_null_literal,
    STATE(13175), 1,
      sym__type,
    STATE(13398), 1,
      sym_template_body,
    STATE(15716), 1,
      sym_parameter_types,
    STATE(17786), 1,
      sym_stable_identifier,
    ACTIONS(4334), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4336), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4340), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3653), 2,
      sym_comment,
      sym_block_comment,
    STATE(9572), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12958), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13360), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13091), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5293), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151028] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6792), 1,
      anon_sym_COLON,
    ACTIONS(6794), 1,
      anon_sym_LBRACE,
    ACTIONS(6796), 1,
      anon_sym__,
    ACTIONS(6798), 1,
      anon_sym_LBRACK,
    ACTIONS(6802), 1,
      anon_sym_LPAREN,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(6806), 1,
      sym_operator_identifier,
    ACTIONS(6808), 1,
      sym_integer_literal,
    STATE(5378), 1,
      sym__simple_type,
    STATE(5755), 1,
      sym_identifier,
    STATE(5860), 1,
      sym__annotated_type,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(9021), 1,
      sym_annotated_type,
    STATE(10969), 1,
      sym__non_null_literal,
    STATE(11155), 1,
      sym_template_body,
    STATE(11266), 1,
      sym__type,
    STATE(12851), 1,
      sym__infix_type_choice,
    STATE(16255), 1,
      sym_parameter_types,
    STATE(16984), 1,
      sym_stable_identifier,
    ACTIONS(6810), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6812), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6814), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3654), 2,
      sym_comment,
      sym_block_comment,
    STATE(10256), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10951), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11066), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10978), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151147] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15248), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3655), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151266] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15247), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3656), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151385] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15740), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3657), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151504] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1770), 1,
      sym_integer_literal,
    ACTIONS(6772), 1,
      sym__alpha_identifier,
    ACTIONS(6774), 1,
      anon_sym_COLON,
    ACTIONS(6776), 1,
      anon_sym_LBRACE,
    ACTIONS(6778), 1,
      anon_sym__,
    ACTIONS(6780), 1,
      anon_sym_LBRACK,
    ACTIONS(6784), 1,
      anon_sym_LPAREN,
    ACTIONS(6786), 1,
      sym__backquoted_id,
    ACTIONS(6788), 1,
      sym_operator_identifier,
    STATE(5792), 1,
      sym__annotated_type,
    STATE(5904), 1,
      sym__simple_type,
    STATE(6418), 1,
      sym__soft_identifier,
    STATE(6643), 1,
      sym_identifier,
    STATE(9119), 1,
      sym_annotated_type,
    STATE(12514), 1,
      sym__infix_type_choice,
    STATE(13807), 1,
      sym__type,
    STATE(13874), 1,
      sym__non_null_literal,
    STATE(13912), 1,
      sym_template_body,
    STATE(15975), 1,
      sym_parameter_types,
    STATE(17852), 1,
      sym_stable_identifier,
    ACTIONS(1772), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1774), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1778), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3658), 2,
      sym_comment,
      sym_block_comment,
    STATE(8992), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9101), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10612), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13869), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6782), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7485), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151623] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6258), 1,
      anon_sym_LBRACK,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(8011), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(14324), 1,
      sym__type,
    STATE(16153), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3659), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151742] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6918), 1,
      sym__alpha_identifier,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(6924), 1,
      anon_sym__,
    ACTIONS(6926), 1,
      anon_sym_LBRACK,
    ACTIONS(6930), 1,
      anon_sym_LPAREN,
    ACTIONS(6932), 1,
      sym__backquoted_id,
    ACTIONS(6934), 1,
      sym_operator_identifier,
    STATE(4539), 1,
      sym__annotated_type,
    STATE(4612), 1,
      sym__simple_type,
    STATE(4637), 1,
      sym_identifier,
    STATE(4714), 1,
      sym__soft_identifier,
    STATE(6684), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11974), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12667), 1,
      sym__infix_type_choice,
    STATE(16106), 1,
      sym_parameter_types,
    STATE(17341), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3660), 2,
      sym_comment,
      sym_block_comment,
    STATE(5668), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8299), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6928), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5056), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151861] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16298), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3661), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [151980] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16200), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3662), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152099] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6918), 1,
      sym__alpha_identifier,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(6924), 1,
      anon_sym__,
    ACTIONS(6926), 1,
      anon_sym_LBRACK,
    ACTIONS(6930), 1,
      anon_sym_LPAREN,
    ACTIONS(6932), 1,
      sym__backquoted_id,
    ACTIONS(6934), 1,
      sym_operator_identifier,
    STATE(4539), 1,
      sym__annotated_type,
    STATE(4612), 1,
      sym__simple_type,
    STATE(4637), 1,
      sym_identifier,
    STATE(4714), 1,
      sym__soft_identifier,
    STATE(6684), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11957), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12667), 1,
      sym__infix_type_choice,
    STATE(16106), 1,
      sym_parameter_types,
    STATE(17341), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3663), 2,
      sym_comment,
      sym_block_comment,
    STATE(5668), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8299), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6928), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5056), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152218] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1538), 1,
      sym_integer_literal,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym__,
    ACTIONS(6604), 1,
      anon_sym_LBRACK,
    ACTIONS(6608), 1,
      anon_sym_LPAREN,
    ACTIONS(6610), 1,
      sym__backquoted_id,
    ACTIONS(6612), 1,
      sym_operator_identifier,
    STATE(6433), 1,
      sym__simple_type,
    STATE(6449), 1,
      sym__annotated_type,
    STATE(7134), 1,
      sym__soft_identifier,
    STATE(7495), 1,
      sym_identifier,
    STATE(9897), 1,
      sym_annotated_type,
    STATE(11749), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12501), 1,
      sym__infix_type_choice,
    STATE(16058), 1,
      sym_parameter_types,
    STATE(17864), 1,
      sym_stable_identifier,
    ACTIONS(1540), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1542), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1546), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3664), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5996), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10820), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7557), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152337] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(14632), 1,
      sym__type,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3665), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152456] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15233), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3666), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152575] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1770), 1,
      sym_integer_literal,
    ACTIONS(6772), 1,
      sym__alpha_identifier,
    ACTIONS(6774), 1,
      anon_sym_COLON,
    ACTIONS(6776), 1,
      anon_sym_LBRACE,
    ACTIONS(6778), 1,
      anon_sym__,
    ACTIONS(6780), 1,
      anon_sym_LBRACK,
    ACTIONS(6784), 1,
      anon_sym_LPAREN,
    ACTIONS(6786), 1,
      sym__backquoted_id,
    ACTIONS(6788), 1,
      sym_operator_identifier,
    STATE(5792), 1,
      sym__annotated_type,
    STATE(5904), 1,
      sym__simple_type,
    STATE(6418), 1,
      sym__soft_identifier,
    STATE(6643), 1,
      sym_identifier,
    STATE(9119), 1,
      sym_annotated_type,
    STATE(12514), 1,
      sym__infix_type_choice,
    STATE(13798), 1,
      sym__type,
    STATE(13874), 1,
      sym__non_null_literal,
    STATE(13912), 1,
      sym_template_body,
    STATE(15975), 1,
      sym_parameter_types,
    STATE(17852), 1,
      sym_stable_identifier,
    ACTIONS(1772), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1774), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1778), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3667), 2,
      sym_comment,
      sym_block_comment,
    STATE(8992), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9101), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10612), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13869), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6782), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7485), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152694] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15229), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3668), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152813] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1306), 1,
      sym_integer_literal,
    ACTIONS(6336), 1,
      sym__alpha_identifier,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(6342), 1,
      anon_sym__,
    ACTIONS(6344), 1,
      anon_sym_LBRACK,
    ACTIONS(6348), 1,
      anon_sym_LPAREN,
    ACTIONS(6350), 1,
      sym__backquoted_id,
    ACTIONS(6352), 1,
      sym_operator_identifier,
    STATE(5944), 1,
      sym__simple_type,
    STATE(5985), 1,
      sym__annotated_type,
    STATE(6347), 1,
      sym__soft_identifier,
    STATE(6696), 1,
      sym_identifier,
    STATE(9248), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11659), 1,
      sym__type,
    STATE(12891), 1,
      sym__infix_type_choice,
    STATE(16056), 1,
      sym_parameter_types,
    STATE(17708), 1,
      sym_stable_identifier,
    ACTIONS(1308), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1310), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1314), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3669), 2,
      sym_comment,
      sym_block_comment,
    STATE(5184), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10495), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6346), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7084), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [152932] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4246), 1,
      sym__alpha_identifier,
    ACTIONS(4248), 1,
      anon_sym_COLON,
    ACTIONS(4250), 1,
      anon_sym_LBRACE,
    ACTIONS(4252), 1,
      anon_sym__,
    ACTIONS(4256), 1,
      anon_sym_LBRACK,
    ACTIONS(4264), 1,
      sym__backquoted_id,
    ACTIONS(4268), 1,
      sym_integer_literal,
    ACTIONS(6742), 1,
      anon_sym_LPAREN,
    ACTIONS(6744), 1,
      sym_operator_identifier,
    STATE(4954), 1,
      sym__annotated_type,
    STATE(5071), 1,
      sym__simple_type,
    STATE(5208), 1,
      sym__soft_identifier,
    STATE(5307), 1,
      sym_identifier,
    STATE(7704), 1,
      sym_annotated_type,
    STATE(12480), 1,
      sym__infix_type_choice,
    STATE(13419), 1,
      sym__non_null_literal,
    STATE(13569), 1,
      sym_template_body,
    STATE(13634), 1,
      sym__type,
    STATE(15629), 1,
      sym_parameter_types,
    STATE(17894), 1,
      sym_stable_identifier,
    ACTIONS(4270), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4272), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3670), 2,
      sym_comment,
      sym_block_comment,
    STATE(9633), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13603), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13681), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13410), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4258), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5976), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153051] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11699), 1,
      sym__type,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3671), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153170] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1306), 1,
      sym_integer_literal,
    ACTIONS(6336), 1,
      sym__alpha_identifier,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(6342), 1,
      anon_sym__,
    ACTIONS(6344), 1,
      anon_sym_LBRACK,
    ACTIONS(6348), 1,
      anon_sym_LPAREN,
    ACTIONS(6350), 1,
      sym__backquoted_id,
    ACTIONS(6352), 1,
      sym_operator_identifier,
    STATE(5944), 1,
      sym__simple_type,
    STATE(5985), 1,
      sym__annotated_type,
    STATE(6347), 1,
      sym__soft_identifier,
    STATE(6696), 1,
      sym_identifier,
    STATE(9248), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11651), 1,
      sym__type,
    STATE(12891), 1,
      sym__infix_type_choice,
    STATE(16056), 1,
      sym_parameter_types,
    STATE(17708), 1,
      sym_stable_identifier,
    ACTIONS(1308), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1310), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1314), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3672), 2,
      sym_comment,
      sym_block_comment,
    STATE(5184), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10495), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6346), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7084), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153289] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16289), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3673), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153408] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1306), 1,
      sym_integer_literal,
    ACTIONS(6336), 1,
      sym__alpha_identifier,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(6342), 1,
      anon_sym__,
    ACTIONS(6344), 1,
      anon_sym_LBRACK,
    ACTIONS(6348), 1,
      anon_sym_LPAREN,
    ACTIONS(6350), 1,
      sym__backquoted_id,
    ACTIONS(6352), 1,
      sym_operator_identifier,
    STATE(5944), 1,
      sym__simple_type,
    STATE(5985), 1,
      sym__annotated_type,
    STATE(6347), 1,
      sym__soft_identifier,
    STATE(6696), 1,
      sym_identifier,
    STATE(9248), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11650), 1,
      sym__type,
    STATE(12891), 1,
      sym__infix_type_choice,
    STATE(16056), 1,
      sym_parameter_types,
    STATE(17708), 1,
      sym_stable_identifier,
    ACTIONS(1308), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1310), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1314), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3674), 2,
      sym_comment,
      sym_block_comment,
    STATE(5184), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10495), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6346), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7084), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153527] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1306), 1,
      sym_integer_literal,
    ACTIONS(6336), 1,
      sym__alpha_identifier,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(6342), 1,
      anon_sym__,
    ACTIONS(6344), 1,
      anon_sym_LBRACK,
    ACTIONS(6348), 1,
      anon_sym_LPAREN,
    ACTIONS(6350), 1,
      sym__backquoted_id,
    ACTIONS(6352), 1,
      sym_operator_identifier,
    STATE(5944), 1,
      sym__simple_type,
    STATE(5985), 1,
      sym__annotated_type,
    STATE(6347), 1,
      sym__soft_identifier,
    STATE(6696), 1,
      sym_identifier,
    STATE(9248), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11649), 1,
      sym__type,
    STATE(12891), 1,
      sym__infix_type_choice,
    STATE(16056), 1,
      sym_parameter_types,
    STATE(17708), 1,
      sym_stable_identifier,
    ACTIONS(1308), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1310), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1314), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3675), 2,
      sym_comment,
      sym_block_comment,
    STATE(5184), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10495), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6346), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7084), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153646] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(13131), 1,
      sym__type,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3676), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153765] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16275), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3677), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [153884] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15764), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3678), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154003] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15480), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3679), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154122] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(14238), 1,
      sym__type,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3680), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154241] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(14633), 1,
      sym__type,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3681), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154360] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15729), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3682), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154479] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(13131), 1,
      sym__type,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3683), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154598] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym__,
    ACTIONS(6834), 1,
      anon_sym_LBRACK,
    ACTIONS(6838), 1,
      anon_sym_LPAREN,
    ACTIONS(6840), 1,
      sym__backquoted_id,
    ACTIONS(6842), 1,
      sym_operator_identifier,
    STATE(5560), 1,
      sym__simple_type,
    STATE(6117), 1,
      sym_identifier,
    STATE(6232), 1,
      sym__soft_identifier,
    STATE(6391), 1,
      sym__annotated_type,
    STATE(9674), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12482), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13400), 1,
      sym__type,
    STATE(16107), 1,
      sym_parameter_types,
    STATE(17531), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3684), 2,
      sym_comment,
      sym_block_comment,
    STATE(10703), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6836), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7013), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154717] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(4342), 1,
      sym__alpha_identifier,
    ACTIONS(4344), 1,
      anon_sym__,
    ACTIONS(4348), 1,
      anon_sym_LBRACK,
    ACTIONS(4354), 1,
      sym__backquoted_id,
    ACTIONS(6936), 1,
      anon_sym_LPAREN,
    ACTIONS(6938), 1,
      sym_operator_identifier,
    STATE(7248), 1,
      sym__annotated_type,
    STATE(7255), 1,
      sym__simple_type,
    STATE(7539), 1,
      sym__soft_identifier,
    STATE(7904), 1,
      sym_identifier,
    STATE(10219), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11611), 1,
      sym__type,
    STATE(12872), 1,
      sym__infix_type_choice,
    STATE(15934), 1,
      sym_parameter_types,
    STATE(17364), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3685), 2,
      sym_comment,
      sym_block_comment,
    STATE(10976), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4350), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8693), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154836] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16854), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3686), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [154955] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(4342), 1,
      sym__alpha_identifier,
    ACTIONS(4344), 1,
      anon_sym__,
    ACTIONS(4348), 1,
      anon_sym_LBRACK,
    ACTIONS(4354), 1,
      sym__backquoted_id,
    ACTIONS(6936), 1,
      anon_sym_LPAREN,
    ACTIONS(6938), 1,
      sym_operator_identifier,
    STATE(7248), 1,
      sym__annotated_type,
    STATE(7255), 1,
      sym__simple_type,
    STATE(7539), 1,
      sym__soft_identifier,
    STATE(7904), 1,
      sym_identifier,
    STATE(10219), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11613), 1,
      sym__type,
    STATE(12872), 1,
      sym__infix_type_choice,
    STATE(15934), 1,
      sym_parameter_types,
    STATE(17364), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3687), 2,
      sym_comment,
      sym_block_comment,
    STATE(10976), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4350), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8693), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155074] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(4342), 1,
      sym__alpha_identifier,
    ACTIONS(4344), 1,
      anon_sym__,
    ACTIONS(4348), 1,
      anon_sym_LBRACK,
    ACTIONS(4354), 1,
      sym__backquoted_id,
    ACTIONS(6936), 1,
      anon_sym_LPAREN,
    ACTIONS(6938), 1,
      sym_operator_identifier,
    STATE(7248), 1,
      sym__annotated_type,
    STATE(7255), 1,
      sym__simple_type,
    STATE(7539), 1,
      sym__soft_identifier,
    STATE(7904), 1,
      sym_identifier,
    STATE(10219), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11623), 1,
      sym__type,
    STATE(12872), 1,
      sym__infix_type_choice,
    STATE(15934), 1,
      sym_parameter_types,
    STATE(17364), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3688), 2,
      sym_comment,
      sym_block_comment,
    STATE(10976), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4350), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8693), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155193] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6918), 1,
      sym__alpha_identifier,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(6924), 1,
      anon_sym__,
    ACTIONS(6926), 1,
      anon_sym_LBRACK,
    ACTIONS(6930), 1,
      anon_sym_LPAREN,
    ACTIONS(6932), 1,
      sym__backquoted_id,
    ACTIONS(6934), 1,
      sym_operator_identifier,
    STATE(4539), 1,
      sym__annotated_type,
    STATE(4612), 1,
      sym__simple_type,
    STATE(4637), 1,
      sym_identifier,
    STATE(4714), 1,
      sym__soft_identifier,
    STATE(6684), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11918), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12667), 1,
      sym__infix_type_choice,
    STATE(16106), 1,
      sym_parameter_types,
    STATE(17341), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3689), 2,
      sym_comment,
      sym_block_comment,
    STATE(5668), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8299), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6928), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5056), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155312] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15718), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3690), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155431] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16344), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3691), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155550] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16199), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3692), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155669] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15707), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3693), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155788] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(4342), 1,
      sym__alpha_identifier,
    ACTIONS(4344), 1,
      anon_sym__,
    ACTIONS(4348), 1,
      anon_sym_LBRACK,
    ACTIONS(4354), 1,
      sym__backquoted_id,
    ACTIONS(6936), 1,
      anon_sym_LPAREN,
    ACTIONS(6938), 1,
      sym_operator_identifier,
    STATE(7248), 1,
      sym__annotated_type,
    STATE(7255), 1,
      sym__simple_type,
    STATE(7539), 1,
      sym__soft_identifier,
    STATE(7904), 1,
      sym_identifier,
    STATE(10219), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11637), 1,
      sym__type,
    STATE(12872), 1,
      sym__infix_type_choice,
    STATE(15934), 1,
      sym_parameter_types,
    STATE(17364), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3694), 2,
      sym_comment,
      sym_block_comment,
    STATE(10976), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4350), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8693), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [155907] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2000), 1,
      sym_integer_literal,
    ACTIONS(6940), 1,
      sym__alpha_identifier,
    ACTIONS(6942), 1,
      anon_sym_COLON,
    ACTIONS(6944), 1,
      anon_sym_LBRACE,
    ACTIONS(6946), 1,
      anon_sym__,
    ACTIONS(6948), 1,
      anon_sym_LBRACK,
    ACTIONS(6952), 1,
      anon_sym_LPAREN,
    ACTIONS(6954), 1,
      sym__backquoted_id,
    ACTIONS(6956), 1,
      sym_operator_identifier,
    STATE(5622), 1,
      sym__simple_type,
    STATE(6024), 1,
      sym__annotated_type,
    STATE(6376), 1,
      sym__soft_identifier,
    STATE(6428), 1,
      sym_identifier,
    STATE(9297), 1,
      sym_annotated_type,
    STATE(12690), 1,
      sym__infix_type_choice,
    STATE(13856), 1,
      sym_template_body,
    STATE(13862), 1,
      sym__non_null_literal,
    STATE(14016), 1,
      sym__type,
    STATE(15972), 1,
      sym_parameter_types,
    STATE(17774), 1,
      sym_stable_identifier,
    ACTIONS(2002), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2004), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2008), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3695), 2,
      sym_comment,
      sym_block_comment,
    STATE(9114), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9333), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10596), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13863), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7299), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156026] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15216), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3696), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156145] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16856), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3697), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156264] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym__,
    ACTIONS(6834), 1,
      anon_sym_LBRACK,
    ACTIONS(6838), 1,
      anon_sym_LPAREN,
    ACTIONS(6840), 1,
      sym__backquoted_id,
    ACTIONS(6842), 1,
      sym_operator_identifier,
    STATE(5560), 1,
      sym__simple_type,
    STATE(6117), 1,
      sym_identifier,
    STATE(6232), 1,
      sym__soft_identifier,
    STATE(6391), 1,
      sym__annotated_type,
    STATE(9674), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12482), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13405), 1,
      sym__type,
    STATE(16107), 1,
      sym_parameter_types,
    STATE(17531), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3698), 2,
      sym_comment,
      sym_block_comment,
    STATE(10703), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6836), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7013), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156383] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6258), 1,
      anon_sym_LBRACK,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(8011), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(14291), 1,
      sym__type,
    STATE(16153), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3699), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156502] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15779), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3700), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156621] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15696), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3701), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156740] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6494), 1,
      anon_sym_LBRACK,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7175), 1,
      sym__annotated_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12512), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(14516), 1,
      sym__type,
    STATE(16155), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3702), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156859] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16203), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3703), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [156978] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15214), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3704), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157097] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym__,
    ACTIONS(6834), 1,
      anon_sym_LBRACK,
    ACTIONS(6838), 1,
      anon_sym_LPAREN,
    ACTIONS(6840), 1,
      sym__backquoted_id,
    ACTIONS(6842), 1,
      sym_operator_identifier,
    STATE(5560), 1,
      sym__simple_type,
    STATE(6117), 1,
      sym_identifier,
    STATE(6232), 1,
      sym__soft_identifier,
    STATE(6391), 1,
      sym__annotated_type,
    STATE(9674), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12482), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13388), 1,
      sym__type,
    STATE(16107), 1,
      sym_parameter_types,
    STATE(17531), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3705), 2,
      sym_comment,
      sym_block_comment,
    STATE(10703), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6836), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7013), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157216] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16356), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3706), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157335] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15933), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3707), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157454] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym__,
    ACTIONS(6834), 1,
      anon_sym_LBRACK,
    ACTIONS(6838), 1,
      anon_sym_LPAREN,
    ACTIONS(6840), 1,
      sym__backquoted_id,
    ACTIONS(6842), 1,
      sym_operator_identifier,
    STATE(5560), 1,
      sym__simple_type,
    STATE(6117), 1,
      sym_identifier,
    STATE(6232), 1,
      sym__soft_identifier,
    STATE(6391), 1,
      sym__annotated_type,
    STATE(9674), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12482), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13382), 1,
      sym__type,
    STATE(16107), 1,
      sym_parameter_types,
    STATE(17531), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3708), 2,
      sym_comment,
      sym_block_comment,
    STATE(10703), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6836), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7013), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157573] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4626), 1,
      anon_sym_COLON,
    ACTIONS(4628), 1,
      anon_sym_LBRACE,
    ACTIONS(4646), 1,
      sym_integer_literal,
    ACTIONS(4868), 1,
      sym__alpha_identifier,
    ACTIONS(4870), 1,
      anon_sym__,
    ACTIONS(4874), 1,
      anon_sym_LBRACK,
    ACTIONS(4880), 1,
      sym__backquoted_id,
    ACTIONS(6848), 1,
      anon_sym_LPAREN,
    ACTIONS(6850), 1,
      sym_operator_identifier,
    STATE(5113), 1,
      sym__simple_type,
    STATE(5161), 1,
      sym__annotated_type,
    STATE(5536), 1,
      sym_identifier,
    STATE(5967), 1,
      sym__soft_identifier,
    STATE(8739), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11649), 1,
      sym__type,
    STATE(12584), 1,
      sym__infix_type_choice,
    STATE(16152), 1,
      sym_parameter_types,
    STATE(17570), 1,
      sym_stable_identifier,
    ACTIONS(4648), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4650), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4654), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3709), 2,
      sym_comment,
      sym_block_comment,
    STATE(10017), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11482), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11561), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6401), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157692] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1538), 1,
      sym_integer_literal,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym__,
    ACTIONS(6604), 1,
      anon_sym_LBRACK,
    ACTIONS(6608), 1,
      anon_sym_LPAREN,
    ACTIONS(6610), 1,
      sym__backquoted_id,
    ACTIONS(6612), 1,
      sym_operator_identifier,
    STATE(6433), 1,
      sym__simple_type,
    STATE(6449), 1,
      sym__annotated_type,
    STATE(7134), 1,
      sym__soft_identifier,
    STATE(7495), 1,
      sym_identifier,
    STATE(9897), 1,
      sym_annotated_type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11833), 1,
      sym__type,
    STATE(11834), 1,
      sym_template_body,
    STATE(12501), 1,
      sym__infix_type_choice,
    STATE(16058), 1,
      sym_parameter_types,
    STATE(17864), 1,
      sym_stable_identifier,
    ACTIONS(1540), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1542), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1546), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3710), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5996), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10820), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7557), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157811] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4626), 1,
      anon_sym_COLON,
    ACTIONS(4628), 1,
      anon_sym_LBRACE,
    ACTIONS(4646), 1,
      sym_integer_literal,
    ACTIONS(4868), 1,
      sym__alpha_identifier,
    ACTIONS(4870), 1,
      anon_sym__,
    ACTIONS(4874), 1,
      anon_sym_LBRACK,
    ACTIONS(4880), 1,
      sym__backquoted_id,
    ACTIONS(6848), 1,
      anon_sym_LPAREN,
    ACTIONS(6850), 1,
      sym_operator_identifier,
    STATE(5113), 1,
      sym__simple_type,
    STATE(5161), 1,
      sym__annotated_type,
    STATE(5536), 1,
      sym_identifier,
    STATE(5967), 1,
      sym__soft_identifier,
    STATE(8739), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11650), 1,
      sym__type,
    STATE(12584), 1,
      sym__infix_type_choice,
    STATE(16152), 1,
      sym_parameter_types,
    STATE(17570), 1,
      sym_stable_identifier,
    ACTIONS(4648), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4650), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4654), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3711), 2,
      sym_comment,
      sym_block_comment,
    STATE(10017), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11482), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11561), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6401), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [157930] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16258), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3712), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158049] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(14745), 1,
      sym__type,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3713), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158168] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17381), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3714), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158287] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15200), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3715), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158406] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15685), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3716), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158525] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15201), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3717), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158644] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4712), 1,
      sym__alpha_identifier,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4718), 1,
      anon_sym__,
    ACTIONS(4722), 1,
      anon_sym_LBRACK,
    ACTIONS(4730), 1,
      sym__backquoted_id,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6958), 1,
      anon_sym_LPAREN,
    ACTIONS(6960), 1,
      sym_operator_identifier,
    STATE(5508), 1,
      sym__annotated_type,
    STATE(6100), 1,
      sym__simple_type,
    STATE(6328), 1,
      sym__soft_identifier,
    STATE(6619), 1,
      sym_identifier,
    STATE(9270), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12853), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13401), 1,
      sym__type,
    STATE(16335), 1,
      sym_parameter_types,
    STATE(17134), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3718), 2,
      sym_comment,
      sym_block_comment,
    STATE(10600), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4724), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7010), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158763] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6716), 1,
      sym__alpha_identifier,
    ACTIONS(6718), 1,
      anon_sym_COLON,
    ACTIONS(6720), 1,
      anon_sym_LBRACE,
    ACTIONS(6722), 1,
      anon_sym__,
    ACTIONS(6724), 1,
      anon_sym_LBRACK,
    ACTIONS(6728), 1,
      anon_sym_LPAREN,
    ACTIONS(6730), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6264), 1,
      sym__annotated_type,
    STATE(6329), 1,
      sym_identifier,
    STATE(6457), 1,
      sym__soft_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(9719), 1,
      sym_annotated_type,
    STATE(11302), 1,
      sym__type,
    STATE(12746), 1,
      sym__infix_type_choice,
    STATE(15884), 1,
      sym_parameter_types,
    STATE(17539), 1,
      sym_stable_identifier,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3719), 2,
      sym_comment,
      sym_block_comment,
    STATE(10409), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11285), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6726), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7381), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [158882] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6716), 1,
      sym__alpha_identifier,
    ACTIONS(6718), 1,
      anon_sym_COLON,
    ACTIONS(6720), 1,
      anon_sym_LBRACE,
    ACTIONS(6722), 1,
      anon_sym__,
    ACTIONS(6724), 1,
      anon_sym_LBRACK,
    ACTIONS(6728), 1,
      anon_sym_LPAREN,
    ACTIONS(6730), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6264), 1,
      sym__annotated_type,
    STATE(6329), 1,
      sym_identifier,
    STATE(6457), 1,
      sym__soft_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8865), 1,
      sym__type,
    STATE(9719), 1,
      sym_annotated_type,
    STATE(12746), 1,
      sym__infix_type_choice,
    STATE(15884), 1,
      sym_parameter_types,
    STATE(17539), 1,
      sym_stable_identifier,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3720), 2,
      sym_comment,
      sym_block_comment,
    STATE(10409), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11285), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6726), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7381), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159001] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4626), 1,
      anon_sym_COLON,
    ACTIONS(4628), 1,
      anon_sym_LBRACE,
    ACTIONS(4646), 1,
      sym_integer_literal,
    ACTIONS(4868), 1,
      sym__alpha_identifier,
    ACTIONS(4870), 1,
      anon_sym__,
    ACTIONS(4874), 1,
      anon_sym_LBRACK,
    ACTIONS(4880), 1,
      sym__backquoted_id,
    ACTIONS(6848), 1,
      anon_sym_LPAREN,
    ACTIONS(6850), 1,
      sym_operator_identifier,
    STATE(5113), 1,
      sym__simple_type,
    STATE(5161), 1,
      sym__annotated_type,
    STATE(5536), 1,
      sym_identifier,
    STATE(5967), 1,
      sym__soft_identifier,
    STATE(8739), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11651), 1,
      sym__type,
    STATE(12584), 1,
      sym__infix_type_choice,
    STATE(16152), 1,
      sym_parameter_types,
    STATE(17570), 1,
      sym_stable_identifier,
    ACTIONS(4648), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4650), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4654), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3721), 2,
      sym_comment,
      sym_block_comment,
    STATE(10017), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11482), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11561), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6401), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159120] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16157), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3722), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159239] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6494), 1,
      anon_sym_LBRACK,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7175), 1,
      sym__annotated_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12512), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(14437), 1,
      sym__type,
    STATE(16155), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3723), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159358] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4280), 1,
      anon_sym_COLON,
    ACTIONS(4282), 1,
      anon_sym_LBRACE,
    ACTIONS(4300), 1,
      sym_integer_literal,
    ACTIONS(4512), 1,
      sym__alpha_identifier,
    ACTIONS(4514), 1,
      anon_sym__,
    ACTIONS(4518), 1,
      anon_sym_LBRACK,
    ACTIONS(4524), 1,
      sym__backquoted_id,
    ACTIONS(6962), 1,
      anon_sym_LPAREN,
    ACTIONS(6964), 1,
      sym_operator_identifier,
    STATE(4600), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__simple_type,
    STATE(4670), 1,
      sym_identifier,
    STATE(4696), 1,
      sym__soft_identifier,
    STATE(6758), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12343), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12714), 1,
      sym__infix_type_choice,
    STATE(15966), 1,
      sym_parameter_types,
    STATE(17301), 1,
      sym_stable_identifier,
    ACTIONS(4302), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4304), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4308), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3724), 2,
      sym_comment,
      sym_block_comment,
    STATE(8405), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12093), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12126), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4520), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5076), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159477] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16228), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3725), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159596] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15209), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3726), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159715] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6632), 1,
      sym__alpha_identifier,
    ACTIONS(6634), 1,
      anon_sym_COLON,
    ACTIONS(6636), 1,
      anon_sym_LBRACE,
    ACTIONS(6638), 1,
      anon_sym__,
    ACTIONS(6640), 1,
      anon_sym_LBRACK,
    ACTIONS(6644), 1,
      anon_sym_LPAREN,
    ACTIONS(6646), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(6650), 1,
      sym_integer_literal,
    STATE(5803), 1,
      sym__simple_type,
    STATE(6337), 1,
      sym_identifier,
    STATE(6520), 1,
      sym__annotated_type,
    STATE(6537), 1,
      sym__soft_identifier,
    STATE(9656), 1,
      sym_annotated_type,
    STATE(11261), 1,
      sym__non_null_literal,
    STATE(11360), 1,
      sym__type,
    STATE(11381), 1,
      sym_template_body,
    STATE(12477), 1,
      sym__infix_type_choice,
    STATE(16195), 1,
      sym_parameter_types,
    STATE(16798), 1,
      sym_stable_identifier,
    ACTIONS(6652), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6654), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6656), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3727), 2,
      sym_comment,
      sym_block_comment,
    STATE(10566), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11277), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11388), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11262), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6642), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6924), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159834] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15674), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3728), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [159953] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17383), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3729), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160072] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4712), 1,
      sym__alpha_identifier,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4718), 1,
      anon_sym__,
    ACTIONS(4722), 1,
      anon_sym_LBRACK,
    ACTIONS(4730), 1,
      sym__backquoted_id,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6958), 1,
      anon_sym_LPAREN,
    ACTIONS(6960), 1,
      sym_operator_identifier,
    STATE(5508), 1,
      sym__annotated_type,
    STATE(6100), 1,
      sym__simple_type,
    STATE(6328), 1,
      sym__soft_identifier,
    STATE(6619), 1,
      sym_identifier,
    STATE(9270), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12853), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13400), 1,
      sym__type,
    STATE(16335), 1,
      sym_parameter_types,
    STATE(17134), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3730), 2,
      sym_comment,
      sym_block_comment,
    STATE(10600), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4724), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7010), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160191] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15211), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3731), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160310] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4712), 1,
      sym__alpha_identifier,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4718), 1,
      anon_sym__,
    ACTIONS(4722), 1,
      anon_sym_LBRACK,
    ACTIONS(4730), 1,
      sym__backquoted_id,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6958), 1,
      anon_sym_LPAREN,
    ACTIONS(6960), 1,
      sym_operator_identifier,
    STATE(5508), 1,
      sym__annotated_type,
    STATE(6100), 1,
      sym__simple_type,
    STATE(6328), 1,
      sym__soft_identifier,
    STATE(6619), 1,
      sym_identifier,
    STATE(9270), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12853), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13405), 1,
      sym__type,
    STATE(16335), 1,
      sym_parameter_types,
    STATE(17134), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3732), 2,
      sym_comment,
      sym_block_comment,
    STATE(10600), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4724), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7010), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160429] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(14625), 1,
      sym__type,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3733), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160548] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(4342), 1,
      sym__alpha_identifier,
    ACTIONS(4344), 1,
      anon_sym__,
    ACTIONS(4348), 1,
      anon_sym_LBRACK,
    ACTIONS(4354), 1,
      sym__backquoted_id,
    ACTIONS(6936), 1,
      anon_sym_LPAREN,
    ACTIONS(6938), 1,
      sym_operator_identifier,
    STATE(7248), 1,
      sym__annotated_type,
    STATE(7255), 1,
      sym__simple_type,
    STATE(7539), 1,
      sym__soft_identifier,
    STATE(7904), 1,
      sym_identifier,
    STATE(10219), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11699), 1,
      sym__type,
    STATE(12872), 1,
      sym__infix_type_choice,
    STATE(15934), 1,
      sym_parameter_types,
    STATE(17364), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3734), 2,
      sym_comment,
      sym_block_comment,
    STATE(10976), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4350), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8693), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160667] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(14629), 1,
      sym__type,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3735), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160786] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4712), 1,
      sym__alpha_identifier,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4718), 1,
      anon_sym__,
    ACTIONS(4722), 1,
      anon_sym_LBRACK,
    ACTIONS(4730), 1,
      sym__backquoted_id,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6958), 1,
      anon_sym_LPAREN,
    ACTIONS(6960), 1,
      sym_operator_identifier,
    STATE(5508), 1,
      sym__annotated_type,
    STATE(6100), 1,
      sym__simple_type,
    STATE(6328), 1,
      sym__soft_identifier,
    STATE(6619), 1,
      sym_identifier,
    STATE(9270), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12853), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13388), 1,
      sym__type,
    STATE(16335), 1,
      sym_parameter_types,
    STATE(17134), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3736), 2,
      sym_comment,
      sym_block_comment,
    STATE(10600), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4724), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7010), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [160905] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6968), 1,
      anon_sym_COLON,
    ACTIONS(6970), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      anon_sym__,
    ACTIONS(6974), 1,
      anon_sym_LBRACK,
    ACTIONS(6978), 1,
      anon_sym_LPAREN,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(6982), 1,
      sym_operator_identifier,
    ACTIONS(6984), 1,
      sym_integer_literal,
    STATE(5099), 1,
      sym__simple_type,
    STATE(5688), 1,
      sym__annotated_type,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6043), 1,
      sym_identifier,
    STATE(9349), 1,
      sym_annotated_type,
    STATE(10982), 1,
      sym__non_null_literal,
    STATE(11063), 1,
      sym_template_body,
    STATE(11106), 1,
      sym__type,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(16218), 1,
      sym_parameter_types,
    STATE(17544), 1,
      sym_stable_identifier,
    ACTIONS(6986), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6988), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6990), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3737), 2,
      sym_comment,
      sym_block_comment,
    STATE(10151), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10959), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11010), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10979), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6339), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161024] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(14632), 1,
      sym__type,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3738), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161143] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(14633), 1,
      sym__type,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3739), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161262] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6874), 1,
      anon_sym_LBRACK,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7099), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11699), 1,
      sym__type,
    STATE(12674), 1,
      sym__infix_type_choice,
    STATE(16190), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3740), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161381] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15226), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3741), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161500] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6968), 1,
      anon_sym_COLON,
    ACTIONS(6970), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      anon_sym__,
    ACTIONS(6974), 1,
      anon_sym_LBRACK,
    ACTIONS(6978), 1,
      anon_sym_LPAREN,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(6982), 1,
      sym_operator_identifier,
    ACTIONS(6984), 1,
      sym_integer_literal,
    STATE(5099), 1,
      sym__simple_type,
    STATE(5688), 1,
      sym__annotated_type,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6043), 1,
      sym_identifier,
    STATE(9349), 1,
      sym_annotated_type,
    STATE(10982), 1,
      sym__non_null_literal,
    STATE(11063), 1,
      sym_template_body,
    STATE(11133), 1,
      sym__type,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(16218), 1,
      sym_parameter_types,
    STATE(17544), 1,
      sym_stable_identifier,
    ACTIONS(6986), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6988), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6990), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3742), 2,
      sym_comment,
      sym_block_comment,
    STATE(10151), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10959), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11010), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10979), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6339), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161619] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15230), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3743), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161738] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4712), 1,
      sym__alpha_identifier,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4718), 1,
      anon_sym__,
    ACTIONS(4722), 1,
      anon_sym_LBRACK,
    ACTIONS(4730), 1,
      sym__backquoted_id,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6958), 1,
      anon_sym_LPAREN,
    ACTIONS(6960), 1,
      sym_operator_identifier,
    STATE(5508), 1,
      sym__annotated_type,
    STATE(6100), 1,
      sym__simple_type,
    STATE(6328), 1,
      sym__soft_identifier,
    STATE(6619), 1,
      sym_identifier,
    STATE(9270), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12853), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13382), 1,
      sym__type,
    STATE(16335), 1,
      sym_parameter_types,
    STATE(17134), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3744), 2,
      sym_comment,
      sym_block_comment,
    STATE(10600), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4724), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7010), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161857] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16282), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3745), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [161976] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(14634), 1,
      sym__type,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3746), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162095] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1154), 1,
      sym_integer_literal,
    ACTIONS(6698), 1,
      sym__alpha_identifier,
    ACTIONS(6700), 1,
      anon_sym_COLON,
    ACTIONS(6702), 1,
      anon_sym_LBRACE,
    ACTIONS(6704), 1,
      anon_sym__,
    ACTIONS(6706), 1,
      anon_sym_LBRACK,
    ACTIONS(6710), 1,
      anon_sym_LPAREN,
    ACTIONS(6712), 1,
      sym__backquoted_id,
    ACTIONS(6714), 1,
      sym_operator_identifier,
    STATE(4911), 1,
      sym__annotated_type,
    STATE(4994), 1,
      sym__simple_type,
    STATE(5215), 1,
      sym__soft_identifier,
    STATE(5482), 1,
      sym_identifier,
    STATE(7805), 1,
      sym_annotated_type,
    STATE(12523), 1,
      sym__infix_type_choice,
    STATE(13093), 1,
      sym__non_null_literal,
    STATE(13398), 1,
      sym_template_body,
    STATE(13685), 1,
      sym__type,
    STATE(15974), 1,
      sym_parameter_types,
    STATE(17840), 1,
      sym_stable_identifier,
    ACTIONS(1156), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1158), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1162), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3747), 2,
      sym_comment,
      sym_block_comment,
    STATE(7810), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7970), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9980), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13091), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6708), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5743), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162214] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1538), 1,
      sym_integer_literal,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym__,
    ACTIONS(6604), 1,
      anon_sym_LBRACK,
    ACTIONS(6608), 1,
      anon_sym_LPAREN,
    ACTIONS(6610), 1,
      sym__backquoted_id,
    ACTIONS(6612), 1,
      sym_operator_identifier,
    STATE(6433), 1,
      sym__simple_type,
    STATE(6449), 1,
      sym__annotated_type,
    STATE(7134), 1,
      sym__soft_identifier,
    STATE(7495), 1,
      sym_identifier,
    STATE(9897), 1,
      sym_annotated_type,
    STATE(11755), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12501), 1,
      sym__infix_type_choice,
    STATE(16058), 1,
      sym_parameter_types,
    STATE(17864), 1,
      sym_stable_identifier,
    ACTIONS(1540), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1542), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1546), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3748), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5996), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10820), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7557), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162333] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15245), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3749), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162452] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15249), 1,
      sym__type,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3750), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162571] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    ACTIONS(6898), 1,
      anon_sym_LBRACK,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7332), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12809), 1,
      sym__infix_type_choice,
    STATE(14291), 1,
      sym__type,
    STATE(16260), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3751), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162690] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6792), 1,
      anon_sym_COLON,
    ACTIONS(6794), 1,
      anon_sym_LBRACE,
    ACTIONS(6796), 1,
      anon_sym__,
    ACTIONS(6798), 1,
      anon_sym_LBRACK,
    ACTIONS(6802), 1,
      anon_sym_LPAREN,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(6806), 1,
      sym_operator_identifier,
    ACTIONS(6808), 1,
      sym_integer_literal,
    STATE(5378), 1,
      sym__simple_type,
    STATE(5755), 1,
      sym_identifier,
    STATE(5860), 1,
      sym__annotated_type,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(9021), 1,
      sym_annotated_type,
    STATE(10969), 1,
      sym__non_null_literal,
    STATE(11083), 1,
      sym__type,
    STATE(11155), 1,
      sym_template_body,
    STATE(12851), 1,
      sym__infix_type_choice,
    STATE(16255), 1,
      sym_parameter_types,
    STATE(16984), 1,
      sym_stable_identifier,
    ACTIONS(6810), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6812), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6814), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3752), 2,
      sym_comment,
      sym_block_comment,
    STATE(10256), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10951), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11066), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10978), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162809] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1538), 1,
      sym_integer_literal,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym__,
    ACTIONS(6604), 1,
      anon_sym_LBRACK,
    ACTIONS(6608), 1,
      anon_sym_LPAREN,
    ACTIONS(6610), 1,
      sym__backquoted_id,
    ACTIONS(6612), 1,
      sym_operator_identifier,
    STATE(6433), 1,
      sym__simple_type,
    STATE(6449), 1,
      sym__annotated_type,
    STATE(7134), 1,
      sym__soft_identifier,
    STATE(7495), 1,
      sym_identifier,
    STATE(9897), 1,
      sym_annotated_type,
    STATE(11752), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12501), 1,
      sym__infix_type_choice,
    STATE(16058), 1,
      sym_parameter_types,
    STATE(17864), 1,
      sym_stable_identifier,
    ACTIONS(1540), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1542), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1546), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3753), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5996), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10820), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7557), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [162928] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1538), 1,
      sym_integer_literal,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym__,
    ACTIONS(6604), 1,
      anon_sym_LBRACK,
    ACTIONS(6608), 1,
      anon_sym_LPAREN,
    ACTIONS(6610), 1,
      sym__backquoted_id,
    ACTIONS(6612), 1,
      sym_operator_identifier,
    STATE(6433), 1,
      sym__simple_type,
    STATE(6449), 1,
      sym__annotated_type,
    STATE(7134), 1,
      sym__soft_identifier,
    STATE(7495), 1,
      sym_identifier,
    STATE(9897), 1,
      sym_annotated_type,
    STATE(11750), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12501), 1,
      sym__infix_type_choice,
    STATE(16058), 1,
      sym_parameter_types,
    STATE(17864), 1,
      sym_stable_identifier,
    ACTIONS(1540), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1542), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1546), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3754), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5996), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10820), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7557), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163047] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6792), 1,
      anon_sym_COLON,
    ACTIONS(6794), 1,
      anon_sym_LBRACE,
    ACTIONS(6796), 1,
      anon_sym__,
    ACTIONS(6798), 1,
      anon_sym_LBRACK,
    ACTIONS(6802), 1,
      anon_sym_LPAREN,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(6806), 1,
      sym_operator_identifier,
    ACTIONS(6808), 1,
      sym_integer_literal,
    STATE(5378), 1,
      sym__simple_type,
    STATE(5755), 1,
      sym_identifier,
    STATE(5860), 1,
      sym__annotated_type,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(9021), 1,
      sym_annotated_type,
    STATE(10969), 1,
      sym__non_null_literal,
    STATE(11086), 1,
      sym__type,
    STATE(11155), 1,
      sym_template_body,
    STATE(12851), 1,
      sym__infix_type_choice,
    STATE(16255), 1,
      sym_parameter_types,
    STATE(16984), 1,
      sym_stable_identifier,
    ACTIONS(6810), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6812), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6814), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3755), 2,
      sym_comment,
      sym_block_comment,
    STATE(10256), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10951), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11066), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10978), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163166] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2000), 1,
      sym_integer_literal,
    ACTIONS(6940), 1,
      sym__alpha_identifier,
    ACTIONS(6942), 1,
      anon_sym_COLON,
    ACTIONS(6944), 1,
      anon_sym_LBRACE,
    ACTIONS(6946), 1,
      anon_sym__,
    ACTIONS(6948), 1,
      anon_sym_LBRACK,
    ACTIONS(6952), 1,
      anon_sym_LPAREN,
    ACTIONS(6954), 1,
      sym__backquoted_id,
    ACTIONS(6956), 1,
      sym_operator_identifier,
    STATE(5622), 1,
      sym__simple_type,
    STATE(6024), 1,
      sym__annotated_type,
    STATE(6376), 1,
      sym__soft_identifier,
    STATE(6428), 1,
      sym_identifier,
    STATE(9297), 1,
      sym_annotated_type,
    STATE(12690), 1,
      sym__infix_type_choice,
    STATE(13747), 1,
      sym__type,
    STATE(13856), 1,
      sym_template_body,
    STATE(13862), 1,
      sym__non_null_literal,
    STATE(15972), 1,
      sym_parameter_types,
    STATE(17774), 1,
      sym_stable_identifier,
    ACTIONS(2002), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2004), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2008), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3756), 2,
      sym_comment,
      sym_block_comment,
    STATE(9114), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9333), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10596), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13863), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7299), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163285] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16224), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3757), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163404] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15660), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3758), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163523] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1306), 1,
      sym_integer_literal,
    ACTIONS(6336), 1,
      sym__alpha_identifier,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(6342), 1,
      anon_sym__,
    ACTIONS(6344), 1,
      anon_sym_LBRACK,
    ACTIONS(6348), 1,
      anon_sym_LPAREN,
    ACTIONS(6350), 1,
      sym__backquoted_id,
    ACTIONS(6352), 1,
      sym_operator_identifier,
    STATE(5944), 1,
      sym__simple_type,
    STATE(5985), 1,
      sym__annotated_type,
    STATE(6347), 1,
      sym__soft_identifier,
    STATE(6696), 1,
      sym_identifier,
    STATE(9248), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11681), 1,
      sym__type,
    STATE(12891), 1,
      sym__infix_type_choice,
    STATE(16056), 1,
      sym_parameter_types,
    STATE(17708), 1,
      sym_stable_identifier,
    ACTIONS(1308), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1310), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1314), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3759), 2,
      sym_comment,
      sym_block_comment,
    STATE(5184), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10495), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6346), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7084), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163642] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16220), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3760), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163761] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15659), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3761), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163880] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4278), 1,
      sym__alpha_identifier,
    ACTIONS(4280), 1,
      anon_sym_COLON,
    ACTIONS(4282), 1,
      anon_sym_LBRACE,
    ACTIONS(4284), 1,
      anon_sym__,
    ACTIONS(4288), 1,
      anon_sym_LBRACK,
    ACTIONS(4296), 1,
      sym__backquoted_id,
    ACTIONS(4300), 1,
      sym_integer_literal,
    ACTIONS(6992), 1,
      anon_sym_LPAREN,
    ACTIONS(6994), 1,
      sym_operator_identifier,
    STATE(6656), 1,
      sym__annotated_type,
    STATE(6764), 1,
      sym__simple_type,
    STATE(6872), 1,
      sym_identifier,
    STATE(7385), 1,
      sym__soft_identifier,
    STATE(9756), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12367), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12805), 1,
      sym__infix_type_choice,
    STATE(16363), 1,
      sym_parameter_types,
    STATE(17176), 1,
      sym_stable_identifier,
    ACTIONS(4302), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4304), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4308), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3762), 2,
      sym_comment,
      sym_block_comment,
    STATE(10874), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12093), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12126), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4290), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8228), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [163999] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15264), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3763), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164118] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15267), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3764), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164237] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4626), 1,
      anon_sym_COLON,
    ACTIONS(4628), 1,
      anon_sym_LBRACE,
    ACTIONS(4646), 1,
      sym_integer_literal,
    ACTIONS(4868), 1,
      sym__alpha_identifier,
    ACTIONS(4870), 1,
      anon_sym__,
    ACTIONS(4874), 1,
      anon_sym_LBRACK,
    ACTIONS(4880), 1,
      sym__backquoted_id,
    ACTIONS(6848), 1,
      anon_sym_LPAREN,
    ACTIONS(6850), 1,
      sym_operator_identifier,
    STATE(5113), 1,
      sym__simple_type,
    STATE(5161), 1,
      sym__annotated_type,
    STATE(5536), 1,
      sym_identifier,
    STATE(5967), 1,
      sym__soft_identifier,
    STATE(8739), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11681), 1,
      sym__type,
    STATE(12584), 1,
      sym__infix_type_choice,
    STATE(16152), 1,
      sym_parameter_types,
    STATE(17570), 1,
      sym_stable_identifier,
    ACTIONS(4648), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4650), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4654), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3765), 2,
      sym_comment,
      sym_block_comment,
    STATE(10017), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11482), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11561), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6401), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164356] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6494), 1,
      anon_sym_LBRACK,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7175), 1,
      sym__annotated_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12512), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(14558), 1,
      sym__type,
    STATE(16155), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3766), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164475] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2000), 1,
      sym_integer_literal,
    ACTIONS(6940), 1,
      sym__alpha_identifier,
    ACTIONS(6942), 1,
      anon_sym_COLON,
    ACTIONS(6944), 1,
      anon_sym_LBRACE,
    ACTIONS(6946), 1,
      anon_sym__,
    ACTIONS(6948), 1,
      anon_sym_LBRACK,
    ACTIONS(6952), 1,
      anon_sym_LPAREN,
    ACTIONS(6954), 1,
      sym__backquoted_id,
    ACTIONS(6956), 1,
      sym_operator_identifier,
    STATE(5622), 1,
      sym__simple_type,
    STATE(6024), 1,
      sym__annotated_type,
    STATE(6376), 1,
      sym__soft_identifier,
    STATE(6428), 1,
      sym_identifier,
    STATE(9297), 1,
      sym_annotated_type,
    STATE(12690), 1,
      sym__infix_type_choice,
    STATE(13741), 1,
      sym__type,
    STATE(13856), 1,
      sym_template_body,
    STATE(13862), 1,
      sym__non_null_literal,
    STATE(15972), 1,
      sym_parameter_types,
    STATE(17774), 1,
      sym_stable_identifier,
    ACTIONS(2002), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2004), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2008), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3767), 2,
      sym_comment,
      sym_block_comment,
    STATE(9114), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9333), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10596), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13863), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7299), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164594] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4280), 1,
      anon_sym_COLON,
    ACTIONS(4282), 1,
      anon_sym_LBRACE,
    ACTIONS(4300), 1,
      sym_integer_literal,
    ACTIONS(4512), 1,
      sym__alpha_identifier,
    ACTIONS(4514), 1,
      anon_sym__,
    ACTIONS(4518), 1,
      anon_sym_LBRACK,
    ACTIONS(4524), 1,
      sym__backquoted_id,
    ACTIONS(6962), 1,
      anon_sym_LPAREN,
    ACTIONS(6964), 1,
      sym_operator_identifier,
    STATE(4600), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__simple_type,
    STATE(4670), 1,
      sym_identifier,
    STATE(4696), 1,
      sym__soft_identifier,
    STATE(6758), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12345), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12714), 1,
      sym__infix_type_choice,
    STATE(15966), 1,
      sym_parameter_types,
    STATE(17301), 1,
      sym_stable_identifier,
    ACTIONS(4302), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4304), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4308), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3768), 2,
      sym_comment,
      sym_block_comment,
    STATE(8405), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12093), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12126), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4520), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5076), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164713] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2000), 1,
      sym_integer_literal,
    ACTIONS(6940), 1,
      sym__alpha_identifier,
    ACTIONS(6942), 1,
      anon_sym_COLON,
    ACTIONS(6944), 1,
      anon_sym_LBRACE,
    ACTIONS(6946), 1,
      anon_sym__,
    ACTIONS(6948), 1,
      anon_sym_LBRACK,
    ACTIONS(6952), 1,
      anon_sym_LPAREN,
    ACTIONS(6954), 1,
      sym__backquoted_id,
    ACTIONS(6956), 1,
      sym_operator_identifier,
    STATE(5622), 1,
      sym__simple_type,
    STATE(6024), 1,
      sym__annotated_type,
    STATE(6376), 1,
      sym__soft_identifier,
    STATE(6428), 1,
      sym_identifier,
    STATE(9297), 1,
      sym_annotated_type,
    STATE(12690), 1,
      sym__infix_type_choice,
    STATE(13853), 1,
      sym__type,
    STATE(13856), 1,
      sym_template_body,
    STATE(13862), 1,
      sym__non_null_literal,
    STATE(15972), 1,
      sym_parameter_types,
    STATE(17774), 1,
      sym_stable_identifier,
    ACTIONS(2002), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2004), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2008), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3769), 2,
      sym_comment,
      sym_block_comment,
    STATE(9114), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9333), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10596), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13863), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7299), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164832] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym__,
    ACTIONS(6834), 1,
      anon_sym_LBRACK,
    ACTIONS(6838), 1,
      anon_sym_LPAREN,
    ACTIONS(6840), 1,
      sym__backquoted_id,
    ACTIONS(6842), 1,
      sym_operator_identifier,
    STATE(5560), 1,
      sym__simple_type,
    STATE(6117), 1,
      sym_identifier,
    STATE(6232), 1,
      sym__soft_identifier,
    STATE(6391), 1,
      sym__annotated_type,
    STATE(9674), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12482), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(14564), 1,
      sym__type,
    STATE(16107), 1,
      sym_parameter_types,
    STATE(17531), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3770), 2,
      sym_comment,
      sym_block_comment,
    STATE(10703), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6836), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7013), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [164951] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    ACTIONS(6522), 1,
      anon_sym_LBRACK,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7325), 1,
      sym__annotated_type,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12504), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(14676), 1,
      sym__type,
    STATE(16054), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3771), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165070] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    ACTIONS(6898), 1,
      anon_sym_LBRACK,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7332), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11611), 1,
      sym__type,
    STATE(12809), 1,
      sym__infix_type_choice,
    STATE(16260), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3772), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165189] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2000), 1,
      sym_integer_literal,
    ACTIONS(6940), 1,
      sym__alpha_identifier,
    ACTIONS(6942), 1,
      anon_sym_COLON,
    ACTIONS(6944), 1,
      anon_sym_LBRACE,
    ACTIONS(6946), 1,
      anon_sym__,
    ACTIONS(6948), 1,
      anon_sym_LBRACK,
    ACTIONS(6952), 1,
      anon_sym_LPAREN,
    ACTIONS(6954), 1,
      sym__backquoted_id,
    ACTIONS(6956), 1,
      sym_operator_identifier,
    STATE(5622), 1,
      sym__simple_type,
    STATE(6024), 1,
      sym__annotated_type,
    STATE(6376), 1,
      sym__soft_identifier,
    STATE(6428), 1,
      sym_identifier,
    STATE(9297), 1,
      sym_annotated_type,
    STATE(12690), 1,
      sym__infix_type_choice,
    STATE(13727), 1,
      sym__type,
    STATE(13856), 1,
      sym_template_body,
    STATE(13862), 1,
      sym__non_null_literal,
    STATE(15972), 1,
      sym_parameter_types,
    STATE(17774), 1,
      sym_stable_identifier,
    ACTIONS(2002), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2004), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2008), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3773), 2,
      sym_comment,
      sym_block_comment,
    STATE(9114), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9333), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10596), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13863), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7299), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165308] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15644), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3774), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165427] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15642), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3775), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165546] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    ACTIONS(6898), 1,
      anon_sym_LBRACK,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7332), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11613), 1,
      sym__type,
    STATE(12809), 1,
      sym__infix_type_choice,
    STATE(16260), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3776), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165665] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    ACTIONS(6898), 1,
      anon_sym_LBRACK,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7332), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11623), 1,
      sym__type,
    STATE(12809), 1,
      sym__infix_type_choice,
    STATE(16260), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3777), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165784] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    ACTIONS(6898), 1,
      anon_sym_LBRACK,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7332), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11637), 1,
      sym__type,
    STATE(12809), 1,
      sym__infix_type_choice,
    STATE(16260), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3778), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [165903] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6874), 1,
      anon_sym_LBRACK,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7099), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11637), 1,
      sym__type,
    STATE(12674), 1,
      sym__infix_type_choice,
    STATE(16190), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3779), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166022] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15627), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3780), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166141] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12097), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3781), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166260] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4280), 1,
      anon_sym_COLON,
    ACTIONS(4282), 1,
      anon_sym_LBRACE,
    ACTIONS(4300), 1,
      sym_integer_literal,
    ACTIONS(4512), 1,
      sym__alpha_identifier,
    ACTIONS(4514), 1,
      anon_sym__,
    ACTIONS(4518), 1,
      anon_sym_LBRACK,
    ACTIONS(4524), 1,
      sym__backquoted_id,
    ACTIONS(6962), 1,
      anon_sym_LPAREN,
    ACTIONS(6964), 1,
      sym_operator_identifier,
    STATE(4600), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__simple_type,
    STATE(4670), 1,
      sym_identifier,
    STATE(4696), 1,
      sym__soft_identifier,
    STATE(6758), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12347), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12714), 1,
      sym__infix_type_choice,
    STATE(15966), 1,
      sym_parameter_types,
    STATE(17301), 1,
      sym_stable_identifier,
    ACTIONS(4302), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4304), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4308), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3782), 2,
      sym_comment,
      sym_block_comment,
    STATE(8405), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12093), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12126), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4520), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5076), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166379] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1538), 1,
      sym_integer_literal,
    ACTIONS(6360), 1,
      sym__alpha_identifier,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(6366), 1,
      anon_sym__,
    ACTIONS(6368), 1,
      anon_sym_LBRACK,
    ACTIONS(6372), 1,
      anon_sym_LPAREN,
    ACTIONS(6374), 1,
      sym__backquoted_id,
    ACTIONS(6376), 1,
      sym_operator_identifier,
    STATE(4549), 1,
      sym__simple_type,
    STATE(4564), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym_identifier,
    STATE(4788), 1,
      sym__soft_identifier,
    STATE(6732), 1,
      sym_annotated_type,
    STATE(11750), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12476), 1,
      sym__infix_type_choice,
    STATE(16111), 1,
      sym_parameter_types,
    STATE(17876), 1,
      sym_stable_identifier,
    ACTIONS(1540), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1542), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1546), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3783), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5996), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8705), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4936), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166498] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15624), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3784), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166617] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4280), 1,
      anon_sym_COLON,
    ACTIONS(4282), 1,
      anon_sym_LBRACE,
    ACTIONS(4300), 1,
      sym_integer_literal,
    ACTIONS(4512), 1,
      sym__alpha_identifier,
    ACTIONS(4514), 1,
      anon_sym__,
    ACTIONS(4518), 1,
      anon_sym_LBRACK,
    ACTIONS(4524), 1,
      sym__backquoted_id,
    ACTIONS(6962), 1,
      anon_sym_LPAREN,
    ACTIONS(6964), 1,
      sym_operator_identifier,
    STATE(4600), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__simple_type,
    STATE(4670), 1,
      sym_identifier,
    STATE(4696), 1,
      sym__soft_identifier,
    STATE(6758), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12351), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12714), 1,
      sym__infix_type_choice,
    STATE(15966), 1,
      sym_parameter_types,
    STATE(17301), 1,
      sym_stable_identifier,
    ACTIONS(4302), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4304), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4308), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3785), 2,
      sym_comment,
      sym_block_comment,
    STATE(8405), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12093), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12126), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4520), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5076), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166736] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6874), 1,
      anon_sym_LBRACK,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7099), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11623), 1,
      sym__type,
    STATE(12674), 1,
      sym__infix_type_choice,
    STATE(16190), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3786), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166855] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6874), 1,
      anon_sym_LBRACK,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7099), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11613), 1,
      sym__type,
    STATE(12674), 1,
      sym__infix_type_choice,
    STATE(16190), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3787), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [166974] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15882), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3788), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167093] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17094), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3789), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167212] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6874), 1,
      anon_sym_LBRACK,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7099), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11611), 1,
      sym__type,
    STATE(12674), 1,
      sym__infix_type_choice,
    STATE(16190), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3790), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167331] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15282), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3791), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167450] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15285), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3792), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167569] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16900), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3793), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167688] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2000), 1,
      sym_integer_literal,
    ACTIONS(6940), 1,
      sym__alpha_identifier,
    ACTIONS(6942), 1,
      anon_sym_COLON,
    ACTIONS(6944), 1,
      anon_sym_LBRACE,
    ACTIONS(6946), 1,
      anon_sym__,
    ACTIONS(6948), 1,
      anon_sym_LBRACK,
    ACTIONS(6952), 1,
      anon_sym_LPAREN,
    ACTIONS(6954), 1,
      sym__backquoted_id,
    ACTIONS(6956), 1,
      sym_operator_identifier,
    STATE(5622), 1,
      sym__simple_type,
    STATE(6024), 1,
      sym__annotated_type,
    STATE(6376), 1,
      sym__soft_identifier,
    STATE(6428), 1,
      sym_identifier,
    STATE(9297), 1,
      sym_annotated_type,
    STATE(12690), 1,
      sym__infix_type_choice,
    STATE(13856), 1,
      sym_template_body,
    STATE(13862), 1,
      sym__non_null_literal,
    STATE(14179), 1,
      sym__type,
    STATE(15972), 1,
      sym_parameter_types,
    STATE(17774), 1,
      sym_stable_identifier,
    ACTIONS(2002), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2004), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2008), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3794), 2,
      sym_comment,
      sym_block_comment,
    STATE(9114), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9333), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10596), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13863), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7299), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167807] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1118), 1,
      sym_integer_literal,
    ACTIONS(6900), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_COLON,
    ACTIONS(6904), 1,
      anon_sym_LBRACE,
    ACTIONS(6906), 1,
      anon_sym__,
    ACTIONS(6908), 1,
      anon_sym_LBRACK,
    ACTIONS(6912), 1,
      anon_sym_LPAREN,
    ACTIONS(6914), 1,
      sym__backquoted_id,
    ACTIONS(6916), 1,
      sym_operator_identifier,
    STATE(4708), 1,
      sym__annotated_type,
    STATE(4794), 1,
      sym__simple_type,
    STATE(5011), 1,
      sym_identifier,
    STATE(5013), 1,
      sym__soft_identifier,
    STATE(6935), 1,
      sym_annotated_type,
    STATE(12645), 1,
      sym_template_body,
    STATE(12704), 1,
      sym__non_null_literal,
    STATE(12720), 1,
      sym__infix_type_choice,
    STATE(12807), 1,
      sym__type,
    STATE(15971), 1,
      sym_parameter_types,
    STATE(17762), 1,
      sym_stable_identifier,
    ACTIONS(1120), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1122), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1126), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3795), 2,
      sym_comment,
      sym_block_comment,
    STATE(7087), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7186), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9279), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12703), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6910), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5168), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [167926] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16902), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3796), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168045] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(18259), 1,
      sym__type,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3797), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168164] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(14745), 1,
      sym__type,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3798), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168283] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4246), 1,
      sym__alpha_identifier,
    ACTIONS(4248), 1,
      anon_sym_COLON,
    ACTIONS(4250), 1,
      anon_sym_LBRACE,
    ACTIONS(4252), 1,
      anon_sym__,
    ACTIONS(4256), 1,
      anon_sym_LBRACK,
    ACTIONS(4264), 1,
      sym__backquoted_id,
    ACTIONS(4268), 1,
      sym_integer_literal,
    ACTIONS(6742), 1,
      anon_sym_LPAREN,
    ACTIONS(6744), 1,
      sym_operator_identifier,
    STATE(4954), 1,
      sym__annotated_type,
    STATE(5071), 1,
      sym__simple_type,
    STATE(5208), 1,
      sym__soft_identifier,
    STATE(5307), 1,
      sym_identifier,
    STATE(7704), 1,
      sym_annotated_type,
    STATE(12480), 1,
      sym__infix_type_choice,
    STATE(13419), 1,
      sym__non_null_literal,
    STATE(13569), 1,
      sym_template_body,
    STATE(13585), 1,
      sym__type,
    STATE(15629), 1,
      sym_parameter_types,
    STATE(17894), 1,
      sym_stable_identifier,
    ACTIONS(4270), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4272), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4276), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3799), 2,
      sym_comment,
      sym_block_comment,
    STATE(9633), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13603), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13681), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13410), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4258), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5976), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168402] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15609), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3800), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168521] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17474), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3801), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168640] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15606), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3802), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168759] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    ACTIONS(6898), 1,
      anon_sym_LBRACK,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7332), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12809), 1,
      sym__infix_type_choice,
    STATE(14324), 1,
      sym__type,
    STATE(16260), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3803), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168878] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15916), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3804), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [168997] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12263), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3805), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169116] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17948), 1,
      sym__type,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3806), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169235] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15300), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3807), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169354] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15303), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3808), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169473] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17472), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3809), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169592] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2106), 1,
      sym_integer_literal,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(6510), 1,
      anon_sym__,
    ACTIONS(6512), 1,
      anon_sym_LBRACK,
    ACTIONS(6516), 1,
      anon_sym_LPAREN,
    ACTIONS(6518), 1,
      sym__backquoted_id,
    ACTIONS(6520), 1,
      sym_operator_identifier,
    STATE(7064), 1,
      sym__simple_type,
    STATE(7487), 1,
      sym__annotated_type,
    STATE(7863), 1,
      sym__soft_identifier,
    STATE(8147), 1,
      sym_identifier,
    STATE(10066), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12325), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12834), 1,
      sym__infix_type_choice,
    STATE(16057), 1,
      sym_parameter_types,
    STATE(17720), 1,
      sym_stable_identifier,
    ACTIONS(2108), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2110), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2114), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3810), 2,
      sym_comment,
      sym_block_comment,
    STATE(6362), 2,
      sym_boolean_literal,
      sym_string,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11043), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6514), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169711] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2106), 1,
      sym_integer_literal,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(6510), 1,
      anon_sym__,
    ACTIONS(6512), 1,
      anon_sym_LBRACK,
    ACTIONS(6516), 1,
      anon_sym_LPAREN,
    ACTIONS(6518), 1,
      sym__backquoted_id,
    ACTIONS(6520), 1,
      sym_operator_identifier,
    STATE(7064), 1,
      sym__simple_type,
    STATE(7487), 1,
      sym__annotated_type,
    STATE(7863), 1,
      sym__soft_identifier,
    STATE(8147), 1,
      sym_identifier,
    STATE(10066), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12315), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12834), 1,
      sym__infix_type_choice,
    STATE(16057), 1,
      sym_parameter_types,
    STATE(17720), 1,
      sym_stable_identifier,
    ACTIONS(2108), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2110), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2114), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3811), 2,
      sym_comment,
      sym_block_comment,
    STATE(6362), 2,
      sym_boolean_literal,
      sym_string,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11043), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6514), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169830] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2106), 1,
      sym_integer_literal,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(6510), 1,
      anon_sym__,
    ACTIONS(6512), 1,
      anon_sym_LBRACK,
    ACTIONS(6516), 1,
      anon_sym_LPAREN,
    ACTIONS(6518), 1,
      sym__backquoted_id,
    ACTIONS(6520), 1,
      sym_operator_identifier,
    STATE(7064), 1,
      sym__simple_type,
    STATE(7487), 1,
      sym__annotated_type,
    STATE(7863), 1,
      sym__soft_identifier,
    STATE(8147), 1,
      sym_identifier,
    STATE(10066), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12314), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12834), 1,
      sym__infix_type_choice,
    STATE(16057), 1,
      sym_parameter_types,
    STATE(17720), 1,
      sym_stable_identifier,
    ACTIONS(2108), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2110), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2114), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3812), 2,
      sym_comment,
      sym_block_comment,
    STATE(6362), 2,
      sym_boolean_literal,
      sym_string,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11043), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6514), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [169949] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17090), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3813), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170068] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2106), 1,
      sym_integer_literal,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(6510), 1,
      anon_sym__,
    ACTIONS(6512), 1,
      anon_sym_LBRACK,
    ACTIONS(6516), 1,
      anon_sym_LPAREN,
    ACTIONS(6518), 1,
      sym__backquoted_id,
    ACTIONS(6520), 1,
      sym_operator_identifier,
    STATE(7064), 1,
      sym__simple_type,
    STATE(7487), 1,
      sym__annotated_type,
    STATE(7863), 1,
      sym__soft_identifier,
    STATE(8147), 1,
      sym_identifier,
    STATE(10066), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12310), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12834), 1,
      sym__infix_type_choice,
    STATE(16057), 1,
      sym_parameter_types,
    STATE(17720), 1,
      sym_stable_identifier,
    ACTIONS(2108), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2110), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2114), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3814), 2,
      sym_comment,
      sym_block_comment,
    STATE(6362), 2,
      sym_boolean_literal,
      sym_string,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11043), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6514), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170187] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16231), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3815), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170306] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(17946), 1,
      sym__type,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3816), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170425] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15591), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3817), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170544] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15318), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3818), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170663] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15588), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3819), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170782] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15321), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3820), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [170901] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6716), 1,
      sym__alpha_identifier,
    ACTIONS(6718), 1,
      anon_sym_COLON,
    ACTIONS(6720), 1,
      anon_sym_LBRACE,
    ACTIONS(6722), 1,
      anon_sym__,
    ACTIONS(6724), 1,
      anon_sym_LBRACK,
    ACTIONS(6728), 1,
      anon_sym_LPAREN,
    ACTIONS(6730), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6264), 1,
      sym__annotated_type,
    STATE(6329), 1,
      sym_identifier,
    STATE(6457), 1,
      sym__soft_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8584), 1,
      sym__type,
    STATE(9719), 1,
      sym_annotated_type,
    STATE(12746), 1,
      sym__infix_type_choice,
    STATE(15884), 1,
      sym_parameter_types,
    STATE(17539), 1,
      sym_stable_identifier,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3821), 2,
      sym_comment,
      sym_block_comment,
    STATE(10409), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11285), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6726), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7381), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171020] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16252), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3822), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171139] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6456), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8051), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11736), 1,
      sym__non_null_literal,
    STATE(11748), 1,
      sym_template_body,
    STATE(12021), 1,
      sym__type,
    STATE(12496), 1,
      sym__infix_type_choice,
    STATE(16167), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3823), 2,
      sym_comment,
      sym_block_comment,
    STATE(11058), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11804), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11740), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171258] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1190), 1,
      sym_integer_literal,
    ACTIONS(6378), 1,
      sym__alpha_identifier,
    ACTIONS(6380), 1,
      anon_sym_COLON,
    ACTIONS(6382), 1,
      anon_sym_LBRACE,
    ACTIONS(6384), 1,
      anon_sym__,
    ACTIONS(6386), 1,
      anon_sym_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_LPAREN,
    ACTIONS(6392), 1,
      sym__backquoted_id,
    ACTIONS(6394), 1,
      sym_operator_identifier,
    STATE(4833), 1,
      sym__annotated_type,
    STATE(5085), 1,
      sym__simple_type,
    STATE(5211), 1,
      sym__soft_identifier,
    STATE(5401), 1,
      sym_identifier,
    STATE(7726), 1,
      sym_annotated_type,
    STATE(12474), 1,
      sym__infix_type_choice,
    STATE(13143), 1,
      sym__type,
    STATE(13245), 1,
      sym_template_body,
    STATE(13295), 1,
      sym__non_null_literal,
    STATE(15977), 1,
      sym_parameter_types,
    STATE(17882), 1,
      sym_stable_identifier,
    ACTIONS(1192), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1194), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1198), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3824), 2,
      sym_comment,
      sym_block_comment,
    STATE(7888), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8149), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9700), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13299), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5762), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171377] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(14787), 1,
      sym__type,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3825), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171496] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16206), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3826), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171615] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16262), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3827), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171734] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15573), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3828), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171853] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15850), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3829), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [171972] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6632), 1,
      sym__alpha_identifier,
    ACTIONS(6634), 1,
      anon_sym_COLON,
    ACTIONS(6636), 1,
      anon_sym_LBRACE,
    ACTIONS(6638), 1,
      anon_sym__,
    ACTIONS(6640), 1,
      anon_sym_LBRACK,
    ACTIONS(6644), 1,
      anon_sym_LPAREN,
    ACTIONS(6646), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(6650), 1,
      sym_integer_literal,
    STATE(5803), 1,
      sym__simple_type,
    STATE(6337), 1,
      sym_identifier,
    STATE(6520), 1,
      sym__annotated_type,
    STATE(6537), 1,
      sym__soft_identifier,
    STATE(9656), 1,
      sym_annotated_type,
    STATE(11261), 1,
      sym__non_null_literal,
    STATE(11368), 1,
      sym__type,
    STATE(11381), 1,
      sym_template_body,
    STATE(12477), 1,
      sym__infix_type_choice,
    STATE(16195), 1,
      sym_parameter_types,
    STATE(16798), 1,
      sym_stable_identifier,
    ACTIONS(6652), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6654), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6656), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3830), 2,
      sym_comment,
      sym_block_comment,
    STATE(10566), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11277), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11388), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11262), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6642), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6924), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172091] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4280), 1,
      anon_sym_COLON,
    ACTIONS(4282), 1,
      anon_sym_LBRACE,
    ACTIONS(4300), 1,
      sym_integer_literal,
    ACTIONS(4512), 1,
      sym__alpha_identifier,
    ACTIONS(4514), 1,
      anon_sym__,
    ACTIONS(4518), 1,
      anon_sym_LBRACK,
    ACTIONS(4524), 1,
      sym__backquoted_id,
    ACTIONS(6962), 1,
      anon_sym_LPAREN,
    ACTIONS(6964), 1,
      sym_operator_identifier,
    STATE(4600), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__simple_type,
    STATE(4670), 1,
      sym_identifier,
    STATE(4696), 1,
      sym__soft_identifier,
    STATE(6758), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12367), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12714), 1,
      sym__infix_type_choice,
    STATE(15966), 1,
      sym_parameter_types,
    STATE(17301), 1,
      sym_stable_identifier,
    ACTIONS(4302), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4304), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4308), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3831), 2,
      sym_comment,
      sym_block_comment,
    STATE(8405), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12093), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12126), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4520), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5076), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172210] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6716), 1,
      sym__alpha_identifier,
    ACTIONS(6718), 1,
      anon_sym_COLON,
    ACTIONS(6720), 1,
      anon_sym_LBRACE,
    ACTIONS(6722), 1,
      anon_sym__,
    ACTIONS(6724), 1,
      anon_sym_LBRACK,
    ACTIONS(6728), 1,
      anon_sym_LPAREN,
    ACTIONS(6730), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6264), 1,
      sym__annotated_type,
    STATE(6329), 1,
      sym_identifier,
    STATE(6457), 1,
      sym__soft_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8499), 1,
      sym__type,
    STATE(9719), 1,
      sym_annotated_type,
    STATE(12746), 1,
      sym__infix_type_choice,
    STATE(15884), 1,
      sym_parameter_types,
    STATE(17539), 1,
      sym_stable_identifier,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3832), 2,
      sym_comment,
      sym_block_comment,
    STATE(10409), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11285), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6726), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7381), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172329] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15336), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3833), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172448] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1190), 1,
      sym_integer_literal,
    ACTIONS(6378), 1,
      sym__alpha_identifier,
    ACTIONS(6380), 1,
      anon_sym_COLON,
    ACTIONS(6382), 1,
      anon_sym_LBRACE,
    ACTIONS(6384), 1,
      anon_sym__,
    ACTIONS(6386), 1,
      anon_sym_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_LPAREN,
    ACTIONS(6392), 1,
      sym__backquoted_id,
    ACTIONS(6394), 1,
      sym_operator_identifier,
    STATE(4833), 1,
      sym__annotated_type,
    STATE(5085), 1,
      sym__simple_type,
    STATE(5211), 1,
      sym__soft_identifier,
    STATE(5401), 1,
      sym_identifier,
    STATE(7726), 1,
      sym_annotated_type,
    STATE(12474), 1,
      sym__infix_type_choice,
    STATE(13059), 1,
      sym__type,
    STATE(13245), 1,
      sym_template_body,
    STATE(13295), 1,
      sym__non_null_literal,
    STATE(15977), 1,
      sym_parameter_types,
    STATE(17882), 1,
      sym_stable_identifier,
    ACTIONS(1192), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1194), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1198), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3834), 2,
      sym_comment,
      sym_block_comment,
    STATE(7888), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8149), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9700), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13299), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5762), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172567] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15570), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3835), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172686] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6716), 1,
      sym__alpha_identifier,
    ACTIONS(6718), 1,
      anon_sym_COLON,
    ACTIONS(6720), 1,
      anon_sym_LBRACE,
    ACTIONS(6722), 1,
      anon_sym__,
    ACTIONS(6724), 1,
      anon_sym_LBRACK,
    ACTIONS(6728), 1,
      anon_sym_LPAREN,
    ACTIONS(6730), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6264), 1,
      sym__annotated_type,
    STATE(6329), 1,
      sym_identifier,
    STATE(6457), 1,
      sym__soft_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8491), 1,
      sym__type,
    STATE(9719), 1,
      sym_annotated_type,
    STATE(12746), 1,
      sym__infix_type_choice,
    STATE(15884), 1,
      sym_parameter_types,
    STATE(17539), 1,
      sym_stable_identifier,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3836), 2,
      sym_comment,
      sym_block_comment,
    STATE(10409), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11285), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6726), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7381), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172805] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(18262), 1,
      sym__type,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3837), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [172924] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6716), 1,
      sym__alpha_identifier,
    ACTIONS(6718), 1,
      anon_sym_COLON,
    ACTIONS(6720), 1,
      anon_sym_LBRACE,
    ACTIONS(6722), 1,
      anon_sym__,
    ACTIONS(6724), 1,
      anon_sym_LBRACK,
    ACTIONS(6728), 1,
      anon_sym_LPAREN,
    ACTIONS(6730), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(6734), 1,
      sym_integer_literal,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6264), 1,
      sym__annotated_type,
    STATE(6329), 1,
      sym_identifier,
    STATE(6457), 1,
      sym__soft_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8482), 1,
      sym__type,
    STATE(9719), 1,
      sym_annotated_type,
    STATE(12746), 1,
      sym__infix_type_choice,
    STATE(15884), 1,
      sym_parameter_types,
    STATE(17539), 1,
      sym_stable_identifier,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3838), 2,
      sym_comment,
      sym_block_comment,
    STATE(10409), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11285), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6726), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7381), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173043] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6878), 1,
      anon_sym_LPAREN,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    ACTIONS(6898), 1,
      anon_sym_LBRACK,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7332), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11699), 1,
      sym__type,
    STATE(12809), 1,
      sym__infix_type_choice,
    STATE(16260), 1,
      sym_parameter_types,
    STATE(16940), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3839), 2,
      sym_comment,
      sym_block_comment,
    STATE(10695), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173162] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2106), 1,
      sym_integer_literal,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(6510), 1,
      anon_sym__,
    ACTIONS(6512), 1,
      anon_sym_LBRACK,
    ACTIONS(6516), 1,
      anon_sym_LPAREN,
    ACTIONS(6518), 1,
      sym__backquoted_id,
    ACTIONS(6520), 1,
      sym_operator_identifier,
    STATE(7064), 1,
      sym__simple_type,
    STATE(7487), 1,
      sym__annotated_type,
    STATE(7863), 1,
      sym__soft_identifier,
    STATE(8147), 1,
      sym_identifier,
    STATE(10066), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12349), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12834), 1,
      sym__infix_type_choice,
    STATE(16057), 1,
      sym_parameter_types,
    STATE(17720), 1,
      sym_stable_identifier,
    ACTIONS(2108), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2110), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2114), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3840), 2,
      sym_comment,
      sym_block_comment,
    STATE(6362), 2,
      sym_boolean_literal,
      sym_string,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11043), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6514), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173281] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(14634), 1,
      sym__type,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3841), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173400] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12278), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3842), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173519] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6968), 1,
      anon_sym_COLON,
    ACTIONS(6970), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      anon_sym__,
    ACTIONS(6974), 1,
      anon_sym_LBRACK,
    ACTIONS(6978), 1,
      anon_sym_LPAREN,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(6982), 1,
      sym_operator_identifier,
    ACTIONS(6984), 1,
      sym_integer_literal,
    STATE(5099), 1,
      sym__simple_type,
    STATE(5688), 1,
      sym__annotated_type,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6043), 1,
      sym_identifier,
    STATE(9349), 1,
      sym_annotated_type,
    STATE(10982), 1,
      sym__non_null_literal,
    STATE(11063), 1,
      sym_template_body,
    STATE(11150), 1,
      sym__type,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(16218), 1,
      sym_parameter_types,
    STATE(17544), 1,
      sym_stable_identifier,
    ACTIONS(6986), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6988), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6990), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3843), 2,
      sym_comment,
      sym_block_comment,
    STATE(10151), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10959), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11010), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10979), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6339), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173638] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(6996), 1,
      sym__alpha_identifier,
    ACTIONS(6998), 1,
      anon_sym__,
    ACTIONS(7000), 1,
      anon_sym_LBRACK,
    ACTIONS(7004), 1,
      anon_sym_LPAREN,
    ACTIONS(7006), 1,
      sym__backquoted_id,
    ACTIONS(7008), 1,
      sym_operator_identifier,
    STATE(6559), 1,
      sym__simple_type,
    STATE(6560), 1,
      sym__annotated_type,
    STATE(7238), 1,
      sym_identifier,
    STATE(7458), 1,
      sym__soft_identifier,
    STATE(9877), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(12011), 1,
      sym_template_body,
    STATE(12272), 1,
      sym__type,
    STATE(12782), 1,
      sym__infix_type_choice,
    STATE(16053), 1,
      sym_parameter_types,
    STATE(17218), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3844), 2,
      sym_comment,
      sym_block_comment,
    STATE(5668), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10785), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(7002), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8023), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173757] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11699), 1,
      sym__type,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3845), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173876] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11637), 1,
      sym__type,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3846), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [173995] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11623), 1,
      sym__type,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3847), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174114] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11613), 1,
      sym__type,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3848), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174233] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6860), 1,
      anon_sym_LBRACK,
    ACTIONS(6864), 1,
      anon_sym_LPAREN,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    STATE(4844), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11611), 1,
      sym__type,
    STATE(12622), 1,
      sym__infix_type_choice,
    STATE(16227), 1,
      sym_parameter_types,
    STATE(16918), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3849), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(9647), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174352] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16142), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3850), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174471] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1118), 1,
      sym_integer_literal,
    ACTIONS(6900), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_COLON,
    ACTIONS(6904), 1,
      anon_sym_LBRACE,
    ACTIONS(6906), 1,
      anon_sym__,
    ACTIONS(6908), 1,
      anon_sym_LBRACK,
    ACTIONS(6912), 1,
      anon_sym_LPAREN,
    ACTIONS(6914), 1,
      sym__backquoted_id,
    ACTIONS(6916), 1,
      sym_operator_identifier,
    STATE(4708), 1,
      sym__annotated_type,
    STATE(4794), 1,
      sym__simple_type,
    STATE(5011), 1,
      sym_identifier,
    STATE(5013), 1,
      sym__soft_identifier,
    STATE(6935), 1,
      sym_annotated_type,
    STATE(12645), 1,
      sym_template_body,
    STATE(12704), 1,
      sym__non_null_literal,
    STATE(12720), 1,
      sym__infix_type_choice,
    STATE(12839), 1,
      sym__type,
    STATE(15971), 1,
      sym_parameter_types,
    STATE(17762), 1,
      sym_stable_identifier,
    ACTIONS(1120), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1122), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1126), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3851), 2,
      sym_comment,
      sym_block_comment,
    STATE(7087), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7186), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9279), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12703), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6910), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5168), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174590] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1118), 1,
      sym_integer_literal,
    ACTIONS(6900), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_COLON,
    ACTIONS(6904), 1,
      anon_sym_LBRACE,
    ACTIONS(6906), 1,
      anon_sym__,
    ACTIONS(6908), 1,
      anon_sym_LBRACK,
    ACTIONS(6912), 1,
      anon_sym_LPAREN,
    ACTIONS(6914), 1,
      sym__backquoted_id,
    ACTIONS(6916), 1,
      sym_operator_identifier,
    STATE(4708), 1,
      sym__annotated_type,
    STATE(4794), 1,
      sym__simple_type,
    STATE(5011), 1,
      sym_identifier,
    STATE(5013), 1,
      sym__soft_identifier,
    STATE(6935), 1,
      sym_annotated_type,
    STATE(12645), 1,
      sym_template_body,
    STATE(12704), 1,
      sym__non_null_literal,
    STATE(12720), 1,
      sym__infix_type_choice,
    STATE(12833), 1,
      sym__type,
    STATE(15971), 1,
      sym_parameter_types,
    STATE(17762), 1,
      sym_stable_identifier,
    ACTIONS(1120), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1122), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1126), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3852), 2,
      sym_comment,
      sym_block_comment,
    STATE(7087), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7186), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9279), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12703), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6910), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5168), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174709] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6494), 1,
      anon_sym_LBRACK,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7175), 1,
      sym__annotated_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12512), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13382), 1,
      sym__type,
    STATE(16155), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3853), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174828] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6968), 1,
      anon_sym_COLON,
    ACTIONS(6970), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      anon_sym__,
    ACTIONS(6974), 1,
      anon_sym_LBRACK,
    ACTIONS(6978), 1,
      anon_sym_LPAREN,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(6982), 1,
      sym_operator_identifier,
    ACTIONS(6984), 1,
      sym_integer_literal,
    STATE(5099), 1,
      sym__simple_type,
    STATE(5688), 1,
      sym__annotated_type,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6043), 1,
      sym_identifier,
    STATE(9349), 1,
      sym_annotated_type,
    STATE(10982), 1,
      sym__non_null_literal,
    STATE(11063), 1,
      sym_template_body,
    STATE(11158), 1,
      sym__type,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(16218), 1,
      sym_parameter_types,
    STATE(17544), 1,
      sym_stable_identifier,
    ACTIONS(6986), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6988), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6990), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3854), 2,
      sym_comment,
      sym_block_comment,
    STATE(10151), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10959), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11010), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10979), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6339), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [174947] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1190), 1,
      sym_integer_literal,
    ACTIONS(6378), 1,
      sym__alpha_identifier,
    ACTIONS(6380), 1,
      anon_sym_COLON,
    ACTIONS(6382), 1,
      anon_sym_LBRACE,
    ACTIONS(6384), 1,
      anon_sym__,
    ACTIONS(6386), 1,
      anon_sym_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_LPAREN,
    ACTIONS(6392), 1,
      sym__backquoted_id,
    ACTIONS(6394), 1,
      sym_operator_identifier,
    STATE(4833), 1,
      sym__annotated_type,
    STATE(5085), 1,
      sym__simple_type,
    STATE(5211), 1,
      sym__soft_identifier,
    STATE(5401), 1,
      sym_identifier,
    STATE(7726), 1,
      sym_annotated_type,
    STATE(12474), 1,
      sym__infix_type_choice,
    STATE(13154), 1,
      sym__type,
    STATE(13245), 1,
      sym_template_body,
    STATE(13295), 1,
      sym__non_null_literal,
    STATE(15977), 1,
      sym_parameter_types,
    STATE(17882), 1,
      sym_stable_identifier,
    ACTIONS(1192), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1194), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1198), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3855), 2,
      sym_comment,
      sym_block_comment,
    STATE(7888), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8149), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9700), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13299), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5762), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175066] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1190), 1,
      sym_integer_literal,
    ACTIONS(6378), 1,
      sym__alpha_identifier,
    ACTIONS(6380), 1,
      anon_sym_COLON,
    ACTIONS(6382), 1,
      anon_sym_LBRACE,
    ACTIONS(6384), 1,
      anon_sym__,
    ACTIONS(6386), 1,
      anon_sym_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_LPAREN,
    ACTIONS(6392), 1,
      sym__backquoted_id,
    ACTIONS(6394), 1,
      sym_operator_identifier,
    STATE(4833), 1,
      sym__annotated_type,
    STATE(5085), 1,
      sym__simple_type,
    STATE(5211), 1,
      sym__soft_identifier,
    STATE(5401), 1,
      sym_identifier,
    STATE(7726), 1,
      sym_annotated_type,
    STATE(12474), 1,
      sym__infix_type_choice,
    STATE(13158), 1,
      sym__type,
    STATE(13245), 1,
      sym_template_body,
    STATE(13295), 1,
      sym__non_null_literal,
    STATE(15977), 1,
      sym_parameter_types,
    STATE(17882), 1,
      sym_stable_identifier,
    ACTIONS(1192), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1194), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1198), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3856), 2,
      sym_comment,
      sym_block_comment,
    STATE(7888), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8149), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9700), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13299), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5762), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175185] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1118), 1,
      sym_integer_literal,
    ACTIONS(6900), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_COLON,
    ACTIONS(6904), 1,
      anon_sym_LBRACE,
    ACTIONS(6906), 1,
      anon_sym__,
    ACTIONS(6908), 1,
      anon_sym_LBRACK,
    ACTIONS(6912), 1,
      anon_sym_LPAREN,
    ACTIONS(6914), 1,
      sym__backquoted_id,
    ACTIONS(6916), 1,
      sym_operator_identifier,
    STATE(4708), 1,
      sym__annotated_type,
    STATE(4794), 1,
      sym__simple_type,
    STATE(5011), 1,
      sym_identifier,
    STATE(5013), 1,
      sym__soft_identifier,
    STATE(6935), 1,
      sym_annotated_type,
    STATE(12645), 1,
      sym_template_body,
    STATE(12704), 1,
      sym__non_null_literal,
    STATE(12720), 1,
      sym__infix_type_choice,
    STATE(12817), 1,
      sym__type,
    STATE(15971), 1,
      sym_parameter_types,
    STATE(17762), 1,
      sym_stable_identifier,
    ACTIONS(1120), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1122), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1126), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3857), 2,
      sym_comment,
      sym_block_comment,
    STATE(7087), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7186), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9279), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12703), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6910), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5168), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175304] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15989), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3858), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175423] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1538), 1,
      sym_integer_literal,
    ACTIONS(6360), 1,
      sym__alpha_identifier,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(6366), 1,
      anon_sym__,
    ACTIONS(6368), 1,
      anon_sym_LBRACK,
    ACTIONS(6372), 1,
      anon_sym_LPAREN,
    ACTIONS(6374), 1,
      sym__backquoted_id,
    ACTIONS(6376), 1,
      sym_operator_identifier,
    STATE(4549), 1,
      sym__simple_type,
    STATE(4564), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym_identifier,
    STATE(4788), 1,
      sym__soft_identifier,
    STATE(6732), 1,
      sym_annotated_type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11833), 1,
      sym__type,
    STATE(11834), 1,
      sym_template_body,
    STATE(12476), 1,
      sym__infix_type_choice,
    STATE(16111), 1,
      sym_parameter_types,
    STATE(17876), 1,
      sym_stable_identifier,
    ACTIONS(1540), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1542), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1546), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3859), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5996), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8705), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4936), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175542] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16370), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3860), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175661] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4278), 1,
      sym__alpha_identifier,
    ACTIONS(4280), 1,
      anon_sym_COLON,
    ACTIONS(4282), 1,
      anon_sym_LBRACE,
    ACTIONS(4284), 1,
      anon_sym__,
    ACTIONS(4288), 1,
      anon_sym_LBRACK,
    ACTIONS(4296), 1,
      sym__backquoted_id,
    ACTIONS(4300), 1,
      sym_integer_literal,
    ACTIONS(6992), 1,
      anon_sym_LPAREN,
    ACTIONS(6994), 1,
      sym_operator_identifier,
    STATE(6656), 1,
      sym__annotated_type,
    STATE(6764), 1,
      sym__simple_type,
    STATE(6872), 1,
      sym_identifier,
    STATE(7385), 1,
      sym__soft_identifier,
    STATE(9756), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12351), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12805), 1,
      sym__infix_type_choice,
    STATE(16363), 1,
      sym_parameter_types,
    STATE(17176), 1,
      sym_stable_identifier,
    ACTIONS(4302), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4304), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4308), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3861), 2,
      sym_comment,
      sym_block_comment,
    STATE(10874), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12093), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12126), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4290), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8228), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175780] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6494), 1,
      anon_sym_LBRACK,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7175), 1,
      sym__annotated_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12512), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13405), 1,
      sym__type,
    STATE(16155), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3862), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [175899] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4278), 1,
      sym__alpha_identifier,
    ACTIONS(4280), 1,
      anon_sym_COLON,
    ACTIONS(4282), 1,
      anon_sym_LBRACE,
    ACTIONS(4284), 1,
      anon_sym__,
    ACTIONS(4288), 1,
      anon_sym_LBRACK,
    ACTIONS(4296), 1,
      sym__backquoted_id,
    ACTIONS(4300), 1,
      sym_integer_literal,
    ACTIONS(6992), 1,
      anon_sym_LPAREN,
    ACTIONS(6994), 1,
      sym_operator_identifier,
    STATE(6656), 1,
      sym__annotated_type,
    STATE(6764), 1,
      sym__simple_type,
    STATE(6872), 1,
      sym_identifier,
    STATE(7385), 1,
      sym__soft_identifier,
    STATE(9756), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12347), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12805), 1,
      sym__infix_type_choice,
    STATE(16363), 1,
      sym_parameter_types,
    STATE(17176), 1,
      sym_stable_identifier,
    ACTIONS(4302), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4304), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4308), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3863), 2,
      sym_comment,
      sym_block_comment,
    STATE(10874), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12093), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12126), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4290), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8228), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176018] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4278), 1,
      sym__alpha_identifier,
    ACTIONS(4280), 1,
      anon_sym_COLON,
    ACTIONS(4282), 1,
      anon_sym_LBRACE,
    ACTIONS(4284), 1,
      anon_sym__,
    ACTIONS(4288), 1,
      anon_sym_LBRACK,
    ACTIONS(4296), 1,
      sym__backquoted_id,
    ACTIONS(4300), 1,
      sym_integer_literal,
    ACTIONS(6992), 1,
      anon_sym_LPAREN,
    ACTIONS(6994), 1,
      sym_operator_identifier,
    STATE(6656), 1,
      sym__annotated_type,
    STATE(6764), 1,
      sym__simple_type,
    STATE(6872), 1,
      sym_identifier,
    STATE(7385), 1,
      sym__soft_identifier,
    STATE(9756), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12345), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12805), 1,
      sym__infix_type_choice,
    STATE(16363), 1,
      sym_parameter_types,
    STATE(17176), 1,
      sym_stable_identifier,
    ACTIONS(4302), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4304), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4308), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3864), 2,
      sym_comment,
      sym_block_comment,
    STATE(10874), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12093), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12126), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4290), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8228), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176137] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4278), 1,
      sym__alpha_identifier,
    ACTIONS(4280), 1,
      anon_sym_COLON,
    ACTIONS(4282), 1,
      anon_sym_LBRACE,
    ACTIONS(4284), 1,
      anon_sym__,
    ACTIONS(4288), 1,
      anon_sym_LBRACK,
    ACTIONS(4296), 1,
      sym__backquoted_id,
    ACTIONS(4300), 1,
      sym_integer_literal,
    ACTIONS(6992), 1,
      anon_sym_LPAREN,
    ACTIONS(6994), 1,
      sym_operator_identifier,
    STATE(6656), 1,
      sym__annotated_type,
    STATE(6764), 1,
      sym__simple_type,
    STATE(6872), 1,
      sym_identifier,
    STATE(7385), 1,
      sym__soft_identifier,
    STATE(9756), 1,
      sym_annotated_type,
    STATE(12120), 1,
      sym_template_body,
    STATE(12343), 1,
      sym__type,
    STATE(12371), 1,
      sym__non_null_literal,
    STATE(12805), 1,
      sym__infix_type_choice,
    STATE(16363), 1,
      sym_parameter_types,
    STATE(17176), 1,
      sym_stable_identifier,
    ACTIONS(4302), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4304), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4308), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3865), 2,
      sym_comment,
      sym_block_comment,
    STATE(10874), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12093), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12126), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12448), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4290), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8228), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176256] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6968), 1,
      anon_sym_COLON,
    ACTIONS(6970), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      anon_sym__,
    ACTIONS(6974), 1,
      anon_sym_LBRACK,
    ACTIONS(6978), 1,
      anon_sym_LPAREN,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(6982), 1,
      sym_operator_identifier,
    ACTIONS(6984), 1,
      sym_integer_literal,
    STATE(5099), 1,
      sym__simple_type,
    STATE(5688), 1,
      sym__annotated_type,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6043), 1,
      sym_identifier,
    STATE(9349), 1,
      sym_annotated_type,
    STATE(10982), 1,
      sym__non_null_literal,
    STATE(11063), 1,
      sym_template_body,
    STATE(11160), 1,
      sym__type,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(16218), 1,
      sym_parameter_types,
    STATE(17544), 1,
      sym_stable_identifier,
    ACTIONS(6986), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6988), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6990), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3866), 2,
      sym_comment,
      sym_block_comment,
    STATE(10151), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10959), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11010), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10979), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6339), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176375] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16280), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3867), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176494] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16286), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3868), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176613] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6918), 1,
      sym__alpha_identifier,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(6924), 1,
      anon_sym__,
    ACTIONS(6926), 1,
      anon_sym_LBRACK,
    ACTIONS(6930), 1,
      anon_sym_LPAREN,
    ACTIONS(6932), 1,
      sym__backquoted_id,
    ACTIONS(6934), 1,
      sym_operator_identifier,
    STATE(4539), 1,
      sym__annotated_type,
    STATE(4612), 1,
      sym__simple_type,
    STATE(4637), 1,
      sym_identifier,
    STATE(4714), 1,
      sym__soft_identifier,
    STATE(6684), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(12011), 1,
      sym_template_body,
    STATE(12272), 1,
      sym__type,
    STATE(12667), 1,
      sym__infix_type_choice,
    STATE(16106), 1,
      sym_parameter_types,
    STATE(17341), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3869), 2,
      sym_comment,
      sym_block_comment,
    STATE(5668), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8299), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6928), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5056), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176732] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6494), 1,
      anon_sym_LBRACK,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7175), 1,
      sym__annotated_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12512), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13401), 1,
      sym__type,
    STATE(16155), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3870), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176851] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2106), 1,
      sym_integer_literal,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(6754), 1,
      sym__alpha_identifier,
    ACTIONS(6756), 1,
      anon_sym__,
    ACTIONS(6758), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_LPAREN,
    ACTIONS(6764), 1,
      sym__backquoted_id,
    ACTIONS(6766), 1,
      sym_operator_identifier,
    STATE(4748), 1,
      sym__simple_type,
    STATE(4761), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym_identifier,
    STATE(4998), 1,
      sym__soft_identifier,
    STATE(6891), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12349), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12756), 1,
      sym__infix_type_choice,
    STATE(16110), 1,
      sym_parameter_types,
    STATE(17750), 1,
      sym_stable_identifier,
    ACTIONS(2108), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2110), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2114), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3871), 2,
      sym_comment,
      sym_block_comment,
    STATE(6362), 2,
      sym_boolean_literal,
      sym_string,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9042), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6760), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [176970] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16366), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3872), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177089] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12090), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3873), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177208] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15339), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3874), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177327] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12088), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3875), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177446] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    ACTIONS(7010), 1,
      anon_sym_LBRACK,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8846), 1,
      sym_identifier,
    STATE(9747), 1,
      sym__annotated_type,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11746), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12738), 1,
      sym__infix_type_choice,
    STATE(16226), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3876), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177565] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12086), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3877), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177684] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    ACTIONS(7010), 1,
      anon_sym_LBRACK,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8846), 1,
      sym_identifier,
    STATE(9747), 1,
      sym__annotated_type,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11754), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12738), 1,
      sym__infix_type_choice,
    STATE(16226), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3878), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177803] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15555), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3879), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [177922] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12205), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3880), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178041] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15552), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3881), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178160] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    ACTIONS(7010), 1,
      anon_sym_LBRACK,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8846), 1,
      sym_identifier,
    STATE(9747), 1,
      sym__annotated_type,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11757), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12738), 1,
      sym__infix_type_choice,
    STATE(16226), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3882), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178279] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6816), 1,
      anon_sym_COLON,
    ACTIONS(6818), 1,
      anon_sym_LBRACE,
    ACTIONS(6820), 1,
      anon_sym_LBRACK,
    ACTIONS(6822), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8571), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11713), 1,
      sym__type,
    STATE(11981), 1,
      sym_template_body,
    STATE(12025), 1,
      sym__non_null_literal,
    STATE(12827), 1,
      sym__infix_type_choice,
    STATE(16010), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3883), 2,
      sym_comment,
      sym_block_comment,
    STATE(11184), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11949), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12026), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178398] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16946), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3884), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178517] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    ACTIONS(7010), 1,
      anon_sym_LBRACK,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8846), 1,
      sym_identifier,
    STATE(9747), 1,
      sym__annotated_type,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11760), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12738), 1,
      sym__infix_type_choice,
    STATE(16226), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3885), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178636] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6968), 1,
      anon_sym_COLON,
    ACTIONS(6970), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      anon_sym__,
    ACTIONS(6974), 1,
      anon_sym_LBRACK,
    ACTIONS(6978), 1,
      anon_sym_LPAREN,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(6982), 1,
      sym_operator_identifier,
    ACTIONS(6984), 1,
      sym_integer_literal,
    STATE(5099), 1,
      sym__simple_type,
    STATE(5688), 1,
      sym__annotated_type,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6043), 1,
      sym_identifier,
    STATE(9349), 1,
      sym_annotated_type,
    STATE(10925), 1,
      sym__type,
    STATE(10982), 1,
      sym__non_null_literal,
    STATE(11063), 1,
      sym_template_body,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(16218), 1,
      sym_parameter_types,
    STATE(17544), 1,
      sym_stable_identifier,
    ACTIONS(6986), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6988), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6990), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3886), 2,
      sym_comment,
      sym_block_comment,
    STATE(10151), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10959), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11010), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10979), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6339), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178755] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12083), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3887), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178874] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6884), 1,
      sym__alpha_identifier,
    ACTIONS(6886), 1,
      anon_sym__,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6892), 1,
      anon_sym_LPAREN,
    ACTIONS(6894), 1,
      sym__backquoted_id,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    STATE(6102), 1,
      sym__simple_type,
    STATE(6268), 1,
      sym__soft_identifier,
    STATE(6295), 1,
      sym__annotated_type,
    STATE(6574), 1,
      sym_identifier,
    STATE(9782), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11699), 1,
      sym__type,
    STATE(12747), 1,
      sym__infix_type_choice,
    STATE(16225), 1,
      sym_parameter_types,
    STATE(16962), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3888), 2,
      sym_comment,
      sym_block_comment,
    STATE(10796), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6890), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7231), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [178993] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15354), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3889), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179112] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1538), 1,
      sym_integer_literal,
    ACTIONS(6360), 1,
      sym__alpha_identifier,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(6366), 1,
      anon_sym__,
    ACTIONS(6368), 1,
      anon_sym_LBRACK,
    ACTIONS(6372), 1,
      anon_sym_LPAREN,
    ACTIONS(6374), 1,
      sym__backquoted_id,
    ACTIONS(6376), 1,
      sym_operator_identifier,
    STATE(4549), 1,
      sym__simple_type,
    STATE(4564), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym_identifier,
    STATE(4788), 1,
      sym__soft_identifier,
    STATE(6732), 1,
      sym_annotated_type,
    STATE(11755), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12476), 1,
      sym__infix_type_choice,
    STATE(16111), 1,
      sym_parameter_types,
    STATE(17876), 1,
      sym_stable_identifier,
    ACTIONS(1540), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1542), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1546), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3890), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5996), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8705), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4936), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179231] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(87), 1,
      sym_integer_literal,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6236), 1,
      anon_sym_LBRACK,
    ACTIONS(6240), 1,
      anon_sym_LPAREN,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    STATE(7854), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12646), 1,
      sym__infix_type_choice,
    STATE(14816), 1,
      sym__type,
    STATE(16137), 1,
      sym_parameter_types,
    STATE(16720), 1,
      sym_stable_identifier,
    ACTIONS(89), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(91), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(103), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3891), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6859), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11362), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179350] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15357), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3892), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179469] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(17898), 1,
      sym__type,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3893), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179588] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16948), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3894), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179707] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16273), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3895), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179826] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15537), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3896), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [179945] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15534), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3897), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180064] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    ACTIONS(7010), 1,
      anon_sym_LBRACK,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8846), 1,
      sym_identifier,
    STATE(9747), 1,
      sym__annotated_type,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12738), 1,
      sym__infix_type_choice,
    STATE(16226), 1,
      sym_parameter_types,
    STATE(16602), 1,
      sym__type,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3898), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180183] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6286), 1,
      sym__alpha_identifier,
    ACTIONS(6288), 1,
      anon_sym__,
    ACTIONS(6290), 1,
      anon_sym_LBRACK,
    ACTIONS(6294), 1,
      anon_sym_LPAREN,
    ACTIONS(6296), 1,
      sym__backquoted_id,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    STATE(6470), 1,
      sym__simple_type,
    STATE(6838), 1,
      sym__soft_identifier,
    STATE(7088), 1,
      sym__annotated_type,
    STATE(7402), 1,
      sym_identifier,
    STATE(10239), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12575), 1,
      sym__infix_type_choice,
    STATE(14400), 1,
      sym__type,
    STATE(16104), 1,
      sym_parameter_types,
    STATE(16771), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3899), 2,
      sym_comment,
      sym_block_comment,
    STATE(10977), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6292), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7941), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180302] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16001), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3900), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180421] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1306), 1,
      sym_integer_literal,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(6662), 1,
      sym__alpha_identifier,
    ACTIONS(6664), 1,
      anon_sym__,
    ACTIONS(6666), 1,
      anon_sym_LBRACK,
    ACTIONS(6670), 1,
      anon_sym_LPAREN,
    ACTIONS(6672), 1,
      sym__backquoted_id,
    ACTIONS(6674), 1,
      sym_operator_identifier,
    STATE(4496), 1,
      sym__simple_type,
    STATE(4537), 1,
      sym__annotated_type,
    STATE(4616), 1,
      sym_identifier,
    STATE(4632), 1,
      sym__soft_identifier,
    STATE(5589), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11659), 1,
      sym__type,
    STATE(12793), 1,
      sym__infix_type_choice,
    STATE(16109), 1,
      sym_parameter_types,
    STATE(17744), 1,
      sym_stable_identifier,
    ACTIONS(1308), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1310), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1314), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3901), 2,
      sym_comment,
      sym_block_comment,
    STATE(5184), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7690), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6668), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4799), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180540] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(15089), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3902), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180659] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16308), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3903), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180778] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12209), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3904), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [180897] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6968), 1,
      anon_sym_COLON,
    ACTIONS(6970), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      anon_sym__,
    ACTIONS(6974), 1,
      anon_sym_LBRACK,
    ACTIONS(6978), 1,
      anon_sym_LPAREN,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(6982), 1,
      sym_operator_identifier,
    ACTIONS(6984), 1,
      sym_integer_literal,
    STATE(5099), 1,
      sym__simple_type,
    STATE(5688), 1,
      sym__annotated_type,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6043), 1,
      sym_identifier,
    STATE(9349), 1,
      sym_annotated_type,
    STATE(10982), 1,
      sym__non_null_literal,
    STATE(11063), 1,
      sym_template_body,
    STATE(11149), 1,
      sym__type,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(16218), 1,
      sym_parameter_types,
    STATE(17544), 1,
      sym_stable_identifier,
    ACTIONS(6986), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6988), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6990), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3905), 2,
      sym_comment,
      sym_block_comment,
    STATE(10151), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10959), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11010), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10979), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6339), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181016] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1306), 1,
      sym_integer_literal,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(6662), 1,
      sym__alpha_identifier,
    ACTIONS(6664), 1,
      anon_sym__,
    ACTIONS(6666), 1,
      anon_sym_LBRACK,
    ACTIONS(6670), 1,
      anon_sym_LPAREN,
    ACTIONS(6672), 1,
      sym__backquoted_id,
    ACTIONS(6674), 1,
      sym_operator_identifier,
    STATE(4496), 1,
      sym__simple_type,
    STATE(4537), 1,
      sym__annotated_type,
    STATE(4616), 1,
      sym_identifier,
    STATE(4632), 1,
      sym__soft_identifier,
    STATE(5589), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11651), 1,
      sym__type,
    STATE(12793), 1,
      sym__infix_type_choice,
    STATE(16109), 1,
      sym_parameter_types,
    STATE(17744), 1,
      sym_stable_identifier,
    ACTIONS(1308), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1310), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1314), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3906), 2,
      sym_comment,
      sym_block_comment,
    STATE(5184), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7690), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6668), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4799), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181135] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16160), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3907), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181254] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15372), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3908), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181373] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17041), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3909), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181492] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15375), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3910), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181611] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16313), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3911), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181730] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1538), 1,
      sym_integer_literal,
    ACTIONS(6360), 1,
      sym__alpha_identifier,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(6366), 1,
      anon_sym__,
    ACTIONS(6368), 1,
      anon_sym_LBRACK,
    ACTIONS(6372), 1,
      anon_sym_LPAREN,
    ACTIONS(6374), 1,
      sym__backquoted_id,
    ACTIONS(6376), 1,
      sym_operator_identifier,
    STATE(4549), 1,
      sym__simple_type,
    STATE(4564), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym_identifier,
    STATE(4788), 1,
      sym__soft_identifier,
    STATE(6732), 1,
      sym_annotated_type,
    STATE(11752), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12476), 1,
      sym__infix_type_choice,
    STATE(16111), 1,
      sym_parameter_types,
    STATE(17876), 1,
      sym_stable_identifier,
    ACTIONS(1540), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1542), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1546), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3912), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5996), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8705), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4936), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181849] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1306), 1,
      sym_integer_literal,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(6662), 1,
      sym__alpha_identifier,
    ACTIONS(6664), 1,
      anon_sym__,
    ACTIONS(6666), 1,
      anon_sym_LBRACK,
    ACTIONS(6670), 1,
      anon_sym_LPAREN,
    ACTIONS(6672), 1,
      sym__backquoted_id,
    ACTIONS(6674), 1,
      sym_operator_identifier,
    STATE(4496), 1,
      sym__simple_type,
    STATE(4537), 1,
      sym__annotated_type,
    STATE(4616), 1,
      sym_identifier,
    STATE(4632), 1,
      sym__soft_identifier,
    STATE(5589), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11650), 1,
      sym__type,
    STATE(12793), 1,
      sym__infix_type_choice,
    STATE(16109), 1,
      sym_parameter_types,
    STATE(17744), 1,
      sym_stable_identifier,
    ACTIONS(1308), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1310), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1314), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3913), 2,
      sym_comment,
      sym_block_comment,
    STATE(5184), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7690), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6668), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4799), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [181968] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    ACTIONS(7010), 1,
      anon_sym_LBRACK,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8846), 1,
      sym_identifier,
    STATE(9747), 1,
      sym__annotated_type,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11762), 1,
      sym__type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12738), 1,
      sym__infix_type_choice,
    STATE(16226), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3914), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182087] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6188), 1,
      anon_sym_LBRACK,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8322), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12511), 1,
      sym__infix_type_choice,
    STATE(15962), 1,
      sym_parameter_types,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(17916), 1,
      sym__type,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3915), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182206] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1538), 1,
      sym_integer_literal,
    ACTIONS(6360), 1,
      sym__alpha_identifier,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(6366), 1,
      anon_sym__,
    ACTIONS(6368), 1,
      anon_sym_LBRACK,
    ACTIONS(6372), 1,
      anon_sym_LPAREN,
    ACTIONS(6374), 1,
      sym__backquoted_id,
    ACTIONS(6376), 1,
      sym_operator_identifier,
    STATE(4549), 1,
      sym__simple_type,
    STATE(4564), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym_identifier,
    STATE(4788), 1,
      sym__soft_identifier,
    STATE(6732), 1,
      sym_annotated_type,
    STATE(11749), 1,
      sym__type,
    STATE(11825), 1,
      sym__non_null_literal,
    STATE(11834), 1,
      sym_template_body,
    STATE(12476), 1,
      sym__infix_type_choice,
    STATE(16111), 1,
      sym_parameter_types,
    STATE(17876), 1,
      sym_stable_identifier,
    ACTIONS(1540), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1542), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1546), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3916), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(5996), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8705), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11827), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4936), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182325] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6884), 1,
      sym__alpha_identifier,
    ACTIONS(6886), 1,
      anon_sym__,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6892), 1,
      anon_sym_LPAREN,
    ACTIONS(6894), 1,
      sym__backquoted_id,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    STATE(6102), 1,
      sym__simple_type,
    STATE(6268), 1,
      sym__soft_identifier,
    STATE(6295), 1,
      sym__annotated_type,
    STATE(6574), 1,
      sym_identifier,
    STATE(9782), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11637), 1,
      sym__type,
    STATE(12747), 1,
      sym__infix_type_choice,
    STATE(16225), 1,
      sym_parameter_types,
    STATE(16962), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3917), 2,
      sym_comment,
      sym_block_comment,
    STATE(10796), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6890), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7231), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182444] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6884), 1,
      sym__alpha_identifier,
    ACTIONS(6886), 1,
      anon_sym__,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6892), 1,
      anon_sym_LPAREN,
    ACTIONS(6894), 1,
      sym__backquoted_id,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    STATE(6102), 1,
      sym__simple_type,
    STATE(6268), 1,
      sym__soft_identifier,
    STATE(6295), 1,
      sym__annotated_type,
    STATE(6574), 1,
      sym_identifier,
    STATE(9782), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11623), 1,
      sym__type,
    STATE(12747), 1,
      sym__infix_type_choice,
    STATE(16225), 1,
      sym_parameter_types,
    STATE(16962), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3918), 2,
      sym_comment,
      sym_block_comment,
    STATE(10796), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6890), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7231), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182563] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6884), 1,
      sym__alpha_identifier,
    ACTIONS(6886), 1,
      anon_sym__,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6892), 1,
      anon_sym_LPAREN,
    ACTIONS(6894), 1,
      sym__backquoted_id,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    STATE(6102), 1,
      sym__simple_type,
    STATE(6268), 1,
      sym__soft_identifier,
    STATE(6295), 1,
      sym__annotated_type,
    STATE(6574), 1,
      sym_identifier,
    STATE(9782), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11613), 1,
      sym__type,
    STATE(12747), 1,
      sym__infix_type_choice,
    STATE(16225), 1,
      sym_parameter_types,
    STATE(16962), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3919), 2,
      sym_comment,
      sym_block_comment,
    STATE(10796), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6890), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7231), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182682] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1306), 1,
      sym_integer_literal,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(6662), 1,
      sym__alpha_identifier,
    ACTIONS(6664), 1,
      anon_sym__,
    ACTIONS(6666), 1,
      anon_sym_LBRACK,
    ACTIONS(6670), 1,
      anon_sym_LPAREN,
    ACTIONS(6672), 1,
      sym__backquoted_id,
    ACTIONS(6674), 1,
      sym_operator_identifier,
    STATE(4496), 1,
      sym__simple_type,
    STATE(4537), 1,
      sym__annotated_type,
    STATE(4616), 1,
      sym_identifier,
    STATE(4632), 1,
      sym__soft_identifier,
    STATE(5589), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11649), 1,
      sym__type,
    STATE(12793), 1,
      sym__infix_type_choice,
    STATE(16109), 1,
      sym_parameter_types,
    STATE(17744), 1,
      sym_stable_identifier,
    ACTIONS(1308), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1310), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1314), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3920), 2,
      sym_comment,
      sym_block_comment,
    STATE(5184), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7690), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6668), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4799), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182801] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6884), 1,
      sym__alpha_identifier,
    ACTIONS(6886), 1,
      anon_sym__,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6892), 1,
      anon_sym_LPAREN,
    ACTIONS(6894), 1,
      sym__backquoted_id,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    STATE(6102), 1,
      sym__simple_type,
    STATE(6268), 1,
      sym__soft_identifier,
    STATE(6295), 1,
      sym__annotated_type,
    STATE(6574), 1,
      sym_identifier,
    STATE(9782), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(11611), 1,
      sym__type,
    STATE(12747), 1,
      sym__infix_type_choice,
    STATE(16225), 1,
      sym_parameter_types,
    STATE(16962), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3921), 2,
      sym_comment,
      sym_block_comment,
    STATE(10796), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6890), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7231), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [182920] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15390), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3922), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183039] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(6996), 1,
      sym__alpha_identifier,
    ACTIONS(6998), 1,
      anon_sym__,
    ACTIONS(7000), 1,
      anon_sym_LBRACK,
    ACTIONS(7004), 1,
      anon_sym_LPAREN,
    ACTIONS(7006), 1,
      sym__backquoted_id,
    ACTIONS(7008), 1,
      sym_operator_identifier,
    STATE(6559), 1,
      sym__simple_type,
    STATE(6560), 1,
      sym__annotated_type,
    STATE(7238), 1,
      sym_identifier,
    STATE(7458), 1,
      sym__soft_identifier,
    STATE(9877), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11918), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12782), 1,
      sym__infix_type_choice,
    STATE(16053), 1,
      sym_parameter_types,
    STATE(17218), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3923), 2,
      sym_comment,
      sym_block_comment,
    STATE(5668), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10785), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(7002), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8023), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183158] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15393), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3924), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183277] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15519), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3925), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183396] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15516), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3926), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183515] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17038), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3927), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183634] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1700), 1,
      sym_integer_literal,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6580), 1,
      anon_sym_COLON,
    ACTIONS(6582), 1,
      anon_sym_LBRACE,
    ACTIONS(6584), 1,
      anon_sym__,
    ACTIONS(6586), 1,
      anon_sym_LBRACK,
    ACTIONS(6590), 1,
      anon_sym_LPAREN,
    ACTIONS(6592), 1,
      sym__backquoted_id,
    ACTIONS(6594), 1,
      sym_operator_identifier,
    STATE(5523), 1,
      sym__simple_type,
    STATE(5974), 1,
      sym__annotated_type,
    STATE(6385), 1,
      sym__soft_identifier,
    STATE(6582), 1,
      sym_identifier,
    STATE(9185), 1,
      sym_annotated_type,
    STATE(12653), 1,
      sym__infix_type_choice,
    STATE(13794), 1,
      sym__non_null_literal,
    STATE(14022), 1,
      sym_template_body,
    STATE(14108), 1,
      sym__type,
    STATE(15973), 1,
      sym_parameter_types,
    STATE(17792), 1,
      sym_stable_identifier,
    ACTIONS(1702), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1704), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1708), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3928), 2,
      sym_comment,
      sym_block_comment,
    STATE(9188), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9358), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10453), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13825), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6588), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7364), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183753] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16253), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3929), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183872] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    ACTIONS(7010), 1,
      anon_sym_LBRACK,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8846), 1,
      sym_identifier,
    STATE(9747), 1,
      sym__annotated_type,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12738), 1,
      sym__infix_type_choice,
    STATE(16226), 1,
      sym_parameter_types,
    STATE(16608), 1,
      sym__type,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3930), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [183991] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2106), 1,
      sym_integer_literal,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(6754), 1,
      sym__alpha_identifier,
    ACTIONS(6756), 1,
      anon_sym__,
    ACTIONS(6758), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_LPAREN,
    ACTIONS(6764), 1,
      sym__backquoted_id,
    ACTIONS(6766), 1,
      sym_operator_identifier,
    STATE(4748), 1,
      sym__simple_type,
    STATE(4761), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym_identifier,
    STATE(4998), 1,
      sym__soft_identifier,
    STATE(6891), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12310), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12756), 1,
      sym__infix_type_choice,
    STATE(16110), 1,
      sym_parameter_types,
    STATE(17750), 1,
      sym_stable_identifier,
    ACTIONS(2108), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2110), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2114), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3931), 2,
      sym_comment,
      sym_block_comment,
    STATE(6362), 2,
      sym_boolean_literal,
      sym_string,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9042), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6760), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [184110] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16341), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3932), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [184229] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15408), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3933), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [184348] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16067), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3934), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [184467] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16992), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3935), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [184586] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4714), 1,
      anon_sym_COLON,
    ACTIONS(4716), 1,
      anon_sym_LBRACE,
    ACTIONS(4734), 1,
      sym_integer_literal,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6494), 1,
      anon_sym_LBRACK,
    ACTIONS(6498), 1,
      anon_sym_LPAREN,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7175), 1,
      sym__annotated_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12512), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(13400), 1,
      sym__type,
    STATE(16155), 1,
      sym_parameter_types,
    STATE(17518), 1,
      sym_stable_identifier,
    ACTIONS(4736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4742), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3936), 2,
      sym_comment,
      sym_block_comment,
    STATE(10790), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13135), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13248), 2,
      sym_boolean_literal,
      sym_string,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [184705] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15411), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3937), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [184824] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(15095), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3938), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [184943] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2106), 1,
      sym_integer_literal,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(6754), 1,
      sym__alpha_identifier,
    ACTIONS(6756), 1,
      anon_sym__,
    ACTIONS(6758), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_LPAREN,
    ACTIONS(6764), 1,
      sym__backquoted_id,
    ACTIONS(6766), 1,
      sym_operator_identifier,
    STATE(4748), 1,
      sym__simple_type,
    STATE(4761), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym_identifier,
    STATE(4998), 1,
      sym__soft_identifier,
    STATE(6891), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12314), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12756), 1,
      sym__infix_type_choice,
    STATE(16110), 1,
      sym_parameter_types,
    STATE(17750), 1,
      sym_stable_identifier,
    ACTIONS(2108), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2110), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2114), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3939), 2,
      sym_comment,
      sym_block_comment,
    STATE(6362), 2,
      sym_boolean_literal,
      sym_string,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9042), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6760), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [185062] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15501), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3940), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [185181] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6466), 1,
      anon_sym_COLON,
    ACTIONS(6468), 1,
      anon_sym_LBRACE,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6472), 1,
      anon_sym_LBRACK,
    ACTIONS(6476), 1,
      anon_sym_LPAREN,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(6482), 1,
      sym_integer_literal,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8901), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(12069), 1,
      sym_template_body,
    STATE(12070), 1,
      sym__non_null_literal,
    STATE(12078), 1,
      sym__type,
    STATE(12919), 1,
      sym__infix_type_choice,
    STATE(15839), 1,
      sym_parameter_types,
    STATE(17416), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3941), 2,
      sym_comment,
      sym_block_comment,
    STATE(11257), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(12195), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12067), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [185300] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15498), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3942), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [185419] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6440), 1,
      anon_sym_COLON,
    ACTIONS(6442), 1,
      anon_sym_LBRACE,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6446), 1,
      anon_sym_LBRACK,
    ACTIONS(6450), 1,
      anon_sym_LPAREN,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(6456), 1,
      sym_integer_literal,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8051), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(11736), 1,
      sym__non_null_literal,
    STATE(11748), 1,
      sym_template_body,
    STATE(11836), 1,
      sym__type,
    STATE(12496), 1,
      sym__infix_type_choice,
    STATE(16167), 1,
      sym_parameter_types,
    STATE(17249), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3943), 2,
      sym_comment,
      sym_block_comment,
    STATE(11058), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11804), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11740), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [185538] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16994), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3944), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [185657] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(15096), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3945), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [185776] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(6996), 1,
      sym__alpha_identifier,
    ACTIONS(6998), 1,
      anon_sym__,
    ACTIONS(7000), 1,
      anon_sym_LBRACK,
    ACTIONS(7004), 1,
      anon_sym_LPAREN,
    ACTIONS(7006), 1,
      sym__backquoted_id,
    ACTIONS(7008), 1,
      sym_operator_identifier,
    STATE(6559), 1,
      sym__simple_type,
    STATE(6560), 1,
      sym__annotated_type,
    STATE(7238), 1,
      sym_identifier,
    STATE(7458), 1,
      sym__soft_identifier,
    STATE(9877), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11957), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12782), 1,
      sym__infix_type_choice,
    STATE(16053), 1,
      sym_parameter_types,
    STATE(17218), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3946), 2,
      sym_comment,
      sym_block_comment,
    STATE(5668), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10785), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(7002), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8023), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [185895] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6304), 1,
      anon_sym_LBRACK,
    ACTIONS(6308), 1,
      anon_sym_LPAREN,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    STATE(7533), 1,
      sym__simple_type,
    STATE(8692), 1,
      sym_identifier,
    STATE(8750), 1,
      sym__annotated_type,
    STATE(8795), 1,
      sym__soft_identifier,
    STATE(10744), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12927), 1,
      sym__infix_type_choice,
    STATE(15030), 1,
      sym__type,
    STATE(16105), 1,
      sym_parameter_types,
    STATE(17006), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3947), 2,
      sym_comment,
      sym_block_comment,
    STATE(11242), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [186014] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6528), 1,
      sym__alpha_identifier,
    ACTIONS(6530), 1,
      anon_sym__,
    ACTIONS(6532), 1,
      anon_sym_LBRACK,
    ACTIONS(6536), 1,
      anon_sym_LPAREN,
    ACTIONS(6538), 1,
      sym__backquoted_id,
    ACTIONS(6540), 1,
      sym_operator_identifier,
    STATE(7390), 1,
      sym__simple_type,
    STATE(7836), 1,
      sym__annotated_type,
    STATE(7921), 1,
      sym_identifier,
    STATE(7952), 1,
      sym__soft_identifier,
    STATE(10528), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12942), 1,
      sym__infix_type_choice,
    STATE(14649), 1,
      sym__type,
    STATE(16154), 1,
      sym_parameter_types,
    STATE(17028), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3948), 2,
      sym_comment,
      sym_block_comment,
    STATE(11027), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6534), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8432), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [186133] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(557), 1,
      sym_integer_literal,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6326), 1,
      anon_sym_LBRACK,
    ACTIONS(6330), 1,
      anon_sym_LPAREN,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    STATE(6239), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12548), 1,
      sym__infix_type_choice,
    STATE(13341), 1,
      sym__non_null_literal,
    STATE(15098), 1,
      sym__type,
    STATE(15965), 1,
      sym_parameter_types,
    STATE(17505), 1,
      sym_stable_identifier,
    ACTIONS(559), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(561), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(571), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3949), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9763), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10858), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13340), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [186252] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15426), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3950), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [186371] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15429), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3951), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [186490] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17426), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3952), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [186609] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4362), 1,
      anon_sym_COLON,
    ACTIONS(4364), 1,
      anon_sym_LBRACE,
    ACTIONS(4382), 1,
      sym_integer_literal,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6192), 1,
      anon_sym_LPAREN,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    ACTIONS(7010), 1,
      anon_sym_LBRACK,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8846), 1,
      sym_identifier,
    STATE(9747), 1,
      sym__annotated_type,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11860), 1,
      sym__non_null_literal,
    STATE(11863), 1,
      sym_template_body,
    STATE(12738), 1,
      sym__infix_type_choice,
    STATE(16226), 1,
      sym_parameter_types,
    STATE(16604), 1,
      sym__type,
    STATE(16823), 1,
      sym_stable_identifier,
    ACTIONS(4384), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4386), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4388), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3953), 2,
      sym_comment,
      sym_block_comment,
    STATE(11401), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11906), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12018), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11862), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [186728] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(6996), 1,
      sym__alpha_identifier,
    ACTIONS(6998), 1,
      anon_sym__,
    ACTIONS(7000), 1,
      anon_sym_LBRACK,
    ACTIONS(7004), 1,
      anon_sym_LPAREN,
    ACTIONS(7006), 1,
      sym__backquoted_id,
    ACTIONS(7008), 1,
      sym_operator_identifier,
    STATE(6559), 1,
      sym__simple_type,
    STATE(6560), 1,
      sym__annotated_type,
    STATE(7238), 1,
      sym_identifier,
    STATE(7458), 1,
      sym__soft_identifier,
    STATE(9877), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11974), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12782), 1,
      sym__infix_type_choice,
    STATE(16053), 1,
      sym_parameter_types,
    STATE(17218), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3954), 2,
      sym_comment,
      sym_block_comment,
    STATE(5668), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10785), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(7002), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8023), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [186847] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1306), 1,
      sym_integer_literal,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(6662), 1,
      sym__alpha_identifier,
    ACTIONS(6664), 1,
      anon_sym__,
    ACTIONS(6666), 1,
      anon_sym_LBRACK,
    ACTIONS(6670), 1,
      anon_sym_LPAREN,
    ACTIONS(6672), 1,
      sym__backquoted_id,
    ACTIONS(6674), 1,
      sym_operator_identifier,
    STATE(4496), 1,
      sym__simple_type,
    STATE(4537), 1,
      sym__annotated_type,
    STATE(4616), 1,
      sym_identifier,
    STATE(4632), 1,
      sym__soft_identifier,
    STATE(5589), 1,
      sym_annotated_type,
    STATE(11513), 1,
      sym_template_body,
    STATE(11572), 1,
      sym__non_null_literal,
    STATE(11681), 1,
      sym__type,
    STATE(12793), 1,
      sym__infix_type_choice,
    STATE(16109), 1,
      sym_parameter_types,
    STATE(17744), 1,
      sym_stable_identifier,
    ACTIONS(1308), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1310), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1314), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3955), 2,
      sym_comment,
      sym_block_comment,
    STATE(5184), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7690), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11571), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6668), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4799), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [186966] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15444), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3956), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [187085] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(6996), 1,
      sym__alpha_identifier,
    ACTIONS(6998), 1,
      anon_sym__,
    ACTIONS(7000), 1,
      anon_sym_LBRACK,
    ACTIONS(7004), 1,
      anon_sym_LPAREN,
    ACTIONS(7006), 1,
      sym__backquoted_id,
    ACTIONS(7008), 1,
      sym_operator_identifier,
    STATE(6559), 1,
      sym__simple_type,
    STATE(6560), 1,
      sym__annotated_type,
    STATE(7238), 1,
      sym_identifier,
    STATE(7458), 1,
      sym__soft_identifier,
    STATE(9877), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11980), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12782), 1,
      sym__infix_type_choice,
    STATE(16053), 1,
      sym_parameter_types,
    STATE(17218), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3957), 2,
      sym_comment,
      sym_block_comment,
    STATE(5668), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10785), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(7002), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8023), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [187204] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16337), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3958), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [187323] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15447), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3959), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [187442] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2106), 1,
      sym_integer_literal,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(6754), 1,
      sym__alpha_identifier,
    ACTIONS(6756), 1,
      anon_sym__,
    ACTIONS(6758), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_LPAREN,
    ACTIONS(6764), 1,
      sym__backquoted_id,
    ACTIONS(6766), 1,
      sym_operator_identifier,
    STATE(4748), 1,
      sym__simple_type,
    STATE(4761), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym_identifier,
    STATE(4998), 1,
      sym__soft_identifier,
    STATE(6891), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12315), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12756), 1,
      sym__infix_type_choice,
    STATE(16110), 1,
      sym_parameter_types,
    STATE(17750), 1,
      sym_stable_identifier,
    ACTIONS(2108), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2110), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2114), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3960), 2,
      sym_comment,
      sym_block_comment,
    STATE(6362), 2,
      sym_boolean_literal,
      sym_string,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9042), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6760), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [187561] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2106), 1,
      sym_integer_literal,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(6754), 1,
      sym__alpha_identifier,
    ACTIONS(6756), 1,
      anon_sym__,
    ACTIONS(6758), 1,
      anon_sym_LBRACK,
    ACTIONS(6762), 1,
      anon_sym_LPAREN,
    ACTIONS(6764), 1,
      sym__backquoted_id,
    ACTIONS(6766), 1,
      sym_operator_identifier,
    STATE(4748), 1,
      sym__simple_type,
    STATE(4761), 1,
      sym__annotated_type,
    STATE(4984), 1,
      sym_identifier,
    STATE(4998), 1,
      sym__soft_identifier,
    STATE(6891), 1,
      sym_annotated_type,
    STATE(12288), 1,
      sym_template_body,
    STATE(12325), 1,
      sym__type,
    STATE(12424), 1,
      sym__non_null_literal,
    STATE(12756), 1,
      sym__infix_type_choice,
    STATE(16110), 1,
      sym_parameter_types,
    STATE(17750), 1,
      sym_stable_identifier,
    ACTIONS(2108), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(2110), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(2114), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3961), 2,
      sym_comment,
      sym_block_comment,
    STATE(6362), 2,
      sym_boolean_literal,
      sym_string,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9042), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12426), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6760), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [187680] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [187749] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1118), 1,
      sym_integer_literal,
    ACTIONS(6900), 1,
      sym__alpha_identifier,
    ACTIONS(6902), 1,
      anon_sym_COLON,
    ACTIONS(6904), 1,
      anon_sym_LBRACE,
    ACTIONS(6906), 1,
      anon_sym__,
    ACTIONS(6908), 1,
      anon_sym_LBRACK,
    ACTIONS(6912), 1,
      anon_sym_LPAREN,
    ACTIONS(6914), 1,
      sym__backquoted_id,
    ACTIONS(6916), 1,
      sym_operator_identifier,
    STATE(4708), 1,
      sym__annotated_type,
    STATE(4794), 1,
      sym__simple_type,
    STATE(5011), 1,
      sym_identifier,
    STATE(5013), 1,
      sym__soft_identifier,
    STATE(6935), 1,
      sym_annotated_type,
    STATE(12645), 1,
      sym_template_body,
    STATE(12704), 1,
      sym__non_null_literal,
    STATE(12720), 1,
      sym__infix_type_choice,
    STATE(12832), 1,
      sym__type,
    STATE(15971), 1,
      sym_parameter_types,
    STATE(17762), 1,
      sym_stable_identifier,
    ACTIONS(1120), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1122), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1126), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3963), 2,
      sym_comment,
      sym_block_comment,
    STATE(7087), 2,
      sym_boolean_literal,
      sym_string,
    STATE(7186), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9279), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(12703), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6910), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5168), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [187868] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15462), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3964), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [187987] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(15465), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3965), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [188106] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1664), 1,
      sym_integer_literal,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(6996), 1,
      sym__alpha_identifier,
    ACTIONS(6998), 1,
      anon_sym__,
    ACTIONS(7000), 1,
      anon_sym_LBRACK,
    ACTIONS(7004), 1,
      anon_sym_LPAREN,
    ACTIONS(7006), 1,
      sym__backquoted_id,
    ACTIONS(7008), 1,
      sym_operator_identifier,
    STATE(6559), 1,
      sym__simple_type,
    STATE(6560), 1,
      sym__annotated_type,
    STATE(7238), 1,
      sym_identifier,
    STATE(7458), 1,
      sym__soft_identifier,
    STATE(9877), 1,
      sym_annotated_type,
    STATE(11764), 1,
      sym__non_null_literal,
    STATE(11982), 1,
      sym__type,
    STATE(12011), 1,
      sym_template_body,
    STATE(12782), 1,
      sym__infix_type_choice,
    STATE(16053), 1,
      sym_parameter_types,
    STATE(17218), 1,
      sym_stable_identifier,
    ACTIONS(1666), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1668), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1672), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3966), 2,
      sym_comment,
      sym_block_comment,
    STATE(5668), 2,
      sym_boolean_literal,
      sym_string,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10785), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11763), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(7002), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8023), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [188225] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(16090), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3967), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [188344] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6968), 1,
      anon_sym_COLON,
    ACTIONS(6970), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      anon_sym__,
    ACTIONS(6974), 1,
      anon_sym_LBRACK,
    ACTIONS(6978), 1,
      anon_sym_LPAREN,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(6982), 1,
      sym_operator_identifier,
    ACTIONS(6984), 1,
      sym_integer_literal,
    STATE(5099), 1,
      sym__simple_type,
    STATE(5688), 1,
      sym__annotated_type,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6043), 1,
      sym_identifier,
    STATE(9349), 1,
      sym_annotated_type,
    STATE(10982), 1,
      sym__non_null_literal,
    STATE(11063), 1,
      sym_template_body,
    STATE(11183), 1,
      sym__type,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(16218), 1,
      sym_parameter_types,
    STATE(17544), 1,
      sym_stable_identifier,
    ACTIONS(6986), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6988), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6990), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3968), 2,
      sym_comment,
      sym_block_comment,
    STATE(10151), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10959), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11010), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10979), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6339), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [188463] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6968), 1,
      anon_sym_COLON,
    ACTIONS(6970), 1,
      anon_sym_LBRACE,
    ACTIONS(6972), 1,
      anon_sym__,
    ACTIONS(6974), 1,
      anon_sym_LBRACK,
    ACTIONS(6978), 1,
      anon_sym_LPAREN,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(6982), 1,
      sym_operator_identifier,
    ACTIONS(6984), 1,
      sym_integer_literal,
    STATE(5099), 1,
      sym__simple_type,
    STATE(5688), 1,
      sym__annotated_type,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6043), 1,
      sym_identifier,
    STATE(9349), 1,
      sym_annotated_type,
    STATE(10982), 1,
      sym__non_null_literal,
    STATE(11063), 1,
      sym_template_body,
    STATE(11396), 1,
      sym__type,
    STATE(12535), 1,
      sym__infix_type_choice,
    STATE(16218), 1,
      sym_parameter_types,
    STATE(17544), 1,
      sym_stable_identifier,
    ACTIONS(6986), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6988), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6990), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3969), 2,
      sym_comment,
      sym_block_comment,
    STATE(10151), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(10959), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11010), 2,
      sym_boolean_literal,
      sym_string,
    STATE(10979), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6339), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [188582] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(4218), 1,
      anon_sym_LBRACE,
    ACTIONS(4236), 1,
      sym_integer_literal,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6258), 1,
      anon_sym_LBRACK,
    ACTIONS(6262), 1,
      anon_sym_LPAREN,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(8011), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11431), 1,
      sym__non_null_literal,
    STATE(12524), 1,
      sym__infix_type_choice,
    STATE(14411), 1,
      sym__type,
    STATE(16153), 1,
      sym_parameter_types,
    STATE(16743), 1,
      sym_stable_identifier,
    ACTIONS(4238), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4240), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(4244), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3970), 2,
      sym_comment,
      sym_block_comment,
    STATE(11032), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(11564), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11644), 2,
      sym_boolean_literal,
      sym_string,
    STATE(11429), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [188701] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(880), 1,
      sym_integer_literal,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(4956), 1,
      anon_sym_LPAREN,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    STATE(5260), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8287), 1,
      sym__non_null_literal,
    STATE(8390), 1,
      sym_template_body,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(12570), 1,
      sym__infix_type_choice,
    STATE(15254), 1,
      sym_parameter_types,
    STATE(17424), 1,
      sym__type,
    STATE(17668), 1,
      sym_stable_identifier,
    ACTIONS(882), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(884), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(894), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3971), 2,
      sym_comment,
      sym_block_comment,
    STATE(8787), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10025), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(8714), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [188820] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1190), 1,
      sym_integer_literal,
    ACTIONS(6378), 1,
      sym__alpha_identifier,
    ACTIONS(6380), 1,
      anon_sym_COLON,
    ACTIONS(6382), 1,
      anon_sym_LBRACE,
    ACTIONS(6384), 1,
      anon_sym__,
    ACTIONS(6386), 1,
      anon_sym_LBRACK,
    ACTIONS(6390), 1,
      anon_sym_LPAREN,
    ACTIONS(6392), 1,
      sym__backquoted_id,
    ACTIONS(6394), 1,
      sym_operator_identifier,
    STATE(4833), 1,
      sym__annotated_type,
    STATE(5085), 1,
      sym__simple_type,
    STATE(5211), 1,
      sym__soft_identifier,
    STATE(5401), 1,
      sym_identifier,
    STATE(7726), 1,
      sym_annotated_type,
    STATE(12474), 1,
      sym__infix_type_choice,
    STATE(13171), 1,
      sym__type,
    STATE(13245), 1,
      sym_template_body,
    STATE(13295), 1,
      sym__non_null_literal,
    STATE(15977), 1,
      sym_parameter_types,
    STATE(17882), 1,
      sym_stable_identifier,
    ACTIONS(1192), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(1194), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1198), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3972), 2,
      sym_comment,
      sym_block_comment,
    STATE(7888), 2,
      sym_boolean_literal,
      sym_string,
    STATE(8149), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(9700), 2,
      sym_compound_type,
      sym_infix_type,
    STATE(13299), 5,
      sym__structural_type,
      sym_match_type,
      sym_function_type,
      sym_type_lambda,
      sym_literal_type,
    ACTIONS(6388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5762), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [188939] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 8,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [189007] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 8,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [189075] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 8,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [189143] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [189211] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 8,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [189279] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7014), 1,
      anon_sym_LBRACE,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7026), 1,
      anon_sym_LPAREN,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16545), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3978), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189394] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7038), 1,
      anon_sym_LBRACE,
    ACTIONS(7040), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16514), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3979), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189509] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7042), 1,
      anon_sym_LBRACE,
    ACTIONS(7044), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16454), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3980), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189624] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7046), 1,
      anon_sym_LBRACE,
    ACTIONS(7048), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16551), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3981), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189739] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7050), 1,
      anon_sym_LBRACE,
    ACTIONS(7052), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16449), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3982), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [189854] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__interpolated_multiline_string_start,
    ACTIONS(4178), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 8,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_DQUOTE,
    ACTIONS(4174), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [189921] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7054), 1,
      anon_sym_LBRACE,
    ACTIONS(7056), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16566), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3984), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190036] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 36,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [190099] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7058), 1,
      anon_sym_LBRACE,
    ACTIONS(7060), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16470), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3986), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190214] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(3987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 36,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [190277] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7066), 1,
      anon_sym_LBRACE,
    ACTIONS(7068), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16491), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3988), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190392] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7070), 1,
      anon_sym_LBRACE,
    ACTIONS(7072), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16444), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3989), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190507] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7074), 1,
      anon_sym_LBRACE,
    ACTIONS(7076), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16535), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3990), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190622] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7078), 1,
      anon_sym_LBRACE,
    ACTIONS(7080), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16652), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3991), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190737] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7082), 1,
      anon_sym_LBRACE,
    ACTIONS(7084), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16537), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3992), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190852] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7086), 1,
      anon_sym_LBRACE,
    ACTIONS(7088), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16507), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3993), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [190967] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7090), 1,
      anon_sym_LBRACE,
    ACTIONS(7092), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16475), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3994), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191082] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7094), 1,
      anon_sym_LBRACE,
    ACTIONS(7096), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16629), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3995), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191197] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7098), 1,
      anon_sym_LBRACE,
    ACTIONS(7100), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16429), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3996), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191312] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7102), 1,
      anon_sym_LBRACE,
    ACTIONS(7104), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16415), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3997), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191427] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7106), 1,
      anon_sym_LBRACE,
    ACTIONS(7108), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16419), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3998), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191542] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7110), 1,
      anon_sym_LBRACE,
    ACTIONS(7112), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16439), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(3999), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191657] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7114), 1,
      anon_sym_LBRACE,
    ACTIONS(7116), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16409), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4000), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191772] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7118), 1,
      anon_sym_LBRACE,
    ACTIONS(7120), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16398), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4001), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [191887] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7122), 1,
      anon_sym_LBRACE,
    ACTIONS(7124), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16676), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4002), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192002] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7126), 1,
      anon_sym_LBRACE,
    ACTIONS(7128), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16594), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4003), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192117] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7130), 1,
      anon_sym_LBRACE,
    ACTIONS(7132), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16463), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4004), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192232] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    ACTIONS(7136), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16527), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4005), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192347] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7138), 1,
      anon_sym_LBRACE,
    ACTIONS(7140), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16481), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4006), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192462] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7142), 1,
      anon_sym_LBRACE,
    ACTIONS(7144), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16388), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4007), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192577] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7146), 1,
      anon_sym_LBRACE,
    ACTIONS(7148), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16681), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4008), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192692] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7150), 1,
      anon_sym_LBRACE,
    ACTIONS(7152), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16574), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4009), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192807] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7154), 1,
      anon_sym_LBRACE,
    ACTIONS(7156), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16426), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4010), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [192922] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7158), 1,
      anon_sym_LBRACE,
    ACTIONS(7160), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16509), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4011), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193037] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7162), 1,
      anon_sym_LBRACE,
    ACTIONS(7164), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16483), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4012), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193152] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7166), 1,
      anon_sym_LBRACE,
    ACTIONS(7168), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16387), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4013), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193267] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7170), 1,
      anon_sym_LBRACE,
    ACTIONS(7172), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16595), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4014), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193382] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7174), 1,
      anon_sym_LBRACE,
    ACTIONS(7176), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16529), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4015), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193497] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7178), 1,
      anon_sym_LBRACE,
    ACTIONS(7180), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16569), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4016), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193612] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7182), 1,
      anon_sym_LBRACE,
    ACTIONS(7184), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16556), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4017), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193727] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7186), 1,
      anon_sym_LBRACE,
    ACTIONS(7188), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16402), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4018), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193842] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7190), 1,
      anon_sym_LBRACE,
    ACTIONS(7192), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16442), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4019), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [193957] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7194), 1,
      anon_sym_LBRACE,
    ACTIONS(7196), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16503), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4020), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194072] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7198), 1,
      anon_sym_LBRACE,
    ACTIONS(7200), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16406), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4021), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194187] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7202), 1,
      anon_sym_LBRACE,
    ACTIONS(7204), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16662), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4022), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194302] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7206), 1,
      anon_sym_LBRACE,
    ACTIONS(7208), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16497), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4023), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194417] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7210), 1,
      anon_sym_LBRACE,
    ACTIONS(7212), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16393), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4024), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194532] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7214), 1,
      anon_sym_LBRACE,
    ACTIONS(7216), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16498), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4025), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194647] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7218), 1,
      anon_sym_LBRACE,
    ACTIONS(7220), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16404), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4026), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194762] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7222), 1,
      anon_sym_LBRACE,
    ACTIONS(7224), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16522), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4027), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194877] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7226), 1,
      anon_sym_LBRACE,
    ACTIONS(7228), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16553), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4028), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [194992] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7230), 1,
      anon_sym_LBRACE,
    ACTIONS(7232), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16474), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4029), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195107] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7234), 1,
      anon_sym_LBRACE,
    ACTIONS(7236), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16458), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4030), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195222] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7238), 1,
      anon_sym_LBRACE,
    ACTIONS(7240), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16518), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4031), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195337] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7242), 1,
      anon_sym_LBRACE,
    ACTIONS(7244), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16544), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4032), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195452] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7246), 1,
      anon_sym_LBRACE,
    ACTIONS(7248), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16628), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4033), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195567] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7250), 1,
      anon_sym_LBRACE,
    ACTIONS(7252), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16431), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4034), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195682] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7254), 1,
      anon_sym_LBRACE,
    ACTIONS(7256), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16414), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4035), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195797] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7258), 1,
      anon_sym_LBRACE,
    ACTIONS(7260), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14650), 1,
      sym_enumerator,
    STATE(16466), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4036), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [195912] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17198), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4037), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196024] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17423), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4038), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196136] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17875), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4039), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196248] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17471), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4040), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196360] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17683), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4041), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196472] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17773), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4042), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196584] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17003), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4043), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196696] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17644), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4044), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196808] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17611), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4045), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [196920] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17728), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4046), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197032] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17845), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4047), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197144] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14481), 1,
      sym_enumerator,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    ACTIONS(7274), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    STATE(4048), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197254] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17056), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4049), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197366] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 35,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [197428] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17797), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4051), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197540] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17048), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4052), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197652] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17796), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4053), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197764] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16953), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4054), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197876] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17245), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4055), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [197988] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16805), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4056), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198100] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16884), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4057), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198212] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17772), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4058), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198324] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16951), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4059), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198436] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17051), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4060), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198548] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17105), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4061), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198660] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 35,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [198722] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17110), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4063), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198834] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17787), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4064), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [198946] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17343), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4065), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199058] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17589), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4066), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199170] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16894), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4067), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199282] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17344), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4068), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199394] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17523), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4069), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199506] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(18475), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4070), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199618] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17741), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4071), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199730] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17524), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4072), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199842] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17740), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4073), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [199954] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17711), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4074), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200066] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17588), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4075), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200178] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16897), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4076), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200290] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17824), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4077), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200402] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16906), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4078), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200514] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16905), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4079), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200626] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 35,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [200688] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17861), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4081), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200800] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17706), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4082), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [200912] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17143), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4083), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201024] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16738), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4084), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201136] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17159), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4085), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201248] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16731), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4086), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201360] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17098), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4087), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201472] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17955), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4088), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201584] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16874), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4089), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201696] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17185), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4090), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201808] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17202), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4091), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [201920] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17097), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4092), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202032] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17470), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4093), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202144] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17841), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4094), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202256] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17954), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4095), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202368] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(18476), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4096), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202480] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17246), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4097), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202592] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16997), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4098), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202704] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16860), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4099), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202816] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17372), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4100), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [202928] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16859), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4101), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203040] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14481), 1,
      sym_enumerator,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    ACTIONS(7276), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(4102), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203150] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17387), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4103), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203262] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16971), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4104), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203374] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16705), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4105), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203486] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14481), 1,
      sym_enumerator,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    ACTIONS(7278), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(4106), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203596] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17902), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4107), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203708] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17920), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4108), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203820] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16813), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4109), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [203932] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17669), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4110), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [204044] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16811), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4111), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [204156] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17860), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4112), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [204268] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17667), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4113), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [204380] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17577), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4114), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [204492] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17685), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4115), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [204604] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17483), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4116), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [204716] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17292), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4117), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [204828] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16706), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4118), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [204940] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17237), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4119), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [205052] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16727), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4120), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [205164] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16769), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4121), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [205276] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17244), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4122), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [205388] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16943), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4123), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [205500] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17823), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4124), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [205612] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17770), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4125), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [205724] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17587), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4126), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [205836] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16853), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4127), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [205948] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17286), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4128), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [206060] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17291), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4129), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [206172] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17346), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4130), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [206284] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17536), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4131), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [206396] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17429), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4132), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [206508] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16726), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4133), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [206620] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17434), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4134), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [206732] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16998), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4135), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [206844] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14481), 1,
      sym_enumerator,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    ACTIONS(7280), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    STATE(4136), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [206954] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17144), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4137), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207066] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17145), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4138), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207178] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17390), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4139), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207290] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17199), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4140), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207402] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17482), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4141), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207514] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17918), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4142), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207626] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16772), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4143), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207738] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 35,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [207800] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17535), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4145), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [207912] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17396), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4146), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208024] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17785), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4147), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208136] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17729), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4148), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208248] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16942), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4149), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208360] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17646), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4150), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208472] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17874), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4151), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208584] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17422), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4152), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208696] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(16858), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4153), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208808] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17519), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4154), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [208920] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7266), 1,
      sym_operator_identifier,
    ACTIONS(7268), 1,
      sym_null_literal,
    STATE(6440), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10146), 1,
      sym_stable_identifier,
    STATE(10147), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17347), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4155), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10508), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209032] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7036), 1,
      sym__indent,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14827), 1,
      sym_enumerator,
    STATE(17294), 1,
      sym_enumerators,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4156), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209144] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 35,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [209205] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [209266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [209327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 35,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [209388] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7282), 1,
      anon_sym_case,
    ACTIONS(7284), 1,
      anon_sym_if,
    ACTIONS(7286), 1,
      sym_operator_identifier,
    ACTIONS(7288), 1,
      sym_null_literal,
    ACTIONS(7290), 1,
      sym__outdent,
    STATE(8810), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10898), 1,
      sym_wildcard,
    STATE(10910), 1,
      sym_stable_identifier,
    STATE(14444), 1,
      aux_sym_enumerator_repeat1,
    STATE(14859), 1,
      sym_guard,
    STATE(15695), 1,
      sym_enumerator,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4161), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11373), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209497] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [209558] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [209619] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7282), 1,
      anon_sym_case,
    ACTIONS(7284), 1,
      anon_sym_if,
    ACTIONS(7286), 1,
      sym_operator_identifier,
    ACTIONS(7288), 1,
      sym_null_literal,
    ACTIONS(7292), 1,
      sym__outdent,
    STATE(8810), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10898), 1,
      sym_wildcard,
    STATE(10910), 1,
      sym_stable_identifier,
    STATE(14444), 1,
      aux_sym_enumerator_repeat1,
    STATE(14859), 1,
      sym_guard,
    STATE(15695), 1,
      sym_enumerator,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4164), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11373), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [209728] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 35,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [209789] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 35,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [209850] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [209910] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [209970] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7282), 1,
      anon_sym_case,
    ACTIONS(7284), 1,
      anon_sym_if,
    ACTIONS(7286), 1,
      sym_operator_identifier,
    ACTIONS(7288), 1,
      sym_null_literal,
    STATE(8810), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10898), 1,
      sym_wildcard,
    STATE(10910), 1,
      sym_stable_identifier,
    STATE(14444), 1,
      aux_sym_enumerator_repeat1,
    STATE(14859), 1,
      sym_guard,
    STATE(14922), 1,
      sym_enumerator,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4169), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11373), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210076] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 33,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [210136] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7016), 1,
      anon_sym_case,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7032), 1,
      sym_operator_identifier,
    ACTIONS(7034), 1,
      sym_null_literal,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    STATE(8852), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11039), 1,
      sym_stable_identifier,
    STATE(11045), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14481), 1,
      sym_enumerator,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4171), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11310), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 34,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [210302] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [210362] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7282), 1,
      anon_sym_case,
    ACTIONS(7284), 1,
      anon_sym_if,
    ACTIONS(7286), 1,
      sym_operator_identifier,
    ACTIONS(7288), 1,
      sym_null_literal,
    STATE(8810), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10898), 1,
      sym_wildcard,
    STATE(10910), 1,
      sym_stable_identifier,
    STATE(14444), 1,
      aux_sym_enumerator_repeat1,
    STATE(14859), 1,
      sym_guard,
    STATE(15695), 1,
      sym_enumerator,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4174), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11373), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210468] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7024), 1,
      anon_sym_if,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7262), 1,
      anon_sym_case,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7270), 1,
      sym_operator_identifier,
    ACTIONS(7272), 1,
      sym_null_literal,
    STATE(8702), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10900), 1,
      sym_stable_identifier,
    STATE(10902), 1,
      sym_wildcard,
    STATE(13748), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(14481), 1,
      sym_enumerator,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4175), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11253), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [210574] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 34,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [210634] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 34,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [210694] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 12,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 33,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
      anon_sym_yield,
  [210754] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 34,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [210814] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 34,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [210874] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 44,
      anon_sym_enum,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_object,
      anon_sym_given,
      anon_sym_EQ_GT,
      anon_sym_as,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_do,
  [210931] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 10,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 34,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [210990] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 44,
      anon_sym_enum,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_object,
      anon_sym_given,
      anon_sym_EQ_GT,
      anon_sym_as,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_do,
  [211047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211106] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 33,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211165] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 33,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211342] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 33,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211401] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 10,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 34,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211460] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211578] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 33,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211696] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7296), 1,
      anon_sym_object,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7302), 1,
      anon_sym_class,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7312), 1,
      sym_operator_identifier,
    ACTIONS(7314), 1,
      sym_null_literal,
    STATE(268), 1,
      sym__case_pattern,
    STATE(7736), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10844), 1,
      sym_stable_identifier,
    STATE(10868), 1,
      sym_wildcard,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4195), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10998), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [211796] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211854] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 32,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [211970] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [212028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__outdent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 32,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [212086] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7316), 1,
      anon_sym_object,
    ACTIONS(7318), 1,
      anon_sym_class,
    ACTIONS(7320), 1,
      sym_operator_identifier,
    ACTIONS(7322), 1,
      sym_null_literal,
    STATE(340), 1,
      sym__case_pattern,
    STATE(7912), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10862), 1,
      sym_stable_identifier,
    STATE(10863), 1,
      sym_wildcard,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4201), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10939), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212186] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [212244] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2538), 1,
      anon_sym_LBRACK,
    STATE(4203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7327), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 5,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_then,
    ACTIONS(7332), 5,
      sym__indent,
      sym__simple_multiline_string,
      sym__simple_string,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7324), 8,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
    ACTIONS(7330), 21,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_implicit,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [212310] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 10,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [212368] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 10,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 33,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [212426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 9,
      sym__indent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7334), 34,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [212484] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 10,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [212541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 31,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [212598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__simple_multiline_string,
      sym__simple_string,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 31,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [212655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 10,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [212712] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2283), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4211), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212806] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2292), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4212), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212900] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2351), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4213), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [212994] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7356), 1,
      sym_operator_identifier,
    ACTIONS(7358), 1,
      sym_null_literal,
    STATE(8107), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11365), 1,
      sym_wildcard,
    STATE(11384), 1,
      sym_stable_identifier,
    STATE(16549), 1,
      sym_identifiers,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4214), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11483), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213088] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2343), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4215), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213182] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2227), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4216), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213276] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7360), 1,
      sym_operator_identifier,
    ACTIONS(7362), 1,
      sym_null_literal,
    STATE(8120), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11371), 1,
      sym_stable_identifier,
    STATE(11372), 1,
      sym_wildcard,
    STATE(16548), 1,
      sym_identifiers,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4217), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11462), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213370] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7374), 1,
      anon_sym_RPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7380), 1,
      sym_operator_identifier,
    ACTIONS(7382), 1,
      sym_null_literal,
    STATE(8817), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10985), 1,
      sym_wildcard,
    STATE(11021), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4218), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11316), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213464] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2306), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4219), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213558] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2195), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4220), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213652] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7380), 1,
      sym_operator_identifier,
    ACTIONS(7382), 1,
      sym_null_literal,
    ACTIONS(7384), 1,
      anon_sym_RPAREN,
    STATE(8817), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10985), 1,
      sym_wildcard,
    STATE(11021), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4221), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11316), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213746] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2172), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4222), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213840] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7386), 1,
      sym_operator_identifier,
    ACTIONS(7388), 1,
      sym_null_literal,
    STATE(7872), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11361), 1,
      sym_stable_identifier,
    STATE(11364), 1,
      sym_wildcard,
    STATE(16679), 1,
      sym_identifiers,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4223), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11480), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [213934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 8,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7334), 33,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [213990] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7390), 1,
      sym_operator_identifier,
    ACTIONS(7392), 1,
      sym_null_literal,
    STATE(7861), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11374), 1,
      sym_stable_identifier,
    STATE(11376), 1,
      sym_wildcard,
    STATE(16678), 1,
      sym_identifiers,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4225), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11461), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214084] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7380), 1,
      sym_operator_identifier,
    ACTIONS(7382), 1,
      sym_null_literal,
    ACTIONS(7394), 1,
      anon_sym_RPAREN,
    STATE(8817), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10985), 1,
      sym_wildcard,
    STATE(11021), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4226), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11316), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214178] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2184), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4227), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214272] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2398), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4228), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214366] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2263), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4229), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214460] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2402), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4230), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214554] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2403), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4231), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214648] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2314), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4232), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214742] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2288), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4233), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214836] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7396), 1,
      sym_operator_identifier,
    ACTIONS(7398), 1,
      sym_null_literal,
    STATE(8161), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11392), 1,
      sym_stable_identifier,
    STATE(11395), 1,
      sym_wildcard,
    STATE(16494), 1,
      sym_identifiers,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4234), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11409), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [214930] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2316), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4235), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215024] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2320), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4236), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215118] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7400), 1,
      sym_operator_identifier,
    ACTIONS(7402), 1,
      sym_null_literal,
    STATE(8166), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11386), 1,
      sym_stable_identifier,
    STATE(11389), 1,
      sym_wildcard,
    STATE(16505), 1,
      sym_identifiers,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4237), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11446), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215212] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2112), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4238), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215306] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2411), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4239), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215400] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2121), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4240), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215494] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2141), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4241), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215588] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7380), 1,
      sym_operator_identifier,
    ACTIONS(7382), 1,
      sym_null_literal,
    ACTIONS(7404), 1,
      anon_sym_RPAREN,
    STATE(8817), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10985), 1,
      sym_wildcard,
    STATE(11021), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4242), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11316), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215682] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2136), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4243), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215776] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2248), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4244), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215870] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7406), 1,
      anon_sym_RPAREN,
    ACTIONS(7408), 1,
      sym_operator_identifier,
    ACTIONS(7410), 1,
      sym_null_literal,
    STATE(7735), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10828), 1,
      sym_stable_identifier,
    STATE(10831), 1,
      sym_wildcard,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4245), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10972), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [215964] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2243), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4246), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216058] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7380), 1,
      sym_operator_identifier,
    ACTIONS(7382), 1,
      sym_null_literal,
    ACTIONS(7412), 1,
      anon_sym_RPAREN,
    STATE(8817), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10985), 1,
      sym_wildcard,
    STATE(11021), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4247), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11316), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216152] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2310), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4248), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216246] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7414), 1,
      sym_operator_identifier,
    ACTIONS(7416), 1,
      sym_null_literal,
    STATE(8234), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11218), 1,
      sym_stable_identifier,
    STATE(11219), 1,
      sym_wildcard,
    STATE(16524), 1,
      sym_identifiers,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4249), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11640), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216340] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7418), 1,
      sym_operator_identifier,
    ACTIONS(7420), 1,
      sym_null_literal,
    STATE(8232), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11215), 1,
      sym_stable_identifier,
    STATE(11216), 1,
      sym_wildcard,
    STATE(16525), 1,
      sym_identifiers,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4250), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11641), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216434] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2321), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4251), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216528] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2230), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4252), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216622] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7422), 1,
      anon_sym_RPAREN,
    ACTIONS(7424), 1,
      sym_operator_identifier,
    ACTIONS(7426), 1,
      sym_null_literal,
    STATE(8188), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10737), 1,
      sym_stable_identifier,
    STATE(10738), 1,
      sym_wildcard,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4253), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11077), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216716] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7312), 1,
      sym_operator_identifier,
    ACTIONS(7314), 1,
      sym_null_literal,
    STATE(268), 1,
      sym__case_pattern,
    STATE(7736), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10844), 1,
      sym_stable_identifier,
    STATE(10868), 1,
      sym_wildcard,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4254), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10998), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216810] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2179), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4255), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216904] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7380), 1,
      sym_operator_identifier,
    ACTIONS(7382), 1,
      sym_null_literal,
    ACTIONS(7428), 1,
      anon_sym_RPAREN,
    STATE(8817), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10985), 1,
      sym_wildcard,
    STATE(11021), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4256), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11316), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [216998] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7380), 1,
      sym_operator_identifier,
    ACTIONS(7382), 1,
      sym_null_literal,
    ACTIONS(7430), 1,
      anon_sym_RPAREN,
    STATE(8817), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10985), 1,
      sym_wildcard,
    STATE(11021), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4257), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11316), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [217092] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7432), 1,
      sym_operator_identifier,
    ACTIONS(7434), 1,
      sym_null_literal,
    STATE(7907), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11222), 1,
      sym_wildcard,
    STATE(11226), 1,
      sym_stable_identifier,
    STATE(16571), 1,
      sym_identifiers,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4258), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11619), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [217186] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7380), 1,
      sym_operator_identifier,
    ACTIONS(7382), 1,
      sym_null_literal,
    ACTIONS(7436), 1,
      anon_sym_RPAREN,
    STATE(8817), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10985), 1,
      sym_wildcard,
    STATE(11021), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4259), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11316), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [217280] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2235), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4260), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [217374] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7438), 1,
      anon_sym_RPAREN,
    ACTIONS(7440), 1,
      sym_operator_identifier,
    ACTIONS(7442), 1,
      sym_null_literal,
    STATE(8176), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10761), 1,
      sym_wildcard,
    STATE(10764), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4261), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11034), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [217468] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7444), 1,
      sym_operator_identifier,
    ACTIONS(7446), 1,
      sym_null_literal,
    STATE(7905), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11248), 1,
      sym_wildcard,
    STATE(11252), 1,
      sym_stable_identifier,
    STATE(16572), 1,
      sym_identifiers,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4262), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11584), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [217562] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2185), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4263), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [217656] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2378), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4264), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [217750] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2254), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4265), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [217844] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2256), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4266), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [217938] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2163), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4267), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [218032] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7448), 1,
      anon_sym_RPAREN,
    ACTIONS(7450), 1,
      sym_operator_identifier,
    ACTIONS(7452), 1,
      sym_null_literal,
    STATE(7955), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10765), 1,
      sym_wildcard,
    STATE(10766), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4268), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11035), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [218126] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2336), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4269), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [218220] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7338), 1,
      sym_operator_identifier,
    ACTIONS(7340), 1,
      sym_null_literal,
    STATE(2222), 1,
      sym__case_pattern,
    STATE(8133), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10837), 1,
      sym_wildcard,
    STATE(10840), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4270), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10956), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [218314] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7320), 1,
      sym_operator_identifier,
    ACTIONS(7322), 1,
      sym_null_literal,
    STATE(340), 1,
      sym__case_pattern,
    STATE(7912), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10862), 1,
      sym_stable_identifier,
    STATE(10863), 1,
      sym_wildcard,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4271), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10939), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [218408] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7454), 1,
      sym_operator_identifier,
    ACTIONS(7456), 1,
      sym_null_literal,
    STATE(8677), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(11152), 1,
      sym_stable_identifier,
    STATE(11157), 1,
      sym_wildcard,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4272), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11221), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [218499] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4356), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(12998), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14877), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(17943), 1,
      sym__constructor_application,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18523), 1,
      sym_template_body,
    STATE(4273), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218606] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7478), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [218663] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4373), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13055), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14681), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4275), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [218770] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7380), 1,
      sym_operator_identifier,
    ACTIONS(7382), 1,
      sym_null_literal,
    STATE(8817), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10985), 1,
      sym_wildcard,
    STATE(11021), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4276), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11316), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [218861] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7480), 1,
      sym_operator_identifier,
    ACTIONS(7482), 1,
      sym_null_literal,
    STATE(8195), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10721), 1,
      sym_stable_identifier,
    STATE(10722), 1,
      sym_wildcard,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4277), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11108), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [218952] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4390), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13142), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14788), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4278), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219059] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7484), 1,
      sym_operator_identifier,
    ACTIONS(7486), 1,
      sym_null_literal,
    STATE(7230), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10417), 1,
      sym_stable_identifier,
    STATE(10431), 1,
      sym_wildcard,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4279), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10696), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [219150] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7488), 1,
      sym_operator_identifier,
    ACTIONS(7490), 1,
      sym_null_literal,
    STATE(8697), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(11065), 1,
      sym_stable_identifier,
    STATE(11075), 1,
      sym_wildcard,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4280), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11227), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [219241] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7492), 1,
      sym_operator_identifier,
    ACTIONS(7494), 1,
      sym_null_literal,
    STATE(8703), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(11049), 1,
      sym_stable_identifier,
    STATE(11050), 1,
      sym_wildcard,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4281), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11182), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [219332] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7496), 1,
      sym_operator_identifier,
    ACTIONS(7498), 1,
      sym_null_literal,
    STATE(7293), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10443), 1,
      sym_stable_identifier,
    STATE(10448), 1,
      sym_wildcard,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4282), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10750), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [219423] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4357), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13019), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(15055), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(17943), 1,
      sym__constructor_application,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18523), 1,
      sym_template_body,
    STATE(4283), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219530] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_EQ_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [219585] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4438), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13130), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14788), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4285), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [219692] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7500), 1,
      sym_operator_identifier,
    ACTIONS(7502), 1,
      sym_null_literal,
    STATE(9549), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11275), 1,
      sym_wildcard,
    STATE(11280), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4286), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11556), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [219783] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7504), 1,
      sym_operator_identifier,
    ACTIONS(7506), 1,
      sym_null_literal,
    STATE(9568), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11282), 1,
      sym_wildcard,
    STATE(11292), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4287), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11535), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [219874] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7508), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [219931] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7510), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [219988] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6482), 1,
      sym_integer_literal,
    ACTIONS(7342), 1,
      sym__alpha_identifier,
    ACTIONS(7344), 1,
      anon_sym__,
    ACTIONS(7346), 1,
      anon_sym_given,
    ACTIONS(7350), 1,
      anon_sym_LPAREN,
    ACTIONS(7352), 1,
      anon_sym_SQUOTE,
    ACTIONS(7354), 1,
      sym__backquoted_id,
    ACTIONS(7512), 1,
      sym_operator_identifier,
    ACTIONS(7514), 1,
      sym_null_literal,
    STATE(9576), 1,
      sym_identifier,
    STATE(10661), 1,
      sym__soft_identifier,
    STATE(11318), 1,
      sym_wildcard,
    STATE(11325), 1,
      sym_stable_identifier,
    ACTIONS(6484), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6486), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6488), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4290), 2,
      sym_comment,
      sym_block_comment,
    STATE(12140), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17936), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7348), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11517), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [220079] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7508), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [220136] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4429), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(12971), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14681), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4292), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220243] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7516), 1,
      sym_operator_identifier,
    ACTIONS(7518), 1,
      sym_null_literal,
    STATE(8880), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(10893), 1,
      sym_wildcard,
    STATE(11044), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4293), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11367), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [220334] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7520), 1,
      sym_operator_identifier,
    ACTIONS(7522), 1,
      sym_null_literal,
    STATE(7273), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10464), 1,
      sym_stable_identifier,
    STATE(10555), 1,
      sym_wildcard,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4294), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10770), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [220425] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4435), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13231), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14615), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4295), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220532] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7524), 1,
      sym_operator_identifier,
    ACTIONS(7526), 1,
      sym_null_literal,
    STATE(8885), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(11089), 1,
      sym_wildcard,
    STATE(11107), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4296), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11363), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [220623] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4404), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(12984), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(15055), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(17943), 1,
      sym__constructor_application,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18523), 1,
      sym_template_body,
    STATE(4297), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [220730] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7528), 1,
      sym_operator_identifier,
    ACTIONS(7530), 1,
      sym_null_literal,
    STATE(7536), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10807), 1,
      sym_wildcard,
    STATE(10813), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4298), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10966), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [220821] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6822), 1,
      sym_integer_literal,
    ACTIONS(7294), 1,
      sym__alpha_identifier,
    ACTIONS(7298), 1,
      anon_sym__,
    ACTIONS(7300), 1,
      anon_sym_given,
    ACTIONS(7306), 1,
      anon_sym_LPAREN,
    ACTIONS(7308), 1,
      anon_sym_SQUOTE,
    ACTIONS(7310), 1,
      sym__backquoted_id,
    ACTIONS(7532), 1,
      sym_operator_identifier,
    ACTIONS(7534), 1,
      sym_null_literal,
    STATE(8895), 1,
      sym_identifier,
    STATE(10502), 1,
      sym__soft_identifier,
    STATE(11127), 1,
      sym_wildcard,
    STATE(11131), 1,
      sym_stable_identifier,
    ACTIONS(6824), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6826), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6828), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4299), 2,
      sym_comment,
      sym_block_comment,
    STATE(11886), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17801), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7304), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11353), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [220912] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4430), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(12972), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14615), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4300), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221019] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4422), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(12980), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14788), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4301), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221126] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7536), 1,
      sym_operator_identifier,
    ACTIONS(7538), 1,
      sym_null_literal,
    STATE(8672), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(10912), 1,
      sym_stable_identifier,
    STATE(10920), 1,
      sym_wildcard,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4302), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11224), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [221217] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7540), 1,
      sym_operator_identifier,
    ACTIONS(7542), 1,
      sym_null_literal,
    STATE(8321), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11055), 1,
      sym_wildcard,
    STATE(11094), 1,
      sym_stable_identifier,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4303), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11263), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [221308] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7478), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [221365] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4407), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13030), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14877), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(17943), 1,
      sym__constructor_application,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18523), 1,
      sym_template_body,
    STATE(4305), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221472] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4415), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13184), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14681), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4306), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221579] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7478), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [221636] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7508), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [221693] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7510), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [221750] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4358), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13000), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14954), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(17943), 1,
      sym__constructor_application,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18523), 1,
      sym_template_body,
    STATE(4310), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221857] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4359), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(12953), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14615), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4311), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [221964] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7544), 1,
      sym_operator_identifier,
    ACTIONS(7546), 1,
      sym_null_literal,
    STATE(8157), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10795), 1,
      sym_wildcard,
    STATE(10797), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4312), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10995), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [222055] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6734), 1,
      sym_integer_literal,
    ACTIONS(7012), 1,
      sym__alpha_identifier,
    ACTIONS(7018), 1,
      anon_sym__,
    ACTIONS(7020), 1,
      anon_sym_given,
    ACTIONS(7028), 1,
      anon_sym_SQUOTE,
    ACTIONS(7030), 1,
      sym__backquoted_id,
    ACTIONS(7264), 1,
      anon_sym_LPAREN,
    ACTIONS(7548), 1,
      sym_operator_identifier,
    ACTIONS(7550), 1,
      sym_null_literal,
    STATE(8868), 1,
      sym_identifier,
    STATE(9854), 1,
      sym__soft_identifier,
    STATE(11017), 1,
      sym_stable_identifier,
    STATE(11097), 1,
      sym_wildcard,
    ACTIONS(6736), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6738), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6740), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4313), 2,
      sym_comment,
      sym_block_comment,
    STATE(11291), 2,
      sym_boolean_literal,
      sym_string,
    STATE(18514), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11398), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [222146] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7460), 1,
      anon_sym_COLON,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(7470), 1,
      anon_sym_LPAREN,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7474), 1,
      sym_operator_identifier,
    ACTIONS(7476), 1,
      sym__automatic_semicolon,
    STATE(4433), 1,
      sym__given_constructor,
    STATE(12016), 1,
      sym_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13012), 1,
      sym__annotated_type,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14588), 1,
      sym_type_parameters,
    STATE(14596), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14954), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(17943), 1,
      sym__constructor_application,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18523), 1,
      sym_template_body,
    STATE(4314), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [222253] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 9,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7510), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [222310] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 32,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_EQ_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [222365] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6456), 1,
      sym_integer_literal,
    ACTIONS(7364), 1,
      sym__alpha_identifier,
    ACTIONS(7366), 1,
      anon_sym__,
    ACTIONS(7368), 1,
      anon_sym_given,
    ACTIONS(7372), 1,
      anon_sym_LPAREN,
    ACTIONS(7376), 1,
      anon_sym_SQUOTE,
    ACTIONS(7378), 1,
      sym__backquoted_id,
    ACTIONS(7552), 1,
      sym_operator_identifier,
    ACTIONS(7554), 1,
      sym_null_literal,
    STATE(7918), 1,
      sym_identifier,
    STATE(10575), 1,
      sym__soft_identifier,
    STATE(10853), 1,
      sym_wildcard,
    STATE(10859), 1,
      sym_stable_identifier,
    ACTIONS(6458), 2,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(6460), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(6462), 2,
      sym__simple_multiline_string,
      sym__simple_string,
    STATE(4317), 2,
      sym_comment,
      sym_block_comment,
    STATE(11813), 2,
      sym_boolean_literal,
      sym_string,
    STATE(17721), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10938), 11,
      sym_case_class_pattern,
      sym_infix_pattern,
      sym_capture_pattern,
      sym_repeat_pattern,
      sym_typed_pattern,
      sym_given_pattern,
      sym_alternative_pattern,
      sym_tuple_pattern,
      sym_quote_expression,
      sym__non_null_literal,
      sym_interpolated_string_expression,
  [222456] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 39,
      anon_sym_enum,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_EQ_GT,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [222508] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7560), 8,
      sym__indent,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7558), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [222560] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4918), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4916), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [222611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 35,
      anon_sym_enum,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [222662] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4922), 7,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4920), 29,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_try,
      anon_sym_new,
      anon_sym_opaque,
      anon_sym_implicit,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_macro,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_DOLLAR,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
      anon_sym_return,
      anon_sym_throw,
      anon_sym_do,
  [222713] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(489), 1,
      sym__alpha_identifier,
    ACTIONS(553), 1,
      sym__backquoted_id,
    ACTIONS(7568), 1,
      sym_operator_identifier,
    STATE(5518), 1,
      sym__soft_identifier,
    STATE(10006), 1,
      sym_identifier,
    STATE(4323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(4176), 6,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_DQUOTE,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(7566), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [222777] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(7574), 1,
      sym_operator_identifier,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(7006), 1,
      sym_identifier,
    STATE(4324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 6,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_DQUOTE,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(7570), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [222841] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 35,
      anon_sym_enum,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [222889] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(7574), 1,
      sym_operator_identifier,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(7006), 1,
      sym_identifier,
    STATE(4326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 5,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_EQ,
      anon_sym_QMARK_EQ_GT,
      anon_sym_DQUOTE,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__interpolated_multiline_string_start,
    ACTIONS(7570), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [222952] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7584), 1,
      anon_sym_implicit,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7594), 1,
      anon_sym_using,
    ACTIONS(7596), 1,
      anon_sym_RPAREN,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15858), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [223043] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7602), 1,
      anon_sym_LBRACE,
    ACTIONS(7604), 1,
      anon_sym_LBRACK,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym__indent,
    STATE(4491), 1,
      sym_type_parameters,
    STATE(4528), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15803), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4328), 2,
      sym_comment,
      sym_block_comment,
    STATE(14670), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [223134] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7604), 1,
      anon_sym_LBRACK,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7626), 1,
      anon_sym_LBRACE,
    ACTIONS(7628), 1,
      sym__indent,
    STATE(4458), 1,
      aux_sym_extension_definition_repeat1,
    STATE(4535), 1,
      sym_type_parameters,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15918), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4329), 2,
      sym_comment,
      sym_block_comment,
    STATE(14863), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [223225] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7602), 1,
      anon_sym_LBRACE,
    ACTIONS(7604), 1,
      anon_sym_LBRACK,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym__indent,
    STATE(4443), 1,
      sym_type_parameters,
    STATE(4483), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15997), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4330), 2,
      sym_comment,
      sym_block_comment,
    STATE(14670), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [223316] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7630), 1,
      anon_sym_implicit,
    ACTIONS(7632), 1,
      anon_sym_using,
    ACTIONS(7634), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15885), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [223407] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7636), 1,
      anon_sym_implicit,
    ACTIONS(7638), 1,
      anon_sym_using,
    ACTIONS(7640), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15992), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [223498] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7642), 1,
      anon_sym_enum,
    ACTIONS(7644), 1,
      anon_sym_case,
    ACTIONS(7646), 1,
      anon_sym_object,
    ACTIONS(7648), 1,
      anon_sym_given,
    ACTIONS(7650), 1,
      anon_sym_class,
    ACTIONS(7652), 1,
      anon_sym_trait,
    ACTIONS(7654), 1,
      anon_sym_val,
    ACTIONS(7656), 1,
      anon_sym_var,
    ACTIONS(7658), 1,
      anon_sym_type,
    ACTIONS(7660), 1,
      anon_sym_def,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(6346), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(13011), 1,
      sym_modifiers,
    STATE(18503), 1,
      sym_opaque_modifier,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4333), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [223591] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7664), 1,
      anon_sym_implicit,
    ACTIONS(7666), 1,
      anon_sym_using,
    ACTIONS(7668), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15333), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [223682] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7670), 1,
      anon_sym_implicit,
    ACTIONS(7672), 1,
      anon_sym_using,
    ACTIONS(7674), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15484), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [223773] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7680), 1,
      anon_sym_LBRACK,
    ACTIONS(7682), 1,
      anon_sym_LPAREN,
    ACTIONS(7684), 1,
      anon_sym_POUND,
    STATE(4474), 1,
      aux_sym_annotation_repeat1,
    STATE(4554), 1,
      sym_type_arguments,
    STATE(4693), 1,
      sym_arguments,
    STATE(4336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [223834] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7686), 1,
      anon_sym_implicit,
    ACTIONS(7688), 1,
      anon_sym_using,
    ACTIONS(7690), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16021), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [223925] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7604), 1,
      anon_sym_LBRACK,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7626), 1,
      anon_sym_LBRACE,
    ACTIONS(7628), 1,
      sym__indent,
    STATE(4498), 1,
      sym_type_parameters,
    STATE(4501), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(16048), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4338), 2,
      sym_comment,
      sym_block_comment,
    STATE(14863), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [224016] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7602), 1,
      anon_sym_LBRACE,
    ACTIONS(7604), 1,
      anon_sym_LBRACK,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym__indent,
    STATE(4505), 1,
      sym_type_parameters,
    STATE(4519), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15218), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4339), 2,
      sym_comment,
      sym_block_comment,
    STATE(14670), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [224107] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7696), 1,
      anon_sym_LBRACK,
    ACTIONS(7698), 1,
      anon_sym_AT,
    ACTIONS(7700), 1,
      anon_sym_LPAREN,
    ACTIONS(7702), 1,
      anon_sym_POUND,
    STATE(4538), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4651), 1,
      sym_type_arguments,
    STATE(4925), 1,
      sym_annotation,
    STATE(5908), 1,
      sym_arguments,
    STATE(4340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [224172] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7704), 1,
      anon_sym_implicit,
    ACTIONS(7706), 1,
      anon_sym_using,
    ACTIONS(7708), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15883), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [224263] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7710), 1,
      anon_sym_implicit,
    ACTIONS(7712), 1,
      anon_sym_using,
    ACTIONS(7714), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15562), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [224354] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7654), 1,
      anon_sym_val,
    ACTIONS(7656), 1,
      anon_sym_var,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(7716), 1,
      anon_sym_enum,
    ACTIONS(7718), 1,
      anon_sym_case,
    ACTIONS(7720), 1,
      anon_sym_object,
    ACTIONS(7722), 1,
      anon_sym_given,
    ACTIONS(7724), 1,
      anon_sym_class,
    ACTIONS(7726), 1,
      anon_sym_trait,
    ACTIONS(7728), 1,
      anon_sym_type,
    ACTIONS(7730), 1,
      anon_sym_def,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(6346), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(13207), 1,
      sym_modifiers,
    STATE(17967), 1,
      sym_opaque_modifier,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4343), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [224447] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7654), 1,
      anon_sym_val,
    ACTIONS(7656), 1,
      anon_sym_var,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(7716), 1,
      anon_sym_enum,
    ACTIONS(7720), 1,
      anon_sym_object,
    ACTIONS(7722), 1,
      anon_sym_given,
    ACTIONS(7724), 1,
      anon_sym_class,
    ACTIONS(7726), 1,
      anon_sym_trait,
    ACTIONS(7728), 1,
      anon_sym_type,
    ACTIONS(7730), 1,
      anon_sym_def,
    ACTIONS(7732), 1,
      anon_sym_case,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(6346), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(13207), 1,
      sym_modifiers,
    STATE(17967), 1,
      sym_opaque_modifier,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4344), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [224540] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7654), 1,
      anon_sym_val,
    ACTIONS(7656), 1,
      anon_sym_var,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(7716), 1,
      anon_sym_enum,
    ACTIONS(7718), 1,
      anon_sym_case,
    ACTIONS(7720), 1,
      anon_sym_object,
    ACTIONS(7724), 1,
      anon_sym_class,
    ACTIONS(7726), 1,
      anon_sym_trait,
    ACTIONS(7728), 1,
      anon_sym_type,
    ACTIONS(7730), 1,
      anon_sym_def,
    ACTIONS(7734), 1,
      anon_sym_given,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(6346), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(13046), 1,
      sym_modifiers,
    STATE(17967), 1,
      sym_opaque_modifier,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4345), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [224633] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7736), 1,
      anon_sym_implicit,
    ACTIONS(7738), 1,
      anon_sym_using,
    ACTIONS(7740), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16033), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [224724] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7642), 1,
      anon_sym_enum,
    ACTIONS(7646), 1,
      anon_sym_object,
    ACTIONS(7650), 1,
      anon_sym_class,
    ACTIONS(7652), 1,
      anon_sym_trait,
    ACTIONS(7654), 1,
      anon_sym_val,
    ACTIONS(7656), 1,
      anon_sym_var,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(7742), 1,
      anon_sym_case,
    ACTIONS(7744), 1,
      anon_sym_given,
    ACTIONS(7746), 1,
      anon_sym_type,
    ACTIONS(7748), 1,
      anon_sym_def,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(6346), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(13347), 1,
      sym_modifiers,
    STATE(17982), 1,
      sym_opaque_modifier,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4347), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [224817] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7754), 1,
      anon_sym_with,
    STATE(4420), 1,
      aux_sym_compound_type_repeat1,
    STATE(5539), 1,
      sym_template_body,
    STATE(5540), 1,
      sym__refinement,
    STATE(5908), 1,
      sym_arguments,
    STATE(4348), 2,
      sym_comment,
      sym_block_comment,
    STATE(5828), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [224878] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7642), 1,
      anon_sym_enum,
    ACTIONS(7644), 1,
      anon_sym_case,
    ACTIONS(7646), 1,
      anon_sym_object,
    ACTIONS(7650), 1,
      anon_sym_class,
    ACTIONS(7652), 1,
      anon_sym_trait,
    ACTIONS(7654), 1,
      anon_sym_val,
    ACTIONS(7656), 1,
      anon_sym_var,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(7746), 1,
      anon_sym_type,
    ACTIONS(7748), 1,
      anon_sym_def,
    ACTIONS(7756), 1,
      anon_sym_given,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(6346), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(13308), 1,
      sym_modifiers,
    STATE(17982), 1,
      sym_opaque_modifier,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4349), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [224971] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7758), 1,
      anon_sym_implicit,
    ACTIONS(7760), 1,
      anon_sym_using,
    ACTIONS(7762), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15961), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(61), 5,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_lazy,
      anon_sym_override,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
  [225062] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7764), 1,
      anon_sym_DOT,
    STATE(4351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [225111] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7642), 1,
      anon_sym_enum,
    ACTIONS(7644), 1,
      anon_sym_case,
    ACTIONS(7646), 1,
      anon_sym_object,
    ACTIONS(7650), 1,
      anon_sym_class,
    ACTIONS(7652), 1,
      anon_sym_trait,
    ACTIONS(7654), 1,
      anon_sym_val,
    ACTIONS(7656), 1,
      anon_sym_var,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(7744), 1,
      anon_sym_given,
    ACTIONS(7746), 1,
      anon_sym_type,
    ACTIONS(7748), 1,
      anon_sym_def,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(6346), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(13347), 1,
      sym_modifiers,
    STATE(17982), 1,
      sym_opaque_modifier,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4352), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [225204] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7696), 1,
      anon_sym_LBRACK,
    ACTIONS(7698), 1,
      anon_sym_AT,
    ACTIONS(7702), 1,
      anon_sym_POUND,
    STATE(4538), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4651), 1,
      sym_type_arguments,
    STATE(4925), 1,
      sym_annotation,
    STATE(4353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [225264] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7768), 1,
      anon_sym_COLON,
    ACTIONS(7770), 1,
      anon_sym_LBRACE,
    ACTIONS(7774), 1,
      anon_sym_with,
    STATE(4355), 1,
      aux_sym_compound_type_repeat1,
    STATE(6951), 1,
      sym__refinement,
    STATE(6952), 1,
      sym_template_body,
    STATE(4354), 2,
      sym_comment,
      sym_block_comment,
    STATE(6811), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [225326] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7768), 1,
      anon_sym_COLON,
    ACTIONS(7770), 1,
      anon_sym_LBRACE,
    ACTIONS(7774), 1,
      anon_sym_with,
    STATE(4982), 1,
      aux_sym_compound_type_repeat1,
    STATE(6938), 1,
      sym__refinement,
    STATE(6952), 1,
      sym_template_body,
    STATE(4355), 2,
      sym_comment,
      sym_block_comment,
    STATE(6811), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [225388] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13006), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14918), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(17943), 1,
      sym__constructor_application,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18523), 1,
      sym_template_body,
    STATE(4356), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [225474] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13020), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(15108), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(17943), 1,
      sym__constructor_application,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18523), 1,
      sym_template_body,
    STATE(4357), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [225560] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(12988), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(15046), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(17943), 1,
      sym__constructor_application,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18523), 1,
      sym_template_body,
    STATE(4358), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [225646] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(12962), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14801), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4359), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [225732] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7792), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4360), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [225818] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7794), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15578), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4361), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [225904] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [225950] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7798), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4363), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226036] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7794), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15578), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4364), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226122] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7714), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15562), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4365), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226208] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [226254] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7802), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15684), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4367), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226340] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7804), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4368), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226426] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7806), 1,
      anon_sym_COLON,
    ACTIONS(7808), 1,
      anon_sym_LBRACE,
    ACTIONS(7810), 1,
      anon_sym__,
    ACTIONS(7812), 1,
      anon_sym_LPAREN,
    ACTIONS(7814), 1,
      sym_operator_identifier,
    STATE(11622), 1,
      sym__simple_type,
    STATE(11910), 1,
      sym__annotated_type,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12944), 1,
      sym_identifier,
    STATE(14068), 1,
      sym__constructor_application,
    STATE(14103), 1,
      sym_annotated_type,
    STATE(14353), 1,
      sym_compound_type,
    STATE(14452), 1,
      sym__constructor_applications,
    STATE(14478), 1,
      sym__structural_type,
    STATE(14551), 1,
      sym_template_body,
    STATE(17617), 1,
      sym_stable_identifier,
    STATE(4369), 2,
      sym_comment,
      sym_block_comment,
    STATE(14520), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13249), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [226512] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7816), 1,
      anon_sym_LBRACK,
    ACTIONS(7818), 1,
      anon_sym_LPAREN,
    ACTIONS(7820), 1,
      anon_sym_POUND,
    STATE(4624), 1,
      aux_sym_annotation_repeat1,
    STATE(4742), 1,
      sym_type_arguments,
    STATE(5004), 1,
      sym_arguments,
    STATE(4370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [226572] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7822), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4371), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226658] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [226704] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13122), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14840), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4373), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [226790] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7826), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4374), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226876] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7828), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4375), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [226962] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7830), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15897), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4376), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227048] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7802), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4377), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227134] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7802), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15684), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4378), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227220] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7634), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15885), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4379), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227306] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7634), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15885), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4380), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227392] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [227438] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7834), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4382), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227524] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7836), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16040), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4383), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227610] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7836), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16040), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4384), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227696] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7838), 1,
      anon_sym_LBRACK,
    ACTIONS(7840), 1,
      anon_sym_AT,
    ACTIONS(7842), 1,
      anon_sym_LPAREN,
    ACTIONS(7844), 1,
      anon_sym_POUND,
    STATE(4711), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5075), 1,
      sym_type_arguments,
    STATE(5431), 1,
      sym_annotation,
    STATE(6444), 1,
      sym_arguments,
    STATE(4385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [227760] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [227806] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [227852] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7762), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15961), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4388), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [227938] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7848), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4389), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228024] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13199), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14645), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4390), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [228110] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7850), 1,
      sym__alpha_identifier,
    ACTIONS(7852), 1,
      anon_sym_COLON,
    ACTIONS(7854), 1,
      anon_sym_LBRACE,
    ACTIONS(7856), 1,
      anon_sym__,
    ACTIONS(7860), 1,
      anon_sym_LPAREN,
    ACTIONS(7862), 1,
      sym__backquoted_id,
    ACTIONS(7864), 1,
      sym_operator_identifier,
    STATE(11512), 1,
      sym__simple_type,
    STATE(11871), 1,
      sym__annotated_type,
    STATE(12550), 1,
      sym_identifier,
    STATE(12664), 1,
      sym__soft_identifier,
    STATE(14163), 1,
      sym__constructor_application,
    STATE(14212), 1,
      sym_annotated_type,
    STATE(14365), 1,
      sym_compound_type,
    STATE(14435), 1,
      sym__constructor_applications,
    STATE(14442), 1,
      sym__structural_type,
    STATE(14468), 1,
      sym_template_body,
    STATE(17732), 1,
      sym_stable_identifier,
    STATE(4391), 2,
      sym_comment,
      sym_block_comment,
    STATE(14489), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13328), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [228196] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7866), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4392), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228282] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7868), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4393), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228368] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7836), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4394), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228454] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [228500] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7872), 1,
      anon_sym_LBRACK,
    ACTIONS(7874), 1,
      anon_sym_AT,
    ACTIONS(7876), 1,
      anon_sym_LPAREN,
    ACTIONS(7878), 1,
      anon_sym_POUND,
    STATE(4808), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4932), 1,
      sym_type_arguments,
    STATE(5173), 1,
      sym_annotation,
    STATE(6139), 1,
      sym_arguments,
    STATE(4396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [228564] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7768), 1,
      anon_sym_COLON,
    ACTIONS(7770), 1,
      anon_sym_LBRACE,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7774), 1,
      anon_sym_with,
    STATE(4355), 1,
      aux_sym_compound_type_repeat1,
    STATE(6951), 1,
      sym__refinement,
    STATE(6952), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4397), 2,
      sym_comment,
      sym_block_comment,
    STATE(6811), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 8,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [228632] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7830), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15897), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4398), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228718] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7886), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4399), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228804] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7888), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4400), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228890] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7890), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4401), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [228976] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [229022] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7798), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15990), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4403), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229108] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(12974), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(15108), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(17943), 1,
      sym__constructor_application,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18523), 1,
      sym_template_body,
    STATE(4404), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [229194] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7798), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15990), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4405), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229280] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7894), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4406), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229366] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13015), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14918), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(17943), 1,
      sym__constructor_application,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18523), 1,
      sym_template_body,
    STATE(4407), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [229452] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7896), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4408), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229538] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [229584] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7900), 1,
      anon_sym_with,
    STATE(4533), 1,
      aux_sym_compound_type_repeat1,
    STATE(6108), 1,
      sym_template_body,
    STATE(6113), 1,
      sym__refinement,
    STATE(6139), 1,
      sym_arguments,
    STATE(4410), 2,
      sym_comment,
      sym_block_comment,
    STATE(6152), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [229644] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7714), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15562), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4411), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229730] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7902), 1,
      anon_sym_LBRACK,
    ACTIONS(7904), 1,
      anon_sym_LPAREN,
    ACTIONS(7906), 1,
      anon_sym_POUND,
    STATE(4628), 1,
      aux_sym_annotation_repeat1,
    STATE(4814), 1,
      sym_type_arguments,
    STATE(5015), 1,
      sym_arguments,
    STATE(4412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [229790] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7908), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4413), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229876] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7910), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4414), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [229962] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13141), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14840), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4415), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [230048] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7850), 1,
      sym__alpha_identifier,
    ACTIONS(7852), 1,
      anon_sym_COLON,
    ACTIONS(7854), 1,
      anon_sym_LBRACE,
    ACTIONS(7856), 1,
      anon_sym__,
    ACTIONS(7860), 1,
      anon_sym_LPAREN,
    ACTIONS(7862), 1,
      sym__backquoted_id,
    ACTIONS(7864), 1,
      sym_operator_identifier,
    STATE(11512), 1,
      sym__simple_type,
    STATE(11871), 1,
      sym__annotated_type,
    STATE(12550), 1,
      sym_identifier,
    STATE(12664), 1,
      sym__soft_identifier,
    STATE(14212), 1,
      sym_annotated_type,
    STATE(14245), 1,
      sym__constructor_application,
    STATE(14365), 1,
      sym_compound_type,
    STATE(14435), 1,
      sym__constructor_applications,
    STATE(14442), 1,
      sym__structural_type,
    STATE(14468), 1,
      sym_template_body,
    STATE(17732), 1,
      sym_stable_identifier,
    STATE(4416), 2,
      sym_comment,
      sym_block_comment,
    STATE(14489), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13328), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [230134] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [230180] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7914), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4418), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [230266] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7916), 1,
      sym__alpha_identifier,
    ACTIONS(7918), 1,
      anon_sym_COLON,
    ACTIONS(7920), 1,
      anon_sym_LBRACE,
    ACTIONS(7922), 1,
      anon_sym__,
    ACTIONS(7926), 1,
      anon_sym_LPAREN,
    ACTIONS(7928), 1,
      sym__backquoted_id,
    ACTIONS(7930), 1,
      sym_operator_identifier,
    STATE(11178), 1,
      sym__simple_type,
    STATE(11188), 1,
      sym__annotated_type,
    STATE(11727), 1,
      sym__soft_identifier,
    STATE(11847), 1,
      sym_identifier,
    STATE(12583), 1,
      sym__constructor_application,
    STATE(13086), 1,
      sym_compound_type,
    STATE(13435), 1,
      sym__structural_type,
    STATE(13575), 1,
      sym_template_body,
    STATE(13592), 1,
      sym_annotated_type,
    STATE(13820), 1,
      sym__constructor_applications,
    STATE(17453), 1,
      sym_stable_identifier,
    STATE(4419), 2,
      sym_comment,
      sym_block_comment,
    STATE(13431), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7924), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12322), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [230352] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7754), 1,
      anon_sym_with,
    STATE(4858), 1,
      aux_sym_compound_type_repeat1,
    STATE(5539), 1,
      sym_template_body,
    STATE(5548), 1,
      sym__refinement,
    STATE(4420), 2,
      sym_comment,
      sym_block_comment,
    STATE(5828), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [230410] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7696), 1,
      anon_sym_LBRACK,
    ACTIONS(7702), 1,
      anon_sym_POUND,
    ACTIONS(7932), 1,
      anon_sym_LPAREN,
    STATE(4602), 1,
      aux_sym_annotation_repeat1,
    STATE(4651), 1,
      sym_type_arguments,
    STATE(5030), 1,
      sym_arguments,
    STATE(4421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [230470] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(12983), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14645), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4422), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [230556] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7934), 1,
      anon_sym_LBRACK,
    ACTIONS(7936), 1,
      anon_sym_LPAREN,
    ACTIONS(7938), 1,
      anon_sym_POUND,
    STATE(4570), 1,
      aux_sym_annotation_repeat1,
    STATE(4751), 1,
      sym_type_arguments,
    STATE(4851), 1,
      sym_arguments,
    STATE(4423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [230616] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7910), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15909), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4424), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [230702] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7940), 1,
      sym__alpha_identifier,
    ACTIONS(7942), 1,
      anon_sym_COLON,
    ACTIONS(7944), 1,
      anon_sym_LBRACE,
    ACTIONS(7946), 1,
      anon_sym__,
    ACTIONS(7950), 1,
      anon_sym_LPAREN,
    ACTIONS(7952), 1,
      sym__backquoted_id,
    ACTIONS(7954), 1,
      sym_operator_identifier,
    STATE(10697), 1,
      sym__simple_type,
    STATE(11038), 1,
      sym__annotated_type,
    STATE(11430), 1,
      sym_identifier,
    STATE(11669), 1,
      sym__soft_identifier,
    STATE(12282), 1,
      sym__constructor_application,
    STATE(12483), 1,
      sym_compound_type,
    STATE(12973), 1,
      sym_template_body,
    STATE(13035), 1,
      sym_annotated_type,
    STATE(13363), 1,
      sym__structural_type,
    STATE(13698), 1,
      sym__constructor_applications,
    STATE(17077), 1,
      sym_stable_identifier,
    STATE(4425), 2,
      sym_comment,
      sym_block_comment,
    STATE(13322), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7948), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11959), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [230788] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7910), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15909), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4426), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [230874] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7806), 1,
      anon_sym_COLON,
    ACTIONS(7808), 1,
      anon_sym_LBRACE,
    ACTIONS(7810), 1,
      anon_sym__,
    ACTIONS(7812), 1,
      anon_sym_LPAREN,
    ACTIONS(7814), 1,
      sym_operator_identifier,
    STATE(11622), 1,
      sym__simple_type,
    STATE(11910), 1,
      sym__annotated_type,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12944), 1,
      sym_identifier,
    STATE(14103), 1,
      sym_annotated_type,
    STATE(14260), 1,
      sym__constructor_application,
    STATE(14353), 1,
      sym_compound_type,
    STATE(14452), 1,
      sym__constructor_applications,
    STATE(14478), 1,
      sym__structural_type,
    STATE(14551), 1,
      sym_template_body,
    STATE(17617), 1,
      sym_stable_identifier,
    STATE(4427), 2,
      sym_comment,
      sym_block_comment,
    STATE(14520), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13249), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [230960] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7740), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16033), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4428), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [231046] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(12977), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14840), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4429), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231132] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13036), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14801), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4430), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231218] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7740), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16033), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4431), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [231304] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7956), 1,
      sym__alpha_identifier,
    ACTIONS(7958), 1,
      anon_sym_COLON,
    ACTIONS(7960), 1,
      anon_sym_LBRACE,
    ACTIONS(7962), 1,
      anon_sym__,
    ACTIONS(7966), 1,
      anon_sym_LPAREN,
    ACTIONS(7968), 1,
      sym__backquoted_id,
    ACTIONS(7970), 1,
      sym_operator_identifier,
    STATE(12149), 1,
      sym__simple_type,
    STATE(12949), 1,
      sym__annotated_type,
    STATE(13475), 1,
      sym_identifier,
    STATE(13521), 1,
      sym__soft_identifier,
    STATE(14232), 1,
      sym__constructor_application,
    STATE(14308), 1,
      sym_compound_type,
    STATE(14451), 1,
      sym_annotated_type,
    STATE(14550), 1,
      sym_template_body,
    STATE(14575), 1,
      sym__structural_type,
    STATE(14614), 1,
      sym__constructor_applications,
    STATE(17306), 1,
      sym_stable_identifier,
    STATE(4432), 2,
      sym_comment,
      sym_block_comment,
    STATE(14568), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7964), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13929), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231390] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13016), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(15046), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(17943), 1,
      sym__constructor_application,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18523), 1,
      sym_template_body,
    STATE(4433), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231476] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(7976), 1,
      sym__interpolated_multiline_string_start,
    STATE(5898), 1,
      sym_interpolated_string,
    STATE(16176), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [231534] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13196), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14801), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4435), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231620] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7978), 1,
      anon_sym_with,
    STATE(4464), 1,
      aux_sym_compound_type_repeat1,
    STATE(6444), 1,
      sym_arguments,
    STATE(6490), 1,
      sym__refinement,
    STATE(6502), 1,
      sym_template_body,
    STATE(4436), 2,
      sym_comment,
      sym_block_comment,
    STATE(6651), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [231680] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7680), 1,
      anon_sym_LBRACK,
    ACTIONS(7684), 1,
      anon_sym_POUND,
    ACTIONS(7980), 1,
      anon_sym_AT,
    STATE(4554), 1,
      sym_type_arguments,
    STATE(4631), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4953), 1,
      sym_annotation,
    STATE(4437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [231740] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7782), 1,
      anon_sym_COLON,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12808), 1,
      sym__simple_type,
    STATE(13106), 1,
      sym__annotated_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(14645), 1,
      sym__structural_instance,
    STATE(15208), 1,
      sym_compound_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(18519), 1,
      sym__structural_type,
    STATE(18521), 1,
      sym__constructor_application,
    STATE(18523), 1,
      sym_template_body,
    STATE(4438), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [231826] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 33,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_do,
  [231872] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7762), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(15961), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4440), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [231958] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7984), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4441), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [232044] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    ACTIONS(7986), 1,
      anon_sym_RPAREN,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4442), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [232130] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7602), 1,
      anon_sym_LBRACE,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym__indent,
    STATE(4488), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15997), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4443), 2,
      sym_comment,
      sym_block_comment,
    STATE(14734), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [232215] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6580), 1,
      anon_sym_COLON,
    ACTIONS(6582), 1,
      anon_sym_LBRACE,
    ACTIONS(7988), 1,
      sym__alpha_identifier,
    ACTIONS(7990), 1,
      anon_sym__,
    ACTIONS(7994), 1,
      anon_sym_LPAREN,
    ACTIONS(7996), 1,
      sym__backquoted_id,
    ACTIONS(7998), 1,
      sym_operator_identifier,
    STATE(4913), 1,
      sym__simple_type,
    STATE(5051), 1,
      sym__annotated_type,
    STATE(7178), 1,
      sym__constructor_application,
    STATE(7258), 1,
      sym__soft_identifier,
    STATE(7416), 1,
      sym_identifier,
    STATE(8300), 1,
      sym_annotated_type,
    STATE(8842), 1,
      sym_compound_type,
    STATE(9089), 1,
      sym__structural_type,
    STATE(9569), 1,
      sym_template_body,
    STATE(17479), 1,
      sym_stable_identifier,
    STATE(4444), 2,
      sym_comment,
      sym_block_comment,
    STATE(9188), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7992), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [232298] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [232345] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7816), 1,
      anon_sym_LBRACK,
    ACTIONS(7820), 1,
      anon_sym_POUND,
    ACTIONS(8000), 1,
      anon_sym_AT,
    STATE(4663), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4742), 1,
      sym_type_arguments,
    STATE(5479), 1,
      sym_annotation,
    STATE(4446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [232404] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7838), 1,
      anon_sym_LBRACK,
    ACTIONS(7840), 1,
      anon_sym_AT,
    ACTIONS(7844), 1,
      anon_sym_POUND,
    STATE(4711), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5075), 1,
      sym_type_arguments,
    STATE(5431), 1,
      sym_annotation,
    STATE(4447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [232463] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7626), 1,
      anon_sym_LBRACE,
    ACTIONS(7628), 1,
      sym__indent,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10166), 1,
      aux_sym_extension_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15918), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4448), 2,
      sym_comment,
      sym_block_comment,
    STATE(15057), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [232548] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8004), 1,
      anon_sym_DOT,
    STATE(4449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [232597] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_COLON,
    ACTIONS(8008), 1,
      anon_sym_LBRACE,
    ACTIONS(8010), 1,
      anon_sym_with,
    STATE(5242), 1,
      aux_sym_compound_type_repeat1,
    STATE(7794), 1,
      sym__refinement,
    STATE(7802), 1,
      sym_template_body,
    STATE(4450), 2,
      sym_comment,
      sym_block_comment,
    STATE(7614), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [232658] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7838), 1,
      anon_sym_LBRACK,
    ACTIONS(7844), 1,
      anon_sym_POUND,
    ACTIONS(8012), 1,
      anon_sym_LPAREN,
    STATE(4710), 1,
      aux_sym_annotation_repeat1,
    STATE(5075), 1,
      sym_type_arguments,
    STATE(5252), 1,
      sym_arguments,
    STATE(4451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [232717] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7916), 1,
      sym__alpha_identifier,
    ACTIONS(7922), 1,
      anon_sym__,
    ACTIONS(7926), 1,
      anon_sym_LPAREN,
    ACTIONS(7928), 1,
      sym__backquoted_id,
    ACTIONS(7930), 1,
      sym_operator_identifier,
    ACTIONS(8014), 1,
      anon_sym_COLON,
    ACTIONS(8016), 1,
      anon_sym_LBRACE,
    STATE(10899), 1,
      sym__simple_type,
    STATE(11236), 1,
      sym__annotated_type,
    STATE(11727), 1,
      sym__soft_identifier,
    STATE(11847), 1,
      sym_identifier,
    STATE(13478), 1,
      sym_compound_type,
    STATE(13592), 1,
      sym_annotated_type,
    STATE(13875), 1,
      sym__structural_type,
    STATE(13948), 1,
      sym__constructor_application,
    STATE(13994), 1,
      sym_template_body,
    STATE(17453), 1,
      sym_stable_identifier,
    STATE(4452), 2,
      sym_comment,
      sym_block_comment,
    STATE(14051), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7924), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12322), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [232800] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6338), 1,
      anon_sym_COLON,
    ACTIONS(6340), 1,
      anon_sym_LBRACE,
    ACTIONS(8018), 1,
      sym__alpha_identifier,
    ACTIONS(8020), 1,
      anon_sym__,
    ACTIONS(8024), 1,
      anon_sym_LPAREN,
    ACTIONS(8026), 1,
      sym__backquoted_id,
    ACTIONS(8028), 1,
      sym_operator_identifier,
    STATE(4835), 1,
      sym__simple_type,
    STATE(4965), 1,
      sym__annotated_type,
    STATE(7036), 1,
      sym__constructor_application,
    STATE(7330), 1,
      sym__soft_identifier,
    STATE(7418), 1,
      sym_identifier,
    STATE(8293), 1,
      sym_annotated_type,
    STATE(8359), 1,
      sym_compound_type,
    STATE(8981), 1,
      sym_template_body,
    STATE(9151), 1,
      sym__structural_type,
    STATE(17155), 1,
      sym_stable_identifier,
    STATE(4453), 2,
      sym_comment,
      sym_block_comment,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6915), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [232883] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6506), 1,
      anon_sym_COLON,
    ACTIONS(6508), 1,
      anon_sym_LBRACE,
    ACTIONS(8030), 1,
      sym__alpha_identifier,
    ACTIONS(8032), 1,
      anon_sym__,
    ACTIONS(8036), 1,
      anon_sym_LPAREN,
    ACTIONS(8038), 1,
      sym__backquoted_id,
    ACTIONS(8040), 1,
      sym_operator_identifier,
    STATE(5520), 1,
      sym__simple_type,
    STATE(5662), 1,
      sym__annotated_type,
    STATE(8285), 1,
      sym_identifier,
    STATE(8625), 1,
      sym__soft_identifier,
    STATE(8765), 1,
      sym__constructor_application,
    STATE(9613), 1,
      sym_annotated_type,
    STATE(9730), 1,
      sym_compound_type,
    STATE(10085), 1,
      sym__structural_type,
    STATE(10189), 1,
      sym_template_body,
    STATE(17197), 1,
      sym_stable_identifier,
    STATE(4454), 2,
      sym_comment,
      sym_block_comment,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8034), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8375), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [232966] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6362), 1,
      anon_sym_COLON,
    ACTIONS(6364), 1,
      anon_sym_LBRACE,
    ACTIONS(8042), 1,
      sym__alpha_identifier,
    ACTIONS(8044), 1,
      anon_sym__,
    ACTIONS(8048), 1,
      anon_sym_LPAREN,
    ACTIONS(8050), 1,
      sym__backquoted_id,
    ACTIONS(8052), 1,
      sym_operator_identifier,
    STATE(5390), 1,
      sym__simple_type,
    STATE(5495), 1,
      sym__annotated_type,
    STATE(7515), 1,
      sym__constructor_application,
    STATE(7769), 1,
      sym__soft_identifier,
    STATE(8225), 1,
      sym_identifier,
    STATE(9170), 1,
      sym_annotated_type,
    STATE(9354), 1,
      sym_compound_type,
    STATE(9652), 1,
      sym_template_body,
    STATE(9787), 1,
      sym__structural_type,
    STATE(17702), 1,
      sym_stable_identifier,
    STATE(4455), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8046), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7951), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [233049] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7916), 1,
      sym__alpha_identifier,
    ACTIONS(7918), 1,
      anon_sym_COLON,
    ACTIONS(7920), 1,
      anon_sym_LBRACE,
    ACTIONS(7922), 1,
      anon_sym__,
    ACTIONS(7926), 1,
      anon_sym_LPAREN,
    ACTIONS(7928), 1,
      sym__backquoted_id,
    ACTIONS(7930), 1,
      sym_operator_identifier,
    STATE(11178), 1,
      sym__simple_type,
    STATE(11188), 1,
      sym__annotated_type,
    STATE(11727), 1,
      sym__soft_identifier,
    STATE(11847), 1,
      sym_identifier,
    STATE(13086), 1,
      sym_compound_type,
    STATE(13435), 1,
      sym__structural_type,
    STATE(13575), 1,
      sym_template_body,
    STATE(13592), 1,
      sym_annotated_type,
    STATE(13959), 1,
      sym__constructor_application,
    STATE(17453), 1,
      sym_stable_identifier,
    STATE(4456), 2,
      sym_comment,
      sym_block_comment,
    STATE(13431), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7924), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12322), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [233132] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8056), 1,
      anon_sym__,
    ACTIONS(8060), 1,
      anon_sym_LPAREN,
    ACTIONS(8062), 1,
      sym__backquoted_id,
    ACTIONS(8064), 1,
      sym_operator_identifier,
    STATE(6516), 1,
      sym__annotated_type,
    STATE(6738), 1,
      sym__simple_type,
    STATE(8964), 1,
      sym__constructor_application,
    STATE(8995), 1,
      sym_identifier,
    STATE(9087), 1,
      sym_compound_type,
    STATE(9392), 1,
      sym__soft_identifier,
    STATE(9951), 1,
      sym__structural_type,
    STATE(10042), 1,
      sym_annotated_type,
    STATE(10650), 1,
      sym_template_body,
    STATE(17942), 1,
      sym_stable_identifier,
    STATE(4457), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8058), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9053), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [233215] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7626), 1,
      anon_sym_LBRACE,
    ACTIONS(7628), 1,
      sym__indent,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10166), 1,
      aux_sym_extension_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15918), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4458), 2,
      sym_comment,
      sym_block_comment,
    STATE(14939), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [233300] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233347] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8066), 1,
      sym__interpolated_multiline_string_start,
    STATE(6183), 1,
      sym_interpolated_string,
    STATE(16163), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233404] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8068), 1,
      anon_sym_COLON,
    ACTIONS(8070), 1,
      anon_sym_LBRACE,
    ACTIONS(8072), 1,
      anon_sym_with,
    STATE(4475), 1,
      aux_sym_compound_type_repeat1,
    STATE(7982), 1,
      sym_template_body,
    STATE(7990), 1,
      sym__refinement,
    STATE(4461), 2,
      sym_comment,
      sym_block_comment,
    STATE(7771), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233465] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8074), 1,
      anon_sym_COLON,
    ACTIONS(8076), 1,
      anon_sym_LBRACE,
    ACTIONS(8078), 1,
      anon_sym_with,
    STATE(5458), 1,
      aux_sym_compound_type_repeat1,
    STATE(8065), 1,
      sym__refinement,
    STATE(8077), 1,
      sym_template_body,
    STATE(4462), 2,
      sym_comment,
      sym_block_comment,
    STATE(7835), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233526] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7956), 1,
      sym__alpha_identifier,
    ACTIONS(7958), 1,
      anon_sym_COLON,
    ACTIONS(7960), 1,
      anon_sym_LBRACE,
    ACTIONS(7962), 1,
      anon_sym__,
    ACTIONS(7966), 1,
      anon_sym_LPAREN,
    ACTIONS(7968), 1,
      sym__backquoted_id,
    ACTIONS(7970), 1,
      sym_operator_identifier,
    STATE(12149), 1,
      sym__simple_type,
    STATE(12949), 1,
      sym__annotated_type,
    STATE(13475), 1,
      sym_identifier,
    STATE(13521), 1,
      sym__soft_identifier,
    STATE(14308), 1,
      sym_compound_type,
    STATE(14451), 1,
      sym_annotated_type,
    STATE(14550), 1,
      sym_template_body,
    STATE(14575), 1,
      sym__structural_type,
    STATE(14660), 1,
      sym__constructor_application,
    STATE(17306), 1,
      sym_stable_identifier,
    STATE(4463), 2,
      sym_comment,
      sym_block_comment,
    STATE(14568), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7964), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13929), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [233609] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7978), 1,
      anon_sym_with,
    STATE(5486), 1,
      aux_sym_compound_type_repeat1,
    STATE(6502), 1,
      sym_template_body,
    STATE(6625), 1,
      sym__refinement,
    STATE(4464), 2,
      sym_comment,
      sym_block_comment,
    STATE(6651), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233666] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7956), 1,
      sym__alpha_identifier,
    ACTIONS(7962), 1,
      anon_sym__,
    ACTIONS(7966), 1,
      anon_sym_LPAREN,
    ACTIONS(7968), 1,
      sym__backquoted_id,
    ACTIONS(7970), 1,
      sym_operator_identifier,
    ACTIONS(8080), 1,
      anon_sym_COLON,
    ACTIONS(8082), 1,
      anon_sym_LBRACE,
    STATE(12425), 1,
      sym__simple_type,
    STATE(12873), 1,
      sym__annotated_type,
    STATE(13475), 1,
      sym_identifier,
    STATE(13521), 1,
      sym__soft_identifier,
    STATE(14451), 1,
      sym_annotated_type,
    STATE(14540), 1,
      sym_compound_type,
    STATE(14714), 1,
      sym__structural_type,
    STATE(14741), 1,
      sym__constructor_application,
    STATE(14783), 1,
      sym_template_body,
    STATE(17306), 1,
      sym_stable_identifier,
    STATE(4465), 2,
      sym_comment,
      sym_block_comment,
    STATE(14824), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7964), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13929), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [233749] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4942), 1,
      anon_sym_COLON,
    ACTIONS(4944), 1,
      anon_sym_LBRACE,
    ACTIONS(8084), 1,
      sym__alpha_identifier,
    ACTIONS(8086), 1,
      anon_sym__,
    ACTIONS(8090), 1,
      anon_sym_LPAREN,
    ACTIONS(8092), 1,
      sym__backquoted_id,
    ACTIONS(8094), 1,
      sym_operator_identifier,
    STATE(5104), 1,
      sym__simple_type,
    STATE(5221), 1,
      sym__annotated_type,
    STATE(7587), 1,
      sym_identifier,
    STATE(7664), 1,
      sym__soft_identifier,
    STATE(7946), 1,
      sym__constructor_application,
    STATE(9173), 1,
      sym_compound_type,
    STATE(9482), 1,
      sym_annotated_type,
    STATE(9891), 1,
      sym__structural_type,
    STATE(9923), 1,
      sym_template_body,
    STATE(17607), 1,
      sym_stable_identifier,
    STATE(4466), 2,
      sym_comment,
      sym_block_comment,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8088), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [233832] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8096), 1,
      anon_sym_LBRACK,
    ACTIONS(8098), 1,
      anon_sym_LPAREN,
    ACTIONS(8100), 1,
      anon_sym_POUND,
    STATE(4666), 1,
      aux_sym_annotation_repeat1,
    STATE(4890), 1,
      sym_type_arguments,
    STATE(5330), 1,
      sym_arguments,
    STATE(4467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [233891] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8102), 1,
      anon_sym_LBRACK,
    ACTIONS(8104), 1,
      anon_sym_LPAREN,
    ACTIONS(8106), 1,
      anon_sym_POUND,
    STATE(4676), 1,
      aux_sym_annotation_repeat1,
    STATE(4875), 1,
      sym_type_arguments,
    STATE(5352), 1,
      sym_arguments,
    STATE(4468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [233950] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8068), 1,
      anon_sym_COLON,
    ACTIONS(8070), 1,
      anon_sym_LBRACE,
    ACTIONS(8072), 1,
      anon_sym_with,
    STATE(4475), 1,
      aux_sym_compound_type_repeat1,
    STATE(7982), 1,
      sym_template_body,
    STATE(7990), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4469), 2,
      sym_comment,
      sym_block_comment,
    STATE(7771), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 7,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [234017] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7934), 1,
      anon_sym_LBRACK,
    ACTIONS(7938), 1,
      anon_sym_POUND,
    ACTIONS(8108), 1,
      anon_sym_AT,
    STATE(4722), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4751), 1,
      sym_type_arguments,
    STATE(5194), 1,
      sym_annotation,
    STATE(4470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234076] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8110), 1,
      anon_sym_with,
    STATE(4630), 1,
      aux_sym_compound_type_repeat1,
    STATE(7026), 1,
      sym_arguments,
    STATE(7167), 1,
      sym__refinement,
    STATE(7169), 1,
      sym_template_body,
    STATE(4471), 2,
      sym_comment,
      sym_block_comment,
    STATE(6847), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234135] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8116), 1,
      anon_sym_LPAREN,
    STATE(4693), 1,
      sym_arguments,
    STATE(4472), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234186] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8119), 1,
      anon_sym_with,
    STATE(4551), 1,
      aux_sym_compound_type_repeat1,
    STATE(7000), 1,
      sym_template_body,
    STATE(7001), 1,
      sym__refinement,
    STATE(7338), 1,
      sym_arguments,
    STATE(4473), 2,
      sym_comment,
      sym_block_comment,
    STATE(7070), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234245] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7682), 1,
      anon_sym_LPAREN,
    STATE(4472), 1,
      aux_sym_annotation_repeat1,
    STATE(4693), 1,
      sym_arguments,
    STATE(4474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234298] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8068), 1,
      anon_sym_COLON,
    ACTIONS(8070), 1,
      anon_sym_LBRACE,
    ACTIONS(8072), 1,
      anon_sym_with,
    STATE(5336), 1,
      aux_sym_compound_type_repeat1,
    STATE(7982), 1,
      sym_template_body,
    STATE(8015), 1,
      sym__refinement,
    STATE(4475), 2,
      sym_comment,
      sym_block_comment,
    STATE(7771), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234359] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(7600), 1,
      sym_operator_identifier,
    STATE(4565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12406), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15040), 1,
      sym_identifier,
    STATE(16625), 1,
      sym_class_parameter,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(7582), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4476), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [234442] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8125), 1,
      sym__alpha_identifier,
    ACTIONS(8127), 1,
      anon_sym_COLON,
    ACTIONS(8129), 1,
      anon_sym_LBRACE,
    ACTIONS(8131), 1,
      anon_sym__,
    ACTIONS(8135), 1,
      anon_sym_LPAREN,
    ACTIONS(8137), 1,
      sym__backquoted_id,
    ACTIONS(8139), 1,
      sym_operator_identifier,
    STATE(7979), 1,
      sym__annotated_type,
    STATE(7995), 1,
      sym__simple_type,
    STATE(10117), 1,
      sym__constructor_application,
    STATE(10205), 1,
      sym_identifier,
    STATE(10235), 1,
      sym__soft_identifier,
    STATE(10780), 1,
      sym_annotated_type,
    STATE(10865), 1,
      sym_compound_type,
    STATE(10936), 1,
      sym__structural_type,
    STATE(10973), 1,
      sym_template_body,
    STATE(17260), 1,
      sym_stable_identifier,
    STATE(4477), 2,
      sym_comment,
      sym_block_comment,
    STATE(11096), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8133), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10246), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [234525] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234574] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8141), 1,
      sym__interpolated_multiline_string_start,
    STATE(6455), 1,
      sym_interpolated_string,
    STATE(15246), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234631] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8143), 1,
      sym__alpha_identifier,
    ACTIONS(8145), 1,
      anon_sym_COLON,
    ACTIONS(8147), 1,
      anon_sym_LBRACE,
    ACTIONS(8149), 1,
      anon_sym__,
    ACTIONS(8153), 1,
      anon_sym_LPAREN,
    ACTIONS(8155), 1,
      sym__backquoted_id,
    ACTIONS(8157), 1,
      sym_operator_identifier,
    STATE(4340), 1,
      sym__simple_type,
    STATE(4348), 1,
      sym__annotated_type,
    STATE(4706), 1,
      sym_identifier,
    STATE(4734), 1,
      sym__soft_identifier,
    STATE(4798), 1,
      sym__constructor_application,
    STATE(5139), 1,
      sym_annotated_type,
    STATE(5228), 1,
      sym_compound_type,
    STATE(5664), 1,
      sym_template_body,
    STATE(5861), 1,
      sym__structural_type,
    STATE(17281), 1,
      sym_stable_identifier,
    STATE(4480), 2,
      sym_comment,
      sym_block_comment,
    STATE(5828), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8151), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4688), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [234714] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6920), 1,
      anon_sym_COLON,
    ACTIONS(6922), 1,
      anon_sym_LBRACE,
    ACTIONS(8159), 1,
      sym__alpha_identifier,
    ACTIONS(8161), 1,
      anon_sym__,
    ACTIONS(8165), 1,
      anon_sym_LPAREN,
    ACTIONS(8167), 1,
      sym__backquoted_id,
    ACTIONS(8169), 1,
      sym_operator_identifier,
    STATE(5109), 1,
      sym__annotated_type,
    STATE(5178), 1,
      sym__simple_type,
    STATE(7625), 1,
      sym_identifier,
    STATE(7755), 1,
      sym__constructor_application,
    STATE(8275), 1,
      sym__soft_identifier,
    STATE(9175), 1,
      sym_annotated_type,
    STATE(9486), 1,
      sym_compound_type,
    STATE(9664), 1,
      sym__structural_type,
    STATE(9889), 1,
      sym_template_body,
    STATE(17481), 1,
      sym_stable_identifier,
    STATE(4481), 2,
      sym_comment,
      sym_block_comment,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8163), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7680), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [234797] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(908), 1,
      anon_sym_LBRACE,
    ACTIONS(7700), 1,
      anon_sym_LPAREN,
    ACTIONS(8175), 1,
      anon_sym_DOT,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4482), 2,
      sym_comment,
      sym_block_comment,
    STATE(5647), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [234858] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7602), 1,
      anon_sym_LBRACE,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym__indent,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10166), 1,
      aux_sym_extension_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15997), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4483), 2,
      sym_comment,
      sym_block_comment,
    STATE(14732), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [234943] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6270), 1,
      anon_sym_COLON,
    ACTIONS(6272), 1,
      anon_sym_LBRACE,
    ACTIONS(8179), 1,
      sym__alpha_identifier,
    ACTIONS(8181), 1,
      anon_sym__,
    ACTIONS(8185), 1,
      anon_sym_LPAREN,
    ACTIONS(8187), 1,
      sym__backquoted_id,
    ACTIONS(8189), 1,
      sym_operator_identifier,
    STATE(4664), 1,
      sym__simple_type,
    STATE(4759), 1,
      sym__annotated_type,
    STATE(6155), 1,
      sym_identifier,
    STATE(6370), 1,
      sym__constructor_application,
    STATE(6730), 1,
      sym__soft_identifier,
    STATE(7525), 1,
      sym_annotated_type,
    STATE(8136), 1,
      sym_compound_type,
    STATE(8581), 1,
      sym__structural_type,
    STATE(8821), 1,
      sym_template_body,
    STATE(17113), 1,
      sym_stable_identifier,
    STATE(4484), 2,
      sym_comment,
      sym_block_comment,
    STATE(8352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8183), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6531), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235026] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(908), 1,
      anon_sym_LBRACE,
    ACTIONS(7700), 1,
      anon_sym_LPAREN,
    ACTIONS(8175), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4485), 2,
      sym_comment,
      sym_block_comment,
    STATE(5647), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [235085] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7940), 1,
      sym__alpha_identifier,
    ACTIONS(7942), 1,
      anon_sym_COLON,
    ACTIONS(7944), 1,
      anon_sym_LBRACE,
    ACTIONS(7946), 1,
      anon_sym__,
    ACTIONS(7950), 1,
      anon_sym_LPAREN,
    ACTIONS(7952), 1,
      sym__backquoted_id,
    ACTIONS(7954), 1,
      sym_operator_identifier,
    STATE(10697), 1,
      sym__simple_type,
    STATE(11038), 1,
      sym__annotated_type,
    STATE(11430), 1,
      sym_identifier,
    STATE(11669), 1,
      sym__soft_identifier,
    STATE(12483), 1,
      sym_compound_type,
    STATE(12973), 1,
      sym_template_body,
    STATE(13035), 1,
      sym_annotated_type,
    STATE(13363), 1,
      sym__structural_type,
    STATE(13558), 1,
      sym__constructor_application,
    STATE(17077), 1,
      sym_stable_identifier,
    STATE(4486), 2,
      sym_comment,
      sym_block_comment,
    STATE(13322), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7948), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11959), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235168] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7940), 1,
      sym__alpha_identifier,
    ACTIONS(7946), 1,
      anon_sym__,
    ACTIONS(7950), 1,
      anon_sym_LPAREN,
    ACTIONS(7952), 1,
      sym__backquoted_id,
    ACTIONS(7954), 1,
      sym_operator_identifier,
    ACTIONS(8195), 1,
      anon_sym_COLON,
    ACTIONS(8197), 1,
      anon_sym_LBRACE,
    STATE(10809), 1,
      sym__simple_type,
    STATE(11099), 1,
      sym__annotated_type,
    STATE(11430), 1,
      sym_identifier,
    STATE(11669), 1,
      sym__soft_identifier,
    STATE(13035), 1,
      sym_annotated_type,
    STATE(13323), 1,
      sym_compound_type,
    STATE(13544), 1,
      sym_template_body,
    STATE(13560), 1,
      sym__constructor_application,
    STATE(13690), 1,
      sym__structural_type,
    STATE(17077), 1,
      sym_stable_identifier,
    STATE(4487), 2,
      sym_comment,
      sym_block_comment,
    STATE(13616), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7948), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11959), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235251] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7602), 1,
      anon_sym_LBRACE,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym__indent,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10166), 1,
      aux_sym_extension_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15997), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4488), 2,
      sym_comment,
      sym_block_comment,
    STATE(14815), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [235336] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6774), 1,
      anon_sym_COLON,
    ACTIONS(6776), 1,
      anon_sym_LBRACE,
    ACTIONS(8199), 1,
      sym__alpha_identifier,
    ACTIONS(8201), 1,
      anon_sym__,
    ACTIONS(8205), 1,
      anon_sym_LPAREN,
    ACTIONS(8207), 1,
      sym__backquoted_id,
    ACTIONS(8209), 1,
      sym_operator_identifier,
    STATE(4940), 1,
      sym__annotated_type,
    STATE(5005), 1,
      sym__simple_type,
    STATE(6795), 1,
      sym_identifier,
    STATE(7174), 1,
      sym__soft_identifier,
    STATE(7388), 1,
      sym__constructor_application,
    STATE(8292), 1,
      sym_annotated_type,
    STATE(8537), 1,
      sym_compound_type,
    STATE(9176), 1,
      sym_template_body,
    STATE(9514), 1,
      sym__structural_type,
    STATE(17684), 1,
      sym_stable_identifier,
    STATE(4489), 2,
      sym_comment,
      sym_block_comment,
    STATE(8992), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8203), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6972), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235419] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8211), 1,
      sym__alpha_identifier,
    ACTIONS(8213), 1,
      anon_sym_COLON,
    ACTIONS(8215), 1,
      anon_sym_LBRACE,
    ACTIONS(8217), 1,
      anon_sym__,
    ACTIONS(8221), 1,
      anon_sym_LPAREN,
    ACTIONS(8223), 1,
      sym__backquoted_id,
    ACTIONS(8225), 1,
      sym_operator_identifier,
    STATE(4473), 1,
      sym__annotated_type,
    STATE(4492), 1,
      sym__simple_type,
    STATE(5101), 1,
      sym__constructor_application,
    STATE(5102), 1,
      sym_identifier,
    STATE(5375), 1,
      sym__soft_identifier,
    STATE(6151), 1,
      sym_compound_type,
    STATE(6740), 1,
      sym_annotated_type,
    STATE(6855), 1,
      sym_template_body,
    STATE(7290), 1,
      sym__structural_type,
    STATE(17321), 1,
      sym_stable_identifier,
    STATE(4490), 2,
      sym_comment,
      sym_block_comment,
    STATE(7070), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8219), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5227), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235502] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7602), 1,
      anon_sym_LBRACE,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym__indent,
    STATE(4510), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15803), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4491), 2,
      sym_comment,
      sym_block_comment,
    STATE(14734), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [235587] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8227), 1,
      anon_sym_LBRACK,
    ACTIONS(8229), 1,
      anon_sym_AT,
    ACTIONS(8231), 1,
      anon_sym_LPAREN,
    ACTIONS(8233), 1,
      anon_sym_POUND,
    STATE(4973), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5230), 1,
      sym_type_arguments,
    STATE(5675), 1,
      sym_annotation,
    STATE(7338), 1,
      sym_arguments,
    STATE(4492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [235650] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6230), 1,
      anon_sym_COLON,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7810), 1,
      anon_sym__,
    ACTIONS(7812), 1,
      anon_sym_LPAREN,
    ACTIONS(7814), 1,
      sym_operator_identifier,
    STATE(9087), 1,
      sym_compound_type,
    STATE(9951), 1,
      sym__structural_type,
    STATE(11019), 1,
      sym_template_body,
    STATE(11543), 1,
      sym__simple_type,
    STATE(11961), 1,
      sym__annotated_type,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12944), 1,
      sym_identifier,
    STATE(14103), 1,
      sym_annotated_type,
    STATE(14782), 1,
      sym__constructor_application,
    STATE(17617), 1,
      sym_stable_identifier,
    STATE(4493), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13249), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235733] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8243), 1,
      anon_sym_inline,
    ACTIONS(8246), 1,
      anon_sym_infix,
    ACTIONS(8249), 1,
      anon_sym_open,
    ACTIONS(8252), 1,
      anon_sym_transparent,
    ACTIONS(8255), 1,
      sym__backquoted_id,
    ACTIONS(8240), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4494), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_modifiers_repeat1,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(8237), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
    ACTIONS(8235), 13,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      sym__alpha_identifier,
      sym_operator_identifier,
  [235794] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7806), 1,
      anon_sym_COLON,
    ACTIONS(7808), 1,
      anon_sym_LBRACE,
    ACTIONS(7810), 1,
      anon_sym__,
    ACTIONS(7812), 1,
      anon_sym_LPAREN,
    ACTIONS(7814), 1,
      sym_operator_identifier,
    STATE(11622), 1,
      sym__simple_type,
    STATE(11910), 1,
      sym__annotated_type,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12944), 1,
      sym_identifier,
    STATE(14103), 1,
      sym_annotated_type,
    STATE(14353), 1,
      sym_compound_type,
    STATE(14478), 1,
      sym__structural_type,
    STATE(14496), 1,
      sym__constructor_application,
    STATE(14551), 1,
      sym_template_body,
    STATE(17617), 1,
      sym_stable_identifier,
    STATE(4495), 2,
      sym_comment,
      sym_block_comment,
    STATE(14520), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13249), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [235877] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7902), 1,
      anon_sym_LBRACK,
    ACTIONS(7906), 1,
      anon_sym_POUND,
    ACTIONS(8257), 1,
      anon_sym_AT,
    STATE(4705), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4814), 1,
      sym_type_arguments,
    STATE(5391), 1,
      sym_annotation,
    STATE(4496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [235936] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8259), 1,
      sym__alpha_identifier,
    ACTIONS(8261), 1,
      anon_sym_COLON,
    ACTIONS(8263), 1,
      anon_sym_LBRACE,
    ACTIONS(8265), 1,
      anon_sym__,
    ACTIONS(8269), 1,
      anon_sym_LPAREN,
    ACTIONS(8271), 1,
      sym__backquoted_id,
    ACTIONS(8273), 1,
      sym_operator_identifier,
    STATE(4396), 1,
      sym__simple_type,
    STATE(4410), 1,
      sym__annotated_type,
    STATE(4853), 1,
      sym__constructor_application,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(5062), 1,
      sym_identifier,
    STATE(5952), 1,
      sym_annotated_type,
    STATE(6025), 1,
      sym_compound_type,
    STATE(6198), 1,
      sym__structural_type,
    STATE(6557), 1,
      sym_template_body,
    STATE(17195), 1,
      sym_stable_identifier,
    STATE(4497), 2,
      sym_comment,
      sym_block_comment,
    STATE(6152), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8267), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4969), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236019] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7626), 1,
      anon_sym_LBRACE,
    ACTIONS(7628), 1,
      sym__indent,
    STATE(4503), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(16048), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4498), 2,
      sym_comment,
      sym_block_comment,
    STATE(14938), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [236104] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8074), 1,
      anon_sym_COLON,
    ACTIONS(8076), 1,
      anon_sym_LBRACE,
    ACTIONS(8078), 1,
      anon_sym_with,
    STATE(4462), 1,
      aux_sym_compound_type_repeat1,
    STATE(8076), 1,
      sym__refinement,
    STATE(8077), 1,
      sym_template_body,
    STATE(4499), 2,
      sym_comment,
      sym_block_comment,
    STATE(7835), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [236165] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6404), 1,
      anon_sym_COLON,
    ACTIONS(6406), 1,
      anon_sym_LBRACE,
    ACTIONS(8275), 1,
      sym__alpha_identifier,
    ACTIONS(8277), 1,
      anon_sym__,
    ACTIONS(8281), 1,
      anon_sym_LPAREN,
    ACTIONS(8283), 1,
      sym__backquoted_id,
    ACTIONS(8285), 1,
      sym_operator_identifier,
    STATE(4701), 1,
      sym__annotated_type,
    STATE(4772), 1,
      sym__simple_type,
    STATE(6136), 1,
      sym_identifier,
    STATE(6327), 1,
      sym__soft_identifier,
    STATE(6525), 1,
      sym__constructor_application,
    STATE(7770), 1,
      sym_annotated_type,
    STATE(8039), 1,
      sym_compound_type,
    STATE(8694), 1,
      sym_template_body,
    STATE(8769), 1,
      sym__structural_type,
    STATE(17071), 1,
      sym_stable_identifier,
    STATE(4500), 2,
      sym_comment,
      sym_block_comment,
    STATE(8569), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8279), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6379), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236248] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7626), 1,
      anon_sym_LBRACE,
    ACTIONS(7628), 1,
      sym__indent,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10166), 1,
      aux_sym_extension_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(16048), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4501), 2,
      sym_comment,
      sym_block_comment,
    STATE(14939), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [236333] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8287), 1,
      sym__alpha_identifier,
    ACTIONS(8289), 1,
      anon_sym_COLON,
    ACTIONS(8291), 1,
      anon_sym_LBRACE,
    ACTIONS(8293), 1,
      anon_sym__,
    ACTIONS(8297), 1,
      anon_sym_LPAREN,
    ACTIONS(8299), 1,
      sym__backquoted_id,
    ACTIONS(8301), 1,
      sym_operator_identifier,
    STATE(4385), 1,
      sym__simple_type,
    STATE(4436), 1,
      sym__annotated_type,
    STATE(4923), 1,
      sym__constructor_application,
    STATE(4930), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(5501), 1,
      sym_annotated_type,
    STATE(5749), 1,
      sym_compound_type,
    STATE(6463), 1,
      sym__structural_type,
    STATE(6670), 1,
      sym_template_body,
    STATE(17738), 1,
      sym_stable_identifier,
    STATE(4502), 2,
      sym_comment,
      sym_block_comment,
    STATE(6651), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8295), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5066), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236416] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7626), 1,
      anon_sym_LBRACE,
    ACTIONS(7628), 1,
      sym__indent,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10166), 1,
      aux_sym_extension_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(16048), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4503), 2,
      sym_comment,
      sym_block_comment,
    STATE(15057), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [236501] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(908), 1,
      anon_sym_LBRACE,
    ACTIONS(7700), 1,
      anon_sym_LPAREN,
    ACTIONS(8175), 1,
      anon_sym_DOT,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8315), 1,
      sym_operator_identifier,
    STATE(1782), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4504), 2,
      sym_comment,
      sym_block_comment,
    STATE(5647), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8309), 8,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [236572] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7602), 1,
      anon_sym_LBRACE,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym__indent,
    STATE(4536), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15218), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4505), 2,
      sym_comment,
      sym_block_comment,
    STATE(14734), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [236657] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7872), 1,
      anon_sym_LBRACK,
    ACTIONS(7878), 1,
      anon_sym_POUND,
    ACTIONS(8317), 1,
      anon_sym_LPAREN,
    STATE(4715), 1,
      aux_sym_annotation_repeat1,
    STATE(4932), 1,
      sym_type_arguments,
    STATE(5202), 1,
      sym_arguments,
    STATE(4506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [236716] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8319), 1,
      anon_sym_with,
    STATE(4583), 1,
      aux_sym_compound_type_repeat1,
    STATE(7222), 1,
      sym_template_body,
    STATE(7223), 1,
      sym__refinement,
    STATE(7473), 1,
      sym_arguments,
    STATE(4507), 2,
      sym_comment,
      sym_block_comment,
    STATE(7186), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [236775] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6700), 1,
      anon_sym_COLON,
    ACTIONS(6702), 1,
      anon_sym_LBRACE,
    ACTIONS(8321), 1,
      sym__alpha_identifier,
    ACTIONS(8323), 1,
      anon_sym__,
    ACTIONS(8327), 1,
      anon_sym_LPAREN,
    ACTIONS(8329), 1,
      sym__backquoted_id,
    ACTIONS(8331), 1,
      sym_operator_identifier,
    STATE(4558), 1,
      sym__simple_type,
    STATE(4623), 1,
      sym__annotated_type,
    STATE(5767), 1,
      sym_identifier,
    STATE(5875), 1,
      sym__soft_identifier,
    STATE(6074), 1,
      sym__constructor_application,
    STATE(6832), 1,
      sym_annotated_type,
    STATE(6929), 1,
      sym_compound_type,
    STATE(7682), 1,
      sym_template_body,
    STATE(8086), 1,
      sym__structural_type,
    STATE(17672), 1,
      sym_stable_identifier,
    STATE(4508), 2,
      sym_comment,
      sym_block_comment,
    STATE(7810), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8325), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5678), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [236858] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8006), 1,
      anon_sym_COLON,
    ACTIONS(8008), 1,
      anon_sym_LBRACE,
    ACTIONS(8010), 1,
      anon_sym_with,
    STATE(4450), 1,
      aux_sym_compound_type_repeat1,
    STATE(7800), 1,
      sym__refinement,
    STATE(7802), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4509), 2,
      sym_comment,
      sym_block_comment,
    STATE(7614), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 7,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [236925] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7602), 1,
      anon_sym_LBRACE,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym__indent,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10166), 1,
      aux_sym_extension_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15803), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4510), 2,
      sym_comment,
      sym_block_comment,
    STATE(14815), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [237010] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6902), 1,
      anon_sym_COLON,
    ACTIONS(6904), 1,
      anon_sym_LBRACE,
    ACTIONS(8333), 1,
      sym__alpha_identifier,
    ACTIONS(8335), 1,
      anon_sym__,
    ACTIONS(8339), 1,
      anon_sym_LPAREN,
    ACTIONS(8341), 1,
      sym__backquoted_id,
    ACTIONS(8343), 1,
      sym_operator_identifier,
    STATE(4507), 1,
      sym__annotated_type,
    STATE(4532), 1,
      sym__simple_type,
    STATE(5158), 1,
      sym__constructor_application,
    STATE(5160), 1,
      sym_identifier,
    STATE(5309), 1,
      sym__soft_identifier,
    STATE(6521), 1,
      sym_compound_type,
    STATE(6631), 1,
      sym_annotated_type,
    STATE(7043), 1,
      sym_template_body,
    STATE(7498), 1,
      sym__structural_type,
    STATE(17360), 1,
      sym_stable_identifier,
    STATE(4511), 2,
      sym_comment,
      sym_block_comment,
    STATE(7186), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8337), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5259), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237093] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7872), 1,
      anon_sym_LBRACK,
    ACTIONS(7874), 1,
      anon_sym_AT,
    ACTIONS(7878), 1,
      anon_sym_POUND,
    STATE(4808), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4932), 1,
      sym_type_arguments,
    STATE(5173), 1,
      sym_annotation,
    STATE(4512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [237152] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8345), 1,
      anon_sym_LBRACK,
    ACTIONS(8347), 1,
      anon_sym_LPAREN,
    ACTIONS(8349), 1,
      anon_sym_POUND,
    STATE(4655), 1,
      aux_sym_annotation_repeat1,
    STATE(4944), 1,
      sym_type_arguments,
    STATE(5360), 1,
      sym_arguments,
    STATE(4513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [237211] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8006), 1,
      anon_sym_COLON,
    ACTIONS(8008), 1,
      anon_sym_LBRACE,
    ACTIONS(8010), 1,
      anon_sym_with,
    STATE(4450), 1,
      aux_sym_compound_type_repeat1,
    STATE(7800), 1,
      sym__refinement,
    STATE(7802), 1,
      sym_template_body,
    STATE(4514), 2,
      sym_comment,
      sym_block_comment,
    STATE(7614), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [237272] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(7850), 1,
      sym__alpha_identifier,
    ACTIONS(7856), 1,
      anon_sym__,
    ACTIONS(7860), 1,
      anon_sym_LPAREN,
    ACTIONS(7862), 1,
      sym__backquoted_id,
    ACTIONS(7864), 1,
      sym_operator_identifier,
    STATE(8691), 1,
      sym_compound_type,
    STATE(9330), 1,
      sym__structural_type,
    STATE(11538), 1,
      sym__simple_type,
    STATE(11718), 1,
      sym__annotated_type,
    STATE(12148), 1,
      sym_template_body,
    STATE(12550), 1,
      sym_identifier,
    STATE(12664), 1,
      sym__soft_identifier,
    STATE(14212), 1,
      sym_annotated_type,
    STATE(14833), 1,
      sym__constructor_application,
    STATE(17732), 1,
      sym_stable_identifier,
    STATE(4515), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13328), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237355] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7850), 1,
      sym__alpha_identifier,
    ACTIONS(7852), 1,
      anon_sym_COLON,
    ACTIONS(7854), 1,
      anon_sym_LBRACE,
    ACTIONS(7856), 1,
      anon_sym__,
    ACTIONS(7860), 1,
      anon_sym_LPAREN,
    ACTIONS(7862), 1,
      sym__backquoted_id,
    ACTIONS(7864), 1,
      sym_operator_identifier,
    STATE(11512), 1,
      sym__simple_type,
    STATE(11871), 1,
      sym__annotated_type,
    STATE(12550), 1,
      sym_identifier,
    STATE(12664), 1,
      sym__soft_identifier,
    STATE(14212), 1,
      sym_annotated_type,
    STATE(14365), 1,
      sym_compound_type,
    STATE(14442), 1,
      sym__structural_type,
    STATE(14459), 1,
      sym__constructor_application,
    STATE(14468), 1,
      sym_template_body,
    STATE(17732), 1,
      sym_stable_identifier,
    STATE(4516), 2,
      sym_comment,
      sym_block_comment,
    STATE(14489), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13328), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237438] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8351), 1,
      anon_sym_LBRACK,
    ACTIONS(8353), 1,
      anon_sym_AT,
    ACTIONS(8355), 1,
      anon_sym_LPAREN,
    ACTIONS(8357), 1,
      anon_sym_POUND,
    STATE(5054), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5421), 1,
      sym_type_arguments,
    STATE(5551), 1,
      sym_annotation,
    STATE(7026), 1,
      sym_arguments,
    STATE(4517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [237501] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6562), 1,
      anon_sym_COLON,
    ACTIONS(6564), 1,
      anon_sym_LBRACE,
    ACTIONS(8359), 1,
      sym__alpha_identifier,
    ACTIONS(8361), 1,
      anon_sym__,
    ACTIONS(8365), 1,
      anon_sym_LPAREN,
    ACTIONS(8367), 1,
      sym__backquoted_id,
    ACTIONS(8369), 1,
      sym_operator_identifier,
    STATE(4738), 1,
      sym__annotated_type,
    STATE(4741), 1,
      sym__simple_type,
    STATE(6325), 1,
      sym__constructor_application,
    STATE(6353), 1,
      sym__soft_identifier,
    STATE(6499), 1,
      sym_identifier,
    STATE(7788), 1,
      sym_compound_type,
    STATE(8180), 1,
      sym_annotated_type,
    STATE(8473), 1,
      sym_template_body,
    STATE(8493), 1,
      sym__structural_type,
    STATE(16832), 1,
      sym_stable_identifier,
    STATE(4518), 2,
      sym_comment,
      sym_block_comment,
    STATE(8689), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8363), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237584] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7602), 1,
      anon_sym_LBRACE,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym__indent,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10166), 1,
      aux_sym_extension_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15218), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4519), 2,
      sym_comment,
      sym_block_comment,
    STATE(14732), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [237669] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8371), 1,
      sym__alpha_identifier,
    ACTIONS(8373), 1,
      anon_sym_COLON,
    ACTIONS(8375), 1,
      anon_sym_LBRACE,
    ACTIONS(8377), 1,
      anon_sym__,
    ACTIONS(8381), 1,
      anon_sym_LPAREN,
    ACTIONS(8383), 1,
      sym__backquoted_id,
    ACTIONS(8385), 1,
      sym_operator_identifier,
    STATE(4471), 1,
      sym__annotated_type,
    STATE(4517), 1,
      sym__simple_type,
    STATE(5397), 1,
      sym_identifier,
    STATE(5408), 1,
      sym__constructor_application,
    STATE(5481), 1,
      sym__soft_identifier,
    STATE(6185), 1,
      sym_compound_type,
    STATE(6590), 1,
      sym_annotated_type,
    STATE(7042), 1,
      sym__structural_type,
    STATE(7206), 1,
      sym_template_body,
    STATE(16872), 1,
      sym_stable_identifier,
    STATE(4520), 2,
      sym_comment,
      sym_block_comment,
    STATE(6847), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8379), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5430), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237752] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8387), 1,
      anon_sym_LBRACK,
    ACTIONS(8389), 1,
      anon_sym_LPAREN,
    ACTIONS(8391), 1,
      anon_sym_POUND,
    STATE(4643), 1,
      aux_sym_annotation_repeat1,
    STATE(5028), 1,
      sym_type_arguments,
    STATE(5347), 1,
      sym_arguments,
    STATE(4521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [237811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [237858] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(8393), 1,
      sym__alpha_identifier,
    ACTIONS(8395), 1,
      anon_sym__,
    ACTIONS(8399), 1,
      anon_sym_LPAREN,
    ACTIONS(8401), 1,
      sym__backquoted_id,
    ACTIONS(8403), 1,
      sym_operator_identifier,
    STATE(5410), 1,
      sym__annotated_type,
    STATE(5443), 1,
      sym__simple_type,
    STATE(7599), 1,
      sym__soft_identifier,
    STATE(7627), 1,
      sym__constructor_application,
    STATE(7844), 1,
      sym_identifier,
    STATE(8691), 1,
      sym_compound_type,
    STATE(9034), 1,
      sym_annotated_type,
    STATE(9330), 1,
      sym__structural_type,
    STATE(9908), 1,
      sym_template_body,
    STATE(16788), 1,
      sym_stable_identifier,
    STATE(4523), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8397), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7617), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [237941] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8405), 1,
      anon_sym_LBRACK,
    ACTIONS(8407), 1,
      anon_sym_LPAREN,
    ACTIONS(8409), 1,
      anon_sym_POUND,
    STATE(4691), 1,
      aux_sym_annotation_repeat1,
    STATE(5084), 1,
      sym_type_arguments,
    STATE(5327), 1,
      sym_arguments,
    STATE(4524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [238000] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6422), 1,
      anon_sym_COLON,
    ACTIONS(6424), 1,
      anon_sym_LBRACE,
    ACTIONS(8411), 1,
      sym__alpha_identifier,
    ACTIONS(8413), 1,
      anon_sym__,
    ACTIONS(8417), 1,
      anon_sym_LPAREN,
    ACTIONS(8419), 1,
      sym__backquoted_id,
    ACTIONS(8421), 1,
      sym_operator_identifier,
    STATE(5766), 1,
      sym__annotated_type,
    STATE(6080), 1,
      sym__simple_type,
    STATE(8325), 1,
      sym_identifier,
    STATE(8328), 1,
      sym__constructor_application,
    STATE(8883), 1,
      sym__soft_identifier,
    STATE(9905), 1,
      sym_compound_type,
    STATE(9910), 1,
      sym_annotated_type,
    STATE(10061), 1,
      sym_template_body,
    STATE(10294), 1,
      sym__structural_type,
    STATE(16739), 1,
      sym_stable_identifier,
    STATE(4525), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8415), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8510), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [238083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [238130] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6942), 1,
      anon_sym_COLON,
    ACTIONS(6944), 1,
      anon_sym_LBRACE,
    ACTIONS(8423), 1,
      sym__alpha_identifier,
    ACTIONS(8425), 1,
      anon_sym__,
    ACTIONS(8429), 1,
      anon_sym_LPAREN,
    ACTIONS(8431), 1,
      sym__backquoted_id,
    ACTIONS(8433), 1,
      sym_operator_identifier,
    STATE(4818), 1,
      sym__annotated_type,
    STATE(4987), 1,
      sym__simple_type,
    STATE(7063), 1,
      sym_identifier,
    STATE(7094), 1,
      sym__constructor_application,
    STATE(7297), 1,
      sym__soft_identifier,
    STATE(8621), 1,
      sym_compound_type,
    STATE(8659), 1,
      sym_annotated_type,
    STATE(9138), 1,
      sym_template_body,
    STATE(9501), 1,
      sym__structural_type,
    STATE(17398), 1,
      sym_stable_identifier,
    STATE(4527), 2,
      sym_comment,
      sym_block_comment,
    STATE(9114), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8427), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [238213] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7602), 1,
      anon_sym_LBRACE,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym__indent,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10166), 1,
      aux_sym_extension_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15803), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4528), 2,
      sym_comment,
      sym_block_comment,
    STATE(14732), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [238298] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 32,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [238343] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6544), 1,
      anon_sym_COLON,
    ACTIONS(6546), 1,
      anon_sym_LBRACE,
    ACTIONS(8437), 1,
      sym__alpha_identifier,
    ACTIONS(8439), 1,
      anon_sym__,
    ACTIONS(8443), 1,
      anon_sym_LPAREN,
    ACTIONS(8445), 1,
      sym__backquoted_id,
    ACTIONS(8447), 1,
      sym_operator_identifier,
    STATE(4684), 1,
      sym__annotated_type,
    STATE(4760), 1,
      sym__simple_type,
    STATE(6388), 1,
      sym_identifier,
    STATE(6404), 1,
      sym__soft_identifier,
    STATE(6577), 1,
      sym__constructor_application,
    STATE(7730), 1,
      sym_compound_type,
    STATE(7834), 1,
      sym_annotated_type,
    STATE(8800), 1,
      sym__structural_type,
    STATE(8847), 1,
      sym_template_body,
    STATE(17834), 1,
      sym_stable_identifier,
    STATE(4530), 2,
      sym_comment,
      sym_block_comment,
    STATE(8733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8441), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6567), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [238426] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6380), 1,
      anon_sym_COLON,
    ACTIONS(6382), 1,
      anon_sym_LBRACE,
    ACTIONS(8449), 1,
      sym__alpha_identifier,
    ACTIONS(8451), 1,
      anon_sym__,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    ACTIONS(8457), 1,
      sym__backquoted_id,
    ACTIONS(8459), 1,
      sym_operator_identifier,
    STATE(4545), 1,
      sym__simple_type,
    STATE(4577), 1,
      sym__annotated_type,
    STATE(5817), 1,
      sym__constructor_application,
    STATE(5831), 1,
      sym__soft_identifier,
    STATE(6085), 1,
      sym_identifier,
    STATE(6909), 1,
      sym_annotated_type,
    STATE(6927), 1,
      sym_compound_type,
    STATE(7693), 1,
      sym_template_body,
    STATE(8084), 1,
      sym__structural_type,
    STATE(17756), 1,
      sym_stable_identifier,
    STATE(4531), 2,
      sym_comment,
      sym_block_comment,
    STATE(8149), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8453), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [238509] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8461), 1,
      anon_sym_LBRACK,
    ACTIONS(8463), 1,
      anon_sym_AT,
    ACTIONS(8465), 1,
      anon_sym_LPAREN,
    ACTIONS(8467), 1,
      anon_sym_POUND,
    STATE(4822), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5270), 1,
      sym_type_arguments,
    STATE(5788), 1,
      sym_annotation,
    STATE(7473), 1,
      sym_arguments,
    STATE(4532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [238572] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7900), 1,
      anon_sym_with,
    STATE(5256), 1,
      aux_sym_compound_type_repeat1,
    STATE(6108), 1,
      sym_template_body,
    STATE(6240), 1,
      sym__refinement,
    STATE(4533), 2,
      sym_comment,
      sym_block_comment,
    STATE(6152), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [238629] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8469), 1,
      sym__alpha_identifier,
    ACTIONS(8471), 1,
      anon_sym_COLON,
    ACTIONS(8473), 1,
      anon_sym_LBRACE,
    ACTIONS(8475), 1,
      anon_sym__,
    ACTIONS(8479), 1,
      anon_sym_LPAREN,
    ACTIONS(8481), 1,
      sym__backquoted_id,
    ACTIONS(8483), 1,
      sym_operator_identifier,
    STATE(4576), 1,
      sym__annotated_type,
    STATE(4626), 1,
      sym__simple_type,
    STATE(5527), 1,
      sym__soft_identifier,
    STATE(5936), 1,
      sym_identifier,
    STATE(5997), 1,
      sym__constructor_application,
    STATE(7058), 1,
      sym_annotated_type,
    STATE(7066), 1,
      sym_compound_type,
    STATE(7961), 1,
      sym__structural_type,
    STATE(8280), 1,
      sym_template_body,
    STATE(17734), 1,
      sym_stable_identifier,
    STATE(4534), 2,
      sym_comment,
      sym_block_comment,
    STATE(7974), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8477), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5525), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [238712] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7626), 1,
      anon_sym_LBRACE,
    ACTIONS(7628), 1,
      sym__indent,
    STATE(4448), 1,
      aux_sym_extension_definition_repeat1,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15918), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4535), 2,
      sym_comment,
      sym_block_comment,
    STATE(14938), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [238797] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7602), 1,
      anon_sym_LBRACE,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7608), 1,
      anon_sym_def,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(7622), 1,
      anon_sym_LPAREN,
    ACTIONS(7624), 1,
      sym__indent,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(8922), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10166), 1,
      aux_sym_extension_definition_repeat1,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(15218), 1,
      sym__function_declaration,
    STATE(18510), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(4536), 2,
      sym_comment,
      sym_block_comment,
    STATE(14815), 2,
      sym__extension_template_body,
      sym_function_definition,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [238882] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8074), 1,
      anon_sym_COLON,
    ACTIONS(8076), 1,
      anon_sym_LBRACE,
    ACTIONS(8078), 1,
      anon_sym_with,
    STATE(4462), 1,
      aux_sym_compound_type_repeat1,
    STATE(8076), 1,
      sym__refinement,
    STATE(8077), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4537), 2,
      sym_comment,
      sym_block_comment,
    STATE(7835), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [238949] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7698), 1,
      anon_sym_AT,
    STATE(4591), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4925), 1,
      sym_annotation,
    STATE(4538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239001] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8489), 1,
      anon_sym_COLON,
    ACTIONS(8491), 1,
      anon_sym_LBRACE,
    ACTIONS(8493), 1,
      anon_sym_with,
    STATE(4604), 1,
      aux_sym_compound_type_repeat1,
    STATE(8876), 1,
      sym__refinement,
    STATE(8879), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4539), 2,
      sym_comment,
      sym_block_comment,
    STATE(8567), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [239067] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8495), 1,
      anon_sym_LBRACK,
    ACTIONS(8497), 1,
      anon_sym_LPAREN,
    ACTIONS(8499), 1,
      anon_sym_POUND,
    STATE(5052), 1,
      aux_sym_annotation_repeat1,
    STATE(5163), 1,
      sym_type_arguments,
    STATE(5919), 1,
      sym_arguments,
    STATE(4540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239125] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239217] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8503), 1,
      anon_sym_COLON,
    ACTIONS(8505), 1,
      anon_sym_LBRACE,
    ACTIONS(8507), 1,
      anon_sym_with,
    STATE(5873), 1,
      aux_sym_compound_type_repeat1,
    STATE(8492), 1,
      sym__refinement,
    STATE(8533), 1,
      sym_template_body,
    STATE(4543), 2,
      sym_comment,
      sym_block_comment,
    STATE(8518), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [239323] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8509), 1,
      anon_sym_LBRACK,
    ACTIONS(8511), 1,
      anon_sym_AT,
    ACTIONS(8513), 1,
      anon_sym_LPAREN,
    ACTIONS(8515), 1,
      anon_sym_POUND,
    STATE(5413), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5505), 1,
      sym_type_arguments,
    STATE(6230), 1,
      sym_annotation,
    STATE(8064), 1,
      sym_arguments,
    STATE(4545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [239385] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239477] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239523] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8345), 1,
      anon_sym_LBRACK,
    ACTIONS(8349), 1,
      anon_sym_POUND,
    ACTIONS(8519), 1,
      anon_sym_AT,
    STATE(4944), 1,
      sym_type_arguments,
    STATE(5091), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5564), 1,
      sym_annotation,
    STATE(4549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239581] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(952), 1,
      anon_sym_LBRACE,
    ACTIONS(7842), 1,
      anon_sym_LPAREN,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8521), 1,
      anon_sym_DOT,
    ACTIONS(8523), 1,
      sym_operator_identifier,
    STATE(1707), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4550), 2,
      sym_comment,
      sym_block_comment,
    STATE(6473), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8309), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [239651] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8119), 1,
      anon_sym_with,
    STATE(5549), 1,
      aux_sym_compound_type_repeat1,
    STATE(7000), 1,
      sym_template_body,
    STATE(7020), 1,
      sym__refinement,
    STATE(4551), 2,
      sym_comment,
      sym_block_comment,
    STATE(7070), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239707] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8351), 1,
      anon_sym_LBRACK,
    ACTIONS(8353), 1,
      anon_sym_AT,
    ACTIONS(8357), 1,
      anon_sym_POUND,
    STATE(5054), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5421), 1,
      sym_type_arguments,
    STATE(5551), 1,
      sym_annotation,
    STATE(4552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239765] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [239811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239857] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239949] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [239995] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8533), 1,
      anon_sym_LBRACK,
    ACTIONS(8535), 1,
      anon_sym_AT,
    ACTIONS(8537), 1,
      anon_sym_LPAREN,
    ACTIONS(8539), 1,
      anon_sym_POUND,
    STATE(5406), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5731), 1,
      sym_type_arguments,
    STATE(6604), 1,
      sym_annotation,
    STATE(8105), 1,
      sym_arguments,
    STATE(4558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [240057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240103] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8096), 1,
      anon_sym_LBRACK,
    ACTIONS(8100), 1,
      anon_sym_POUND,
    ACTIONS(8543), 1,
      anon_sym_AT,
    STATE(4890), 1,
      sym_type_arguments,
    STATE(4934), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5772), 1,
      sym_annotation,
    STATE(4560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [240161] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8461), 1,
      anon_sym_LBRACK,
    ACTIONS(8463), 1,
      anon_sym_AT,
    ACTIONS(8467), 1,
      anon_sym_POUND,
    STATE(4822), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5270), 1,
      sym_type_arguments,
    STATE(5788), 1,
      sym_annotation,
    STATE(4561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [240219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240267] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8545), 1,
      anon_sym_COLON,
    ACTIONS(8547), 1,
      anon_sym_LBRACE,
    ACTIONS(8549), 1,
      anon_sym_with,
    STATE(4622), 1,
      aux_sym_compound_type_repeat1,
    STATE(8647), 1,
      sym_template_body,
    STATE(8653), 1,
      sym__refinement,
    STATE(4563), 2,
      sym_comment,
      sym_block_comment,
    STATE(8463), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240327] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8551), 1,
      anon_sym_COLON,
    ACTIONS(8553), 1,
      anon_sym_LBRACE,
    ACTIONS(8555), 1,
      anon_sym_with,
    STATE(4585), 1,
      aux_sym_compound_type_repeat1,
    STATE(8674), 1,
      sym__refinement,
    STATE(8675), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4564), 2,
      sym_comment,
      sym_block_comment,
    STATE(8527), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [240393] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7586), 1,
      anon_sym_inline,
    ACTIONS(7588), 1,
      anon_sym_infix,
    ACTIONS(7590), 1,
      anon_sym_open,
    ACTIONS(7592), 1,
      anon_sym_transparent,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(8559), 1,
      sym_operator_identifier,
    STATE(6798), 1,
      aux_sym_modifiers_repeat1,
    STATE(9016), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(12206), 1,
      sym_modifiers,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15097), 1,
      sym_identifier,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    ACTIONS(7580), 2,
      anon_sym_end,
      anon_sym_opaque,
    ACTIONS(8557), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(4565), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [240473] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8561), 1,
      anon_sym_COLON,
    ACTIONS(8563), 1,
      anon_sym_LBRACE,
    ACTIONS(8565), 1,
      anon_sym_with,
    STATE(4619), 1,
      aux_sym_compound_type_repeat1,
    STATE(8454), 1,
      sym__refinement,
    STATE(8455), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4566), 2,
      sym_comment,
      sym_block_comment,
    STATE(8598), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 7,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [240539] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [240585] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8567), 1,
      sym__interpolated_multiline_string_start,
    STATE(7326), 1,
      sym_interpolated_string,
    STATE(16092), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240641] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(988), 1,
      anon_sym_LBRACE,
    ACTIONS(7876), 1,
      anon_sym_LPAREN,
    ACTIONS(8569), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4569), 2,
      sym_comment,
      sym_block_comment,
    STATE(6534), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240699] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7936), 1,
      anon_sym_LPAREN,
    STATE(4573), 1,
      aux_sym_annotation_repeat1,
    STATE(4851), 1,
      sym_arguments,
    STATE(4570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240751] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240799] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8503), 1,
      anon_sym_COLON,
    ACTIONS(8505), 1,
      anon_sym_LBRACE,
    ACTIONS(8507), 1,
      anon_sym_with,
    STATE(4543), 1,
      aux_sym_compound_type_repeat1,
    STATE(8524), 1,
      sym__refinement,
    STATE(8533), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4572), 2,
      sym_comment,
      sym_block_comment,
    STATE(8518), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [240865] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8571), 1,
      anon_sym_LPAREN,
    STATE(4851), 1,
      sym_arguments,
    STATE(4573), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [240915] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [240961] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8574), 1,
      anon_sym_LPAREN,
    STATE(5004), 1,
      sym_arguments,
    STATE(4575), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241011] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8577), 1,
      anon_sym_with,
    STATE(4646), 1,
      aux_sym_compound_type_repeat1,
    STATE(7893), 1,
      sym_arguments,
    STATE(7894), 1,
      sym__refinement,
    STATE(7895), 1,
      sym_template_body,
    STATE(4576), 2,
      sym_comment,
      sym_block_comment,
    STATE(7974), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241069] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8579), 1,
      anon_sym_with,
    STATE(4720), 1,
      aux_sym_compound_type_repeat1,
    STATE(8012), 1,
      sym__refinement,
    STATE(8013), 1,
      sym_template_body,
    STATE(8064), 1,
      sym_arguments,
    STATE(4577), 2,
      sym_comment,
      sym_block_comment,
    STATE(8149), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [241127] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8351), 1,
      anon_sym_LBRACK,
    ACTIONS(8357), 1,
      anon_sym_POUND,
    ACTIONS(8581), 1,
      anon_sym_LPAREN,
    STATE(5065), 1,
      aux_sym_annotation_repeat1,
    STATE(5421), 1,
      sym_type_arguments,
    STATE(6098), 1,
      sym_arguments,
    STATE(4578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241185] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241279] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [241325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241371] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8319), 1,
      anon_sym_with,
    STATE(5661), 1,
      aux_sym_compound_type_repeat1,
    STATE(7222), 1,
      sym_template_body,
    STATE(7242), 1,
      sym__refinement,
    STATE(4583), 2,
      sym_comment,
      sym_block_comment,
    STATE(7186), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [241427] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241473] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8551), 1,
      anon_sym_COLON,
    ACTIONS(8553), 1,
      anon_sym_LBRACE,
    ACTIONS(8555), 1,
      anon_sym_with,
    STATE(5568), 1,
      aux_sym_compound_type_repeat1,
    STATE(8662), 1,
      sym__refinement,
    STATE(8675), 1,
      sym_template_body,
    STATE(4585), 2,
      sym_comment,
      sym_block_comment,
    STATE(8527), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241533] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8589), 1,
      anon_sym_LBRACK,
    ACTIONS(8591), 1,
      anon_sym_LPAREN,
    ACTIONS(8593), 1,
      anon_sym_POUND,
    STATE(4854), 1,
      aux_sym_annotation_repeat1,
    STATE(5298), 1,
      sym_type_arguments,
    STATE(5592), 1,
      sym_arguments,
    STATE(4586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [241591] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8595), 1,
      anon_sym_LBRACK,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    ACTIONS(8599), 1,
      anon_sym_POUND,
    STATE(4873), 1,
      aux_sym_annotation_repeat1,
    STATE(5444), 1,
      sym_type_arguments,
    STATE(5775), 1,
      sym_arguments,
    STATE(4587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [241649] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8561), 1,
      anon_sym_COLON,
    ACTIONS(8563), 1,
      anon_sym_LBRACE,
    ACTIONS(8565), 1,
      anon_sym_with,
    STATE(4619), 1,
      aux_sym_compound_type_repeat1,
    STATE(8454), 1,
      sym__refinement,
    STATE(8455), 1,
      sym_template_body,
    STATE(4588), 2,
      sym_comment,
      sym_block_comment,
    STATE(8598), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [241709] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8551), 1,
      anon_sym_COLON,
    ACTIONS(8553), 1,
      anon_sym_LBRACE,
    ACTIONS(8555), 1,
      anon_sym_with,
    STATE(4585), 1,
      aux_sym_compound_type_repeat1,
    STATE(8674), 1,
      sym__refinement,
    STATE(8675), 1,
      sym_template_body,
    STATE(4589), 2,
      sym_comment,
      sym_block_comment,
    STATE(8527), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241769] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8227), 1,
      anon_sym_LBRACK,
    ACTIONS(8229), 1,
      anon_sym_AT,
    ACTIONS(8233), 1,
      anon_sym_POUND,
    STATE(4973), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5230), 1,
      sym_type_arguments,
    STATE(5675), 1,
      sym_annotation,
    STATE(4590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241827] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8605), 1,
      anon_sym_AT,
    STATE(4925), 1,
      sym_annotation,
    STATE(4591), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241877] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8489), 1,
      anon_sym_COLON,
    ACTIONS(8491), 1,
      anon_sym_LBRACE,
    ACTIONS(8493), 1,
      anon_sym_with,
    STATE(4604), 1,
      aux_sym_compound_type_repeat1,
    STATE(8876), 1,
      sym__refinement,
    STATE(8879), 1,
      sym_template_body,
    STATE(4592), 2,
      sym_comment,
      sym_block_comment,
    STATE(8567), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [241937] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(988), 1,
      anon_sym_LBRACE,
    ACTIONS(7876), 1,
      anon_sym_LPAREN,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8569), 1,
      anon_sym_DOT,
    ACTIONS(8608), 1,
      sym_operator_identifier,
    STATE(1786), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4593), 2,
      sym_comment,
      sym_block_comment,
    STATE(6534), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8309), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [242007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242053] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8004), 1,
      anon_sym_DOT,
    ACTIONS(8610), 1,
      anon_sym_EQ_GT,
    STATE(4595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242103] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [242149] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8612), 1,
      anon_sym_LBRACK,
    ACTIONS(8614), 1,
      anon_sym_LPAREN,
    ACTIONS(8616), 1,
      anon_sym_POUND,
    STATE(4908), 1,
      aux_sym_annotation_repeat1,
    STATE(5172), 1,
      sym_type_arguments,
    STATE(5899), 1,
      sym_arguments,
    STATE(4597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [242207] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8618), 1,
      sym__interpolated_multiline_string_start,
    STATE(7397), 1,
      sym_interpolated_string,
    STATE(16007), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [242263] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(952), 1,
      anon_sym_LBRACE,
    ACTIONS(7842), 1,
      anon_sym_LPAREN,
    ACTIONS(8521), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4599), 2,
      sym_comment,
      sym_block_comment,
    STATE(6473), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242321] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8545), 1,
      anon_sym_COLON,
    ACTIONS(8547), 1,
      anon_sym_LBRACE,
    ACTIONS(8549), 1,
      anon_sym_with,
    STATE(4622), 1,
      aux_sym_compound_type_repeat1,
    STATE(8647), 1,
      sym_template_body,
    STATE(8653), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4600), 2,
      sym_comment,
      sym_block_comment,
    STATE(8463), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [242387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242433] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7932), 1,
      anon_sym_LPAREN,
    STATE(4603), 1,
      aux_sym_annotation_repeat1,
    STATE(5030), 1,
      sym_arguments,
    STATE(4602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242485] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8620), 1,
      anon_sym_LPAREN,
    STATE(5030), 1,
      sym_arguments,
    STATE(4603), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242535] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8489), 1,
      anon_sym_COLON,
    ACTIONS(8491), 1,
      anon_sym_LBRACE,
    ACTIONS(8493), 1,
      anon_sym_with,
    STATE(5603), 1,
      aux_sym_compound_type_repeat1,
    STATE(8823), 1,
      sym__refinement,
    STATE(8879), 1,
      sym_template_body,
    STATE(4604), 2,
      sym_comment,
      sym_block_comment,
    STATE(8567), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242595] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8405), 1,
      anon_sym_LBRACK,
    ACTIONS(8409), 1,
      anon_sym_POUND,
    ACTIONS(8623), 1,
      anon_sym_AT,
    STATE(5084), 1,
      sym_type_arguments,
    STATE(5086), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5616), 1,
      sym_annotation,
    STATE(4605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242653] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242699] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8625), 1,
      sym__interpolated_multiline_string_start,
    STATE(6974), 1,
      sym_interpolated_string,
    STATE(16306), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242755] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_as,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [242801] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(988), 1,
      anon_sym_LBRACE,
    ACTIONS(7876), 1,
      anon_sym_LPAREN,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8569), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4609), 2,
      sym_comment,
      sym_block_comment,
    STATE(6534), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242861] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8627), 1,
      anon_sym_AT,
    STATE(4953), 1,
      sym_annotation,
    STATE(4610), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242911] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8630), 1,
      anon_sym_LBRACK,
    ACTIONS(8632), 1,
      anon_sym_LPAREN,
    ACTIONS(8634), 1,
      anon_sym_POUND,
    STATE(4959), 1,
      aux_sym_annotation_repeat1,
    STATE(5472), 1,
      sym_type_arguments,
    STATE(5897), 1,
      sym_arguments,
    STATE(4611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [242969] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8387), 1,
      anon_sym_LBRACK,
    ACTIONS(8391), 1,
      anon_sym_POUND,
    ACTIONS(8636), 1,
      anon_sym_AT,
    STATE(4896), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5028), 1,
      sym_type_arguments,
    STATE(5714), 1,
      sym_annotation,
    STATE(4612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243027] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243073] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8102), 1,
      anon_sym_LBRACK,
    ACTIONS(8106), 1,
      anon_sym_POUND,
    ACTIONS(8640), 1,
      anon_sym_AT,
    STATE(4875), 1,
      sym_type_arguments,
    STATE(4968), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5799), 1,
      sym_annotation,
    STATE(4614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243131] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8503), 1,
      anon_sym_COLON,
    ACTIONS(8505), 1,
      anon_sym_LBRACE,
    ACTIONS(8507), 1,
      anon_sym_with,
    STATE(4543), 1,
      aux_sym_compound_type_repeat1,
    STATE(8524), 1,
      sym__refinement,
    STATE(8533), 1,
      sym_template_body,
    STATE(4615), 2,
      sym_comment,
      sym_block_comment,
    STATE(8518), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243191] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8642), 1,
      anon_sym_DOT,
    STATE(4616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243239] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8227), 1,
      anon_sym_LBRACK,
    ACTIONS(8233), 1,
      anon_sym_POUND,
    ACTIONS(8644), 1,
      anon_sym_LPAREN,
    STATE(5020), 1,
      aux_sym_annotation_repeat1,
    STATE(5230), 1,
      sym_type_arguments,
    STATE(5986), 1,
      sym_arguments,
    STATE(4617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243297] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(952), 1,
      anon_sym_LBRACE,
    ACTIONS(7842), 1,
      anon_sym_LPAREN,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8521), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4618), 2,
      sym_comment,
      sym_block_comment,
    STATE(6473), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243357] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8561), 1,
      anon_sym_COLON,
    ACTIONS(8563), 1,
      anon_sym_LBRACE,
    ACTIONS(8565), 1,
      anon_sym_with,
    STATE(5834), 1,
      aux_sym_compound_type_repeat1,
    STATE(8441), 1,
      sym__refinement,
    STATE(8455), 1,
      sym_template_body,
    STATE(4619), 2,
      sym_comment,
      sym_block_comment,
    STATE(8598), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [243417] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8646), 1,
      anon_sym_DOT,
    STATE(4620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243465] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8648), 1,
      anon_sym_DOT,
    STATE(4621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243513] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8545), 1,
      anon_sym_COLON,
    ACTIONS(8547), 1,
      anon_sym_LBRACE,
    ACTIONS(8549), 1,
      anon_sym_with,
    STATE(5507), 1,
      aux_sym_compound_type_repeat1,
    STATE(8647), 1,
      sym_template_body,
    STATE(8690), 1,
      sym__refinement,
    STATE(4622), 2,
      sym_comment,
      sym_block_comment,
    STATE(8463), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243573] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8650), 1,
      anon_sym_with,
    STATE(4733), 1,
      aux_sym_compound_type_repeat1,
    STATE(8105), 1,
      sym_arguments,
    STATE(8258), 1,
      sym__refinement,
    STATE(8259), 1,
      sym_template_body,
    STATE(4623), 2,
      sym_comment,
      sym_block_comment,
    STATE(7810), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [243631] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7818), 1,
      anon_sym_LPAREN,
    STATE(4575), 1,
      aux_sym_annotation_repeat1,
    STATE(5004), 1,
      sym_arguments,
    STATE(4624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243683] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8461), 1,
      anon_sym_LBRACK,
    ACTIONS(8467), 1,
      anon_sym_POUND,
    ACTIONS(8652), 1,
      anon_sym_LPAREN,
    STATE(5009), 1,
      aux_sym_annotation_repeat1,
    STATE(5270), 1,
      sym_type_arguments,
    STATE(5940), 1,
      sym_arguments,
    STATE(4625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [243741] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8654), 1,
      anon_sym_LBRACK,
    ACTIONS(8656), 1,
      anon_sym_AT,
    ACTIONS(8658), 1,
      anon_sym_LPAREN,
    ACTIONS(8660), 1,
      anon_sym_POUND,
    STATE(5196), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5558), 1,
      sym_type_arguments,
    STATE(6348), 1,
      sym_annotation,
    STATE(7893), 1,
      sym_arguments,
    STATE(4626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243803] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243849] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7904), 1,
      anon_sym_LPAREN,
    STATE(4629), 1,
      aux_sym_annotation_repeat1,
    STATE(5015), 1,
      sym_arguments,
    STATE(4628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243901] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8664), 1,
      anon_sym_LPAREN,
    STATE(5015), 1,
      sym_arguments,
    STATE(4629), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [243951] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8110), 1,
      anon_sym_with,
    STATE(5854), 1,
      aux_sym_compound_type_repeat1,
    STATE(7127), 1,
      sym__refinement,
    STATE(7169), 1,
      sym_template_body,
    STATE(4630), 2,
      sym_comment,
      sym_block_comment,
    STATE(6847), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244007] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7980), 1,
      anon_sym_AT,
    STATE(4610), 1,
      aux_sym_enum_definition_repeat1,
    STATE(4953), 1,
      sym_annotation,
    STATE(4631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244059] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244105] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8667), 1,
      anon_sym_LBRACK,
    ACTIONS(8669), 1,
      anon_sym_LPAREN,
    ACTIONS(8671), 1,
      anon_sym_POUND,
    STATE(4986), 1,
      aux_sym_annotation_repeat1,
    STATE(5120), 1,
      sym_type_arguments,
    STATE(6096), 1,
      sym_arguments,
    STATE(4633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [244208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244253] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8673), 1,
      anon_sym_COLON,
    ACTIONS(8675), 1,
      anon_sym_LBRACE,
    ACTIONS(8677), 1,
      anon_sym_with,
    STATE(6493), 1,
      aux_sym_compound_type_repeat1,
    STATE(9167), 1,
      sym_template_body,
    STATE(9181), 1,
      sym__refinement,
    STATE(4636), 2,
      sym_comment,
      sym_block_comment,
    STATE(9495), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [244312] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8679), 1,
      anon_sym_DOT,
    STATE(4637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244404] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244451] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8681), 1,
      anon_sym_LBRACK,
    ACTIONS(8683), 1,
      anon_sym_LPAREN,
    ACTIONS(8685), 1,
      anon_sym_POUND,
    STATE(4439), 1,
      sym_type_arguments,
    STATE(4529), 1,
      sym_arguments,
    STATE(6076), 1,
      aux_sym_annotation_repeat1,
    STATE(4640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 24,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [244506] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244596] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8389), 1,
      anon_sym_LPAREN,
    STATE(4644), 1,
      aux_sym_annotation_repeat1,
    STATE(5347), 1,
      sym_arguments,
    STATE(4643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244647] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8691), 1,
      anon_sym_LPAREN,
    STATE(5347), 1,
      sym_arguments,
    STATE(4644), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244741] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8577), 1,
      anon_sym_with,
    STATE(6621), 1,
      aux_sym_compound_type_repeat1,
    STATE(7868), 1,
      sym__refinement,
    STATE(7895), 1,
      sym_template_body,
    STATE(4646), 2,
      sym_comment,
      sym_block_comment,
    STATE(7974), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244796] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244841] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244886] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244931] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8698), 1,
      anon_sym_LPAREN,
    STATE(5360), 1,
      sym_arguments,
    STATE(4650), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [244980] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245025] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245070] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8495), 1,
      anon_sym_LBRACK,
    ACTIONS(8499), 1,
      anon_sym_POUND,
    ACTIONS(8701), 1,
      anon_sym_AT,
    STATE(5163), 1,
      sym_type_arguments,
    STATE(5199), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6750), 1,
      sym_annotation,
    STATE(4653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245127] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245172] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8347), 1,
      anon_sym_LPAREN,
    STATE(4650), 1,
      aux_sym_annotation_repeat1,
    STATE(5360), 1,
      sym_arguments,
    STATE(4655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245223] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245268] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [245313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [245358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245403] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8707), 1,
      anon_sym_COLON,
    ACTIONS(8709), 1,
      anon_sym_LBRACE,
    ACTIONS(8711), 1,
      anon_sym_with,
    STATE(4683), 1,
      aux_sym_compound_type_repeat1,
    STATE(9277), 1,
      sym_template_body,
    STATE(9285), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4660), 2,
      sym_comment,
      sym_block_comment,
    STATE(9112), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [245468] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8713), 1,
      anon_sym_DOT,
    STATE(4661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [245515] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8533), 1,
      anon_sym_LBRACK,
    ACTIONS(8535), 1,
      anon_sym_AT,
    ACTIONS(8539), 1,
      anon_sym_POUND,
    STATE(5406), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5731), 1,
      sym_type_arguments,
    STATE(6604), 1,
      sym_annotation,
    STATE(4662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [245572] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8000), 1,
      anon_sym_AT,
    STATE(4762), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5479), 1,
      sym_annotation,
    STATE(4663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [245623] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8715), 1,
      anon_sym_LBRACK,
    ACTIONS(8717), 1,
      anon_sym_AT,
    ACTIONS(8719), 1,
      anon_sym_LPAREN,
    ACTIONS(8721), 1,
      anon_sym_POUND,
    STATE(6048), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6549), 1,
      sym_type_arguments,
    STATE(7249), 1,
      sym_annotation,
    STATE(8539), 1,
      sym_arguments,
    STATE(4664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [245684] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8723), 1,
      anon_sym_LPAREN,
    STATE(5330), 1,
      sym_arguments,
    STATE(4665), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [245733] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8098), 1,
      anon_sym_LPAREN,
    STATE(4665), 1,
      aux_sym_annotation_repeat1,
    STATE(5330), 1,
      sym_arguments,
    STATE(4666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [245784] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8726), 1,
      anon_sym_LBRACK,
    ACTIONS(8728), 1,
      anon_sym_LPAREN,
    ACTIONS(8730), 1,
      anon_sym_POUND,
    STATE(5370), 1,
      aux_sym_annotation_repeat1,
    STATE(6038), 1,
      sym_type_arguments,
    STATE(6298), 1,
      sym_arguments,
    STATE(4667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [245841] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8595), 1,
      anon_sym_LBRACK,
    ACTIONS(8599), 1,
      anon_sym_POUND,
    ACTIONS(8732), 1,
      anon_sym_AT,
    STATE(5203), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5444), 1,
      sym_type_arguments,
    STATE(6673), 1,
      sym_annotation,
    STATE(4668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [245898] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8673), 1,
      anon_sym_COLON,
    ACTIONS(8675), 1,
      anon_sym_LBRACE,
    ACTIONS(8677), 1,
      anon_sym_with,
    STATE(4636), 1,
      aux_sym_compound_type_repeat1,
    STATE(9167), 1,
      sym_template_body,
    STATE(9168), 1,
      sym__refinement,
    STATE(4669), 2,
      sym_comment,
      sym_block_comment,
    STATE(9495), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [245957] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8734), 1,
      anon_sym_DOT,
    STATE(4670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246004] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [246049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246094] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8736), 1,
      anon_sym_COLON,
    ACTIONS(8738), 1,
      anon_sym_LBRACE,
    ACTIONS(8740), 1,
      anon_sym_with,
    STATE(6594), 1,
      aux_sym_compound_type_repeat1,
    STATE(9262), 1,
      sym__refinement,
    STATE(9291), 1,
      sym_template_body,
    STATE(4673), 2,
      sym_comment,
      sym_block_comment,
    STATE(9078), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246153] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8742), 1,
      anon_sym_LBRACK,
    ACTIONS(8744), 1,
      anon_sym_LPAREN,
    ACTIONS(8746), 1,
      anon_sym_POUND,
    STATE(5334), 1,
      aux_sym_annotation_repeat1,
    STATE(5905), 1,
      sym_type_arguments,
    STATE(6220), 1,
      sym_arguments,
    STATE(4674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [246210] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8748), 1,
      anon_sym_LPAREN,
    STATE(5352), 1,
      sym_arguments,
    STATE(4675), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246259] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8104), 1,
      anon_sym_LPAREN,
    STATE(4675), 1,
      aux_sym_annotation_repeat1,
    STATE(5352), 1,
      sym_arguments,
    STATE(4676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246310] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246355] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8736), 1,
      anon_sym_COLON,
    ACTIONS(8738), 1,
      anon_sym_LBRACE,
    ACTIONS(8740), 1,
      anon_sym_with,
    STATE(4673), 1,
      aux_sym_compound_type_repeat1,
    STATE(9289), 1,
      sym__refinement,
    STATE(9291), 1,
      sym_template_body,
    STATE(4678), 2,
      sym_comment,
      sym_block_comment,
    STATE(9078), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246414] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8509), 1,
      anon_sym_LBRACK,
    ACTIONS(8515), 1,
      anon_sym_POUND,
    ACTIONS(8751), 1,
      anon_sym_LPAREN,
    STATE(5373), 1,
      aux_sym_annotation_repeat1,
    STATE(5505), 1,
      sym_type_arguments,
    STATE(6154), 1,
      sym_arguments,
    STATE(4679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [246471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [246516] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8753), 1,
      anon_sym_COLON,
    ACTIONS(8755), 1,
      anon_sym_LBRACE,
    ACTIONS(8757), 1,
      anon_sym_with,
    STATE(4780), 1,
      aux_sym_compound_type_repeat1,
    STATE(8942), 1,
      sym__refinement,
    STATE(9475), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4681), 2,
      sym_comment,
      sym_block_comment,
    STATE(9318), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [246581] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246626] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8707), 1,
      anon_sym_COLON,
    ACTIONS(8709), 1,
      anon_sym_LBRACE,
    ACTIONS(8711), 1,
      anon_sym_with,
    STATE(6484), 1,
      aux_sym_compound_type_repeat1,
    STATE(9277), 1,
      sym_template_body,
    STATE(9337), 1,
      sym__refinement,
    STATE(4683), 2,
      sym_comment,
      sym_block_comment,
    STATE(9112), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246685] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8759), 1,
      anon_sym_with,
    STATE(4992), 1,
      aux_sym_compound_type_repeat1,
    STATE(8766), 1,
      sym_arguments,
    STATE(8778), 1,
      sym__refinement,
    STATE(8779), 1,
      sym_template_body,
    STATE(4684), 2,
      sym_comment,
      sym_block_comment,
    STATE(8733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [246742] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246787] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8761), 1,
      anon_sym_AT,
    STATE(5391), 1,
      sym_annotation,
    STATE(4686), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246836] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246881] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246926] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8764), 1,
      anon_sym_LPAREN,
    STATE(5327), 1,
      sym_arguments,
    STATE(4689), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [246975] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8673), 1,
      anon_sym_COLON,
    ACTIONS(8675), 1,
      anon_sym_LBRACE,
    ACTIONS(8677), 1,
      anon_sym_with,
    STATE(4636), 1,
      aux_sym_compound_type_repeat1,
    STATE(9167), 1,
      sym_template_body,
    STATE(9168), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4690), 2,
      sym_comment,
      sym_block_comment,
    STATE(9495), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [247040] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8407), 1,
      anon_sym_LPAREN,
    STATE(4689), 1,
      aux_sym_annotation_repeat1,
    STATE(5327), 1,
      sym_arguments,
    STATE(4691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247091] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [247138] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247183] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [247228] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8769), 1,
      anon_sym_AT,
    STATE(5431), 1,
      sym_annotation,
    STATE(4695), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247322] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(7976), 1,
      sym__interpolated_multiline_string_start,
    STATE(5898), 1,
      sym_interpolated_string,
    STATE(16176), 1,
      sym__interpolated_string_start,
    ACTIONS(8772), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247377] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247424] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8774), 1,
      anon_sym_LPAREN,
    STATE(5252), 1,
      sym_arguments,
    STATE(4699), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247473] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8753), 1,
      anon_sym_COLON,
    ACTIONS(8755), 1,
      anon_sym_LBRACE,
    ACTIONS(8757), 1,
      anon_sym_with,
    STATE(4780), 1,
      aux_sym_compound_type_repeat1,
    STATE(8942), 1,
      sym__refinement,
    STATE(9475), 1,
      sym_template_body,
    STATE(4700), 2,
      sym_comment,
      sym_block_comment,
    STATE(9318), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [247532] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8777), 1,
      anon_sym_with,
    STATE(4816), 1,
      aux_sym_compound_type_repeat1,
    STATE(8635), 1,
      sym__refinement,
    STATE(8637), 1,
      sym_template_body,
    STATE(8732), 1,
      sym_arguments,
    STATE(4701), 2,
      sym_comment,
      sym_block_comment,
    STATE(8569), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [247589] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [247634] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247724] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8257), 1,
      anon_sym_AT,
    STATE(4686), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5391), 1,
      sym_annotation,
    STATE(4705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247775] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8779), 1,
      anon_sym_DOT,
    STATE(4706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247822] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8646), 1,
      anon_sym_DOT,
    ACTIONS(8781), 1,
      anon_sym_EQ_GT,
    STATE(4707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247871] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8783), 1,
      anon_sym_COLON,
    ACTIONS(8785), 1,
      anon_sym_LBRACE,
    ACTIONS(8787), 1,
      anon_sym_with,
    STATE(4763), 1,
      aux_sym_compound_type_repeat1,
    STATE(9161), 1,
      sym__refinement,
    STATE(9166), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4708), 2,
      sym_comment,
      sym_block_comment,
    STATE(9198), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [247936] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 23,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [247981] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8012), 1,
      anon_sym_LPAREN,
    STATE(4699), 1,
      aux_sym_annotation_repeat1,
    STATE(5252), 1,
      sym_arguments,
    STATE(4710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248032] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7840), 1,
      anon_sym_AT,
    STATE(4695), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5431), 1,
      sym_annotation,
    STATE(4711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248083] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8789), 1,
      anon_sym_LBRACK,
    ACTIONS(8791), 1,
      anon_sym_LPAREN,
    ACTIONS(8793), 1,
      anon_sym_POUND,
    STATE(5382), 1,
      aux_sym_annotation_repeat1,
    STATE(5745), 1,
      sym_type_arguments,
    STATE(6378), 1,
      sym_arguments,
    STATE(4712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [248140] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8707), 1,
      anon_sym_COLON,
    ACTIONS(8709), 1,
      anon_sym_LBRACE,
    ACTIONS(8711), 1,
      anon_sym_with,
    STATE(4683), 1,
      aux_sym_compound_type_repeat1,
    STATE(9277), 1,
      sym_template_body,
    STATE(9285), 1,
      sym__refinement,
    STATE(4713), 2,
      sym_comment,
      sym_block_comment,
    STATE(9112), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248199] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248244] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8317), 1,
      anon_sym_LPAREN,
    STATE(4782), 1,
      aux_sym_annotation_repeat1,
    STATE(5202), 1,
      sym_arguments,
    STATE(4715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248295] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8795), 1,
      anon_sym_LBRACK,
    ACTIONS(8797), 1,
      anon_sym_LPAREN,
    ACTIONS(8799), 1,
      anon_sym_POUND,
    STATE(5154), 1,
      aux_sym_annotation_repeat1,
    STATE(5736), 1,
      sym_type_arguments,
    STATE(6657), 1,
      sym_arguments,
    STATE(4716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [248352] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248397] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      anon_sym_LBRACK,
    ACTIONS(8803), 1,
      anon_sym_LPAREN,
    ACTIONS(8805), 1,
      anon_sym_POUND,
    STATE(5314), 1,
      aux_sym_annotation_repeat1,
    STATE(5990), 1,
      sym_type_arguments,
    STATE(6161), 1,
      sym_arguments,
    STATE(4718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [248454] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248499] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8579), 1,
      anon_sym_with,
    STATE(6430), 1,
      aux_sym_compound_type_repeat1,
    STATE(8002), 1,
      sym__refinement,
    STATE(8013), 1,
      sym_template_body,
    STATE(4720), 2,
      sym_comment,
      sym_block_comment,
    STATE(8149), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [248554] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8610), 1,
      anon_sym_EQ_GT,
    STATE(4721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248601] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8108), 1,
      anon_sym_AT,
    STATE(4765), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5194), 1,
      sym_annotation,
    STATE(4722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248652] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248697] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248742] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8533), 1,
      anon_sym_LBRACK,
    ACTIONS(8539), 1,
      anon_sym_POUND,
    ACTIONS(8807), 1,
      anon_sym_LPAREN,
    STATE(5265), 1,
      aux_sym_annotation_repeat1,
    STATE(5731), 1,
      sym_type_arguments,
    STATE(6222), 1,
      sym_arguments,
    STATE(4725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [248799] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8654), 1,
      anon_sym_LBRACK,
    ACTIONS(8660), 1,
      anon_sym_POUND,
    ACTIONS(8809), 1,
      anon_sym_LPAREN,
    STATE(5342), 1,
      aux_sym_annotation_repeat1,
    STATE(5558), 1,
      sym_type_arguments,
    STATE(6217), 1,
      sym_arguments,
    STATE(4726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [248901] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8811), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_LBRACE,
    ACTIONS(8815), 1,
      anon_sym_with,
    STATE(4795), 1,
      aux_sym_compound_type_repeat1,
    STATE(9438), 1,
      sym_template_body,
    STATE(9454), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4728), 2,
      sym_comment,
      sym_block_comment,
    STATE(9424), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [248966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249011] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(7976), 1,
      sym__interpolated_multiline_string_start,
    STATE(5898), 1,
      sym_interpolated_string,
    STATE(16176), 1,
      sym__interpolated_string_start,
    ACTIONS(8817), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [249066] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249111] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8819), 1,
      anon_sym_DOT,
    STATE(4732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249158] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8650), 1,
      anon_sym_with,
    STATE(6467), 1,
      aux_sym_compound_type_repeat1,
    STATE(8251), 1,
      sym__refinement,
    STATE(8259), 1,
      sym_template_body,
    STATE(4733), 2,
      sym_comment,
      sym_block_comment,
    STATE(7810), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [249213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249258] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1096), 1,
      anon_sym_LBRACE,
    ACTIONS(8465), 1,
      anon_sym_LPAREN,
    ACTIONS(8821), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4735), 2,
      sym_comment,
      sym_block_comment,
    STATE(7045), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [249315] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8823), 1,
      sym__interpolated_multiline_string_start,
    STATE(8260), 1,
      sym_interpolated_string,
    STATE(15874), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249370] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8589), 1,
      anon_sym_LBRACK,
    ACTIONS(8593), 1,
      anon_sym_POUND,
    ACTIONS(8825), 1,
      anon_sym_AT,
    STATE(5298), 1,
      sym_type_arguments,
    STATE(5331), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6190), 1,
      sym_annotation,
    STATE(4737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [249427] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8827), 1,
      anon_sym_with,
    STATE(5047), 1,
      aux_sym_compound_type_repeat1,
    STATE(8538), 1,
      sym__refinement,
    STATE(8579), 1,
      sym_arguments,
    STATE(8583), 1,
      sym_template_body,
    STATE(4738), 2,
      sym_comment,
      sym_block_comment,
    STATE(8689), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [249484] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249529] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249574] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8829), 1,
      anon_sym_LBRACK,
    ACTIONS(8831), 1,
      anon_sym_AT,
    ACTIONS(8833), 1,
      anon_sym_LPAREN,
    ACTIONS(8835), 1,
      anon_sym_POUND,
    STATE(5595), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6115), 1,
      sym_type_arguments,
    STATE(7156), 1,
      sym_annotation,
    STATE(8579), 1,
      sym_arguments,
    STATE(4741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [249635] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249680] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249727] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8837), 1,
      sym__interpolated_multiline_string_start,
    STATE(8159), 1,
      sym_interpolated_string,
    STATE(15346), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [249782] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249827] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1024), 1,
      anon_sym_LBRACE,
    ACTIONS(8231), 1,
      anon_sym_LPAREN,
    ACTIONS(8839), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4746), 2,
      sym_comment,
      sym_block_comment,
    STATE(6866), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249884] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249929] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8667), 1,
      anon_sym_LBRACK,
    ACTIONS(8671), 1,
      anon_sym_POUND,
    ACTIONS(8841), 1,
      anon_sym_AT,
    STATE(5120), 1,
      sym_type_arguments,
    STATE(5441), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6265), 1,
      sym_annotation,
    STATE(4748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [249986] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1060), 1,
      anon_sym_LBRACE,
    ACTIONS(8355), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4749), 2,
      sym_comment,
      sym_block_comment,
    STATE(7191), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250043] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8845), 1,
      sym__interpolated_multiline_string_start,
    STATE(7712), 1,
      sym_interpolated_string,
    STATE(15736), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [250098] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250143] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250190] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8847), 1,
      anon_sym_DOT,
    STATE(4753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250237] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250284] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250329] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250374] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250419] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8811), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_LBRACE,
    ACTIONS(8815), 1,
      anon_sym_with,
    STATE(4795), 1,
      aux_sym_compound_type_repeat1,
    STATE(9438), 1,
      sym_template_body,
    STATE(9454), 1,
      sym__refinement,
    STATE(4758), 2,
      sym_comment,
      sym_block_comment,
    STATE(9424), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250478] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8849), 1,
      anon_sym_with,
    STATE(5089), 1,
      aux_sym_compound_type_repeat1,
    STATE(8391), 1,
      sym__refinement,
    STATE(8392), 1,
      sym_template_body,
    STATE(8539), 1,
      sym_arguments,
    STATE(4759), 2,
      sym_comment,
      sym_block_comment,
    STATE(8352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [250535] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8851), 1,
      anon_sym_LBRACK,
    ACTIONS(8853), 1,
      anon_sym_AT,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(8857), 1,
      anon_sym_POUND,
    STATE(5698), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6550), 1,
      sym_type_arguments,
    STATE(7229), 1,
      sym_annotation,
    STATE(8766), 1,
      sym_arguments,
    STATE(4760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [250596] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8736), 1,
      anon_sym_COLON,
    ACTIONS(8738), 1,
      anon_sym_LBRACE,
    ACTIONS(8740), 1,
      anon_sym_with,
    STATE(4673), 1,
      aux_sym_compound_type_repeat1,
    STATE(9289), 1,
      sym__refinement,
    STATE(9291), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4761), 2,
      sym_comment,
      sym_block_comment,
    STATE(9078), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [250661] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8859), 1,
      anon_sym_AT,
    STATE(5479), 1,
      sym_annotation,
    STATE(4762), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250710] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8783), 1,
      anon_sym_COLON,
    ACTIONS(8785), 1,
      anon_sym_LBRACE,
    ACTIONS(8787), 1,
      anon_sym_with,
    STATE(6286), 1,
      aux_sym_compound_type_repeat1,
    STATE(9139), 1,
      sym__refinement,
    STATE(9166), 1,
      sym_template_body,
    STATE(4763), 2,
      sym_comment,
      sym_block_comment,
    STATE(9198), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [250769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250814] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8862), 1,
      anon_sym_AT,
    STATE(5194), 1,
      sym_annotation,
    STATE(4765), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250908] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1024), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8231), 1,
      anon_sym_LPAREN,
    ACTIONS(8839), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4767), 2,
      sym_comment,
      sym_block_comment,
    STATE(6866), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [250967] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251012] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251102] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [251147] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8865), 1,
      anon_sym_LBRACK,
    ACTIONS(8867), 1,
      anon_sym_AT,
    ACTIONS(8869), 1,
      anon_sym_LPAREN,
    ACTIONS(8871), 1,
      anon_sym_POUND,
    STATE(6015), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6397), 1,
      sym_type_arguments,
    STATE(7429), 1,
      sym_annotation,
    STATE(8732), 1,
      sym_arguments,
    STATE(4772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [251208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251253] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8654), 1,
      anon_sym_LBRACK,
    ACTIONS(8656), 1,
      anon_sym_AT,
    ACTIONS(8660), 1,
      anon_sym_POUND,
    STATE(5196), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5558), 1,
      sym_type_arguments,
    STATE(6348), 1,
      sym_annotation,
    STATE(4774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251310] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251355] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1060), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8355), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      anon_sym_DOT,
    ACTIONS(8873), 1,
      sym_operator_identifier,
    STATE(1835), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4776), 2,
      sym_comment,
      sym_block_comment,
    STATE(7191), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8309), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [251424] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251469] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251514] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1096), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8465), 1,
      anon_sym_LPAREN,
    ACTIONS(8821), 1,
      anon_sym_DOT,
    ACTIONS(8875), 1,
      sym_operator_identifier,
    STATE(1756), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4779), 2,
      sym_comment,
      sym_block_comment,
    STATE(7045), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8309), 7,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [251583] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8753), 1,
      anon_sym_COLON,
    ACTIONS(8755), 1,
      anon_sym_LBRACE,
    ACTIONS(8757), 1,
      anon_sym_with,
    STATE(6199), 1,
      aux_sym_compound_type_repeat1,
    STATE(8941), 1,
      sym__refinement,
    STATE(9475), 1,
      sym_template_body,
    STATE(4780), 2,
      sym_comment,
      sym_block_comment,
    STATE(9318), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [251642] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [251687] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8877), 1,
      anon_sym_LPAREN,
    STATE(5202), 1,
      sym_arguments,
    STATE(4782), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251826] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251871] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8648), 1,
      anon_sym_DOT,
    ACTIONS(8880), 1,
      anon_sym_EQ_GT,
    STATE(4786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [251920] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8783), 1,
      anon_sym_COLON,
    ACTIONS(8785), 1,
      anon_sym_LBRACE,
    ACTIONS(8787), 1,
      anon_sym_with,
    STATE(4763), 1,
      aux_sym_compound_type_repeat1,
    STATE(9161), 1,
      sym__refinement,
    STATE(9166), 1,
      sym_template_body,
    STATE(4787), 2,
      sym_comment,
      sym_block_comment,
    STATE(9198), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [251979] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252024] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252114] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8882), 1,
      anon_sym_LBRACK,
    ACTIONS(8884), 1,
      anon_sym_LPAREN,
    ACTIONS(8886), 1,
      anon_sym_POUND,
    STATE(5427), 1,
      aux_sym_annotation_repeat1,
    STATE(5943), 1,
      sym_type_arguments,
    STATE(6564), 1,
      sym_arguments,
    STATE(4791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [252171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252216] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252261] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8612), 1,
      anon_sym_LBRACK,
    ACTIONS(8616), 1,
      anon_sym_POUND,
    ACTIONS(8888), 1,
      anon_sym_AT,
    STATE(5172), 1,
      sym_type_arguments,
    STATE(5376), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6124), 1,
      sym_annotation,
    STATE(4794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [252318] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8811), 1,
      anon_sym_COLON,
    ACTIONS(8813), 1,
      anon_sym_LBRACE,
    ACTIONS(8815), 1,
      anon_sym_with,
    STATE(6301), 1,
      aux_sym_compound_type_repeat1,
    STATE(9438), 1,
      sym_template_body,
    STATE(9505), 1,
      sym__refinement,
    STATE(4795), 2,
      sym_comment,
      sym_block_comment,
    STATE(9424), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252377] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8630), 1,
      anon_sym_LBRACK,
    ACTIONS(8634), 1,
      anon_sym_POUND,
    ACTIONS(8890), 1,
      anon_sym_AT,
    STATE(5369), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5472), 1,
      sym_type_arguments,
    STATE(6380), 1,
      sym_annotation,
    STATE(4796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252434] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [252479] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8894), 1,
      anon_sym_COLON,
    ACTIONS(8897), 1,
      anon_sym_LBRACE,
    STATE(5635), 1,
      sym_template_body,
    STATE(4798), 2,
      sym_comment,
      sym_block_comment,
    STATE(5828), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 17,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252622] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1096), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8465), 1,
      anon_sym_LPAREN,
    ACTIONS(8821), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4801), 2,
      sym_comment,
      sym_block_comment,
    STATE(7045), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [252681] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252726] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252771] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1024), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8231), 1,
      anon_sym_LPAREN,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8839), 1,
      anon_sym_DOT,
    ACTIONS(8902), 1,
      sym_operator_identifier,
    STATE(1771), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4804), 2,
      sym_comment,
      sym_block_comment,
    STATE(6866), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8309), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [252840] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8904), 1,
      anon_sym_LBRACK,
    ACTIONS(8906), 1,
      anon_sym_LPAREN,
    ACTIONS(8908), 1,
      anon_sym_POUND,
    STATE(5258), 1,
      aux_sym_annotation_repeat1,
    STATE(5852), 1,
      sym_type_arguments,
    STATE(6251), 1,
      sym_arguments,
    STATE(4805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252897] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1060), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8355), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4806), 2,
      sym_comment,
      sym_block_comment,
    STATE(7191), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [252956] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253001] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7874), 1,
      anon_sym_AT,
    STATE(4811), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5173), 1,
      sym_annotation,
    STATE(4808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253052] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253097] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253142] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8910), 1,
      anon_sym_AT,
    STATE(5173), 1,
      sym_annotation,
    STATE(4811), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253191] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253236] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8509), 1,
      anon_sym_LBRACK,
    ACTIONS(8511), 1,
      anon_sym_AT,
    ACTIONS(8515), 1,
      anon_sym_POUND,
    STATE(5413), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5505), 1,
      sym_type_arguments,
    STATE(6230), 1,
      sym_annotation,
    STATE(4813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [253293] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253338] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253382] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8777), 1,
      anon_sym_with,
    STATE(7287), 1,
      aux_sym_compound_type_repeat1,
    STATE(8613), 1,
      sym__refinement,
    STATE(8637), 1,
      sym_template_body,
    STATE(4816), 2,
      sym_comment,
      sym_block_comment,
    STATE(8569), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [253436] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8913), 1,
      anon_sym_COLON,
    ACTIONS(8915), 1,
      anon_sym_LBRACE,
    ACTIONS(8917), 1,
      anon_sym_with,
    STATE(7289), 1,
      aux_sym_compound_type_repeat1,
    STATE(9690), 1,
      sym__refinement,
    STATE(9705), 1,
      sym_template_body,
    STATE(4817), 2,
      sym_comment,
      sym_block_comment,
    STATE(9704), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [253494] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8919), 1,
      anon_sym_with,
    STATE(5297), 1,
      aux_sym_compound_type_repeat1,
    STATE(9043), 1,
      sym_template_body,
    STATE(9045), 1,
      sym__refinement,
    STATE(9451), 1,
      sym_arguments,
    STATE(4818), 2,
      sym_comment,
      sym_block_comment,
    STATE(9114), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [253550] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8921), 1,
      anon_sym_LBRACK,
    ACTIONS(8923), 1,
      anon_sym_LPAREN,
    ACTIONS(8925), 1,
      anon_sym_POUND,
    STATE(5652), 1,
      aux_sym_annotation_repeat1,
    STATE(6742), 1,
      sym_type_arguments,
    STATE(7476), 1,
      sym_arguments,
    STATE(4819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [253606] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253652] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253696] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8463), 1,
      anon_sym_AT,
    STATE(5081), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5788), 1,
      sym_annotation,
    STATE(4822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [253746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253790] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253834] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253878] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253922] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [253968] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8734), 1,
      anon_sym_DOT,
    ACTIONS(8933), 1,
      anon_sym_EQ_GT,
    STATE(4828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254016] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254060] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8829), 1,
      anon_sym_LBRACK,
    ACTIONS(8835), 1,
      anon_sym_POUND,
    ACTIONS(8935), 1,
      anon_sym_LPAREN,
    STATE(5619), 1,
      aux_sym_annotation_repeat1,
    STATE(6115), 1,
      sym_type_arguments,
    STATE(7462), 1,
      sym_arguments,
    STATE(4830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [254116] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8913), 1,
      anon_sym_COLON,
    ACTIONS(8915), 1,
      anon_sym_LBRACE,
    ACTIONS(8917), 1,
      anon_sym_with,
    STATE(4817), 1,
      aux_sym_compound_type_repeat1,
    STATE(9701), 1,
      sym__refinement,
    STATE(9705), 1,
      sym_template_body,
    STATE(4831), 2,
      sym_comment,
      sym_block_comment,
    STATE(9704), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [254174] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254218] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8937), 1,
      anon_sym_COLON,
    ACTIONS(8939), 1,
      anon_sym_LBRACE,
    ACTIONS(8941), 1,
      anon_sym_with,
    STATE(4839), 1,
      aux_sym_compound_type_repeat1,
    STATE(9736), 1,
      sym__refinement,
    STATE(9738), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4833), 2,
      sym_comment,
      sym_block_comment,
    STATE(9675), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [254282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254326] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8943), 1,
      anon_sym_LBRACK,
    ACTIONS(8945), 1,
      anon_sym_AT,
    ACTIONS(8947), 1,
      anon_sym_LPAREN,
    ACTIONS(8949), 1,
      anon_sym_POUND,
    STATE(6322), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6889), 1,
      sym_type_arguments,
    STATE(7852), 1,
      sym_annotation,
    STATE(8971), 1,
      sym_arguments,
    STATE(4835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [254386] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254430] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254474] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8819), 1,
      anon_sym_DOT,
    ACTIONS(8951), 1,
      anon_sym_EQ_GT,
    STATE(4838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254522] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8937), 1,
      anon_sym_COLON,
    ACTIONS(8939), 1,
      anon_sym_LBRACE,
    ACTIONS(8941), 1,
      anon_sym_with,
    STATE(7274), 1,
      aux_sym_compound_type_repeat1,
    STATE(9731), 1,
      sym__refinement,
    STATE(9738), 1,
      sym_template_body,
    STATE(4839), 2,
      sym_comment,
      sym_block_comment,
    STATE(9675), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [254580] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254624] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254668] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254712] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8880), 1,
      anon_sym_EQ_GT,
    STATE(4843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254758] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8953), 1,
      anon_sym_COLON,
    ACTIONS(8955), 1,
      anon_sym_LBRACE,
    ACTIONS(8957), 1,
      anon_sym_with,
    STATE(4898), 1,
      aux_sym_compound_type_repeat1,
    STATE(9715), 1,
      sym__refinement,
    STATE(9728), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4844), 2,
      sym_comment,
      sym_block_comment,
    STATE(9710), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7882), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [254822] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8959), 1,
      anon_sym_AT,
    STATE(5675), 1,
      sym_annotation,
    STATE(4845), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [254870] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8962), 1,
      anon_sym_LBRACK,
    ACTIONS(8964), 1,
      anon_sym_LPAREN,
    ACTIONS(8966), 1,
      anon_sym_POUND,
    STATE(5692), 1,
      aux_sym_annotation_repeat1,
    STATE(6513), 1,
      sym_type_arguments,
    STATE(7151), 1,
      sym_arguments,
    STATE(4846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [254926] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8937), 1,
      anon_sym_COLON,
    ACTIONS(8939), 1,
      anon_sym_LBRACE,
    ACTIONS(8941), 1,
      anon_sym_with,
    STATE(4839), 1,
      aux_sym_compound_type_repeat1,
    STATE(9736), 1,
      sym__refinement,
    STATE(9738), 1,
      sym_template_body,
    STATE(4847), 2,
      sym_comment,
      sym_block_comment,
    STATE(9675), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [254984] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255028] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8968), 1,
      anon_sym_LPAREN,
    STATE(5592), 1,
      sym_arguments,
    STATE(4849), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [255076] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255120] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255164] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255208] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8971), 1,
      anon_sym_COLON,
    ACTIONS(8974), 1,
      anon_sym_LBRACE,
    STATE(6485), 1,
      sym_template_body,
    STATE(4853), 2,
      sym_comment,
      sym_block_comment,
    STATE(6152), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 16,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255260] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8591), 1,
      anon_sym_LPAREN,
    STATE(4849), 1,
      aux_sym_annotation_repeat1,
    STATE(5592), 1,
      sym_arguments,
    STATE(4854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [255310] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8977), 1,
      anon_sym_AT,
    STATE(5616), 1,
      sym_annotation,
    STATE(4855), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [255402] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255446] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8984), 1,
      anon_sym_with,
    STATE(4858), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255492] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255536] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255580] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255624] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255668] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255712] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255756] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255800] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8987), 1,
      anon_sym_AT,
    STATE(5772), 1,
      sym_annotation,
    STATE(4866), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [255848] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8715), 1,
      anon_sym_LBRACK,
    ACTIONS(8721), 1,
      anon_sym_POUND,
    ACTIONS(8990), 1,
      anon_sym_LPAREN,
    STATE(5649), 1,
      aux_sym_annotation_repeat1,
    STATE(6549), 1,
      sym_type_arguments,
    STATE(7009), 1,
      sym_arguments,
    STATE(4867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [255904] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255948] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [255992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256036] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8992), 1,
      anon_sym_LBRACK,
    ACTIONS(8994), 1,
      anon_sym_LPAREN,
    ACTIONS(8996), 1,
      anon_sym_POUND,
    STATE(6352), 1,
      sym_type_arguments,
    STATE(6712), 1,
      aux_sym_annotation_repeat1,
    STATE(8202), 1,
      sym_arguments,
    STATE(4871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [256092] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256136] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8597), 1,
      anon_sym_LPAREN,
    STATE(4889), 1,
      aux_sym_annotation_repeat1,
    STATE(5775), 1,
      sym_arguments,
    STATE(4873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [256186] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256230] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256318] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256362] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256406] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [256452] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [256498] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256542] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256586] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8658), 1,
      anon_sym_LPAREN,
    ACTIONS(8998), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4883), 2,
      sym_comment,
      sym_block_comment,
    STATE(8261), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [256644] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [256688] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [256732] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9000), 1,
      anon_sym_LBRACK,
    ACTIONS(9002), 1,
      anon_sym_LPAREN,
    ACTIONS(9004), 1,
      anon_sym_POUND,
    STATE(5528), 1,
      aux_sym_annotation_repeat1,
    STATE(6423), 1,
      sym_type_arguments,
    STATE(6856), 1,
      sym_arguments,
    STATE(4886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [256788] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [256832] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [256876] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9006), 1,
      anon_sym_LPAREN,
    STATE(5775), 1,
      sym_arguments,
    STATE(4889), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [256924] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [256968] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [257012] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [257056] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8141), 1,
      sym__interpolated_multiline_string_start,
    STATE(6455), 1,
      sym_interpolated_string,
    STATE(15246), 1,
      sym__interpolated_string_start,
    ACTIONS(9009), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [257110] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9011), 1,
      anon_sym_LPAREN,
    STATE(5899), 1,
      sym_arguments,
    STATE(4894), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [257158] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257202] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8636), 1,
      anon_sym_AT,
    STATE(4993), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5714), 1,
      sym_annotation,
    STATE(4896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257252] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [257296] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8953), 1,
      anon_sym_COLON,
    ACTIONS(8955), 1,
      anon_sym_LBRACE,
    ACTIONS(8957), 1,
      anon_sym_with,
    STATE(6896), 1,
      aux_sym_compound_type_repeat1,
    STATE(9657), 1,
      sym__refinement,
    STATE(9728), 1,
      sym_template_body,
    STATE(4898), 2,
      sym_comment,
      sym_block_comment,
    STATE(9710), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257354] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [257398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257442] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8851), 1,
      anon_sym_LBRACK,
    ACTIONS(8857), 1,
      anon_sym_POUND,
    ACTIONS(9014), 1,
      anon_sym_LPAREN,
    STATE(5791), 1,
      aux_sym_annotation_repeat1,
    STATE(6550), 1,
      sym_type_arguments,
    STATE(7463), 1,
      sym_arguments,
    STATE(4901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [257498] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(908), 1,
      anon_sym_LBRACE,
    ACTIONS(7700), 1,
      anon_sym_LPAREN,
    ACTIONS(8175), 1,
      anon_sym_DOT,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9016), 1,
      sym__alpha_identifier,
    ACTIONS(9024), 1,
      anon_sym_EQ,
    ACTIONS(9026), 1,
      sym__backquoted_id,
    ACTIONS(9028), 1,
      sym_operator_identifier,
    STATE(579), 1,
      sym_identifier,
    STATE(3987), 1,
      sym__soft_identifier,
    STATE(4902), 2,
      sym_comment,
      sym_block_comment,
    STATE(5647), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [257566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257610] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9030), 1,
      anon_sym_AT,
    STATE(5551), 1,
      sym_annotation,
    STATE(4904), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257658] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9033), 1,
      anon_sym_AT,
    STATE(5799), 1,
      sym_annotation,
    STATE(4905), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257706] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9036), 1,
      anon_sym_DOT,
    STATE(4906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [257752] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9038), 1,
      sym__interpolated_multiline_string_start,
    STATE(8542), 1,
      sym_interpolated_string,
    STATE(16331), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [257806] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8614), 1,
      anon_sym_LPAREN,
    STATE(4894), 1,
      aux_sym_annotation_repeat1,
    STATE(5899), 1,
      sym_arguments,
    STATE(4908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [257856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257900] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [257944] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9040), 1,
      anon_sym_COLON,
    ACTIONS(9042), 1,
      anon_sym_LBRACE,
    ACTIONS(9044), 1,
      anon_sym_with,
    STATE(4962), 1,
      aux_sym_compound_type_repeat1,
    STATE(9830), 1,
      sym__refinement,
    STATE(9831), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4911), 2,
      sym_comment,
      sym_block_comment,
    STATE(9621), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [258008] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258052] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9046), 1,
      anon_sym_LBRACK,
    ACTIONS(9048), 1,
      anon_sym_AT,
    ACTIONS(9050), 1,
      anon_sym_LPAREN,
    ACTIONS(9052), 1,
      anon_sym_POUND,
    STATE(6277), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7184), 1,
      sym_type_arguments,
    STATE(7538), 1,
      sym_annotation,
    STATE(9019), 1,
      sym_arguments,
    STATE(4913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [258112] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9054), 1,
      anon_sym_DOT,
    STATE(4914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258158] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8066), 1,
      sym__interpolated_multiline_string_start,
    STATE(6183), 1,
      sym_interpolated_string,
    STATE(16163), 1,
      sym__interpolated_string_start,
    ACTIONS(9056), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258212] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258256] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9058), 1,
      anon_sym_LBRACK,
    ACTIONS(9060), 1,
      anon_sym_LPAREN,
    ACTIONS(9062), 1,
      anon_sym_POUND,
    STATE(5811), 1,
      aux_sym_annotation_repeat1,
    STATE(6133), 1,
      sym_type_arguments,
    STATE(6903), 1,
      sym_arguments,
    STATE(4917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [258312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [258356] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8066), 1,
      sym__interpolated_multiline_string_start,
    STATE(6183), 1,
      sym_interpolated_string,
    STATE(16163), 1,
      sym__interpolated_string_start,
    ACTIONS(9064), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [258410] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8658), 1,
      anon_sym_LPAREN,
    ACTIONS(8998), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4920), 2,
      sym_comment,
      sym_block_comment,
    STATE(8261), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258466] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9066), 1,
      sym__interpolated_multiline_string_start,
    STATE(8410), 1,
      sym_interpolated_string,
    STATE(15587), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [258520] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258564] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9068), 1,
      anon_sym_COLON,
    ACTIONS(9071), 1,
      anon_sym_LBRACE,
    STATE(6340), 1,
      sym_template_body,
    STATE(4923), 2,
      sym_comment,
      sym_block_comment,
    STATE(6651), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 16,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258616] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258660] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258704] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258750] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(908), 1,
      anon_sym_LBRACE,
    ACTIONS(7700), 1,
      anon_sym_LPAREN,
    ACTIONS(8175), 1,
      anon_sym_DOT,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9016), 1,
      sym__alpha_identifier,
    ACTIONS(9026), 1,
      sym__backquoted_id,
    ACTIONS(9028), 1,
      sym_operator_identifier,
    ACTIONS(9078), 1,
      anon_sym_EQ,
    STATE(579), 1,
      sym_identifier,
    STATE(3987), 1,
      sym__soft_identifier,
    STATE(4927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(5647), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(9022), 7,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [258818] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1168), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8513), 1,
      anon_sym_LPAREN,
    ACTIONS(9080), 1,
      anon_sym_DOT,
    ACTIONS(9082), 1,
      sym_operator_identifier,
    STATE(1740), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4928), 2,
      sym_comment,
      sym_block_comment,
    STATE(7711), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8309), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [258886] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258930] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [258974] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259062] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259106] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8543), 1,
      anon_sym_AT,
    STATE(4866), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5772), 1,
      sym_annotation,
    STATE(4934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [259156] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9084), 1,
      anon_sym_LPAREN,
    STATE(5919), 1,
      sym_arguments,
    STATE(4935), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259204] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259248] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8829), 1,
      anon_sym_LBRACK,
    ACTIONS(8831), 1,
      anon_sym_AT,
    ACTIONS(8835), 1,
      anon_sym_POUND,
    STATE(5595), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6115), 1,
      sym_type_arguments,
    STATE(7156), 1,
      sym_annotation,
    STATE(4937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [259304] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9087), 1,
      anon_sym_COLON,
    ACTIONS(9089), 1,
      anon_sym_LBRACE,
    ACTIONS(9091), 1,
      anon_sym_with,
    STATE(4942), 1,
      aux_sym_compound_type_repeat1,
    STATE(9689), 1,
      sym__refinement,
    STATE(9904), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4938), 2,
      sym_comment,
      sym_block_comment,
    STATE(9665), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(7882), 6,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [259368] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259412] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9093), 1,
      anon_sym_with,
    STATE(5470), 1,
      aux_sym_compound_type_repeat1,
    STATE(9269), 1,
      sym_template_body,
    STATE(9280), 1,
      sym__refinement,
    STATE(9503), 1,
      sym_arguments,
    STATE(4940), 2,
      sym_comment,
      sym_block_comment,
    STATE(8992), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [259468] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259512] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9087), 1,
      anon_sym_COLON,
    ACTIONS(9089), 1,
      anon_sym_LBRACE,
    ACTIONS(9091), 1,
      anon_sym_with,
    STATE(7408), 1,
      aux_sym_compound_type_repeat1,
    STATE(9739), 1,
      sym__refinement,
    STATE(9904), 1,
      sym_template_body,
    STATE(4942), 2,
      sym_comment,
      sym_block_comment,
    STATE(9665), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [259570] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9095), 1,
      anon_sym_DOT,
    STATE(4943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259616] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259660] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259704] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [259748] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259792] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [259836] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [259880] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [259924] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9097), 1,
      sym__interpolated_multiline_string_start,
    STATE(8323), 1,
      sym_interpolated_string,
    STATE(16360), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [259978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260022] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260066] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(8913), 1,
      anon_sym_COLON,
    ACTIONS(8915), 1,
      anon_sym_LBRACE,
    ACTIONS(8917), 1,
      anon_sym_with,
    STATE(4817), 1,
      aux_sym_compound_type_repeat1,
    STATE(9701), 1,
      sym__refinement,
    STATE(9705), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4954), 2,
      sym_comment,
      sym_block_comment,
    STATE(9704), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [260130] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9040), 1,
      anon_sym_COLON,
    ACTIONS(9042), 1,
      anon_sym_LBRACE,
    ACTIONS(9044), 1,
      anon_sym_with,
    STATE(4962), 1,
      aux_sym_compound_type_repeat1,
    STATE(9830), 1,
      sym__refinement,
    STATE(9831), 1,
      sym_template_body,
    STATE(4955), 2,
      sym_comment,
      sym_block_comment,
    STATE(9621), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [260188] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260232] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260276] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260320] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8632), 1,
      anon_sym_LPAREN,
    STATE(4963), 1,
      aux_sym_annotation_repeat1,
    STATE(5897), 1,
      sym_arguments,
    STATE(4959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260370] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260414] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8845), 1,
      sym__interpolated_multiline_string_start,
    STATE(7712), 1,
      sym_interpolated_string,
    STATE(15736), 1,
      sym__interpolated_string_start,
    ACTIONS(9099), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [260468] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9040), 1,
      anon_sym_COLON,
    ACTIONS(9042), 1,
      anon_sym_LBRACE,
    ACTIONS(9044), 1,
      anon_sym_with,
    STATE(7207), 1,
      aux_sym_compound_type_repeat1,
    STATE(9826), 1,
      sym__refinement,
    STATE(9831), 1,
      sym_template_body,
    STATE(4962), 2,
      sym_comment,
      sym_block_comment,
    STATE(9621), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [260526] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9101), 1,
      anon_sym_LPAREN,
    STATE(5897), 1,
      sym_arguments,
    STATE(4963), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260574] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260618] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9104), 1,
      anon_sym_with,
    STATE(5181), 1,
      aux_sym_compound_type_repeat1,
    STATE(8971), 1,
      sym_arguments,
    STATE(9397), 1,
      sym_template_body,
    STATE(9400), 1,
      sym__refinement,
    STATE(4965), 2,
      sym_comment,
      sym_block_comment,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [260674] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260718] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9106), 1,
      anon_sym_COLON,
    ACTIONS(9108), 1,
      anon_sym_LBRACE,
    ACTIONS(9110), 1,
      anon_sym_with,
    STATE(7095), 1,
      aux_sym_compound_type_repeat1,
    STATE(9996), 1,
      sym__refinement,
    STATE(9999), 1,
      sym_template_body,
    STATE(4967), 2,
      sym_comment,
      sym_block_comment,
    STATE(9788), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [260776] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8640), 1,
      anon_sym_AT,
    STATE(4905), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5799), 1,
      sym_annotation,
    STATE(4968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260826] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260870] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9106), 1,
      anon_sym_COLON,
    ACTIONS(9108), 1,
      anon_sym_LBRACE,
    ACTIONS(9110), 1,
      anon_sym_with,
    STATE(4967), 1,
      aux_sym_compound_type_repeat1,
    STATE(9938), 1,
      sym__refinement,
    STATE(9999), 1,
      sym_template_body,
    STATE(4970), 2,
      sym_comment,
      sym_block_comment,
    STATE(9788), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [260928] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8141), 1,
      sym__interpolated_multiline_string_start,
    STATE(6455), 1,
      sym_interpolated_string,
    STATE(15246), 1,
      sym__interpolated_string_start,
    ACTIONS(9112), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [260982] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8953), 1,
      anon_sym_COLON,
    ACTIONS(8955), 1,
      anon_sym_LBRACE,
    ACTIONS(8957), 1,
      anon_sym_with,
    STATE(4898), 1,
      aux_sym_compound_type_repeat1,
    STATE(9715), 1,
      sym__refinement,
    STATE(9728), 1,
      sym_template_body,
    STATE(4972), 2,
      sym_comment,
      sym_block_comment,
    STATE(9710), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261040] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8229), 1,
      anon_sym_AT,
    STATE(4845), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5675), 1,
      sym_annotation,
    STATE(4973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261090] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261134] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8865), 1,
      anon_sym_LBRACK,
    ACTIONS(8867), 1,
      anon_sym_AT,
    ACTIONS(8871), 1,
      anon_sym_POUND,
    STATE(6015), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6397), 1,
      sym_type_arguments,
    STATE(7429), 1,
      sym_annotation,
    STATE(4975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [261190] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261234] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9114), 1,
      anon_sym_DOT,
    STATE(4977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261280] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261326] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9116), 1,
      anon_sym_LPAREN,
    STATE(6096), 1,
      sym_arguments,
    STATE(4979), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261374] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261418] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(4981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [261464] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9119), 1,
      anon_sym_with,
    STATE(4982), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261510] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261554] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9122), 1,
      anon_sym_DOT,
    STATE(4984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261600] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9124), 1,
      anon_sym_LBRACK,
    ACTIONS(9126), 1,
      anon_sym_LPAREN,
    ACTIONS(9128), 1,
      anon_sym_POUND,
    STATE(6094), 1,
      aux_sym_annotation_repeat1,
    STATE(6745), 1,
      sym_type_arguments,
    STATE(7054), 1,
      sym_arguments,
    STATE(4985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [261656] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8669), 1,
      anon_sym_LPAREN,
    STATE(4979), 1,
      aux_sym_annotation_repeat1,
    STATE(6096), 1,
      sym_arguments,
    STATE(4986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261706] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9130), 1,
      anon_sym_LBRACK,
    ACTIONS(9132), 1,
      anon_sym_AT,
    ACTIONS(9134), 1,
      anon_sym_LPAREN,
    ACTIONS(9136), 1,
      anon_sym_POUND,
    STATE(6488), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7447), 1,
      sym_type_arguments,
    STATE(7653), 1,
      sym_annotation,
    STATE(9451), 1,
      sym_arguments,
    STATE(4987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [261766] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8537), 1,
      anon_sym_LPAREN,
    ACTIONS(9138), 1,
      anon_sym_DOT,
    ACTIONS(9140), 1,
      sym_operator_identifier,
    STATE(1813), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(4988), 2,
      sym_comment,
      sym_block_comment,
    STATE(7668), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [261834] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [261878] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [261922] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9142), 1,
      anon_sym_LBRACK,
    ACTIONS(9144), 1,
      anon_sym_LPAREN,
    ACTIONS(9146), 1,
      anon_sym_POUND,
    STATE(6066), 1,
      aux_sym_annotation_repeat1,
    STATE(6603), 1,
      sym_type_arguments,
    STATE(7080), 1,
      sym_arguments,
    STATE(4991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [261978] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8759), 1,
      anon_sym_with,
    STATE(7187), 1,
      aux_sym_compound_type_repeat1,
    STATE(8767), 1,
      sym__refinement,
    STATE(8779), 1,
      sym_template_body,
    STATE(4992), 2,
      sym_comment,
      sym_block_comment,
    STATE(8733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [262032] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9148), 1,
      anon_sym_AT,
    STATE(5714), 1,
      sym_annotation,
    STATE(4993), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262080] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8789), 1,
      anon_sym_LBRACK,
    ACTIONS(8793), 1,
      anon_sym_POUND,
    ACTIONS(9151), 1,
      anon_sym_AT,
    STATE(5633), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5745), 1,
      sym_type_arguments,
    STATE(7245), 1,
      sym_annotation,
    STATE(4994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [262136] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262180] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262268] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262312] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(7976), 1,
      sym__interpolated_multiline_string_start,
    STATE(5898), 1,
      sym_interpolated_string,
    STATE(16176), 1,
      sym__interpolated_string_start,
    ACTIONS(9153), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(4999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [262366] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262410] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262454] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262498] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9155), 1,
      anon_sym_DOT,
    STATE(5003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [262544] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262588] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9157), 1,
      anon_sym_LBRACK,
    ACTIONS(9159), 1,
      anon_sym_AT,
    ACTIONS(9161), 1,
      anon_sym_LPAREN,
    ACTIONS(9163), 1,
      anon_sym_POUND,
    STATE(6558), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6979), 1,
      sym_type_arguments,
    STATE(8229), 1,
      sym_annotation,
    STATE(9503), 1,
      sym_arguments,
    STATE(5005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [262648] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9165), 1,
      anon_sym_LPAREN,
    STATE(5940), 1,
      sym_arguments,
    STATE(5006), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [262696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262740] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262784] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8652), 1,
      anon_sym_LPAREN,
    STATE(5006), 1,
      aux_sym_annotation_repeat1,
    STATE(5940), 1,
      sym_arguments,
    STATE(5009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [262834] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [262878] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9168), 1,
      anon_sym_DOT,
    STATE(5011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [262924] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8904), 1,
      anon_sym_LBRACK,
    ACTIONS(8908), 1,
      anon_sym_POUND,
    ACTIONS(9170), 1,
      anon_sym_AT,
    STATE(5708), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5852), 1,
      sym_type_arguments,
    STATE(6786), 1,
      sym_annotation,
    STATE(5012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [262980] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [263024] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263068] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263112] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8726), 1,
      anon_sym_LBRACK,
    ACTIONS(8730), 1,
      anon_sym_POUND,
    ACTIONS(9172), 1,
      anon_sym_AT,
    STATE(5683), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6038), 1,
      sym_type_arguments,
    STATE(7277), 1,
      sym_annotation,
    STATE(5016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [263168] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9174), 1,
      anon_sym_LPAREN,
    STATE(5986), 1,
      sym_arguments,
    STATE(5017), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263216] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263260] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263304] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8644), 1,
      anon_sym_LPAREN,
    STATE(5017), 1,
      aux_sym_annotation_repeat1,
    STATE(5986), 1,
      sym_arguments,
    STATE(5020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263354] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263398] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9177), 1,
      anon_sym_COLON,
    ACTIONS(9179), 1,
      anon_sym_LBRACE,
    ACTIONS(9181), 1,
      anon_sym_with,
    STATE(7446), 1,
      aux_sym_compound_type_repeat1,
    STATE(9687), 1,
      sym_template_body,
    STATE(9724), 1,
      sym__refinement,
    STATE(5022), 2,
      sym_comment,
      sym_block_comment,
    STATE(9917), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [263456] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9177), 1,
      anon_sym_COLON,
    ACTIONS(9179), 1,
      anon_sym_LBRACE,
    ACTIONS(9181), 1,
      anon_sym_with,
    STATE(5022), 1,
      aux_sym_compound_type_repeat1,
    STATE(9687), 1,
      sym_template_body,
    STATE(9688), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5023), 2,
      sym_comment,
      sym_block_comment,
    STATE(9917), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [263520] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9106), 1,
      anon_sym_COLON,
    ACTIONS(9108), 1,
      anon_sym_LBRACE,
    ACTIONS(9110), 1,
      anon_sym_with,
    STATE(4967), 1,
      aux_sym_compound_type_repeat1,
    STATE(9938), 1,
      sym__refinement,
    STATE(9999), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5024), 2,
      sym_comment,
      sym_block_comment,
    STATE(9788), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [263584] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8715), 1,
      anon_sym_LBRACK,
    ACTIONS(8717), 1,
      anon_sym_AT,
    ACTIONS(8721), 1,
      anon_sym_POUND,
    STATE(6048), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6549), 1,
      sym_type_arguments,
    STATE(7249), 1,
      sym_annotation,
    STATE(5025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [263640] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [263684] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263730] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263774] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263862] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263906] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [263950] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9177), 1,
      anon_sym_COLON,
    ACTIONS(9179), 1,
      anon_sym_LBRACE,
    ACTIONS(9181), 1,
      anon_sym_with,
    STATE(5022), 1,
      aux_sym_compound_type_repeat1,
    STATE(9687), 1,
      sym_template_body,
    STATE(9688), 1,
      sym__refinement,
    STATE(5033), 2,
      sym_comment,
      sym_block_comment,
    STATE(9917), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264008] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8618), 1,
      sym__interpolated_multiline_string_start,
    STATE(7397), 1,
      sym_interpolated_string,
    STATE(16007), 1,
      sym__interpolated_string_start,
    ACTIONS(9183), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264062] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9087), 1,
      anon_sym_COLON,
    ACTIONS(9089), 1,
      anon_sym_LBRACE,
    ACTIONS(9091), 1,
      anon_sym_with,
    STATE(4942), 1,
      aux_sym_compound_type_repeat1,
    STATE(9689), 1,
      sym__refinement,
    STATE(9904), 1,
      sym_template_body,
    STATE(5035), 2,
      sym_comment,
      sym_block_comment,
    STATE(9665), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [264120] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9185), 1,
      anon_sym_AT,
    STATE(5564), 1,
      sym_annotation,
    STATE(5036), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264168] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9188), 1,
      anon_sym_LBRACK,
    ACTIONS(9190), 1,
      anon_sym_LPAREN,
    ACTIONS(9192), 1,
      anon_sym_POUND,
    STATE(6116), 1,
      sym_type_arguments,
    STATE(6480), 1,
      aux_sym_annotation_repeat1,
    STATE(7857), 1,
      sym_arguments,
    STATE(5037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [264268] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 22,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264356] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264400] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8537), 1,
      anon_sym_LPAREN,
    ACTIONS(9138), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5042), 2,
      sym_comment,
      sym_block_comment,
    STATE(7668), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264458] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8845), 1,
      sym__interpolated_multiline_string_start,
    STATE(7712), 1,
      sym_interpolated_string,
    STATE(15736), 1,
      sym__interpolated_string_start,
    ACTIONS(9194), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264512] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1168), 1,
      anon_sym_LBRACE,
    ACTIONS(8513), 1,
      anon_sym_LPAREN,
    ACTIONS(9080), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5044), 2,
      sym_comment,
      sym_block_comment,
    STATE(7711), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [264568] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8781), 1,
      anon_sym_EQ_GT,
    STATE(5045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264614] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264658] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8827), 1,
      anon_sym_with,
    STATE(6895), 1,
      aux_sym_compound_type_repeat1,
    STATE(8583), 1,
      sym_template_body,
    STATE(8592), 1,
      sym__refinement,
    STATE(5047), 2,
      sym_comment,
      sym_block_comment,
    STATE(8689), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [264712] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9196), 1,
      anon_sym_LBRACK,
    ACTIONS(9198), 1,
      anon_sym_LPAREN,
    ACTIONS(9200), 1,
      anon_sym_POUND,
    STATE(5816), 1,
      aux_sym_annotation_repeat1,
    STATE(6312), 1,
      sym_type_arguments,
    STATE(7146), 1,
      sym_arguments,
    STATE(5048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264812] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264856] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9202), 1,
      anon_sym_with,
    STATE(5326), 1,
      aux_sym_compound_type_repeat1,
    STATE(9019), 1,
      sym_arguments,
    STATE(9565), 1,
      sym__refinement,
    STATE(9567), 1,
      sym_template_body,
    STATE(5051), 2,
      sym_comment,
      sym_block_comment,
    STATE(9188), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [264912] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8497), 1,
      anon_sym_LPAREN,
    STATE(4935), 1,
      aux_sym_annotation_repeat1,
    STATE(5919), 1,
      sym_arguments,
    STATE(5052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [264962] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8851), 1,
      anon_sym_LBRACK,
    ACTIONS(8853), 1,
      anon_sym_AT,
    ACTIONS(8857), 1,
      anon_sym_POUND,
    STATE(5698), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6550), 1,
      sym_type_arguments,
    STATE(7229), 1,
      sym_annotation,
    STATE(5053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [265018] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8353), 1,
      anon_sym_AT,
    STATE(4904), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5551), 1,
      sym_annotation,
    STATE(5054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265068] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [265112] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265156] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8865), 1,
      anon_sym_LBRACK,
    ACTIONS(8871), 1,
      anon_sym_POUND,
    ACTIONS(9204), 1,
      anon_sym_LPAREN,
    STATE(5500), 1,
      aux_sym_annotation_repeat1,
    STATE(6397), 1,
      sym_type_arguments,
    STATE(6785), 1,
      sym_arguments,
    STATE(5057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [265212] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265256] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265300] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8713), 1,
      anon_sym_DOT,
    ACTIONS(9206), 1,
      anon_sym_EQ_GT,
    STATE(5060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [265348] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8795), 1,
      anon_sym_LBRACK,
    ACTIONS(8799), 1,
      anon_sym_POUND,
    ACTIONS(9208), 1,
      anon_sym_AT,
    STATE(5736), 1,
      sym_type_arguments,
    STATE(6093), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7343), 1,
      sym_annotation,
    STATE(5061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [265404] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9210), 1,
      anon_sym_DOT,
    STATE(5062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265450] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [265494] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265538] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8581), 1,
      anon_sym_LPAREN,
    STATE(5083), 1,
      aux_sym_annotation_repeat1,
    STATE(6098), 1,
      sym_arguments,
    STATE(5065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265588] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265632] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265678] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265724] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9212), 1,
      anon_sym_LBRACK,
    ACTIONS(9214), 1,
      anon_sym_LPAREN,
    ACTIONS(9216), 1,
      anon_sym_POUND,
    STATE(5621), 1,
      aux_sym_annotation_repeat1,
    STATE(6244), 1,
      sym_type_arguments,
    STATE(7201), 1,
      sym_arguments,
    STATE(5069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [265780] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265824] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8801), 1,
      anon_sym_LBRACK,
    ACTIONS(8805), 1,
      anon_sym_POUND,
    ACTIONS(9218), 1,
      anon_sym_AT,
    STATE(5858), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5990), 1,
      sym_type_arguments,
    STATE(7345), 1,
      sym_annotation,
    STATE(5071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [265880] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [265924] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9220), 1,
      sym__interpolated_multiline_string_start,
    STATE(8549), 1,
      sym_interpolated_string,
    STATE(16193), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [265978] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9222), 1,
      anon_sym_LBRACK,
    ACTIONS(9224), 1,
      anon_sym_LPAREN,
    ACTIONS(9226), 1,
      anon_sym_POUND,
    STATE(6101), 1,
      aux_sym_annotation_repeat1,
    STATE(6163), 1,
      sym_type_arguments,
    STATE(7335), 1,
      sym_arguments,
    STATE(5074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [266034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266078] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266122] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266210] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266254] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266298] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9228), 1,
      anon_sym_AT,
    STATE(5788), 1,
      sym_annotation,
    STATE(5081), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [266346] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266390] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9231), 1,
      anon_sym_LPAREN,
    STATE(6098), 1,
      sym_arguments,
    STATE(5083), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266438] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266482] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8742), 1,
      anon_sym_LBRACK,
    ACTIONS(8746), 1,
      anon_sym_POUND,
    ACTIONS(9234), 1,
      anon_sym_AT,
    STATE(5672), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5905), 1,
      sym_type_arguments,
    STATE(7333), 1,
      sym_annotation,
    STATE(5085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [266538] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8623), 1,
      anon_sym_AT,
    STATE(4855), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5616), 1,
      sym_annotation,
    STATE(5086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266588] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [266632] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [266676] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8849), 1,
      anon_sym_with,
    STATE(7479), 1,
      aux_sym_compound_type_repeat1,
    STATE(8368), 1,
      sym__refinement,
    STATE(8392), 1,
      sym_template_body,
    STATE(5089), 2,
      sym_comment,
      sym_block_comment,
    STATE(8352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [266730] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8882), 1,
      anon_sym_LBRACK,
    ACTIONS(8886), 1,
      anon_sym_POUND,
    ACTIONS(9236), 1,
      anon_sym_AT,
    STATE(5943), 1,
      sym_type_arguments,
    STATE(6004), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7398), 1,
      sym_annotation,
    STATE(5090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [266786] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8519), 1,
      anon_sym_AT,
    STATE(5036), 1,
      aux_sym_enum_definition_repeat1,
    STATE(5564), 1,
      sym_annotation,
    STATE(5091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [266836] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1168), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8513), 1,
      anon_sym_LPAREN,
    ACTIONS(9080), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5092), 2,
      sym_comment,
      sym_block_comment,
    STATE(7711), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [266894] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACE,
    ACTIONS(8537), 1,
      anon_sym_LPAREN,
    ACTIONS(9138), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5093), 2,
      sym_comment,
      sym_block_comment,
    STATE(7668), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [266950] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [266994] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9238), 1,
      anon_sym_COLON,
    ACTIONS(9240), 1,
      anon_sym_LBRACE,
    ACTIONS(9242), 1,
      anon_sym_with,
    STATE(7757), 1,
      aux_sym_compound_type_repeat1,
    STATE(10164), 1,
      sym_template_body,
    STATE(10170), 1,
      sym__refinement,
    STATE(5095), 2,
      sym_comment,
      sym_block_comment,
    STATE(10306), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [267051] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9244), 1,
      anon_sym_DOT,
    STATE(5096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267096] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9246), 1,
      anon_sym_AT,
    STATE(6750), 1,
      sym_annotation,
    STATE(5097), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267143] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9206), 1,
      anon_sym_EQ_GT,
    STATE(5098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [267188] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8992), 1,
      anon_sym_LBRACK,
    ACTIONS(8996), 1,
      anon_sym_POUND,
    ACTIONS(9249), 1,
      anon_sym_AT,
    STATE(6352), 1,
      sym_type_arguments,
    STATE(7300), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8849), 1,
      sym_annotation,
    STATE(5099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267243] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [267288] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9251), 1,
      anon_sym_COLON,
    ACTIONS(9254), 1,
      anon_sym_LBRACE,
    STATE(6874), 1,
      sym_template_body,
    STATE(5101), 2,
      sym_comment,
      sym_block_comment,
    STATE(7070), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 15,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267339] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9257), 1,
      anon_sym_DOT,
    STATE(5102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267384] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(952), 1,
      anon_sym_LBRACE,
    ACTIONS(7842), 1,
      anon_sym_LPAREN,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8521), 1,
      anon_sym_DOT,
    ACTIONS(9259), 1,
      sym__alpha_identifier,
    ACTIONS(9263), 1,
      anon_sym_EQ,
    ACTIONS(9265), 1,
      sym__backquoted_id,
    ACTIONS(9267), 1,
      sym_operator_identifier,
    STATE(580), 1,
      sym_identifier,
    STATE(4062), 1,
      sym__soft_identifier,
    STATE(5103), 2,
      sym_comment,
      sym_block_comment,
    STATE(6473), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9261), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [267451] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9269), 1,
      anon_sym_LBRACK,
    ACTIONS(9271), 1,
      anon_sym_AT,
    ACTIONS(9273), 1,
      anon_sym_LPAREN,
    ACTIONS(9275), 1,
      anon_sym_POUND,
    STATE(7421), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(8350), 1,
      sym_annotation,
    STATE(9766), 1,
      sym_arguments,
    STATE(5104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [267510] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267553] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9066), 1,
      sym__interpolated_multiline_string_start,
    STATE(8410), 1,
      sym_interpolated_string,
    STATE(15587), 1,
      sym__interpolated_string_start,
    ACTIONS(9277), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267606] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [267649] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9279), 1,
      anon_sym_LBRACK,
    ACTIONS(9281), 1,
      anon_sym_LPAREN,
    ACTIONS(9283), 1,
      anon_sym_POUND,
    STATE(6770), 1,
      aux_sym_annotation_repeat1,
    STATE(7098), 1,
      sym_type_arguments,
    STATE(7738), 1,
      sym_arguments,
    STATE(5108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267704] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9285), 1,
      anon_sym_with,
    STATE(6047), 1,
      aux_sym_compound_type_repeat1,
    STATE(9643), 1,
      sym_arguments,
    STATE(9934), 1,
      sym_template_body,
    STATE(9935), 1,
      sym__refinement,
    STATE(5109), 2,
      sym_comment,
      sym_block_comment,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267759] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9289), 1,
      anon_sym_end,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(9293), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16680), 1,
      sym_identifier,
    STATE(5110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(850), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [267812] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9297), 1,
      anon_sym_LBRACK,
    ACTIONS(9299), 1,
      sym__backquoted_id,
    STATE(6464), 1,
      sym_access_qualifier,
    STATE(5111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9295), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267859] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9066), 1,
      sym__interpolated_multiline_string_start,
    STATE(8410), 1,
      sym_interpolated_string,
    STATE(15587), 1,
      sym__interpolated_string_start,
    ACTIONS(9301), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267912] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9000), 1,
      anon_sym_LBRACK,
    ACTIONS(9004), 1,
      anon_sym_POUND,
    ACTIONS(9303), 1,
      anon_sym_AT,
    STATE(6205), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6423), 1,
      sym_type_arguments,
    STATE(7856), 1,
      sym_annotation,
    STATE(5113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [267967] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268010] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268053] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268096] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [268139] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(952), 1,
      anon_sym_LBRACE,
    ACTIONS(7842), 1,
      anon_sym_LPAREN,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8521), 1,
      anon_sym_DOT,
    ACTIONS(9259), 1,
      sym__alpha_identifier,
    ACTIONS(9265), 1,
      sym__backquoted_id,
    ACTIONS(9267), 1,
      sym_operator_identifier,
    ACTIONS(9305), 1,
      anon_sym_EQ,
    STATE(580), 1,
      sym_identifier,
    STATE(4062), 1,
      sym__soft_identifier,
    STATE(5118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6473), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 6,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9261), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [268206] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268249] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268292] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9307), 1,
      anon_sym_COLON,
    ACTIONS(9309), 1,
      anon_sym_LBRACE,
    ACTIONS(9311), 1,
      anon_sym_with,
    STATE(7935), 1,
      aux_sym_compound_type_repeat1,
    STATE(10011), 1,
      sym_template_body,
    STATE(10252), 1,
      sym__refinement,
    STATE(5121), 2,
      sym_comment,
      sym_block_comment,
    STATE(10360), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [268349] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268392] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268435] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268478] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9317), 1,
      anon_sym_DOT,
    STATE(5125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [268523] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268566] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8567), 1,
      sym__interpolated_multiline_string_start,
    STATE(7326), 1,
      sym_interpolated_string,
    STATE(16092), 1,
      sym__interpolated_string_start,
    ACTIONS(9319), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268662] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8537), 1,
      anon_sym_LPAREN,
    ACTIONS(9138), 1,
      anon_sym_DOT,
    ACTIONS(9321), 1,
      sym__alpha_identifier,
    ACTIONS(9325), 1,
      anon_sym_EQ,
    ACTIONS(9327), 1,
      sym__backquoted_id,
    ACTIONS(9329), 1,
      sym_operator_identifier,
    STATE(585), 1,
      sym_identifier,
    STATE(4157), 1,
      sym__soft_identifier,
    STATE(5129), 2,
      sym_comment,
      sym_block_comment,
    STATE(7668), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9323), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [268729] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9331), 1,
      anon_sym_COLON,
    ACTIONS(9333), 1,
      anon_sym_LBRACE,
    ACTIONS(9335), 1,
      anon_sym_with,
    STATE(7687), 1,
      aux_sym_compound_type_repeat1,
    STATE(10320), 1,
      sym_template_body,
    STATE(10342), 1,
      sym__refinement,
    STATE(5130), 2,
      sym_comment,
      sym_block_comment,
    STATE(10124), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [268786] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268829] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268872] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(988), 1,
      anon_sym_LBRACE,
    ACTIONS(7876), 1,
      anon_sym_LPAREN,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8569), 1,
      anon_sym_DOT,
    ACTIONS(9337), 1,
      sym__alpha_identifier,
    ACTIONS(9341), 1,
      anon_sym_EQ,
    ACTIONS(9343), 1,
      sym__backquoted_id,
    ACTIONS(9345), 1,
      sym_operator_identifier,
    STATE(581), 1,
      sym_identifier,
    STATE(4080), 1,
      sym__soft_identifier,
    STATE(5133), 2,
      sym_comment,
      sym_block_comment,
    STATE(6534), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9339), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [268939] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [268982] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9097), 1,
      sym__interpolated_multiline_string_start,
    STATE(8323), 1,
      sym_interpolated_string,
    STATE(16360), 1,
      sym__interpolated_string_start,
    ACTIONS(9347), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [269035] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8625), 1,
      sym__interpolated_multiline_string_start,
    STATE(6974), 1,
      sym_interpolated_string,
    STATE(16306), 1,
      sym__interpolated_string_start,
    ACTIONS(9349), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269088] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9351), 1,
      anon_sym_AT,
    STATE(6673), 1,
      sym_annotation,
    STATE(5137), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [269135] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(988), 1,
      anon_sym_LBRACE,
    ACTIONS(7876), 1,
      anon_sym_LPAREN,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8569), 1,
      anon_sym_DOT,
    ACTIONS(9337), 1,
      sym__alpha_identifier,
    ACTIONS(9343), 1,
      sym__backquoted_id,
    ACTIONS(9345), 1,
      sym_operator_identifier,
    ACTIONS(9354), 1,
      anon_sym_EQ,
    STATE(581), 1,
      sym_identifier,
    STATE(4080), 1,
      sym__soft_identifier,
    STATE(5138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6534), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 6,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9339), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [269202] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269245] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8625), 1,
      sym__interpolated_multiline_string_start,
    STATE(6974), 1,
      sym_interpolated_string,
    STATE(16306), 1,
      sym__interpolated_string_start,
    ACTIONS(9356), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [269298] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269341] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269384] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269429] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(908), 1,
      anon_sym_LBRACE,
    ACTIONS(7700), 1,
      anon_sym_LPAREN,
    ACTIONS(8175), 1,
      anon_sym_DOT,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9016), 1,
      sym__alpha_identifier,
    ACTIONS(9026), 1,
      sym__backquoted_id,
    ACTIONS(9028), 1,
      sym_operator_identifier,
    ACTIONS(9358), 1,
      anon_sym_EQ,
    STATE(579), 1,
      sym_identifier,
    STATE(3987), 1,
      sym__soft_identifier,
    STATE(5144), 2,
      sym_comment,
      sym_block_comment,
    STATE(5647), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [269496] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [269539] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269584] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269627] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9362), 1,
      sym__interpolated_multiline_string_start,
    STATE(9516), 1,
      sym_interpolated_string,
    STATE(16367), 1,
      sym__interpolated_string_start,
    ACTIONS(9360), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [269680] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8658), 1,
      anon_sym_LPAREN,
    ACTIONS(8998), 1,
      anon_sym_DOT,
    ACTIONS(9364), 1,
      sym_operator_identifier,
    STATE(1752), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5149), 2,
      sym_comment,
      sym_block_comment,
    STATE(8261), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8309), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [269747] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8567), 1,
      sym__interpolated_multiline_string_start,
    STATE(7326), 1,
      sym_interpolated_string,
    STATE(16092), 1,
      sym__interpolated_string_start,
    ACTIONS(9366), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [269800] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269843] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    STATE(4494), 1,
      aux_sym_modifiers_repeat1,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(5152), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
    ACTIONS(9368), 10,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
  [269900] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [269943] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8797), 1,
      anon_sym_LPAREN,
    STATE(5156), 1,
      aux_sym_annotation_repeat1,
    STATE(6657), 1,
      sym_arguments,
    STATE(5154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [269992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270035] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9370), 1,
      anon_sym_LPAREN,
    STATE(6657), 1,
      sym_arguments,
    STATE(5156), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270082] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8951), 1,
      anon_sym_EQ_GT,
    STATE(5157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270127] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9373), 1,
      anon_sym_COLON,
    ACTIONS(9376), 1,
      anon_sym_LBRACE,
    STATE(7051), 1,
      sym_template_body,
    STATE(5158), 2,
      sym_comment,
      sym_block_comment,
    STATE(7186), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 7,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 16,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270221] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9379), 1,
      anon_sym_DOT,
    STATE(5160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270266] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9381), 1,
      anon_sym_COLON,
    ACTIONS(9383), 1,
      anon_sym_LBRACE,
    ACTIONS(9385), 1,
      anon_sym_with,
    STATE(5380), 1,
      aux_sym_compound_type_repeat1,
    STATE(10242), 1,
      sym__refinement,
    STATE(10243), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5161), 2,
      sym_comment,
      sym_block_comment,
    STATE(10056), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_STAR,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270329] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9331), 1,
      anon_sym_COLON,
    ACTIONS(9333), 1,
      anon_sym_LBRACE,
    ACTIONS(9335), 1,
      anon_sym_with,
    STATE(5130), 1,
      aux_sym_compound_type_repeat1,
    STATE(10320), 1,
      sym_template_body,
    STATE(10321), 1,
      sym__refinement,
    STATE(5162), 2,
      sym_comment,
      sym_block_comment,
    STATE(10124), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270386] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270429] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270472] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270515] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9387), 1,
      anon_sym_COLON,
    ACTIONS(9389), 1,
      anon_sym_LBRACE,
    ACTIONS(9391), 1,
      anon_sym_with,
    STATE(5468), 1,
      aux_sym_compound_type_repeat1,
    STATE(10049), 1,
      sym__refinement,
    STATE(10051), 1,
      sym_template_body,
    STATE(5166), 2,
      sym_comment,
      sym_block_comment,
    STATE(10139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270572] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270615] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270658] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9097), 1,
      sym__interpolated_multiline_string_start,
    STATE(8323), 1,
      sym_interpolated_string,
    STATE(16360), 1,
      sym__interpolated_string_start,
    ACTIONS(9393), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270754] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1340), 1,
      anon_sym_LBRACE,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(9395), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5171), 2,
      sym_comment,
      sym_block_comment,
    STATE(8867), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [270809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270852] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [270938] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [270981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 22,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [271024] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8066), 1,
      sym__interpolated_multiline_string_start,
    STATE(6183), 1,
      sym_interpolated_string,
    STATE(16163), 1,
      sym__interpolated_string_start,
    ACTIONS(9397), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [271077] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9399), 1,
      anon_sym_LBRACK,
    ACTIONS(9401), 1,
      anon_sym_AT,
    ACTIONS(9403), 1,
      anon_sym_LPAREN,
    ACTIONS(9405), 1,
      anon_sym_POUND,
    STATE(7368), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7692), 1,
      sym_type_arguments,
    STATE(8683), 1,
      sym_annotation,
    STATE(9643), 1,
      sym_arguments,
    STATE(5178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [271136] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9289), 1,
      anon_sym_end,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(9407), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16462), 1,
      sym_identifier,
    STATE(5179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(850), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [271189] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271234] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9104), 1,
      anon_sym_with,
    STATE(7640), 1,
      aux_sym_compound_type_repeat1,
    STATE(9397), 1,
      sym_template_body,
    STATE(9436), 1,
      sym__refinement,
    STATE(5181), 2,
      sym_comment,
      sym_block_comment,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [271287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271330] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [271373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271416] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271459] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9421), 1,
      anon_sym_COLON,
    ACTIONS(9423), 1,
      anon_sym_LBRACE,
    ACTIONS(9425), 1,
      anon_sym_with,
    STATE(5483), 1,
      aux_sym_compound_type_repeat1,
    STATE(10022), 1,
      sym_template_body,
    STATE(10023), 1,
      sym__refinement,
    STATE(5186), 2,
      sym_comment,
      sym_block_comment,
    STATE(10150), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [271516] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [271559] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271602] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9427), 1,
      sym__interpolated_multiline_string_start,
    STATE(9056), 1,
      sym_interpolated_string,
    STATE(15558), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [271655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271698] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9429), 1,
      anon_sym_LBRACK,
    ACTIONS(9431), 1,
      anon_sym_LPAREN,
    ACTIONS(9433), 1,
      anon_sym_POUND,
    STATE(6483), 1,
      aux_sym_annotation_repeat1,
    STATE(6992), 1,
      sym_type_arguments,
    STATE(7864), 1,
      sym_arguments,
    STATE(5191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [271753] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [271796] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9381), 1,
      anon_sym_COLON,
    ACTIONS(9383), 1,
      anon_sym_LBRACE,
    ACTIONS(9385), 1,
      anon_sym_with,
    STATE(5380), 1,
      aux_sym_compound_type_repeat1,
    STATE(10242), 1,
      sym__refinement,
    STATE(10243), 1,
      sym_template_body,
    STATE(5193), 2,
      sym_comment,
      sym_block_comment,
    STATE(10056), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [271853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271896] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271939] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8656), 1,
      anon_sym_AT,
    STATE(5243), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6348), 1,
      sym_annotation,
    STATE(5196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [271988] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [272031] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9387), 1,
      anon_sym_COLON,
    ACTIONS(9389), 1,
      anon_sym_LBRACE,
    ACTIONS(9391), 1,
      anon_sym_with,
    STATE(5468), 1,
      aux_sym_compound_type_repeat1,
    STATE(10049), 1,
      sym__refinement,
    STATE(10051), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5198), 2,
      sym_comment,
      sym_block_comment,
    STATE(10139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272094] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8701), 1,
      anon_sym_AT,
    STATE(5097), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6750), 1,
      sym_annotation,
    STATE(5199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [272143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272186] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [272229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [272272] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8732), 1,
      anon_sym_AT,
    STATE(5137), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6673), 1,
      sym_annotation,
    STATE(5203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272321] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1340), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(9395), 1,
      anon_sym_DOT,
    ACTIONS(9435), 1,
      sym_operator_identifier,
    STATE(1745), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5204), 2,
      sym_comment,
      sym_block_comment,
    STATE(8867), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [272388] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9289), 1,
      anon_sym_end,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(9437), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16573), 1,
      sym_identifier,
    STATE(5205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(850), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [272441] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9439), 1,
      anon_sym_COLON,
    ACTIONS(9441), 1,
      anon_sym_LBRACE,
    ACTIONS(9443), 1,
      anon_sym_with,
    STATE(5493), 1,
      aux_sym_compound_type_repeat1,
    STATE(10047), 1,
      sym_template_body,
    STATE(10048), 1,
      sym__refinement,
    STATE(5206), 2,
      sym_comment,
      sym_block_comment,
    STATE(10202), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272498] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9289), 1,
      anon_sym_end,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(9445), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16413), 1,
      sym_identifier,
    STATE(5207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(850), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [272551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272594] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272637] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9157), 1,
      anon_sym_LBRACK,
    ACTIONS(9163), 1,
      anon_sym_POUND,
    ACTIONS(9447), 1,
      anon_sym_LPAREN,
    STATE(6471), 1,
      aux_sym_annotation_repeat1,
    STATE(6979), 1,
      sym_type_arguments,
    STATE(7859), 1,
      sym_arguments,
    STATE(5210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272692] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [272778] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5554), 1,
      sym__end_marker,
    STATE(5213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [272823] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8943), 1,
      anon_sym_LBRACK,
    ACTIONS(8949), 1,
      anon_sym_POUND,
    ACTIONS(9453), 1,
      anon_sym_LPAREN,
    STATE(6390), 1,
      aux_sym_annotation_repeat1,
    STATE(6889), 1,
      sym_type_arguments,
    STATE(7764), 1,
      sym_arguments,
    STATE(5214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272878] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272921] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1340), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(9395), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5216), 2,
      sym_comment,
      sym_block_comment,
    STATE(8867), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [272978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273064] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [273107] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9421), 1,
      anon_sym_COLON,
    ACTIONS(9423), 1,
      anon_sym_LBRACE,
    ACTIONS(9425), 1,
      anon_sym_with,
    STATE(5483), 1,
      aux_sym_compound_type_repeat1,
    STATE(10022), 1,
      sym_template_body,
    STATE(10023), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5220), 2,
      sym_comment,
      sym_block_comment,
    STATE(10150), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(7882), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [273170] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9455), 1,
      anon_sym_with,
    STATE(5712), 1,
      aux_sym_compound_type_repeat1,
    STATE(9645), 1,
      sym__refinement,
    STATE(9646), 1,
      sym_template_body,
    STATE(9766), 1,
      sym_arguments,
    STATE(5221), 2,
      sym_comment,
      sym_block_comment,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7750), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273268] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9457), 1,
      anon_sym_LBRACK,
    ACTIONS(9459), 1,
      anon_sym_LPAREN,
    ACTIONS(9461), 1,
      anon_sym_POUND,
    STATE(7224), 1,
      aux_sym_annotation_repeat1,
    STATE(7253), 1,
      sym_type_arguments,
    STATE(8478), 1,
      sym_arguments,
    STATE(5223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [273323] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8837), 1,
      sym__interpolated_multiline_string_start,
    STATE(8159), 1,
      sym_interpolated_string,
    STATE(15346), 1,
      sym__interpolated_string_start,
    ACTIONS(9463), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [273376] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9465), 1,
      anon_sym_COLON,
    ACTIONS(9467), 1,
      anon_sym_LBRACE,
    ACTIONS(9469), 1,
      anon_sym_with,
    STATE(5445), 1,
      aux_sym_compound_type_repeat1,
    STATE(10067), 1,
      sym_template_body,
    STATE(10068), 1,
      sym__refinement,
    STATE(5225), 2,
      sym_comment,
      sym_block_comment,
    STATE(10217), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [273433] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1096), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8465), 1,
      anon_sym_LPAREN,
    ACTIONS(8821), 1,
      anon_sym_DOT,
    ACTIONS(9471), 1,
      sym__alpha_identifier,
    ACTIONS(9475), 1,
      anon_sym_EQ,
    ACTIONS(9477), 1,
      sym__backquoted_id,
    ACTIONS(9479), 1,
      sym_operator_identifier,
    STATE(584), 1,
      sym_identifier,
    STATE(4160), 1,
      sym__soft_identifier,
    STATE(5226), 2,
      sym_comment,
      sym_block_comment,
    STATE(7045), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9473), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [273500] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273543] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5908), 1,
      sym_arguments,
    STATE(5228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273588] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9439), 1,
      anon_sym_COLON,
    ACTIONS(9441), 1,
      anon_sym_LBRACE,
    ACTIONS(9443), 1,
      anon_sym_with,
    STATE(5493), 1,
      aux_sym_compound_type_repeat1,
    STATE(10047), 1,
      sym_template_body,
    STATE(10048), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5229), 2,
      sym_comment,
      sym_block_comment,
    STATE(10202), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [273651] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273694] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9481), 1,
      anon_sym_DOT,
    STATE(5231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273739] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1428), 1,
      anon_sym_LBRACE,
    ACTIONS(8833), 1,
      anon_sym_LPAREN,
    ACTIONS(9483), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5232), 2,
      sym_comment,
      sym_block_comment,
    STATE(8440), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8191), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273794] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [273880] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [273923] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1428), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8833), 1,
      anon_sym_LPAREN,
    ACTIONS(9483), 1,
      anon_sym_DOT,
    ACTIONS(9485), 1,
      sym_operator_identifier,
    STATE(1728), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    STATE(8440), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8309), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [273990] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274033] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9058), 1,
      anon_sym_LBRACK,
    ACTIONS(9062), 1,
      anon_sym_POUND,
    ACTIONS(9487), 1,
      anon_sym_AT,
    STATE(6133), 1,
      sym_type_arguments,
    STATE(6398), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7588), 1,
      sym_annotation,
    STATE(5238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [274088] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274131] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274174] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 10,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
      anon_sym_yield,
  [274217] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9489), 1,
      anon_sym_with,
    STATE(5242), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274262] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9492), 1,
      anon_sym_AT,
    STATE(6348), 1,
      sym_annotation,
    STATE(5243), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274352] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8141), 1,
      sym__interpolated_multiline_string_start,
    STATE(6455), 1,
      sym_interpolated_string,
    STATE(15246), 1,
      sym__interpolated_string_start,
    ACTIONS(9495), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [274405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [274491] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274534] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9222), 1,
      anon_sym_LBRACK,
    ACTIONS(9226), 1,
      anon_sym_POUND,
    ACTIONS(9497), 1,
      anon_sym_AT,
    STATE(6163), 1,
      sym_type_arguments,
    STATE(6296), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7633), 1,
      sym_annotation,
    STATE(5249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [274589] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [274632] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274718] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9465), 1,
      anon_sym_COLON,
    ACTIONS(9467), 1,
      anon_sym_LBRACE,
    ACTIONS(9469), 1,
      anon_sym_with,
    STATE(5445), 1,
      aux_sym_compound_type_repeat1,
    STATE(10067), 1,
      sym_template_body,
    STATE(10068), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5253), 2,
      sym_comment,
      sym_block_comment,
    STATE(10217), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [274781] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1428), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8833), 1,
      anon_sym_LPAREN,
    ACTIONS(9483), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5254), 2,
      sym_comment,
      sym_block_comment,
    STATE(8440), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8171), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [274838] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9499), 1,
      anon_sym_LPAREN,
    STATE(6251), 1,
      sym_arguments,
    STATE(5255), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274885] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9502), 1,
      anon_sym_with,
    STATE(5256), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [274930] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9036), 1,
      anon_sym_DOT,
    ACTIONS(9505), 1,
      anon_sym_EQ_GT,
    STATE(5257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [274977] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8906), 1,
      anon_sym_LPAREN,
    STATE(5255), 1,
      aux_sym_annotation_repeat1,
    STATE(6251), 1,
      sym_arguments,
    STATE(5258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [275026] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275069] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9331), 1,
      anon_sym_COLON,
    ACTIONS(9333), 1,
      anon_sym_LBRACE,
    ACTIONS(9335), 1,
      anon_sym_with,
    STATE(5130), 1,
      aux_sym_compound_type_repeat1,
    STATE(10320), 1,
      sym_template_body,
    STATE(10321), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5260), 2,
      sym_comment,
      sym_block_comment,
    STATE(10124), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7882), 3,
      anon_sym_while,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(7880), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275132] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9507), 1,
      anon_sym_LPAREN,
    STATE(6222), 1,
      sym_arguments,
    STATE(5261), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275179] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275222] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [275265] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275308] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8807), 1,
      anon_sym_LPAREN,
    STATE(5261), 1,
      aux_sym_annotation_repeat1,
    STATE(6222), 1,
      sym_arguments,
    STATE(5265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275357] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8962), 1,
      anon_sym_LBRACK,
    ACTIONS(8966), 1,
      anon_sym_POUND,
    ACTIONS(9510), 1,
      anon_sym_AT,
    STATE(6513), 1,
      sym_type_arguments,
    STATE(6697), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7601), 1,
      sym_annotation,
    STATE(5266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275412] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [275455] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9157), 1,
      anon_sym_LBRACK,
    ACTIONS(9159), 1,
      anon_sym_AT,
    ACTIONS(9163), 1,
      anon_sym_POUND,
    STATE(6558), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6979), 1,
      sym_type_arguments,
    STATE(8229), 1,
      sym_annotation,
    STATE(5268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275510] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9512), 1,
      anon_sym_AT,
    STATE(6190), 1,
      sym_annotation,
    STATE(5269), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275600] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [275686] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [275729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275772] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275858] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [275901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275944] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [275987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [276030] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [276075] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [276118] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [276161] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [276204] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [276247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276290] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276333] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276376] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276419] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [276462] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [276505] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276550] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [276679] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9124), 1,
      anon_sym_LBRACK,
    ACTIONS(9128), 1,
      anon_sym_POUND,
    ACTIONS(9523), 1,
      anon_sym_AT,
    STATE(6392), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6745), 1,
      sym_type_arguments,
    STATE(8230), 1,
      sym_annotation,
    STATE(5296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [276734] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8919), 1,
      anon_sym_with,
    STATE(7848), 1,
      aux_sym_compound_type_repeat1,
    STATE(9043), 1,
      sym_template_body,
    STATE(9154), 1,
      sym__refinement,
    STATE(5297), 2,
      sym_comment,
      sym_block_comment,
    STATE(9114), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [276787] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [276830] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [276873] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1572), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8869), 1,
      anon_sym_LPAREN,
    ACTIONS(9525), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5300), 2,
      sym_comment,
      sym_block_comment,
    STATE(8709), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [276930] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [276975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277061] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277104] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277147] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277192] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9527), 1,
      anon_sym_DOT,
    STATE(5307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [277237] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9529), 1,
      anon_sym_AT,
    STATE(6124), 1,
      sym_annotation,
    STATE(5308), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277284] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277327] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9238), 1,
      anon_sym_COLON,
    ACTIONS(9240), 1,
      anon_sym_LBRACE,
    ACTIONS(9242), 1,
      anon_sym_with,
    STATE(5095), 1,
      aux_sym_compound_type_repeat1,
    STATE(10164), 1,
      sym_template_body,
    STATE(10165), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5310), 2,
      sym_comment,
      sym_block_comment,
    STATE(10306), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(7882), 5,
      anon_sym_while,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [277390] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9142), 1,
      anon_sym_LBRACK,
    ACTIONS(9146), 1,
      anon_sym_POUND,
    ACTIONS(9532), 1,
      anon_sym_AT,
    STATE(6425), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6603), 1,
      sym_type_arguments,
    STATE(8272), 1,
      sym_annotation,
    STATE(5311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277445] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277488] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9538), 1,
      anon_sym_LPAREN,
    STATE(6161), 1,
      sym_arguments,
    STATE(5313), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [277535] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8803), 1,
      anon_sym_LPAREN,
    STATE(5313), 1,
      aux_sym_annotation_repeat1,
    STATE(6161), 1,
      sym_arguments,
    STATE(5314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [277584] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277627] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277670] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [277713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [277756] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9196), 1,
      anon_sym_LBRACK,
    ACTIONS(9200), 1,
      anon_sym_POUND,
    ACTIONS(9541), 1,
      anon_sym_AT,
    STATE(6312), 1,
      sym_type_arguments,
    STATE(6515), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8246), 1,
      sym_annotation,
    STATE(5319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [277811] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [277856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277942] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [277987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278030] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9543), 1,
      anon_sym_LPAREN,
    STATE(6220), 1,
      sym_arguments,
    STATE(5325), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [278077] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9202), 1,
      anon_sym_with,
    STATE(7619), 1,
      aux_sym_compound_type_repeat1,
    STATE(9531), 1,
      sym__refinement,
    STATE(9567), 1,
      sym_template_body,
    STATE(5326), 2,
      sym_comment,
      sym_block_comment,
    STATE(9188), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278130] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [278216] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [278302] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8825), 1,
      anon_sym_AT,
    STATE(5269), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6190), 1,
      sym_annotation,
    STATE(5331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278351] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [278396] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278439] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8744), 1,
      anon_sym_LPAREN,
    STATE(5325), 1,
      aux_sym_annotation_repeat1,
    STATE(6220), 1,
      sym_arguments,
    STATE(5334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [278488] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9546), 1,
      anon_sym_AT,
    STATE(6230), 1,
      sym_annotation,
    STATE(5335), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [278535] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9549), 1,
      anon_sym_with,
    STATE(5336), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278580] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9212), 1,
      anon_sym_LBRACK,
    ACTIONS(9216), 1,
      anon_sym_POUND,
    ACTIONS(9552), 1,
      anon_sym_AT,
    STATE(6244), 1,
      sym_type_arguments,
    STATE(6609), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8216), 1,
      sym_annotation,
    STATE(5337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278635] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9554), 1,
      sym__interpolated_multiline_string_start,
    STATE(9483), 1,
      sym_interpolated_string,
    STATE(15793), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278688] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278774] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278817] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8809), 1,
      anon_sym_LPAREN,
    STATE(5362), 1,
      aux_sym_annotation_repeat1,
    STATE(6217), 1,
      sym_arguments,
    STATE(5342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [278866] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9307), 1,
      anon_sym_COLON,
    ACTIONS(9309), 1,
      anon_sym_LBRACE,
    ACTIONS(9311), 1,
      anon_sym_with,
    STATE(5121), 1,
      aux_sym_compound_type_repeat1,
    STATE(10011), 1,
      sym_template_body,
    STATE(10250), 1,
      sym__refinement,
    STATE(5343), 2,
      sym_comment,
      sym_block_comment,
    STATE(10360), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [278923] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [278966] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8943), 1,
      anon_sym_LBRACK,
    ACTIONS(8945), 1,
      anon_sym_AT,
    ACTIONS(8949), 1,
      anon_sym_POUND,
    STATE(6322), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6889), 1,
      sym_type_arguments,
    STATE(7852), 1,
      sym_annotation,
    STATE(5345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [279021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279064] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279107] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279150] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279193] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9238), 1,
      anon_sym_COLON,
    ACTIONS(9240), 1,
      anon_sym_LBRACE,
    ACTIONS(9242), 1,
      anon_sym_with,
    STATE(5095), 1,
      aux_sym_compound_type_repeat1,
    STATE(10164), 1,
      sym_template_body,
    STATE(10165), 1,
      sym__refinement,
    STATE(5350), 2,
      sym_comment,
      sym_block_comment,
    STATE(10306), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [279250] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279293] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279336] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9560), 1,
      anon_sym_AT,
    STATE(6265), 1,
      sym_annotation,
    STATE(5353), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279383] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279426] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9155), 1,
      anon_sym_DOT,
    ACTIONS(9563), 1,
      anon_sym_EQ_GT,
    STATE(5355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [279473] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9307), 1,
      anon_sym_COLON,
    ACTIONS(9309), 1,
      anon_sym_LBRACE,
    ACTIONS(9311), 1,
      anon_sym_with,
    STATE(5121), 1,
      aux_sym_compound_type_repeat1,
    STATE(10011), 1,
      sym_template_body,
    STATE(10250), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5356), 2,
      sym_comment,
      sym_block_comment,
    STATE(10360), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [279536] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [279579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279622] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279665] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279708] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279751] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9565), 1,
      anon_sym_LPAREN,
    STATE(6217), 1,
      sym_arguments,
    STATE(5362), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279841] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9568), 1,
      anon_sym_LBRACK,
    ACTIONS(9570), 1,
      anon_sym_LPAREN,
    ACTIONS(9572), 1,
      anon_sym_POUND,
    STATE(6911), 1,
      sym_type_arguments,
    STATE(7131), 1,
      aux_sym_annotation_repeat1,
    STATE(8938), 1,
      sym_arguments,
    STATE(5364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [279896] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279939] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [279982] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280025] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9574), 1,
      sym__interpolated_multiline_string_start,
    STATE(9538), 1,
      sym_interpolated_string,
    STATE(15920), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [280078] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8890), 1,
      anon_sym_AT,
    STATE(5384), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6380), 1,
      sym_annotation,
    STATE(5369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280127] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8728), 1,
      anon_sym_LPAREN,
    STATE(5371), 1,
      aux_sym_annotation_repeat1,
    STATE(6298), 1,
      sym_arguments,
    STATE(5370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [280176] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9576), 1,
      anon_sym_LPAREN,
    STATE(6298), 1,
      sym_arguments,
    STATE(5371), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [280223] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9579), 1,
      anon_sym_LBRACK,
    ACTIONS(9581), 1,
      anon_sym_LPAREN,
    ACTIONS(9583), 1,
      anon_sym_POUND,
    STATE(6368), 1,
      aux_sym_annotation_repeat1,
    STATE(7194), 1,
      sym_type_arguments,
    STATE(7578), 1,
      sym_arguments,
    STATE(5372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [280278] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8751), 1,
      anon_sym_LPAREN,
    STATE(5386), 1,
      aux_sym_annotation_repeat1,
    STATE(6154), 1,
      sym_arguments,
    STATE(5373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [280327] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9130), 1,
      anon_sym_LBRACK,
    ACTIONS(9136), 1,
      anon_sym_POUND,
    ACTIONS(9585), 1,
      anon_sym_LPAREN,
    STATE(6313), 1,
      aux_sym_annotation_repeat1,
    STATE(7447), 1,
      sym_type_arguments,
    STATE(8018), 1,
      sym_arguments,
    STATE(5374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [280382] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280425] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8888), 1,
      anon_sym_AT,
    STATE(5308), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6124), 1,
      sym_annotation,
    STATE(5376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [280474] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9289), 1,
      anon_sym_end,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(9587), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16653), 1,
      sym_identifier,
    STATE(5377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(850), 22,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [280527] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9188), 1,
      anon_sym_LBRACK,
    ACTIONS(9192), 1,
      anon_sym_POUND,
    ACTIONS(9589), 1,
      anon_sym_AT,
    STATE(6116), 1,
      sym_type_arguments,
    STATE(7154), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8828), 1,
      sym_annotation,
    STATE(5378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [280582] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9591), 1,
      anon_sym_LBRACK,
    ACTIONS(9593), 1,
      anon_sym_LPAREN,
    ACTIONS(9595), 1,
      anon_sym_POUND,
    STATE(6336), 1,
      aux_sym_annotation_repeat1,
    STATE(7481), 1,
      sym_type_arguments,
    STATE(7595), 1,
      sym_arguments,
    STATE(5379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [280637] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9381), 1,
      anon_sym_COLON,
    ACTIONS(9383), 1,
      anon_sym_LBRACE,
    ACTIONS(9385), 1,
      anon_sym_with,
    STATE(7740), 1,
      aux_sym_compound_type_repeat1,
    STATE(10240), 1,
      sym__refinement,
    STATE(10243), 1,
      sym_template_body,
    STATE(5380), 2,
      sym_comment,
      sym_block_comment,
    STATE(10056), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [280694] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9597), 1,
      anon_sym_LPAREN,
    STATE(6378), 1,
      sym_arguments,
    STATE(5381), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [280741] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8791), 1,
      anon_sym_LPAREN,
    STATE(5381), 1,
      aux_sym_annotation_repeat1,
    STATE(6378), 1,
      sym_arguments,
    STATE(5382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [280790] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280833] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9600), 1,
      anon_sym_AT,
    STATE(6380), 1,
      sym_annotation,
    STATE(5384), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280880] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [280923] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9603), 1,
      anon_sym_LPAREN,
    STATE(6154), 1,
      sym_arguments,
    STATE(5386), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [280970] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [281015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281058] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [281103] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9606), 1,
      anon_sym_LBRACK,
    ACTIONS(9608), 1,
      anon_sym_AT,
    ACTIONS(9610), 1,
      anon_sym_LPAREN,
    ACTIONS(9612), 1,
      anon_sym_POUND,
    STATE(6790), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7943), 1,
      sym_type_arguments,
    STATE(8476), 1,
      sym_annotation,
    STATE(9825), 1,
      sym_arguments,
    STATE(5390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [281162] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281205] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8658), 1,
      anon_sym_LPAREN,
    ACTIONS(8998), 1,
      anon_sym_DOT,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(9622), 1,
      sym_operator_identifier,
    STATE(608), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    STATE(5392), 2,
      sym_comment,
      sym_block_comment,
    STATE(8261), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8305), 4,
      anon_sym_COLON,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9616), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [281274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281317] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281360] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9624), 1,
      anon_sym_DOT,
    STATE(5395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [281405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281448] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9630), 1,
      anon_sym_DOT,
    STATE(5397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [281536] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281622] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9632), 1,
      anon_sym_DOT,
    STATE(5401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [281667] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1572), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8869), 1,
      anon_sym_LPAREN,
    ACTIONS(9525), 1,
      anon_sym_DOT,
    ACTIONS(9634), 1,
      sym_operator_identifier,
    STATE(1819), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5402), 2,
      sym_comment,
      sym_block_comment,
    STATE(8709), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8309), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [281734] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9046), 1,
      anon_sym_LBRACK,
    ACTIONS(9052), 1,
      anon_sym_POUND,
    ACTIONS(9636), 1,
      anon_sym_LPAREN,
    STATE(6460), 1,
      aux_sym_annotation_repeat1,
    STATE(7184), 1,
      sym_type_arguments,
    STATE(8204), 1,
      sym_arguments,
    STATE(5403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [281789] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281832] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281875] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8535), 1,
      anon_sym_AT,
    STATE(5442), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6604), 1,
      sym_annotation,
    STATE(5406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [281924] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [281967] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9638), 1,
      anon_sym_COLON,
    ACTIONS(9641), 1,
      anon_sym_LBRACE,
    STATE(7152), 1,
      sym_template_body,
    STATE(5408), 2,
      sym_comment,
      sym_block_comment,
    STATE(6847), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 15,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282061] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9644), 1,
      anon_sym_with,
    STATE(5638), 1,
      aux_sym_compound_type_repeat1,
    STATE(8959), 1,
      sym_template_body,
    STATE(8962), 1,
      sym__refinement,
    STATE(9271), 1,
      sym_arguments,
    STATE(5410), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [282116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282159] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282202] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8511), 1,
      anon_sym_AT,
    STATE(5335), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6230), 1,
      sym_annotation,
    STATE(5413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [282251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282294] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1132), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8537), 1,
      anon_sym_LPAREN,
    ACTIONS(9138), 1,
      anon_sym_DOT,
    ACTIONS(9321), 1,
      sym__alpha_identifier,
    ACTIONS(9327), 1,
      sym__backquoted_id,
    ACTIONS(9329), 1,
      sym_operator_identifier,
    ACTIONS(9646), 1,
      anon_sym_EQ,
    STATE(585), 1,
      sym_identifier,
    STATE(4157), 1,
      sym__soft_identifier,
    STATE(5415), 2,
      sym_comment,
      sym_block_comment,
    STATE(7668), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9323), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [282361] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282404] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9648), 1,
      anon_sym_LBRACK,
    ACTIONS(9650), 1,
      anon_sym_LPAREN,
    ACTIONS(9652), 1,
      anon_sym_POUND,
    STATE(7077), 1,
      aux_sym_annotation_repeat1,
    STATE(7369), 1,
      sym_type_arguments,
    STATE(8873), 1,
      sym_arguments,
    STATE(5417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [282459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282502] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282545] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282588] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282674] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1228), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8719), 1,
      anon_sym_LPAREN,
    ACTIONS(9658), 1,
      anon_sym_DOT,
    ACTIONS(9660), 1,
      sym_operator_identifier,
    STATE(1799), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5423), 2,
      sym_comment,
      sym_block_comment,
    STATE(8854), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [282741] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9662), 1,
      anon_sym_COLON,
    ACTIONS(9664), 1,
      anon_sym_LBRACE,
    ACTIONS(9666), 1,
      anon_sym_with,
    STATE(7675), 1,
      aux_sym_compound_type_repeat1,
    STATE(10328), 1,
      sym__refinement,
    STATE(10333), 1,
      sym_template_body,
    STATE(5424), 2,
      sym_comment,
      sym_block_comment,
    STATE(10207), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [282798] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9668), 1,
      anon_sym_LBRACK,
    ACTIONS(9670), 1,
      anon_sym_LPAREN,
    ACTIONS(9672), 1,
      anon_sym_POUND,
    STATE(6529), 1,
      aux_sym_annotation_repeat1,
    STATE(7426), 1,
      sym_type_arguments,
    STATE(7514), 1,
      sym_arguments,
    STATE(5425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [282853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [282896] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8884), 1,
      anon_sym_LPAREN,
    STATE(5434), 1,
      aux_sym_annotation_repeat1,
    STATE(6564), 1,
      sym_arguments,
    STATE(5427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [282945] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [282988] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [283031] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283074] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283160] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1572), 1,
      anon_sym_LBRACE,
    ACTIONS(8869), 1,
      anon_sym_LPAREN,
    ACTIONS(9525), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5433), 2,
      sym_comment,
      sym_block_comment,
    STATE(8709), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [283215] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9678), 1,
      anon_sym_LPAREN,
    STATE(6564), 1,
      sym_arguments,
    STATE(5434), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [283262] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283305] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9662), 1,
      anon_sym_COLON,
    ACTIONS(9664), 1,
      anon_sym_LBRACE,
    ACTIONS(9666), 1,
      anon_sym_with,
    STATE(5424), 1,
      aux_sym_compound_type_repeat1,
    STATE(10331), 1,
      sym__refinement,
    STATE(10333), 1,
      sym_template_body,
    STATE(5436), 2,
      sym_comment,
      sym_block_comment,
    STATE(10207), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [283362] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [283448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283491] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [283534] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8841), 1,
      anon_sym_AT,
    STATE(5353), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6265), 1,
      sym_annotation,
    STATE(5441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283583] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9681), 1,
      anon_sym_AT,
    STATE(6604), 1,
      sym_annotation,
    STATE(5442), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [283630] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9684), 1,
      anon_sym_LBRACK,
    ACTIONS(9686), 1,
      anon_sym_AT,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    ACTIONS(9690), 1,
      anon_sym_POUND,
    STATE(7049), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7585), 1,
      sym_type_arguments,
    STATE(8395), 1,
      sym_annotation,
    STATE(9271), 1,
      sym_arguments,
    STATE(5443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [283689] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [283732] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9465), 1,
      anon_sym_COLON,
    ACTIONS(9467), 1,
      anon_sym_LBRACE,
    ACTIONS(9469), 1,
      anon_sym_with,
    STATE(8250), 1,
      aux_sym_compound_type_repeat1,
    STATE(10067), 1,
      sym_template_body,
    STATE(10073), 1,
      sym__refinement,
    STATE(5445), 2,
      sym_comment,
      sym_block_comment,
    STATE(10217), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [283789] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [283832] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9130), 1,
      anon_sym_LBRACK,
    ACTIONS(9132), 1,
      anon_sym_AT,
    ACTIONS(9136), 1,
      anon_sym_POUND,
    STATE(6488), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7447), 1,
      sym_type_arguments,
    STATE(7653), 1,
      sym_annotation,
    STATE(5447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [283887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [283930] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [283973] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284016] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284059] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1228), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8719), 1,
      anon_sym_LPAREN,
    ACTIONS(9658), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5452), 2,
      sym_comment,
      sym_block_comment,
    STATE(8854), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [284116] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8933), 1,
      anon_sym_EQ_GT,
    STATE(5453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284161] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9662), 1,
      anon_sym_COLON,
    ACTIONS(9664), 1,
      anon_sym_LBRACE,
    ACTIONS(9666), 1,
      anon_sym_with,
    STATE(5424), 1,
      aux_sym_compound_type_repeat1,
    STATE(10331), 1,
      sym__refinement,
    STATE(10333), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5454), 2,
      sym_comment,
      sym_block_comment,
    STATE(10207), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [284224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [284267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [284310] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [284353] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9692), 1,
      anon_sym_with,
    STATE(5458), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284398] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9695), 1,
      anon_sym_LBRACK,
    ACTIONS(9697), 1,
      anon_sym_LPAREN,
    ACTIONS(9699), 1,
      anon_sym_POUND,
    STATE(6636), 1,
      aux_sym_annotation_repeat1,
    STATE(7375), 1,
      sym_type_arguments,
    STATE(7545), 1,
      sym_arguments,
    STATE(5459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [284453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [284496] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284539] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [284582] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284625] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9701), 1,
      anon_sym_LBRACK,
    ACTIONS(9703), 1,
      anon_sym_LPAREN,
    ACTIONS(9705), 1,
      anon_sym_POUND,
    STATE(6807), 1,
      aux_sym_annotation_repeat1,
    STATE(7002), 1,
      sym_type_arguments,
    STATE(8412), 1,
      sym_arguments,
    STATE(5464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [284680] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284811] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9387), 1,
      anon_sym_COLON,
    ACTIONS(9389), 1,
      anon_sym_LBRACE,
    ACTIONS(9391), 1,
      anon_sym_with,
    STATE(8124), 1,
      aux_sym_compound_type_repeat1,
    STATE(10037), 1,
      sym__refinement,
    STATE(10051), 1,
      sym_template_body,
    STATE(5468), 2,
      sym_comment,
      sym_block_comment,
    STATE(10139), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [284868] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [284911] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9093), 1,
      anon_sym_with,
    STATE(8271), 1,
      aux_sym_compound_type_repeat1,
    STATE(9269), 1,
      sym_template_body,
    STATE(9326), 1,
      sym__refinement,
    STATE(5470), 2,
      sym_comment,
      sym_block_comment,
    STATE(8992), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [284964] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8921), 1,
      anon_sym_LBRACK,
    ACTIONS(8925), 1,
      anon_sym_POUND,
    ACTIONS(9711), 1,
      anon_sym_AT,
    STATE(6209), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6742), 1,
      sym_type_arguments,
    STATE(7883), 1,
      sym_annotation,
    STATE(5471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [285019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285062] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9713), 1,
      anon_sym_LBRACK,
    ACTIONS(9715), 1,
      anon_sym_LPAREN,
    ACTIONS(9717), 1,
      anon_sym_POUND,
    STATE(6641), 1,
      aux_sym_annotation_repeat1,
    STATE(7380), 1,
      sym_type_arguments,
    STATE(8233), 1,
      sym_arguments,
    STATE(5473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [285117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285160] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285246] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285332] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285375] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285418] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285461] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9719), 1,
      anon_sym_DOT,
    STATE(5482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [285506] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9421), 1,
      anon_sym_COLON,
    ACTIONS(9423), 1,
      anon_sym_LBRACE,
    ACTIONS(9425), 1,
      anon_sym_with,
    STATE(8170), 1,
      aux_sym_compound_type_repeat1,
    STATE(10022), 1,
      sym_template_body,
    STATE(10030), 1,
      sym__refinement,
    STATE(5483), 2,
      sym_comment,
      sym_block_comment,
    STATE(10150), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [285563] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [285606] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9362), 1,
      sym__interpolated_multiline_string_start,
    STATE(9516), 1,
      sym_interpolated_string,
    STATE(16367), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [285659] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9721), 1,
      anon_sym_with,
    STATE(5486), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285704] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [285747] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285790] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_LPAREN,
    ACTIONS(9732), 1,
      anon_sym_POUND,
    STATE(6736), 1,
      aux_sym_annotation_repeat1,
    STATE(7307), 1,
      sym_type_arguments,
    STATE(7568), 1,
      sym_arguments,
    STATE(5489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [285845] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9046), 1,
      anon_sym_LBRACK,
    ACTIONS(9048), 1,
      anon_sym_AT,
    ACTIONS(9052), 1,
      anon_sym_POUND,
    STATE(6277), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7184), 1,
      sym_type_arguments,
    STATE(7538), 1,
      sym_annotation,
    STATE(5490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [285900] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [285943] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1228), 1,
      anon_sym_LBRACE,
    ACTIONS(8719), 1,
      anon_sym_LPAREN,
    ACTIONS(9658), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5492), 2,
      sym_comment,
      sym_block_comment,
    STATE(8854), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [285998] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9439), 1,
      anon_sym_COLON,
    ACTIONS(9441), 1,
      anon_sym_LBRACE,
    ACTIONS(9443), 1,
      anon_sym_with,
    STATE(8257), 1,
      aux_sym_compound_type_repeat1,
    STATE(10047), 1,
      sym_template_body,
    STATE(10054), 1,
      sym__refinement,
    STATE(5493), 2,
      sym_comment,
      sym_block_comment,
    STATE(10202), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [286055] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9054), 1,
      anon_sym_DOT,
    ACTIONS(9734), 1,
      anon_sym_EQ_GT,
    STATE(5494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286102] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9736), 1,
      anon_sym_with,
    STATE(5728), 1,
      aux_sym_compound_type_repeat1,
    STATE(9695), 1,
      sym__refinement,
    STATE(9696), 1,
      sym_template_body,
    STATE(9825), 1,
      sym_arguments,
    STATE(5495), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [286157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286200] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [286242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [286284] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6754), 1,
      sym__alpha_identifier,
    ACTIONS(6756), 1,
      anon_sym__,
    ACTIONS(6764), 1,
      sym__backquoted_id,
    ACTIONS(6766), 1,
      sym_operator_identifier,
    ACTIONS(9742), 1,
      anon_sym_LPAREN,
    STATE(4678), 1,
      sym__annotated_type,
    STATE(4748), 1,
      sym__simple_type,
    STATE(4984), 1,
      sym_identifier,
    STATE(4998), 1,
      sym__soft_identifier,
    STATE(6891), 1,
      sym_annotated_type,
    STATE(7728), 1,
      sym__infix_type_choice,
    STATE(17750), 1,
      sym_stable_identifier,
    STATE(5499), 2,
      sym_comment,
      sym_block_comment,
    STATE(9300), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6760), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [286352] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9204), 1,
      anon_sym_LPAREN,
    STATE(5515), 1,
      aux_sym_annotation_repeat1,
    STATE(6785), 1,
      sym_arguments,
    STATE(5500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [286400] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286442] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286486] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(9744), 1,
      anon_sym_LPAREN,
    STATE(5162), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(8999), 1,
      sym__infix_type_choice,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(5503), 2,
      sym_comment,
      sym_block_comment,
    STATE(10231), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [286554] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286596] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [286638] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9748), 1,
      sym__interpolated_multiline_string_start,
    STATE(9649), 1,
      sym_interpolated_string,
    STATE(16063), 1,
      sym__interpolated_string_start,
    ACTIONS(9746), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [286690] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9750), 1,
      anon_sym_with,
    STATE(5507), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [286734] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9753), 1,
      anon_sym_COLON,
    ACTIONS(9755), 1,
      anon_sym_LBRACE,
    ACTIONS(9757), 1,
      anon_sym_with,
    STATE(5738), 1,
      aux_sym_compound_type_repeat1,
    STATE(10372), 1,
      sym_template_body,
    STATE(10373), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5508), 2,
      sym_comment,
      sym_block_comment,
    STATE(10666), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7882), 3,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [286796] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(9759), 1,
      anon_sym_LPAREN,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8848), 1,
      sym__annotated_type,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(10836), 1,
      sym__infix_type_choice,
    STATE(17416), 1,
      sym_stable_identifier,
    STATE(5509), 2,
      sym_comment,
      sym_block_comment,
    STATE(11397), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [286864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [286906] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9527), 1,
      anon_sym_DOT,
    ACTIONS(9761), 1,
      anon_sym_EQ_GT,
    STATE(5511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [286952] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9763), 1,
      anon_sym_COLON,
    ACTIONS(9765), 1,
      anon_sym_LBRACE,
    ACTIONS(9767), 1,
      anon_sym_with,
    STATE(8902), 1,
      aux_sym_compound_type_repeat1,
    STATE(10597), 1,
      sym__refinement,
    STATE(10604), 1,
      sym_template_body,
    STATE(5512), 2,
      sym_comment,
      sym_block_comment,
    STATE(10367), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287008] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6996), 1,
      sym__alpha_identifier,
    ACTIONS(6998), 1,
      anon_sym__,
    ACTIONS(7006), 1,
      sym__backquoted_id,
    ACTIONS(7008), 1,
      sym_operator_identifier,
    ACTIONS(9769), 1,
      anon_sym_LPAREN,
    STATE(6559), 1,
      sym__simple_type,
    STATE(6713), 1,
      sym__annotated_type,
    STATE(7238), 1,
      sym_identifier,
    STATE(7458), 1,
      sym__soft_identifier,
    STATE(9877), 1,
      sym_annotated_type,
    STATE(10178), 1,
      sym__infix_type_choice,
    STATE(17218), 1,
      sym_stable_identifier,
    STATE(5513), 2,
      sym_comment,
      sym_block_comment,
    STATE(10852), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(7002), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8023), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [287076] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287118] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9771), 1,
      anon_sym_LPAREN,
    STATE(6785), 1,
      sym_arguments,
    STATE(5515), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [287164] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287206] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287248] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_as,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [287290] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287332] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9774), 1,
      anon_sym_LBRACK,
    ACTIONS(9776), 1,
      anon_sym_AT,
    ACTIONS(9778), 1,
      anon_sym_LPAREN,
    ACTIONS(9780), 1,
      anon_sym_POUND,
    STATE(7853), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8475), 1,
      sym_type_arguments,
    STATE(8940), 1,
      sym_annotation,
    STATE(10100), 1,
      sym_arguments,
    STATE(5520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287390] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287432] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9782), 1,
      anon_sym_LPAREN,
    STATE(6856), 1,
      sym_arguments,
    STATE(5522), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287478] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9695), 1,
      anon_sym_LBRACK,
    ACTIONS(9699), 1,
      anon_sym_POUND,
    ACTIONS(9785), 1,
      anon_sym_AT,
    STATE(7039), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7375), 1,
      sym_type_arguments,
    STATE(8916), 1,
      sym_annotation,
    STATE(5523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287574] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287616] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287658] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287700] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9002), 1,
      anon_sym_LPAREN,
    STATE(5522), 1,
      aux_sym_annotation_repeat1,
    STATE(6856), 1,
      sym_arguments,
    STATE(5528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287748] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287790] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9787), 1,
      anon_sym_AT,
    STATE(7245), 1,
      sym_annotation,
    STATE(5530), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [287836] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287878] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [287920] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    ACTIONS(9790), 1,
      anon_sym_LPAREN,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8846), 1,
      sym_identifier,
    STATE(9907), 1,
      sym__annotated_type,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(11336), 1,
      sym__infix_type_choice,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(5533), 2,
      sym_comment,
      sym_block_comment,
    STATE(11347), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [287988] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288030] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288072] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9796), 1,
      anon_sym_DOT,
    STATE(5536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [288116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288158] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6900), 1,
      sym__alpha_identifier,
    ACTIONS(6906), 1,
      anon_sym__,
    ACTIONS(6914), 1,
      sym__backquoted_id,
    ACTIONS(6916), 1,
      sym_operator_identifier,
    ACTIONS(9798), 1,
      anon_sym_LPAREN,
    STATE(4787), 1,
      sym__annotated_type,
    STATE(4794), 1,
      sym__simple_type,
    STATE(5011), 1,
      sym_identifier,
    STATE(5013), 1,
      sym__soft_identifier,
    STATE(6935), 1,
      sym_annotated_type,
    STATE(7666), 1,
      sym__infix_type_choice,
    STATE(17762), 1,
      sym_stable_identifier,
    STATE(5538), 2,
      sym_comment,
      sym_block_comment,
    STATE(8955), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6910), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5168), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [288226] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288268] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288310] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288352] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288394] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9427), 1,
      sym__interpolated_multiline_string_start,
    STATE(9056), 1,
      sym_interpolated_string,
    STATE(15558), 1,
      sym__interpolated_string_start,
    ACTIONS(9808), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [288446] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1340), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(9395), 1,
      anon_sym_DOT,
    ACTIONS(9810), 1,
      sym__alpha_identifier,
    ACTIONS(9814), 1,
      anon_sym_EQ,
    ACTIONS(9816), 1,
      sym__backquoted_id,
    ACTIONS(9818), 1,
      sym_operator_identifier,
    STATE(592), 1,
      sym_identifier,
    STATE(4173), 1,
      sym__soft_identifier,
    STATE(5544), 2,
      sym_comment,
      sym_block_comment,
    STATE(8867), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9812), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [288512] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9554), 1,
      sym__interpolated_multiline_string_start,
    STATE(9483), 1,
      sym_interpolated_string,
    STATE(15793), 1,
      sym__interpolated_string_start,
    ACTIONS(9820), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [288564] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9822), 1,
      anon_sym_AT,
    STATE(7229), 1,
      sym_annotation,
    STATE(5546), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [288610] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8618), 1,
      sym__interpolated_multiline_string_start,
    STATE(7397), 1,
      sym_interpolated_string,
    STATE(16007), 1,
      sym__interpolated_string_start,
    ACTIONS(9825), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288662] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288704] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9831), 1,
      anon_sym_with,
    STATE(5549), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288748] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [288790] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [288832] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6698), 1,
      sym__alpha_identifier,
    ACTIONS(6704), 1,
      anon_sym__,
    ACTIONS(6712), 1,
      sym__backquoted_id,
    ACTIONS(6714), 1,
      sym_operator_identifier,
    ACTIONS(9834), 1,
      anon_sym_LPAREN,
    STATE(4955), 1,
      sym__annotated_type,
    STATE(4994), 1,
      sym__simple_type,
    STATE(5215), 1,
      sym__soft_identifier,
    STATE(5482), 1,
      sym_identifier,
    STATE(7805), 1,
      sym_annotated_type,
    STATE(8882), 1,
      sym__infix_type_choice,
    STATE(17840), 1,
      sym_stable_identifier,
    STATE(5552), 2,
      sym_comment,
      sym_block_comment,
    STATE(9964), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6708), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5743), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [288900] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    ACTIONS(9790), 1,
      anon_sym_LPAREN,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8418), 1,
      sym__annotated_type,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(10923), 1,
      sym__infix_type_choice,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(5553), 2,
      sym_comment,
      sym_block_comment,
    STATE(11347), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [288968] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [289010] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [289052] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1024), 1,
      anon_sym_LBRACE,
    ACTIONS(8231), 1,
      anon_sym_LPAREN,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8839), 1,
      anon_sym_DOT,
    ACTIONS(9836), 1,
      sym__alpha_identifier,
    ACTIONS(9840), 1,
      anon_sym_EQ,
    ACTIONS(9842), 1,
      sym__backquoted_id,
    ACTIONS(9844), 1,
      sym_operator_identifier,
    STATE(582), 1,
      sym_identifier,
    STATE(4162), 1,
      sym__soft_identifier,
    STATE(5556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6866), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9838), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [289118] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [289160] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [289202] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4750), 1,
      sym__alpha_identifier,
    ACTIONS(4752), 1,
      anon_sym__,
    ACTIONS(4762), 1,
      sym__backquoted_id,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    ACTIONS(9846), 1,
      anon_sym_LPAREN,
    STATE(4614), 1,
      sym__simple_type,
    STATE(4615), 1,
      sym__annotated_type,
    STATE(4635), 1,
      sym__soft_identifier,
    STATE(4732), 1,
      sym_identifier,
    STATE(6307), 1,
      sym_annotated_type,
    STATE(7047), 1,
      sym__infix_type_choice,
    STATE(17642), 1,
      sym_stable_identifier,
    STATE(5559), 2,
      sym_comment,
      sym_block_comment,
    STATE(8929), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4758), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4869), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [289270] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9701), 1,
      anon_sym_LBRACK,
    ACTIONS(9705), 1,
      anon_sym_POUND,
    ACTIONS(9848), 1,
      anon_sym_AT,
    STATE(7002), 1,
      sym_type_arguments,
    STATE(7622), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9174), 1,
      sym_annotation,
    STATE(5560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289324] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [289366] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9850), 1,
      anon_sym_COLON,
    ACTIONS(9852), 1,
      anon_sym_LBRACE,
    ACTIONS(9854), 1,
      anon_sym_with,
    STATE(8822), 1,
      aux_sym_compound_type_repeat1,
    STATE(10664), 1,
      sym_template_body,
    STATE(10669), 1,
      sym__refinement,
    STATE(5562), 2,
      sym_comment,
      sym_block_comment,
    STATE(10402), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289422] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4278), 1,
      sym__alpha_identifier,
    ACTIONS(4284), 1,
      anon_sym__,
    ACTIONS(4296), 1,
      sym__backquoted_id,
    ACTIONS(6994), 1,
      sym_operator_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    STATE(6690), 1,
      sym__annotated_type,
    STATE(6764), 1,
      sym__simple_type,
    STATE(6872), 1,
      sym_identifier,
    STATE(7385), 1,
      sym__soft_identifier,
    STATE(9756), 1,
      sym_annotated_type,
    STATE(10234), 1,
      sym__infix_type_choice,
    STATE(17176), 1,
      sym_stable_identifier,
    STATE(5563), 2,
      sym_comment,
      sym_block_comment,
    STATE(10707), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4290), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8228), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [289490] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [289532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [289574] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1228), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8719), 1,
      anon_sym_LPAREN,
    ACTIONS(9658), 1,
      anon_sym_DOT,
    ACTIONS(9858), 1,
      sym__alpha_identifier,
    ACTIONS(9862), 1,
      anon_sym_EQ,
    ACTIONS(9864), 1,
      sym__backquoted_id,
    ACTIONS(9866), 1,
      sym_operator_identifier,
    STATE(588), 1,
      sym_identifier,
    STATE(4168), 1,
      sym__soft_identifier,
    STATE(5566), 2,
      sym_comment,
      sym_block_comment,
    STATE(8854), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9860), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [289640] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [289682] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9868), 1,
      anon_sym_with,
    STATE(5568), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [289726] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1060), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8355), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      anon_sym_DOT,
    ACTIONS(9871), 1,
      sym__alpha_identifier,
    ACTIONS(9875), 1,
      anon_sym_EQ,
    ACTIONS(9877), 1,
      sym__backquoted_id,
    ACTIONS(9879), 1,
      sym_operator_identifier,
    STATE(583), 1,
      sym_identifier,
    STATE(4158), 1,
      sym__soft_identifier,
    STATE(5569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(7191), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9873), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [289792] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9881), 1,
      anon_sym_LPAREN,
    STATE(7151), 1,
      sym_arguments,
    STATE(5570), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [289838] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9884), 1,
      anon_sym_DOT,
    STATE(5571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [289882] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4512), 1,
      sym__alpha_identifier,
    ACTIONS(4514), 1,
      anon_sym__,
    ACTIONS(4524), 1,
      sym__backquoted_id,
    ACTIONS(6964), 1,
      sym_operator_identifier,
    ACTIONS(9886), 1,
      anon_sym_LPAREN,
    STATE(4563), 1,
      sym__annotated_type,
    STATE(4605), 1,
      sym__simple_type,
    STATE(4670), 1,
      sym_identifier,
    STATE(4696), 1,
      sym__soft_identifier,
    STATE(6758), 1,
      sym_annotated_type,
    STATE(6888), 1,
      sym__infix_type_choice,
    STATE(17301), 1,
      sym_stable_identifier,
    STATE(5572), 2,
      sym_comment,
      sym_block_comment,
    STATE(8600), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4520), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5076), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [289950] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9606), 1,
      anon_sym_LBRACK,
    ACTIONS(9612), 1,
      anon_sym_POUND,
    ACTIONS(9888), 1,
      anon_sym_LPAREN,
    STATE(7213), 1,
      aux_sym_annotation_repeat1,
    STATE(7943), 1,
      sym_type_arguments,
    STATE(8824), 1,
      sym_arguments,
    STATE(5573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290004] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290046] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9734), 1,
      anon_sym_EQ_GT,
    STATE(5575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [290090] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [290132] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [290174] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1060), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8355), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      anon_sym_DOT,
    ACTIONS(9871), 1,
      sym__alpha_identifier,
    ACTIONS(9877), 1,
      sym__backquoted_id,
    ACTIONS(9879), 1,
      sym_operator_identifier,
    ACTIONS(9898), 1,
      anon_sym_EQ,
    STATE(583), 1,
      sym_identifier,
    STATE(4158), 1,
      sym__soft_identifier,
    STATE(5578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    STATE(7191), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9873), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [290240] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290282] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1024), 1,
      anon_sym_LBRACE,
    ACTIONS(8231), 1,
      anon_sym_LPAREN,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8839), 1,
      anon_sym_DOT,
    ACTIONS(9836), 1,
      sym__alpha_identifier,
    ACTIONS(9842), 1,
      sym__backquoted_id,
    ACTIONS(9844), 1,
      sym_operator_identifier,
    ACTIONS(9900), 1,
      anon_sym_EQ,
    STATE(582), 1,
      sym_identifier,
    STATE(4162), 1,
      sym__soft_identifier,
    STATE(5580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    STATE(6866), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9838), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [290348] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9902), 1,
      anon_sym_LPAREN,
    STATE(7462), 1,
      sym_arguments,
    STATE(5581), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290394] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6451), 1,
      sym__end_marker,
    STATE(5582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [290438] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [290480] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4390), 1,
      sym__alpha_identifier,
    ACTIONS(4396), 1,
      anon_sym__,
    ACTIONS(4408), 1,
      sym__backquoted_id,
    ACTIONS(6692), 1,
      sym_operator_identifier,
    ACTIONS(9905), 1,
      anon_sym_LPAREN,
    STATE(6105), 1,
      sym__annotated_type,
    STATE(6561), 1,
      sym__simple_type,
    STATE(7208), 1,
      sym__soft_identifier,
    STATE(7259), 1,
      sym_identifier,
    STATE(9943), 1,
      sym_annotated_type,
    STATE(10125), 1,
      sym__infix_type_choice,
    STATE(17606), 1,
      sym_stable_identifier,
    STATE(5584), 2,
      sym_comment,
      sym_block_comment,
    STATE(10838), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4402), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8276), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [290548] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [290632] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [290674] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9907), 1,
      anon_sym_LPAREN,
    STATE(7201), 1,
      sym_arguments,
    STATE(5588), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290720] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [290762] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    ACTIONS(9912), 1,
      anon_sym_LPAREN,
    ACTIONS(9914), 1,
      anon_sym_POUND,
    STATE(6876), 1,
      aux_sym_annotation_repeat1,
    STATE(8269), 1,
      sym_type_arguments,
    STATE(8572), 1,
      sym_arguments,
    STATE(5590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290816] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [290858] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [290900] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [290942] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [290984] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8831), 1,
      anon_sym_AT,
    STATE(5900), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7156), 1,
      sym_annotation,
    STATE(5595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [291032] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [291074] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9399), 1,
      anon_sym_LBRACK,
    ACTIONS(9401), 1,
      anon_sym_AT,
    ACTIONS(9405), 1,
      anon_sym_POUND,
    STATE(7368), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7692), 1,
      sym_type_arguments,
    STATE(8683), 1,
      sym_annotation,
    STATE(5597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291128] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [291170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [291212] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291254] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291296] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [291338] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9916), 1,
      anon_sym_with,
    STATE(5603), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [291382] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [291424] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291466] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291508] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291550] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9919), 1,
      anon_sym_COLON,
    ACTIONS(9921), 1,
      anon_sym_LBRACE,
    ACTIONS(9923), 1,
      anon_sym_with,
    STATE(8291), 1,
      aux_sym_compound_type_repeat1,
    STATE(10374), 1,
      sym__refinement,
    STATE(10398), 1,
      sym_template_body,
    STATE(5608), 2,
      sym_comment,
      sym_block_comment,
    STATE(10376), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [291606] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(952), 1,
      anon_sym_LBRACE,
    ACTIONS(7842), 1,
      anon_sym_LPAREN,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8521), 1,
      anon_sym_DOT,
    ACTIONS(9259), 1,
      sym__alpha_identifier,
    ACTIONS(9265), 1,
      sym__backquoted_id,
    ACTIONS(9267), 1,
      sym_operator_identifier,
    ACTIONS(9925), 1,
      anon_sym_EQ,
    STATE(580), 1,
      sym_identifier,
    STATE(4062), 1,
      sym__soft_identifier,
    STATE(5609), 2,
      sym_comment,
      sym_block_comment,
    STATE(6473), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9261), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [291672] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4712), 1,
      sym__alpha_identifier,
    ACTIONS(4718), 1,
      anon_sym__,
    ACTIONS(4730), 1,
      sym__backquoted_id,
    ACTIONS(6960), 1,
      sym_operator_identifier,
    ACTIONS(9927), 1,
      anon_sym_LPAREN,
    STATE(5963), 1,
      sym__annotated_type,
    STATE(6100), 1,
      sym__simple_type,
    STATE(6328), 1,
      sym__soft_identifier,
    STATE(6619), 1,
      sym_identifier,
    STATE(9270), 1,
      sym_annotated_type,
    STATE(9902), 1,
      sym__infix_type_choice,
    STATE(17134), 1,
      sym_stable_identifier,
    STATE(5610), 2,
      sym_comment,
      sym_block_comment,
    STATE(10544), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4724), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7010), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [291740] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [291782] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [291824] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9933), 1,
      anon_sym_LBRACK,
    ACTIONS(9935), 1,
      anon_sym_LPAREN,
    ACTIONS(9937), 1,
      anon_sym_POUND,
    STATE(7978), 1,
      aux_sym_annotation_repeat1,
    STATE(8052), 1,
      sym_type_arguments,
    STATE(8968), 1,
      sym_arguments,
    STATE(5613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291878] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8625), 1,
      sym__interpolated_multiline_string_start,
    STATE(6974), 1,
      sym_interpolated_string,
    STATE(16306), 1,
      sym__interpolated_string_start,
    ACTIONS(9939), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [291930] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6918), 1,
      sym__alpha_identifier,
    ACTIONS(6924), 1,
      anon_sym__,
    ACTIONS(6932), 1,
      sym__backquoted_id,
    ACTIONS(6934), 1,
      sym_operator_identifier,
    ACTIONS(9941), 1,
      anon_sym_LPAREN,
    STATE(4592), 1,
      sym__annotated_type,
    STATE(4612), 1,
      sym__simple_type,
    STATE(4637), 1,
      sym_identifier,
    STATE(4714), 1,
      sym__soft_identifier,
    STATE(6684), 1,
      sym_annotated_type,
    STATE(6822), 1,
      sym__infix_type_choice,
    STATE(17341), 1,
      sym_stable_identifier,
    STATE(5615), 2,
      sym_comment,
      sym_block_comment,
    STATE(8457), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6928), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5056), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [291998] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [292040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [292082] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4182), 1,
      sym__alpha_identifier,
    ACTIONS(4188), 1,
      anon_sym__,
    ACTIONS(4200), 1,
      sym__backquoted_id,
    ACTIONS(6316), 1,
      sym_operator_identifier,
    ACTIONS(9943), 1,
      anon_sym_LPAREN,
    STATE(4560), 1,
      sym__simple_type,
    STATE(4588), 1,
      sym__annotated_type,
    STATE(4657), 1,
      sym__soft_identifier,
    STATE(4661), 1,
      sym_identifier,
    STATE(6338), 1,
      sym_annotated_type,
    STATE(6936), 1,
      sym__infix_type_choice,
    STATE(17648), 1,
      sym_stable_identifier,
    STATE(5618), 2,
      sym_comment,
      sym_block_comment,
    STATE(8678), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4194), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4885), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [292150] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8935), 1,
      anon_sym_LPAREN,
    STATE(5581), 1,
      aux_sym_annotation_repeat1,
    STATE(7462), 1,
      sym_arguments,
    STATE(5619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [292198] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [292240] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9214), 1,
      anon_sym_LPAREN,
    STATE(5588), 1,
      aux_sym_annotation_repeat1,
    STATE(7201), 1,
      sym_arguments,
    STATE(5621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [292288] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9732), 1,
      anon_sym_POUND,
    ACTIONS(9945), 1,
      anon_sym_AT,
    STATE(6982), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7307), 1,
      sym_type_arguments,
    STATE(8836), 1,
      sym_annotation,
    STATE(5622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [292342] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [292386] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [292428] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1978), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9134), 1,
      anon_sym_LPAREN,
    ACTIONS(9947), 1,
      anon_sym_DOT,
    ACTIONS(9949), 1,
      sym_operator_identifier,
    STATE(1742), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    STATE(9158), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8309), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [292494] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6676), 1,
      sym__alpha_identifier,
    ACTIONS(6678), 1,
      anon_sym__,
    ACTIONS(6686), 1,
      sym__backquoted_id,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    ACTIONS(9951), 1,
      anon_sym_LPAREN,
    STATE(6998), 1,
      sym__simple_type,
    STATE(7050), 1,
      sym__annotated_type,
    STATE(7765), 1,
      sym_identifier,
    STATE(7792), 1,
      sym__soft_identifier,
    STATE(10305), 1,
      sym_annotated_type,
    STATE(10385), 1,
      sym__infix_type_choice,
    STATE(17582), 1,
      sym_stable_identifier,
    STATE(5626), 2,
      sym_comment,
      sym_block_comment,
    STATE(11059), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6682), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8371), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [292562] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8618), 1,
      sym__interpolated_multiline_string_start,
    STATE(7397), 1,
      sym_interpolated_string,
    STATE(16007), 1,
      sym__interpolated_string_start,
    ACTIONS(9953), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [292614] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [292656] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [292698] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9959), 1,
      anon_sym_LBRACK,
    ACTIONS(9961), 1,
      anon_sym_LPAREN,
    ACTIONS(9963), 1,
      anon_sym_POUND,
    STATE(7968), 1,
      sym_type_arguments,
    STATE(8242), 1,
      aux_sym_annotation_repeat1,
    STATE(9194), 1,
      sym_arguments,
    STATE(5630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [292752] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [292794] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4624), 1,
      sym__alpha_identifier,
    ACTIONS(4630), 1,
      anon_sym__,
    ACTIONS(4642), 1,
      sym__backquoted_id,
    ACTIONS(6630), 1,
      sym_operator_identifier,
    ACTIONS(9965), 1,
      anon_sym_LPAREN,
    STATE(4354), 1,
      sym__annotated_type,
    STATE(4437), 1,
      sym__simple_type,
    STATE(4445), 1,
      sym__soft_identifier,
    STATE(4449), 1,
      sym_identifier,
    STATE(5361), 1,
      sym_annotated_type,
    STATE(5784), 1,
      sym__infix_type_choice,
    STATE(17628), 1,
      sym_stable_identifier,
    STATE(5632), 2,
      sym_comment,
      sym_block_comment,
    STATE(7202), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4542), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [292862] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9151), 1,
      anon_sym_AT,
    STATE(5530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7245), 1,
      sym_annotation,
    STATE(5633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [292910] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9317), 1,
      anon_sym_DOT,
    ACTIONS(9967), 1,
      anon_sym_EQ_GT,
    STATE(5634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [292956] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [292998] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [293082] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9644), 1,
      anon_sym_with,
    STATE(8897), 1,
      aux_sym_compound_type_repeat1,
    STATE(8959), 1,
      sym_template_body,
    STATE(8998), 1,
      sym__refinement,
    STATE(5638), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293134] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4830), 1,
      sym__alpha_identifier,
    ACTIONS(4836), 1,
      anon_sym__,
    ACTIONS(4848), 1,
      sym__backquoted_id,
    ACTIONS(6854), 1,
      sym_operator_identifier,
    ACTIONS(9973), 1,
      anon_sym_LPAREN,
    STATE(5035), 1,
      sym__annotated_type,
    STATE(5061), 1,
      sym__simple_type,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5395), 1,
      sym_identifier,
    STATE(7629), 1,
      sym_annotated_type,
    STATE(8657), 1,
      sym__infix_type_choice,
    STATE(17092), 1,
      sym_stable_identifier,
    STATE(5639), 2,
      sym_comment,
      sym_block_comment,
    STATE(9748), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4842), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5759), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [293202] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293244] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293286] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6940), 1,
      sym__alpha_identifier,
    ACTIONS(6946), 1,
      anon_sym__,
    ACTIONS(6954), 1,
      sym__backquoted_id,
    ACTIONS(6956), 1,
      sym_operator_identifier,
    ACTIONS(9975), 1,
      anon_sym_LPAREN,
    STATE(5622), 1,
      sym__simple_type,
    STATE(6059), 1,
      sym__annotated_type,
    STATE(6376), 1,
      sym__soft_identifier,
    STATE(6428), 1,
      sym_identifier,
    STATE(9297), 1,
      sym_annotated_type,
    STATE(9871), 1,
      sym__infix_type_choice,
    STATE(17774), 1,
      sym_stable_identifier,
    STATE(5642), 2,
      sym_comment,
      sym_block_comment,
    STATE(10491), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7299), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [293354] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [293440] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293482] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293566] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9668), 1,
      anon_sym_LBRACK,
    ACTIONS(9672), 1,
      anon_sym_POUND,
    ACTIONS(9985), 1,
      anon_sym_AT,
    STATE(7100), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7426), 1,
      sym_type_arguments,
    STATE(8898), 1,
      sym_annotation,
    STATE(5648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293620] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8990), 1,
      anon_sym_LPAREN,
    STATE(5663), 1,
      aux_sym_annotation_repeat1,
    STATE(7009), 1,
      sym_arguments,
    STATE(5649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293668] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293710] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9991), 1,
      anon_sym_LBRACK,
    ACTIONS(9993), 1,
      anon_sym_LPAREN,
    ACTIONS(9995), 1,
      anon_sym_POUND,
    STATE(6788), 1,
      aux_sym_annotation_repeat1,
    STATE(7920), 1,
      sym_type_arguments,
    STATE(8331), 1,
      sym_arguments,
    STATE(5651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293764] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8923), 1,
      anon_sym_LPAREN,
    STATE(5666), 1,
      aux_sym_annotation_repeat1,
    STATE(7476), 1,
      sym_arguments,
    STATE(5652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293812] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293854] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [293896] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9997), 1,
      sym__interpolated_multiline_string_start,
    STATE(9920), 1,
      sym_interpolated_string,
    STATE(15352), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293948] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [293992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [294076] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6286), 1,
      sym__alpha_identifier,
    ACTIONS(6288), 1,
      anon_sym__,
    ACTIONS(6296), 1,
      sym__backquoted_id,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    ACTIONS(10003), 1,
      anon_sym_LPAREN,
    STATE(6470), 1,
      sym__simple_type,
    STATE(6838), 1,
      sym__soft_identifier,
    STATE(7030), 1,
      sym__annotated_type,
    STATE(7402), 1,
      sym_identifier,
    STATE(10239), 1,
      sym_annotated_type,
    STATE(10658), 1,
      sym__infix_type_choice,
    STATE(16771), 1,
      sym_stable_identifier,
    STATE(5659), 2,
      sym_comment,
      sym_block_comment,
    STATE(11134), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6292), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7941), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [294144] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__alpha_identifier,
    ACTIONS(4468), 1,
      anon_sym__,
    ACTIONS(4480), 1,
      sym__backquoted_id,
    ACTIONS(6748), 1,
      sym_operator_identifier,
    ACTIONS(10005), 1,
      anon_sym_LPAREN,
    STATE(4970), 1,
      sym__annotated_type,
    STATE(5016), 1,
      sym__simple_type,
    STATE(5231), 1,
      sym_identifier,
    STATE(5328), 1,
      sym__soft_identifier,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(8344), 1,
      sym__infix_type_choice,
    STATE(17379), 1,
      sym_stable_identifier,
    STATE(5660), 2,
      sym_comment,
      sym_block_comment,
    STATE(9918), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6029), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [294212] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10007), 1,
      anon_sym_with,
    STATE(5661), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [294256] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10010), 1,
      anon_sym_with,
    STATE(6700), 1,
      aux_sym_compound_type_repeat1,
    STATE(10100), 1,
      sym_arguments,
    STATE(10307), 1,
      sym__refinement,
    STATE(10308), 1,
      sym_template_body,
    STATE(5662), 2,
      sym_comment,
      sym_block_comment,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [294310] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10012), 1,
      anon_sym_LPAREN,
    STATE(7009), 1,
      sym_arguments,
    STATE(5663), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [294356] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294440] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10023), 1,
      anon_sym_LPAREN,
    STATE(7476), 1,
      sym_arguments,
    STATE(5666), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [294486] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294528] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294570] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294612] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [294656] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(988), 1,
      anon_sym_LBRACE,
    ACTIONS(7876), 1,
      anon_sym_LPAREN,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8569), 1,
      anon_sym_DOT,
    ACTIONS(9337), 1,
      sym__alpha_identifier,
    ACTIONS(9343), 1,
      sym__backquoted_id,
    ACTIONS(9345), 1,
      sym_operator_identifier,
    ACTIONS(10026), 1,
      anon_sym_EQ,
    STATE(581), 1,
      sym_identifier,
    STATE(4080), 1,
      sym__soft_identifier,
    STATE(5671), 2,
      sym_comment,
      sym_block_comment,
    STATE(6534), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9339), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [294722] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9234), 1,
      anon_sym_AT,
    STATE(6013), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7333), 1,
      sym_annotation,
    STATE(5672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [294770] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [294812] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [294854] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294896] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [294938] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9684), 1,
      anon_sym_LBRACK,
    ACTIONS(9690), 1,
      anon_sym_POUND,
    ACTIONS(10028), 1,
      anon_sym_LPAREN,
    STATE(7160), 1,
      aux_sym_annotation_repeat1,
    STATE(7585), 1,
      sym_type_arguments,
    STATE(8891), 1,
      sym_arguments,
    STATE(5677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [294992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [295034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [295076] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10030), 1,
      anon_sym_AT,
    STATE(6786), 1,
      sym_annotation,
    STATE(5680), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [295122] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6510), 1,
      anon_sym__,
    ACTIONS(6518), 1,
      sym__backquoted_id,
    ACTIONS(6520), 1,
      sym_operator_identifier,
    ACTIONS(10033), 1,
      anon_sym_LPAREN,
    STATE(7064), 1,
      sym__simple_type,
    STATE(7393), 1,
      sym__annotated_type,
    STATE(7863), 1,
      sym__soft_identifier,
    STATE(8147), 1,
      sym_identifier,
    STATE(10066), 1,
      sym_annotated_type,
    STATE(10485), 1,
      sym__infix_type_choice,
    STATE(17720), 1,
      sym_stable_identifier,
    STATE(5681), 2,
      sym_comment,
      sym_block_comment,
    STATE(10968), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6514), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [295190] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4342), 1,
      sym__alpha_identifier,
    ACTIONS(4344), 1,
      anon_sym__,
    ACTIONS(4354), 1,
      sym__backquoted_id,
    ACTIONS(6938), 1,
      sym_operator_identifier,
    ACTIONS(10035), 1,
      anon_sym_LPAREN,
    STATE(7255), 1,
      sym__simple_type,
    STATE(7351), 1,
      sym__annotated_type,
    STATE(7539), 1,
      sym__soft_identifier,
    STATE(7904), 1,
      sym_identifier,
    STATE(10219), 1,
      sym_annotated_type,
    STATE(10371), 1,
      sym__infix_type_choice,
    STATE(17364), 1,
      sym_stable_identifier,
    STATE(5682), 2,
      sym_comment,
      sym_block_comment,
    STATE(11171), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4350), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8693), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [295258] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9172), 1,
      anon_sym_AT,
    STATE(5856), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7277), 1,
      sym_annotation,
    STATE(5683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [295306] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6662), 1,
      sym__alpha_identifier,
    ACTIONS(6664), 1,
      anon_sym__,
    ACTIONS(6672), 1,
      sym__backquoted_id,
    ACTIONS(6674), 1,
      sym_operator_identifier,
    ACTIONS(10037), 1,
      anon_sym_LPAREN,
    STATE(4496), 1,
      sym__simple_type,
    STATE(4499), 1,
      sym__annotated_type,
    STATE(4616), 1,
      sym_identifier,
    STATE(4632), 1,
      sym__soft_identifier,
    STATE(5589), 1,
      sym_annotated_type,
    STATE(6454), 1,
      sym__infix_type_choice,
    STATE(17744), 1,
      sym_stable_identifier,
    STATE(5684), 2,
      sym_comment,
      sym_block_comment,
    STATE(7831), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6668), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4799), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [295374] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6716), 1,
      sym__alpha_identifier,
    ACTIONS(6722), 1,
      anon_sym__,
    ACTIONS(6730), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(10039), 1,
      anon_sym_LPAREN,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6131), 1,
      sym__annotated_type,
    STATE(6329), 1,
      sym_identifier,
    STATE(6457), 1,
      sym__soft_identifier,
    STATE(9719), 1,
      sym_annotated_type,
    STATE(9768), 1,
      sym__infix_type_choice,
    STATE(17539), 1,
      sym_stable_identifier,
    STATE(5685), 2,
      sym_comment,
      sym_block_comment,
    STATE(10521), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6726), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7381), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [295442] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4310), 1,
      sym__alpha_identifier,
    ACTIONS(4316), 1,
      anon_sym__,
    ACTIONS(4328), 1,
      sym__backquoted_id,
    ACTIONS(6696), 1,
      sym_operator_identifier,
    ACTIONS(10041), 1,
      anon_sym_LPAREN,
    STATE(4700), 1,
      sym__annotated_type,
    STATE(4737), 1,
      sym__simple_type,
    STATE(4906), 1,
      sym_identifier,
    STATE(5094), 1,
      sym__soft_identifier,
    STATE(6999), 1,
      sym_annotated_type,
    STATE(7546), 1,
      sym__infix_type_choice,
    STATE(17786), 1,
      sym_stable_identifier,
    STATE(5686), 2,
      sym_comment,
      sym_block_comment,
    STATE(9356), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5293), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [295510] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8823), 1,
      sym__interpolated_multiline_string_start,
    STATE(8260), 1,
      sym_interpolated_string,
    STATE(15874), 1,
      sym__interpolated_string_start,
    ACTIONS(10043), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [295562] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10045), 1,
      anon_sym_COLON,
    ACTIONS(10048), 1,
      anon_sym_LBRACE,
    ACTIONS(10050), 1,
      anon_sym_with,
    STATE(5883), 1,
      aux_sym_compound_type_repeat1,
    STATE(10274), 1,
      sym__refinement,
    STATE(10277), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5688), 2,
      sym_comment,
      sym_block_comment,
    STATE(10118), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [295624] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [295666] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [295708] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6772), 1,
      sym__alpha_identifier,
    ACTIONS(6778), 1,
      anon_sym__,
    ACTIONS(6786), 1,
      sym__backquoted_id,
    ACTIONS(6788), 1,
      sym_operator_identifier,
    ACTIONS(10052), 1,
      anon_sym_LPAREN,
    STATE(5829), 1,
      sym__annotated_type,
    STATE(5904), 1,
      sym__simple_type,
    STATE(6418), 1,
      sym__soft_identifier,
    STATE(6643), 1,
      sym_identifier,
    STATE(9119), 1,
      sym_annotated_type,
    STATE(9989), 1,
      sym__infix_type_choice,
    STATE(17852), 1,
      sym_stable_identifier,
    STATE(5691), 2,
      sym_comment,
      sym_block_comment,
    STATE(10641), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6782), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7485), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [295776] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8964), 1,
      anon_sym_LPAREN,
    STATE(5570), 1,
      aux_sym_annotation_repeat1,
    STATE(7151), 1,
      sym_arguments,
    STATE(5692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [295824] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4660), 1,
      sym__alpha_identifier,
    ACTIONS(4666), 1,
      anon_sym__,
    ACTIONS(4678), 1,
      sym__backquoted_id,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    ACTIONS(10054), 1,
      anon_sym_LPAREN,
    STATE(4446), 1,
      sym__simple_type,
    STATE(4461), 1,
      sym__annotated_type,
    STATE(4601), 1,
      sym__soft_identifier,
    STATE(4620), 1,
      sym_identifier,
    STATE(6053), 1,
      sym_annotated_type,
    STATE(6556), 1,
      sym__infix_type_choice,
    STATE(16896), 1,
      sym_stable_identifier,
    STATE(5693), 2,
      sym_comment,
      sym_block_comment,
    STATE(8185), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4672), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4757), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [295892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [295934] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10056), 1,
      anon_sym_DOT,
    STATE(5695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [295978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [296020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296062] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8853), 1,
      anon_sym_AT,
    STATE(5546), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7229), 1,
      sym_annotation,
    STATE(5698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [296110] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [296152] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296194] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296236] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4886), 1,
      sym__alpha_identifier,
    ACTIONS(4892), 1,
      anon_sym__,
    ACTIONS(4904), 1,
      sym__backquoted_id,
    ACTIONS(6660), 1,
      sym_operator_identifier,
    ACTIONS(10058), 1,
      anon_sym_LPAREN,
    STATE(4668), 1,
      sym__simple_type,
    STATE(4669), 1,
      sym__annotated_type,
    STATE(5003), 1,
      sym_identifier,
    STATE(5087), 1,
      sym__soft_identifier,
    STATE(7155), 1,
      sym_annotated_type,
    STATE(7799), 1,
      sym__infix_type_choice,
    STATE(17828), 1,
      sym_stable_identifier,
    STATE(5702), 2,
      sym_comment,
      sym_block_comment,
    STATE(9096), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5448), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [296304] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296346] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296388] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [296430] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    ACTIONS(10060), 1,
      anon_sym_LPAREN,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7773), 1,
      sym__annotated_type,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(10671), 1,
      sym__infix_type_choice,
    STATE(17050), 1,
      sym_stable_identifier,
    STATE(5706), 2,
      sym_comment,
      sym_block_comment,
    STATE(11209), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [296498] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296540] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9170), 1,
      anon_sym_AT,
    STATE(5680), 1,
      aux_sym_enum_definition_repeat1,
    STATE(6786), 1,
      sym_annotation,
    STATE(5708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296588] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6336), 1,
      sym__alpha_identifier,
    ACTIONS(6342), 1,
      anon_sym__,
    ACTIONS(6350), 1,
      sym__backquoted_id,
    ACTIONS(6352), 1,
      sym_operator_identifier,
    ACTIONS(10062), 1,
      anon_sym_LPAREN,
    STATE(5877), 1,
      sym__annotated_type,
    STATE(5944), 1,
      sym__simple_type,
    STATE(6347), 1,
      sym__soft_identifier,
    STATE(6696), 1,
      sym_identifier,
    STATE(9248), 1,
      sym_annotated_type,
    STATE(9985), 1,
      sym__infix_type_choice,
    STATE(17708), 1,
      sym_stable_identifier,
    STATE(5709), 2,
      sym_comment,
      sym_block_comment,
    STATE(10636), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6346), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7084), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [296656] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [296698] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9713), 1,
      anon_sym_LBRACK,
    ACTIONS(9717), 1,
      anon_sym_POUND,
    ACTIONS(10064), 1,
      anon_sym_AT,
    STATE(7196), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7380), 1,
      sym_type_arguments,
    STATE(8504), 1,
      sym_annotation,
    STATE(5711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [296752] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9455), 1,
      anon_sym_with,
    STATE(8588), 1,
      aux_sym_compound_type_repeat1,
    STATE(9624), 1,
      sym__refinement,
    STATE(9646), 1,
      sym_template_body,
    STATE(5712), 2,
      sym_comment,
      sym_block_comment,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [296804] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [296846] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [296888] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [296930] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1978), 1,
      anon_sym_LBRACE,
    ACTIONS(9134), 1,
      anon_sym_LPAREN,
    ACTIONS(9947), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5716), 2,
      sym_comment,
      sym_block_comment,
    STATE(9158), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8191), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [296984] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10066), 1,
      anon_sym_DOT,
    STATE(5717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297070] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1678), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9050), 1,
      anon_sym_LPAREN,
    ACTIONS(10068), 1,
      anon_sym_DOT,
    ACTIONS(10070), 1,
      sym_operator_identifier,
    STATE(1803), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5719), 2,
      sym_comment,
      sym_block_comment,
    STATE(9555), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [297136] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8567), 1,
      sym__interpolated_multiline_string_start,
    STATE(7326), 1,
      sym_interpolated_string,
    STATE(16092), 1,
      sym__interpolated_string_start,
    ACTIONS(10072), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [297188] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(10074), 1,
      anon_sym_LPAREN,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(7466), 1,
      sym__annotated_type,
    STATE(10266), 1,
      sym__infix_type_choice,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(17249), 1,
      sym_stable_identifier,
    STATE(5721), 2,
      sym_comment,
      sym_block_comment,
    STATE(10786), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [297256] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297298] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10076), 1,
      sym__interpolated_multiline_string_start,
    STATE(9806), 1,
      sym_interpolated_string,
    STATE(16222), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [297350] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8823), 1,
      sym__interpolated_multiline_string_start,
    STATE(8260), 1,
      sym_interpolated_string,
    STATE(15874), 1,
      sym__interpolated_string_start,
    ACTIONS(10078), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [297402] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [297446] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6268), 1,
      sym__alpha_identifier,
    ACTIONS(6274), 1,
      anon_sym__,
    ACTIONS(6282), 1,
      sym__backquoted_id,
    ACTIONS(6284), 1,
      sym_operator_identifier,
    ACTIONS(10080), 1,
      anon_sym_LPAREN,
    STATE(5225), 1,
      sym__annotated_type,
    STATE(5337), 1,
      sym__simple_type,
    STATE(5695), 1,
      sym_identifier,
    STATE(5862), 1,
      sym__soft_identifier,
    STATE(8317), 1,
      sym_annotated_type,
    STATE(8939), 1,
      sym__infix_type_choice,
    STATE(17690), 1,
      sym_stable_identifier,
    STATE(5726), 2,
      sym_comment,
      sym_block_comment,
    STATE(10169), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6278), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6225), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [297514] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [297556] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9736), 1,
      anon_sym_with,
    STATE(8382), 1,
      aux_sym_compound_type_repeat1,
    STATE(9681), 1,
      sym__refinement,
    STATE(9696), 1,
      sym_template_body,
    STATE(5728), 2,
      sym_comment,
      sym_block_comment,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [297608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297650] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4214), 1,
      sym__alpha_identifier,
    ACTIONS(4220), 1,
      anon_sym__,
    ACTIONS(4232), 1,
      sym__backquoted_id,
    ACTIONS(6752), 1,
      sym_operator_identifier,
    ACTIONS(10082), 1,
      anon_sym_LPAREN,
    STATE(4653), 1,
      sym__simple_type,
    STATE(4713), 1,
      sym__annotated_type,
    STATE(4914), 1,
      sym_identifier,
    STATE(5031), 1,
      sym__soft_identifier,
    STATE(6990), 1,
      sym_annotated_type,
    STATE(7580), 1,
      sym__infix_type_choice,
    STATE(17054), 1,
      sym_stable_identifier,
    STATE(5730), 2,
      sym_comment,
      sym_block_comment,
    STATE(9242), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4226), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5167), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [297718] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [297760] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    ACTIONS(10084), 1,
      anon_sym_LPAREN,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(7909), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(10854), 1,
      sym__infix_type_choice,
    STATE(16743), 1,
      sym_stable_identifier,
    STATE(5732), 2,
      sym_comment,
      sym_block_comment,
    STATE(10943), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [297828] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [297870] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [297912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [297954] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [297996] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298040] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9753), 1,
      anon_sym_COLON,
    ACTIONS(9755), 1,
      anon_sym_LBRACE,
    ACTIONS(9757), 1,
      anon_sym_with,
    STATE(8361), 1,
      aux_sym_compound_type_repeat1,
    STATE(10372), 1,
      sym_template_body,
    STATE(10435), 1,
      sym__refinement,
    STATE(5738), 2,
      sym_comment,
      sym_block_comment,
    STATE(10666), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298096] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298138] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9684), 1,
      anon_sym_LBRACK,
    ACTIONS(9686), 1,
      anon_sym_AT,
    ACTIONS(9690), 1,
      anon_sym_POUND,
    STATE(7049), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7585), 1,
      sym_type_arguments,
    STATE(8395), 1,
      sym_annotation,
    STATE(5740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298192] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9269), 1,
      anon_sym_LBRACK,
    ACTIONS(9271), 1,
      anon_sym_AT,
    ACTIONS(9275), 1,
      anon_sym_POUND,
    STATE(7421), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(8350), 1,
      sym_annotation,
    STATE(5741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [298246] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    ACTIONS(10084), 1,
      anon_sym_LPAREN,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(8025), 1,
      sym__annotated_type,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(10633), 1,
      sym__infix_type_choice,
    STATE(16743), 1,
      sym_stable_identifier,
    STATE(5742), 2,
      sym_comment,
      sym_block_comment,
    STATE(10943), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [298314] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298356] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298440] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298482] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298566] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6444), 1,
      sym_arguments,
    STATE(5749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298610] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6566), 1,
      anon_sym__,
    ACTIONS(6574), 1,
      sym__backquoted_id,
    ACTIONS(6576), 1,
      sym_operator_identifier,
    ACTIONS(10086), 1,
      anon_sym_LPAREN,
    STATE(5238), 1,
      sym__simple_type,
    STATE(5350), 1,
      sym__annotated_type,
    STATE(5717), 1,
      sym_identifier,
    STATE(6060), 1,
      sym__soft_identifier,
    STATE(8512), 1,
      sym_annotated_type,
    STATE(9202), 1,
      sym__infix_type_choice,
    STATE(17417), 1,
      sym_stable_identifier,
    STATE(5750), 2,
      sym_comment,
      sym_block_comment,
    STATE(10052), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6570), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6110), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [298678] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298720] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6202), 1,
      sym__alpha_identifier,
    ACTIONS(6208), 1,
      anon_sym__,
    ACTIONS(6216), 1,
      sym__backquoted_id,
    ACTIONS(6218), 1,
      sym_operator_identifier,
    ACTIONS(10088), 1,
      anon_sym_LPAREN,
    STATE(8726), 1,
      sym__simple_type,
    STATE(9074), 1,
      sym__annotated_type,
    STATE(9360), 1,
      sym_identifier,
    STATE(9455), 1,
      sym__soft_identifier,
    STATE(11142), 1,
      sym_annotated_type,
    STATE(11357), 1,
      sym__infix_type_choice,
    STATE(17822), 1,
      sym_stable_identifier,
    STATE(5752), 2,
      sym_comment,
      sym_block_comment,
    STATE(11840), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6212), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9589), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [298788] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298830] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298872] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10090), 1,
      anon_sym_DOT,
    STATE(5755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [298916] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [298958] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(9744), 1,
      anon_sym_LPAREN,
    STATE(5162), 1,
      sym__annotated_type,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(11998), 1,
      sym__infix_type_choice,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(5757), 2,
      sym_comment,
      sym_block_comment,
    STATE(10231), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [299026] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6584), 1,
      anon_sym__,
    ACTIONS(6592), 1,
      sym__backquoted_id,
    ACTIONS(6594), 1,
      sym_operator_identifier,
    ACTIONS(10092), 1,
      anon_sym_LPAREN,
    STATE(5523), 1,
      sym__simple_type,
    STATE(6000), 1,
      sym__annotated_type,
    STATE(6385), 1,
      sym__soft_identifier,
    STATE(6582), 1,
      sym_identifier,
    STATE(9185), 1,
      sym_annotated_type,
    STATE(9637), 1,
      sym__infix_type_choice,
    STATE(17792), 1,
      sym_stable_identifier,
    STATE(5758), 2,
      sym_comment,
      sym_block_comment,
    STATE(10637), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6588), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7364), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [299094] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [299136] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4562), 1,
      sym__alpha_identifier,
    ACTIONS(4568), 1,
      anon_sym__,
    ACTIONS(4580), 1,
      sym__backquoted_id,
    ACTIONS(6770), 1,
      sym_operator_identifier,
    ACTIONS(10094), 1,
      anon_sym_LPAREN,
    STATE(5206), 1,
      sym__annotated_type,
    STATE(5319), 1,
      sym__simple_type,
    STATE(5571), 1,
      sym_identifier,
    STATE(5868), 1,
      sym__soft_identifier,
    STATE(8394), 1,
      sym_annotated_type,
    STATE(9579), 1,
      sym__infix_type_choice,
    STATE(17678), 1,
      sym_stable_identifier,
    STATE(5760), 2,
      sym_comment,
      sym_block_comment,
    STATE(10115), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4574), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6389), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [299204] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1978), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9134), 1,
      anon_sym_LPAREN,
    ACTIONS(9947), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5761), 2,
      sym_comment,
      sym_block_comment,
    STATE(9158), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8171), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [299260] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [299302] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10096), 1,
      anon_sym_COLON,
    ACTIONS(10098), 1,
      anon_sym_LBRACE,
    ACTIONS(10100), 1,
      anon_sym_with,
    STATE(8742), 1,
      aux_sym_compound_type_repeat1,
    STATE(10618), 1,
      sym_template_body,
    STATE(10623), 1,
      sym__refinement,
    STATE(5763), 2,
      sym_comment,
      sym_block_comment,
    STATE(10481), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [299358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299400] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299442] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10102), 1,
      anon_sym_with,
    STATE(6474), 1,
      aux_sym_compound_type_repeat1,
    STATE(10276), 1,
      sym_arguments,
    STATE(10312), 1,
      sym_template_body,
    STATE(10313), 1,
      sym__refinement,
    STATE(5766), 2,
      sym_comment,
      sym_block_comment,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [299496] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10104), 1,
      anon_sym_DOT,
    STATE(5767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [299540] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299582] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(10106), 1,
      anon_sym_LPAREN,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6089), 1,
      sym__annotated_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(9992), 1,
      sym__infix_type_choice,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(5769), 2,
      sym_comment,
      sym_block_comment,
    STATE(10406), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [299650] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299692] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8947), 1,
      anon_sym_LPAREN,
    ACTIONS(10108), 1,
      sym__alpha_identifier,
    ACTIONS(10110), 1,
      anon_sym_DOT,
    ACTIONS(10114), 1,
      anon_sym_EQ,
    ACTIONS(10116), 1,
      sym__backquoted_id,
    ACTIONS(10118), 1,
      sym_operator_identifier,
    STATE(590), 1,
      sym_identifier,
    STATE(4176), 1,
      sym__soft_identifier,
    STATE(5771), 2,
      sym_comment,
      sym_block_comment,
    STATE(9005), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10112), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [299758] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [299800] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299842] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9269), 1,
      anon_sym_LBRACK,
    ACTIONS(9275), 1,
      anon_sym_POUND,
    ACTIONS(10120), 1,
      anon_sym_LPAREN,
    STATE(7110), 1,
      aux_sym_annotation_repeat1,
    STATE(7547), 1,
      sym_type_arguments,
    STATE(8744), 1,
      sym_arguments,
    STATE(5774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [299896] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [299938] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [299980] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300022] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300064] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9748), 1,
      sym__interpolated_multiline_string_start,
    STATE(9649), 1,
      sym_interpolated_string,
    STATE(16063), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300158] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300200] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [300284] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5632), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(5784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300330] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10048), 1,
      anon_sym_LBRACE,
    ACTIONS(10050), 1,
      anon_sym_with,
    STATE(5883), 1,
      aux_sym_compound_type_repeat1,
    STATE(10274), 1,
      sym__refinement,
    STATE(10277), 1,
      sym_template_body,
    STATE(5785), 2,
      sym_comment,
      sym_block_comment,
    STATE(10118), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300384] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300468] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [300510] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300552] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300594] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9014), 1,
      anon_sym_LPAREN,
    STATE(5801), 1,
      aux_sym_annotation_repeat1,
    STATE(7463), 1,
      sym_arguments,
    STATE(5791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300642] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10126), 1,
      anon_sym_COLON,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    ACTIONS(10130), 1,
      anon_sym_with,
    STATE(5804), 1,
      aux_sym_compound_type_repeat1,
    STATE(10451), 1,
      sym__refinement,
    STATE(10455), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5792), 2,
      sym_comment,
      sym_block_comment,
    STATE(10552), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7882), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_finally,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300704] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [300788] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300832] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10132), 1,
      anon_sym_LPAREN,
    STATE(7146), 1,
      sym_arguments,
    STATE(5796), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [300878] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [300920] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6528), 1,
      sym__alpha_identifier,
    ACTIONS(6530), 1,
      anon_sym__,
    ACTIONS(6538), 1,
      sym__backquoted_id,
    ACTIONS(6540), 1,
      sym_operator_identifier,
    ACTIONS(10135), 1,
      anon_sym_LPAREN,
    STATE(7390), 1,
      sym__simple_type,
    STATE(7648), 1,
      sym__annotated_type,
    STATE(7921), 1,
      sym_identifier,
    STATE(7952), 1,
      sym__soft_identifier,
    STATE(10528), 1,
      sym_annotated_type,
    STATE(10609), 1,
      sym__infix_type_choice,
    STATE(17028), 1,
      sym_stable_identifier,
    STATE(5798), 2,
      sym_comment,
      sym_block_comment,
    STATE(11013), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6534), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8432), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [300988] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [301030] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301072] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10137), 1,
      anon_sym_LPAREN,
    STATE(7463), 1,
      sym_arguments,
    STATE(5801), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301118] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301160] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9568), 1,
      anon_sym_LBRACK,
    ACTIONS(9572), 1,
      anon_sym_POUND,
    ACTIONS(10140), 1,
      anon_sym_AT,
    STATE(6911), 1,
      sym_type_arguments,
    STATE(7624), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9040), 1,
      sym_annotation,
    STATE(5803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301214] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10126), 1,
      anon_sym_COLON,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    ACTIONS(10130), 1,
      anon_sym_with,
    STATE(8818), 1,
      aux_sym_compound_type_repeat1,
    STATE(10445), 1,
      sym__refinement,
    STATE(10455), 1,
      sym_template_body,
    STATE(5804), 2,
      sym_comment,
      sym_block_comment,
    STATE(10552), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301270] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [301354] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [301396] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10142), 1,
      anon_sym_LPAREN,
    STATE(6903), 1,
      sym_arguments,
    STATE(5808), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [301442] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301484] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301526] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9060), 1,
      anon_sym_LPAREN,
    STATE(5808), 1,
      aux_sym_annotation_repeat1,
    STATE(6903), 1,
      sym_arguments,
    STATE(5811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [301574] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301616] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [301658] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym__,
    ACTIONS(6610), 1,
      sym__backquoted_id,
    ACTIONS(6612), 1,
      sym_operator_identifier,
    ACTIONS(10145), 1,
      anon_sym_LPAREN,
    STATE(6395), 1,
      sym__annotated_type,
    STATE(6433), 1,
      sym__simple_type,
    STATE(7134), 1,
      sym__soft_identifier,
    STATE(7495), 1,
      sym_identifier,
    STATE(9897), 1,
      sym_annotated_type,
    STATE(10213), 1,
      sym__infix_type_choice,
    STATE(17864), 1,
      sym_stable_identifier,
    STATE(5814), 2,
      sym_comment,
      sym_block_comment,
    STATE(10760), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7557), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [301726] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10147), 1,
      anon_sym_AT,
    STATE(7249), 1,
      sym_annotation,
    STATE(5815), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301772] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9198), 1,
      anon_sym_LPAREN,
    STATE(5796), 1,
      aux_sym_annotation_repeat1,
    STATE(7146), 1,
      sym_arguments,
    STATE(5816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301820] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10150), 1,
      anon_sym_COLON,
    ACTIONS(10153), 1,
      anon_sym_LBRACE,
    STATE(7733), 1,
      sym_template_body,
    STATE(5817), 2,
      sym_comment,
      sym_block_comment,
    STATE(8149), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 7,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 15,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [301870] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10156), 1,
      anon_sym_DOT,
    STATE(5818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [301914] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [301958] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302000] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1748), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9161), 1,
      anon_sym_LPAREN,
    ACTIONS(10158), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5821), 2,
      sym_comment,
      sym_block_comment,
    STATE(9210), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302098] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302140] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [302182] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [302224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302308] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302350] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10126), 1,
      anon_sym_COLON,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    ACTIONS(10130), 1,
      anon_sym_with,
    STATE(5804), 1,
      aux_sym_compound_type_repeat1,
    STATE(10451), 1,
      sym__refinement,
    STATE(10455), 1,
      sym_template_body,
    STATE(5829), 2,
      sym_comment,
      sym_block_comment,
    STATE(10552), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302406] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [302448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [302490] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302532] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9606), 1,
      anon_sym_LBRACK,
    ACTIONS(9608), 1,
      anon_sym_AT,
    ACTIONS(9612), 1,
      anon_sym_POUND,
    STATE(6790), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7943), 1,
      sym_type_arguments,
    STATE(8476), 1,
      sym_annotation,
    STATE(5833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302586] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10160), 1,
      anon_sym_with,
    STATE(5834), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [302630] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10163), 1,
      anon_sym_COLON,
    ACTIONS(10165), 1,
      anon_sym_LBRACE,
    ACTIONS(10167), 1,
      anon_sym_with,
    STATE(5911), 1,
      aux_sym_compound_type_repeat1,
    STATE(10638), 1,
      sym_template_body,
    STATE(10643), 1,
      sym__refinement,
    STATE(5835), 2,
      sym_comment,
      sym_block_comment,
    STATE(10624), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302686] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [302728] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4594), 1,
      sym__alpha_identifier,
    ACTIONS(4600), 1,
      anon_sym__,
    ACTIONS(4612), 1,
      sym__backquoted_id,
    ACTIONS(6252), 1,
      sym_operator_identifier,
    ACTIONS(10169), 1,
      anon_sym_LPAREN,
    STATE(5033), 1,
      sym__annotated_type,
    STATE(5090), 1,
      sym__simple_type,
    STATE(5125), 1,
      sym_identifier,
    STATE(5264), 1,
      sym__soft_identifier,
    STATE(7582), 1,
      sym_annotated_type,
    STATE(8599), 1,
      sym__infix_type_choice,
    STATE(17492), 1,
      sym_stable_identifier,
    STATE(5837), 2,
      sym_comment,
      sym_block_comment,
    STATE(9622), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5951), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [302796] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10171), 1,
      anon_sym_LBRACK,
    ACTIONS(10173), 1,
      anon_sym_LPAREN,
    ACTIONS(10175), 1,
      anon_sym_POUND,
    STATE(7994), 1,
      sym_type_arguments,
    STATE(8056), 1,
      aux_sym_annotation_repeat1,
    STATE(9307), 1,
      sym_arguments,
    STATE(5838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302850] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [302892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [302934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [302976] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    ACTIONS(10177), 1,
      anon_sym_LPAREN,
    STATE(4972), 1,
      sym__annotated_type,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(8393), 1,
      sym__infix_type_choice,
    STATE(16918), 1,
      sym_stable_identifier,
    STATE(5842), 2,
      sym_comment,
      sym_block_comment,
    STATE(9866), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [303044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [303086] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [303128] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [303170] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4422), 1,
      sym__alpha_identifier,
    ACTIONS(4428), 1,
      anon_sym__,
    ACTIONS(4440), 1,
      sym__backquoted_id,
    ACTIONS(6200), 1,
      sym_operator_identifier,
    ACTIONS(10179), 1,
      anon_sym_LPAREN,
    STATE(5648), 1,
      sym__simple_type,
    STATE(5958), 1,
      sym__annotated_type,
    STATE(6343), 1,
      sym_identifier,
    STATE(6399), 1,
      sym__soft_identifier,
    STATE(9039), 1,
      sym_annotated_type,
    STATE(9750), 1,
      sym__infix_type_choice,
    STATE(17810), 1,
      sym_stable_identifier,
    STATE(5846), 2,
      sym_comment,
      sym_block_comment,
    STATE(10381), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4434), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7419), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [303238] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1340), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(9395), 1,
      anon_sym_DOT,
    ACTIONS(9810), 1,
      sym__alpha_identifier,
    ACTIONS(9816), 1,
      sym__backquoted_id,
    ACTIONS(9818), 1,
      sym_operator_identifier,
    ACTIONS(10181), 1,
      anon_sym_EQ,
    STATE(592), 1,
      sym_identifier,
    STATE(4173), 1,
      sym__soft_identifier,
    STATE(5847), 2,
      sym_comment,
      sym_block_comment,
    STATE(8867), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9812), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [303304] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [303346] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10183), 1,
      sym__interpolated_multiline_string_start,
    STATE(9974), 1,
      sym_interpolated_string,
    STATE(15927), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [303398] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4692), 1,
      sym__alpha_identifier,
    ACTIONS(4694), 1,
      anon_sym__,
    ACTIONS(4704), 1,
      sym__backquoted_id,
    ACTIONS(6358), 1,
      sym_operator_identifier,
    ACTIONS(10185), 1,
      anon_sym_LPAREN,
    STATE(4470), 1,
      sym__simple_type,
    STATE(4514), 1,
      sym__annotated_type,
    STATE(4547), 1,
      sym__soft_identifier,
    STATE(4621), 1,
      sym_identifier,
    STATE(5917), 1,
      sym_annotated_type,
    STATE(6187), 1,
      sym__infix_type_choice,
    STATE(17816), 1,
      sym_stable_identifier,
    STATE(5850), 2,
      sym_comment,
      sym_block_comment,
    STATE(7702), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4739), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [303466] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10187), 1,
      anon_sym_LBRACE,
    ACTIONS(10189), 1,
      anon_sym_with,
    STATE(8326), 1,
      aux_sym_compound_type_repeat1,
    STATE(10029), 1,
      sym_template_body,
    STATE(10033), 1,
      sym__refinement,
    STATE(5851), 2,
      sym_comment,
      sym_block_comment,
    STATE(10034), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303520] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [303562] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [303604] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10191), 1,
      anon_sym_with,
    STATE(5854), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [303648] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9220), 1,
      sym__interpolated_multiline_string_start,
    STATE(8549), 1,
      sym_interpolated_string,
    STATE(16193), 1,
      sym__interpolated_string_start,
    ACTIONS(10194), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303700] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10196), 1,
      anon_sym_AT,
    STATE(7277), 1,
      sym_annotation,
    STATE(5856), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [303746] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6632), 1,
      sym__alpha_identifier,
    ACTIONS(6638), 1,
      anon_sym__,
    ACTIONS(6646), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(10199), 1,
      anon_sym_LPAREN,
    STATE(5803), 1,
      sym__simple_type,
    STATE(6337), 1,
      sym_identifier,
    STATE(6487), 1,
      sym__annotated_type,
    STATE(6537), 1,
      sym__soft_identifier,
    STATE(9656), 1,
      sym_annotated_type,
    STATE(9890), 1,
      sym__infix_type_choice,
    STATE(16798), 1,
      sym_stable_identifier,
    STATE(5857), 2,
      sym_comment,
      sym_block_comment,
    STATE(10595), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6642), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6924), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [303814] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9218), 1,
      anon_sym_AT,
    STATE(6081), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7345), 1,
      sym_annotation,
    STATE(5858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303862] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10201), 1,
      anon_sym_DOT,
    STATE(5859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [303906] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10187), 1,
      anon_sym_LBRACE,
    ACTIONS(10189), 1,
      anon_sym_with,
    ACTIONS(10203), 1,
      anon_sym_COLON,
    STATE(5851), 1,
      aux_sym_compound_type_repeat1,
    STATE(10027), 1,
      sym__refinement,
    STATE(10029), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5860), 2,
      sym_comment,
      sym_block_comment,
    STATE(10034), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [303968] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304010] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304052] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304094] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [304136] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304178] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1678), 1,
      anon_sym_LBRACE,
    ACTIONS(9050), 1,
      anon_sym_LPAREN,
    ACTIONS(10068), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5866), 2,
      sym_comment,
      sym_block_comment,
    STATE(9555), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304232] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304316] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10206), 1,
      anon_sym_COLON,
    ACTIONS(10208), 1,
      anon_sym_LBRACE,
    ACTIONS(10210), 1,
      anon_sym_with,
    STATE(8422), 1,
      aux_sym_compound_type_repeat1,
    STATE(10469), 1,
      sym_template_body,
    STATE(10478), 1,
      sym__refinement,
    STATE(5869), 2,
      sym_comment,
      sym_block_comment,
    STATE(10657), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304372] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304414] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304456] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304498] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10212), 1,
      anon_sym_with,
    STATE(5873), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304542] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    ACTIONS(10215), 1,
      anon_sym_LPAREN,
    STATE(7533), 1,
      sym__simple_type,
    STATE(8587), 1,
      sym__annotated_type,
    STATE(8692), 1,
      sym_identifier,
    STATE(8795), 1,
      sym__soft_identifier,
    STATE(10744), 1,
      sym_annotated_type,
    STATE(10745), 1,
      sym__infix_type_choice,
    STATE(17006), 1,
      sym_stable_identifier,
    STATE(5874), 2,
      sym_comment,
      sym_block_comment,
    STATE(11350), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [304610] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304652] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304694] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10206), 1,
      anon_sym_COLON,
    ACTIONS(10208), 1,
      anon_sym_LBRACE,
    ACTIONS(10210), 1,
      anon_sym_with,
    STATE(5869), 1,
      aux_sym_compound_type_repeat1,
    STATE(10469), 1,
      sym_template_body,
    STATE(10470), 1,
      sym__refinement,
    STATE(5877), 2,
      sym_comment,
      sym_block_comment,
    STATE(10657), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [304750] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10217), 1,
      anon_sym_AT,
    STATE(7343), 1,
      sym_annotation,
    STATE(5878), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [304796] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304838] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304880] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [304922] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [304964] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10048), 1,
      anon_sym_LBRACE,
    ACTIONS(10050), 1,
      anon_sym_with,
    STATE(8713), 1,
      aux_sym_compound_type_repeat1,
    STATE(10264), 1,
      sym__refinement,
    STATE(10277), 1,
      sym_template_body,
    STATE(5883), 2,
      sym_comment,
      sym_block_comment,
    STATE(10118), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305060] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6402), 1,
      sym__alpha_identifier,
    ACTIONS(6408), 1,
      anon_sym__,
    ACTIONS(6416), 1,
      sym__backquoted_id,
    ACTIONS(6418), 1,
      sym_operator_identifier,
    ACTIONS(10224), 1,
      anon_sym_LPAREN,
    STATE(5166), 1,
      sym__annotated_type,
    STATE(5296), 1,
      sym__simple_type,
    STATE(5859), 1,
      sym_identifier,
    STATE(5895), 1,
      sym__soft_identifier,
    STATE(8665), 1,
      sym_annotated_type,
    STATE(9364), 1,
      sym__infix_type_choice,
    STATE(17654), 1,
      sym_stable_identifier,
    STATE(5885), 2,
      sym_comment,
      sym_block_comment,
    STATE(10075), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6775), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [305128] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305212] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10230), 1,
      anon_sym_LBRACK,
    ACTIONS(10232), 1,
      anon_sym_LPAREN,
    ACTIONS(10234), 1,
      anon_sym_POUND,
    STATE(7677), 1,
      aux_sym_annotation_repeat1,
    STATE(7766), 1,
      sym_type_arguments,
    STATE(9142), 1,
      sym_arguments,
    STATE(5888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305308] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10236), 1,
      anon_sym_LBRACK,
    ACTIONS(10238), 1,
      anon_sym_LPAREN,
    ACTIONS(10240), 1,
      anon_sym_POUND,
    STATE(7386), 1,
      aux_sym_annotation_repeat1,
    STATE(7559), 1,
      sym_type_arguments,
    STATE(8367), 1,
      sym_arguments,
    STATE(5890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305362] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [305404] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305446] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305488] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305530] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [305572] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305616] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305658] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [305700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [305742] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10246), 1,
      anon_sym_AT,
    STATE(7156), 1,
      sym_annotation,
    STATE(5900), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [305788] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [305830] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [305872] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4868), 1,
      sym__alpha_identifier,
    ACTIONS(4870), 1,
      anon_sym__,
    ACTIONS(4880), 1,
      sym__backquoted_id,
    ACTIONS(6850), 1,
      sym_operator_identifier,
    ACTIONS(10249), 1,
      anon_sym_LPAREN,
    STATE(5113), 1,
      sym__simple_type,
    STATE(5193), 1,
      sym__annotated_type,
    STATE(5536), 1,
      sym_identifier,
    STATE(5967), 1,
      sym__soft_identifier,
    STATE(8739), 1,
      sym_annotated_type,
    STATE(9352), 1,
      sym__infix_type_choice,
    STATE(17570), 1,
      sym_stable_identifier,
    STATE(5903), 2,
      sym_comment,
      sym_block_comment,
    STATE(10174), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6401), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [305940] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9591), 1,
      anon_sym_LBRACK,
    ACTIONS(9595), 1,
      anon_sym_POUND,
    ACTIONS(10251), 1,
      anon_sym_AT,
    STATE(7212), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7481), 1,
      sym_type_arguments,
    STATE(8755), 1,
      sym_annotation,
    STATE(5904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [305994] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [306036] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [306080] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [306122] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [306164] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1228), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8719), 1,
      anon_sym_LPAREN,
    ACTIONS(9658), 1,
      anon_sym_DOT,
    ACTIONS(9858), 1,
      sym__alpha_identifier,
    ACTIONS(9864), 1,
      sym__backquoted_id,
    ACTIONS(9866), 1,
      sym_operator_identifier,
    ACTIONS(10257), 1,
      anon_sym_EQ,
    STATE(588), 1,
      sym_identifier,
    STATE(4168), 1,
      sym__soft_identifier,
    STATE(5909), 2,
      sym_comment,
      sym_block_comment,
    STATE(8854), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9860), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [306230] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10259), 1,
      anon_sym_LBRACK,
    ACTIONS(10261), 1,
      anon_sym_LPAREN,
    ACTIONS(10263), 1,
      anon_sym_POUND,
    STATE(7372), 1,
      aux_sym_annotation_repeat1,
    STATE(8151), 1,
      sym_type_arguments,
    STATE(8341), 1,
      sym_arguments,
    STATE(5910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306284] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10163), 1,
      anon_sym_COLON,
    ACTIONS(10165), 1,
      anon_sym_LBRACE,
    ACTIONS(10167), 1,
      anon_sym_with,
    STATE(8497), 1,
      aux_sym_compound_type_repeat1,
    STATE(10638), 1,
      sym_template_body,
    STATE(10639), 1,
      sym__refinement,
    STATE(5911), 2,
      sym_comment,
      sym_block_comment,
    STATE(10624), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306340] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4530), 1,
      sym__alpha_identifier,
    ACTIONS(4536), 1,
      anon_sym__,
    ACTIONS(4548), 1,
      sym__backquoted_id,
    ACTIONS(6526), 1,
      sym_operator_identifier,
    ACTIONS(10265), 1,
      anon_sym_LPAREN,
    STATE(5186), 1,
      sym__annotated_type,
    STATE(5311), 1,
      sym__simple_type,
    STATE(5882), 1,
      sym__soft_identifier,
    STATE(5987), 1,
      sym_identifier,
    STATE(8575), 1,
      sym_annotated_type,
    STATE(9022), 1,
      sym__infix_type_choice,
    STATE(17666), 1,
      sym_stable_identifier,
    STATE(5912), 2,
      sym_comment,
      sym_block_comment,
    STATE(10031), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4542), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6618), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [306408] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [306450] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10267), 1,
      anon_sym_LPAREN,
    STATE(4529), 1,
      sym_arguments,
    STATE(5914), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 24,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [306494] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [306536] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1748), 1,
      anon_sym_LBRACE,
    ACTIONS(9161), 1,
      anon_sym_LPAREN,
    ACTIONS(10158), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5916), 2,
      sym_comment,
      sym_block_comment,
    STATE(9210), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [306632] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306674] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [306716] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [306758] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4812), 1,
      sym__alpha_identifier,
    ACTIONS(4814), 1,
      anon_sym__,
    ACTIONS(4824), 1,
      sym__backquoted_id,
    ACTIONS(6598), 1,
      sym_operator_identifier,
    ACTIONS(10270), 1,
      anon_sym_LPAREN,
    STATE(5711), 1,
      sym__simple_type,
    STATE(5835), 1,
      sym__annotated_type,
    STATE(6255), 1,
      sym_identifier,
    STATE(6330), 1,
      sym__soft_identifier,
    STATE(9582), 1,
      sym_annotated_type,
    STATE(9588), 1,
      sym__infix_type_choice,
    STATE(16701), 1,
      sym_stable_identifier,
    STATE(5921), 2,
      sym_comment,
      sym_block_comment,
    STATE(10550), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4820), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7403), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [306826] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306868] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [306910] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9763), 1,
      anon_sym_COLON,
    ACTIONS(9765), 1,
      anon_sym_LBRACE,
    ACTIONS(9767), 1,
      anon_sym_with,
    STATE(5512), 1,
      aux_sym_compound_type_repeat1,
    STATE(10603), 1,
      sym__refinement,
    STATE(10604), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5924), 2,
      sym_comment,
      sym_block_comment,
    STATE(10367), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7882), 3,
      anon_sym_STAR,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [306972] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307014] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [307056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [307098] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    ACTIONS(10272), 1,
      anon_sym_LPAREN,
    STATE(6122), 1,
      sym__annotated_type,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(10192), 1,
      sym__infix_type_choice,
    STATE(17505), 1,
      sym_stable_identifier,
    STATE(5928), 2,
      sym_comment,
      sym_block_comment,
    STATE(10829), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [307166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [307208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307250] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1678), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9050), 1,
      anon_sym_LPAREN,
    ACTIONS(10068), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5931), 2,
      sym_comment,
      sym_block_comment,
    STATE(9555), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307306] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307348] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9038), 1,
      sym__interpolated_multiline_string_start,
    STATE(8542), 1,
      sym_interpolated_string,
    STATE(16331), 1,
      sym__interpolated_string_start,
    ACTIONS(10274), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307400] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307442] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9624), 1,
      anon_sym_DOT,
    ACTIONS(10276), 1,
      anon_sym_EQ_GT,
    STATE(5935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [307488] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10278), 1,
      anon_sym_DOT,
    STATE(5936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [307532] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6360), 1,
      sym__alpha_identifier,
    ACTIONS(6366), 1,
      anon_sym__,
    ACTIONS(6374), 1,
      sym__backquoted_id,
    ACTIONS(6376), 1,
      sym_operator_identifier,
    ACTIONS(10280), 1,
      anon_sym_LPAREN,
    STATE(4549), 1,
      sym__simple_type,
    STATE(4589), 1,
      sym__annotated_type,
    STATE(4753), 1,
      sym_identifier,
    STATE(4788), 1,
      sym__soft_identifier,
    STATE(6732), 1,
      sym_annotated_type,
    STATE(7033), 1,
      sym__infix_type_choice,
    STATE(17876), 1,
      sym_stable_identifier,
    STATE(5937), 2,
      sym_comment,
      sym_block_comment,
    STATE(8797), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4936), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [307600] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307642] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [307684] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [307726] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [307768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [307810] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307852] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9279), 1,
      anon_sym_LBRACK,
    ACTIONS(9283), 1,
      anon_sym_POUND,
    ACTIONS(10282), 1,
      anon_sym_AT,
    STATE(6804), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7098), 1,
      sym_type_arguments,
    STATE(8516), 1,
      sym_annotation,
    STATE(5944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [307906] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9648), 1,
      anon_sym_LBRACK,
    ACTIONS(9652), 1,
      anon_sym_POUND,
    ACTIONS(10284), 1,
      anon_sym_AT,
    STATE(7369), 1,
      sym_type_arguments,
    STATE(7548), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9413), 1,
      sym_annotation,
    STATE(5945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [307960] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308002] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308044] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9505), 1,
      anon_sym_EQ_GT,
    STATE(5948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308088] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [308130] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308172] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308214] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [308256] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308298] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308340] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308384] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308468] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9763), 1,
      anon_sym_COLON,
    ACTIONS(9765), 1,
      anon_sym_LBRACE,
    ACTIONS(9767), 1,
      anon_sym_with,
    STATE(5512), 1,
      aux_sym_compound_type_repeat1,
    STATE(10603), 1,
      sym__refinement,
    STATE(10604), 1,
      sym_template_body,
    STATE(5958), 2,
      sym_comment,
      sym_block_comment,
    STATE(10367), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308650] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6614), 1,
      sym__end_marker,
    STATE(5962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [308694] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9753), 1,
      anon_sym_COLON,
    ACTIONS(9755), 1,
      anon_sym_LBRACE,
    ACTIONS(9757), 1,
      anon_sym_with,
    STATE(5738), 1,
      aux_sym_compound_type_repeat1,
    STATE(10372), 1,
      sym_template_body,
    STATE(10373), 1,
      sym__refinement,
    STATE(5963), 2,
      sym_comment,
      sym_block_comment,
    STATE(10666), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308750] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308792] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(5965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [308836] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACE,
    ACTIONS(8947), 1,
      anon_sym_LPAREN,
    ACTIONS(10110), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(5966), 2,
      sym_comment,
      sym_block_comment,
    STATE(9005), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308890] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [308932] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [308974] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9399), 1,
      anon_sym_LBRACK,
    ACTIONS(9405), 1,
      anon_sym_POUND,
    ACTIONS(10290), 1,
      anon_sym_LPAREN,
    STATE(7023), 1,
      aux_sym_annotation_repeat1,
    STATE(7692), 1,
      sym_type_arguments,
    STATE(8861), 1,
      sym_arguments,
    STATE(5969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309070] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9563), 1,
      anon_sym_EQ_GT,
    STATE(5971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [309114] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10292), 1,
      anon_sym_AT,
    STATE(7429), 1,
      sym_annotation,
    STATE(5972), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [309160] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309202] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9850), 1,
      anon_sym_COLON,
    ACTIONS(9852), 1,
      anon_sym_LBRACE,
    ACTIONS(9854), 1,
      anon_sym_with,
    STATE(5562), 1,
      aux_sym_compound_type_repeat1,
    STATE(10664), 1,
      sym_template_body,
    STATE(10665), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5974), 2,
      sym_comment,
      sym_block_comment,
    STATE(10402), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7882), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309264] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309306] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309348] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309390] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309432] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309474] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309516] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309558] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10303), 1,
      anon_sym_DOT,
    STATE(5982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309602] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309644] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309686] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10206), 1,
      anon_sym_COLON,
    ACTIONS(10208), 1,
      anon_sym_LBRACE,
    ACTIONS(10210), 1,
      anon_sym_with,
    STATE(5869), 1,
      aux_sym_compound_type_repeat1,
    STATE(10469), 1,
      sym_template_body,
    STATE(10470), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5985), 2,
      sym_comment,
      sym_block_comment,
    STATE(10657), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7882), 3,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309748] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [309790] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10305), 1,
      anon_sym_DOT,
    STATE(5987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [309834] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309876] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9997), 1,
      sym__interpolated_multiline_string_start,
    STATE(9920), 1,
      sym_interpolated_string,
    STATE(15352), 1,
      sym__interpolated_string_start,
    ACTIONS(10307), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(5989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [309970] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [310012] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10187), 1,
      anon_sym_LBRACE,
    ACTIONS(10189), 1,
      anon_sym_with,
    STATE(5851), 1,
      aux_sym_compound_type_repeat1,
    STATE(10027), 1,
      sym__refinement,
    STATE(10029), 1,
      sym_template_body,
    STATE(5992), 2,
      sym_comment,
      sym_block_comment,
    STATE(10034), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [310066] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [310108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310150] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [310234] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10309), 1,
      anon_sym_COLON,
    ACTIONS(10312), 1,
      anon_sym_LBRACE,
    STATE(8220), 1,
      sym_template_body,
    STATE(5997), 2,
      sym_comment,
      sym_block_comment,
    STATE(7974), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 14,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [310284] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310326] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    ACTIONS(10315), 1,
      anon_sym_LPAREN,
    STATE(7875), 1,
      sym__annotated_type,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(10678), 1,
      sym__infix_type_choice,
    STATE(16720), 1,
      sym_stable_identifier,
    STATE(5999), 2,
      sym_comment,
      sym_block_comment,
    STATE(11399), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [310394] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9850), 1,
      anon_sym_COLON,
    ACTIONS(9852), 1,
      anon_sym_LBRACE,
    ACTIONS(9854), 1,
      anon_sym_with,
    STATE(5562), 1,
      aux_sym_compound_type_repeat1,
    STATE(10664), 1,
      sym_template_body,
    STATE(10665), 1,
      sym__refinement,
    STATE(6000), 2,
      sym_comment,
      sym_block_comment,
    STATE(10402), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [310450] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310492] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    ACTIONS(10317), 1,
      anon_sym_LPAREN,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7075), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(10530), 1,
      sym__infix_type_choice,
    STATE(16940), 1,
      sym_stable_identifier,
    STATE(6002), 2,
      sym_comment,
      sym_block_comment,
    STATE(10886), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [310560] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6972), 1,
      anon_sym__,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(6982), 1,
      sym_operator_identifier,
    ACTIONS(10319), 1,
      anon_sym_LPAREN,
    STATE(5099), 1,
      sym__simple_type,
    STATE(5785), 1,
      sym__annotated_type,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6043), 1,
      sym_identifier,
    STATE(9349), 1,
      sym_annotated_type,
    STATE(9550), 1,
      sym__infix_type_choice,
    STATE(17544), 1,
      sym_stable_identifier,
    STATE(6003), 2,
      sym_comment,
      sym_block_comment,
    STATE(10304), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6339), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [310628] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9236), 1,
      anon_sym_AT,
    STATE(6087), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7398), 1,
      sym_annotation,
    STATE(6004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [310676] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [310718] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310760] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [310802] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    ACTIONS(10321), 1,
      anon_sym_LPAREN,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7459), 1,
      sym_identifier,
    STATE(7461), 1,
      sym__annotated_type,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(10606), 1,
      sym__infix_type_choice,
    STATE(17518), 1,
      sym_stable_identifier,
    STATE(6008), 2,
      sym_comment,
      sym_block_comment,
    STATE(10763), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [310870] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [310912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [310954] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [310996] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6796), 1,
      anon_sym__,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(6806), 1,
      sym_operator_identifier,
    ACTIONS(10323), 1,
      anon_sym_LPAREN,
    STATE(5378), 1,
      sym__simple_type,
    STATE(5755), 1,
      sym_identifier,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(5992), 1,
      sym__annotated_type,
    STATE(9021), 1,
      sym_annotated_type,
    STATE(9456), 1,
      sym__infix_type_choice,
    STATE(16984), 1,
      sym_stable_identifier,
    STATE(6012), 2,
      sym_comment,
      sym_block_comment,
    STATE(10344), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [311064] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10325), 1,
      anon_sym_AT,
    STATE(7333), 1,
      sym_annotation,
    STATE(6013), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [311110] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [311152] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8867), 1,
      anon_sym_AT,
    STATE(5972), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7429), 1,
      sym_annotation,
    STATE(6015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [311200] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311242] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10163), 1,
      anon_sym_COLON,
    ACTIONS(10165), 1,
      anon_sym_LBRACE,
    ACTIONS(10167), 1,
      anon_sym_with,
    STATE(5911), 1,
      aux_sym_compound_type_repeat1,
    STATE(10638), 1,
      sym_template_body,
    STATE(10643), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6017), 2,
      sym_comment,
      sym_block_comment,
    STATE(10624), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7882), 3,
      anon_sym_STAR,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311304] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4774), 1,
      sym__alpha_identifier,
    ACTIONS(4780), 1,
      anon_sym__,
    ACTIONS(4792), 1,
      sym__backquoted_id,
    ACTIONS(6398), 1,
      sym_operator_identifier,
    ACTIONS(10328), 1,
      anon_sym_LPAREN,
    STATE(5343), 1,
      sym__annotated_type,
    STATE(5471), 1,
      sym__simple_type,
    STATE(5800), 1,
      sym__soft_identifier,
    STATE(5818), 1,
      sym_identifier,
    STATE(8839), 1,
      sym_annotated_type,
    STATE(9509), 1,
      sym__infix_type_choice,
    STATE(17804), 1,
      sym_stable_identifier,
    STATE(6018), 2,
      sym_comment,
      sym_block_comment,
    STATE(10322), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4786), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6677), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [311372] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311414] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311456] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [311500] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311542] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [311584] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10096), 1,
      anon_sym_COLON,
    ACTIONS(10098), 1,
      anon_sym_LBRACE,
    ACTIONS(10100), 1,
      anon_sym_with,
    STATE(5763), 1,
      aux_sym_compound_type_repeat1,
    STATE(10618), 1,
      sym_template_body,
    STATE(10620), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6024), 2,
      sym_comment,
      sym_block_comment,
    STATE(10481), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(7882), 4,
      anon_sym_while,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311646] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6139), 1,
      sym_arguments,
    STATE(6025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [311690] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    ACTIONS(10330), 1,
      anon_sym_LPAREN,
    STATE(4758), 1,
      sym__annotated_type,
    STATE(4796), 1,
      sym__simple_type,
    STATE(4977), 1,
      sym_identifier,
    STATE(5072), 1,
      sym__soft_identifier,
    STATE(7069), 1,
      sym_annotated_type,
    STATE(7873), 1,
      sym__infix_type_choice,
    STATE(17635), 1,
      sym_stable_identifier,
    STATE(6026), 2,
      sym_comment,
      sym_block_comment,
    STATE(9446), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5463), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [311758] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [311800] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_as,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [311842] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [311884] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [311926] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1168), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8513), 1,
      anon_sym_LPAREN,
    ACTIONS(9080), 1,
      anon_sym_DOT,
    ACTIONS(10332), 1,
      sym__alpha_identifier,
    ACTIONS(10336), 1,
      anon_sym_EQ,
    ACTIONS(10338), 1,
      sym__backquoted_id,
    ACTIONS(10340), 1,
      sym_operator_identifier,
    STATE(586), 1,
      sym_identifier,
    STATE(4180), 1,
      sym__soft_identifier,
    STATE(6031), 2,
      sym_comment,
      sym_block_comment,
    STATE(7711), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
    ACTIONS(10334), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [311992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312076] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312118] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312162] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9554), 1,
      sym__interpolated_multiline_string_start,
    STATE(9483), 1,
      sym_interpolated_string,
    STATE(15793), 1,
      sym__interpolated_string_start,
    ACTIONS(10342), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312214] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312256] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312298] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8947), 1,
      anon_sym_LPAREN,
    ACTIONS(10110), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6039), 2,
      sym_comment,
      sym_block_comment,
    STATE(9005), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312354] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [312396] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [312440] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10344), 1,
      anon_sym_LPAREN,
    STATE(7080), 1,
      sym_arguments,
    STATE(6042), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312486] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10347), 1,
      anon_sym_DOT,
    STATE(6043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312530] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9919), 1,
      anon_sym_COLON,
    ACTIONS(9921), 1,
      anon_sym_LBRACE,
    ACTIONS(9923), 1,
      anon_sym_with,
    STATE(5608), 1,
      aux_sym_compound_type_repeat1,
    STATE(10394), 1,
      sym__refinement,
    STATE(10398), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6044), 2,
      sym_comment,
      sym_block_comment,
    STATE(10376), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(7882), 4,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312592] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9579), 1,
      anon_sym_LBRACK,
    ACTIONS(9583), 1,
      anon_sym_POUND,
    ACTIONS(10349), 1,
      anon_sym_AT,
    STATE(6794), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7194), 1,
      sym_type_arguments,
    STATE(8843), 1,
      sym_annotation,
    STATE(6045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312646] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(9744), 1,
      anon_sym_LPAREN,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(9412), 1,
      sym__annotated_type,
    STATE(10961), 1,
      sym__infix_type_choice,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(6046), 2,
      sym_comment,
      sym_block_comment,
    STATE(11567), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [312714] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9285), 1,
      anon_sym_with,
    STATE(8311), 1,
      aux_sym_compound_type_repeat1,
    STATE(9934), 1,
      sym_template_body,
    STATE(9967), 1,
      sym__refinement,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7778), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312766] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8717), 1,
      anon_sym_AT,
    STATE(5815), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7249), 1,
      sym_annotation,
    STATE(6048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [312814] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym__,
    ACTIONS(6840), 1,
      sym__backquoted_id,
    ACTIONS(6842), 1,
      sym_operator_identifier,
    ACTIONS(10351), 1,
      anon_sym_LPAREN,
    STATE(5560), 1,
      sym__simple_type,
    STATE(6117), 1,
      sym_identifier,
    STATE(6232), 1,
      sym__soft_identifier,
    STATE(6275), 1,
      sym__annotated_type,
    STATE(9674), 1,
      sym_annotated_type,
    STATE(10350), 1,
      sym__infix_type_choice,
    STATE(17531), 1,
      sym_stable_identifier,
    STATE(6049), 2,
      sym_comment,
      sym_block_comment,
    STATE(10720), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6836), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7013), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [312882] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6378), 1,
      sym__alpha_identifier,
    ACTIONS(6384), 1,
      anon_sym__,
    ACTIONS(6392), 1,
      sym__backquoted_id,
    ACTIONS(6394), 1,
      sym_operator_identifier,
    ACTIONS(10353), 1,
      anon_sym_LPAREN,
    STATE(4847), 1,
      sym__annotated_type,
    STATE(5085), 1,
      sym__simple_type,
    STATE(5211), 1,
      sym__soft_identifier,
    STATE(5401), 1,
      sym_identifier,
    STATE(7726), 1,
      sym_annotated_type,
    STATE(8736), 1,
      sym__infix_type_choice,
    STATE(17882), 1,
      sym_stable_identifier,
    STATE(6050), 2,
      sym_comment,
      sym_block_comment,
    STATE(9821), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5762), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [312950] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [312992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [313034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [313076] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [313118] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [313160] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313202] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10359), 1,
      anon_sym_DOT,
    STATE(6057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [313246] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [313288] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10096), 1,
      anon_sym_COLON,
    ACTIONS(10098), 1,
      anon_sym_LBRACE,
    ACTIONS(10100), 1,
      anon_sym_with,
    STATE(5763), 1,
      aux_sym_compound_type_repeat1,
    STATE(10618), 1,
      sym_template_body,
    STATE(10620), 1,
      sym__refinement,
    STATE(6059), 2,
      sym_comment,
      sym_block_comment,
    STATE(10481), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [313344] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [313386] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6542), 1,
      sym__alpha_identifier,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    ACTIONS(10361), 1,
      anon_sym_LPAREN,
    STATE(5249), 1,
      sym__simple_type,
    STATE(5436), 1,
      sym__annotated_type,
    STATE(5780), 1,
      sym__soft_identifier,
    STATE(5982), 1,
      sym_identifier,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(9532), 1,
      sym__infix_type_choice,
    STATE(17900), 1,
      sym_stable_identifier,
    STATE(6061), 2,
      sym_comment,
      sym_block_comment,
    STATE(10126), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6174), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [313454] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313498] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [313540] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    ACTIONS(10317), 1,
      anon_sym_LPAREN,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7295), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(10221), 1,
      sym__infix_type_choice,
    STATE(16940), 1,
      sym_stable_identifier,
    STATE(6064), 2,
      sym_comment,
      sym_block_comment,
    STATE(10886), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [313608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313650] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9144), 1,
      anon_sym_LPAREN,
    STATE(6042), 1,
      aux_sym_annotation_repeat1,
    STATE(7080), 1,
      sym_arguments,
    STATE(6066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [313698] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9427), 1,
      sym__interpolated_multiline_string_start,
    STATE(9056), 1,
      sym_interpolated_string,
    STATE(15558), 1,
      sym__interpolated_string_start,
    ACTIONS(10363), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313750] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [313792] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [313834] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [313878] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [313922] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [313964] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [314006] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10365), 1,
      anon_sym_COLON,
    ACTIONS(10368), 1,
      anon_sym_LBRACE,
    STATE(7651), 1,
      sym_template_body,
    STATE(6074), 2,
      sym_comment,
      sym_block_comment,
    STATE(7810), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 15,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314056] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1284), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8947), 1,
      anon_sym_LPAREN,
    ACTIONS(10110), 1,
      anon_sym_DOT,
    ACTIONS(10371), 1,
      sym_operator_identifier,
    STATE(1701), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6075), 2,
      sym_comment,
      sym_block_comment,
    STATE(9005), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [314122] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8683), 1,
      anon_sym_LPAREN,
    STATE(4529), 1,
      sym_arguments,
    STATE(5914), 1,
      aux_sym_annotation_repeat1,
    STATE(6076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 24,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [314168] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10373), 1,
      anon_sym_LBRACK,
    ACTIONS(10375), 1,
      anon_sym_LPAREN,
    ACTIONS(10377), 1,
      anon_sym_POUND,
    STATE(7436), 1,
      aux_sym_annotation_repeat1,
    STATE(8083), 1,
      sym_type_arguments,
    STATE(8590), 1,
      sym_arguments,
    STATE(6077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314222] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [314264] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [314306] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10379), 1,
      anon_sym_LBRACK,
    ACTIONS(10381), 1,
      anon_sym_AT,
    ACTIONS(10383), 1,
      anon_sym_LPAREN,
    ACTIONS(10385), 1,
      anon_sym_POUND,
    STATE(7910), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8563), 1,
      sym_type_arguments,
    STATE(9118), 1,
      sym_annotation,
    STATE(10276), 1,
      sym_arguments,
    STATE(6080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314364] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10387), 1,
      anon_sym_AT,
    STATE(7345), 1,
      sym_annotation,
    STATE(6081), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314410] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [314452] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1748), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9161), 1,
      anon_sym_LPAREN,
    ACTIONS(10158), 1,
      anon_sym_DOT,
    ACTIONS(10390), 1,
      sym_operator_identifier,
    STATE(1719), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6083), 2,
      sym_comment,
      sym_block_comment,
    STATE(9210), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [314518] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314560] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10392), 1,
      anon_sym_DOT,
    STATE(6085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [314604] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9481), 1,
      anon_sym_DOT,
    ACTIONS(10394), 1,
      anon_sym_EQ_GT,
    STATE(6086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [314650] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10396), 1,
      anon_sym_AT,
    STATE(7398), 1,
      sym_annotation,
    STATE(6087), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [314738] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9919), 1,
      anon_sym_COLON,
    ACTIONS(9921), 1,
      anon_sym_LBRACE,
    ACTIONS(9923), 1,
      anon_sym_with,
    STATE(5608), 1,
      aux_sym_compound_type_repeat1,
    STATE(10394), 1,
      sym__refinement,
    STATE(10398), 1,
      sym_template_body,
    STATE(6089), 2,
      sym_comment,
      sym_block_comment,
    STATE(10376), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [314794] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10399), 1,
      anon_sym_LPAREN,
    STATE(7054), 1,
      sym_arguments,
    STATE(6090), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [314840] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    ACTIONS(10321), 1,
      anon_sym_LPAREN,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7281), 1,
      sym__annotated_type,
    STATE(7459), 1,
      sym_identifier,
    STATE(10220), 1,
      sym__infix_type_choice,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(17518), 1,
      sym_stable_identifier,
    STATE(6091), 2,
      sym_comment,
      sym_block_comment,
    STATE(10763), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [314908] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [314952] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9208), 1,
      anon_sym_AT,
    STATE(5878), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7343), 1,
      sym_annotation,
    STATE(6093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315000] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9126), 1,
      anon_sym_LPAREN,
    STATE(6090), 1,
      aux_sym_annotation_repeat1,
    STATE(7054), 1,
      sym_arguments,
    STATE(6094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315048] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6884), 1,
      sym__alpha_identifier,
    ACTIONS(6886), 1,
      anon_sym__,
    ACTIONS(6894), 1,
      sym__backquoted_id,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    ACTIONS(10402), 1,
      anon_sym_LPAREN,
    STATE(6102), 1,
      sym__simple_type,
    STATE(6268), 1,
      sym__soft_identifier,
    STATE(6402), 1,
      sym__annotated_type,
    STATE(6574), 1,
      sym_identifier,
    STATE(9782), 1,
      sym_annotated_type,
    STATE(10268), 1,
      sym__infix_type_choice,
    STATE(16962), 1,
      sym_stable_identifier,
    STATE(6095), 2,
      sym_comment,
      sym_block_comment,
    STATE(10781), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(6890), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7231), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [315116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315158] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10404), 1,
      anon_sym_LPAREN,
    STATE(7335), 1,
      sym_arguments,
    STATE(6097), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315204] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315246] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315288] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9429), 1,
      anon_sym_LBRACK,
    ACTIONS(9433), 1,
      anon_sym_POUND,
    ACTIONS(10407), 1,
      anon_sym_AT,
    STATE(6992), 1,
      sym_type_arguments,
    STATE(7404), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8557), 1,
      sym_annotation,
    STATE(6100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315342] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9224), 1,
      anon_sym_LPAREN,
    STATE(6097), 1,
      aux_sym_annotation_repeat1,
    STATE(7335), 1,
      sym_arguments,
    STATE(6101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315390] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9457), 1,
      anon_sym_LBRACK,
    ACTIONS(9461), 1,
      anon_sym_POUND,
    ACTIONS(10409), 1,
      anon_sym_AT,
    STATE(7253), 1,
      sym_type_arguments,
    STATE(8231), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9387), 1,
      sym_annotation,
    STATE(6102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315444] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4246), 1,
      sym__alpha_identifier,
    ACTIONS(4252), 1,
      anon_sym__,
    ACTIONS(4264), 1,
      sym__backquoted_id,
    ACTIONS(6744), 1,
      sym_operator_identifier,
    ACTIONS(10411), 1,
      anon_sym_LPAREN,
    STATE(4831), 1,
      sym__annotated_type,
    STATE(5071), 1,
      sym__simple_type,
    STATE(5208), 1,
      sym__soft_identifier,
    STATE(5307), 1,
      sym_identifier,
    STATE(7704), 1,
      sym_annotated_type,
    STATE(8676), 1,
      sym__infix_type_choice,
    STATE(17894), 1,
      sym_stable_identifier,
    STATE(6103), 2,
      sym_comment,
      sym_block_comment,
    STATE(9769), 2,
      sym_compound_type,
      sym_infix_type,
    ACTIONS(4258), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5976), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [315512] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315553] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10413), 1,
      anon_sym_COLON,
    ACTIONS(10415), 1,
      anon_sym_LBRACE,
    ACTIONS(10417), 1,
      anon_sym_with,
    STATE(6415), 1,
      aux_sym_compound_type_repeat1,
    STATE(10670), 1,
      sym_template_body,
    STATE(10776), 1,
      sym__refinement,
    STATE(6105), 2,
      sym_comment,
      sym_block_comment,
    STATE(10687), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315690] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315772] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [315813] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315854] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [315936] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [315977] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [316018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316059] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10419), 1,
      anon_sym_DOT,
    STATE(6117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316102] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [316143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316184] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [316225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316266] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10421), 1,
      anon_sym_COLON,
    ACTIONS(10423), 1,
      anon_sym_LBRACE,
    ACTIONS(10425), 1,
      anon_sym_with,
    STATE(6237), 1,
      aux_sym_compound_type_repeat1,
    STATE(10728), 1,
      sym__refinement,
    STATE(10773), 1,
      sym_template_body,
    STATE(6122), 2,
      sym_comment,
      sym_block_comment,
    STATE(10808), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [316362] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [316403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [316444] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [316485] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316526] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316610] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10427), 1,
      anon_sym_AT,
    STATE(7538), 1,
      sym_annotation,
    STATE(6130), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316655] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10430), 1,
      anon_sym_LBRACE,
    ACTIONS(10432), 1,
      anon_sym_with,
    STATE(6288), 1,
      aux_sym_compound_type_repeat1,
    STATE(10557), 1,
      sym__refinement,
    STATE(10562), 1,
      sym_template_body,
    STATE(6131), 2,
      sym_comment,
      sym_block_comment,
    STATE(10461), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [316708] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316749] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [316790] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [316831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [316872] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10434), 1,
      anon_sym_DOT,
    STATE(6136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [316915] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [316956] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [316997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [317038] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317079] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [317120] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [317161] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [317202] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317243] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317284] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [317325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [317366] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10156), 1,
      anon_sym_DOT,
    ACTIONS(10436), 1,
      anon_sym_EQ_GT,
    STATE(6148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317411] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10440), 1,
      sym__interpolated_multiline_string_start,
    STATE(10281), 1,
      sym_interpolated_string,
    STATE(16251), 1,
      sym__interpolated_string_start,
    ACTIONS(10438), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317462] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(493), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    ACTIONS(10442), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6150), 2,
      sym_comment,
      sym_block_comment,
    STATE(9927), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317517] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7338), 1,
      sym_arguments,
    STATE(6151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [317560] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [317601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [317642] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [317683] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10444), 1,
      anon_sym_DOT,
    STATE(6155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317726] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [317767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317808] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [317890] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [317931] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [317972] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318013] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318095] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318136] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318218] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318300] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318341] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [318382] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318423] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318464] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [318546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318587] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318628] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [318710] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [318751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [318792] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10446), 1,
      anon_sym_AT,
    STATE(7601), 1,
      sym_annotation,
    STATE(6182), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [318878] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [318919] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7026), 1,
      sym_arguments,
    STATE(6185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [318962] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [319003] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5850), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(6187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [319048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [319130] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319171] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9796), 1,
      anon_sym_DOT,
    ACTIONS(10449), 1,
      anon_sym_EQ_GT,
    STATE(6191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319216] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319257] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319298] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319339] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319380] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [319421] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(493), 1,
      anon_sym_LBRACE,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    ACTIONS(10442), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6197), 2,
      sym_comment,
      sym_block_comment,
    STATE(9927), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319474] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [319515] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10451), 1,
      anon_sym_with,
    STATE(6199), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319558] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [319599] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10394), 1,
      anon_sym_EQ_GT,
    STATE(6201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [319642] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [319683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319724] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [319765] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9303), 1,
      anon_sym_AT,
    STATE(6442), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7856), 1,
      sym_annotation,
    STATE(6205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319812] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [319853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [319894] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319935] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9711), 1,
      anon_sym_AT,
    STATE(6350), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7883), 1,
      sym_annotation,
    STATE(6209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [319982] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320023] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320064] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320146] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [320228] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320269] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [320310] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320392] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [320474] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320515] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7078), 1,
      sym__end_marker,
    STATE(6223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [320558] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320640] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10454), 1,
      anon_sym_AT,
    STATE(7588), 1,
      sym_annotation,
    STATE(6226), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320685] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320726] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [320767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320808] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320849] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9774), 1,
      anon_sym_LBRACK,
    ACTIONS(9780), 1,
      anon_sym_POUND,
    ACTIONS(10457), 1,
      anon_sym_LPAREN,
    STATE(7567), 1,
      aux_sym_annotation_repeat1,
    STATE(8475), 1,
      sym_type_arguments,
    STATE(9301), 1,
      sym_arguments,
    STATE(6231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320902] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [320943] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [320984] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321025] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321066] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321107] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10421), 1,
      anon_sym_COLON,
    ACTIONS(10423), 1,
      anon_sym_LBRACE,
    ACTIONS(10425), 1,
      anon_sym_with,
    STATE(9492), 1,
      aux_sym_compound_type_repeat1,
    STATE(10751), 1,
      sym__refinement,
    STATE(10773), 1,
      sym_template_body,
    STATE(6237), 2,
      sym_comment,
      sym_block_comment,
    STATE(10808), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321162] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321203] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10421), 1,
      anon_sym_COLON,
    ACTIONS(10423), 1,
      anon_sym_LBRACE,
    ACTIONS(10425), 1,
      anon_sym_with,
    STATE(6237), 1,
      aux_sym_compound_type_repeat1,
    STATE(10728), 1,
      sym__refinement,
    STATE(10773), 1,
      sym_template_body,
    ACTIONS(7882), 2,
      anon_sym_case,
      anon_sym_if,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6239), 2,
      sym_comment,
      sym_block_comment,
    STATE(10808), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321264] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321305] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321346] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [321387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321428] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321469] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321510] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10076), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10459), 1,
      anon_sym_COLON,
    ACTIONS(10462), 1,
      anon_sym_EQ_GT,
    ACTIONS(10464), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(9806), 1,
      sym_interpolated_string,
    STATE(16222), 1,
      sym__interpolated_string_start,
    STATE(17928), 1,
      sym__self_type_ascription,
    STATE(6246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [321608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321690] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321772] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321813] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [321854] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [321895] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10466), 1,
      anon_sym_DOT,
    STATE(6255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321938] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8823), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10459), 1,
      anon_sym_COLON,
    ACTIONS(10468), 1,
      anon_sym_EQ_GT,
    ACTIONS(10470), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(8260), 1,
      sym_interpolated_string,
    STATE(15874), 1,
      sym__interpolated_string_start,
    STATE(18331), 1,
      sym__self_type_ascription,
    STATE(6256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [321995] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322036] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322118] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [322159] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322200] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322241] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10276), 1,
      anon_sym_EQ_GT,
    STATE(6263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [322284] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10430), 1,
      anon_sym_LBRACE,
    ACTIONS(10432), 1,
      anon_sym_with,
    ACTIONS(10472), 1,
      anon_sym_COLON,
    STATE(6288), 1,
      aux_sym_compound_type_repeat1,
    STATE(10557), 1,
      sym__refinement,
    STATE(10562), 1,
      sym_template_body,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6264), 2,
      sym_comment,
      sym_block_comment,
    STATE(10461), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7882), 4,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322345] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322386] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322427] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [322470] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322511] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1572), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8869), 1,
      anon_sym_LPAREN,
    ACTIONS(9525), 1,
      anon_sym_DOT,
    ACTIONS(10475), 1,
      sym__alpha_identifier,
    ACTIONS(10479), 1,
      anon_sym_EQ,
    ACTIONS(10481), 1,
      sym__backquoted_id,
    ACTIONS(10483), 1,
      sym_operator_identifier,
    STATE(602), 1,
      sym_identifier,
    STATE(4191), 1,
      sym__soft_identifier,
    STATE(6269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
    STATE(8709), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(10477), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [322576] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322617] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [322658] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322699] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1516), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9610), 1,
      anon_sym_LPAREN,
    ACTIONS(10485), 1,
      sym__alpha_identifier,
    ACTIONS(10487), 1,
      anon_sym_DOT,
    ACTIONS(10491), 1,
      anon_sym_EQ,
    ACTIONS(10493), 1,
      sym__backquoted_id,
    ACTIONS(10495), 1,
      sym_operator_identifier,
    STATE(600), 1,
      sym_identifier,
    STATE(4192), 1,
      sym__soft_identifier,
    STATE(6273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    STATE(9632), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10489), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [322764] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1678), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9050), 1,
      anon_sym_LPAREN,
    ACTIONS(10068), 1,
      anon_sym_DOT,
    ACTIONS(10497), 1,
      sym__alpha_identifier,
    ACTIONS(10501), 1,
      anon_sym_EQ,
    ACTIONS(10503), 1,
      sym__backquoted_id,
    ACTIONS(10505), 1,
      sym_operator_identifier,
    STATE(606), 1,
      sym_identifier,
    STATE(4189), 1,
      sym__soft_identifier,
    STATE(6274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
    STATE(9555), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10499), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [322829] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10507), 1,
      anon_sym_COLON,
    ACTIONS(10509), 1,
      anon_sym_LBRACE,
    ACTIONS(10511), 1,
      anon_sym_with,
    STATE(6283), 1,
      aux_sym_compound_type_repeat1,
    STATE(10869), 1,
      sym_template_body,
    STATE(10888), 1,
      sym__refinement,
    STATE(6275), 2,
      sym_comment,
      sym_block_comment,
    STATE(10877), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322884] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322925] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9048), 1,
      anon_sym_AT,
    STATE(6130), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7538), 1,
      sym_annotation,
    STATE(6277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [322972] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323013] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323054] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10513), 1,
      anon_sym_AT,
    STATE(7633), 1,
      sym_annotation,
    STATE(6280), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323099] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [323140] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9774), 1,
      anon_sym_LBRACK,
    ACTIONS(9776), 1,
      anon_sym_AT,
    ACTIONS(9780), 1,
      anon_sym_POUND,
    STATE(7853), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8475), 1,
      sym_type_arguments,
    STATE(8940), 1,
      sym_annotation,
    STATE(6282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323193] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10507), 1,
      anon_sym_COLON,
    ACTIONS(10509), 1,
      anon_sym_LBRACE,
    ACTIONS(10511), 1,
      anon_sym_with,
    STATE(9422), 1,
      aux_sym_compound_type_repeat1,
    STATE(10869), 1,
      sym_template_body,
    STATE(10871), 1,
      sym__refinement,
    STATE(6283), 2,
      sym_comment,
      sym_block_comment,
    STATE(10877), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323248] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10516), 1,
      anon_sym_AT,
    STATE(7653), 1,
      sym_annotation,
    STATE(6284), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [323293] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323334] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10519), 1,
      anon_sym_with,
    STATE(6286), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [323377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323418] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10430), 1,
      anon_sym_LBRACE,
    ACTIONS(10432), 1,
      anon_sym_with,
    STATE(9296), 1,
      aux_sym_compound_type_repeat1,
    STATE(10547), 1,
      sym__refinement,
    STATE(10562), 1,
      sym_template_body,
    STATE(6288), 2,
      sym_comment,
      sym_block_comment,
    STATE(10461), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [323471] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [323514] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323555] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323596] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [323678] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10230), 1,
      anon_sym_LBRACK,
    ACTIONS(10234), 1,
      anon_sym_POUND,
    ACTIONS(10522), 1,
      anon_sym_AT,
    STATE(7766), 1,
      sym_type_arguments,
    STATE(8509), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9771), 1,
      sym_annotation,
    STATE(6294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323731] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10524), 1,
      anon_sym_COLON,
    ACTIONS(10526), 1,
      anon_sym_LBRACE,
    ACTIONS(10528), 1,
      anon_sym_with,
    STATE(6543), 1,
      aux_sym_compound_type_repeat1,
    STATE(10710), 1,
      sym__refinement,
    STATE(10733), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6295), 2,
      sym_comment,
      sym_block_comment,
    STATE(10881), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(7882), 3,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323792] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9497), 1,
      anon_sym_AT,
    STATE(6280), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7633), 1,
      sym_annotation,
    STATE(6296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323839] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [323880] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [323921] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [323962] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324003] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10530), 1,
      anon_sym_with,
    STATE(6301), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324046] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [324087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324128] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324210] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [324251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324292] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324333] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324374] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324415] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1516), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9610), 1,
      anon_sym_LPAREN,
    ACTIONS(10487), 1,
      anon_sym_DOT,
    ACTIONS(10533), 1,
      sym_operator_identifier,
    STATE(1729), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8309), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    STATE(9632), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [324480] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324521] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9585), 1,
      anon_sym_LPAREN,
    STATE(6320), 1,
      aux_sym_annotation_repeat1,
    STATE(8018), 1,
      sym_arguments,
    STATE(6313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [324568] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324650] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [324691] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10535), 1,
      anon_sym_LPAREN,
    STATE(7595), 1,
      sym_arguments,
    STATE(6317), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324777] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324820] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10538), 1,
      anon_sym_LPAREN,
    STATE(8018), 1,
      sym_arguments,
    STATE(6320), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [324865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324906] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8945), 1,
      anon_sym_AT,
    STATE(6541), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7852), 1,
      sym_annotation,
    STATE(6322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [324994] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325035] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10541), 1,
      anon_sym_COLON,
    ACTIONS(10544), 1,
      anon_sym_LBRACE,
    STATE(8427), 1,
      sym_template_body,
    STATE(6325), 2,
      sym_comment,
      sym_block_comment,
    STATE(8689), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8892), 15,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [325084] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325125] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [325166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325207] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10547), 1,
      anon_sym_DOT,
    STATE(6329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [325250] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325291] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325334] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [325375] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [325416] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325457] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325500] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9593), 1,
      anon_sym_LPAREN,
    STATE(6317), 1,
      aux_sym_annotation_repeat1,
    STATE(7595), 1,
      sym_arguments,
    STATE(6336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325547] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10549), 1,
      anon_sym_DOT,
    STATE(6337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [325631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325672] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [325713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [325754] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [325795] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10551), 1,
      anon_sym_DOT,
    STATE(6343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325838] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [325879] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1428), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8833), 1,
      anon_sym_LPAREN,
    ACTIONS(9483), 1,
      anon_sym_DOT,
    ACTIONS(10553), 1,
      sym__alpha_identifier,
    ACTIONS(10557), 1,
      anon_sym_EQ,
    ACTIONS(10559), 1,
      sym__backquoted_id,
    ACTIONS(10561), 1,
      sym_operator_identifier,
    STATE(596), 1,
      sym_identifier,
    STATE(4182), 1,
      sym__soft_identifier,
    STATE(6345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    STATE(8440), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 4,
      anon_sym_match,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10555), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [325944] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10563), 1,
      anon_sym_AT,
    STATE(8122), 1,
      sym_annotation,
    STATE(6346), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 23,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [325987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326110] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10566), 1,
      anon_sym_AT,
    STATE(7883), 1,
      sym_annotation,
    STATE(6350), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326155] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326196] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [326278] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326319] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326360] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326401] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326442] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326483] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326565] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326606] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326647] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326688] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [326770] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [326811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326852] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9581), 1,
      anon_sym_LPAREN,
    STATE(6429), 1,
      aux_sym_annotation_repeat1,
    STATE(7578), 1,
      sym_arguments,
    STATE(6368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [326899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326940] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10569), 1,
      anon_sym_COLON,
    ACTIONS(10572), 1,
      anon_sym_LBRACE,
    STATE(8872), 1,
      sym_template_body,
    STATE(6370), 2,
      sym_comment,
      sym_block_comment,
    STATE(8352), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 14,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [326989] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10575), 1,
      anon_sym_LPAREN,
    STATE(7764), 1,
      sym_arguments,
    STATE(6371), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [327075] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [327116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [327198] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [327239] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(9273), 1,
      anon_sym_LPAREN,
    ACTIONS(10578), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6377), 2,
      sym_comment,
      sym_block_comment,
    STATE(9953), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8191), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [327292] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327333] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [327374] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [327415] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327456] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327497] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327538] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327620] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [327661] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [327702] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10580), 1,
      anon_sym_DOT,
    STATE(6388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327786] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9453), 1,
      anon_sym_LPAREN,
    STATE(6371), 1,
      aux_sym_annotation_repeat1,
    STATE(7764), 1,
      sym_arguments,
    STATE(6390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327833] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10507), 1,
      anon_sym_COLON,
    ACTIONS(10509), 1,
      anon_sym_LBRACE,
    ACTIONS(10511), 1,
      anon_sym_with,
    STATE(6283), 1,
      aux_sym_compound_type_repeat1,
    STATE(10869), 1,
      sym_template_body,
    STATE(10888), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6391), 2,
      sym_comment,
      sym_block_comment,
    STATE(10877), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(7882), 3,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327894] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9523), 1,
      anon_sym_AT,
    STATE(6495), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8230), 1,
      sym_annotation,
    STATE(6392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [327941] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [327982] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9933), 1,
      anon_sym_LBRACK,
    ACTIONS(9937), 1,
      anon_sym_POUND,
    ACTIONS(10582), 1,
      anon_sym_AT,
    STATE(8052), 1,
      sym_type_arguments,
    STATE(8870), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9648), 1,
      sym_annotation,
    STATE(6394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328035] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10584), 1,
      anon_sym_COLON,
    ACTIONS(10586), 1,
      anon_sym_LBRACE,
    ACTIONS(10588), 1,
      anon_sym_with,
    STATE(6728), 1,
      aux_sym_compound_type_repeat1,
    STATE(10739), 1,
      sym__refinement,
    STATE(10740), 1,
      sym_template_body,
    STATE(6395), 2,
      sym_comment,
      sym_block_comment,
    STATE(10778), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328090] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [328174] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9487), 1,
      anon_sym_AT,
    STATE(6226), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7588), 1,
      sym_annotation,
    STATE(6398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [328221] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328262] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [328303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328344] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10524), 1,
      anon_sym_COLON,
    ACTIONS(10526), 1,
      anon_sym_LBRACE,
    ACTIONS(10528), 1,
      anon_sym_with,
    STATE(6543), 1,
      aux_sym_compound_type_repeat1,
    STATE(10710), 1,
      sym__refinement,
    STATE(10733), 1,
      sym_template_body,
    STATE(6402), 2,
      sym_comment,
      sym_block_comment,
    STATE(10881), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328399] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328440] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328481] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9273), 1,
      anon_sym_LPAREN,
    ACTIONS(10578), 1,
      anon_sym_DOT,
    ACTIONS(10590), 1,
      sym_operator_identifier,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    STATE(9953), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8309), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [328546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [328587] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [328630] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [328671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328712] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [328753] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10379), 1,
      anon_sym_LBRACK,
    ACTIONS(10385), 1,
      anon_sym_POUND,
    ACTIONS(10592), 1,
      anon_sym_LPAREN,
    STATE(8109), 1,
      aux_sym_annotation_repeat1,
    STATE(8563), 1,
      sym_type_arguments,
    STATE(9452), 1,
      sym_arguments,
    STATE(6411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328847] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [328888] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328929] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10413), 1,
      anon_sym_COLON,
    ACTIONS(10415), 1,
      anon_sym_LBRACE,
    ACTIONS(10417), 1,
      anon_sym_with,
    STATE(9038), 1,
      aux_sym_compound_type_repeat1,
    STATE(10670), 1,
      sym_template_body,
    STATE(10782), 1,
      sym__refinement,
    STATE(6415), 2,
      sym_comment,
      sym_block_comment,
    STATE(10687), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [328984] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329025] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [329066] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329107] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [329148] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [329189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [329230] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329353] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9532), 1,
      anon_sym_AT,
    STATE(6542), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8272), 1,
      sym_annotation,
    STATE(6425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329400] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329482] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10594), 1,
      anon_sym_DOT,
    STATE(6428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329525] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10596), 1,
      anon_sym_LPAREN,
    STATE(7578), 1,
      sym_arguments,
    STATE(6429), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329570] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10599), 1,
      anon_sym_with,
    STATE(6430), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329613] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329654] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329695] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10236), 1,
      anon_sym_LBRACK,
    ACTIONS(10240), 1,
      anon_sym_POUND,
    ACTIONS(10602), 1,
      anon_sym_AT,
    STATE(7559), 1,
      sym_type_arguments,
    STATE(7760), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9276), 1,
      sym_annotation,
    STATE(6433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329748] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329789] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329830] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [329912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [329953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [329994] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10620), 1,
      anon_sym_RPAREN,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    ACTIONS(10628), 1,
      sym__interpolated_multiline_string_start,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11265), 1,
      sym_interpolated_string,
    STATE(15412), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(16003), 1,
      sym__interpolated_string_start,
    ACTIONS(10618), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(6440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [330071] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330112] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10630), 1,
      anon_sym_AT,
    STATE(7856), 1,
      sym_annotation,
    STATE(6442), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330198] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [330239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [330323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [330364] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [330405] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10584), 1,
      anon_sym_COLON,
    ACTIONS(10586), 1,
      anon_sym_LBRACE,
    ACTIONS(10588), 1,
      anon_sym_with,
    STATE(6728), 1,
      aux_sym_compound_type_repeat1,
    STATE(10739), 1,
      sym__refinement,
    STATE(10740), 1,
      sym_template_body,
    ACTIONS(7882), 2,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6449), 2,
      sym_comment,
      sym_block_comment,
    STATE(10778), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330466] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9884), 1,
      anon_sym_DOT,
    ACTIONS(10633), 1,
      anon_sym_EQ_GT,
    STATE(6450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330511] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [330552] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [330593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [330634] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5684), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(6454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [330679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [330720] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [330761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [330802] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10635), 1,
      anon_sym_LBRACK,
    ACTIONS(10637), 1,
      anon_sym_LPAREN,
    ACTIONS(10639), 1,
      anon_sym_POUND,
    STATE(8472), 1,
      aux_sym_annotation_repeat1,
    STATE(8888), 1,
      sym_type_arguments,
    STATE(9737), 1,
      sym_arguments,
    STATE(6458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [330896] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9636), 1,
      anon_sym_LPAREN,
    STATE(6469), 1,
      aux_sym_annotation_repeat1,
    STATE(8204), 1,
      sym_arguments,
    STATE(6460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [330943] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [330984] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331025] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331066] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10643), 1,
      sym__backquoted_id,
    STATE(6464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10641), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331107] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331148] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10645), 1,
      anon_sym_LPAREN,
    STATE(7864), 1,
      sym_arguments,
    STATE(6466), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10648), 1,
      anon_sym_with,
    STATE(6467), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331236] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [331279] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10651), 1,
      anon_sym_LPAREN,
    STATE(8204), 1,
      sym_arguments,
    STATE(6469), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331324] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10171), 1,
      anon_sym_LBRACK,
    ACTIONS(10175), 1,
      anon_sym_POUND,
    ACTIONS(10654), 1,
      anon_sym_AT,
    STATE(7994), 1,
      sym_type_arguments,
    STATE(8566), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9926), 1,
      sym_annotation,
    STATE(6470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331377] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9447), 1,
      anon_sym_LPAREN,
    STATE(6494), 1,
      aux_sym_annotation_repeat1,
    STATE(7859), 1,
      sym_arguments,
    STATE(6471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331424] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331465] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331506] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10102), 1,
      anon_sym_with,
    STATE(9288), 1,
      aux_sym_compound_type_repeat1,
    STATE(10312), 1,
      sym_template_body,
    STATE(10345), 1,
      sym__refinement,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7778), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331639] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331680] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [331721] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331762] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9190), 1,
      anon_sym_LPAREN,
    STATE(6497), 1,
      aux_sym_annotation_repeat1,
    STATE(7857), 1,
      sym_arguments,
    STATE(6480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [331850] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331891] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9431), 1,
      anon_sym_LPAREN,
    STATE(6466), 1,
      aux_sym_annotation_repeat1,
    STATE(7864), 1,
      sym_arguments,
    STATE(6483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [331938] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10656), 1,
      anon_sym_with,
    STATE(6484), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [331981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [332022] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332063] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10659), 1,
      anon_sym_LBRACE,
    ACTIONS(10661), 1,
      anon_sym_with,
    STATE(6660), 1,
      aux_sym_compound_type_repeat1,
    STATE(10422), 1,
      sym__refinement,
    STATE(10426), 1,
      sym_template_body,
    STATE(6487), 2,
      sym_comment,
      sym_block_comment,
    STATE(10396), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332116] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9132), 1,
      anon_sym_AT,
    STATE(6284), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7653), 1,
      sym_annotation,
    STATE(6488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [332163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [332204] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [332245] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332286] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332327] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10663), 1,
      anon_sym_with,
    STATE(6493), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [332370] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10666), 1,
      anon_sym_LPAREN,
    STATE(7859), 1,
      sym_arguments,
    STATE(6494), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332415] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10669), 1,
      anon_sym_AT,
    STATE(8230), 1,
      sym_annotation,
    STATE(6495), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [332460] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332501] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10672), 1,
      anon_sym_LPAREN,
    STATE(7857), 1,
      sym_arguments,
    STATE(6497), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332587] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10675), 1,
      anon_sym_DOT,
    STATE(6499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [332630] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8315), 1,
      sym_operator_identifier,
    STATE(1782), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8309), 8,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [332687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [332728] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [332769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [332810] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [332851] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10677), 1,
      sym__backquoted_id,
    STATE(6506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7478), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332933] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10679), 1,
      sym__backquoted_id,
    STATE(6507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7508), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [332974] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10681), 1,
      sym__backquoted_id,
    STATE(6508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7510), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4178), 1,
      sym__backquoted_id,
    STATE(6509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4174), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333056] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10683), 1,
      anon_sym_LPAREN,
    STATE(7514), 1,
      sym_arguments,
    STATE(6510), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333101] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333142] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [333183] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [333224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [333265] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9541), 1,
      anon_sym_AT,
    STATE(6629), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8246), 1,
      sym_annotation,
    STATE(6515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333312] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10686), 1,
      anon_sym_with,
    STATE(6797), 1,
      aux_sym_compound_type_repeat1,
    STATE(9848), 1,
      sym_arguments,
    STATE(9867), 1,
      sym__refinement,
    STATE(9878), 1,
      sym_template_body,
    STATE(6516), 2,
      sym_comment,
      sym_block_comment,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333365] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333408] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333449] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333492] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10659), 1,
      anon_sym_LBRACE,
    ACTIONS(10661), 1,
      anon_sym_with,
    ACTIONS(10688), 1,
      anon_sym_COLON,
    STATE(6660), 1,
      aux_sym_compound_type_repeat1,
    STATE(10422), 1,
      sym__refinement,
    STATE(10426), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6520), 2,
      sym_comment,
      sym_block_comment,
    STATE(10396), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(7882), 3,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333553] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7473), 1,
      sym_arguments,
    STATE(6521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [333596] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333637] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10693), 1,
      sym__interpolated_multiline_string_start,
    STATE(10237), 1,
      sym_interpolated_string,
    STATE(16294), 1,
      sym__interpolated_string_start,
    ACTIONS(10691), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333688] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [333735] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10695), 1,
      anon_sym_COLON,
    ACTIONS(10698), 1,
      anon_sym_LBRACE,
    STATE(8743), 1,
      sym_template_body,
    STATE(6525), 2,
      sym_comment,
      sym_block_comment,
    STATE(8569), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 7,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 14,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [333784] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1024), 1,
      anon_sym_LBRACE,
    ACTIONS(8231), 1,
      anon_sym_LPAREN,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8839), 1,
      anon_sym_DOT,
    ACTIONS(9836), 1,
      sym__alpha_identifier,
    ACTIONS(9842), 1,
      sym__backquoted_id,
    ACTIONS(9844), 1,
      sym_operator_identifier,
    ACTIONS(10701), 1,
      anon_sym_EQ,
    STATE(582), 1,
      sym_identifier,
    STATE(4162), 1,
      sym__soft_identifier,
    STATE(6526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_finally,
    STATE(6866), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9838), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [333849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [333890] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [333931] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9670), 1,
      anon_sym_LPAREN,
    STATE(6510), 1,
      aux_sym_annotation_repeat1,
    STATE(7514), 1,
      sym_arguments,
    STATE(6529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [333978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334060] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334101] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1516), 1,
      anon_sym_LBRACE,
    ACTIONS(9610), 1,
      anon_sym_LPAREN,
    ACTIONS(10487), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6533), 2,
      sym_comment,
      sym_block_comment,
    STATE(9632), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334154] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334195] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [334236] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334318] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334359] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334402] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334443] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10703), 1,
      anon_sym_AT,
    STATE(7852), 1,
      sym_annotation,
    STATE(6541), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334488] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10706), 1,
      anon_sym_AT,
    STATE(8272), 1,
      sym_annotation,
    STATE(6542), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [334533] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10524), 1,
      anon_sym_COLON,
    ACTIONS(10526), 1,
      anon_sym_LBRACE,
    ACTIONS(10528), 1,
      anon_sym_with,
    STATE(9290), 1,
      aux_sym_compound_type_repeat1,
    STATE(10724), 1,
      sym__refinement,
    STATE(10733), 1,
      sym_template_body,
    STATE(6543), 2,
      sym_comment,
      sym_block_comment,
    STATE(10881), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334588] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9991), 1,
      anon_sym_LBRACK,
    ACTIONS(9995), 1,
      anon_sym_POUND,
    ACTIONS(10709), 1,
      anon_sym_AT,
    STATE(7519), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7920), 1,
      sym_type_arguments,
    STATE(9355), 1,
      sym_annotation,
    STATE(6544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334641] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8658), 1,
      anon_sym_LPAREN,
    ACTIONS(8998), 1,
      anon_sym_DOT,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(9622), 1,
      sym_operator_identifier,
    ACTIONS(10711), 1,
      anon_sym_EQ,
    STATE(608), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(6545), 2,
      sym_comment,
      sym_block_comment,
    STATE(8261), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [334706] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334747] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10715), 1,
      sym__backquoted_id,
    STATE(6547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10713), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334788] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334829] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334870] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334911] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [334952] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [334993] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [335034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335075] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335116] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5693), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(6556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [335161] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [335202] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9159), 1,
      anon_sym_AT,
    STATE(6654), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8229), 1,
      sym_annotation,
    STATE(6558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335249] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10373), 1,
      anon_sym_LBRACK,
    ACTIONS(10377), 1,
      anon_sym_POUND,
    ACTIONS(10717), 1,
      anon_sym_AT,
    STATE(7917), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8083), 1,
      sym_type_arguments,
    STATE(9030), 1,
      sym_annotation,
    STATE(6559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335302] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10719), 1,
      anon_sym_COLON,
    ACTIONS(10721), 1,
      anon_sym_LBRACE,
    ACTIONS(10723), 1,
      anon_sym_with,
    STATE(6776), 1,
      aux_sym_compound_type_repeat1,
    STATE(10811), 1,
      sym_template_body,
    STATE(10818), 1,
      sym__refinement,
    ACTIONS(7882), 2,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6560), 2,
      sym_comment,
      sym_block_comment,
    STATE(10701), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335363] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    ACTIONS(9914), 1,
      anon_sym_POUND,
    ACTIONS(10725), 1,
      anon_sym_AT,
    STATE(7825), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8269), 1,
      sym_type_arguments,
    STATE(9098), 1,
      sym_annotation,
    STATE(6561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335416] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [335498] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335539] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [335580] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [335621] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335662] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335703] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7221), 1,
      sym__end_marker,
    STATE(6569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [335746] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9273), 1,
      anon_sym_LPAREN,
    ACTIONS(10578), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6570), 2,
      sym_comment,
      sym_block_comment,
    STATE(9953), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8171), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [335801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [335842] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [335883] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [335924] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10727), 1,
      anon_sym_DOT,
    STATE(6574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [335967] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_do,
  [336008] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [336049] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10729), 1,
      anon_sym_COLON,
    ACTIONS(10732), 1,
      anon_sym_LBRACE,
    STATE(8889), 1,
      sym_template_body,
    STATE(6577), 2,
      sym_comment,
      sym_block_comment,
    STATE(8733), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 14,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336098] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336139] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [336180] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336221] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336262] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10735), 1,
      anon_sym_DOT,
    STATE(6582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336305] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336346] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [336387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336428] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [336469] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [336510] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10737), 1,
      anon_sym_LBRACK,
    ACTIONS(10739), 1,
      anon_sym_LPAREN,
    ACTIONS(10741), 1,
      anon_sym_POUND,
    STATE(7721), 1,
      aux_sym_annotation_repeat1,
    STATE(8283), 1,
      sym_type_arguments,
    STATE(9252), 1,
      sym_arguments,
    STATE(6588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336563] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336604] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336645] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336686] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336727] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [336768] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10743), 1,
      anon_sym_with,
    STATE(6594), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336852] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [336893] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10305), 1,
      anon_sym_DOT,
    ACTIONS(10746), 1,
      anon_sym_EQ_GT,
    STATE(6597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [336938] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9967), 1,
      anon_sym_EQ_GT,
    STATE(6598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [336981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337022] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337063] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10748), 1,
      anon_sym_LBRACK,
    ACTIONS(10750), 1,
      anon_sym_LPAREN,
    ACTIONS(10752), 1,
      anon_sym_POUND,
    STATE(8223), 1,
      aux_sym_annotation_repeat1,
    STATE(8740), 1,
      sym_type_arguments,
    STATE(8982), 1,
      sym_arguments,
    STATE(6601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337198] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337239] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337280] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [337321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [337362] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [337403] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9552), 1,
      anon_sym_AT,
    STATE(6702), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8216), 1,
      sym_annotation,
    STATE(6609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337450] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337491] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337532] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10754), 1,
      anon_sym_LBRACK,
    ACTIONS(10756), 1,
      anon_sym_LPAREN,
    ACTIONS(10758), 1,
      anon_sym_POUND,
    STATE(8389), 1,
      sym_type_arguments,
    STATE(8758), 1,
      aux_sym_annotation_repeat1,
    STATE(9853), 1,
      sym_arguments,
    STATE(6612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337626] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [337667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337708] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337749] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337790] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [337831] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10760), 1,
      anon_sym_DOT,
    STATE(6619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337874] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9959), 1,
      anon_sym_LBRACK,
    ACTIONS(9963), 1,
      anon_sym_POUND,
    ACTIONS(10762), 1,
      anon_sym_AT,
    STATE(7968), 1,
      sym_type_arguments,
    STATE(8586), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9823), 1,
      sym_annotation,
    STATE(6620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [337927] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10764), 1,
      anon_sym_with,
    STATE(6621), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [337970] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [338011] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10767), 1,
      anon_sym_LPAREN,
    STATE(8233), 1,
      sym_arguments,
    STATE(6623), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338056] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10770), 1,
      anon_sym_COLON,
    ACTIONS(10772), 1,
      anon_sym_LBRACE,
    ACTIONS(10774), 1,
      anon_sym_with,
    STATE(9450), 1,
      aux_sym_compound_type_repeat1,
    STATE(10817), 1,
      sym_template_body,
    STATE(10875), 1,
      sym__refinement,
    STATE(6624), 2,
      sym_comment,
      sym_block_comment,
    STATE(10674), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [338152] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9574), 1,
      sym__interpolated_multiline_string_start,
    STATE(9538), 1,
      sym_interpolated_string,
    STATE(15920), 1,
      sym__interpolated_string_start,
    ACTIONS(10776), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [338244] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [338285] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10778), 1,
      anon_sym_AT,
    STATE(8246), 1,
      sym_annotation,
    STATE(6629), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338330] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [338371] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [338412] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [338453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338494] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [338535] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [338576] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9697), 1,
      anon_sym_LPAREN,
    STATE(6708), 1,
      aux_sym_annotation_repeat1,
    STATE(7545), 1,
      sym_arguments,
    STATE(6636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [338664] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1516), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9610), 1,
      anon_sym_LPAREN,
    ACTIONS(10487), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6638), 2,
      sym_comment,
      sym_block_comment,
    STATE(9632), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338760] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1060), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8355), 1,
      anon_sym_LPAREN,
    ACTIONS(8843), 1,
      anon_sym_DOT,
    ACTIONS(9871), 1,
      sym__alpha_identifier,
    ACTIONS(9877), 1,
      sym__backquoted_id,
    ACTIONS(9879), 1,
      sym_operator_identifier,
    ACTIONS(10781), 1,
      anon_sym_EQ,
    STATE(583), 1,
      sym_identifier,
    STATE(4158), 1,
      sym__soft_identifier,
    STATE(6640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
    STATE(7191), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9873), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [338825] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9715), 1,
      anon_sym_LPAREN,
    STATE(6623), 1,
      aux_sym_annotation_repeat1,
    STATE(8233), 1,
      sym_arguments,
    STATE(6641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338872] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(6642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [338915] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10785), 1,
      anon_sym_DOT,
    STATE(6643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [338958] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8837), 1,
      sym__interpolated_multiline_string_start,
    STATE(8159), 1,
      sym_interpolated_string,
    STATE(15346), 1,
      sym__interpolated_string_start,
    ACTIONS(10787), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [339050] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339093] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10076), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(10459), 1,
      anon_sym_COLON,
    ACTIONS(10464), 1,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(10789), 1,
      anon_sym_EQ_GT,
    STATE(9806), 1,
      sym_interpolated_string,
    STATE(16222), 1,
      sym__interpolated_string_start,
    STATE(17842), 1,
      sym__self_type_ascription,
    STATE(6647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339150] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [339191] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [339232] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339273] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339314] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339398] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10791), 1,
      anon_sym_AT,
    STATE(8229), 1,
      sym_annotation,
    STATE(6654), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339484] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10770), 1,
      anon_sym_COLON,
    ACTIONS(10772), 1,
      anon_sym_LBRACE,
    ACTIONS(10774), 1,
      anon_sym_with,
    STATE(6624), 1,
      aux_sym_compound_type_repeat1,
    STATE(10817), 1,
      sym_template_body,
    STATE(10822), 1,
      sym__refinement,
    ACTIONS(7882), 2,
      anon_sym_STAR,
      anon_sym_else,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6656), 2,
      sym_comment,
      sym_block_comment,
    STATE(10674), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339545] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [339586] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339627] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339668] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10659), 1,
      anon_sym_LBRACE,
    ACTIONS(10661), 1,
      anon_sym_with,
    STATE(9414), 1,
      aux_sym_compound_type_repeat1,
    STATE(10375), 1,
      sym__refinement,
    STATE(10426), 1,
      sym_template_body,
    STATE(6660), 2,
      sym_comment,
      sym_block_comment,
    STATE(10396), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339721] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10794), 1,
      anon_sym_LPAREN,
    STATE(7738), 1,
      sym_arguments,
    STATE(6661), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339766] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [339850] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339891] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [339932] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [339973] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10379), 1,
      anon_sym_LBRACK,
    ACTIONS(10381), 1,
      anon_sym_AT,
    ACTIONS(10385), 1,
      anon_sym_POUND,
    STATE(7910), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8563), 1,
      sym_type_arguments,
    STATE(9118), 1,
      sym_annotation,
    STATE(6667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340026] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [340067] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8817), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340110] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [340274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340315] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1096), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8465), 1,
      anon_sym_LPAREN,
    ACTIONS(8821), 1,
      anon_sym_DOT,
    ACTIONS(9471), 1,
      sym__alpha_identifier,
    ACTIONS(9477), 1,
      sym__backquoted_id,
    ACTIONS(9479), 1,
      sym_operator_identifier,
    ACTIONS(10797), 1,
      anon_sym_EQ,
    STATE(584), 1,
      sym_identifier,
    STATE(4160), 1,
      sym__soft_identifier,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6675), 2,
      sym_comment,
      sym_block_comment,
    STATE(7045), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9473), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [340380] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1642), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9403), 1,
      anon_sym_LPAREN,
    ACTIONS(10799), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6676), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340435] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340476] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340558] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10076), 1,
      sym__interpolated_multiline_string_start,
    STATE(9806), 1,
      sym_interpolated_string,
    STATE(16222), 1,
      sym__interpolated_string_start,
    ACTIONS(10801), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340650] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [340734] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [340775] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10693), 1,
      sym__interpolated_multiline_string_start,
    STATE(10237), 1,
      sym_interpolated_string,
    STATE(16294), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340826] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [340867] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10076), 1,
      sym__interpolated_multiline_string_start,
    STATE(9806), 1,
      sym_interpolated_string,
    STATE(16222), 1,
      sym__interpolated_string_start,
    ACTIONS(10803), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340918] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10805), 1,
      anon_sym_LBRACK,
    ACTIONS(10807), 1,
      anon_sym_LPAREN,
    ACTIONS(10809), 1,
      anon_sym_POUND,
    STATE(8289), 1,
      sym_type_arguments,
    STATE(8562), 1,
      aux_sym_annotation_repeat1,
    STATE(9603), 1,
      sym_arguments,
    STATE(6688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [340971] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341012] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10770), 1,
      anon_sym_COLON,
    ACTIONS(10772), 1,
      anon_sym_LBRACE,
    ACTIONS(10774), 1,
      anon_sym_with,
    STATE(6624), 1,
      aux_sym_compound_type_repeat1,
    STATE(10817), 1,
      sym_template_body,
    STATE(10822), 1,
      sym__refinement,
    STATE(6690), 2,
      sym_comment,
      sym_block_comment,
    STATE(10674), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341067] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [341108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341149] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [341190] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [341231] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [341272] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10811), 1,
      anon_sym_DOT,
    STATE(6696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341315] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9510), 1,
      anon_sym_AT,
    STATE(6182), 1,
      aux_sym_enum_definition_repeat1,
    STATE(7601), 1,
      sym_annotation,
    STATE(6697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [341362] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [341403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [341444] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10010), 1,
      anon_sym_with,
    STATE(9527), 1,
      aux_sym_compound_type_repeat1,
    STATE(10251), 1,
      sym__refinement,
    STATE(10308), 1,
      sym_template_body,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7778), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341495] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341536] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10813), 1,
      anon_sym_AT,
    STATE(8216), 1,
      sym_annotation,
    STATE(6702), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341581] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1096), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8465), 1,
      anon_sym_LPAREN,
    ACTIONS(8821), 1,
      anon_sym_DOT,
    ACTIONS(9471), 1,
      sym__alpha_identifier,
    ACTIONS(9477), 1,
      sym__backquoted_id,
    ACTIONS(9479), 1,
      sym_operator_identifier,
    ACTIONS(10816), 1,
      anon_sym_EQ,
    STATE(584), 1,
      sym_identifier,
    STATE(4160), 1,
      sym__soft_identifier,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6703), 2,
      sym_comment,
      sym_block_comment,
    STATE(7045), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 5,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(9473), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [341646] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8772), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [341689] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [341730] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1678), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9050), 1,
      anon_sym_LPAREN,
    ACTIONS(10068), 1,
      anon_sym_DOT,
    ACTIONS(10497), 1,
      sym__alpha_identifier,
    ACTIONS(10503), 1,
      sym__backquoted_id,
    ACTIONS(10505), 1,
      sym_operator_identifier,
    ACTIONS(10818), 1,
      anon_sym_EQ,
    STATE(606), 1,
      sym_identifier,
    STATE(4189), 1,
      sym__soft_identifier,
    STATE(6706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    STATE(9555), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10499), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [341795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341836] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10820), 1,
      anon_sym_LPAREN,
    STATE(7545), 1,
      sym_arguments,
    STATE(6708), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341881] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [341922] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1748), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9161), 1,
      anon_sym_LPAREN,
    ACTIONS(10158), 1,
      anon_sym_DOT,
    ACTIONS(10823), 1,
      sym__alpha_identifier,
    ACTIONS(10827), 1,
      anon_sym_EQ,
    ACTIONS(10829), 1,
      sym__backquoted_id,
    ACTIONS(10831), 1,
      sym_operator_identifier,
    STATE(610), 1,
      sym_identifier,
    STATE(4185), 1,
      sym__soft_identifier,
    STATE(6710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    STATE(9210), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10825), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [341987] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8823), 1,
      sym__interpolated_multiline_string_start,
    STATE(8260), 1,
      sym_interpolated_string,
    STATE(15874), 1,
      sym__interpolated_string_start,
    ACTIONS(10833), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342038] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8994), 1,
      anon_sym_LPAREN,
    STATE(6725), 1,
      aux_sym_annotation_repeat1,
    STATE(8202), 1,
      sym_arguments,
    STATE(6712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342085] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10719), 1,
      anon_sym_COLON,
    ACTIONS(10721), 1,
      anon_sym_LBRACE,
    ACTIONS(10723), 1,
      anon_sym_with,
    STATE(6776), 1,
      aux_sym_compound_type_repeat1,
    STATE(10811), 1,
      sym_template_body,
    STATE(10818), 1,
      sym__refinement,
    STATE(6713), 2,
      sym_comment,
      sym_block_comment,
    STATE(10701), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342140] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [342181] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [342224] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [342308] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1642), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9403), 1,
      anon_sym_LPAREN,
    ACTIONS(10799), 1,
      anon_sym_DOT,
    ACTIONS(10835), 1,
      sym_operator_identifier,
    STATE(1828), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8309), 3,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    STATE(9859), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [342373] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10837), 1,
      anon_sym_LPAREN,
    STATE(7568), 1,
      sym_arguments,
    STATE(6719), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [342418] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [342459] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6920), 1,
      sym__end_marker,
    STATE(6721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [342502] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8658), 1,
      anon_sym_LPAREN,
    ACTIONS(8998), 1,
      anon_sym_DOT,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(9622), 1,
      sym_operator_identifier,
    ACTIONS(10840), 1,
      anon_sym_EQ,
    STATE(608), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    STATE(6722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(8261), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [342567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [342608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [342649] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10842), 1,
      anon_sym_LPAREN,
    STATE(8202), 1,
      sym_arguments,
    STATE(6725), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342694] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8837), 1,
      sym__interpolated_multiline_string_start,
    STATE(8159), 1,
      sym_interpolated_string,
    STATE(15346), 1,
      sym__interpolated_string_start,
    ACTIONS(10845), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [342745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [342786] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10584), 1,
      anon_sym_COLON,
    ACTIONS(10586), 1,
      anon_sym_LBRACE,
    ACTIONS(10588), 1,
      anon_sym_with,
    STATE(9182), 1,
      aux_sym_compound_type_repeat1,
    STATE(10725), 1,
      sym__refinement,
    STATE(10740), 1,
      sym_template_body,
    STATE(6728), 2,
      sym_comment,
      sym_block_comment,
    STATE(10778), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342841] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [342882] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [342923] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [342964] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [343005] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7678), 1,
      sym__backquoted_id,
    ACTIONS(10847), 1,
      anon_sym_LBRACK,
    ACTIONS(10849), 1,
      anon_sym_LPAREN,
    ACTIONS(10851), 1,
      anon_sym_POUND,
    STATE(8752), 1,
      aux_sym_annotation_repeat1,
    STATE(8794), 1,
      sym_type_arguments,
    STATE(9837), 1,
      sym_arguments,
    STATE(6733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7676), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343058] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [343101] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10853), 1,
      sym__backquoted_id,
    STATE(6735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(850), 25,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343142] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9730), 1,
      anon_sym_LPAREN,
    STATE(6719), 1,
      aux_sym_annotation_repeat1,
    STATE(7568), 1,
      sym_arguments,
    STATE(6736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [343189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [343230] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10855), 1,
      anon_sym_LBRACK,
    ACTIONS(10857), 1,
      anon_sym_AT,
    ACTIONS(10859), 1,
      anon_sym_LPAREN,
    ACTIONS(10861), 1,
      anon_sym_POUND,
    STATE(8406), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9240), 1,
      sym_type_arguments,
    STATE(9676), 1,
      sym_annotation,
    STATE(9848), 1,
      sym_arguments,
    STATE(6738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [343328] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [343369] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343410] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343451] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [343492] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [343533] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [343574] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343617] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343658] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343699] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [343742] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [343783] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10440), 1,
      sym__interpolated_multiline_string_start,
    STATE(10281), 1,
      sym_interpolated_string,
    STATE(16251), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343834] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [343875] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1642), 1,
      anon_sym_LBRACE,
    ACTIONS(9403), 1,
      anon_sym_LPAREN,
    ACTIONS(10799), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6753), 2,
      sym_comment,
      sym_block_comment,
    STATE(9859), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [343928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [343969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [344010] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344051] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344092] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [344133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [344174] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9761), 1,
      anon_sym_EQ_GT,
    STATE(6760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344258] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [344299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [344340] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10259), 1,
      anon_sym_LBRACK,
    ACTIONS(10263), 1,
      anon_sym_POUND,
    ACTIONS(10863), 1,
      anon_sym_AT,
    STATE(7776), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8151), 1,
      sym_type_arguments,
    STATE(9090), 1,
      sym_annotation,
    STATE(6764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344393] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1748), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9161), 1,
      anon_sym_LPAREN,
    ACTIONS(10158), 1,
      anon_sym_DOT,
    ACTIONS(10823), 1,
      sym__alpha_identifier,
    ACTIONS(10829), 1,
      sym__backquoted_id,
    ACTIONS(10831), 1,
      sym_operator_identifier,
    ACTIONS(10865), 1,
      anon_sym_EQ,
    STATE(610), 1,
      sym_identifier,
    STATE(4185), 1,
      sym__soft_identifier,
    STATE(6765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_finally,
    STATE(9210), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10825), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [344458] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344499] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1642), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9403), 1,
      anon_sym_LPAREN,
    ACTIONS(10799), 1,
      anon_sym_DOT,
    ACTIONS(10867), 1,
      sym__alpha_identifier,
    ACTIONS(10871), 1,
      anon_sym_EQ,
    ACTIONS(10873), 1,
      sym__backquoted_id,
    ACTIONS(10875), 1,
      sym_operator_identifier,
    STATE(605), 1,
      sym_identifier,
    STATE(4186), 1,
      sym__soft_identifier,
    STATE(6767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    STATE(9859), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10869), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [344564] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [344605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [344646] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9281), 1,
      anon_sym_LPAREN,
    STATE(6661), 1,
      aux_sym_annotation_repeat1,
    STATE(7738), 1,
      sym_arguments,
    STATE(6770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344693] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10413), 1,
      anon_sym_COLON,
    ACTIONS(10415), 1,
      anon_sym_LBRACE,
    ACTIONS(10417), 1,
      anon_sym_with,
    STATE(6415), 1,
      aux_sym_compound_type_repeat1,
    STATE(10670), 1,
      sym_template_body,
    STATE(10776), 1,
      sym__refinement,
    ACTIONS(7882), 2,
      anon_sym_STAR,
      anon_sym_finally,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6771), 2,
      sym_comment,
      sym_block_comment,
    STATE(10687), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344754] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [344795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [344836] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [344877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [344918] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10719), 1,
      anon_sym_COLON,
    ACTIONS(10721), 1,
      anon_sym_LBRACE,
    ACTIONS(10723), 1,
      anon_sym_with,
    STATE(9011), 1,
      aux_sym_compound_type_repeat1,
    STATE(10811), 1,
      sym_template_body,
    STATE(10861), 1,
      sym__refinement,
    STATE(6776), 2,
      sym_comment,
      sym_block_comment,
    STATE(10701), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [344973] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10877), 1,
      anon_sym_LBRACK,
    ACTIONS(10879), 1,
      anon_sym_LPAREN,
    ACTIONS(10881), 1,
      anon_sym_POUND,
    STATE(8154), 1,
      aux_sym_annotation_repeat1,
    STATE(8453), 1,
      sym_type_arguments,
    STATE(9524), 1,
      sym_arguments,
    STATE(6777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345026] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345067] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [345107] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345147] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9009), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345189] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1168), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8513), 1,
      anon_sym_LPAREN,
    ACTIONS(9080), 1,
      anon_sym_DOT,
    ACTIONS(10332), 1,
      sym__alpha_identifier,
    ACTIONS(10338), 1,
      sym__backquoted_id,
    ACTIONS(10340), 1,
      sym_operator_identifier,
    ACTIONS(10883), 1,
      anon_sym_EQ,
    STATE(586), 1,
      sym_identifier,
    STATE(4180), 1,
      sym__soft_identifier,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6782), 2,
      sym_comment,
      sym_block_comment,
    STATE(7711), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(10334), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [345253] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10885), 1,
      anon_sym_LBRACK,
    ACTIONS(10887), 1,
      anon_sym_LPAREN,
    ACTIONS(10889), 1,
      anon_sym_POUND,
    STATE(8452), 1,
      aux_sym_annotation_repeat1,
    STATE(9228), 1,
      sym_type_arguments,
    STATE(10002), 1,
      sym_arguments,
    STATE(6783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345305] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [345345] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [345385] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [345425] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [345465] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9993), 1,
      anon_sym_LPAREN,
    STATE(6789), 1,
      aux_sym_annotation_repeat1,
    STATE(8331), 1,
      sym_arguments,
    STATE(6788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345511] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10891), 1,
      anon_sym_LPAREN,
    STATE(8331), 1,
      sym_arguments,
    STATE(6789), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345555] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9608), 1,
      anon_sym_AT,
    STATE(6853), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8476), 1,
      sym_annotation,
    STATE(6790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [345641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [345681] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [345721] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10349), 1,
      anon_sym_AT,
    STATE(7097), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8843), 1,
      sym_annotation,
    STATE(6794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [345767] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10894), 1,
      anon_sym_DOT,
    STATE(6795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [345849] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10686), 1,
      anon_sym_with,
    STATE(9607), 1,
      aux_sym_compound_type_repeat1,
    STATE(9614), 1,
      sym__refinement,
    STATE(9878), 1,
      sym_template_body,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(6797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7778), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345899] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9368), 1,
      sym__backquoted_id,
    STATE(4494), 1,
      aux_sym_modifiers_repeat1,
    ACTIONS(65), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(6798), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(61), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
    ACTIONS(10896), 10,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345947] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [345987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [346027] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9038), 1,
      sym__interpolated_multiline_string_start,
    STATE(8542), 1,
      sym_interpolated_string,
    STATE(16331), 1,
      sym__interpolated_string_start,
    ACTIONS(10898), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [346117] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10900), 1,
      anon_sym_COLON,
    ACTIONS(10902), 1,
      anon_sym_LBRACE,
    ACTIONS(10904), 1,
      anon_sym_with,
    STATE(9703), 1,
      aux_sym_compound_type_repeat1,
    STATE(10759), 1,
      sym__refinement,
    STATE(10784), 1,
      sym_template_body,
    STATE(6803), 2,
      sym_comment,
      sym_block_comment,
    STATE(10676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346171] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10282), 1,
      anon_sym_AT,
    STATE(6873), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8516), 1,
      sym_annotation,
    STATE(6804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346257] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(8823), 1,
      sym__interpolated_multiline_string_start,
    STATE(8260), 1,
      sym_interpolated_string,
    STATE(15874), 1,
      sym__interpolated_string_start,
    ACTIONS(10470), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346307] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9703), 1,
      anon_sym_LPAREN,
    STATE(6810), 1,
      aux_sym_annotation_repeat1,
    STATE(8412), 1,
      sym_arguments,
    STATE(6807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346393] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10906), 1,
      anon_sym_DOT,
    STATE(6809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346435] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10908), 1,
      anon_sym_LPAREN,
    STATE(8412), 1,
      sym_arguments,
    STATE(6810), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346479] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [346519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346559] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346601] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(493), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    ACTIONS(10442), 1,
      anon_sym_DOT,
    ACTIONS(10911), 1,
      sym__alpha_identifier,
    ACTIONS(10915), 1,
      anon_sym_EQ,
    ACTIONS(10917), 1,
      sym__backquoted_id,
    ACTIONS(10919), 1,
      sym_operator_identifier,
    STATE(646), 1,
      sym_identifier,
    STATE(4200), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(6814), 2,
      sym_comment,
      sym_block_comment,
    STATE(9927), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [346665] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [346705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [346745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [346785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [346865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346905] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9220), 1,
      sym__interpolated_multiline_string_start,
    STATE(8549), 1,
      sym_interpolated_string,
    STATE(16193), 1,
      sym__interpolated_string_start,
    ACTIONS(10921), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [346955] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5615), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(6822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [346999] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [347039] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347081] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10923), 1,
      anon_sym_type,
    STATE(6825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [347123] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9064), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347165] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2084), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9778), 1,
      anon_sym_LPAREN,
    ACTIONS(10925), 1,
      sym__alpha_identifier,
    ACTIONS(10927), 1,
      anon_sym_DOT,
    ACTIONS(10931), 1,
      anon_sym_EQ,
    ACTIONS(10933), 1,
      sym__backquoted_id,
    ACTIONS(10935), 1,
      sym_operator_identifier,
    STATE(628), 1,
      sym_identifier,
    STATE(4202), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_match,
      anon_sym_finally,
    STATE(6827), 2,
      sym_comment,
      sym_block_comment,
    STATE(10185), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10929), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [347229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [347269] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [347349] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [347389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347429] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10900), 1,
      anon_sym_COLON,
    ACTIONS(10904), 1,
      anon_sym_with,
    STATE(9703), 1,
      aux_sym_compound_type_repeat1,
    STATE(10759), 1,
      sym__refinement,
    STATE(10784), 1,
      sym_template_body,
    STATE(6833), 2,
      sym_comment,
      sym_block_comment,
    STATE(10676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347481] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10939), 1,
      anon_sym_RBRACK,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(6834), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [347551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [347591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [347631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [347671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [347711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [347751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [347791] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [347831] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(10949), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(6842), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [347901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [347941] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(10951), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(6844), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [348011] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348051] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348091] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348131] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [348211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [348251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [348291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348331] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10953), 1,
      anon_sym_AT,
    STATE(8476), 1,
      sym_annotation,
    STATE(6853), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348497] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348539] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348659] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348699] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348739] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348779] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(10956), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(6864), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [348849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [348889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [348969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [349009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [349049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [349129] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10958), 1,
      anon_sym_DOT,
    STATE(6872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349171] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10960), 1,
      anon_sym_AT,
    STATE(8516), 1,
      sym_annotation,
    STATE(6873), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [349255] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [349295] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9912), 1,
      anon_sym_LPAREN,
    STATE(6880), 1,
      aux_sym_annotation_repeat1,
    STATE(8572), 1,
      sym_arguments,
    STATE(6876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349341] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [349421] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8315), 1,
      sym_operator_identifier,
    STATE(1782), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8309), 8,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [349475] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10963), 1,
      anon_sym_LPAREN,
    STATE(8572), 1,
      sym_arguments,
    STATE(6880), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349559] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10966), 1,
      anon_sym_LBRACK,
    ACTIONS(10968), 1,
      anon_sym_LPAREN,
    ACTIONS(10970), 1,
      anon_sym_POUND,
    STATE(9491), 1,
      aux_sym_annotation_repeat1,
    STATE(9558), 1,
      sym_type_arguments,
    STATE(10097), 1,
      sym_arguments,
    ACTIONS(7678), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(6882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7676), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [349651] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [349691] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [349731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [349771] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(10972), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(6887), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [349841] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5572), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(6888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [349885] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [349965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [350005] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350085] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350125] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10974), 1,
      anon_sym_with,
    STATE(6895), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [350167] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10977), 1,
      anon_sym_with,
    STATE(6896), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [350209] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(493), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    ACTIONS(10442), 1,
      anon_sym_DOT,
    ACTIONS(10911), 1,
      sym__alpha_identifier,
    ACTIONS(10917), 1,
      sym__backquoted_id,
    ACTIONS(10919), 1,
      sym_operator_identifier,
    STATE(646), 1,
      sym_identifier,
    STATE(4200), 1,
      sym__soft_identifier,
    ACTIONS(8305), 2,
      anon_sym_COLON,
      anon_sym_if,
    STATE(6897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9616), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    STATE(9927), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(10913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [350275] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [350315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [350355] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [350395] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350477] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [350517] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_else,
    ACTIONS(10980), 1,
      anon_sym_COLON,
    ACTIONS(10982), 1,
      anon_sym_LBRACE,
    ACTIONS(10984), 1,
      anon_sym_with,
    STATE(6908), 1,
      aux_sym_compound_type_repeat1,
    STATE(11070), 1,
      sym__refinement,
    STATE(11076), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6904), 2,
      sym_comment,
      sym_block_comment,
    STATE(11172), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350577] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(10986), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(6905), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [350647] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [350687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350727] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10980), 1,
      anon_sym_COLON,
    ACTIONS(10982), 1,
      anon_sym_LBRACE,
    ACTIONS(10984), 1,
      anon_sym_with,
    STATE(9937), 1,
      aux_sym_compound_type_repeat1,
    STATE(11047), 1,
      sym__refinement,
    STATE(11076), 1,
      sym_template_body,
    STATE(6908), 2,
      sym_comment,
      sym_block_comment,
    STATE(11172), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [350821] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [350861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [350901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [350941] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [350981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351061] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351101] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351181] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [351221] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [351261] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351301] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10990), 1,
      sym__interpolated_multiline_string_start,
    STATE(10649), 1,
      sym_interpolated_string,
    STATE(15232), 1,
      sym__interpolated_string_start,
    ACTIONS(10988), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351391] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351511] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8064), 1,
      sym_arguments,
    STATE(6927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [351553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351593] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8105), 1,
      sym_arguments,
    STATE(6929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351635] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [351675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [351715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351755] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [351835] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [351875] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5618), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(6936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [351919] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9112), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [351961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352001] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9099), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352043] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352085] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(10992), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(6941), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [352155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(6942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [352317] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1168), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8513), 1,
      anon_sym_LPAREN,
    ACTIONS(9080), 1,
      anon_sym_DOT,
    ACTIONS(10332), 1,
      sym__alpha_identifier,
    ACTIONS(10338), 1,
      sym__backquoted_id,
    ACTIONS(10340), 1,
      sym_operator_identifier,
    ACTIONS(10994), 1,
      anon_sym_EQ,
    STATE(586), 1,
      sym_identifier,
    STATE(4180), 1,
      sym__soft_identifier,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(6946), 2,
      sym_comment,
      sym_block_comment,
    STATE(7711), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10334), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [352381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352501] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [352541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352581] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352621] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352661] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352741] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352821] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [352941] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [352981] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(10996), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(6962), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [353051] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353091] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2084), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9778), 1,
      anon_sym_LPAREN,
    ACTIONS(10927), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6964), 2,
      sym_comment,
      sym_block_comment,
    STATE(10185), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353145] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353185] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [353225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353265] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353305] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353345] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [353385] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353425] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353465] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [353505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [353545] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353625] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [353665] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10998), 1,
      anon_sym_COLON,
    ACTIONS(11000), 1,
      anon_sym_LBRACE,
    ACTIONS(11002), 1,
      anon_sym_with,
    STATE(9749), 1,
      aux_sym_compound_type_repeat1,
    STATE(10967), 1,
      sym__refinement,
    STATE(10975), 1,
      sym_template_body,
    STATE(6978), 2,
      sym_comment,
      sym_block_comment,
    STATE(11128), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353759] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353799] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9038), 1,
      sym__interpolated_multiline_string_start,
    STATE(8542), 1,
      sym_interpolated_string,
    STATE(16331), 1,
      sym__interpolated_string_start,
    ACTIONS(11004), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353849] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9945), 1,
      anon_sym_AT,
    STATE(7073), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8836), 1,
      sym_annotation,
    STATE(6982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [353895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353935] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [353975] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2084), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9778), 1,
      anon_sym_LPAREN,
    ACTIONS(10927), 1,
      anon_sym_DOT,
    ACTIONS(11006), 1,
      sym_operator_identifier,
    STATE(1790), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_match,
      anon_sym_finally,
    STATE(6985), 2,
      sym_comment,
      sym_block_comment,
    STATE(10185), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [354039] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2084), 1,
      anon_sym_LBRACE,
    ACTIONS(9778), 1,
      anon_sym_LPAREN,
    ACTIONS(10927), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(6986), 2,
      sym_comment,
      sym_block_comment,
    STATE(10185), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354091] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354131] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [354251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354331] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(6993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [354373] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(493), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    ACTIONS(10442), 1,
      anon_sym_DOT,
    ACTIONS(11008), 1,
      sym_operator_identifier,
    STATE(1722), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(6994), 2,
      sym_comment,
      sym_block_comment,
    STATE(9927), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [354437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [354477] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(493), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    ACTIONS(10442), 1,
      anon_sym_DOT,
    ACTIONS(10911), 1,
      sym__alpha_identifier,
    ACTIONS(10917), 1,
      sym__backquoted_id,
    ACTIONS(11010), 1,
      anon_sym_EQ,
    ACTIONS(11012), 1,
      sym_operator_identifier,
    STATE(626), 1,
      sym_identifier,
    STATE(4200), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(6996), 2,
      sym_comment,
      sym_block_comment,
    STATE(9927), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [354541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354581] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10877), 1,
      anon_sym_LBRACK,
    ACTIONS(10881), 1,
      anon_sym_POUND,
    ACTIONS(11014), 1,
      anon_sym_AT,
    STATE(8453), 1,
      sym_type_arguments,
    STATE(8815), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9991), 1,
      sym_annotation,
    STATE(6998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [354713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [354753] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [354793] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [354833] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [354873] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9220), 1,
      sym__interpolated_multiline_string_start,
    STATE(8549), 1,
      sym_interpolated_string,
    STATE(16193), 1,
      sym__interpolated_string_start,
    ACTIONS(11016), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [354923] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [354963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355003] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11018), 1,
      anon_sym_LPAREN,
    STATE(8861), 1,
      sym_arguments,
    STATE(7008), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355127] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9056), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355169] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10923), 1,
      anon_sym_type,
    STATE(7012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [355211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [355331] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10449), 1,
      anon_sym_EQ_GT,
    STATE(7016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355373] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355415] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [355455] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9016), 1,
      sym__alpha_identifier,
    ACTIONS(9026), 1,
      sym__backquoted_id,
    ACTIONS(9028), 1,
      sym_operator_identifier,
    STATE(579), 1,
      sym_identifier,
    STATE(3987), 1,
      sym__soft_identifier,
    STATE(7019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(9022), 8,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [355509] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355589] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    ACTIONS(11021), 1,
      anon_sym_EQ_GT,
    STATE(7022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [355633] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10290), 1,
      anon_sym_LPAREN,
    STATE(7008), 1,
      aux_sym_annotation_repeat1,
    STATE(8861), 1,
      sym_arguments,
    STATE(7023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [355759] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355799] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [355839] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355879] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10635), 1,
      anon_sym_LBRACK,
    ACTIONS(10639), 1,
      anon_sym_POUND,
    ACTIONS(11023), 1,
      anon_sym_AT,
    STATE(8888), 1,
      sym_type_arguments,
    STATE(9241), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10346), 1,
      sym_annotation,
    STATE(7029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355931] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11025), 1,
      anon_sym_COLON,
    ACTIONS(11027), 1,
      anon_sym_LBRACE,
    ACTIONS(11029), 1,
      anon_sym_with,
    STATE(7471), 1,
      aux_sym_compound_type_repeat1,
    STATE(11016), 1,
      sym__refinement,
    STATE(11022), 1,
      sym_template_body,
    STATE(7030), 2,
      sym_comment,
      sym_block_comment,
    STATE(11068), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [355985] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [356025] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8658), 1,
      anon_sym_LPAREN,
    ACTIONS(8998), 1,
      anon_sym_DOT,
    ACTIONS(11031), 1,
      sym_operator_identifier,
    STATE(1702), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(7032), 2,
      sym_comment,
      sym_block_comment,
    STATE(8261), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [356089] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5937), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(7033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [356133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [356173] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8658), 1,
      anon_sym_LPAREN,
    ACTIONS(8998), 1,
      anon_sym_DOT,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(11033), 1,
      anon_sym_EQ,
    ACTIONS(11035), 1,
      sym_operator_identifier,
    STATE(621), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(7035), 2,
      sym_comment,
      sym_block_comment,
    STATE(8261), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [356237] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11037), 1,
      anon_sym_COLON,
    ACTIONS(11040), 1,
      anon_sym_LBRACE,
    STATE(9058), 1,
      sym_template_body,
    STATE(5496), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8900), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 13,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356285] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356325] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11043), 1,
      anon_sym_DOT,
    STATE(7038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356367] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9785), 1,
      anon_sym_AT,
    STATE(7120), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8916), 1,
      sym_annotation,
    STATE(7039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356413] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [356453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [356533] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356573] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356613] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356653] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356693] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5559), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(7047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [356737] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356777] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9686), 1,
      anon_sym_AT,
    STATE(7328), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8395), 1,
      sym_annotation,
    STATE(7049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356823] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10980), 1,
      anon_sym_COLON,
    ACTIONS(10982), 1,
      anon_sym_LBRACE,
    ACTIONS(10984), 1,
      anon_sym_with,
    STATE(6908), 1,
      aux_sym_compound_type_repeat1,
    STATE(11070), 1,
      sym__refinement,
    STATE(11076), 1,
      sym_template_body,
    STATE(7050), 2,
      sym_comment,
      sym_block_comment,
    STATE(11172), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [356957] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [356997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [357037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357077] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11045), 1,
      anon_sym_COLON,
    ACTIONS(11047), 1,
      anon_sym_with,
    STATE(9639), 1,
      aux_sym_compound_type_repeat1,
    STATE(10794), 1,
      sym_template_body,
    STATE(10841), 1,
      sym__refinement,
    STATE(7056), 2,
      sym_comment,
      sym_block_comment,
    STATE(10864), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357129] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [357169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357209] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10746), 1,
      anon_sym_EQ_GT,
    STATE(7059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [357251] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(11049), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(7060), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [357321] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357403] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11051), 1,
      anon_sym_DOT,
    STATE(7063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [357445] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10737), 1,
      anon_sym_LBRACK,
    ACTIONS(10741), 1,
      anon_sym_POUND,
    ACTIONS(11053), 1,
      anon_sym_AT,
    STATE(8283), 1,
      sym_type_arguments,
    STATE(8451), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9617), 1,
      sym_annotation,
    STATE(7064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357497] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11055), 1,
      anon_sym_LPAREN,
    STATE(8873), 1,
      sym_arguments,
    STATE(7065), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [357541] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7893), 1,
      sym_arguments,
    STATE(7066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [357623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [357663] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357703] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357823] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11058), 1,
      anon_sym_AT,
    STATE(8836), 1,
      sym_annotation,
    STATE(7073), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [357867] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [357907] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10900), 1,
      anon_sym_COLON,
    ACTIONS(10902), 1,
      anon_sym_LBRACE,
    ACTIONS(10904), 1,
      anon_sym_with,
    STATE(6803), 1,
      aux_sym_compound_type_repeat1,
    STATE(10779), 1,
      sym__refinement,
    STATE(10784), 1,
      sym_template_body,
    STATE(7075), 2,
      sym_comment,
      sym_block_comment,
    STATE(10676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [357961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358001] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9650), 1,
      anon_sym_LPAREN,
    STATE(7065), 1,
      aux_sym_annotation_repeat1,
    STATE(8873), 1,
      sym_arguments,
    STATE(7077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [358047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [358087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358127] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [358167] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [358207] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358247] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(11061), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(7083), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [358317] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358357] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11063), 1,
      anon_sym_LBRACE,
    ACTIONS(11065), 1,
      anon_sym_with,
    STATE(9970), 1,
      aux_sym_compound_type_repeat1,
    STATE(10734), 1,
      sym__refinement,
    STATE(10806), 1,
      sym_template_body,
    STATE(7085), 2,
      sym_comment,
      sym_block_comment,
    STATE(10692), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358409] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [358449] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [358489] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(11025), 1,
      anon_sym_COLON,
    ACTIONS(11027), 1,
      anon_sym_LBRACE,
    ACTIONS(11029), 1,
      anon_sym_with,
    STATE(7471), 1,
      aux_sym_compound_type_repeat1,
    STATE(11016), 1,
      sym__refinement,
    STATE(11022), 1,
      sym_template_body,
    ACTIONS(7882), 2,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7088), 2,
      sym_comment,
      sym_block_comment,
    STATE(11068), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358589] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358631] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [358713] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11067), 1,
      anon_sym_AT,
    STATE(8828), 1,
      sym_annotation,
    STATE(7093), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358757] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11070), 1,
      anon_sym_COLON,
    ACTIONS(11073), 1,
      anon_sym_LBRACE,
    STATE(9199), 1,
      sym_template_body,
    STATE(7094), 2,
      sym_comment,
      sym_block_comment,
    STATE(9114), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8892), 14,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [358805] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11076), 1,
      anon_sym_with,
    STATE(7095), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [358847] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [358887] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11079), 1,
      anon_sym_AT,
    STATE(8843), 1,
      sym_annotation,
    STATE(7097), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [358931] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [358971] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10900), 1,
      anon_sym_COLON,
    ACTIONS(10902), 1,
      anon_sym_LBRACE,
    ACTIONS(10904), 1,
      anon_sym_with,
    STATE(6803), 1,
      aux_sym_compound_type_repeat1,
    STATE(10779), 1,
      sym__refinement,
    STATE(10784), 1,
      sym_template_body,
    ACTIONS(7882), 2,
      anon_sym_case,
      anon_sym_EQ,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7099), 2,
      sym_comment,
      sym_block_comment,
    STATE(10676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359031] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9985), 1,
      anon_sym_AT,
    STATE(7161), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8898), 1,
      sym_annotation,
    STATE(7100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359117] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 8,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359163] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359205] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359245] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [359285] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11082), 1,
      anon_sym_LPAREN,
    STATE(8744), 1,
      sym_arguments,
    STATE(7106), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [359329] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11085), 1,
      anon_sym_LBRACK,
    ACTIONS(11087), 1,
      anon_sym_LPAREN,
    ACTIONS(11089), 1,
      anon_sym_POUND,
    STATE(9048), 1,
      aux_sym_annotation_repeat1,
    STATE(9441), 1,
      sym_type_arguments,
    STATE(10273), 1,
      sym_arguments,
    STATE(7107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7676), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359461] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10120), 1,
      anon_sym_LPAREN,
    STATE(7106), 1,
      aux_sym_annotation_repeat1,
    STATE(8744), 1,
      sym_arguments,
    STATE(7110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [359507] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359547] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359587] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10633), 1,
      anon_sym_EQ_GT,
    STATE(7113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [359709] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10855), 1,
      anon_sym_LBRACK,
    ACTIONS(10857), 1,
      anon_sym_AT,
    ACTIONS(10861), 1,
      anon_sym_POUND,
    STATE(8406), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9240), 1,
      sym_type_arguments,
    STATE(9676), 1,
      sym_annotation,
    STATE(7116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359841] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [359881] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11091), 1,
      anon_sym_AT,
    STATE(8916), 1,
      sym_annotation,
    STATE(7120), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [359965] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7890), 1,
      sym__end_marker,
    STATE(7122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [360007] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10990), 1,
      sym__interpolated_multiline_string_start,
    STATE(10649), 1,
      sym_interpolated_string,
    STATE(15232), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360057] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11094), 1,
      anon_sym_AT,
    STATE(8683), 1,
      sym_annotation,
    STATE(7124), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360101] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [360143] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11097), 1,
      anon_sym_LPAREN,
    STATE(8891), 1,
      sym_arguments,
    STATE(7126), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [360227] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [360307] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360347] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9570), 1,
      anon_sym_LPAREN,
    STATE(7164), 1,
      aux_sym_annotation_repeat1,
    STATE(8938), 1,
      sym_arguments,
    STATE(7131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [360433] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(11100), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(7133), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [360503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360543] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [360663] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [360703] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [360783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [360823] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360903] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11045), 1,
      anon_sym_COLON,
    ACTIONS(11047), 1,
      anon_sym_with,
    ACTIONS(11102), 1,
      anon_sym_LBRACE,
    STATE(9639), 1,
      aux_sym_compound_type_repeat1,
    STATE(10794), 1,
      sym_template_body,
    STATE(10841), 1,
      sym__refinement,
    STATE(7144), 2,
      sym_comment,
      sym_block_comment,
    STATE(10864), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [360957] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [360997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [361077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [361117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [361157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [361237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [361277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361317] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9589), 1,
      anon_sym_AT,
    STATE(7093), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8828), 1,
      sym_annotation,
    STATE(7154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [361403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [361443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361483] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [361523] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11104), 1,
      anon_sym_COLON,
    ACTIONS(11106), 1,
      anon_sym_LBRACE,
    ACTIONS(11108), 1,
      anon_sym_with,
    STATE(9678), 1,
      aux_sym_compound_type_repeat1,
    STATE(10895), 1,
      sym_template_body,
    STATE(11007), 1,
      sym__refinement,
    STATE(7159), 2,
      sym_comment,
      sym_block_comment,
    STATE(11116), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361577] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10028), 1,
      anon_sym_LPAREN,
    STATE(7126), 1,
      aux_sym_annotation_repeat1,
    STATE(8891), 1,
      sym_arguments,
    STATE(7160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361623] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11110), 1,
      anon_sym_AT,
    STATE(8898), 1,
      sym_annotation,
    STATE(7161), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [361707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [361747] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11113), 1,
      anon_sym_LPAREN,
    STATE(8938), 1,
      sym_arguments,
    STATE(7164), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361791] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [361831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [361871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [361911] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [361951] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [361991] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [362031] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [362071] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [362151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362191] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(11045), 1,
      anon_sym_COLON,
    ACTIONS(11047), 1,
      anon_sym_with,
    ACTIONS(11116), 1,
      anon_sym_LBRACE,
    STATE(7056), 1,
      aux_sym_compound_type_repeat1,
    STATE(10794), 1,
      sym_template_body,
    STATE(10803), 1,
      sym__refinement,
    ACTIONS(7882), 2,
      anon_sym_case,
      anon_sym_EQ,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7175), 2,
      sym_comment,
      sym_block_comment,
    STATE(10864), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [362331] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11119), 1,
      anon_sym_COLON,
    ACTIONS(11122), 1,
      anon_sym_LBRACE,
    STATE(9530), 1,
      sym_template_body,
    STATE(7178), 2,
      sym_comment,
      sym_block_comment,
    STATE(9188), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 13,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362379] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11125), 1,
      anon_sym_AT,
    STATE(8557), 1,
      sym_annotation,
    STATE(7179), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362423] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362463] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [362543] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [362583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [362663] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [362703] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11128), 1,
      anon_sym_with,
    STATE(7187), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [362785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362825] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11131), 1,
      anon_sym_AT,
    STATE(8849), 1,
      sym_annotation,
    STATE(7190), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362869] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [362909] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [362949] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [362989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363029] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363069] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10064), 1,
      anon_sym_AT,
    STATE(7488), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8504), 1,
      sym_annotation,
    STATE(7196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363115] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [363237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363317] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 19,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [363357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [363397] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363477] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [363517] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11134), 1,
      anon_sym_with,
    STATE(7207), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363559] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363639] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11137), 1,
      anon_sym_LPAREN,
    STATE(8478), 1,
      sym_arguments,
    STATE(7210), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363723] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10251), 1,
      anon_sym_AT,
    STATE(7267), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8755), 1,
      sym_annotation,
    STATE(7212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363769] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9888), 1,
      anon_sym_LPAREN,
    STATE(7225), 1,
      aux_sym_annotation_repeat1,
    STATE(8824), 1,
      sym_arguments,
    STATE(7213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [363935] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [363977] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [364057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364097] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [364137] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [364177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [364217] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9459), 1,
      anon_sym_LPAREN,
    STATE(7210), 1,
      aux_sym_annotation_repeat1,
    STATE(8478), 1,
      sym_arguments,
    STATE(7224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364263] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11140), 1,
      anon_sym_LPAREN,
    STATE(8824), 1,
      sym_arguments,
    STATE(7225), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364307] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364427] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364467] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10628), 1,
      sym__interpolated_multiline_string_start,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11265), 1,
      sym_interpolated_string,
    STATE(16003), 1,
      sym__interpolated_string_start,
    STATE(7230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11145), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11143), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [364525] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364565] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [364605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [364645] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364685] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364765] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [364805] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11147), 1,
      anon_sym_DOT,
    STATE(7238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364847] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [364969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [365009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [365049] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11149), 1,
      anon_sym_LBRACK,
    ACTIONS(11151), 1,
      anon_sym_LPAREN,
    ACTIONS(11153), 1,
      anon_sym_POUND,
    STATE(9239), 1,
      aux_sym_annotation_repeat1,
    STATE(9497), 1,
      sym_type_arguments,
    STATE(10319), 1,
      sym_arguments,
    STATE(7244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7676), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365101] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365181] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365221] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_STAR,
    ACTIONS(11104), 1,
      anon_sym_COLON,
    ACTIONS(11106), 1,
      anon_sym_LBRACE,
    ACTIONS(11108), 1,
      anon_sym_with,
    STATE(7159), 1,
      aux_sym_compound_type_repeat1,
    STATE(10895), 1,
      sym_template_body,
    STATE(10896), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7248), 2,
      sym_comment,
      sym_block_comment,
    STATE(11116), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365361] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365401] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [365441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365481] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365521] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10748), 1,
      anon_sym_LBRACK,
    ACTIONS(10752), 1,
      anon_sym_POUND,
    ACTIONS(11155), 1,
      anon_sym_AT,
    STATE(8593), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8740), 1,
      sym_type_arguments,
    STATE(10001), 1,
      sym_annotation,
    STATE(7255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365573] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365613] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365653] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365693] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11157), 1,
      anon_sym_DOT,
    STATE(7259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365735] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1978), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9134), 1,
      anon_sym_LPAREN,
    ACTIONS(9947), 1,
      anon_sym_DOT,
    ACTIONS(11159), 1,
      sym__alpha_identifier,
    ACTIONS(11163), 1,
      anon_sym_EQ,
    ACTIONS(11165), 1,
      sym__backquoted_id,
    ACTIONS(11167), 1,
      sym_operator_identifier,
    STATE(622), 1,
      sym_identifier,
    STATE(4205), 1,
      sym__soft_identifier,
    STATE(7260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_then,
      anon_sym_finally,
    STATE(9158), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(11161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [365799] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365839] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365879] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365919] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365959] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [365999] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366039] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11169), 1,
      anon_sym_AT,
    STATE(8755), 1,
      sym_annotation,
    STATE(7267), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366083] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10805), 1,
      anon_sym_LBRACK,
    ACTIONS(10809), 1,
      anon_sym_POUND,
    ACTIONS(11172), 1,
      anon_sym_AT,
    STATE(8289), 1,
      sym_type_arguments,
    STATE(8949), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10260), 1,
      sym_annotation,
    STATE(7268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366135] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [366215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [366255] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [366295] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10628), 1,
      sym__interpolated_multiline_string_start,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11265), 1,
      sym_interpolated_string,
    STATE(16003), 1,
      sym__interpolated_string_start,
    STATE(7273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11176), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11174), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [366353] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11178), 1,
      anon_sym_with,
    STATE(7274), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [366395] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366435] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [366515] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1818), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(10383), 1,
      anon_sym_LPAREN,
    ACTIONS(11181), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7278), 2,
      sym_comment,
      sym_block_comment,
    STATE(10084), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [366609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366649] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11045), 1,
      anon_sym_COLON,
    ACTIONS(11047), 1,
      anon_sym_with,
    STATE(7056), 1,
      aux_sym_compound_type_repeat1,
    STATE(10794), 1,
      sym_template_body,
    STATE(10803), 1,
      sym__refinement,
    STATE(7281), 2,
      sym_comment,
      sym_block_comment,
    STATE(10864), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366741] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10466), 1,
      anon_sym_DOT,
    ACTIONS(11183), 1,
      anon_sym_EQ_GT,
    STATE(7283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [366865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [366905] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11185), 1,
      anon_sym_with,
    STATE(7287), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [366947] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [366987] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11188), 1,
      anon_sym_with,
    STATE(7289), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367029] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [367069] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11191), 1,
      anon_sym_AT,
    STATE(8350), 1,
      sym_annotation,
    STATE(7291), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367113] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367153] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    ACTIONS(10628), 1,
      sym__interpolated_multiline_string_start,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11265), 1,
      sym_interpolated_string,
    STATE(16003), 1,
      sym__interpolated_string_start,
    ACTIONS(11194), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(7293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11196), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [367223] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1818), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10383), 1,
      anon_sym_LPAREN,
    ACTIONS(11181), 1,
      anon_sym_DOT,
    ACTIONS(11198), 1,
      sym_operator_identifier,
    STATE(1852), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_match,
      anon_sym_else,
    STATE(7294), 2,
      sym_comment,
      sym_block_comment,
    STATE(10084), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [367287] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10900), 1,
      anon_sym_COLON,
    ACTIONS(10904), 1,
      anon_sym_with,
    STATE(6833), 1,
      aux_sym_compound_type_repeat1,
    STATE(10779), 1,
      sym__refinement,
    STATE(10784), 1,
      sym_template_body,
    STATE(7295), 2,
      sym_comment,
      sym_block_comment,
    STATE(10676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367339] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367419] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367499] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9249), 1,
      anon_sym_AT,
    STATE(7190), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8849), 1,
      sym_annotation,
    STATE(7300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367545] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367625] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367665] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1818), 1,
      anon_sym_LBRACE,
    ACTIONS(10383), 1,
      anon_sym_LPAREN,
    ACTIONS(11181), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7304), 2,
      sym_comment,
      sym_block_comment,
    STATE(10084), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367717] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367797] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [367877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367957] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [367997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [368237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [368317] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [368357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368397] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368437] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9183), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368479] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368519] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(11045), 1,
      anon_sym_COLON,
    ACTIONS(11047), 1,
      anon_sym_with,
    ACTIONS(11102), 1,
      anon_sym_LBRACE,
    STATE(7144), 1,
      aux_sym_compound_type_repeat1,
    STATE(10794), 1,
      sym_template_body,
    STATE(10803), 1,
      sym__refinement,
    ACTIONS(7882), 2,
      anon_sym_case,
      anon_sym_EQ,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7325), 2,
      sym_comment,
      sym_block_comment,
    STATE(10864), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [368619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368659] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11200), 1,
      anon_sym_AT,
    STATE(8395), 1,
      sym_annotation,
    STATE(7328), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368703] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1818), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10383), 1,
      anon_sym_LPAREN,
    ACTIONS(11181), 1,
      anon_sym_DOT,
    ACTIONS(11203), 1,
      sym__alpha_identifier,
    ACTIONS(11207), 1,
      anon_sym_EQ,
    ACTIONS(11209), 1,
      sym__backquoted_id,
    ACTIONS(11211), 1,
      sym_operator_identifier,
    STATE(613), 1,
      sym_identifier,
    STATE(4197), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_match,
      anon_sym_else,
    STATE(7329), 2,
      sym_comment,
      sym_block_comment,
    STATE(10084), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11205), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [368767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368807] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368847] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(10900), 1,
      anon_sym_COLON,
    ACTIONS(10904), 1,
      anon_sym_with,
    ACTIONS(11213), 1,
      anon_sym_LBRACE,
    STATE(6833), 1,
      aux_sym_compound_type_repeat1,
    STATE(10779), 1,
      sym__refinement,
    STATE(10784), 1,
      sym_template_body,
    ACTIONS(7882), 2,
      anon_sym_case,
      anon_sym_EQ,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7332), 2,
      sym_comment,
      sym_block_comment,
    STATE(10676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [368907] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [368947] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [368987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369027] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [369067] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369107] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [369147] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369227] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [369307] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [369347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369427] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369467] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369507] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9194), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369589] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369629] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11104), 1,
      anon_sym_COLON,
    ACTIONS(11106), 1,
      anon_sym_LBRACE,
    ACTIONS(11108), 1,
      anon_sym_with,
    STATE(7159), 1,
      aux_sym_compound_type_repeat1,
    STATE(10895), 1,
      sym_template_body,
    STATE(10896), 1,
      sym__refinement,
    STATE(7351), 2,
      sym_comment,
      sym_block_comment,
    STATE(11116), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369683] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10436), 1,
      anon_sym_EQ_GT,
    STATE(7352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [369765] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369805] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7584), 1,
      sym__end_marker,
    STATE(7355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [369847] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [369887] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7742), 1,
      sym__end_marker,
    STATE(7357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [369929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [369969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [370009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [370049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370089] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(11216), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(7362), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [370159] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [370199] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370239] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370279] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [370319] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10760), 1,
      anon_sym_DOT,
    ACTIONS(11218), 1,
      anon_sym_EQ_GT,
    STATE(7367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370363] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9401), 1,
      anon_sym_AT,
    STATE(7124), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8683), 1,
      sym_annotation,
    STATE(7368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370409] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [370449] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [370495] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9153), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370537] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10261), 1,
      anon_sym_LPAREN,
    STATE(7387), 1,
      aux_sym_annotation_repeat1,
    STATE(8341), 1,
      sym_arguments,
    STATE(7372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370583] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370625] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(493), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    ACTIONS(10442), 1,
      anon_sym_DOT,
    ACTIONS(11220), 1,
      sym_operator_identifier,
    STATE(1847), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(7374), 2,
      sym_comment,
      sym_block_comment,
    STATE(9927), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [370689] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [370809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [370929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [370969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371009] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11222), 1,
      anon_sym_LPAREN,
    STATE(8367), 1,
      sym_arguments,
    STATE(7383), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371053] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371133] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10238), 1,
      anon_sym_LPAREN,
    STATE(7383), 1,
      aux_sym_annotation_repeat1,
    STATE(8367), 1,
      sym_arguments,
    STATE(7386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371179] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11225), 1,
      anon_sym_LPAREN,
    STATE(8341), 1,
      sym_arguments,
    STATE(7387), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371223] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11228), 1,
      anon_sym_COLON,
    ACTIONS(11231), 1,
      anon_sym_LBRACE,
    STATE(9244), 1,
      sym_template_body,
    STATE(7388), 2,
      sym_comment,
      sym_block_comment,
    STATE(8992), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 13,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [371311] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10754), 1,
      anon_sym_LBRACK,
    ACTIONS(10758), 1,
      anon_sym_POUND,
    ACTIONS(11234), 1,
      anon_sym_AT,
    STATE(8389), 1,
      sym_type_arguments,
    STATE(9504), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10357), 1,
      sym_annotation,
    STATE(7390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [371403] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371445] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10998), 1,
      anon_sym_COLON,
    ACTIONS(11000), 1,
      anon_sym_LBRACE,
    ACTIONS(11002), 1,
      anon_sym_with,
    STATE(6978), 1,
      aux_sym_compound_type_repeat1,
    STATE(10974), 1,
      sym__refinement,
    STATE(10975), 1,
      sym_template_body,
    STATE(7393), 2,
      sym_comment,
      sym_block_comment,
    STATE(11128), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371499] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [371539] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10076), 1,
      sym__interpolated_multiline_string_start,
    STATE(9806), 1,
      sym_interpolated_string,
    STATE(16222), 1,
      sym__interpolated_string_start,
    ACTIONS(10464), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371589] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [371629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [371669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371709] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371749] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371789] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [371829] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11236), 1,
      anon_sym_DOT,
    STATE(7402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371911] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10407), 1,
      anon_sym_AT,
    STATE(7179), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8557), 1,
      sym_annotation,
    STATE(7404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [371957] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [371997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [372077] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11238), 1,
      anon_sym_with,
    STATE(7408), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [372119] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 25,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [372157] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [372199] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [372239] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8608), 1,
      sym_operator_identifier,
    STATE(1786), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8309), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [372295] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [372335] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11241), 1,
      anon_sym_LPAREN,
    STATE(8590), 1,
      sym_arguments,
    STATE(7414), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372419] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11244), 1,
      anon_sym_DOT,
    STATE(7416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372461] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 25,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [372499] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11246), 1,
      anon_sym_DOT,
    STATE(7418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372581] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10551), 1,
      anon_sym_DOT,
    ACTIONS(11248), 1,
      anon_sym_EQ_GT,
    STATE(7420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372625] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9271), 1,
      anon_sym_AT,
    STATE(7291), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8350), 1,
      sym_annotation,
    STATE(7421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [372671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [372711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372791] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [372837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [372957] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [372997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [373037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [373117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [373197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [373237] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10375), 1,
      anon_sym_LPAREN,
    STATE(7414), 1,
      aux_sym_annotation_repeat1,
    STATE(8590), 1,
      sym_arguments,
    STATE(7436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [373403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373483] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [373523] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [373563] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373643] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11250), 1,
      anon_sym_with,
    STATE(7446), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373685] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [373725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373765] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [373805] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [373845] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [373885] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 25,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [373923] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [373963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [374043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [374083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374163] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11253), 1,
      anon_sym_DOT,
    STATE(7459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374205] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [374245] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11045), 1,
      anon_sym_COLON,
    ACTIONS(11047), 1,
      anon_sym_with,
    ACTIONS(11102), 1,
      anon_sym_LBRACE,
    STATE(7144), 1,
      aux_sym_compound_type_repeat1,
    STATE(10794), 1,
      sym_template_body,
    STATE(10803), 1,
      sym__refinement,
    STATE(7461), 2,
      sym_comment,
      sym_block_comment,
    STATE(10864), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [374339] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [374419] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374459] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11063), 1,
      anon_sym_LBRACE,
    ACTIONS(11065), 1,
      anon_sym_with,
    STATE(7085), 1,
      aux_sym_compound_type_repeat1,
    STATE(10802), 1,
      sym__refinement,
    STATE(10806), 1,
      sym_template_body,
    STATE(7466), 2,
      sym_comment,
      sym_block_comment,
    STATE(10692), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374511] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374671] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11025), 1,
      anon_sym_COLON,
    ACTIONS(11027), 1,
      anon_sym_LBRACE,
    ACTIONS(11029), 1,
      anon_sym_with,
    STATE(9609), 1,
      aux_sym_compound_type_repeat1,
    STATE(10965), 1,
      sym__refinement,
    STATE(11022), 1,
      sym_template_body,
    STATE(7471), 2,
      sym_comment,
      sym_block_comment,
    STATE(11068), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374765] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [374805] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374845] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [374885] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [374965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [375005] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11255), 1,
      anon_sym_with,
    STATE(7479), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375047] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11258), 1,
      anon_sym_DOT,
    STATE(7480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375129] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375209] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375249] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375289] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8927), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [375331] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_finally,
    ACTIONS(10998), 1,
      anon_sym_COLON,
    ACTIONS(11000), 1,
      anon_sym_LBRACE,
    ACTIONS(11002), 1,
      anon_sym_with,
    STATE(6978), 1,
      aux_sym_compound_type_repeat1,
    STATE(10974), 1,
      sym__refinement,
    STATE(10975), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7487), 2,
      sym_comment,
      sym_block_comment,
    STATE(11128), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375391] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11260), 1,
      anon_sym_AT,
    STATE(8504), 1,
      sym_annotation,
    STATE(7488), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375435] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10855), 1,
      anon_sym_LBRACK,
    ACTIONS(10861), 1,
      anon_sym_POUND,
    ACTIONS(11263), 1,
      anon_sym_LPAREN,
    STATE(8425), 1,
      aux_sym_annotation_repeat1,
    STATE(9240), 1,
      sym_type_arguments,
    STATE(9783), 1,
      sym_arguments,
    STATE(7489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7676), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375527] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375607] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375647] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8523), 1,
      sym_operator_identifier,
    STATE(1707), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8309), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [375703] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11265), 1,
      anon_sym_DOT,
    STATE(7495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [375865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375905] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375945] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [375985] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [376024] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [376063] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376102] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376180] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376219] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11267), 1,
      anon_sym_COLON,
    ACTIONS(11269), 1,
      anon_sym_LBRACE,
    ACTIONS(11271), 1,
      anon_sym_with,
    STATE(10218), 1,
      aux_sym_compound_type_repeat1,
    STATE(11312), 1,
      sym__refinement,
    STATE(11343), 1,
      sym_template_body,
    STATE(7508), 2,
      sym_comment,
      sym_block_comment,
    STATE(11189), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376272] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376311] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    ACTIONS(9790), 1,
      anon_sym_LPAREN,
    STATE(8212), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8846), 1,
      sym_identifier,
    STATE(10846), 1,
      sym_annotated_type,
    STATE(10849), 1,
      sym__annotated_type,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(7510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [376372] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376411] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(10859), 1,
      anon_sym_LPAREN,
    ACTIONS(11273), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7512), 2,
      sym_comment,
      sym_block_comment,
    STATE(10626), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376464] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11275), 1,
      anon_sym_DOT,
    STATE(7513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376544] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11277), 1,
      anon_sym_COLON,
    ACTIONS(11280), 1,
      anon_sym_LBRACE,
    STATE(9602), 1,
      sym_template_body,
    STATE(5768), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8900), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 12,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376591] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8523), 1,
      sym_operator_identifier,
    STATE(1707), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8309), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [376644] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11283), 1,
      anon_sym_LBRACK,
    ACTIONS(11285), 1,
      anon_sym_LPAREN,
    ACTIONS(11287), 1,
      anon_sym_POUND,
    STATE(9592), 1,
      sym_type_arguments,
    STATE(9712), 1,
      aux_sym_annotation_repeat1,
    STATE(10621), 1,
      sym_arguments,
    STATE(7517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(7676), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376695] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376734] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10709), 1,
      anon_sym_AT,
    STATE(7672), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9355), 1,
      sym_annotation,
    STATE(7519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376779] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376857] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [376896] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376935] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [376974] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377013] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8321), 1,
      sym__alpha_identifier,
    ACTIONS(8323), 1,
      anon_sym__,
    ACTIONS(8327), 1,
      anon_sym_LPAREN,
    ACTIONS(8329), 1,
      sym__backquoted_id,
    ACTIONS(8331), 1,
      sym_operator_identifier,
    STATE(4662), 1,
      sym__simple_type,
    STATE(5767), 1,
      sym_identifier,
    STATE(5875), 1,
      sym__soft_identifier,
    STATE(6812), 1,
      sym__annotated_type,
    STATE(6832), 1,
      sym_annotated_type,
    STATE(17672), 1,
      sym_stable_identifier,
    STATE(7526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8325), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5678), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [377074] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377113] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377152] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377191] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377230] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377269] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377308] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11085), 1,
      anon_sym_LBRACK,
    ACTIONS(11089), 1,
      anon_sym_POUND,
    ACTIONS(11289), 1,
      anon_sym_AT,
    STATE(9441), 1,
      sym_type_arguments,
    STATE(9742), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10551), 1,
      sym_annotation,
    STATE(7533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377359] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11248), 1,
      anon_sym_EQ_GT,
    STATE(7534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377400] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377439] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11299), 1,
      anon_sym_RPAREN,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11305), 1,
      sym__interpolated_multiline_string_start,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11780), 1,
      sym_interpolated_string,
    STATE(15873), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(16279), 1,
      sym__interpolated_string_start,
    STATE(7536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [377512] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377668] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377785] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6632), 1,
      sym__alpha_identifier,
    ACTIONS(6638), 1,
      anon_sym__,
    ACTIONS(6646), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(10199), 1,
      anon_sym_LPAREN,
    STATE(5803), 1,
      sym__simple_type,
    STATE(6337), 1,
      sym_identifier,
    STATE(6537), 1,
      sym__soft_identifier,
    STATE(9656), 1,
      sym_annotated_type,
    STATE(9726), 1,
      sym__annotated_type,
    STATE(16798), 1,
      sym_stable_identifier,
    STATE(7544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6642), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6924), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [377846] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377885] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5686), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(7546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [377928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [377967] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10284), 1,
      anon_sym_AT,
    STATE(7820), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9413), 1,
      sym_annotation,
    STATE(7548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [378012] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [378051] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [378090] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378129] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378168] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4562), 1,
      sym__alpha_identifier,
    ACTIONS(4568), 1,
      anon_sym__,
    ACTIONS(4580), 1,
      sym__backquoted_id,
    ACTIONS(6770), 1,
      sym_operator_identifier,
    ACTIONS(10094), 1,
      anon_sym_LPAREN,
    STATE(5319), 1,
      sym__simple_type,
    STATE(5571), 1,
      sym_identifier,
    STATE(5868), 1,
      sym__soft_identifier,
    STATE(8332), 1,
      sym__annotated_type,
    STATE(8394), 1,
      sym_annotated_type,
    STATE(17678), 1,
      sym_stable_identifier,
    STATE(7553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4574), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6389), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [378229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [378268] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378307] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11307), 1,
      anon_sym_LPAREN,
    STATE(9301), 1,
      sym_arguments,
    STATE(7556), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378428] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378467] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378506] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378545] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [378584] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [378623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378662] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [378701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378740] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10457), 1,
      anon_sym_LPAREN,
    STATE(7556), 1,
      aux_sym_annotation_repeat1,
    STATE(9301), 1,
      sym_arguments,
    STATE(7567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [378824] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378902] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [378941] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8371), 1,
      sym__alpha_identifier,
    ACTIONS(8377), 1,
      anon_sym__,
    ACTIONS(8381), 1,
      anon_sym_LPAREN,
    ACTIONS(8383), 1,
      sym__backquoted_id,
    ACTIONS(8385), 1,
      sym_operator_identifier,
    STATE(4552), 1,
      sym__simple_type,
    STATE(5397), 1,
      sym_identifier,
    STATE(5481), 1,
      sym__soft_identifier,
    STATE(6356), 1,
      sym__annotated_type,
    STATE(6590), 1,
      sym_annotated_type,
    STATE(16872), 1,
      sym_stable_identifier,
    STATE(7572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8379), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5430), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [379002] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [379041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379080] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379119] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8199), 1,
      sym__alpha_identifier,
    ACTIONS(8201), 1,
      anon_sym__,
    ACTIONS(8205), 1,
      anon_sym_LPAREN,
    ACTIONS(8207), 1,
      sym__backquoted_id,
    ACTIONS(8209), 1,
      sym_operator_identifier,
    STATE(5268), 1,
      sym__simple_type,
    STATE(6795), 1,
      sym_identifier,
    STATE(7174), 1,
      sym__soft_identifier,
    STATE(8292), 1,
      sym_annotated_type,
    STATE(8305), 1,
      sym__annotated_type,
    STATE(17684), 1,
      sym_stable_identifier,
    STATE(7576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8203), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6972), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [379180] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [379219] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [379258] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6286), 1,
      sym__alpha_identifier,
    ACTIONS(6288), 1,
      anon_sym__,
    ACTIONS(6296), 1,
      sym__backquoted_id,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    ACTIONS(10003), 1,
      anon_sym_LPAREN,
    STATE(6470), 1,
      sym__simple_type,
    STATE(6838), 1,
      sym__soft_identifier,
    STATE(7402), 1,
      sym_identifier,
    STATE(10239), 1,
      sym_annotated_type,
    STATE(10299), 1,
      sym__annotated_type,
    STATE(16771), 1,
      sym_stable_identifier,
    STATE(7579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6292), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7941), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [379319] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5730), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(7580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [379362] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379401] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379440] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379479] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [379518] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379557] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8608), 1,
      sym_operator_identifier,
    STATE(1786), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8309), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [379610] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11310), 1,
      anon_sym_DOT,
    STATE(7587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [379651] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [379690] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [379729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [379768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [379807] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379846] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11312), 1,
      anon_sym_COLON,
    ACTIONS(11314), 1,
      anon_sym_LBRACE,
    ACTIONS(11316), 1,
      anon_sym_with,
    STATE(10180), 1,
      aux_sym_compound_type_repeat1,
    STATE(10919), 1,
      sym_template_body,
    STATE(10942), 1,
      sym__refinement,
    STATE(7593), 2,
      sym_comment,
      sym_block_comment,
    STATE(10924), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379938] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [379977] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380016] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380055] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [380094] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [380172] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [380211] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(493), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    ACTIONS(10442), 1,
      anon_sym_DOT,
    ACTIONS(10911), 1,
      sym__alpha_identifier,
    ACTIONS(10917), 1,
      sym__backquoted_id,
    ACTIONS(10919), 1,
      sym_operator_identifier,
    ACTIONS(11318), 1,
      anon_sym_EQ,
    STATE(646), 1,
      sym_identifier,
    STATE(4200), 1,
      sym__soft_identifier,
    STATE(7602), 2,
      sym_comment,
      sym_block_comment,
    STATE(9927), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [380274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380313] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9337), 1,
      sym__alpha_identifier,
    ACTIONS(9343), 1,
      sym__backquoted_id,
    ACTIONS(9345), 1,
      sym_operator_identifier,
    STATE(581), 1,
      sym_identifier,
    STATE(4080), 1,
      sym__soft_identifier,
    STATE(7604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9339), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(9022), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [380366] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [380405] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11320), 1,
      anon_sym_AT,
    STATE(9118), 1,
      sym_annotation,
    STATE(7606), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380448] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6402), 1,
      sym__alpha_identifier,
    ACTIONS(6408), 1,
      anon_sym__,
    ACTIONS(6416), 1,
      sym__backquoted_id,
    ACTIONS(6418), 1,
      sym_operator_identifier,
    ACTIONS(10224), 1,
      anon_sym_LPAREN,
    STATE(5296), 1,
      sym__simple_type,
    STATE(5859), 1,
      sym_identifier,
    STATE(5895), 1,
      sym__soft_identifier,
    STATE(8619), 1,
      sym__annotated_type,
    STATE(8665), 1,
      sym_annotated_type,
    STATE(17654), 1,
      sym_stable_identifier,
    STATE(7607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6775), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [380509] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11323), 1,
      anon_sym_LBRACE,
    ACTIONS(11325), 1,
      anon_sym_with,
    STATE(10181), 1,
      aux_sym_compound_type_repeat1,
    STATE(11090), 1,
      sym_template_body,
    STATE(11123), 1,
      sym__refinement,
    STATE(7608), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7776), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380560] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9397), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380640] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [380718] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4660), 1,
      sym__alpha_identifier,
    ACTIONS(4666), 1,
      anon_sym__,
    ACTIONS(4678), 1,
      sym__backquoted_id,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    ACTIONS(10054), 1,
      anon_sym_LPAREN,
    STATE(4446), 1,
      sym__simple_type,
    STATE(4601), 1,
      sym__soft_identifier,
    STATE(4620), 1,
      sym_identifier,
    STATE(6010), 1,
      sym__annotated_type,
    STATE(6053), 1,
      sym_annotated_type,
    STATE(16896), 1,
      sym_stable_identifier,
    STATE(7613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4672), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4757), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [380779] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [380818] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380859] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380898] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380937] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11312), 1,
      anon_sym_COLON,
    ACTIONS(11316), 1,
      anon_sym_with,
    STATE(10180), 1,
      aux_sym_compound_type_repeat1,
    STATE(10919), 1,
      sym_template_body,
    STATE(10942), 1,
      sym__refinement,
    STATE(7618), 2,
      sym_comment,
      sym_block_comment,
    STATE(10924), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [380988] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11327), 1,
      anon_sym_with,
    STATE(7619), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381029] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [381068] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [381107] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9848), 1,
      anon_sym_AT,
    STATE(7768), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9174), 1,
      sym_annotation,
    STATE(7622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381152] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4182), 1,
      sym__alpha_identifier,
    ACTIONS(4188), 1,
      anon_sym__,
    ACTIONS(4200), 1,
      sym__backquoted_id,
    ACTIONS(6316), 1,
      sym_operator_identifier,
    ACTIONS(9943), 1,
      anon_sym_LPAREN,
    STATE(4560), 1,
      sym__simple_type,
    STATE(4657), 1,
      sym__soft_identifier,
    STATE(4661), 1,
      sym_identifier,
    STATE(6338), 1,
      sym_annotated_type,
    STATE(6366), 1,
      sym__annotated_type,
    STATE(17648), 1,
      sym_stable_identifier,
    STATE(7623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4194), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4885), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [381213] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10140), 1,
      anon_sym_AT,
    STATE(7965), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9040), 1,
      sym_annotation,
    STATE(7624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381258] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11330), 1,
      anon_sym_DOT,
    STATE(7625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381299] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    ACTIONS(10084), 1,
      anon_sym_LPAREN,
    STATE(7029), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(10479), 1,
      sym_annotated_type,
    STATE(10554), 1,
      sym__annotated_type,
    STATE(16743), 1,
      sym_stable_identifier,
    STATE(7626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [381360] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11332), 1,
      anon_sym_COLON,
    ACTIONS(11335), 1,
      anon_sym_LBRACE,
    STATE(9942), 1,
      sym_template_body,
    STATE(7627), 2,
      sym_comment,
      sym_block_comment,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 12,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381407] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [381446] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [381485] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [381524] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4750), 1,
      sym__alpha_identifier,
    ACTIONS(4752), 1,
      anon_sym__,
    ACTIONS(4762), 1,
      sym__backquoted_id,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    ACTIONS(9846), 1,
      anon_sym_LPAREN,
    STATE(4614), 1,
      sym__simple_type,
    STATE(4635), 1,
      sym__soft_identifier,
    STATE(4732), 1,
      sym_identifier,
    STATE(6307), 1,
      sym_annotated_type,
    STATE(6316), 1,
      sym__annotated_type,
    STATE(17642), 1,
      sym_stable_identifier,
    STATE(7631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4758), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4869), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [381585] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11218), 1,
      anon_sym_EQ_GT,
    STATE(7632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381626] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381665] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6268), 1,
      sym__alpha_identifier,
    ACTIONS(6274), 1,
      anon_sym__,
    ACTIONS(6282), 1,
      sym__backquoted_id,
    ACTIONS(6284), 1,
      sym_operator_identifier,
    ACTIONS(10080), 1,
      anon_sym_LPAREN,
    STATE(5337), 1,
      sym__simple_type,
    STATE(5695), 1,
      sym_identifier,
    STATE(5862), 1,
      sym__soft_identifier,
    STATE(8317), 1,
      sym_annotated_type,
    STATE(8339), 1,
      sym__annotated_type,
    STATE(17690), 1,
      sym_stable_identifier,
    STATE(7634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6278), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6225), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [381726] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381765] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [381804] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381845] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [381884] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    ACTIONS(10330), 1,
      anon_sym_LPAREN,
    STATE(4796), 1,
      sym__simple_type,
    STATE(4977), 1,
      sym_identifier,
    STATE(5072), 1,
      sym__soft_identifier,
    STATE(7040), 1,
      sym__annotated_type,
    STATE(7069), 1,
      sym_annotated_type,
    STATE(17635), 1,
      sym_stable_identifier,
    STATE(7639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5463), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [381945] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11338), 1,
      anon_sym_with,
    STATE(7640), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [381986] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [382025] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382064] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    ACTIONS(10315), 1,
      anon_sym_LPAREN,
    STATE(7919), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(10414), 1,
      sym__annotated_type,
    STATE(10460), 1,
      sym_annotated_type,
    STATE(16720), 1,
      sym_stable_identifier,
    STATE(7643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [382125] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382164] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [382203] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4624), 1,
      sym__alpha_identifier,
    ACTIONS(4630), 1,
      anon_sym__,
    ACTIONS(4642), 1,
      sym__backquoted_id,
    ACTIONS(6630), 1,
      sym_operator_identifier,
    ACTIONS(9965), 1,
      anon_sym_LPAREN,
    STATE(4437), 1,
      sym__simple_type,
    STATE(4445), 1,
      sym__soft_identifier,
    STATE(4449), 1,
      sym_identifier,
    STATE(5361), 1,
      sym_annotated_type,
    STATE(5365), 1,
      sym__annotated_type,
    STATE(17628), 1,
      sym_stable_identifier,
    STATE(7646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4542), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [382264] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9495), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382305] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11323), 1,
      anon_sym_LBRACE,
    ACTIONS(11325), 1,
      anon_sym_with,
    STATE(7608), 1,
      aux_sym_compound_type_repeat1,
    STATE(11090), 1,
      sym_template_body,
    STATE(11098), 1,
      sym__refinement,
    STATE(7648), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382356] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382395] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [382434] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382512] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [382551] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8042), 1,
      sym__alpha_identifier,
    ACTIONS(8044), 1,
      anon_sym__,
    ACTIONS(8048), 1,
      anon_sym_LPAREN,
    ACTIONS(8050), 1,
      sym__backquoted_id,
    ACTIONS(8052), 1,
      sym_operator_identifier,
    STATE(5833), 1,
      sym__simple_type,
    STATE(7769), 1,
      sym__soft_identifier,
    STATE(8225), 1,
      sym_identifier,
    STATE(9170), 1,
      sym_annotated_type,
    STATE(9207), 1,
      sym__annotated_type,
    STATE(17702), 1,
      sym_stable_identifier,
    STATE(7654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8046), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7951), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [382612] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(13547), 1,
      sym__simple_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(14600), 1,
      sym_annotated_type,
    STATE(15141), 1,
      sym__annotated_type,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(7655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [382673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [382712] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11341), 1,
      anon_sym_COLON,
    ACTIONS(11343), 1,
      anon_sym_LBRACE,
    ACTIONS(11345), 1,
      anon_sym_with,
    STATE(10057), 1,
      aux_sym_compound_type_repeat1,
    STATE(11259), 1,
      sym_template_body,
    STATE(11317), 1,
      sym__refinement,
    STATE(7657), 2,
      sym_comment,
      sym_block_comment,
    STATE(11210), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7776), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382765] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [382804] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    ACTIONS(10177), 1,
      anon_sym_LPAREN,
    STATE(5012), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(8079), 1,
      sym_annotated_type,
    STATE(8117), 1,
      sym__annotated_type,
    STATE(16918), 1,
      sym_stable_identifier,
    STATE(7659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [382865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [382904] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [382943] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [382982] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6336), 1,
      sym__alpha_identifier,
    ACTIONS(6342), 1,
      anon_sym__,
    ACTIONS(6350), 1,
      sym__backquoted_id,
    ACTIONS(6352), 1,
      sym_operator_identifier,
    ACTIONS(10062), 1,
      anon_sym_LPAREN,
    STATE(5944), 1,
      sym__simple_type,
    STATE(6347), 1,
      sym__soft_identifier,
    STATE(6696), 1,
      sym_identifier,
    STATE(9248), 1,
      sym_annotated_type,
    STATE(9308), 1,
      sym__annotated_type,
    STATE(17708), 1,
      sym_stable_identifier,
    STATE(7663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6346), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7084), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [383043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [383082] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383121] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5538), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(7666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [383164] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [383203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383320] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8722), 1,
      sym__end_marker,
    STATE(7671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [383361] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11347), 1,
      anon_sym_AT,
    STATE(9355), 1,
      sym_annotation,
    STATE(7672), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383404] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6510), 1,
      anon_sym__,
    ACTIONS(6518), 1,
      sym__backquoted_id,
    ACTIONS(6520), 1,
      sym_operator_identifier,
    ACTIONS(10033), 1,
      anon_sym_LPAREN,
    STATE(7064), 1,
      sym__simple_type,
    STATE(7863), 1,
      sym__soft_identifier,
    STATE(8147), 1,
      sym_identifier,
    STATE(10066), 1,
      sym_annotated_type,
    STATE(10072), 1,
      sym__annotated_type,
    STATE(17720), 1,
      sym_stable_identifier,
    STATE(7673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6514), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [383465] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [383504] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11350), 1,
      anon_sym_with,
    STATE(7675), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383545] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [383584] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10232), 1,
      anon_sym_LPAREN,
    STATE(7695), 1,
      aux_sym_annotation_repeat1,
    STATE(9142), 1,
      sym_arguments,
    STATE(7677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383629] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4812), 1,
      sym__alpha_identifier,
    ACTIONS(4814), 1,
      anon_sym__,
    ACTIONS(4824), 1,
      sym__backquoted_id,
    ACTIONS(6598), 1,
      sym_operator_identifier,
    ACTIONS(10270), 1,
      anon_sym_LPAREN,
    STATE(5711), 1,
      sym__simple_type,
    STATE(6255), 1,
      sym_identifier,
    STATE(6330), 1,
      sym__soft_identifier,
    STATE(9473), 1,
      sym__annotated_type,
    STATE(9582), 1,
      sym_annotated_type,
    STATE(16701), 1,
      sym_stable_identifier,
    STATE(7678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4820), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7403), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [383690] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [383729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383807] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383846] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383885] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [383924] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [383963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384002] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11353), 1,
      anon_sym_with,
    STATE(7687), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [384043] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7850), 1,
      sym__alpha_identifier,
    ACTIONS(7856), 1,
      anon_sym__,
    ACTIONS(7860), 1,
      anon_sym_LPAREN,
    ACTIONS(7862), 1,
      sym__backquoted_id,
    ACTIONS(7864), 1,
      sym_operator_identifier,
    STATE(11873), 1,
      sym__simple_type,
    STATE(12550), 1,
      sym_identifier,
    STATE(12664), 1,
      sym__soft_identifier,
    STATE(14212), 1,
      sym_annotated_type,
    STATE(14223), 1,
      sym__annotated_type,
    STATE(17732), 1,
      sym_stable_identifier,
    STATE(7688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13328), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [384104] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384143] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384188] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384227] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [384305] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384344] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11356), 1,
      anon_sym_LPAREN,
    STATE(9142), 1,
      sym_arguments,
    STATE(7695), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384387] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    ACTIONS(10317), 1,
      anon_sym_LPAREN,
    STATE(6294), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(10087), 1,
      sym__annotated_type,
    STATE(10099), 1,
      sym_annotated_type,
    STATE(16940), 1,
      sym_stable_identifier,
    STATE(7696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [384448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [384487] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11183), 1,
      anon_sym_EQ_GT,
    STATE(7698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384528] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11359), 1,
      anon_sym_AT,
    STATE(9276), 1,
      sym_annotation,
    STATE(7699), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384571] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [384610] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7810), 1,
      anon_sym__,
    ACTIONS(7812), 1,
      anon_sym_LPAREN,
    ACTIONS(7814), 1,
      sym_operator_identifier,
    STATE(11732), 1,
      sym__simple_type,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12944), 1,
      sym_identifier,
    STATE(14103), 1,
      sym_annotated_type,
    STATE(14209), 1,
      sym__annotated_type,
    STATE(17617), 1,
      sym_stable_identifier,
    STATE(7701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13249), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [384671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [384710] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [384749] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384788] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [384827] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8287), 1,
      sym__alpha_identifier,
    ACTIONS(8293), 1,
      anon_sym__,
    ACTIONS(8297), 1,
      anon_sym_LPAREN,
    ACTIONS(8299), 1,
      sym__backquoted_id,
    ACTIONS(8301), 1,
      sym_operator_identifier,
    STATE(4447), 1,
      sym__simple_type,
    STATE(4930), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(5501), 1,
      sym_annotated_type,
    STATE(5542), 1,
      sym__annotated_type,
    STATE(17738), 1,
      sym_stable_identifier,
    STATE(7706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8295), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5066), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [384888] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [384927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [384966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385005] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385122] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10958), 1,
      anon_sym_DOT,
    ACTIONS(11362), 1,
      anon_sym_EQ_GT,
    STATE(7713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385165] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11364), 1,
      anon_sym_LPAREN,
    STATE(9252), 1,
      sym_arguments,
    STATE(7714), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385286] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385325] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8411), 1,
      sym__alpha_identifier,
    ACTIONS(8413), 1,
      anon_sym__,
    ACTIONS(8417), 1,
      anon_sym_LPAREN,
    ACTIONS(8419), 1,
      sym__backquoted_id,
    ACTIONS(8421), 1,
      sym_operator_identifier,
    STATE(6667), 1,
      sym__simple_type,
    STATE(8325), 1,
      sym_identifier,
    STATE(8883), 1,
      sym__soft_identifier,
    STATE(9816), 1,
      sym__annotated_type,
    STATE(9910), 1,
      sym_annotated_type,
    STATE(16739), 1,
      sym_stable_identifier,
    STATE(7718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8415), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8510), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [385386] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385425] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385464] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10739), 1,
      anon_sym_LPAREN,
    STATE(7714), 1,
      aux_sym_annotation_repeat1,
    STATE(9252), 1,
      sym_arguments,
    STATE(7721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385509] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [385548] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385587] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6662), 1,
      sym__alpha_identifier,
    ACTIONS(6664), 1,
      anon_sym__,
    ACTIONS(6672), 1,
      sym__backquoted_id,
    ACTIONS(6674), 1,
      sym_operator_identifier,
    ACTIONS(10037), 1,
      anon_sym_LPAREN,
    STATE(4496), 1,
      sym__simple_type,
    STATE(4616), 1,
      sym_identifier,
    STATE(4632), 1,
      sym__soft_identifier,
    STATE(5589), 1,
      sym_annotated_type,
    STATE(5604), 1,
      sym__annotated_type,
    STATE(17744), 1,
      sym_stable_identifier,
    STATE(7724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6668), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4799), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [385648] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [385726] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385765] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5499), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(7728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [385808] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385847] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8766), 1,
      sym_arguments,
    STATE(7730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385888] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9463), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [385968] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [386007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [386046] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11305), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11367), 1,
      anon_sym_COMMA,
    ACTIONS(11369), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11780), 1,
      sym_interpolated_string,
    STATE(15557), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(16279), 1,
      sym__interpolated_string_start,
    STATE(7735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [386119] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11377), 1,
      anon_sym_EQ_GT,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    ACTIONS(11387), 1,
      sym__interpolated_multiline_string_start,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11852), 1,
      sym_interpolated_string,
    STATE(16134), 1,
      sym__interpolated_string_start,
    STATE(18342), 1,
      sym_guard,
    STATE(7736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [386192] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4390), 1,
      sym__alpha_identifier,
    ACTIONS(4396), 1,
      anon_sym__,
    ACTIONS(4408), 1,
      sym__backquoted_id,
    ACTIONS(6692), 1,
      sym_operator_identifier,
    ACTIONS(9905), 1,
      anon_sym_LPAREN,
    STATE(6561), 1,
      sym__simple_type,
    STATE(7208), 1,
      sym__soft_identifier,
    STATE(7259), 1,
      sym_identifier,
    STATE(9943), 1,
      sym_annotated_type,
    STATE(9959), 1,
      sym__annotated_type,
    STATE(17606), 1,
      sym_stable_identifier,
    STATE(7737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4402), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8276), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [386253] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386292] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [386331] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11389), 1,
      anon_sym_with,
    STATE(7740), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386372] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386411] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386450] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386489] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6884), 1,
      sym__alpha_identifier,
    ACTIONS(6886), 1,
      anon_sym__,
    ACTIONS(6894), 1,
      sym__backquoted_id,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    ACTIONS(10402), 1,
      anon_sym_LPAREN,
    STATE(6102), 1,
      sym__simple_type,
    STATE(6268), 1,
      sym__soft_identifier,
    STATE(6574), 1,
      sym_identifier,
    STATE(9782), 1,
      sym_annotated_type,
    STATE(9876), 1,
      sym__annotated_type,
    STATE(16962), 1,
      sym_stable_identifier,
    STATE(7744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6890), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7231), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [386550] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [386589] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386628] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386706] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386745] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(15833), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(7750), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [386812] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6676), 1,
      sym__alpha_identifier,
    ACTIONS(6678), 1,
      anon_sym__,
    ACTIONS(6686), 1,
      sym__backquoted_id,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    ACTIONS(9951), 1,
      anon_sym_LPAREN,
    STATE(6998), 1,
      sym__simple_type,
    STATE(7765), 1,
      sym_identifier,
    STATE(7792), 1,
      sym__soft_identifier,
    STATE(10292), 1,
      sym__annotated_type,
    STATE(10305), 1,
      sym_annotated_type,
    STATE(17582), 1,
      sym_stable_identifier,
    STATE(7751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6682), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8371), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [386873] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386912] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11392), 1,
      anon_sym_DOT,
    STATE(7753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [386992] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11394), 1,
      anon_sym_COLON,
    ACTIONS(11397), 1,
      anon_sym_LBRACE,
    STATE(9841), 1,
      sym_template_body,
    STATE(5676), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(7755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8900), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 12,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387078] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11400), 1,
      anon_sym_with,
    STATE(7757), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [387119] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387158] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387197] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10602), 1,
      anon_sym_AT,
    STATE(7699), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9276), 1,
      sym_annotation,
    STATE(7760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [387281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387320] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387398] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11403), 1,
      anon_sym_DOT,
    STATE(7765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387439] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387478] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [387517] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11405), 1,
      anon_sym_AT,
    STATE(9174), 1,
      sym_annotation,
    STATE(7768), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387560] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387599] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [387638] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [387677] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 7,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387722] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11267), 1,
      anon_sym_COLON,
    ACTIONS(11269), 1,
      anon_sym_LBRACE,
    ACTIONS(11271), 1,
      anon_sym_with,
    STATE(7508), 1,
      aux_sym_compound_type_repeat1,
    STATE(11341), 1,
      sym__refinement,
    STATE(11343), 1,
      sym_template_body,
    STATE(7773), 2,
      sym_comment,
      sym_block_comment,
    STATE(11189), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387775] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387814] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387853] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10863), 1,
      anon_sym_AT,
    STATE(8016), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9090), 1,
      sym_annotation,
    STATE(7776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387898] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [387939] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8393), 1,
      sym__alpha_identifier,
    ACTIONS(8395), 1,
      anon_sym__,
    ACTIONS(8399), 1,
      anon_sym_LPAREN,
    ACTIONS(8401), 1,
      sym__backquoted_id,
    ACTIONS(8403), 1,
      sym_operator_identifier,
    STATE(5740), 1,
      sym__simple_type,
    STATE(7599), 1,
      sym__soft_identifier,
    STATE(7844), 1,
      sym_identifier,
    STATE(8993), 1,
      sym__annotated_type,
    STATE(9034), 1,
      sym_annotated_type,
    STATE(16788), 1,
      sym_stable_identifier,
    STATE(7778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8397), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7617), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [388000] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [388039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388078] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [388117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388156] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4868), 1,
      sym__alpha_identifier,
    ACTIONS(4870), 1,
      anon_sym__,
    ACTIONS(4880), 1,
      sym__backquoted_id,
    ACTIONS(6850), 1,
      sym_operator_identifier,
    ACTIONS(10249), 1,
      anon_sym_LPAREN,
    STATE(5113), 1,
      sym__simple_type,
    STATE(5536), 1,
      sym_identifier,
    STATE(5967), 1,
      sym__soft_identifier,
    STATE(8739), 1,
      sym_annotated_type,
    STATE(8772), 1,
      sym__annotated_type,
    STATE(17570), 1,
      sym_stable_identifier,
    STATE(7783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6401), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [388217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388256] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388295] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6754), 1,
      sym__alpha_identifier,
    ACTIONS(6756), 1,
      anon_sym__,
    ACTIONS(6764), 1,
      sym__backquoted_id,
    ACTIONS(6766), 1,
      sym_operator_identifier,
    ACTIONS(9742), 1,
      anon_sym_LPAREN,
    STATE(4748), 1,
      sym__simple_type,
    STATE(4984), 1,
      sym_identifier,
    STATE(4998), 1,
      sym__soft_identifier,
    STATE(6891), 1,
      sym_annotated_type,
    STATE(6898), 1,
      sym__annotated_type,
    STATE(17750), 1,
      sym_stable_identifier,
    STATE(7786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6760), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [388356] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8829), 1,
      sym__end_marker,
    STATE(7787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9449), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [388397] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8579), 1,
      sym_arguments,
    STATE(7788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [388438] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6796), 1,
      anon_sym__,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(6806), 1,
      sym_operator_identifier,
    ACTIONS(10323), 1,
      anon_sym_LPAREN,
    STATE(5378), 1,
      sym__simple_type,
    STATE(5755), 1,
      sym_identifier,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(9007), 1,
      sym__annotated_type,
    STATE(9021), 1,
      sym_annotated_type,
    STATE(16984), 1,
      sym_stable_identifier,
    STATE(7789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [388499] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [388538] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388616] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [388694] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388733] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9259), 1,
      sym__alpha_identifier,
    ACTIONS(9265), 1,
      sym__backquoted_id,
    ACTIONS(9267), 1,
      sym_operator_identifier,
    STATE(580), 1,
      sym_identifier,
    STATE(4062), 1,
      sym__soft_identifier,
    STATE(7796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9261), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(9022), 7,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [388786] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [388866] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5702), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(7799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [388909] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [388948] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8873), 1,
      sym_operator_identifier,
    STATE(1835), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8309), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [389003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [389042] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [389081] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [389120] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389159] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [389198] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8449), 1,
      sym__alpha_identifier,
    ACTIONS(8451), 1,
      anon_sym__,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    ACTIONS(8457), 1,
      sym__backquoted_id,
    ACTIONS(8459), 1,
      sym_operator_identifier,
    STATE(4813), 1,
      sym__simple_type,
    STATE(5831), 1,
      sym__soft_identifier,
    STATE(6085), 1,
      sym_identifier,
    STATE(6909), 1,
      sym_annotated_type,
    STATE(6919), 1,
      sym__annotated_type,
    STATE(17756), 1,
      sym_stable_identifier,
    STATE(7807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8453), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [389259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389298] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [389337] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389376] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389415] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389454] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    ACTIONS(10215), 1,
      anon_sym_LPAREN,
    STATE(7533), 1,
      sym__simple_type,
    STATE(8692), 1,
      sym_identifier,
    STATE(8795), 1,
      sym__soft_identifier,
    STATE(10744), 1,
      sym_annotated_type,
    STATE(10771), 1,
      sym__annotated_type,
    STATE(17006), 1,
      sym_stable_identifier,
    STATE(7813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [389515] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [389554] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6972), 1,
      anon_sym__,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(6982), 1,
      sym_operator_identifier,
    ACTIONS(10319), 1,
      anon_sym_LPAREN,
    STATE(5099), 1,
      sym__simple_type,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6043), 1,
      sym_identifier,
    STATE(9303), 1,
      sym__annotated_type,
    STATE(9349), 1,
      sym_annotated_type,
    STATE(17544), 1,
      sym_stable_identifier,
    STATE(7815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6339), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [389615] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389654] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389732] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389771] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11408), 1,
      anon_sym_AT,
    STATE(9413), 1,
      sym_annotation,
    STATE(7820), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [389814] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389931] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [389970] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10725), 1,
      anon_sym_AT,
    STATE(7960), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9098), 1,
      sym_annotation,
    STATE(7825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [390054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [390093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390132] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390171] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390212] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [390251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [390290] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6528), 1,
      sym__alpha_identifier,
    ACTIONS(6530), 1,
      anon_sym__,
    ACTIONS(6538), 1,
      sym__backquoted_id,
    ACTIONS(6540), 1,
      sym_operator_identifier,
    ACTIONS(10135), 1,
      anon_sym_LPAREN,
    STATE(7390), 1,
      sym__simple_type,
    STATE(7921), 1,
      sym_identifier,
    STATE(7952), 1,
      sym__soft_identifier,
    STATE(10528), 1,
      sym_annotated_type,
    STATE(10561), 1,
      sym__annotated_type,
    STATE(17028), 1,
      sym_stable_identifier,
    STATE(7833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6534), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8432), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [390351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390390] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [390429] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(11323), 1,
      anon_sym_LBRACE,
    ACTIONS(11325), 1,
      anon_sym_with,
    ACTIONS(11411), 1,
      anon_sym_COLON,
    STATE(7608), 1,
      aux_sym_compound_type_repeat1,
    STATE(11090), 1,
      sym_template_body,
    STATE(11098), 1,
      sym__refinement,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(7882), 2,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7836), 2,
      sym_comment,
      sym_block_comment,
    STATE(11015), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390488] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6900), 1,
      sym__alpha_identifier,
    ACTIONS(6906), 1,
      anon_sym__,
    ACTIONS(6914), 1,
      sym__backquoted_id,
    ACTIONS(6916), 1,
      sym_operator_identifier,
    ACTIONS(9798), 1,
      anon_sym_LPAREN,
    STATE(4794), 1,
      sym__simple_type,
    STATE(5011), 1,
      sym_identifier,
    STATE(5013), 1,
      sym__soft_identifier,
    STATE(6935), 1,
      sym_annotated_type,
    STATE(6950), 1,
      sym__annotated_type,
    STATE(17762), 1,
      sym_stable_identifier,
    STATE(7837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6910), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5168), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [390549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390588] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390627] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390666] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390744] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390783] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11414), 1,
      anon_sym_DOT,
    STATE(7844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390824] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390902] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [390941] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11416), 1,
      anon_sym_with,
    STATE(7848), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [390982] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391060] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391099] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391138] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9776), 1,
      anon_sym_AT,
    STATE(8114), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8940), 1,
      sym_annotation,
    STATE(7853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391183] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(11341), 1,
      anon_sym_COLON,
    ACTIONS(11343), 1,
      anon_sym_LBRACE,
    ACTIONS(11345), 1,
      anon_sym_with,
    STATE(7657), 1,
      aux_sym_compound_type_repeat1,
    STATE(11259), 1,
      sym_template_body,
    STATE(11264), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7854), 2,
      sym_comment,
      sym_block_comment,
    STATE(11210), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391240] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391320] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391359] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym__,
    ACTIONS(6840), 1,
      sym__backquoted_id,
    ACTIONS(6842), 1,
      sym_operator_identifier,
    ACTIONS(10351), 1,
      anon_sym_LPAREN,
    STATE(5560), 1,
      sym__simple_type,
    STATE(6117), 1,
      sym_identifier,
    STATE(6232), 1,
      sym__soft_identifier,
    STATE(9674), 1,
      sym_annotated_type,
    STATE(9718), 1,
      sym__annotated_type,
    STATE(17531), 1,
      sym_stable_identifier,
    STATE(7858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6836), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7013), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [391420] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391498] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11419), 1,
      anon_sym_COLON,
    ACTIONS(11421), 1,
      anon_sym_COMMA,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11429), 1,
      anon_sym_EQ,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(15294), 1,
      aux_sym_val_declaration_repeat1,
    STATE(16094), 1,
      sym__interpolated_string_start,
    STATE(7861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [391571] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391610] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391688] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391727] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [391766] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [391805] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [391844] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6940), 1,
      sym__alpha_identifier,
    ACTIONS(6946), 1,
      anon_sym__,
    ACTIONS(6954), 1,
      sym__backquoted_id,
    ACTIONS(6956), 1,
      sym_operator_identifier,
    ACTIONS(9975), 1,
      anon_sym_LPAREN,
    STATE(5622), 1,
      sym__simple_type,
    STATE(6376), 1,
      sym__soft_identifier,
    STATE(6428), 1,
      sym_identifier,
    STATE(9264), 1,
      sym__annotated_type,
    STATE(9297), 1,
      sym_annotated_type,
    STATE(17774), 1,
      sym_stable_identifier,
    STATE(7869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7299), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [391905] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [391950] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8359), 1,
      sym__alpha_identifier,
    ACTIONS(8361), 1,
      anon_sym__,
    ACTIONS(8365), 1,
      anon_sym_LPAREN,
    ACTIONS(8367), 1,
      sym__backquoted_id,
    ACTIONS(8369), 1,
      sym_operator_identifier,
    STATE(4937), 1,
      sym__simple_type,
    STATE(6353), 1,
      sym__soft_identifier,
    STATE(6499), 1,
      sym_identifier,
    STATE(8135), 1,
      sym__annotated_type,
    STATE(8180), 1,
      sym_annotated_type,
    STATE(16832), 1,
      sym_stable_identifier,
    STATE(7871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8363), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [392011] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11421), 1,
      anon_sym_COMMA,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11437), 1,
      anon_sym_COLON,
    ACTIONS(11439), 1,
      anon_sym_EQ,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(15288), 1,
      aux_sym_val_declaration_repeat1,
    STATE(16094), 1,
      sym__interpolated_string_start,
    STATE(7872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [392084] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6026), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(7873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [392127] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    ACTIONS(10321), 1,
      anon_sym_LPAREN,
    STATE(6620), 1,
      sym__simple_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7459), 1,
      sym_identifier,
    STATE(10224), 1,
      sym_annotated_type,
    STATE(10311), 1,
      sym__annotated_type,
    STATE(17518), 1,
      sym_stable_identifier,
    STATE(7874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [392188] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11341), 1,
      anon_sym_COLON,
    ACTIONS(11343), 1,
      anon_sym_LBRACE,
    ACTIONS(11345), 1,
      anon_sym_with,
    STATE(7657), 1,
      aux_sym_compound_type_repeat1,
    STATE(11259), 1,
      sym_template_body,
    STATE(11264), 1,
      sym__refinement,
    STATE(7875), 2,
      sym_comment,
      sym_block_comment,
    STATE(11210), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392241] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392280] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392319] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [392360] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(10106), 1,
      anon_sym_LPAREN,
    STATE(6045), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(8944), 1,
      sym__annotated_type,
    STATE(9180), 1,
      sym_annotated_type,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(7879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [392421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [392460] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392499] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [392538] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392616] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    ACTIONS(10060), 1,
      anon_sym_LPAREN,
    STATE(7268), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(10616), 1,
      sym_annotated_type,
    STATE(10651), 1,
      sym__annotated_type,
    STATE(17050), 1,
      sym_stable_identifier,
    STATE(7885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [392677] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392716] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [392755] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [392794] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [392833] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [392872] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4530), 1,
      sym__alpha_identifier,
    ACTIONS(4536), 1,
      anon_sym__,
    ACTIONS(4548), 1,
      sym__backquoted_id,
    ACTIONS(6526), 1,
      sym_operator_identifier,
    ACTIONS(10265), 1,
      anon_sym_LPAREN,
    STATE(5311), 1,
      sym__simple_type,
    STATE(5882), 1,
      sym__soft_identifier,
    STATE(5987), 1,
      sym_identifier,
    STATE(8467), 1,
      sym__annotated_type,
    STATE(8575), 1,
      sym_annotated_type,
    STATE(17666), 1,
      sym_stable_identifier,
    STATE(7891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4542), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6618), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [392933] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8275), 1,
      sym__alpha_identifier,
    ACTIONS(8277), 1,
      anon_sym__,
    ACTIONS(8281), 1,
      anon_sym_LPAREN,
    ACTIONS(8283), 1,
      sym__backquoted_id,
    ACTIONS(8285), 1,
      sym_operator_identifier,
    STATE(4975), 1,
      sym__simple_type,
    STATE(6136), 1,
      sym_identifier,
    STATE(6327), 1,
      sym__soft_identifier,
    STATE(7703), 1,
      sym__annotated_type,
    STATE(7770), 1,
      sym_annotated_type,
    STATE(17071), 1,
      sym_stable_identifier,
    STATE(7892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8279), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6379), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [392994] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [393033] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [393072] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [393111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393150] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393228] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4310), 1,
      sym__alpha_identifier,
    ACTIONS(4316), 1,
      anon_sym__,
    ACTIONS(4328), 1,
      sym__backquoted_id,
    ACTIONS(6696), 1,
      sym_operator_identifier,
    ACTIONS(10041), 1,
      anon_sym_LPAREN,
    STATE(4737), 1,
      sym__simple_type,
    STATE(4906), 1,
      sym_identifier,
    STATE(5094), 1,
      sym__soft_identifier,
    STATE(6999), 1,
      sym_annotated_type,
    STATE(7014), 1,
      sym__annotated_type,
    STATE(17786), 1,
      sym_stable_identifier,
    STATE(7899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5293), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [393289] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_EQ,
    ACTIONS(11312), 1,
      anon_sym_COLON,
    ACTIONS(11314), 1,
      anon_sym_LBRACE,
    ACTIONS(11316), 1,
      anon_sym_with,
    STATE(7593), 1,
      aux_sym_compound_type_repeat1,
    STATE(10918), 1,
      sym__refinement,
    STATE(10919), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7900), 2,
      sym_comment,
      sym_block_comment,
    STATE(10924), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393348] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393428] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7940), 1,
      sym__alpha_identifier,
    ACTIONS(7946), 1,
      anon_sym__,
    ACTIONS(7950), 1,
      anon_sym_LPAREN,
    ACTIONS(7952), 1,
      sym__backquoted_id,
    ACTIONS(7954), 1,
      sym_operator_identifier,
    STATE(11033), 1,
      sym__simple_type,
    STATE(11430), 1,
      sym_identifier,
    STATE(11669), 1,
      sym__soft_identifier,
    STATE(12986), 1,
      sym__annotated_type,
    STATE(13035), 1,
      sym_annotated_type,
    STATE(17077), 1,
      sym_stable_identifier,
    STATE(7903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7948), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11959), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [393489] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11441), 1,
      anon_sym_DOT,
    STATE(7904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393530] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11421), 1,
      anon_sym_COMMA,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11443), 1,
      anon_sym_COLON,
    ACTIONS(11445), 1,
      anon_sym_EQ,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(15896), 1,
      aux_sym_val_declaration_repeat1,
    STATE(16094), 1,
      sym__interpolated_string_start,
    STATE(7905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [393603] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10966), 1,
      anon_sym_LBRACK,
    ACTIONS(10970), 1,
      anon_sym_POUND,
    ACTIONS(11447), 1,
      anon_sym_AT,
    STATE(9558), 1,
      sym_type_arguments,
    STATE(9883), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10529), 1,
      sym_annotation,
    ACTIONS(7694), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(7906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393654] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11421), 1,
      anon_sym_COMMA,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11449), 1,
      anon_sym_COLON,
    ACTIONS(11451), 1,
      anon_sym_EQ,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(15900), 1,
      aux_sym_val_declaration_repeat1,
    STATE(16094), 1,
      sym__interpolated_string_start,
    STATE(7907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [393727] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393766] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11312), 1,
      anon_sym_COLON,
    ACTIONS(11314), 1,
      anon_sym_LBRACE,
    ACTIONS(11316), 1,
      anon_sym_with,
    STATE(7593), 1,
      aux_sym_compound_type_repeat1,
    STATE(10918), 1,
      sym__refinement,
    STATE(10919), 1,
      sym_template_body,
    STATE(7909), 2,
      sym_comment,
      sym_block_comment,
    STATE(10924), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393819] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10381), 1,
      anon_sym_AT,
    STATE(7606), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9118), 1,
      sym_annotation,
    STATE(7910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [393864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [393903] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    ACTIONS(11387), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11453), 1,
      anon_sym_EQ_GT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11852), 1,
      sym_interpolated_string,
    STATE(16134), 1,
      sym__interpolated_string_start,
    STATE(17930), 1,
      sym_guard,
    STATE(7912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [393976] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4214), 1,
      sym__alpha_identifier,
    ACTIONS(4220), 1,
      anon_sym__,
    ACTIONS(4232), 1,
      sym__backquoted_id,
    ACTIONS(6752), 1,
      sym_operator_identifier,
    ACTIONS(10082), 1,
      anon_sym_LPAREN,
    STATE(4653), 1,
      sym__simple_type,
    STATE(4914), 1,
      sym_identifier,
    STATE(5031), 1,
      sym__soft_identifier,
    STATE(6944), 1,
      sym__annotated_type,
    STATE(6990), 1,
      sym_annotated_type,
    STATE(17054), 1,
      sym_stable_identifier,
    STATE(7913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4226), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5167), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [394037] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8469), 1,
      sym__alpha_identifier,
    ACTIONS(8475), 1,
      anon_sym__,
    ACTIONS(8479), 1,
      anon_sym_LPAREN,
    ACTIONS(8481), 1,
      sym__backquoted_id,
    ACTIONS(8483), 1,
      sym_operator_identifier,
    STATE(4774), 1,
      sym__simple_type,
    STATE(5527), 1,
      sym__soft_identifier,
    STATE(5936), 1,
      sym_identifier,
    STATE(7058), 1,
      sym_annotated_type,
    STATE(7147), 1,
      sym__annotated_type,
    STATE(17734), 1,
      sym_stable_identifier,
    STATE(7914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8477), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5525), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [394098] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8927), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [394139] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [394178] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10717), 1,
      anon_sym_AT,
    STATE(8237), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9030), 1,
      sym_annotation,
    STATE(7917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394223] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11305), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11455), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11780), 1,
      sym_interpolated_string,
    STATE(15955), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(16279), 1,
      sym__interpolated_string_start,
    STATE(7918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [394296] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10885), 1,
      anon_sym_LBRACK,
    ACTIONS(10889), 1,
      anon_sym_POUND,
    ACTIONS(11457), 1,
      anon_sym_AT,
    STATE(8979), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9228), 1,
      sym_type_arguments,
    STATE(10323), 1,
      sym_annotation,
    STATE(7919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394386] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11459), 1,
      anon_sym_DOT,
    STATE(7921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394427] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394466] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394544] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394622] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394661] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    ACTIONS(10272), 1,
      anon_sym_LPAREN,
    STATE(6544), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(9684), 1,
      sym__annotated_type,
    STATE(9746), 1,
      sym_annotated_type,
    STATE(17505), 1,
      sym_stable_identifier,
    STATE(7928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [394722] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394800] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394839] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394878] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394956] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11461), 1,
      anon_sym_with,
    STATE(7935), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [394997] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8309), 1,
      anon_sym_match,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10859), 1,
      anon_sym_LPAREN,
    ACTIONS(11273), 1,
      anon_sym_DOT,
    ACTIONS(11464), 1,
      sym_operator_identifier,
    STATE(1709), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7936), 2,
      sym_comment,
      sym_block_comment,
    STATE(10626), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [395060] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395099] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395138] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395216] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395255] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10183), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11466), 1,
      anon_sym_COLON,
    STATE(9974), 1,
      sym_interpolated_string,
    STATE(15927), 1,
      sym__interpolated_string_start,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(11469), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(7942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395308] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395386] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4830), 1,
      sym__alpha_identifier,
    ACTIONS(4836), 1,
      anon_sym__,
    ACTIONS(4848), 1,
      sym__backquoted_id,
    ACTIONS(6854), 1,
      sym_operator_identifier,
    ACTIONS(9973), 1,
      anon_sym_LPAREN,
    STATE(5061), 1,
      sym__simple_type,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5395), 1,
      sym_identifier,
    STATE(7590), 1,
      sym__annotated_type,
    STATE(7629), 1,
      sym_annotated_type,
    STATE(17092), 1,
      sym_stable_identifier,
    STATE(7945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4842), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5759), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [395447] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11472), 1,
      anon_sym_COLON,
    ACTIONS(11475), 1,
      anon_sym_LBRACE,
    STATE(9990), 1,
      sym_template_body,
    STATE(7946), 2,
      sym_comment,
      sym_block_comment,
    STATE(8802), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8892), 13,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [395494] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8259), 1,
      sym__alpha_identifier,
    ACTIONS(8265), 1,
      anon_sym__,
    ACTIONS(8269), 1,
      anon_sym_LPAREN,
    ACTIONS(8271), 1,
      sym__backquoted_id,
    ACTIONS(8273), 1,
      sym_operator_identifier,
    STATE(4512), 1,
      sym__simple_type,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(5062), 1,
      sym_identifier,
    STATE(5952), 1,
      sym_annotated_type,
    STATE(6014), 1,
      sym__annotated_type,
    STATE(17195), 1,
      sym_stable_identifier,
    STATE(7947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8267), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4969), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [395555] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395594] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395672] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395750] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395791] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395830] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11305), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11478), 1,
      anon_sym_COMMA,
    ACTIONS(11480), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11780), 1,
      sym_interpolated_string,
    STATE(15913), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(16279), 1,
      sym__interpolated_string_start,
    STATE(7955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [395903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395942] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [395981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396059] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11482), 1,
      anon_sym_AT,
    STATE(9098), 1,
      sym_annotation,
    STATE(7960), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396102] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [396141] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(7962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396182] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11485), 1,
      anon_sym_LPAREN,
    STATE(8968), 1,
      sym_arguments,
    STATE(7963), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396264] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11488), 1,
      anon_sym_AT,
    STATE(9040), 1,
      sym_annotation,
    STATE(7965), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396307] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6584), 1,
      anon_sym__,
    ACTIONS(6592), 1,
      sym__backquoted_id,
    ACTIONS(6594), 1,
      sym_operator_identifier,
    ACTIONS(10092), 1,
      anon_sym_LPAREN,
    STATE(5523), 1,
      sym__simple_type,
    STATE(6385), 1,
      sym__soft_identifier,
    STATE(6582), 1,
      sym_identifier,
    STATE(9141), 1,
      sym__annotated_type,
    STATE(9185), 1,
      sym_annotated_type,
    STATE(17792), 1,
      sym_stable_identifier,
    STATE(7966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6588), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7364), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [396368] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [396407] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396446] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396485] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396524] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [396565] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(10074), 1,
      anon_sym_LPAREN,
    STATE(6394), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(10254), 1,
      sym__annotated_type,
    STATE(10295), 1,
      sym_annotated_type,
    STATE(17249), 1,
      sym_stable_identifier,
    STATE(7972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [396626] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [396665] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [396704] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396743] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(7976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [396788] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396827] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9935), 1,
      anon_sym_LPAREN,
    STATE(7963), 1,
      aux_sym_annotation_repeat1,
    STATE(8968), 1,
      sym_arguments,
    STATE(7978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396872] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11491), 1,
      anon_sym_with,
    STATE(8803), 1,
      aux_sym_compound_type_repeat1,
    STATE(10935), 1,
      sym_arguments,
    STATE(11057), 1,
      sym_template_body,
    STATE(11180), 1,
      sym__refinement,
    STATE(7979), 2,
      sym_comment,
      sym_block_comment,
    STATE(11096), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7750), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396923] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(11267), 1,
      anon_sym_COLON,
    ACTIONS(11269), 1,
      anon_sym_LBRACE,
    ACTIONS(11271), 1,
      anon_sym_with,
    STATE(7508), 1,
      aux_sym_compound_type_repeat1,
    STATE(11341), 1,
      sym__refinement,
    STATE(11343), 1,
      sym_template_body,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7882), 2,
      anon_sym_STAR,
      anon_sym_EQ,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7980), 2,
      sym_comment,
      sym_block_comment,
    STATE(11189), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [396982] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [397060] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4342), 1,
      sym__alpha_identifier,
    ACTIONS(4344), 1,
      anon_sym__,
    ACTIONS(4354), 1,
      sym__backquoted_id,
    ACTIONS(6938), 1,
      sym_operator_identifier,
    ACTIONS(10035), 1,
      anon_sym_LPAREN,
    STATE(7255), 1,
      sym__simple_type,
    STATE(7539), 1,
      sym__soft_identifier,
    STATE(7904), 1,
      sym_identifier,
    STATE(10219), 1,
      sym_annotated_type,
    STATE(10330), 1,
      sym__annotated_type,
    STATE(17364), 1,
      sym_stable_identifier,
    STATE(7983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4350), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8693), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [397121] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397160] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9273), 1,
      anon_sym_LPAREN,
    ACTIONS(10578), 1,
      anon_sym_DOT,
    ACTIONS(10590), 1,
      sym_operator_identifier,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_match,
      anon_sym_then,
    STATE(7985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    STATE(9953), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [397223] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397262] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397301] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397340] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [397418] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4774), 1,
      sym__alpha_identifier,
    ACTIONS(4780), 1,
      anon_sym__,
    ACTIONS(4792), 1,
      sym__backquoted_id,
    ACTIONS(6398), 1,
      sym_operator_identifier,
    ACTIONS(10328), 1,
      anon_sym_LPAREN,
    STATE(5471), 1,
      sym__simple_type,
    STATE(5800), 1,
      sym__soft_identifier,
    STATE(5818), 1,
      sym_identifier,
    STATE(8839), 1,
      sym_annotated_type,
    STATE(8860), 1,
      sym__annotated_type,
    STATE(17804), 1,
      sym_stable_identifier,
    STATE(7991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4786), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6677), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [397479] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397518] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(7993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397559] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397598] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11493), 1,
      anon_sym_LBRACK,
    ACTIONS(11495), 1,
      anon_sym_AT,
    ACTIONS(11497), 1,
      anon_sym_LPAREN,
    ACTIONS(11499), 1,
      anon_sym_POUND,
    STATE(9856), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10267), 1,
      sym_type_arguments,
    STATE(10419), 1,
      sym_annotation,
    STATE(10935), 1,
      sym_arguments,
    STATE(7995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 3,
      anon_sym_LBRACE,
      anon_sym_DOT,
      sym__backquoted_id,
    ACTIONS(7692), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397653] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397692] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [397731] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7956), 1,
      sym__alpha_identifier,
    ACTIONS(7962), 1,
      anon_sym__,
    ACTIONS(7966), 1,
      anon_sym_LPAREN,
    ACTIONS(7968), 1,
      sym__backquoted_id,
    ACTIONS(7970), 1,
      sym_operator_identifier,
    STATE(12855), 1,
      sym__simple_type,
    STATE(13475), 1,
      sym_identifier,
    STATE(13521), 1,
      sym__soft_identifier,
    STATE(14451), 1,
      sym_annotated_type,
    STATE(14534), 1,
      sym__annotated_type,
    STATE(17306), 1,
      sym_stable_identifier,
    STATE(7998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7964), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13929), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [397792] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [397831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [397870] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11021), 1,
      anon_sym_EQ_GT,
    STATE(8001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [397911] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [397950] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4422), 1,
      sym__alpha_identifier,
    ACTIONS(4428), 1,
      anon_sym__,
    ACTIONS(4440), 1,
      sym__backquoted_id,
    ACTIONS(6200), 1,
      sym_operator_identifier,
    ACTIONS(10179), 1,
      anon_sym_LPAREN,
    STATE(5648), 1,
      sym__simple_type,
    STATE(6343), 1,
      sym_identifier,
    STATE(6399), 1,
      sym__soft_identifier,
    STATE(8996), 1,
      sym__annotated_type,
    STATE(9039), 1,
      sym_annotated_type,
    STATE(17810), 1,
      sym_stable_identifier,
    STATE(8003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4434), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7419), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [398011] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9360), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398052] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398091] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398130] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [398208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398247] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(8010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398288] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_EQ,
    ACTIONS(11312), 1,
      anon_sym_COLON,
    ACTIONS(11316), 1,
      anon_sym_with,
    ACTIONS(11501), 1,
      anon_sym_LBRACE,
    STATE(7618), 1,
      aux_sym_compound_type_repeat1,
    STATE(10918), 1,
      sym__refinement,
    STATE(10919), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8011), 2,
      sym_comment,
      sym_block_comment,
    STATE(10924), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398347] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [398386] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [398425] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1428), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8833), 1,
      anon_sym_LPAREN,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9483), 1,
      anon_sym_DOT,
    ACTIONS(10553), 1,
      sym__alpha_identifier,
    ACTIONS(10559), 1,
      sym__backquoted_id,
    ACTIONS(10561), 1,
      sym_operator_identifier,
    ACTIONS(11504), 1,
      anon_sym_EQ,
    STATE(596), 1,
      sym_identifier,
    STATE(4182), 1,
      sym__soft_identifier,
    STATE(8014), 2,
      sym_comment,
      sym_block_comment,
    STATE(8440), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 4,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10555), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [398488] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [398527] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11506), 1,
      anon_sym_AT,
    STATE(9090), 1,
      sym_annotation,
    STATE(8016), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398570] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [398648] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4594), 1,
      sym__alpha_identifier,
    ACTIONS(4600), 1,
      anon_sym__,
    ACTIONS(4612), 1,
      sym__backquoted_id,
    ACTIONS(6252), 1,
      sym_operator_identifier,
    ACTIONS(10169), 1,
      anon_sym_LPAREN,
    STATE(5090), 1,
      sym__simple_type,
    STATE(5125), 1,
      sym_identifier,
    STATE(5264), 1,
      sym__soft_identifier,
    STATE(7560), 1,
      sym__annotated_type,
    STATE(7582), 1,
      sym_annotated_type,
    STATE(17492), 1,
      sym_stable_identifier,
    STATE(8019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5951), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [398709] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8179), 1,
      sym__alpha_identifier,
    ACTIONS(8181), 1,
      anon_sym__,
    ACTIONS(8185), 1,
      anon_sym_LPAREN,
    ACTIONS(8187), 1,
      sym__backquoted_id,
    ACTIONS(8189), 1,
      sym_operator_identifier,
    STATE(5025), 1,
      sym__simple_type,
    STATE(6155), 1,
      sym_identifier,
    STATE(6730), 1,
      sym__soft_identifier,
    STATE(7525), 1,
      sym_annotated_type,
    STATE(7532), 1,
      sym__annotated_type,
    STATE(17113), 1,
      sym_stable_identifier,
    STATE(8020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8183), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6531), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [398770] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398848] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398926] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11312), 1,
      anon_sym_COLON,
    ACTIONS(11316), 1,
      anon_sym_with,
    STATE(7618), 1,
      aux_sym_compound_type_repeat1,
    STATE(10918), 1,
      sym__refinement,
    STATE(10919), 1,
      sym_template_body,
    STATE(8025), 2,
      sym_comment,
      sym_block_comment,
    STATE(10924), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [398977] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399016] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(15928), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(8027), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [399083] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11509), 1,
      anon_sym_LPAREN,
    STATE(9307), 1,
      sym_arguments,
    STATE(8028), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399126] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399165] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399204] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(10859), 1,
      anon_sym_LPAREN,
    ACTIONS(11273), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8031), 2,
      sym_comment,
      sym_block_comment,
    STATE(10626), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8193), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8191), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399255] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [399294] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399333] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399372] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8431), 1,
      sym__end_marker,
    STATE(8035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399413] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9349), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [399454] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1572), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8869), 1,
      anon_sym_LPAREN,
    ACTIONS(9525), 1,
      anon_sym_DOT,
    ACTIONS(10475), 1,
      sym__alpha_identifier,
    ACTIONS(10481), 1,
      sym__backquoted_id,
    ACTIONS(10483), 1,
      sym_operator_identifier,
    ACTIONS(11512), 1,
      anon_sym_EQ,
    STATE(602), 1,
      sym_identifier,
    STATE(4191), 1,
      sym__soft_identifier,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(8037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
    STATE(8709), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(10477), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [399517] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4712), 1,
      sym__alpha_identifier,
    ACTIONS(4718), 1,
      anon_sym__,
    ACTIONS(4730), 1,
      sym__backquoted_id,
    ACTIONS(6960), 1,
      sym_operator_identifier,
    ACTIONS(9927), 1,
      anon_sym_LPAREN,
    STATE(6100), 1,
      sym__simple_type,
    STATE(6328), 1,
      sym__soft_identifier,
    STATE(6619), 1,
      sym_identifier,
    STATE(9193), 1,
      sym__annotated_type,
    STATE(9270), 1,
      sym_annotated_type,
    STATE(17134), 1,
      sym_stable_identifier,
    STATE(8038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4724), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7010), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [399578] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8732), 1,
      sym_arguments,
    STATE(8039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [399619] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(9759), 1,
      anon_sym_LPAREN,
    STATE(7906), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(10694), 1,
      sym_annotated_type,
    STATE(10855), 1,
      sym__annotated_type,
    STATE(17416), 1,
      sym_stable_identifier,
    STATE(8040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [399680] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(8041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399721] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4692), 1,
      sym__alpha_identifier,
    ACTIONS(4694), 1,
      anon_sym__,
    ACTIONS(4704), 1,
      sym__backquoted_id,
    ACTIONS(6358), 1,
      sym_operator_identifier,
    ACTIONS(10185), 1,
      anon_sym_LPAREN,
    STATE(4470), 1,
      sym__simple_type,
    STATE(4547), 1,
      sym__soft_identifier,
    STATE(4621), 1,
      sym_identifier,
    STATE(5889), 1,
      sym__annotated_type,
    STATE(5917), 1,
      sym_annotated_type,
    STATE(17816), 1,
      sym_stable_identifier,
    STATE(8042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4739), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [399782] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [399821] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 4,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399860] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399899] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9347), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399940] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [399979] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400057] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6202), 1,
      sym__alpha_identifier,
    ACTIONS(6208), 1,
      anon_sym__,
    ACTIONS(6216), 1,
      sym__backquoted_id,
    ACTIONS(6218), 1,
      sym_operator_identifier,
    ACTIONS(10088), 1,
      anon_sym_LPAREN,
    STATE(8726), 1,
      sym__simple_type,
    STATE(9360), 1,
      sym_identifier,
    STATE(9455), 1,
      sym__soft_identifier,
    STATE(11054), 1,
      sym__annotated_type,
    STATE(11142), 1,
      sym_annotated_type,
    STATE(17822), 1,
      sym_stable_identifier,
    STATE(8050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6212), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9589), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [400118] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(11063), 1,
      anon_sym_LBRACE,
    ACTIONS(11065), 1,
      anon_sym_with,
    ACTIONS(11514), 1,
      anon_sym_COLON,
    STATE(7085), 1,
      aux_sym_compound_type_repeat1,
    STATE(10802), 1,
      sym__refinement,
    STATE(10806), 1,
      sym_template_body,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7882), 2,
      anon_sym_STAR,
      anon_sym_PIPE,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8051), 2,
      sym_comment,
      sym_block_comment,
    STATE(10692), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400216] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400255] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11157), 1,
      anon_sym_DOT,
    ACTIONS(11517), 1,
      anon_sym_EQ_GT,
    STATE(8054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400298] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400337] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10173), 1,
      anon_sym_LPAREN,
    STATE(8028), 1,
      aux_sym_annotation_repeat1,
    STATE(9307), 1,
      sym_arguments,
    STATE(8056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400382] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400460] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(15244), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(8059), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [400527] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [400566] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9319), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [400607] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400646] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8018), 1,
      sym__alpha_identifier,
    ACTIONS(8020), 1,
      anon_sym__,
    ACTIONS(8024), 1,
      anon_sym_LPAREN,
    ACTIONS(8026), 1,
      sym__backquoted_id,
    ACTIONS(8028), 1,
      sym_operator_identifier,
    STATE(5345), 1,
      sym__simple_type,
    STATE(7330), 1,
      sym__soft_identifier,
    STATE(7418), 1,
      sym_identifier,
    STATE(8293), 1,
      sym_annotated_type,
    STATE(8333), 1,
      sym__annotated_type,
    STATE(17155), 1,
      sym_stable_identifier,
    STATE(8063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6915), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [400707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [400746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [400785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [400824] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7988), 1,
      sym__alpha_identifier,
    ACTIONS(7990), 1,
      anon_sym__,
    ACTIONS(7994), 1,
      anon_sym_LPAREN,
    ACTIONS(7996), 1,
      sym__backquoted_id,
    ACTIONS(7998), 1,
      sym_operator_identifier,
    STATE(5490), 1,
      sym__simple_type,
    STATE(7258), 1,
      sym__soft_identifier,
    STATE(7416), 1,
      sym_identifier,
    STATE(8300), 1,
      sym_annotated_type,
    STATE(8403), 1,
      sym__annotated_type,
    STATE(17479), 1,
      sym_stable_identifier,
    STATE(8067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7992), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [400885] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [400924] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [400963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401002] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401041] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9574), 1,
      sym__interpolated_multiline_string_start,
    STATE(9538), 1,
      sym_interpolated_string,
    STATE(15920), 1,
      sym__interpolated_string_start,
    ACTIONS(11519), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [401090] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11521), 1,
      anon_sym_AT,
    STATE(9387), 1,
      sym_annotation,
    STATE(8073), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401172] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4886), 1,
      sym__alpha_identifier,
    ACTIONS(4892), 1,
      anon_sym__,
    ACTIONS(4904), 1,
      sym__backquoted_id,
    ACTIONS(6660), 1,
      sym_operator_identifier,
    ACTIONS(10058), 1,
      anon_sym_LPAREN,
    STATE(4668), 1,
      sym__simple_type,
    STATE(5003), 1,
      sym_identifier,
    STATE(5087), 1,
      sym__soft_identifier,
    STATE(7155), 1,
      sym_annotated_type,
    STATE(7163), 1,
      sym__annotated_type,
    STATE(17828), 1,
      sym_stable_identifier,
    STATE(8075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5448), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [401233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [401272] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 18,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [401311] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [401350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [401389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401428] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401467] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9301), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401508] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401547] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [401586] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [401625] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401664] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8159), 1,
      sym__alpha_identifier,
    ACTIONS(8161), 1,
      anon_sym__,
    ACTIONS(8165), 1,
      anon_sym_LPAREN,
    ACTIONS(8167), 1,
      sym__backquoted_id,
    ACTIONS(8169), 1,
      sym_operator_identifier,
    STATE(5597), 1,
      sym__simple_type,
    STATE(7625), 1,
      sym_identifier,
    STATE(8275), 1,
      sym__soft_identifier,
    STATE(9029), 1,
      sym__annotated_type,
    STATE(9175), 1,
      sym_annotated_type,
    STATE(17481), 1,
      sym_stable_identifier,
    STATE(8087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8163), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7680), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [401725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401764] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401803] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401842] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8437), 1,
      sym__alpha_identifier,
    ACTIONS(8439), 1,
      anon_sym__,
    ACTIONS(8443), 1,
      anon_sym_LPAREN,
    ACTIONS(8445), 1,
      sym__backquoted_id,
    ACTIONS(8447), 1,
      sym_operator_identifier,
    STATE(5053), 1,
      sym__simple_type,
    STATE(6388), 1,
      sym_identifier,
    STATE(6404), 1,
      sym__soft_identifier,
    STATE(7822), 1,
      sym__annotated_type,
    STATE(7834), 1,
      sym_annotated_type,
    STATE(17834), 1,
      sym_stable_identifier,
    STATE(8091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8441), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6567), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [401903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401942] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [401981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402059] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402098] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402137] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402176] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [402254] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7916), 1,
      sym__alpha_identifier,
    ACTIONS(7922), 1,
      anon_sym__,
    ACTIONS(7926), 1,
      anon_sym_LPAREN,
    ACTIONS(7928), 1,
      sym__backquoted_id,
    ACTIONS(7930), 1,
      sym_operator_identifier,
    STATE(11383), 1,
      sym__simple_type,
    STATE(11727), 1,
      sym__soft_identifier,
    STATE(11847), 1,
      sym_identifier,
    STATE(13571), 1,
      sym__annotated_type,
    STATE(13592), 1,
      sym_annotated_type,
    STATE(17453), 1,
      sym_stable_identifier,
    STATE(8101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7924), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12322), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [402315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402354] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402393] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16637), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(8104), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [402460] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402499] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402538] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11421), 1,
      anon_sym_COMMA,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11524), 1,
      anon_sym_COLON,
    ACTIONS(11526), 1,
      anon_sym_EQ,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(15846), 1,
      aux_sym_val_declaration_repeat1,
    STATE(16094), 1,
      sym__interpolated_string_start,
    STATE(8107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [402611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [402650] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10592), 1,
      anon_sym_LPAREN,
    STATE(8126), 1,
      aux_sym_annotation_repeat1,
    STATE(9452), 1,
      sym_arguments,
    STATE(8109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402695] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [402734] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6542), 1,
      sym__alpha_identifier,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    ACTIONS(10361), 1,
      anon_sym_LPAREN,
    STATE(5249), 1,
      sym__simple_type,
    STATE(5780), 1,
      sym__soft_identifier,
    STATE(5982), 1,
      sym_identifier,
    STATE(8686), 1,
      sym__annotated_type,
    STATE(8698), 1,
      sym_annotated_type,
    STATE(17900), 1,
      sym_stable_identifier,
    STATE(8111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6174), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [402795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 4,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402834] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402873] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11528), 1,
      anon_sym_AT,
    STATE(8940), 1,
      sym_annotation,
    STATE(8114), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [402916] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6698), 1,
      sym__alpha_identifier,
    ACTIONS(6704), 1,
      anon_sym__,
    ACTIONS(6712), 1,
      sym__backquoted_id,
    ACTIONS(6714), 1,
      sym_operator_identifier,
    ACTIONS(9834), 1,
      anon_sym_LPAREN,
    STATE(4994), 1,
      sym__simple_type,
    STATE(5215), 1,
      sym__soft_identifier,
    STATE(5482), 1,
      sym_identifier,
    STATE(7795), 1,
      sym__annotated_type,
    STATE(7805), 1,
      sym_annotated_type,
    STATE(17840), 1,
      sym_stable_identifier,
    STATE(8115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6708), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5743), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [402977] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4278), 1,
      sym__alpha_identifier,
    ACTIONS(4284), 1,
      anon_sym__,
    ACTIONS(4296), 1,
      sym__backquoted_id,
    ACTIONS(6994), 1,
      sym_operator_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    STATE(6764), 1,
      sym__simple_type,
    STATE(6872), 1,
      sym_identifier,
    STATE(7385), 1,
      sym__soft_identifier,
    STATE(9702), 1,
      sym__annotated_type,
    STATE(9756), 1,
      sym_annotated_type,
    STATE(17176), 1,
      sym_stable_identifier,
    STATE(8116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4290), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8228), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [403038] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [403077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [403155] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11421), 1,
      anon_sym_COMMA,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11531), 1,
      anon_sym_COLON,
    ACTIONS(11533), 1,
      anon_sym_EQ,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(15849), 1,
      aux_sym_val_declaration_repeat1,
    STATE(16094), 1,
      sym__interpolated_string_start,
    STATE(8120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [403228] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(10859), 1,
      anon_sym_LPAREN,
    ACTIONS(11273), 1,
      anon_sym_DOT,
    ACTIONS(11535), 1,
      sym__alpha_identifier,
    ACTIONS(11539), 1,
      anon_sym_EQ,
    ACTIONS(11541), 1,
      sym__backquoted_id,
    ACTIONS(11543), 1,
      sym_operator_identifier,
    STATE(645), 1,
      sym_identifier,
    STATE(4209), 1,
      sym__soft_identifier,
    STATE(8121), 2,
      sym_comment,
      sym_block_comment,
    STATE(10626), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11537), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [403291] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 24,
      anon_sym_enum,
      anon_sym_case,
      anon_sym_object,
      anon_sym_given,
      anon_sym_class,
      anon_sym_trait,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_type,
      anon_sym_def,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [403328] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403367] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11545), 1,
      anon_sym_with,
    STATE(8124), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [403408] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [403447] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11548), 1,
      anon_sym_LPAREN,
    STATE(9452), 1,
      sym_arguments,
    STATE(8126), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403490] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [403529] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6566), 1,
      anon_sym__,
    ACTIONS(6574), 1,
      sym__backquoted_id,
    ACTIONS(6576), 1,
      sym_operator_identifier,
    ACTIONS(10086), 1,
      anon_sym_LPAREN,
    STATE(5238), 1,
      sym__simple_type,
    STATE(5717), 1,
      sym_identifier,
    STATE(6060), 1,
      sym__soft_identifier,
    STATE(8456), 1,
      sym__annotated_type,
    STATE(8512), 1,
      sym_annotated_type,
    STATE(17417), 1,
      sym_stable_identifier,
    STATE(8128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6570), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6110), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [403590] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8030), 1,
      sym__alpha_identifier,
    ACTIONS(8032), 1,
      anon_sym__,
    ACTIONS(8036), 1,
      anon_sym_LPAREN,
    ACTIONS(8038), 1,
      sym__backquoted_id,
    ACTIONS(8040), 1,
      sym_operator_identifier,
    STATE(6282), 1,
      sym__simple_type,
    STATE(8285), 1,
      sym_identifier,
    STATE(8625), 1,
      sym__soft_identifier,
    STATE(9613), 1,
      sym_annotated_type,
    STATE(9640), 1,
      sym__annotated_type,
    STATE(17197), 1,
      sym_stable_identifier,
    STATE(8129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8034), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8375), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [403651] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [403690] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16005), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(8131), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [403757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [403796] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    ACTIONS(11387), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11551), 1,
      anon_sym_EQ_GT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11852), 1,
      sym_interpolated_string,
    STATE(16134), 1,
      sym__interpolated_string_start,
    STATE(17844), 1,
      sym_guard,
    STATE(8133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [403869] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [403908] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [403947] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8539), 1,
      sym_arguments,
    STATE(8136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [403988] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(9744), 1,
      anon_sym_LPAREN,
    STATE(5266), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(8718), 1,
      sym__annotated_type,
    STATE(8754), 1,
      sym_annotated_type,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(8137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [404049] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6996), 1,
      sym__alpha_identifier,
    ACTIONS(6998), 1,
      anon_sym__,
    ACTIONS(7006), 1,
      sym__backquoted_id,
    ACTIONS(7008), 1,
      sym_operator_identifier,
    ACTIONS(9769), 1,
      anon_sym_LPAREN,
    STATE(6559), 1,
      sym__simple_type,
    STATE(7238), 1,
      sym_identifier,
    STATE(7458), 1,
      sym__soft_identifier,
    STATE(9877), 1,
      sym_annotated_type,
    STATE(9973), 1,
      sym__annotated_type,
    STATE(17218), 1,
      sym_stable_identifier,
    STATE(8138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7002), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8023), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [404110] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [404149] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [404188] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404227] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6772), 1,
      sym__alpha_identifier,
    ACTIONS(6778), 1,
      anon_sym__,
    ACTIONS(6786), 1,
      sym__backquoted_id,
    ACTIONS(6788), 1,
      sym_operator_identifier,
    ACTIONS(10052), 1,
      anon_sym_LPAREN,
    STATE(5904), 1,
      sym__simple_type,
    STATE(6418), 1,
      sym__soft_identifier,
    STATE(6643), 1,
      sym_identifier,
    STATE(9119), 1,
      sym_annotated_type,
    STATE(9140), 1,
      sym__annotated_type,
    STATE(17852), 1,
      sym_stable_identifier,
    STATE(8142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6782), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7485), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [404288] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [404333] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [404372] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4246), 1,
      sym__alpha_identifier,
    ACTIONS(4252), 1,
      anon_sym__,
    ACTIONS(4264), 1,
      sym__backquoted_id,
    ACTIONS(6744), 1,
      sym_operator_identifier,
    ACTIONS(10411), 1,
      anon_sym_LPAREN,
    STATE(5071), 1,
      sym__simple_type,
    STATE(5208), 1,
      sym__soft_identifier,
    STATE(5307), 1,
      sym_identifier,
    STATE(7691), 1,
      sym__annotated_type,
    STATE(7704), 1,
      sym_annotated_type,
    STATE(17894), 1,
      sym_stable_identifier,
    STATE(8145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4258), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5976), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [404433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [404472] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11553), 1,
      anon_sym_DOT,
    STATE(8147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404513] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8423), 1,
      sym__alpha_identifier,
    ACTIONS(8425), 1,
      anon_sym__,
    ACTIONS(8429), 1,
      anon_sym_LPAREN,
    ACTIONS(8431), 1,
      sym__backquoted_id,
    ACTIONS(8433), 1,
      sym_operator_identifier,
    STATE(5447), 1,
      sym__simple_type,
    STATE(7063), 1,
      sym_identifier,
    STATE(7297), 1,
      sym__soft_identifier,
    STATE(8408), 1,
      sym__annotated_type,
    STATE(8659), 1,
      sym_annotated_type,
    STATE(17398), 1,
      sym_stable_identifier,
    STATE(8148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8427), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [404574] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [404613] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404654] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404693] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8125), 1,
      sym__alpha_identifier,
    ACTIONS(8131), 1,
      anon_sym__,
    ACTIONS(8135), 1,
      anon_sym_LPAREN,
    ACTIONS(8137), 1,
      sym__backquoted_id,
    ACTIONS(8139), 1,
      sym_operator_identifier,
    STATE(8771), 1,
      sym__simple_type,
    STATE(10205), 1,
      sym_identifier,
    STATE(10235), 1,
      sym__soft_identifier,
    STATE(10780), 1,
      sym_annotated_type,
    STATE(10848), 1,
      sym__annotated_type,
    STATE(17260), 1,
      sym_stable_identifier,
    STATE(8152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8133), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10246), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [404754] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11555), 1,
      anon_sym_LPAREN,
    STATE(9524), 1,
      sym_arguments,
    STATE(8153), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404797] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10879), 1,
      anon_sym_LPAREN,
    STATE(8153), 1,
      aux_sym_annotation_repeat1,
    STATE(9524), 1,
      sym_arguments,
    STATE(8154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404842] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6716), 1,
      sym__alpha_identifier,
    ACTIONS(6722), 1,
      anon_sym__,
    ACTIONS(6730), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(10039), 1,
      anon_sym_LPAREN,
    STATE(5945), 1,
      sym__simple_type,
    STATE(6329), 1,
      sym_identifier,
    STATE(6457), 1,
      sym__soft_identifier,
    STATE(9719), 1,
      sym_annotated_type,
    STATE(9802), 1,
      sym__annotated_type,
    STATE(17539), 1,
      sym_stable_identifier,
    STATE(8155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6726), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7381), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [404903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [404942] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10620), 1,
      anon_sym_RPAREN,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11305), 1,
      sym__interpolated_multiline_string_start,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11780), 1,
      sym_interpolated_string,
    STATE(15412), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(16279), 1,
      sym__interpolated_string_start,
    STATE(8157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [405015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [405054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [405093] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8143), 1,
      sym__alpha_identifier,
    ACTIONS(8149), 1,
      anon_sym__,
    ACTIONS(8153), 1,
      anon_sym_LPAREN,
    ACTIONS(8155), 1,
      sym__backquoted_id,
    ACTIONS(8157), 1,
      sym_operator_identifier,
    STATE(4353), 1,
      sym__simple_type,
    STATE(4706), 1,
      sym_identifier,
    STATE(4734), 1,
      sym__soft_identifier,
    STATE(5123), 1,
      sym__annotated_type,
    STATE(5139), 1,
      sym_annotated_type,
    STATE(17281), 1,
      sym_stable_identifier,
    STATE(8160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8151), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4688), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [405154] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11421), 1,
      anon_sym_COMMA,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11558), 1,
      anon_sym_COLON,
    ACTIONS(11560), 1,
      anon_sym_EQ,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(15849), 1,
      aux_sym_val_declaration_repeat1,
    STATE(16094), 1,
      sym__interpolated_string_start,
    STATE(8161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [405227] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [405266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [405305] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [405344] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405383] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11421), 1,
      anon_sym_COMMA,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11562), 1,
      anon_sym_COLON,
    ACTIONS(11564), 1,
      anon_sym_EQ,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(15846), 1,
      aux_sym_val_declaration_repeat1,
    STATE(16094), 1,
      sym__interpolated_string_start,
    STATE(8166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [405456] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [405495] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8875), 1,
      sym_operator_identifier,
    STATE(1756), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8309), 7,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [405550] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [405589] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11566), 1,
      anon_sym_with,
    STATE(8170), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [405630] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [405669] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8450), 1,
      sym__end_marker,
    STATE(8172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405710] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11569), 1,
      anon_sym_DOT,
    STATE(8173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405751] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8294), 1,
      sym__end_marker,
    STATE(8174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [405792] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [405831] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11305), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11571), 1,
      anon_sym_COMMA,
    ACTIONS(11573), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11780), 1,
      sym_interpolated_string,
    STATE(15987), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(16279), 1,
      sym__interpolated_string_start,
    STATE(8176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [405904] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [405943] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [405982] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(8179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406023] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [406062] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406101] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [406140] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406179] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406218] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 18,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [406257] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16064), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(8186), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [406324] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [406363] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11305), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11575), 1,
      anon_sym_COMMA,
    ACTIONS(11577), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11780), 1,
      sym_interpolated_string,
    STATE(16035), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(16279), 1,
      sym__interpolated_string_start,
    STATE(8188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [406436] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406514] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__alpha_identifier,
    ACTIONS(4468), 1,
      anon_sym__,
    ACTIONS(4480), 1,
      sym__backquoted_id,
    ACTIONS(6748), 1,
      sym_operator_identifier,
    ACTIONS(10005), 1,
      anon_sym_LPAREN,
    STATE(5016), 1,
      sym__simple_type,
    STATE(5231), 1,
      sym_identifier,
    STATE(5328), 1,
      sym__soft_identifier,
    STATE(7916), 1,
      sym__annotated_type,
    STATE(7967), 1,
      sym_annotated_type,
    STATE(17379), 1,
      sym_stable_identifier,
    STATE(8191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6029), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [406575] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [406614] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9393), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [406694] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11305), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11579), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11780), 1,
      sym_interpolated_string,
    STATE(16029), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(16279), 1,
      sym__interpolated_string_start,
    STATE(8195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [406767] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9277), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406808] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [406847] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10923), 1,
      anon_sym_type,
    STATE(8198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [406888] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [406966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [407005] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407044] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1428), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8833), 1,
      anon_sym_LPAREN,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9483), 1,
      anon_sym_DOT,
    ACTIONS(10553), 1,
      sym__alpha_identifier,
    ACTIONS(10559), 1,
      sym__backquoted_id,
    ACTIONS(10561), 1,
      sym_operator_identifier,
    ACTIONS(11581), 1,
      anon_sym_EQ,
    STATE(596), 1,
      sym_identifier,
    STATE(4182), 1,
      sym__soft_identifier,
    STATE(8203), 2,
      sym_comment,
      sym_block_comment,
    STATE(8440), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9022), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10555), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [407107] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407146] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407185] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [407224] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8902), 1,
      sym_operator_identifier,
    STATE(1771), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8309), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [407279] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [407318] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8084), 1,
      sym__alpha_identifier,
    ACTIONS(8086), 1,
      anon_sym__,
    ACTIONS(8090), 1,
      anon_sym_LPAREN,
    ACTIONS(8092), 1,
      sym__backquoted_id,
    ACTIONS(8094), 1,
      sym_operator_identifier,
    STATE(5741), 1,
      sym__simple_type,
    STATE(7587), 1,
      sym_identifier,
    STATE(7664), 1,
      sym__soft_identifier,
    STATE(9482), 1,
      sym_annotated_type,
    STATE(9545), 1,
      sym__annotated_type,
    STATE(17607), 1,
      sym_stable_identifier,
    STATE(8209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8088), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [407379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407418] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407457] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11149), 1,
      anon_sym_LBRACK,
    ACTIONS(11153), 1,
      anon_sym_POUND,
    ACTIONS(11583), 1,
      anon_sym_AT,
    STATE(9497), 1,
      sym_type_arguments,
    STATE(9852), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10533), 1,
      sym_annotation,
    STATE(8212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407508] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9356), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407549] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(107), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8658), 1,
      anon_sym_LPAREN,
    ACTIONS(8998), 1,
      anon_sym_DOT,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(9622), 1,
      sym_operator_identifier,
    ACTIONS(11585), 1,
      anon_sym_EQ,
    STATE(608), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    STATE(8214), 2,
      sym_comment,
      sym_block_comment,
    STATE(8261), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [407612] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4512), 1,
      sym__alpha_identifier,
    ACTIONS(4514), 1,
      anon_sym__,
    ACTIONS(4524), 1,
      sym__backquoted_id,
    ACTIONS(6964), 1,
      sym_operator_identifier,
    ACTIONS(9886), 1,
      anon_sym_LPAREN,
    STATE(4605), 1,
      sym__simple_type,
    STATE(4670), 1,
      sym_identifier,
    STATE(4696), 1,
      sym__soft_identifier,
    STATE(6758), 1,
      sym_annotated_type,
    STATE(6769), 1,
      sym__annotated_type,
    STATE(17301), 1,
      sym_stable_identifier,
    STATE(8215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4520), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5076), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [407673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407712] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407751] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym__,
    ACTIONS(6610), 1,
      sym__backquoted_id,
    ACTIONS(6612), 1,
      sym_operator_identifier,
    ACTIONS(10145), 1,
      anon_sym_LPAREN,
    STATE(6433), 1,
      sym__simple_type,
    STATE(7134), 1,
      sym__soft_identifier,
    STATE(7495), 1,
      sym_identifier,
    STATE(9888), 1,
      sym__annotated_type,
    STATE(9897), 1,
      sym_annotated_type,
    STATE(17864), 1,
      sym_stable_identifier,
    STATE(8218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7557), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [407812] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11587), 1,
      anon_sym_LPAREN,
    STATE(8982), 1,
      sym_arguments,
    STATE(8219), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [407894] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 7,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [407939] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1572), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8869), 1,
      anon_sym_LPAREN,
    ACTIONS(9525), 1,
      anon_sym_DOT,
    ACTIONS(10475), 1,
      sym__alpha_identifier,
    ACTIONS(10481), 1,
      sym__backquoted_id,
    ACTIONS(10483), 1,
      sym_operator_identifier,
    ACTIONS(11590), 1,
      anon_sym_EQ,
    STATE(602), 1,
      sym_identifier,
    STATE(4191), 1,
      sym__soft_identifier,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(8222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
    STATE(8709), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(10477), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [408002] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10750), 1,
      anon_sym_LPAREN,
    STATE(8219), 1,
      aux_sym_annotation_repeat1,
    STATE(8982), 1,
      sym_arguments,
    STATE(8223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408086] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11592), 1,
      anon_sym_DOT,
    STATE(8225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408127] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408205] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408244] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [408322] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10409), 1,
      anon_sym_AT,
    STATE(8073), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9387), 1,
      sym_annotation,
    STATE(8231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408367] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11421), 1,
      anon_sym_COMMA,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11594), 1,
      anon_sym_COLON,
    ACTIONS(11596), 1,
      anon_sym_EQ,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(15896), 1,
      aux_sym_val_declaration_repeat1,
    STATE(16094), 1,
      sym__interpolated_string_start,
    STATE(8232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [408440] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408479] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11421), 1,
      anon_sym_COMMA,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(11600), 1,
      anon_sym_EQ,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(15900), 1,
      aux_sym_val_declaration_repeat1,
    STATE(16094), 1,
      sym__interpolated_string_start,
    STATE(8234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [408552] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [408630] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11602), 1,
      anon_sym_AT,
    STATE(9030), 1,
      sym_annotation,
    STATE(8237), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408673] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11605), 1,
      anon_sym_LPAREN,
    STATE(9194), 1,
      sym_arguments,
    STATE(8238), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408716] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(8239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408757] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8056), 1,
      anon_sym__,
    ACTIONS(8060), 1,
      anon_sym_LPAREN,
    ACTIONS(8062), 1,
      sym__backquoted_id,
    ACTIONS(8064), 1,
      sym_operator_identifier,
    STATE(7116), 1,
      sym__simple_type,
    STATE(8995), 1,
      sym_identifier,
    STATE(9392), 1,
      sym__soft_identifier,
    STATE(10042), 1,
      sym_annotated_type,
    STATE(10107), 1,
      sym__annotated_type,
    STATE(17942), 1,
      sym_stable_identifier,
    STATE(8240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8058), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9053), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [408818] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9366), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408859] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9961), 1,
      anon_sym_LPAREN,
    STATE(8238), 1,
      aux_sym_annotation_repeat1,
    STATE(9194), 1,
      sym_arguments,
    STATE(8242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408904] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [408943] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8211), 1,
      sym__alpha_identifier,
    ACTIONS(8217), 1,
      anon_sym__,
    ACTIONS(8221), 1,
      anon_sym_LPAREN,
    ACTIONS(8223), 1,
      sym__backquoted_id,
    ACTIONS(8225), 1,
      sym_operator_identifier,
    STATE(4590), 1,
      sym__simple_type,
    STATE(5102), 1,
      sym_identifier,
    STATE(5375), 1,
      sym__soft_identifier,
    STATE(6714), 1,
      sym__annotated_type,
    STATE(6740), 1,
      sym_annotated_type,
    STATE(17321), 1,
      sym_stable_identifier,
    STATE(8244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8219), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5227), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [409004] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8333), 1,
      sym__alpha_identifier,
    ACTIONS(8335), 1,
      anon_sym__,
    ACTIONS(8339), 1,
      anon_sym_LPAREN,
    ACTIONS(8341), 1,
      sym__backquoted_id,
    ACTIONS(8343), 1,
      sym_operator_identifier,
    STATE(4561), 1,
      sym__simple_type,
    STATE(5160), 1,
      sym_identifier,
    STATE(5309), 1,
      sym__soft_identifier,
    STATE(6599), 1,
      sym__annotated_type,
    STATE(6631), 1,
      sym_annotated_type,
    STATE(17360), 1,
      sym_stable_identifier,
    STATE(8245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8337), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5259), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [409065] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409104] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [409143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [409182] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409221] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11608), 1,
      anon_sym_with,
    STATE(8250), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409262] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409301] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [409340] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [409379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409418] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [409457] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6378), 1,
      sym__alpha_identifier,
    ACTIONS(6384), 1,
      anon_sym__,
    ACTIONS(6392), 1,
      sym__backquoted_id,
    ACTIONS(6394), 1,
      sym_operator_identifier,
    ACTIONS(10353), 1,
      anon_sym_LPAREN,
    STATE(5085), 1,
      sym__simple_type,
    STATE(5211), 1,
      sym__soft_identifier,
    STATE(5401), 1,
      sym_identifier,
    STATE(7717), 1,
      sym__annotated_type,
    STATE(7726), 1,
      sym_annotated_type,
    STATE(17882), 1,
      sym_stable_identifier,
    STATE(8256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5762), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [409518] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11611), 1,
      anon_sym_with,
    STATE(8257), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409559] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [409676] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [409715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [409754] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6918), 1,
      sym__alpha_identifier,
    ACTIONS(6924), 1,
      anon_sym__,
    ACTIONS(6932), 1,
      sym__backquoted_id,
    ACTIONS(6934), 1,
      sym_operator_identifier,
    ACTIONS(9941), 1,
      anon_sym_LPAREN,
    STATE(4612), 1,
      sym__simple_type,
    STATE(4637), 1,
      sym_identifier,
    STATE(4714), 1,
      sym__soft_identifier,
    STATE(6652), 1,
      sym__annotated_type,
    STATE(6684), 1,
      sym_annotated_type,
    STATE(17341), 1,
      sym_stable_identifier,
    STATE(8263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6928), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5056), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [409815] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8316), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16095), 1,
      sym__variant_type_parameter,
    STATE(16670), 1,
      sym__type_parameter,
    STATE(8264), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16671), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [409882] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(8265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [409923] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [409962] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410001] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410079] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(9574), 1,
      sym__interpolated_multiline_string_start,
    STATE(9538), 1,
      sym_interpolated_string,
    STATE(15920), 1,
      sym__interpolated_string_start,
    ACTIONS(11614), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410128] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11616), 1,
      anon_sym_with,
    STATE(8271), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [410208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [410286] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410364] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410403] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6360), 1,
      sym__alpha_identifier,
    ACTIONS(6366), 1,
      anon_sym__,
    ACTIONS(6374), 1,
      sym__backquoted_id,
    ACTIONS(6376), 1,
      sym_operator_identifier,
    ACTIONS(10280), 1,
      anon_sym_LPAREN,
    STATE(4549), 1,
      sym__simple_type,
    STATE(4753), 1,
      sym_identifier,
    STATE(4788), 1,
      sym__soft_identifier,
    STATE(6355), 1,
      sym__annotated_type,
    STATE(6732), 1,
      sym_annotated_type,
    STATE(17876), 1,
      sym_stable_identifier,
    STATE(8278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4936), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [410464] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [410542] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410581] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410657] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410695] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11619), 1,
      anon_sym_DOT,
    STATE(8285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410773] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11621), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [410811] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9953), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410851] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [410927] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11625), 1,
      anon_sym_with,
    STATE(8291), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [410967] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411005] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [411081] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1978), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9134), 1,
      anon_sym_LPAREN,
    ACTIONS(9947), 1,
      anon_sym_DOT,
    ACTIONS(11159), 1,
      sym__alpha_identifier,
    ACTIONS(11165), 1,
      sym__backquoted_id,
    ACTIONS(11167), 1,
      sym_operator_identifier,
    ACTIONS(11628), 1,
      anon_sym_EQ,
    STATE(622), 1,
      sym_identifier,
    STATE(4205), 1,
      sym__soft_identifier,
    STATE(8295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_while,
      anon_sym_match,
      anon_sym_finally,
    STATE(9158), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(11161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [411143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [411181] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [411219] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9016), 1,
      sym__alpha_identifier,
    ACTIONS(9024), 1,
      anon_sym_EQ,
    ACTIONS(9026), 1,
      sym__backquoted_id,
    ACTIONS(9028), 1,
      sym_operator_identifier,
    STATE(579), 1,
      sym_identifier,
    STATE(3987), 1,
      sym__soft_identifier,
    STATE(8298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [411273] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411317] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411355] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411431] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411513] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [411589] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [411627] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411665] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411703] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [411741] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11630), 1,
      anon_sym_with,
    STATE(8311), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [411819] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [411857] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411895] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [411933] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4948), 1,
      anon_sym_LBRACK,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10941), 1,
      anon_sym_PLUS,
    ACTIONS(10943), 1,
      anon_sym_DASH,
    ACTIONS(10945), 1,
      anon_sym_AT,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(11391), 1,
      aux_sym_enum_definition_repeat1,
    STATE(11975), 1,
      sym_annotation,
    STATE(16654), 1,
      sym__type_parameter,
    STATE(8316), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(16655), 3,
      sym_covariant_type_parameter,
      sym_contravariant_type_parameter,
      sym_type_lambda,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [411997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412035] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [412073] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [412111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [412149] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    ACTIONS(10628), 1,
      sym__interpolated_multiline_string_start,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11265), 1,
      sym_interpolated_string,
    STATE(16003), 1,
      sym__interpolated_string_start,
    ACTIONS(11633), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(8321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [412217] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_EQ,
    ACTIONS(11635), 1,
      anon_sym_COLON,
    ACTIONS(11637), 1,
      anon_sym_LBRACE,
    ACTIONS(11639), 1,
      anon_sym_with,
    STATE(8887), 1,
      aux_sym_compound_type_repeat1,
    STATE(11254), 1,
      sym_template_body,
    STATE(11256), 1,
      sym__refinement,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8322), 2,
      sym_comment,
      sym_block_comment,
    STATE(11233), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412275] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [412351] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11641), 1,
      anon_sym_DOT,
    STATE(8325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412391] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11643), 1,
      anon_sym_with,
    STATE(8326), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [412469] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11646), 1,
      anon_sym_COLON,
    ACTIONS(11649), 1,
      anon_sym_LBRACE,
    STATE(10110), 1,
      sym_template_body,
    STATE(6266), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8900), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 11,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412515] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412553] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412781] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8902), 1,
      sym_operator_identifier,
    STATE(1771), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8309), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [412833] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [412909] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412947] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [412985] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413023] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413061] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413099] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5660), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(8344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [413141] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11652), 1,
      anon_sym_LPAREN,
    STATE(10002), 1,
      sym_arguments,
    STATE(8345), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413183] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413223] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413261] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413337] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [413375] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7778), 1,
      sym__backquoted_id,
    ACTIONS(11655), 1,
      anon_sym_LBRACE,
    ACTIONS(11657), 1,
      anon_sym_with,
    STATE(10505), 1,
      aux_sym_compound_type_repeat1,
    STATE(11194), 1,
      sym_template_body,
    STATE(11223), 1,
      sym__refinement,
    STATE(8351), 2,
      sym_comment,
      sym_block_comment,
    STATE(11358), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7776), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413425] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413463] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413501] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413539] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413615] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413653] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11659), 1,
      anon_sym_DOT,
    STATE(8358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413693] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8971), 1,
      sym_arguments,
    STATE(8359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413733] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413771] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11661), 1,
      anon_sym_with,
    STATE(8361), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [413849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [413963] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10183), 1,
      sym__interpolated_multiline_string_start,
    STATE(9974), 1,
      sym_interpolated_string,
    STATE(15927), 1,
      sym__interpolated_string_start,
    ACTIONS(11664), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414011] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7334), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [414125] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [414163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414201] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [414239] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10220), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [414277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [414315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414353] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11362), 1,
      anon_sym_EQ_GT,
    STATE(8376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414469] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(8379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414509] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414547] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414585] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11670), 1,
      anon_sym_with,
    STATE(8382), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414625] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414663] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414739] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414777] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414891] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11673), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [414929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [414967] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415005] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5842), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(8393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [415047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415085] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415161] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9792), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [415199] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9890), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [415237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [415275] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9894), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [415313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415351] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11677), 1,
      anon_sym_LPAREN,
    STATE(9783), 1,
      sym_arguments,
    STATE(8402), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [415469] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415513] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10857), 1,
      anon_sym_AT,
    STATE(8604), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9676), 1,
      sym_annotation,
    STATE(8406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [415633] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10307), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415749] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415787] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415939] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [415977] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11635), 1,
      anon_sym_COLON,
    ACTIONS(11637), 1,
      anon_sym_LBRACE,
    ACTIONS(11639), 1,
      anon_sym_with,
    STATE(8887), 1,
      aux_sym_compound_type_repeat1,
    STATE(11254), 1,
      sym_template_body,
    STATE(11256), 1,
      sym__refinement,
    STATE(8418), 2,
      sym_comment,
      sym_block_comment,
    STATE(11233), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416029] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416067] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9929), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416143] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11680), 1,
      anon_sym_with,
    STATE(8422), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416183] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9955), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416221] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416259] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11263), 1,
      anon_sym_LPAREN,
    STATE(8402), 1,
      aux_sym_annotation_repeat1,
    STATE(9783), 1,
      sym_arguments,
    STATE(8425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416341] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9969), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416455] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416531] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416607] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416645] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9536), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416721] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9977), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416759] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [416797] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416835] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9981), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416873] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416911] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9987), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416949] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9999), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [416987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417025] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417063] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417101] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417139] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10355), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417253] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11053), 1,
      anon_sym_AT,
    STATE(8564), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9617), 1,
      sym_annotation,
    STATE(8451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417297] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10887), 1,
      anon_sym_LPAREN,
    STATE(8345), 1,
      aux_sym_annotation_repeat1,
    STATE(10002), 1,
      sym_arguments,
    STATE(8452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417341] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417455] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [417531] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9411), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417607] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417645] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417685] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9415), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [417761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9419), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417799] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417875] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [417913] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417951] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [417989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [418027] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418065] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10637), 1,
      anon_sym_LPAREN,
    STATE(8554), 1,
      aux_sym_annotation_repeat1,
    STATE(9737), 1,
      sym_arguments,
    STATE(8472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8121), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10015), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418147] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418185] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418223] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418261] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10019), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418337] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418375] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418413] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10043), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [418453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11683), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [418491] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418529] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418605] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10194), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418645] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [418721] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418759] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418797] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11687), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [418835] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [418873] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7750), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [418911] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11441), 1,
      anon_sym_DOT,
    ACTIONS(11691), 1,
      anon_sym_EQ_GT,
    STATE(8494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418953] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [418991] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11693), 1,
      anon_sym_LPAREN,
    STATE(9603), 1,
      sym_arguments,
    STATE(8496), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419033] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11696), 1,
      anon_sym_with,
    STATE(8497), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419073] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [419117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11699), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [419155] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8875), 1,
      sym_operator_identifier,
    STATE(1756), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(8309), 7,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [419207] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419245] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10072), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419285] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11703), 1,
      anon_sym_DOT,
    STATE(8503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [419401] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [419439] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [419477] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [419515] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10522), 1,
      anon_sym_AT,
    STATE(8565), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9771), 1,
      sym_annotation,
    STATE(8509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419559] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419597] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [419635] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [419673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419749] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [419787] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419825] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [419903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [419941] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [419979] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11705), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [420055] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420093] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [420131] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [420169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420207] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [420245] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420321] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(8873), 1,
      sym_operator_identifier,
    STATE(1835), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8309), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [420373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420411] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420449] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [420487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420525] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [420563] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10226), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420601] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9503), 1,
      sym_arguments,
    STATE(8537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420717] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9383), 1,
      sym__end_marker,
    STATE(8540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9449), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420757] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11709), 1,
      anon_sym_AT,
    STATE(9648), 1,
      sym_annotation,
    STATE(8541), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420799] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [420875] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420913] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420951] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [420989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [421027] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [421065] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10242), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [421103] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [421179] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [421255] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11712), 1,
      anon_sym_LPAREN,
    STATE(9737), 1,
      sym_arguments,
    STATE(8554), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421297] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421335] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9140), 1,
      sym_operator_identifier,
    STATE(1813), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [421389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421427] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421465] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421503] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10363), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421543] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421581] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10807), 1,
      anon_sym_LPAREN,
    STATE(8496), 1,
      aux_sym_annotation_repeat1,
    STATE(9603), 1,
      sym_arguments,
    STATE(8562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421625] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421663] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11715), 1,
      anon_sym_AT,
    STATE(9617), 1,
      sym_annotation,
    STATE(8564), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421705] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11718), 1,
      anon_sym_AT,
    STATE(9771), 1,
      sym_annotation,
    STATE(8565), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421747] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10654), 1,
      anon_sym_AT,
    STATE(8871), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9926), 1,
      sym_annotation,
    STATE(8566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421791] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [421829] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(8568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421869] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [421907] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [421945] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 1,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(11063), 1,
      anon_sym_LBRACE,
    ACTIONS(11065), 1,
      anon_sym_with,
    ACTIONS(11514), 1,
      anon_sym_COLON,
    STATE(7085), 1,
      aux_sym_compound_type_repeat1,
    STATE(10802), 1,
      sym__refinement,
    STATE(10806), 1,
      sym_template_body,
    STATE(8571), 2,
      sym_comment,
      sym_block_comment,
    STATE(10692), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7882), 4,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422001] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422115] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [422153] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422191] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [422229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10253), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [422305] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422419] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [422457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11721), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [422495] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422533] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10762), 1,
      anon_sym_AT,
    STATE(8741), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9823), 1,
      sym_annotation,
    STATE(8586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422577] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11725), 1,
      anon_sym_LBRACE,
    ACTIONS(11727), 1,
      anon_sym_with,
    STATE(8761), 1,
      aux_sym_compound_type_repeat1,
    STATE(11240), 1,
      sym__refinement,
    STATE(11251), 1,
      sym_template_body,
    STATE(8587), 2,
      sym_comment,
      sym_block_comment,
    STATE(11204), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422627] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11729), 1,
      anon_sym_with,
    STATE(8588), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [422667] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9471), 1,
      sym__alpha_identifier,
    ACTIONS(9477), 1,
      sym__backquoted_id,
    ACTIONS(9479), 1,
      sym_operator_identifier,
    STATE(584), 1,
      sym_identifier,
    STATE(4160), 1,
      sym__soft_identifier,
    STATE(8589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9473), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(9022), 7,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [422719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [422833] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11155), 1,
      anon_sym_AT,
    STATE(8886), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10001), 1,
      sym_annotation,
    STATE(8593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [422915] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422953] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [422997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423035] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423073] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5837), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(8599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423115] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [423153] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423191] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(8602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423231] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423269] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11732), 1,
      anon_sym_AT,
    STATE(9676), 1,
      sym_annotation,
    STATE(8604), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423311] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423349] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5488), 1,
      sym__end_marker,
    STATE(8606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423389] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423429] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423467] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423543] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10286), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423581] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423657] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423695] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423733] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [423771] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9463), 1,
      sym__end_marker,
    STATE(8617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [423811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9656), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [423925] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9451), 1,
      sym_arguments,
    STATE(8621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [423965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424003] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10078), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9676), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424081] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424119] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424195] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424233] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9082), 1,
      sym_operator_identifier,
    STATE(1740), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8309), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [424287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424363] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(8632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424403] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11493), 1,
      anon_sym_LBRACK,
    ACTIONS(11499), 1,
      anon_sym_POUND,
    ACTIONS(11735), 1,
      anon_sym_LPAREN,
    STATE(9706), 1,
      aux_sym_annotation_repeat1,
    STATE(10267), 1,
      sym_type_arguments,
    STATE(10545), 1,
      sym_arguments,
    STATE(8633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 3,
      anon_sym_LBRACE,
      anon_sym_DOT,
      sym__backquoted_id,
    ACTIONS(7676), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424491] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424529] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424681] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424833] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10295), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [424909] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [424947] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [424985] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425023] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10299), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [425061] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425099] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11737), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [425137] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [425213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [425327] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5639), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(8657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10122), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [425369] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [425407] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [425445] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425483] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425521] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [425559] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425597] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [425635] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [425673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425711] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9939), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425751] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8114), 1,
      sym__backquoted_id,
    ACTIONS(11741), 1,
      anon_sym_LPAREN,
    STATE(9837), 1,
      sym_arguments,
    STATE(8668), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8112), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425793] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425869] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [425907] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    ACTIONS(10628), 1,
      sym__interpolated_multiline_string_start,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11265), 1,
      sym_interpolated_string,
    STATE(16003), 1,
      sym__interpolated_string_start,
    ACTIONS(11744), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(8672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [425975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [426013] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [426051] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [426089] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6103), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(8676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426131] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11305), 1,
      sym__interpolated_multiline_string_start,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11780), 1,
      sym_interpolated_string,
    STATE(16279), 1,
      sym__interpolated_string_start,
    STATE(8677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11176), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11174), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [426225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [426263] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [426301] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426339] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9808), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426455] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9871), 1,
      sym__alpha_identifier,
    ACTIONS(9877), 1,
      sym__backquoted_id,
    ACTIONS(9879), 1,
      sym_operator_identifier,
    STATE(583), 1,
      sym_identifier,
    STATE(4158), 1,
      sym__soft_identifier,
    STATE(8685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9022), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9873), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [426507] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426545] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9217), 1,
      sym__end_marker,
    STATE(8687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [426585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [426623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [426661] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [426699] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9271), 1,
      sym_arguments,
    STATE(8691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426739] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11746), 1,
      anon_sym_DOT,
    STATE(8692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426779] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [426855] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9820), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426895] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9263), 1,
      sym__end_marker,
    STATE(8696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [426935] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11196), 1,
      anon_sym_PIPE,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11305), 1,
      sym__interpolated_multiline_string_start,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11780), 1,
      sym_interpolated_string,
    STATE(16279), 1,
      sym__interpolated_string_start,
    ACTIONS(11194), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [427003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427041] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11748), 1,
      anon_sym_LPAREN,
    STATE(9853), 1,
      sym_arguments,
    STATE(8699), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8112), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427121] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9825), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427161] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    ACTIONS(10628), 1,
      sym__interpolated_multiline_string_start,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11265), 1,
      sym_interpolated_string,
    STATE(16003), 1,
      sym__interpolated_string_start,
    ACTIONS(10618), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(8702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [427229] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11305), 1,
      sym__interpolated_multiline_string_start,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11780), 1,
      sym_interpolated_string,
    STATE(16279), 1,
      sym__interpolated_string_start,
    STATE(8703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11145), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11143), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427285] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 7,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427329] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427411] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427449] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427525] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427563] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11517), 1,
      anon_sym_EQ_GT,
    STATE(8711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427603] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1978), 1,
      anon_sym_LBRACE,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9134), 1,
      anon_sym_LPAREN,
    ACTIONS(9947), 1,
      anon_sym_DOT,
    ACTIONS(11159), 1,
      sym__alpha_identifier,
    ACTIONS(11165), 1,
      sym__backquoted_id,
    ACTIONS(11167), 1,
      sym_operator_identifier,
    ACTIONS(11751), 1,
      anon_sym_EQ,
    STATE(622), 1,
      sym_identifier,
    STATE(4205), 1,
      sym__soft_identifier,
    STATE(8712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
    STATE(9158), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(11161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [427665] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11753), 1,
      anon_sym_with,
    STATE(8713), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7882), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [427743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427781] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9016), 1,
      sym__alpha_identifier,
    ACTIONS(9026), 1,
      sym__backquoted_id,
    ACTIONS(9028), 1,
      sym_operator_identifier,
    ACTIONS(9078), 1,
      anon_sym_EQ,
    STATE(579), 1,
      sym_identifier,
    STATE(3987), 1,
      sym__soft_identifier,
    STATE(8716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(9022), 7,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [427835] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427873] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [427911] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427949] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [427987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428025] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [428063] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [428101] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428139] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [428177] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11283), 1,
      anon_sym_LBRACK,
    ACTIONS(11287), 1,
      anon_sym_POUND,
    ACTIONS(11756), 1,
      anon_sym_AT,
    STATE(9592), 1,
      sym_type_arguments,
    STATE(10241), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10826), 1,
      sym_annotation,
    STATE(8726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428227] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428265] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [428303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428341] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [428455] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428531] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428569] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6050), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(8736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [428611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428725] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428763] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11758), 1,
      anon_sym_AT,
    STATE(9823), 1,
      sym_annotation,
    STATE(8741), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428805] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11761), 1,
      anon_sym_with,
    STATE(8742), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [428845] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [428883] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [428921] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [428959] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [428997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429035] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429073] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [429111] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_LT_PERCENT,
    ACTIONS(11725), 1,
      anon_sym_LBRACE,
    ACTIONS(11727), 1,
      anon_sym_with,
    ACTIONS(11764), 1,
      anon_sym_COLON,
    STATE(8761), 1,
      aux_sym_compound_type_repeat1,
    STATE(11240), 1,
      sym__refinement,
    STATE(11251), 1,
      sym_template_body,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8750), 2,
      sym_comment,
      sym_block_comment,
    STATE(11204), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [429207] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8123), 1,
      sym__backquoted_id,
    ACTIONS(10849), 1,
      anon_sym_LPAREN,
    STATE(8668), 1,
      aux_sym_annotation_repeat1,
    STATE(9837), 1,
      sym_arguments,
    STATE(8752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8121), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [429289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [429327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429365] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429441] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10756), 1,
      anon_sym_LPAREN,
    STATE(8699), 1,
      aux_sym_annotation_repeat1,
    STATE(9853), 1,
      sym_arguments,
    STATE(8758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8121), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429485] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429523] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429561] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11725), 1,
      anon_sym_LBRACE,
    ACTIONS(11727), 1,
      anon_sym_with,
    STATE(10466), 1,
      aux_sym_compound_type_repeat1,
    STATE(11251), 1,
      sym_template_body,
    STATE(11289), 1,
      sym__refinement,
    STATE(8761), 2,
      sym_comment,
      sym_block_comment,
    STATE(11204), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7776), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9411), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [429649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [429687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429725] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11767), 1,
      anon_sym_COLON,
    ACTIONS(11770), 1,
      anon_sym_LBRACE,
    STATE(10177), 1,
      sym_template_body,
    STATE(6592), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8900), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 11,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429771] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429847] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [429885] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [429923] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [429961] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11493), 1,
      anon_sym_LBRACK,
    ACTIONS(11495), 1,
      anon_sym_AT,
    ACTIONS(11499), 1,
      anon_sym_POUND,
    STATE(9856), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10267), 1,
      sym_type_arguments,
    STATE(10419), 1,
      sym_annotation,
    STATE(8771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430011] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [430087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430125] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [430163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430201] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [430245] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430321] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9073), 1,
      sym__end_marker,
    STATE(8780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430361] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430399] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430475] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430515] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [430555] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9415), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [430631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [430669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9419), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [430707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430821] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430859] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430897] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430935] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [430973] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [431011] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [431049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [431087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431125] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431163] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [431201] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11491), 1,
      anon_sym_with,
    STATE(10558), 1,
      aux_sym_compound_type_repeat1,
    STATE(11057), 1,
      sym_template_body,
    STATE(11170), 1,
      sym__refinement,
    STATE(8803), 2,
      sym_comment,
      sym_block_comment,
    STATE(11096), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431249] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431287] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4178), 1,
      sym__backquoted_id,
    ACTIONS(4176), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(4180), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4174), 18,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431329] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431367] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [431405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431481] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    ACTIONS(10628), 1,
      sym__interpolated_multiline_string_start,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11265), 1,
      sym_interpolated_string,
    STATE(16003), 1,
      sym__interpolated_string_start,
    ACTIONS(11773), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(8810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [431549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431587] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9746), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431627] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431665] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10677), 1,
      sym__backquoted_id,
    ACTIONS(4176), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(4180), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7478), 18,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431707] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11014), 1,
      anon_sym_AT,
    STATE(8896), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9991), 1,
      sym_annotation,
    STATE(8815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431789] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11305), 1,
      sym__interpolated_multiline_string_start,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11780), 1,
      sym_interpolated_string,
    STATE(16279), 1,
      sym__interpolated_string_start,
    ACTIONS(11775), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [431857] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11777), 1,
      anon_sym_with,
    STATE(8818), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431897] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10679), 1,
      sym__backquoted_id,
    ACTIONS(4176), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(4180), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7508), 18,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431939] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10681), 1,
      sym__backquoted_id,
    ACTIONS(4176), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(4180), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7510), 18,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [431981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432019] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11780), 1,
      anon_sym_with,
    STATE(8822), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432059] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [432097] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432135] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(8825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 20,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9726), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432365] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432479] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432555] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432593] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432631] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9836), 1,
      sym__alpha_identifier,
    ACTIONS(9842), 1,
      sym__backquoted_id,
    ACTIONS(9844), 1,
      sym_operator_identifier,
    STATE(582), 1,
      sym_identifier,
    STATE(4162), 1,
      sym__soft_identifier,
    STATE(8838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9022), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9838), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [432683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432721] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432759] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432797] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9019), 1,
      sym_arguments,
    STATE(8842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [432875] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432913] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432951] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11783), 1,
      anon_sym_DOT,
    STATE(8846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [432991] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433029] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(11655), 1,
      anon_sym_LBRACE,
    ACTIONS(11657), 1,
      anon_sym_with,
    STATE(8351), 1,
      aux_sym_compound_type_repeat1,
    STATE(11190), 1,
      sym__refinement,
    STATE(11194), 1,
      sym_template_body,
    STATE(8848), 2,
      sym_comment,
      sym_block_comment,
    STATE(11358), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7766), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433079] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433155] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [433193] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    ACTIONS(10628), 1,
      sym__interpolated_multiline_string_start,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11265), 1,
      sym_interpolated_string,
    STATE(16003), 1,
      sym__interpolated_string_start,
    ACTIONS(11785), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(8852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [433261] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [433299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433337] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [433375] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433413] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433451] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433489] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433527] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433565] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433717] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11787), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [433755] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433833] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    ACTIONS(10628), 1,
      sym__interpolated_multiline_string_start,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11265), 1,
      sym_interpolated_string,
    STATE(16003), 1,
      sym__interpolated_string_start,
    ACTIONS(11791), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(8868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [433901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433939] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10582), 1,
      anon_sym_AT,
    STATE(8541), 1,
      aux_sym_enum_definition_repeat1,
    STATE(9648), 1,
      sym_annotation,
    STATE(8870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [433983] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11793), 1,
      anon_sym_AT,
    STATE(9926), 1,
      sym_annotation,
    STATE(8871), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434025] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434063] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [434101] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434139] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [434215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434253] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10183), 1,
      sym__interpolated_multiline_string_start,
    STATE(9974), 1,
      sym_interpolated_string,
    STATE(15927), 1,
      sym__interpolated_string_start,
    ACTIONS(11796), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [434301] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 17,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [434339] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(11176), 1,
      sym__backquoted_id,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11387), 1,
      sym__interpolated_multiline_string_start,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11852), 1,
      sym_interpolated_string,
    STATE(16134), 1,
      sym__interpolated_string_start,
    STATE(8880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11174), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434395] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434433] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5552), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(8882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434513] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10342), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434553] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    ACTIONS(11387), 1,
      sym__interpolated_multiline_string_start,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11852), 1,
      sym_interpolated_string,
    STATE(16134), 1,
      sym__interpolated_string_start,
    STATE(8885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11196), 3,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [434619] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11798), 1,
      anon_sym_AT,
    STATE(10001), 1,
      sym_annotation,
    STATE(8886), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434661] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11635), 1,
      anon_sym_COLON,
    ACTIONS(11637), 1,
      anon_sym_LBRACE,
    ACTIONS(11639), 1,
      anon_sym_with,
    STATE(10500), 1,
      aux_sym_compound_type_repeat1,
    STATE(11254), 1,
      sym_template_body,
    STATE(11273), 1,
      sym__refinement,
    STATE(8887), 2,
      sym_comment,
      sym_block_comment,
    STATE(11233), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7776), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434789] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [434941] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [434979] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(11145), 1,
      sym__backquoted_id,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11387), 1,
      sym__interpolated_multiline_string_start,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11852), 1,
      sym_interpolated_string,
    STATE(16134), 1,
      sym__interpolated_string_start,
    STATE(8895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11143), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435035] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11801), 1,
      anon_sym_AT,
    STATE(9991), 1,
      sym_annotation,
    STATE(8896), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435077] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11804), 1,
      anon_sym_with,
    STATE(8897), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435155] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [435231] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(11655), 1,
      anon_sym_LBRACE,
    ACTIONS(11657), 1,
      anon_sym_with,
    ACTIONS(11807), 1,
      anon_sym_COLON,
    STATE(8351), 1,
      aux_sym_compound_type_repeat1,
    STATE(11190), 1,
      sym__refinement,
    STATE(11194), 1,
      sym_template_body,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8901), 2,
      sym_comment,
      sym_block_comment,
    STATE(11358), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7882), 3,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435287] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11810), 1,
      anon_sym_with,
    STATE(8902), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435327] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(8903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435367] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435481] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435709] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435747] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9709), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [435823] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [435899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [435937] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [435975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436013] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436051] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7606), 1,
      anon_sym_AT,
    ACTIONS(7614), 1,
      anon_sym_inline,
    ACTIONS(7616), 1,
      anon_sym_infix,
    ACTIONS(7618), 1,
      anon_sym_open,
    ACTIONS(7620), 1,
      anon_sym_transparent,
    ACTIONS(11813), 1,
      anon_sym_def,
    STATE(5152), 1,
      aux_sym_modifiers_repeat1,
    STATE(6346), 1,
      aux_sym_enum_definition_repeat1,
    STATE(8122), 1,
      sym_annotation,
    STATE(18471), 1,
      sym_modifiers,
    ACTIONS(7612), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(8922), 2,
      sym_comment,
      sym_block_comment,
    STATE(6735), 5,
      sym_access_modifier,
      sym_inline_modifier,
      sym_infix_modifier,
      sym_open_modifier,
      sym_transparent_modifier,
    ACTIONS(7610), 6,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
  [436111] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8927), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [436151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436227] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436265] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436341] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [436379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11815), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_LT_DASH,
  [436455] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436531] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10274), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436571] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436647] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [436685] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436723] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5726), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(8939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436764] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436838] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [436875] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9259), 1,
      sym__alpha_identifier,
    ACTIONS(9263), 1,
      anon_sym_EQ,
    ACTIONS(9265), 1,
      sym__backquoted_id,
    ACTIONS(9267), 1,
      sym_operator_identifier,
    STATE(580), 1,
      sym_identifier,
    STATE(4062), 1,
      sym__soft_identifier,
    STATE(8943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9261), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [436928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [436965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437002] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6402), 1,
      sym__alpha_identifier,
    ACTIONS(6408), 1,
      anon_sym__,
    ACTIONS(6416), 1,
      sym__backquoted_id,
    ACTIONS(6418), 1,
      sym_operator_identifier,
    ACTIONS(10224), 1,
      anon_sym_LPAREN,
    STATE(4985), 1,
      sym__simple_type,
    STATE(5859), 1,
      sym_identifier,
    STATE(5895), 1,
      sym__soft_identifier,
    STATE(17654), 1,
      sym_stable_identifier,
    STATE(8946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6775), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [437057] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6632), 1,
      sym__alpha_identifier,
    ACTIONS(6638), 1,
      anon_sym__,
    ACTIONS(6646), 1,
      sym__backquoted_id,
    ACTIONS(6648), 1,
      sym_operator_identifier,
    ACTIONS(10199), 1,
      anon_sym_LPAREN,
    STATE(5364), 1,
      sym__simple_type,
    STATE(6337), 1,
      sym_identifier,
    STATE(6537), 1,
      sym__soft_identifier,
    STATE(16798), 1,
      sym_stable_identifier,
    STATE(8947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6642), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6924), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [437112] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437149] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11172), 1,
      anon_sym_AT,
    STATE(9512), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10260), 1,
      sym_annotation,
    STATE(8949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437229] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(8951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437268] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437305] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10438), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437344] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [437418] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6698), 1,
      sym__alpha_identifier,
    ACTIONS(6704), 1,
      anon_sym__,
    ACTIONS(6712), 1,
      sym__backquoted_id,
    ACTIONS(6714), 1,
      sym_operator_identifier,
    ACTIONS(9834), 1,
      anon_sym_LPAREN,
    STATE(4712), 1,
      sym__simple_type,
    STATE(5215), 1,
      sym__soft_identifier,
    STATE(5482), 1,
      sym_identifier,
    STATE(17840), 1,
      sym_stable_identifier,
    STATE(8956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6708), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5743), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [437473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437510] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437547] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437584] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [437621] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437658] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437695] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437732] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11819), 1,
      anon_sym_COLON,
    ACTIONS(11822), 1,
      anon_sym_LBRACE,
    STATE(10524), 1,
      sym_template_body,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(8964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8900), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8892), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437777] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6832), 1,
      anon_sym__,
    ACTIONS(6840), 1,
      sym__backquoted_id,
    ACTIONS(6842), 1,
      sym_operator_identifier,
    ACTIONS(10351), 1,
      anon_sym_LPAREN,
    STATE(5464), 1,
      sym__simple_type,
    STATE(6117), 1,
      sym_identifier,
    STATE(6232), 1,
      sym__soft_identifier,
    STATE(17531), 1,
      sym_stable_identifier,
    STATE(8965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6836), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7013), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [437832] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11825), 1,
      sym__alpha_identifier,
    ACTIONS(11827), 1,
      anon_sym__,
    ACTIONS(11831), 1,
      anon_sym_LPAREN,
    ACTIONS(11833), 1,
      sym__backquoted_id,
    ACTIONS(11835), 1,
      sym_operator_identifier,
    STATE(11011), 1,
      sym__simple_type,
    STATE(11473), 1,
      sym__soft_identifier,
    STATE(11568), 1,
      sym_identifier,
    STATE(17726), 1,
      sym_stable_identifier,
    STATE(8966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11829), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11837), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [437887] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8084), 1,
      sym__alpha_identifier,
    ACTIONS(8086), 1,
      anon_sym__,
    ACTIONS(8090), 1,
      anon_sym_LPAREN,
    ACTIONS(8092), 1,
      sym__backquoted_id,
    ACTIONS(8094), 1,
      sym_operator_identifier,
    STATE(5774), 1,
      sym__simple_type,
    STATE(7587), 1,
      sym_identifier,
    STATE(7664), 1,
      sym__soft_identifier,
    STATE(17607), 1,
      sym_stable_identifier,
    STATE(8967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8088), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [437942] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [437979] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6492), 1,
      anon_sym__,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(6502), 1,
      sym_operator_identifier,
    ACTIONS(10321), 1,
      anon_sym_LPAREN,
    STATE(5630), 1,
      sym__simple_type,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7459), 1,
      sym_identifier,
    STATE(17518), 1,
      sym_stable_identifier,
    STATE(8969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7956), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438071] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438145] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6772), 1,
      sym__alpha_identifier,
    ACTIONS(6778), 1,
      anon_sym__,
    ACTIONS(6786), 1,
      sym__backquoted_id,
    ACTIONS(6788), 1,
      sym_operator_identifier,
    ACTIONS(10052), 1,
      anon_sym_LPAREN,
    STATE(5379), 1,
      sym__simple_type,
    STATE(6418), 1,
      sym__soft_identifier,
    STATE(6643), 1,
      sym_identifier,
    STATE(17852), 1,
      sym_stable_identifier,
    STATE(8973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6782), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7485), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438200] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438311] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9335), 1,
      anon_sym_with,
    ACTIONS(11837), 1,
      anon_sym_LBRACE,
    STATE(7687), 1,
      aux_sym_compound_type_repeat1,
    STATE(11419), 1,
      sym_template_body,
    STATE(11537), 1,
      sym__refinement,
    STATE(8977), 2,
      sym_comment,
      sym_block_comment,
    STATE(11645), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7776), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438360] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438397] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11457), 1,
      anon_sym_AT,
    STATE(9478), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10323), 1,
      sym_annotation,
    STATE(8979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438440] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6324), 1,
      anon_sym__,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(6334), 1,
      sym_operator_identifier,
    ACTIONS(10272), 1,
      anon_sym_LPAREN,
    STATE(5651), 1,
      sym__simple_type,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7480), 1,
      sym_identifier,
    STATE(17505), 1,
      sym_stable_identifier,
    STATE(8980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7908), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438495] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [438606] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438643] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6286), 1,
      sym__alpha_identifier,
    ACTIONS(6288), 1,
      anon_sym__,
    ACTIONS(6296), 1,
      sym__backquoted_id,
    ACTIONS(6298), 1,
      sym_operator_identifier,
    ACTIONS(10003), 1,
      anon_sym_LPAREN,
    STATE(5838), 1,
      sym__simple_type,
    STATE(6838), 1,
      sym__soft_identifier,
    STATE(7402), 1,
      sym_identifier,
    STATE(16771), 1,
      sym_stable_identifier,
    STATE(8985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6292), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7941), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438698] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438735] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11839), 1,
      sym__alpha_identifier,
    ACTIONS(11841), 1,
      anon_sym__,
    ACTIONS(11845), 1,
      anon_sym_LPAREN,
    ACTIONS(11847), 1,
      sym__backquoted_id,
    ACTIONS(11849), 1,
      sym_operator_identifier,
    STATE(11952), 1,
      sym__simple_type,
    STATE(12571), 1,
      sym_identifier,
    STATE(12789), 1,
      sym__soft_identifier,
    STATE(17906), 1,
      sym_stable_identifier,
    STATE(8987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11843), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13402), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438790] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4214), 1,
      sym__alpha_identifier,
    ACTIONS(4220), 1,
      anon_sym__,
    ACTIONS(4232), 1,
      sym__backquoted_id,
    ACTIONS(6752), 1,
      sym_operator_identifier,
    ACTIONS(10082), 1,
      anon_sym_LPAREN,
    STATE(4540), 1,
      sym__simple_type,
    STATE(4914), 1,
      sym_identifier,
    STATE(5031), 1,
      sym__soft_identifier,
    STATE(17054), 1,
      sym_stable_identifier,
    STATE(8988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4226), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5167), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [438845] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11851), 1,
      anon_sym_LPAREN,
    STATE(10273), 1,
      sym_arguments,
    STATE(8989), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438886] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(8990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [438966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439040] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10459), 1,
      anon_sym_COLON,
    ACTIONS(10464), 1,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(10789), 1,
      anon_sym_EQ_GT,
    STATE(17842), 1,
      sym__self_type_ascription,
    STATE(8994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439085] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11854), 1,
      anon_sym_DOT,
    STATE(8995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439124] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439161] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(8997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439204] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439241] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5503), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(8999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10122), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [439282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7334), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [439319] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439356] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439393] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4182), 1,
      sym__alpha_identifier,
    ACTIONS(4188), 1,
      anon_sym__,
    ACTIONS(4200), 1,
      sym__backquoted_id,
    ACTIONS(6316), 1,
      sym_operator_identifier,
    ACTIONS(9943), 1,
      anon_sym_LPAREN,
    STATE(4467), 1,
      sym__simple_type,
    STATE(4657), 1,
      sym__soft_identifier,
    STATE(4661), 1,
      sym_identifier,
    STATE(17648), 1,
      sym_stable_identifier,
    STATE(9003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4194), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4885), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439485] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439522] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11856), 1,
      sym__alpha_identifier,
    ACTIONS(11858), 1,
      anon_sym__,
    ACTIONS(11862), 1,
      anon_sym_LPAREN,
    ACTIONS(11864), 1,
      sym__backquoted_id,
    ACTIONS(11866), 1,
      sym_operator_identifier,
    STATE(6733), 1,
      sym__simple_type,
    STATE(8044), 1,
      sym__soft_identifier,
    STATE(8173), 1,
      sym_identifier,
    STATE(16950), 1,
      sym_stable_identifier,
    STATE(9006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11860), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8826), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439614] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439651] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [439688] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [439725] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11868), 1,
      anon_sym_with,
    STATE(9011), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439764] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439801] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6336), 1,
      sym__alpha_identifier,
    ACTIONS(6342), 1,
      anon_sym__,
    ACTIONS(6350), 1,
      sym__backquoted_id,
    ACTIONS(6352), 1,
      sym_operator_identifier,
    ACTIONS(10062), 1,
      anon_sym_LPAREN,
    STATE(5108), 1,
      sym__simple_type,
    STATE(6347), 1,
      sym__soft_identifier,
    STATE(6696), 1,
      sym_identifier,
    STATE(17708), 1,
      sym_stable_identifier,
    STATE(9013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6346), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7084), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439856] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6996), 1,
      sym__alpha_identifier,
    ACTIONS(6998), 1,
      anon_sym__,
    ACTIONS(7006), 1,
      sym__backquoted_id,
    ACTIONS(7008), 1,
      sym_operator_identifier,
    ACTIONS(9769), 1,
      anon_sym_LPAREN,
    STATE(6077), 1,
      sym__simple_type,
    STATE(7238), 1,
      sym_identifier,
    STATE(7458), 1,
      sym__soft_identifier,
    STATE(17218), 1,
      sym_stable_identifier,
    STATE(9014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7002), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8023), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [439911] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9932), 1,
      sym__end_marker,
    STATE(9015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9449), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [439950] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8603), 1,
      sym__backquoted_id,
    ACTIONS(11871), 1,
      anon_sym_AT,
    STATE(10198), 1,
      sym_annotation,
    STATE(9016), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8601), 18,
      anon_sym_end,
      anon_sym_val,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [439991] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6602), 1,
      anon_sym__,
    ACTIONS(6610), 1,
      sym__backquoted_id,
    ACTIONS(6612), 1,
      sym_operator_identifier,
    ACTIONS(10145), 1,
      anon_sym_LPAREN,
    STATE(5890), 1,
      sym__simple_type,
    STATE(7134), 1,
      sym__soft_identifier,
    STATE(7495), 1,
      sym_identifier,
    STATE(17864), 1,
      sym_stable_identifier,
    STATE(9017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7557), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440046] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440120] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440194] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5912), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [440235] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440272] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440309] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9364), 1,
      sym_operator_identifier,
    STATE(1752), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8309), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [440362] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440399] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440436] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440510] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440547] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [440584] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6716), 1,
      sym__alpha_identifier,
    ACTIONS(6722), 1,
      anon_sym__,
    ACTIONS(6730), 1,
      sym__backquoted_id,
    ACTIONS(6732), 1,
      sym_operator_identifier,
    ACTIONS(10039), 1,
      anon_sym_LPAREN,
    STATE(5417), 1,
      sym__simple_type,
    STATE(6329), 1,
      sym_identifier,
    STATE(6457), 1,
      sym__soft_identifier,
    STATE(17539), 1,
      sym_stable_identifier,
    STATE(9032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6726), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7381), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440639] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4830), 1,
      sym__alpha_identifier,
    ACTIONS(4836), 1,
      anon_sym__,
    ACTIONS(4848), 1,
      sym__backquoted_id,
    ACTIONS(6854), 1,
      sym_operator_identifier,
    ACTIONS(9973), 1,
      anon_sym_LPAREN,
    STATE(4716), 1,
      sym__simple_type,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5395), 1,
      sym_identifier,
    STATE(17092), 1,
      sym_stable_identifier,
    STATE(9033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4842), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5759), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440694] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440731] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440774] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6972), 1,
      anon_sym__,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(6982), 1,
      sym_operator_identifier,
    ACTIONS(10319), 1,
      anon_sym_LPAREN,
    STATE(4871), 1,
      sym__simple_type,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6043), 1,
      sym_identifier,
    STATE(17544), 1,
      sym_stable_identifier,
    STATE(9036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6339), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [440829] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9273), 1,
      anon_sym_LPAREN,
    ACTIONS(10578), 1,
      anon_sym_DOT,
    ACTIONS(10590), 1,
      sym_operator_identifier,
    ACTIONS(11874), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_match,
      anon_sym_do,
    STATE(9037), 2,
      sym_comment,
      sym_block_comment,
    STATE(9953), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [440890] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11876), 1,
      anon_sym_with,
    STATE(9038), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [440966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441040] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [441120] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10332), 1,
      sym__alpha_identifier,
    ACTIONS(10338), 1,
      sym__backquoted_id,
    ACTIONS(10340), 1,
      sym_operator_identifier,
    STATE(586), 1,
      sym_identifier,
    STATE(4180), 1,
      sym__soft_identifier,
    STATE(9044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9022), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10334), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [441171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [441208] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(11879), 1,
      anon_sym_LPAREN,
    ACTIONS(11881), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(4351), 1,
      sym_identifier,
    STATE(4640), 1,
      sym__simple_type,
    STATE(17813), 1,
      sym_stable_identifier,
    STATE(9046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4372), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441263] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441300] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11087), 1,
      anon_sym_LPAREN,
    STATE(8989), 1,
      aux_sym_annotation_repeat1,
    STATE(10273), 1,
      sym_arguments,
    STATE(9048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8121), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441380] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6256), 1,
      anon_sym__,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(6266), 1,
      sym_operator_identifier,
    ACTIONS(10084), 1,
      anon_sym_LPAREN,
    STATE(6458), 1,
      sym__simple_type,
    STATE(7513), 1,
      sym_identifier,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(16743), 1,
      sym_stable_identifier,
    STATE(9050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8845), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441435] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6900), 1,
      sym__alpha_identifier,
    ACTIONS(6906), 1,
      anon_sym__,
    ACTIONS(6914), 1,
      sym__backquoted_id,
    ACTIONS(6916), 1,
      sym_operator_identifier,
    ACTIONS(9798), 1,
      anon_sym_LPAREN,
    STATE(4597), 1,
      sym__simple_type,
    STATE(5011), 1,
      sym_identifier,
    STATE(5013), 1,
      sym__soft_identifier,
    STATE(17762), 1,
      sym_stable_identifier,
    STATE(9051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6910), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5168), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441490] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11883), 1,
      sym__alpha_identifier,
    ACTIONS(11885), 1,
      anon_sym__,
    ACTIONS(11889), 1,
      anon_sym_LPAREN,
    ACTIONS(11891), 1,
      sym__backquoted_id,
    ACTIONS(11893), 1,
      sym_operator_identifier,
    STATE(12043), 1,
      sym__simple_type,
    STATE(12652), 1,
      sym__soft_identifier,
    STATE(12928), 1,
      sym_identifier,
    STATE(17660), 1,
      sym_stable_identifier,
    STATE(9052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11887), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13307), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441545] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441582] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10801), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441621] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441658] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441695] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441732] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441769] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6186), 1,
      anon_sym__,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(6196), 1,
      sym_operator_identifier,
    ACTIONS(9790), 1,
      anon_sym_LPAREN,
    STATE(7244), 1,
      sym__simple_type,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8846), 1,
      sym_identifier,
    STATE(16823), 1,
      sym_stable_identifier,
    STATE(9059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9522), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441824] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8042), 1,
      sym__alpha_identifier,
    ACTIONS(8044), 1,
      anon_sym__,
    ACTIONS(8048), 1,
      anon_sym_LPAREN,
    ACTIONS(8050), 1,
      sym__backquoted_id,
    ACTIONS(8052), 1,
      sym_operator_identifier,
    STATE(5573), 1,
      sym__simple_type,
    STATE(7769), 1,
      sym__soft_identifier,
    STATE(8225), 1,
      sym_identifier,
    STATE(17702), 1,
      sym_stable_identifier,
    STATE(9060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8046), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7951), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441879] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8030), 1,
      sym__alpha_identifier,
    ACTIONS(8032), 1,
      anon_sym__,
    ACTIONS(8036), 1,
      anon_sym_LPAREN,
    ACTIONS(8038), 1,
      sym__backquoted_id,
    ACTIONS(8040), 1,
      sym_operator_identifier,
    STATE(6231), 1,
      sym__simple_type,
    STATE(8285), 1,
      sym_identifier,
    STATE(8625), 1,
      sym__soft_identifier,
    STATE(17197), 1,
      sym_stable_identifier,
    STATE(9061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8034), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8375), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [441934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [441971] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442010] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4310), 1,
      sym__alpha_identifier,
    ACTIONS(4316), 1,
      anon_sym__,
    ACTIONS(4328), 1,
      sym__backquoted_id,
    ACTIONS(6696), 1,
      sym_operator_identifier,
    ACTIONS(10041), 1,
      anon_sym_LPAREN,
    STATE(4586), 1,
      sym__simple_type,
    STATE(4906), 1,
      sym_identifier,
    STATE(5094), 1,
      sym__soft_identifier,
    STATE(17786), 1,
      sym_stable_identifier,
    STATE(9064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5293), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [442065] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442102] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442139] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8125), 1,
      sym__alpha_identifier,
    ACTIONS(8131), 1,
      anon_sym__,
    ACTIONS(8135), 1,
      anon_sym_LPAREN,
    ACTIONS(8137), 1,
      sym__backquoted_id,
    ACTIONS(8139), 1,
      sym_operator_identifier,
    STATE(8633), 1,
      sym__simple_type,
    STATE(10205), 1,
      sym_identifier,
    STATE(10235), 1,
      sym__soft_identifier,
    STATE(17260), 1,
      sym_stable_identifier,
    STATE(9067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8133), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(10246), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [442194] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442231] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442268] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9016), 1,
      sym__alpha_identifier,
    ACTIONS(9026), 1,
      sym__backquoted_id,
    ACTIONS(9028), 1,
      sym_operator_identifier,
    ACTIONS(9358), 1,
      anon_sym_EQ,
    STATE(579), 1,
      sym_identifier,
    STATE(3987), 1,
      sym__soft_identifier,
    STATE(9070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [442321] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8259), 1,
      sym__alpha_identifier,
    ACTIONS(8265), 1,
      anon_sym__,
    ACTIONS(8269), 1,
      anon_sym_LPAREN,
    ACTIONS(8271), 1,
      sym__backquoted_id,
    ACTIONS(8273), 1,
      sym_operator_identifier,
    STATE(4506), 1,
      sym__simple_type,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(5062), 1,
      sym_identifier,
    STATE(17195), 1,
      sym_stable_identifier,
    STATE(9071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8267), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4969), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [442376] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442413] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442450] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6204), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(11895), 1,
      anon_sym_with,
    STATE(9329), 1,
      aux_sym_compound_type_repeat1,
    STATE(11955), 1,
      sym_template_body,
    STATE(11956), 1,
      sym__refinement,
    ACTIONS(7772), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(9074), 2,
      sym_comment,
      sym_block_comment,
    STATE(11933), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7766), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442501] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4946), 1,
      anon_sym__,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(5138), 1,
      sym_operator_identifier,
    ACTIONS(9744), 1,
      anon_sym_LPAREN,
    STATE(4846), 1,
      sym__simple_type,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6057), 1,
      sym_identifier,
    STATE(17668), 1,
      sym_stable_identifier,
    STATE(9075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6565), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [442556] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10691), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442632] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [442669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442706] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442780] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [442817] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4594), 1,
      sym__alpha_identifier,
    ACTIONS(4600), 1,
      anon_sym__,
    ACTIONS(4612), 1,
      sym__backquoted_id,
    ACTIONS(6252), 1,
      sym_operator_identifier,
    ACTIONS(10169), 1,
      anon_sym_LPAREN,
    STATE(4791), 1,
      sym__simple_type,
    STATE(5125), 1,
      sym_identifier,
    STATE(5264), 1,
      sym__soft_identifier,
    STATE(17492), 1,
      sym_stable_identifier,
    STATE(9083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5951), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [442872] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [442909] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [442946] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [442983] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9848), 1,
      sym_arguments,
    STATE(9087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443022] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443059] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443096] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443207] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [443244] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7940), 1,
      sym__alpha_identifier,
    ACTIONS(7946), 1,
      anon_sym__,
    ACTIONS(7950), 1,
      anon_sym_LPAREN,
    ACTIONS(7952), 1,
      sym__backquoted_id,
    ACTIONS(7954), 1,
      sym_operator_identifier,
    STATE(11100), 1,
      sym__simple_type,
    STATE(11430), 1,
      sym_identifier,
    STATE(11669), 1,
      sym__soft_identifier,
    STATE(17077), 1,
      sym_stable_identifier,
    STATE(9094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7948), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11959), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [443299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [443336] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [443373] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10787), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443412] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443449] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [443486] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    ACTIONS(11897), 1,
      anon_sym_COLON,
    ACTIONS(11900), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(9100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443529] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443566] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9660), 1,
      sym_operator_identifier,
    STATE(1799), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [443619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10019), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [443656] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443730] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10776), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [443806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9656), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [443880] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [443917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [443954] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [443991] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [444065] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444102] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6234), 1,
      anon_sym__,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(6244), 1,
      sym_operator_identifier,
    ACTIONS(10315), 1,
      anon_sym_LPAREN,
    STATE(6783), 1,
      sym__simple_type,
    STATE(8358), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(16720), 1,
      sym_stable_identifier,
    STATE(9116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9309), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [444157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444194] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444231] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444268] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10620), 1,
      anon_sym_RPAREN,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15412), 1,
      aux_sym_case_class_pattern_repeat1,
    ACTIONS(10618), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(9120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [444333] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444370] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444407] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444444] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444481] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444518] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5765), 1,
      sym__end_marker,
    STATE(9126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444557] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4530), 1,
      sym__alpha_identifier,
    ACTIONS(4536), 1,
      anon_sym__,
    ACTIONS(4548), 1,
      sym__backquoted_id,
    ACTIONS(6526), 1,
      sym_operator_identifier,
    ACTIONS(10265), 1,
      anon_sym_LPAREN,
    STATE(4991), 1,
      sym__simple_type,
    STATE(5882), 1,
      sym__soft_identifier,
    STATE(5987), 1,
      sym_identifier,
    STATE(17666), 1,
      sym_stable_identifier,
    STATE(9127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4542), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6618), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [444612] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4812), 1,
      sym__alpha_identifier,
    ACTIONS(4814), 1,
      anon_sym__,
    ACTIONS(4824), 1,
      sym__backquoted_id,
    ACTIONS(6598), 1,
      sym_operator_identifier,
    ACTIONS(10270), 1,
      anon_sym_LPAREN,
    STATE(5473), 1,
      sym__simple_type,
    STATE(6255), 1,
      sym_identifier,
    STATE(6330), 1,
      sym__soft_identifier,
    STATE(16701), 1,
      sym_stable_identifier,
    STATE(9128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4820), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7403), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [444667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9676), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [444704] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [444741] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8143), 1,
      sym__alpha_identifier,
    ACTIONS(8149), 1,
      anon_sym__,
    ACTIONS(8153), 1,
      anon_sym_LPAREN,
    ACTIONS(8155), 1,
      sym__backquoted_id,
    ACTIONS(8157), 1,
      sym_operator_identifier,
    STATE(4421), 1,
      sym__simple_type,
    STATE(4706), 1,
      sym_identifier,
    STATE(4734), 1,
      sym__soft_identifier,
    STATE(17281), 1,
      sym_stable_identifier,
    STATE(9131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8151), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4688), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [444796] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [444833] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [444870] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444907] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444944] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [444981] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8437), 1,
      sym__alpha_identifier,
    ACTIONS(8439), 1,
      anon_sym__,
    ACTIONS(8443), 1,
      anon_sym_LPAREN,
    ACTIONS(8445), 1,
      sym__backquoted_id,
    ACTIONS(8447), 1,
      sym_operator_identifier,
    STATE(4901), 1,
      sym__simple_type,
    STATE(6388), 1,
      sym_identifier,
    STATE(6404), 1,
      sym__soft_identifier,
    STATE(17834), 1,
      sym_stable_identifier,
    STATE(9137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8441), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6567), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [445036] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10015), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [445073] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [445110] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445147] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445184] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445221] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10459), 1,
      anon_sym_COLON,
    ACTIONS(10462), 1,
      anon_sym_EQ_GT,
    ACTIONS(10464), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(17928), 1,
      sym__self_type_ascription,
    STATE(9143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445340] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445377] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6940), 1,
      sym__alpha_identifier,
    ACTIONS(6946), 1,
      anon_sym__,
    ACTIONS(6954), 1,
      sym__backquoted_id,
    ACTIONS(6956), 1,
      sym_operator_identifier,
    ACTIONS(9975), 1,
      anon_sym_LPAREN,
    STATE(5489), 1,
      sym__simple_type,
    STATE(6376), 1,
      sym__soft_identifier,
    STATE(6428), 1,
      sym_identifier,
    STATE(17774), 1,
      sym_stable_identifier,
    STATE(9147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7299), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [445432] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9337), 1,
      sym__alpha_identifier,
    ACTIONS(9341), 1,
      anon_sym_EQ,
    ACTIONS(9343), 1,
      sym__backquoted_id,
    ACTIONS(9345), 1,
      sym_operator_identifier,
    STATE(581), 1,
      sym_identifier,
    STATE(4080), 1,
      sym__soft_identifier,
    STATE(9148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9339), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [445485] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9337), 1,
      sym__alpha_identifier,
    ACTIONS(9343), 1,
      sym__backquoted_id,
    ACTIONS(9345), 1,
      sym_operator_identifier,
    ACTIONS(9354), 1,
      anon_sym_EQ,
    STATE(581), 1,
      sym_identifier,
    STATE(4080), 1,
      sym__soft_identifier,
    STATE(9149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 6,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9339), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [445538] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445575] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445612] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9999), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [445649] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10459), 1,
      anon_sym_COLON,
    ACTIONS(10468), 1,
      anon_sym_EQ_GT,
    ACTIONS(10470), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(18331), 1,
      sym__self_type_ascription,
    STATE(9153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445694] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [445731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9987), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [445805] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445842] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9981), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [445879] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4868), 1,
      sym__alpha_identifier,
    ACTIONS(4870), 1,
      anon_sym__,
    ACTIONS(4880), 1,
      sym__backquoted_id,
    ACTIONS(6850), 1,
      sym_operator_identifier,
    ACTIONS(10249), 1,
      anon_sym_LPAREN,
    STATE(4886), 1,
      sym__simple_type,
    STATE(5536), 1,
      sym_identifier,
    STATE(5967), 1,
      sym__soft_identifier,
    STATE(17570), 1,
      sym_stable_identifier,
    STATE(9159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6401), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [445934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [445971] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446008] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9977), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9536), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446082] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8159), 1,
      sym__alpha_identifier,
    ACTIONS(8161), 1,
      anon_sym__,
    ACTIONS(8165), 1,
      anon_sym_LPAREN,
    ACTIONS(8167), 1,
      sym__backquoted_id,
    ACTIONS(8169), 1,
      sym_operator_identifier,
    STATE(5969), 1,
      sym__simple_type,
    STATE(7625), 1,
      sym_identifier,
    STATE(8275), 1,
      sym__soft_identifier,
    STATE(17481), 1,
      sym_stable_identifier,
    STATE(9164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8163), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7680), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [446137] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9629), 1,
      sym__end_marker,
    STATE(9165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [446176] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446213] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446250] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [446324] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446361] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446398] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11903), 1,
      sym__alpha_identifier,
    ACTIONS(11905), 1,
      anon_sym__,
    ACTIONS(11909), 1,
      anon_sym_LPAREN,
    ACTIONS(11911), 1,
      sym__backquoted_id,
    ACTIONS(11913), 1,
      sym_operator_identifier,
    STATE(11672), 1,
      sym__simple_type,
    STATE(12153), 1,
      sym_identifier,
    STATE(12194), 1,
      sym__soft_identifier,
    STATE(17888), 1,
      sym_stable_identifier,
    STATE(9172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11907), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12640), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [446453] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9766), 1,
      sym_arguments,
    STATE(9173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7750), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446492] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446529] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446640] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446677] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    ACTIONS(11915), 1,
      anon_sym_COLON,
    STATE(9179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446718] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446755] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [446792] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11917), 1,
      anon_sym_with,
    STATE(9182), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446831] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9273), 1,
      anon_sym_LPAREN,
    ACTIONS(10578), 1,
      anon_sym_DOT,
    ACTIONS(10590), 1,
      sym_operator_identifier,
    ACTIONS(11920), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_while,
      anon_sym_match,
    STATE(9183), 2,
      sym_comment,
      sym_block_comment,
    STATE(9953), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [446892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [446966] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4512), 1,
      sym__alpha_identifier,
    ACTIONS(4514), 1,
      anon_sym__,
    ACTIONS(4524), 1,
      sym__backquoted_id,
    ACTIONS(6964), 1,
      sym_operator_identifier,
    ACTIONS(9886), 1,
      anon_sym_LPAREN,
    STATE(4524), 1,
      sym__simple_type,
    STATE(4670), 1,
      sym_identifier,
    STATE(4696), 1,
      sym__soft_identifier,
    STATE(17301), 1,
      sym_stable_identifier,
    STATE(9186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4520), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5076), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [447021] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8002), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447058] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447095] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447132] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11922), 1,
      sym__alpha_identifier,
    ACTIONS(11924), 1,
      anon_sym__,
    ACTIONS(11928), 1,
      anon_sym_LPAREN,
    ACTIONS(11930), 1,
      sym__backquoted_id,
    ACTIONS(11932), 1,
      sym_operator_identifier,
    STATE(10872), 1,
      sym__simple_type,
    STATE(11258), 1,
      sym_identifier,
    STATE(11400), 1,
      sym__soft_identifier,
    STATE(17870), 1,
      sym_stable_identifier,
    STATE(9190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11926), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11487), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [447187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447261] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447298] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447335] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447372] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10833), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447411] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10803), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447450] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [447487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9969), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [447524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447598] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5750), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [447639] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447676] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4886), 1,
      sym__alpha_identifier,
    ACTIONS(4892), 1,
      anon_sym__,
    ACTIONS(4904), 1,
      sym__backquoted_id,
    ACTIONS(6660), 1,
      sym_operator_identifier,
    ACTIONS(10058), 1,
      anon_sym_LPAREN,
    STATE(4587), 1,
      sym__simple_type,
    STATE(5003), 1,
      sym_identifier,
    STATE(5087), 1,
      sym__soft_identifier,
    STATE(17828), 1,
      sym_stable_identifier,
    STATE(9204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5448), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [447731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [447768] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8469), 1,
      sym__alpha_identifier,
    ACTIONS(8475), 1,
      anon_sym__,
    ACTIONS(8479), 1,
      anon_sym_LPAREN,
    ACTIONS(8481), 1,
      sym__backquoted_id,
    ACTIONS(8483), 1,
      sym_operator_identifier,
    STATE(4726), 1,
      sym__simple_type,
    STATE(5527), 1,
      sym__soft_identifier,
    STATE(5936), 1,
      sym_identifier,
    STATE(17734), 1,
      sym_stable_identifier,
    STATE(9206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8477), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5525), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [447823] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447860] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4178), 1,
      sym__backquoted_id,
    STATE(9208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(4174), 8,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
    ACTIONS(4176), 8,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
  [447901] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8211), 1,
      sym__alpha_identifier,
    ACTIONS(8217), 1,
      anon_sym__,
    ACTIONS(8221), 1,
      anon_sym_LPAREN,
    ACTIONS(8223), 1,
      sym__backquoted_id,
    ACTIONS(8225), 1,
      sym_operator_identifier,
    STATE(4617), 1,
      sym__simple_type,
    STATE(5102), 1,
      sym_identifier,
    STATE(5375), 1,
      sym__soft_identifier,
    STATE(17321), 1,
      sym_stable_identifier,
    STATE(9209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8219), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5227), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [447956] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [447993] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6676), 1,
      sym__alpha_identifier,
    ACTIONS(6678), 1,
      anon_sym__,
    ACTIONS(6686), 1,
      sym__backquoted_id,
    ACTIONS(6688), 1,
      sym_operator_identifier,
    ACTIONS(9951), 1,
      anon_sym_LPAREN,
    STATE(6777), 1,
      sym__simple_type,
    STATE(7765), 1,
      sym_identifier,
    STATE(7792), 1,
      sym__soft_identifier,
    STATE(17582), 1,
      sym_stable_identifier,
    STATE(9211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6682), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8371), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [448048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448085] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8371), 1,
      sym__alpha_identifier,
    ACTIONS(8377), 1,
      anon_sym__,
    ACTIONS(8381), 1,
      anon_sym_LPAREN,
    ACTIONS(8383), 1,
      sym__backquoted_id,
    ACTIONS(8385), 1,
      sym_operator_identifier,
    STATE(4578), 1,
      sym__simple_type,
    STATE(5397), 1,
      sym_identifier,
    STATE(5481), 1,
      sym__soft_identifier,
    STATE(16872), 1,
      sym_stable_identifier,
    STATE(9213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8379), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5430), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [448140] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [448214] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9955), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [448251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [448288] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8275), 1,
      sym__alpha_identifier,
    ACTIONS(8277), 1,
      anon_sym__,
    ACTIONS(8281), 1,
      anon_sym_LPAREN,
    ACTIONS(8283), 1,
      sym__backquoted_id,
    ACTIONS(8285), 1,
      sym_operator_identifier,
    STATE(5057), 1,
      sym__simple_type,
    STATE(6136), 1,
      sym_identifier,
    STATE(6327), 1,
      sym__soft_identifier,
    STATE(17071), 1,
      sym_stable_identifier,
    STATE(9218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8279), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6379), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [448343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448380] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6204), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7880), 1,
      sym__outdent,
    ACTIONS(7882), 1,
      anon_sym_case,
    ACTIONS(11895), 1,
      anon_sym_with,
    STATE(9329), 1,
      aux_sym_compound_type_repeat1,
    STATE(11955), 1,
      sym_template_body,
    STATE(11956), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9220), 2,
      sym_comment,
      sym_block_comment,
    STATE(11933), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448437] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448474] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448511] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11934), 1,
      sym__alpha_identifier,
    ACTIONS(11936), 1,
      anon_sym__,
    ACTIONS(11940), 1,
      anon_sym_LPAREN,
    ACTIONS(11942), 1,
      sym__backquoted_id,
    ACTIONS(11944), 1,
      sym_operator_identifier,
    STATE(11012), 1,
      sym__simple_type,
    STATE(11479), 1,
      sym_identifier,
    STATE(11507), 1,
      sym__soft_identifier,
    STATE(17594), 1,
      sym_stable_identifier,
    STATE(9223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11938), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11968), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [448566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448640] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [448677] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [448714] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [448788] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4366), 1,
      anon_sym__,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(4972), 1,
      sym_operator_identifier,
    ACTIONS(10106), 1,
      anon_sym_LPAREN,
    STATE(5372), 1,
      sym__simple_type,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6642), 1,
      sym_identifier,
    STATE(16887), 1,
      sym_stable_identifier,
    STATE(9230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7165), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [448843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [448880] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [448919] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8321), 1,
      sym__alpha_identifier,
    ACTIONS(8323), 1,
      anon_sym__,
    ACTIONS(8327), 1,
      anon_sym_LPAREN,
    ACTIONS(8329), 1,
      sym__backquoted_id,
    ACTIONS(8331), 1,
      sym_operator_identifier,
    STATE(4725), 1,
      sym__simple_type,
    STATE(5767), 1,
      sym_identifier,
    STATE(5875), 1,
      sym__soft_identifier,
    STATE(17672), 1,
      sym_stable_identifier,
    STATE(9233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8325), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5678), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [448974] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11946), 1,
      sym__alpha_identifier,
    ACTIONS(11948), 1,
      anon_sym__,
    ACTIONS(11952), 1,
      anon_sym_LPAREN,
    ACTIONS(11954), 1,
      sym__backquoted_id,
    ACTIONS(11956), 1,
      sym_operator_identifier,
    STATE(10830), 1,
      sym__simple_type,
    STATE(11232), 1,
      sym__soft_identifier,
    STATE(11387), 1,
      sym_identifier,
    STATE(17239), 1,
      sym_stable_identifier,
    STATE(9234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11549), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [449029] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449066] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449103] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6360), 1,
      sym__alpha_identifier,
    ACTIONS(6366), 1,
      anon_sym__,
    ACTIONS(6374), 1,
      sym__backquoted_id,
    ACTIONS(6376), 1,
      sym_operator_identifier,
    ACTIONS(10280), 1,
      anon_sym_LPAREN,
    STATE(4513), 1,
      sym__simple_type,
    STATE(4753), 1,
      sym_identifier,
    STATE(4788), 1,
      sym__soft_identifier,
    STATE(17876), 1,
      sym_stable_identifier,
    STATE(9237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4936), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [449158] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(11879), 1,
      anon_sym_LPAREN,
    ACTIONS(11881), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(4351), 1,
      sym_identifier,
    STATE(12729), 1,
      sym__simple_type,
    STATE(17813), 1,
      sym_stable_identifier,
    STATE(9238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4372), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [449213] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11151), 1,
      anon_sym_LPAREN,
    STATE(9323), 1,
      aux_sym_annotation_repeat1,
    STATE(10319), 1,
      sym_arguments,
    STATE(9239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8121), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449256] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8525), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449293] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11023), 1,
      anon_sym_AT,
    STATE(9265), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10346), 1,
      sym_annotation,
    STATE(9241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8485), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449336] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [449373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449410] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449447] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6444), 1,
      anon_sym__,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(6454), 1,
      sym_operator_identifier,
    ACTIONS(10074), 1,
      anon_sym_LPAREN,
    STATE(5613), 1,
      sym__simple_type,
    STATE(7038), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(17249), 1,
      sym_stable_identifier,
    STATE(9245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8034), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [449502] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449539] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449576] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449613] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449650] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [449693] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [449730] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449767] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449804] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449841] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449878] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449915] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449952] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [449989] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8449), 1,
      sym__alpha_identifier,
    ACTIONS(8451), 1,
      anon_sym__,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    ACTIONS(8457), 1,
      sym__backquoted_id,
    ACTIONS(8459), 1,
      sym_operator_identifier,
    STATE(4679), 1,
      sym__simple_type,
    STATE(5831), 1,
      sym__soft_identifier,
    STATE(6085), 1,
      sym_identifier,
    STATE(17756), 1,
      sym_stable_identifier,
    STATE(9259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8453), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [450044] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6918), 1,
      sym__alpha_identifier,
    ACTIONS(6924), 1,
      anon_sym__,
    ACTIONS(6932), 1,
      sym__backquoted_id,
    ACTIONS(6934), 1,
      sym_operator_identifier,
    ACTIONS(9941), 1,
      anon_sym_LPAREN,
    STATE(4521), 1,
      sym__simple_type,
    STATE(4637), 1,
      sym_identifier,
    STATE(4714), 1,
      sym__soft_identifier,
    STATE(17341), 1,
      sym_stable_identifier,
    STATE(9260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6928), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5056), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [450099] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450136] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [450173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450210] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [450247] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11958), 1,
      anon_sym_AT,
    STATE(10346), 1,
      sym_annotation,
    STATE(9265), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450288] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4660), 1,
      sym__alpha_identifier,
    ACTIONS(4666), 1,
      anon_sym__,
    ACTIONS(4678), 1,
      sym__backquoted_id,
    ACTIONS(6846), 1,
      sym_operator_identifier,
    ACTIONS(10054), 1,
      anon_sym_LPAREN,
    STATE(4370), 1,
      sym__simple_type,
    STATE(4601), 1,
      sym__soft_identifier,
    STATE(4620), 1,
      sym_identifier,
    STATE(16896), 1,
      sym_stable_identifier,
    STATE(9266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4672), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4757), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [450343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9929), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [450380] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11961), 1,
      sym__alpha_identifier,
    ACTIONS(11963), 1,
      anon_sym__,
    ACTIONS(11967), 1,
      anon_sym_LPAREN,
    ACTIONS(11969), 1,
      sym__backquoted_id,
    ACTIONS(11971), 1,
      sym_operator_identifier,
    STATE(11496), 1,
      sym__simple_type,
    STATE(12057), 1,
      sym_identifier,
    STATE(12212), 1,
      sym__soft_identifier,
    STATE(17846), 1,
      sym_stable_identifier,
    STATE(9268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11965), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12828), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [450435] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450472] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450509] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450620] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [450657] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [450694] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [450768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450805] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450848] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [450885] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9435), 1,
      sym_operator_identifier,
    STATE(1745), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [450938] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [450975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451012] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [451086] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6510), 1,
      anon_sym__,
    ACTIONS(6518), 1,
      sym__backquoted_id,
    ACTIONS(6520), 1,
      sym_operator_identifier,
    ACTIONS(10033), 1,
      anon_sym_LPAREN,
    STATE(6588), 1,
      sym__simple_type,
    STATE(7863), 1,
      sym__soft_identifier,
    STATE(8147), 1,
      sym_identifier,
    STATE(17720), 1,
      sym_stable_identifier,
    STATE(9286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6514), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8933), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [451141] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11975), 1,
      anon_sym__,
    ACTIONS(11977), 1,
      anon_sym_LPAREN,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(11981), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11377), 1,
      sym__simple_type,
    STATE(11744), 1,
      sym_identifier,
    STATE(16848), 1,
      sym_stable_identifier,
    STATE(9287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12244), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [451196] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11983), 1,
      anon_sym_with,
    STATE(9288), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451235] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [451272] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11986), 1,
      anon_sym_with,
    STATE(9290), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451311] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [451348] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11989), 1,
      sym__alpha_identifier,
    ACTIONS(11991), 1,
      anon_sym__,
    ACTIONS(11995), 1,
      anon_sym_LPAREN,
    ACTIONS(11997), 1,
      sym__backquoted_id,
    ACTIONS(11999), 1,
      sym_operator_identifier,
    STATE(12136), 1,
      sym__simple_type,
    STATE(13246), 1,
      sym_identifier,
    STATE(13272), 1,
      sym__soft_identifier,
    STATE(17798), 1,
      sym_stable_identifier,
    STATE(9292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11993), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13642), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [451403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8541), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451440] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451477] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4278), 1,
      sym__alpha_identifier,
    ACTIONS(4284), 1,
      anon_sym__,
    ACTIONS(4296), 1,
      sym__backquoted_id,
    ACTIONS(6994), 1,
      sym_operator_identifier,
    ACTIONS(9856), 1,
      anon_sym_LPAREN,
    STATE(5910), 1,
      sym__simple_type,
    STATE(6872), 1,
      sym_identifier,
    STATE(7385), 1,
      sym__soft_identifier,
    STATE(17176), 1,
      sym_stable_identifier,
    STATE(9295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4290), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8228), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [451532] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12001), 1,
      anon_sym_with,
    STATE(9296), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [451571] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [451608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451645] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4750), 1,
      sym__alpha_identifier,
    ACTIONS(4752), 1,
      anon_sym__,
    ACTIONS(4762), 1,
      sym__backquoted_id,
    ACTIONS(6248), 1,
      sym_operator_identifier,
    ACTIONS(9846), 1,
      anon_sym_LPAREN,
    STATE(4468), 1,
      sym__simple_type,
    STATE(4635), 1,
      sym__soft_identifier,
    STATE(4732), 1,
      sym_identifier,
    STATE(17642), 1,
      sym_stable_identifier,
    STATE(9299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4758), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4869), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [451700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [451737] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451774] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451848] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8411), 1,
      sym__alpha_identifier,
    ACTIONS(8413), 1,
      anon_sym__,
    ACTIONS(8417), 1,
      anon_sym_LPAREN,
    ACTIONS(8419), 1,
      sym__backquoted_id,
    ACTIONS(8421), 1,
      sym_operator_identifier,
    STATE(6411), 1,
      sym__simple_type,
    STATE(8325), 1,
      sym_identifier,
    STATE(8883), 1,
      sym__soft_identifier,
    STATE(16739), 1,
      sym_stable_identifier,
    STATE(9304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8415), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8510), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [451903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [451940] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6754), 1,
      sym__alpha_identifier,
    ACTIONS(6756), 1,
      anon_sym__,
    ACTIONS(6764), 1,
      sym__backquoted_id,
    ACTIONS(6766), 1,
      sym_operator_identifier,
    ACTIONS(9742), 1,
      anon_sym_LPAREN,
    STATE(4633), 1,
      sym__simple_type,
    STATE(4984), 1,
      sym_identifier,
    STATE(4998), 1,
      sym__soft_identifier,
    STATE(17750), 1,
      sym_stable_identifier,
    STATE(9306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6760), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5126), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [451995] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452032] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452106] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452143] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452180] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9321), 1,
      sym__alpha_identifier,
    ACTIONS(9325), 1,
      anon_sym_EQ,
    ACTIONS(9327), 1,
      sym__backquoted_id,
    ACTIONS(9329), 1,
      sym_operator_identifier,
    STATE(585), 1,
      sym_identifier,
    STATE(4157), 1,
      sym__soft_identifier,
    STATE(9312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9323), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [452233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [452270] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6858), 1,
      anon_sym__,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(6868), 1,
      sym_operator_identifier,
    ACTIONS(10177), 1,
      anon_sym_LPAREN,
    STATE(4805), 1,
      sym__simple_type,
    STATE(5096), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(16918), 1,
      sym_stable_identifier,
    STATE(9314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5832), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [452325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452362] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9634), 1,
      sym_operator_identifier,
    STATE(1819), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8309), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [452415] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452452] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452489] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12004), 1,
      sym__alpha_identifier,
    ACTIONS(12006), 1,
      anon_sym__,
    ACTIONS(12010), 1,
      anon_sym_LPAREN,
    ACTIONS(12012), 1,
      sym__backquoted_id,
    ACTIONS(12014), 1,
      sym_operator_identifier,
    STATE(10476), 1,
      sym__simple_type,
    STATE(10937), 1,
      sym__soft_identifier,
    STATE(11042), 1,
      sym_identifier,
    STATE(17714), 1,
      sym_stable_identifier,
    STATE(9319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11268), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [452544] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12018), 1,
      anon_sym__,
    ACTIONS(12022), 1,
      anon_sym_LPAREN,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(12026), 1,
      sym_operator_identifier,
    STATE(11154), 1,
      sym__simple_type,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11511), 1,
      sym_identifier,
    STATE(17977), 1,
      sym_stable_identifier,
    STATE(9320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11976), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [452599] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6202), 1,
      sym__alpha_identifier,
    ACTIONS(6208), 1,
      anon_sym__,
    ACTIONS(6216), 1,
      sym__backquoted_id,
    ACTIONS(6218), 1,
      sym_operator_identifier,
    ACTIONS(10088), 1,
      anon_sym_LPAREN,
    STATE(7517), 1,
      sym__simple_type,
    STATE(9360), 1,
      sym_identifier,
    STATE(9455), 1,
      sym__soft_identifier,
    STATE(17822), 1,
      sym_stable_identifier,
    STATE(9321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6212), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9589), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [452654] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8662), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452691] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12028), 1,
      anon_sym_LPAREN,
    STATE(10319), 1,
      sym_arguments,
    STATE(9323), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452732] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4562), 1,
      sym__alpha_identifier,
    ACTIONS(4568), 1,
      anon_sym__,
    ACTIONS(4580), 1,
      sym__backquoted_id,
    ACTIONS(6770), 1,
      sym_operator_identifier,
    ACTIONS(10094), 1,
      anon_sym_LPAREN,
    STATE(5048), 1,
      sym__simple_type,
    STATE(5571), 1,
      sym_identifier,
    STATE(5868), 1,
      sym__soft_identifier,
    STATE(17678), 1,
      sym_stable_identifier,
    STATE(9324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4574), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6389), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [452787] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452824] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [452861] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9259), 1,
      sym__alpha_identifier,
    ACTIONS(9265), 1,
      sym__backquoted_id,
    ACTIONS(9267), 1,
      sym_operator_identifier,
    ACTIONS(9305), 1,
      anon_sym_EQ,
    STATE(580), 1,
      sym_identifier,
    STATE(4062), 1,
      sym__soft_identifier,
    STATE(9327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 6,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9261), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [452914] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [452951] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6204), 1,
      anon_sym_COLON,
    ACTIONS(6206), 1,
      anon_sym_LBRACE,
    ACTIONS(11895), 1,
      anon_sym_with,
    STATE(10675), 1,
      aux_sym_compound_type_repeat1,
    STATE(11955), 1,
      sym_template_body,
    STATE(11990), 1,
      sym__refinement,
    ACTIONS(7778), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(9329), 2,
      sym_comment,
      sym_block_comment,
    STATE(11933), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7776), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453002] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453039] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9651), 1,
      sym__end_marker,
    STATE(9331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [453078] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9411), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [453115] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9415), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [453152] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453226] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6470), 1,
      anon_sym__,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(6480), 1,
      sym_operator_identifier,
    ACTIONS(9759), 1,
      anon_sym_LPAREN,
    STATE(6882), 1,
      sym__simple_type,
    STATE(8503), 1,
      sym_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(17416), 1,
      sym_stable_identifier,
    STATE(9336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [453281] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [453318] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9894), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [453355] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8333), 1,
      sym__alpha_identifier,
    ACTIONS(8335), 1,
      anon_sym__,
    ACTIONS(8339), 1,
      anon_sym_LPAREN,
    ACTIONS(8341), 1,
      sym__backquoted_id,
    ACTIONS(8343), 1,
      sym_operator_identifier,
    STATE(4625), 1,
      sym__simple_type,
    STATE(5160), 1,
      sym_identifier,
    STATE(5309), 1,
      sym__soft_identifier,
    STATE(17360), 1,
      sym_stable_identifier,
    STATE(9339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8337), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5259), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [453410] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8171), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [453453] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6378), 1,
      sym__alpha_identifier,
    ACTIONS(6384), 1,
      anon_sym__,
    ACTIONS(6392), 1,
      sym__backquoted_id,
    ACTIONS(6394), 1,
      sym_operator_identifier,
    ACTIONS(10353), 1,
      anon_sym_LPAREN,
    STATE(4674), 1,
      sym__simple_type,
    STATE(5211), 1,
      sym__soft_identifier,
    STATE(5401), 1,
      sym_identifier,
    STATE(17882), 1,
      sym_stable_identifier,
    STATE(9341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5762), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [453508] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8359), 1,
      sym__alpha_identifier,
    ACTIONS(8361), 1,
      anon_sym__,
    ACTIONS(8365), 1,
      anon_sym_LPAREN,
    ACTIONS(8367), 1,
      sym__backquoted_id,
    ACTIONS(8369), 1,
      sym_operator_identifier,
    STATE(4830), 1,
      sym__simple_type,
    STATE(6353), 1,
      sym__soft_identifier,
    STATE(6499), 1,
      sym_identifier,
    STATE(16832), 1,
      sym_stable_identifier,
    STATE(9342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8363), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6147), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [453563] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453600] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453637] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7988), 1,
      sym__alpha_identifier,
    ACTIONS(7990), 1,
      anon_sym__,
    ACTIONS(7994), 1,
      anon_sym_LPAREN,
    ACTIONS(7996), 1,
      sym__backquoted_id,
    ACTIONS(7998), 1,
      sym_operator_identifier,
    STATE(5403), 1,
      sym__simple_type,
    STATE(7258), 1,
      sym__soft_identifier,
    STATE(7416), 1,
      sym_identifier,
    STATE(17479), 1,
      sym_stable_identifier,
    STATE(9345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7992), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [453692] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453729] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453766] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [453803] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453840] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453914] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5903), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [453955] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [453992] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9825), 1,
      sym_arguments,
    STATE(9354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454031] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454068] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454142] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454179] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454218] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12031), 1,
      anon_sym_DOT,
    STATE(9360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454257] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454294] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454337] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10845), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [454376] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5885), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [454417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454454] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6058), 1,
      sym__end_marker,
    STATE(9366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454493] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454532] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454575] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454612] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454686] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10355), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [454723] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6884), 1,
      sym__alpha_identifier,
    ACTIONS(6886), 1,
      anon_sym__,
    ACTIONS(6894), 1,
      sym__backquoted_id,
    ACTIONS(6896), 1,
      sym_operator_identifier,
    ACTIONS(10402), 1,
      anon_sym_LPAREN,
    STATE(5223), 1,
      sym__simple_type,
    STATE(6268), 1,
      sym__soft_identifier,
    STATE(6574), 1,
      sym_identifier,
    STATE(16962), 1,
      sym_stable_identifier,
    STATE(9373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6890), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7231), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [454778] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6662), 1,
      sym__alpha_identifier,
    ACTIONS(6664), 1,
      anon_sym__,
    ACTIONS(6672), 1,
      sym__backquoted_id,
    ACTIONS(6674), 1,
      sym_operator_identifier,
    ACTIONS(10037), 1,
      anon_sym_LPAREN,
    STATE(4412), 1,
      sym__simple_type,
    STATE(4616), 1,
      sym_identifier,
    STATE(4632), 1,
      sym__soft_identifier,
    STATE(17744), 1,
      sym_stable_identifier,
    STATE(9374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6668), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4799), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [454833] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454870] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9485), 1,
      sym_operator_identifier,
    STATE(1728), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8309), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [454923] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454960] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [454997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455034] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9419), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [455071] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3312), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(11497), 1,
      anon_sym_LPAREN,
    ACTIONS(12033), 1,
      sym__alpha_identifier,
    ACTIONS(12035), 1,
      anon_sym_DOT,
    ACTIONS(12039), 1,
      sym__backquoted_id,
    ACTIONS(12041), 1,
      sym_operator_identifier,
    STATE(1076), 1,
      sym_identifier,
    STATE(4316), 1,
      sym__soft_identifier,
    ACTIONS(8305), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    STATE(9381), 2,
      sym_comment,
      sym_block_comment,
    STATE(10988), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(12037), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [455132] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9890), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [455169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9726), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [455206] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455243] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12043), 1,
      sym__alpha_identifier,
    ACTIONS(12045), 1,
      anon_sym__,
    ACTIONS(12049), 1,
      anon_sym_LPAREN,
    ACTIONS(12051), 1,
      sym__backquoted_id,
    ACTIONS(12053), 1,
      sym_operator_identifier,
    STATE(10617), 1,
      sym__simple_type,
    STATE(10946), 1,
      sym__soft_identifier,
    STATE(11124), 1,
      sym_identifier,
    STATE(17011), 1,
      sym_stable_identifier,
    STATE(9385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12047), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(11288), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [455298] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12055), 1,
      anon_sym_LPAREN,
    STATE(10097), 1,
      sym_arguments,
    ACTIONS(8114), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(9386), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8112), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455339] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455376] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12060), 1,
      anon_sym__,
    ACTIONS(12064), 1,
      anon_sym_LPAREN,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(12068), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(12506), 1,
      sym__simple_type,
    STATE(13432), 1,
      sym_identifier,
    STATE(17557), 1,
      sym_stable_identifier,
    STATE(9388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13945), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [455431] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6872), 1,
      anon_sym__,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(6882), 1,
      sym_operator_identifier,
    ACTIONS(10317), 1,
      anon_sym_LPAREN,
    STATE(5888), 1,
      sym__simple_type,
    STATE(6809), 1,
      sym_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(16940), 1,
      sym_stable_identifier,
    STATE(9389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7939), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [455486] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455523] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8199), 1,
      sym__alpha_identifier,
    ACTIONS(8201), 1,
      anon_sym__,
    ACTIONS(8205), 1,
      anon_sym_LPAREN,
    ACTIONS(8207), 1,
      sym__backquoted_id,
    ACTIONS(8209), 1,
      sym_operator_identifier,
    STATE(5210), 1,
      sym__simple_type,
    STATE(6795), 1,
      sym_identifier,
    STATE(7174), 1,
      sym__soft_identifier,
    STATE(17684), 1,
      sym_stable_identifier,
    STATE(9391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8203), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6972), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [455578] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455615] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455652] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9709), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [455689] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455726] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455763] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455800] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8018), 1,
      sym__alpha_identifier,
    ACTIONS(8020), 1,
      anon_sym__,
    ACTIONS(8024), 1,
      anon_sym_LPAREN,
    ACTIONS(8026), 1,
      sym__backquoted_id,
    ACTIONS(8028), 1,
      sym_operator_identifier,
    STATE(5214), 1,
      sym__simple_type,
    STATE(7330), 1,
      sym__soft_identifier,
    STATE(7418), 1,
      sym_identifier,
    STATE(17155), 1,
      sym_stable_identifier,
    STATE(9398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6915), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [455855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [455966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [456040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [456077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456114] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12070), 1,
      sym__alpha_identifier,
    ACTIONS(12072), 1,
      anon_sym__,
    ACTIONS(12076), 1,
      anon_sym_LPAREN,
    ACTIONS(12078), 1,
      sym__backquoted_id,
    ACTIONS(12080), 1,
      sym_operator_identifier,
    STATE(11338), 1,
      sym__simple_type,
    STATE(11779), 1,
      sym_identifier,
    STATE(11859), 1,
      sym__soft_identifier,
    STATE(17768), 1,
      sym_stable_identifier,
    STATE(9406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12074), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12109), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [456169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456206] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4246), 1,
      sym__alpha_identifier,
    ACTIONS(4252), 1,
      anon_sym__,
    ACTIONS(4264), 1,
      sym__backquoted_id,
    ACTIONS(6744), 1,
      sym_operator_identifier,
    ACTIONS(10411), 1,
      anon_sym_LPAREN,
    STATE(4718), 1,
      sym__simple_type,
    STATE(5208), 1,
      sym__soft_identifier,
    STATE(5307), 1,
      sym_identifier,
    STATE(17894), 1,
      sym_stable_identifier,
    STATE(9408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4258), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5976), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [456261] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456298] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9779), 1,
      sym__end_marker,
    STATE(9410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456337] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [456374] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9335), 1,
      anon_sym_with,
    ACTIONS(11837), 1,
      anon_sym_LBRACE,
    STATE(8977), 1,
      aux_sym_compound_type_repeat1,
    STATE(11419), 1,
      sym_template_body,
    STATE(11522), 1,
      sym__refinement,
    STATE(9412), 2,
      sym_comment,
      sym_block_comment,
    STATE(11645), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456423] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [456460] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12082), 1,
      anon_sym_with,
    STATE(9414), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456499] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456536] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7916), 1,
      sym__alpha_identifier,
    ACTIONS(7922), 1,
      anon_sym__,
    ACTIONS(7926), 1,
      anon_sym_LPAREN,
    ACTIONS(7928), 1,
      sym__backquoted_id,
    ACTIONS(7930), 1,
      sym_operator_identifier,
    STATE(11281), 1,
      sym__simple_type,
    STATE(11727), 1,
      sym__soft_identifier,
    STATE(11847), 1,
      sym_identifier,
    STATE(17453), 1,
      sym_stable_identifier,
    STATE(9416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7924), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12322), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [456591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [456628] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4390), 1,
      sym__alpha_identifier,
    ACTIONS(4396), 1,
      anon_sym__,
    ACTIONS(4408), 1,
      sym__backquoted_id,
    ACTIONS(6692), 1,
      sym_operator_identifier,
    ACTIONS(9905), 1,
      anon_sym_LPAREN,
    STATE(5590), 1,
      sym__simple_type,
    STATE(7208), 1,
      sym__soft_identifier,
    STATE(7259), 1,
      sym_identifier,
    STATE(17606), 1,
      sym_stable_identifier,
    STATE(9418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4402), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8276), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [456683] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6542), 1,
      sym__alpha_identifier,
    ACTIONS(6548), 1,
      anon_sym__,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(6558), 1,
      sym_operator_identifier,
    ACTIONS(10361), 1,
      anon_sym_LPAREN,
    STATE(5074), 1,
      sym__simple_type,
    STATE(5780), 1,
      sym__soft_identifier,
    STATE(5982), 1,
      sym_identifier,
    STATE(17900), 1,
      sym_stable_identifier,
    STATE(9419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6174), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [456738] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8517), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456775] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456812] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12085), 1,
      anon_sym_with,
    STATE(9422), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456851] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5122), 1,
      anon_sym__,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(5134), 1,
      sym_operator_identifier,
    ACTIONS(10060), 1,
      anon_sym_LPAREN,
    STATE(6688), 1,
      sym__simple_type,
    STATE(7753), 1,
      sym_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(17050), 1,
      sym_stable_identifier,
    STATE(9423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8290), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [456906] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [456943] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(9425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [456982] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457019] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(9622), 1,
      sym_operator_identifier,
    STATE(608), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    STATE(9427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8305), 4,
      anon_sym_COLON,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9616), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [457074] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457148] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457185] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457222] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__alpha_identifier,
    ACTIONS(4468), 1,
      anon_sym__,
    ACTIONS(4480), 1,
      sym__backquoted_id,
    ACTIONS(6748), 1,
      sym_operator_identifier,
    ACTIONS(10005), 1,
      anon_sym_LPAREN,
    STATE(4667), 1,
      sym__simple_type,
    STATE(5231), 1,
      sym_identifier,
    STATE(5328), 1,
      sym__soft_identifier,
    STATE(17379), 1,
      sym_stable_identifier,
    STATE(9432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6029), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [457277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457314] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [457388] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457425] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12088), 1,
      sym__alpha_identifier,
    ACTIONS(12090), 1,
      anon_sym__,
    ACTIONS(12094), 1,
      anon_sym_LPAREN,
    ACTIONS(12096), 1,
      sym__backquoted_id,
    ACTIONS(12098), 1,
      sym_operator_identifier,
    STATE(12051), 1,
      sym__simple_type,
    STATE(12528), 1,
      sym__soft_identifier,
    STATE(12686), 1,
      sym_identifier,
    STATE(17436), 1,
      sym_stable_identifier,
    STATE(9437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12092), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13077), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [457480] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [457517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457554] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457628] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [457665] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457702] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8287), 1,
      sym__alpha_identifier,
    ACTIONS(8293), 1,
      anon_sym__,
    ACTIONS(8297), 1,
      anon_sym_LPAREN,
    ACTIONS(8299), 1,
      sym__backquoted_id,
    ACTIONS(8301), 1,
      sym_operator_identifier,
    STATE(4451), 1,
      sym__simple_type,
    STATE(4930), 1,
      sym__soft_identifier,
    STATE(4943), 1,
      sym_identifier,
    STATE(17738), 1,
      sym_stable_identifier,
    STATE(9444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8295), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5066), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [457757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457794] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [457831] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457868] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8423), 1,
      sym__alpha_identifier,
    ACTIONS(8425), 1,
      anon_sym__,
    ACTIONS(8429), 1,
      anon_sym_LPAREN,
    ACTIONS(8431), 1,
      sym__backquoted_id,
    ACTIONS(8433), 1,
      sym_operator_identifier,
    STATE(5374), 1,
      sym__simple_type,
    STATE(7063), 1,
      sym_identifier,
    STATE(7297), 1,
      sym__soft_identifier,
    STATE(17398), 1,
      sym_stable_identifier,
    STATE(9448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8427), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7460), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [457923] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12100), 1,
      anon_sym_AT,
    STATE(10357), 1,
      sym_annotation,
    STATE(9449), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [457964] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12103), 1,
      anon_sym_with,
    STATE(9450), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458003] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10253), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [458040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [458114] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [458151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 6,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458188] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6012), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [458303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458340] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458414] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4342), 1,
      sym__alpha_identifier,
    ACTIONS(4344), 1,
      anon_sym__,
    ACTIONS(4354), 1,
      sym__backquoted_id,
    ACTIONS(6938), 1,
      sym_operator_identifier,
    ACTIONS(10035), 1,
      anon_sym_LPAREN,
    STATE(6601), 1,
      sym__simple_type,
    STATE(7539), 1,
      sym__soft_identifier,
    STATE(7904), 1,
      sym_identifier,
    STATE(17364), 1,
      sym_stable_identifier,
    STATE(9462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4350), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8693), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [458469] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [458506] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458543] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3312), 1,
      anon_sym_LBRACE,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(11497), 1,
      anon_sym_LPAREN,
    ACTIONS(12035), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8173), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(9465), 2,
      sym_comment,
      sym_block_comment,
    STATE(10988), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8171), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458594] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12106), 1,
      sym__alpha_identifier,
    ACTIONS(12108), 1,
      anon_sym__,
    ACTIONS(12112), 1,
      anon_sym_LPAREN,
    ACTIONS(12114), 1,
      sym__backquoted_id,
    ACTIONS(12116), 1,
      sym_operator_identifier,
    STATE(12100), 1,
      sym__simple_type,
    STATE(13264), 1,
      sym__soft_identifier,
    STATE(13321), 1,
      sym_identifier,
    STATE(17780), 1,
      sym_stable_identifier,
    STATE(9466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12110), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13446), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [458649] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10220), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [458686] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9792), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [458723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458760] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8056), 1,
      anon_sym__,
    ACTIONS(8060), 1,
      anon_sym_LPAREN,
    ACTIONS(8062), 1,
      sym__backquoted_id,
    ACTIONS(8064), 1,
      sym_operator_identifier,
    STATE(7489), 1,
      sym__simple_type,
    STATE(8995), 1,
      sym_identifier,
    STATE(9392), 1,
      sym__soft_identifier,
    STATE(17942), 1,
      sym_stable_identifier,
    STATE(9470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8058), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9053), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [458815] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7956), 1,
      sym__alpha_identifier,
    ACTIONS(7962), 1,
      anon_sym__,
    ACTIONS(7966), 1,
      anon_sym_LPAREN,
    ACTIONS(7968), 1,
      sym__backquoted_id,
    ACTIONS(7970), 1,
      sym_operator_identifier,
    STATE(12737), 1,
      sym__simple_type,
    STATE(13475), 1,
      sym_identifier,
    STATE(13521), 1,
      sym__soft_identifier,
    STATE(17306), 1,
      sym_stable_identifier,
    STATE(9471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7964), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13929), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [458870] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12118), 1,
      sym__alpha_identifier,
    ACTIONS(12120), 1,
      anon_sym__,
    ACTIONS(12124), 1,
      anon_sym_LPAREN,
    ACTIONS(12126), 1,
      sym__backquoted_id,
    ACTIONS(12128), 1,
      sym_operator_identifier,
    STATE(12293), 1,
      sym__simple_type,
    STATE(13107), 1,
      sym_identifier,
    STATE(13294), 1,
      sym__soft_identifier,
    STATE(17858), 1,
      sym_stable_identifier,
    STATE(9472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12122), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13481), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [458925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [458962] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(9335), 1,
      anon_sym_with,
    ACTIONS(11837), 1,
      anon_sym_LBRACE,
    ACTIONS(12130), 1,
      anon_sym_COLON,
    STATE(8977), 1,
      aux_sym_compound_type_repeat1,
    STATE(11419), 1,
      sym_template_body,
    STATE(11522), 1,
      sym__refinement,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9474), 2,
      sym_comment,
      sym_block_comment,
    STATE(11645), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 17,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459091] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4692), 1,
      sym__alpha_identifier,
    ACTIONS(4694), 1,
      anon_sym__,
    ACTIONS(4704), 1,
      sym__backquoted_id,
    ACTIONS(6358), 1,
      sym_operator_identifier,
    ACTIONS(10185), 1,
      anon_sym_LPAREN,
    STATE(4423), 1,
      sym__simple_type,
    STATE(4547), 1,
      sym__soft_identifier,
    STATE(4621), 1,
      sym_identifier,
    STATE(17816), 1,
      sym_stable_identifier,
    STATE(9477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4739), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [459146] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12133), 1,
      anon_sym_AT,
    STATE(10323), 1,
      sym_annotation,
    STATE(9478), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8601), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459261] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9321), 1,
      sym__alpha_identifier,
    ACTIONS(9327), 1,
      sym__backquoted_id,
    ACTIONS(9329), 1,
      sym_operator_identifier,
    STATE(585), 1,
      sym_identifier,
    STATE(4157), 1,
      sym__soft_identifier,
    STATE(9481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9323), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [459312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [459349] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459386] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459423] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7464), 1,
      anon_sym__,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7786), 1,
      anon_sym_LPAREN,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(7790), 1,
      sym_operator_identifier,
    STATE(12964), 1,
      sym__simple_type,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(13950), 1,
      sym_identifier,
    STATE(18518), 1,
      sym_stable_identifier,
    STATE(9485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(14192), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [459478] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9643), 1,
      sym_arguments,
    STATE(9486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [459554] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9082), 1,
      sym_operator_identifier,
    STATE(1740), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8309), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [459605] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9321), 1,
      sym__alpha_identifier,
    ACTIONS(9327), 1,
      sym__backquoted_id,
    ACTIONS(9329), 1,
      sym_operator_identifier,
    ACTIONS(9646), 1,
      anon_sym_EQ,
    STATE(585), 1,
      sym_identifier,
    STATE(4157), 1,
      sym__soft_identifier,
    STATE(9489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9323), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [459658] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8393), 1,
      sym__alpha_identifier,
    ACTIONS(8395), 1,
      anon_sym__,
    ACTIONS(8399), 1,
      anon_sym_LPAREN,
    ACTIONS(8401), 1,
      sym__backquoted_id,
    ACTIONS(8403), 1,
      sym_operator_identifier,
    STATE(5677), 1,
      sym__simple_type,
    STATE(7599), 1,
      sym__soft_identifier,
    STATE(7844), 1,
      sym_identifier,
    STATE(16788), 1,
      sym_stable_identifier,
    STATE(9490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8397), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7617), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [459713] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10968), 1,
      anon_sym_LPAREN,
    STATE(9386), 1,
      aux_sym_annotation_repeat1,
    STATE(10097), 1,
      sym_arguments,
    ACTIONS(8123), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(9491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8121), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459756] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12136), 1,
      anon_sym_with,
    STATE(9492), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459795] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459832] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459869] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [459906] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459943] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [459980] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460017] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8527), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [460091] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7750), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [460128] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [460165] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460202] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11234), 1,
      anon_sym_AT,
    STATE(9449), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10357), 1,
      sym_annotation,
    STATE(9504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8485), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460245] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [460282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [460319] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460356] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [460393] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6018), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460434] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460508] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12139), 1,
      anon_sym_AT,
    STATE(10260), 1,
      sym_annotation,
    STATE(9512), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460549] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6566), 1,
      anon_sym__,
    ACTIONS(6574), 1,
      sym__backquoted_id,
    ACTIONS(6576), 1,
      sym_operator_identifier,
    ACTIONS(10086), 1,
      anon_sym_LPAREN,
    STATE(4917), 1,
      sym__simple_type,
    STATE(5717), 1,
      sym_identifier,
    STATE(6060), 1,
      sym__soft_identifier,
    STATE(17417), 1,
      sym_stable_identifier,
    STATE(9513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6570), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6110), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [460604] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [460678] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460715] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12142), 1,
      sym__alpha_identifier,
    ACTIONS(12144), 1,
      anon_sym__,
    ACTIONS(12148), 1,
      anon_sym_LPAREN,
    ACTIONS(12150), 1,
      sym__backquoted_id,
    ACTIONS(12152), 1,
      sym_operator_identifier,
    STATE(11964), 1,
      sym__simple_type,
    STATE(12655), 1,
      sym__soft_identifier,
    STATE(12780), 1,
      sym_identifier,
    STATE(17696), 1,
      sym_stable_identifier,
    STATE(9517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12146), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13377), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [460770] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9752), 1,
      sym__end_marker,
    STATE(9518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [460809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [460846] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6584), 1,
      anon_sym__,
    ACTIONS(6592), 1,
      sym__backquoted_id,
    ACTIONS(6594), 1,
      sym_operator_identifier,
    ACTIONS(10092), 1,
      anon_sym_LPAREN,
    STATE(5459), 1,
      sym__simple_type,
    STATE(6385), 1,
      sym__soft_identifier,
    STATE(6582), 1,
      sym_identifier,
    STATE(17792), 1,
      sym_stable_identifier,
    STATE(9520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6588), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7364), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [460901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460938] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [460975] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7850), 1,
      sym__alpha_identifier,
    ACTIONS(7856), 1,
      anon_sym__,
    ACTIONS(7860), 1,
      anon_sym_LPAREN,
    ACTIONS(7862), 1,
      sym__backquoted_id,
    ACTIONS(7864), 1,
      sym_operator_identifier,
    STATE(12027), 1,
      sym__simple_type,
    STATE(12550), 1,
      sym_identifier,
    STATE(12664), 1,
      sym__soft_identifier,
    STATE(17732), 1,
      sym_stable_identifier,
    STATE(9523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13328), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [461030] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461067] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6528), 1,
      sym__alpha_identifier,
    ACTIONS(6530), 1,
      anon_sym__,
    ACTIONS(6538), 1,
      sym__backquoted_id,
    ACTIONS(6540), 1,
      sym_operator_identifier,
    ACTIONS(10135), 1,
      anon_sym_LPAREN,
    STATE(6612), 1,
      sym__simple_type,
    STATE(7921), 1,
      sym_identifier,
    STATE(7952), 1,
      sym__soft_identifier,
    STATE(17028), 1,
      sym_stable_identifier,
    STATE(9525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6534), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(8432), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [461122] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461159] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12154), 1,
      anon_sym_with,
    STATE(9527), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461198] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(7810), 1,
      anon_sym__,
    ACTIONS(7812), 1,
      anon_sym_LPAREN,
    ACTIONS(7814), 1,
      sym_operator_identifier,
    STATE(11771), 1,
      sym__simple_type,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12944), 1,
      sym_identifier,
    STATE(17617), 1,
      sym_stable_identifier,
    STATE(9528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(13249), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [461253] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10226), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [461290] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461364] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6061), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461405] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11691), 1,
      anon_sym_EQ_GT,
    STATE(9533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461444] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4712), 1,
      sym__alpha_identifier,
    ACTIONS(4718), 1,
      anon_sym__,
    ACTIONS(4730), 1,
      sym__backquoted_id,
    ACTIONS(6960), 1,
      sym_operator_identifier,
    ACTIONS(9927), 1,
      anon_sym_LPAREN,
    STATE(5191), 1,
      sym__simple_type,
    STATE(6328), 1,
      sym__soft_identifier,
    STATE(6619), 1,
      sym_identifier,
    STATE(17134), 1,
      sym_stable_identifier,
    STATE(9534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4724), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7010), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [461499] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4422), 1,
      sym__alpha_identifier,
    ACTIONS(4428), 1,
      anon_sym__,
    ACTIONS(4440), 1,
      sym__backquoted_id,
    ACTIONS(6200), 1,
      sym_operator_identifier,
    ACTIONS(10179), 1,
      anon_sym_LPAREN,
    STATE(5425), 1,
      sym__simple_type,
    STATE(6343), 1,
      sym_identifier,
    STATE(6399), 1,
      sym__soft_identifier,
    STATE(17810), 1,
      sym_stable_identifier,
    STATE(9535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4434), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(7419), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [461554] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8179), 1,
      sym__alpha_identifier,
    ACTIONS(8181), 1,
      anon_sym__,
    ACTIONS(8185), 1,
      anon_sym_LPAREN,
    ACTIONS(8187), 1,
      sym__backquoted_id,
    ACTIONS(8189), 1,
      sym_operator_identifier,
    STATE(4867), 1,
      sym__simple_type,
    STATE(6155), 1,
      sym_identifier,
    STATE(6730), 1,
      sym__soft_identifier,
    STATE(17113), 1,
      sym_stable_identifier,
    STATE(9536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8183), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6531), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [461609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461646] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10242), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [461683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461720] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461757] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6796), 1,
      anon_sym__,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(6806), 1,
      sym_operator_identifier,
    ACTIONS(10323), 1,
      anon_sym_LPAREN,
    STATE(5037), 1,
      sym__simple_type,
    STATE(5755), 1,
      sym_identifier,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(16984), 1,
      sym_stable_identifier,
    STATE(9541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6140), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [461812] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6426), 1,
      anon_sym__,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(6436), 1,
      sym_operator_identifier,
    ACTIONS(10330), 1,
      anon_sym_LPAREN,
    STATE(4611), 1,
      sym__simple_type,
    STATE(4977), 1,
      sym_identifier,
    STATE(5072), 1,
      sym__soft_identifier,
    STATE(17635), 1,
      sym_stable_identifier,
    STATE(9542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(5463), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [461867] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461904] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [461941] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [461978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462052] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462089] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(11176), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(16094), 1,
      sym__interpolated_string_start,
    STATE(9549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11174), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462144] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6003), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462185] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462222] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462296] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12159), 1,
      anon_sym__,
    ACTIONS(12163), 1,
      anon_sym_LPAREN,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(12167), 1,
      sym_operator_identifier,
    STATE(11235), 1,
      sym__simple_type,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(11774), 1,
      sym_identifier,
    STATE(17466), 1,
      sym_stable_identifier,
    STATE(9554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(12228), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [462351] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462388] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10299), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [462425] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4624), 1,
      sym__alpha_identifier,
    ACTIONS(4630), 1,
      anon_sym__,
    ACTIONS(4642), 1,
      sym__backquoted_id,
    ACTIONS(6630), 1,
      sym_operator_identifier,
    ACTIONS(9965), 1,
      anon_sym_LPAREN,
    STATE(4336), 1,
      sym__simple_type,
    STATE(4445), 1,
      sym__soft_identifier,
    STATE(4449), 1,
      sym_identifier,
    STATE(17628), 1,
      sym_stable_identifier,
    STATE(9557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(4542), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [462480] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462517] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9471), 1,
      sym__alpha_identifier,
    ACTIONS(9475), 1,
      anon_sym_EQ,
    ACTIONS(9477), 1,
      sym__backquoted_id,
    ACTIONS(9479), 1,
      sym_operator_identifier,
    STATE(584), 1,
      sym_identifier,
    STATE(4160), 1,
      sym__soft_identifier,
    STATE(9559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9473), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [462570] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462607] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10295), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [462644] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462681] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462718] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9140), 1,
      sym_operator_identifier,
    STATE(1813), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 6,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [462769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462880] = 19,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    ACTIONS(12169), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(16094), 1,
      sym__interpolated_string_start,
    ACTIONS(11196), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    STATE(9568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [462945] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [462982] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 1,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(12171), 1,
      anon_sym_EQ_GT,
    ACTIONS(12174), 1,
      sym__interpolated_multiline_string_start,
    STATE(10907), 1,
      sym_interpolated_string,
    STATE(16230), 1,
      sym__interpolated_string_start,
    STATE(9570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463031] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463068] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 6,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463148] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3312), 1,
      anon_sym_LBRACE,
    ACTIONS(11497), 1,
      anon_sym_LPAREN,
    ACTIONS(12035), 1,
      anon_sym_DOT,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8193), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(9574), 2,
      sym_comment,
      sym_block_comment,
    STATE(10988), 3,
      sym_block,
      sym_case_block,
      sym_arguments,
    ACTIONS(8191), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463234] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7974), 1,
      anon_sym_DQUOTE,
    ACTIONS(11145), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11435), 1,
      sym__interpolated_multiline_string_start,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(12164), 1,
      sym_interpolated_string,
    STATE(16094), 1,
      sym__interpolated_string_start,
    STATE(9576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11143), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [463326] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463363] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5760), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463404] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8529), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463478] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463515] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6302), 1,
      anon_sym__,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(6312), 1,
      sym_operator_identifier,
    ACTIONS(10215), 1,
      anon_sym_LPAREN,
    STATE(7107), 1,
      sym__simple_type,
    STATE(8692), 1,
      sym_identifier,
    STATE(8795), 1,
      sym__soft_identifier,
    STATE(17006), 1,
      sym_stable_identifier,
    STATE(9583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(9537), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [463570] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6268), 1,
      sym__alpha_identifier,
    ACTIONS(6274), 1,
      anon_sym__,
    ACTIONS(6282), 1,
      sym__backquoted_id,
    ACTIONS(6284), 1,
      sym_operator_identifier,
    ACTIONS(10080), 1,
      anon_sym_LPAREN,
    STATE(5069), 1,
      sym__simple_type,
    STATE(5695), 1,
      sym_identifier,
    STATE(5862), 1,
      sym__soft_identifier,
    STATE(17690), 1,
      sym_stable_identifier,
    STATE(9584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6278), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6225), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [463625] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4774), 1,
      sym__alpha_identifier,
    ACTIONS(4780), 1,
      anon_sym__,
    ACTIONS(4792), 1,
      sym__backquoted_id,
    ACTIONS(6398), 1,
      sym_operator_identifier,
    ACTIONS(10328), 1,
      anon_sym_LPAREN,
    STATE(4819), 1,
      sym__simple_type,
    STATE(5800), 1,
      sym__soft_identifier,
    STATE(5818), 1,
      sym_identifier,
    STATE(17804), 1,
      sym_stable_identifier,
    STATE(9585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4786), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    STATE(6677), 7,
      sym_tuple_type,
      sym_singleton_type,
      sym_stable_type_identifier,
      sym_generic_type,
      sym_projected_type,
      sym__type_identifier,
      sym_wildcard,
  [463680] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463717] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10286), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [463754] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5921), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463794] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463830] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9634), 1,
      sym_operator_identifier,
    STATE(1819), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8309), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [463880] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [463916] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463952] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [463988] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464024] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464060] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1164), 1,
      sym__alpha_identifier,
    ACTIONS(1186), 1,
      sym__backquoted_id,
    ACTIONS(12178), 1,
      sym_operator_identifier,
    STATE(5247), 1,
      sym__soft_identifier,
    STATE(7804), 1,
      sym_identifier,
    STATE(9596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1174), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12176), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [464106] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12182), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(12180), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [464142] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464214] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1092), 1,
      sym__alpha_identifier,
    ACTIONS(1114), 1,
      sym__backquoted_id,
    ACTIONS(12186), 1,
      sym_operator_identifier,
    STATE(5026), 1,
      sym__soft_identifier,
    STATE(6885), 1,
      sym_identifier,
    STATE(9600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1102), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12184), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [464260] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464296] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464332] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464368] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464404] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464440] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464476] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12188), 1,
      anon_sym_with,
    STATE(9607), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464514] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464550] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12191), 1,
      anon_sym_with,
    STATE(9609), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464588] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464624] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12196), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(12194), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [464660] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464732] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464804] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464840] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464876] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464948] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [464984] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465092] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [465128] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465164] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465200] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(4176), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [465236] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465272] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [465308] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [465344] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [465380] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465416] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465458] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10201), 1,
      sym__end_marker,
    STATE(9634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [465496] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465568] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5758), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465644] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12198), 1,
      anon_sym_with,
    STATE(9639), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465682] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465718] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7334), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465754] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465790] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465826] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [465862] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [465898] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [465934] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(7880), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [465976] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466012] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466084] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [466120] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466156] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [466192] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10270), 1,
      sym__end_marker,
    STATE(9654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [466230] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [466266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466302] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [466338] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [466374] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [466410] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466452] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12203), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(12201), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [466488] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [466560] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466596] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [466632] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466668] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [466704] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466740] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [466776] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9337), 1,
      sym__alpha_identifier,
    ACTIONS(9343), 1,
      sym__backquoted_id,
    ACTIONS(9345), 1,
      sym_operator_identifier,
    ACTIONS(10026), 1,
      anon_sym_EQ,
    STATE(581), 1,
      sym_identifier,
    STATE(4080), 1,
      sym__soft_identifier,
    STATE(9670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9339), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [466828] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12207), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(12205), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [466864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466900] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466936] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [466972] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467008] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8689), 2,
      anon_sym_LPAREN,
      sym__backquoted_id,
    STATE(9677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8687), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467080] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12209), 1,
      anon_sym_with,
    STATE(9678), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467118] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10988), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467156] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467228] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467264] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [467300] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467336] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467372] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467408] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467444] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467480] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467516] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467552] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467588] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4178), 1,
      sym__backquoted_id,
    STATE(9692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(4176), 7,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(4174), 8,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467628] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467664] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467772] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467808] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467844] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [467880] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467922] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467958] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [467994] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12212), 1,
      anon_sym_with,
    STATE(9703), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468032] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468068] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468104] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11735), 1,
      anon_sym_LPAREN,
    STATE(9729), 1,
      aux_sym_annotation_repeat1,
    STATE(10545), 1,
      sym_arguments,
    STATE(9706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 4,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8121), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468146] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468182] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10553), 1,
      sym__alpha_identifier,
    ACTIONS(10559), 1,
      sym__backquoted_id,
    ACTIONS(10561), 1,
      sym_operator_identifier,
    STATE(596), 1,
      sym_identifier,
    STATE(4182), 1,
      sym__soft_identifier,
    STATE(9708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(9022), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10555), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [468232] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468268] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [468304] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [468340] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11285), 1,
      anon_sym_LPAREN,
    STATE(9720), 1,
      aux_sym_annotation_repeat1,
    STATE(10621), 1,
      sym_arguments,
    STATE(9712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(8121), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468382] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468418] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468454] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [468490] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_LT_DASH,
  [468526] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8638), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468562] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [468634] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12215), 1,
      anon_sym_LPAREN,
    STATE(10621), 1,
      sym_arguments,
    ACTIONS(8114), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(9720), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8112), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468674] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [468710] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(9622), 1,
      sym_operator_identifier,
    STATE(608), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    STATE(9722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8305), 4,
      anon_sym_COLON,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9616), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [468762] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468834] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8696), 2,
      anon_sym_LPAREN,
      sym__backquoted_id,
    STATE(9725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8694), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468870] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468906] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [468942] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [468978] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12218), 1,
      anon_sym_LPAREN,
    STATE(10545), 1,
      sym_arguments,
    STATE(9729), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 4,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8112), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469018] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10100), 1,
      sym_arguments,
    STATE(9730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469092] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [469128] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469164] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11635), 1,
      anon_sym_COLON,
    ACTIONS(11639), 1,
      anon_sym_with,
    STATE(10500), 1,
      aux_sym_compound_type_repeat1,
    STATE(11254), 1,
      sym_template_body,
    STATE(11273), 1,
      sym__refinement,
    ACTIONS(7778), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(9734), 2,
      sym_comment,
      sym_block_comment,
    STATE(11233), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7776), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469212] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [469248] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469284] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469320] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469356] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469392] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469428] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9709), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469464] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11289), 1,
      anon_sym_AT,
    STATE(9884), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10551), 1,
      sym_annotation,
    STATE(9742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8485), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469506] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469548] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469584] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8531), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469620] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469656] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_EQ,
    ACTIONS(11635), 1,
      anon_sym_COLON,
    ACTIONS(11639), 1,
      anon_sym_with,
    ACTIONS(12221), 1,
      anon_sym_LBRACE,
    STATE(9734), 1,
      aux_sym_compound_type_repeat1,
    STATE(11254), 1,
      sym_template_body,
    STATE(11256), 1,
      sym__refinement,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9747), 2,
      sym_comment,
      sym_block_comment,
    STATE(11233), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469710] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [469746] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12224), 1,
      anon_sym_with,
    STATE(9749), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469784] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5846), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469824] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [469860] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [469896] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10470), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [469934] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1814), 1,
      sym__alpha_identifier,
    ACTIONS(1836), 1,
      sym__backquoted_id,
    ACTIONS(12229), 1,
      sym_operator_identifier,
    STATE(4680), 1,
      sym__soft_identifier,
    STATE(6332), 1,
      sym_identifier,
    STATE(9754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1824), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12227), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [469980] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [470016] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470052] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470088] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12231), 1,
      anon_sym_AT,
    STATE(10533), 1,
      sym_annotation,
    STATE(9758), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470128] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9485), 1,
      sym_operator_identifier,
    STATE(1728), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8309), 6,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [470178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [470214] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [470250] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10616), 1,
      anon_sym_AT,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(9762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11145), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11143), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [470296] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470332] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12234), 1,
      anon_sym_AT,
    STATE(10419), 1,
      sym_annotation,
    STATE(9764), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8601), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470372] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [470408] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10253), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [470444] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470480] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5685), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10122), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [470520] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470556] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470592] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470628] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [470664] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(7062), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [470700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [470772] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470808] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(7574), 1,
      sym_operator_identifier,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(7006), 1,
      sym_identifier,
    STATE(9777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(7570), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [470854] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470890] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [470926] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(9622), 1,
      sym_operator_identifier,
    STATE(608), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    STATE(9780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [470976] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [471012] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471084] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1974), 1,
      sym__alpha_identifier,
    ACTIONS(1996), 1,
      sym__backquoted_id,
    ACTIONS(12239), 1,
      sym_operator_identifier,
    STATE(6575), 1,
      sym__soft_identifier,
    STATE(9109), 1,
      sym_identifier,
    STATE(9784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1984), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12237), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [471130] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [471166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [471202] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471238] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [471274] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9810), 1,
      sym__alpha_identifier,
    ACTIONS(9816), 1,
      sym__backquoted_id,
    ACTIONS(9818), 1,
      sym_operator_identifier,
    ACTIONS(10181), 1,
      anon_sym_EQ,
    STATE(592), 1,
      sym_identifier,
    STATE(4173), 1,
      sym__soft_identifier,
    STATE(9789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9812), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [471326] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [471362] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9810), 1,
      sym__alpha_identifier,
    ACTIONS(9816), 1,
      sym__backquoted_id,
    ACTIONS(9818), 1,
      sym_operator_identifier,
    STATE(592), 1,
      sym_identifier,
    STATE(4173), 1,
      sym__soft_identifier,
    STATE(9791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9812), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [471412] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1424), 1,
      sym__alpha_identifier,
    ACTIONS(1446), 1,
      sym__backquoted_id,
    ACTIONS(12243), 1,
      sym_operator_identifier,
    STATE(5939), 1,
      sym__soft_identifier,
    STATE(8618), 1,
      sym_identifier,
    STATE(9792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1434), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12241), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [471458] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471494] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9810), 1,
      sym__alpha_identifier,
    ACTIONS(9814), 1,
      anon_sym_EQ,
    ACTIONS(9816), 1,
      sym__backquoted_id,
    ACTIONS(9818), 1,
      sym_operator_identifier,
    STATE(592), 1,
      sym_identifier,
    STATE(4173), 1,
      sym__soft_identifier,
    STATE(9794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9812), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [471546] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [471582] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11194), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(9796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11196), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [471640] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [471676] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471712] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471748] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7334), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [471784] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471820] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [471856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [471892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471928] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [471966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472002] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9836), 1,
      sym__alpha_identifier,
    ACTIONS(9840), 1,
      anon_sym_EQ,
    ACTIONS(9842), 1,
      sym__backquoted_id,
    ACTIONS(9844), 1,
      sym_operator_identifier,
    STATE(582), 1,
      sym_identifier,
    STATE(4162), 1,
      sym__soft_identifier,
    STATE(9807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9838), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [472054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472090] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472126] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1568), 1,
      sym__alpha_identifier,
    ACTIONS(1590), 1,
      sym__backquoted_id,
    ACTIONS(12247), 1,
      sym_operator_identifier,
    STATE(5783), 1,
      sym__soft_identifier,
    STATE(8319), 1,
      sym_identifier,
    STATE(9810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1578), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12245), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [472172] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [472208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472244] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9435), 1,
      sym_operator_identifier,
    STATE(1745), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [472294] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10616), 1,
      anon_sym_AT,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(9814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11176), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11174), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [472340] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472376] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472412] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [472448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472484] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472520] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472556] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [472592] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 5,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472628] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472664] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472772] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472814] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [472850] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472886] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472922] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472958] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [472994] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10175), 1,
      sym__end_marker,
    STATE(9833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473032] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473068] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473104] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [473140] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8435), 2,
      anon_sym_LPAREN,
      sym__backquoted_id,
    STATE(9837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8767), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473176] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9858), 1,
      sym__alpha_identifier,
    ACTIONS(9862), 1,
      anon_sym_EQ,
    ACTIONS(9864), 1,
      sym__backquoted_id,
    ACTIONS(9866), 1,
      sym_operator_identifier,
    STATE(588), 1,
      sym_identifier,
    STATE(4168), 1,
      sym__soft_identifier,
    STATE(9838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9860), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [473228] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473264] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473300] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473336] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473372] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11004), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [473410] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8171), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [473452] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 21,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_as,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [473486] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473522] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9871), 1,
      sym__alpha_identifier,
    ACTIONS(9875), 1,
      anon_sym_EQ,
    ACTIONS(9877), 1,
      sym__backquoted_id,
    ACTIONS(9879), 1,
      sym_operator_identifier,
    STATE(583), 1,
      sym_identifier,
    STATE(4158), 1,
      sym__soft_identifier,
    STATE(9847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9873), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [473574] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473610] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8705), 2,
      anon_sym_LPAREN,
      sym__backquoted_id,
    STATE(9849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8703), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473646] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(489), 1,
      sym__alpha_identifier,
    ACTIONS(553), 1,
      sym__backquoted_id,
    ACTIONS(7568), 1,
      sym_operator_identifier,
    STATE(5518), 1,
      sym__soft_identifier,
    STATE(10006), 1,
      sym_identifier,
    STATE(9850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(7566), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [473692] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473728] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11583), 1,
      anon_sym_AT,
    STATE(9758), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10533), 1,
      sym_annotation,
    STATE(9852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473770] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
      anon_sym_LT_DASH,
  [473842] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10464), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473880] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11495), 1,
      anon_sym_AT,
    STATE(9764), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10419), 1,
      sym_annotation,
    STATE(9856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8485), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473922] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473958] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [473994] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474030] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474066] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474102] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10108), 1,
      sym__alpha_identifier,
    ACTIONS(10114), 1,
      anon_sym_EQ,
    ACTIONS(10116), 1,
      sym__backquoted_id,
    ACTIONS(10118), 1,
      sym_operator_identifier,
    STATE(590), 1,
      sym_identifier,
    STATE(4176), 1,
      sym__soft_identifier,
    STATE(9862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10112), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [474154] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474190] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1224), 1,
      sym__alpha_identifier,
    ACTIONS(1246), 1,
      sym__backquoted_id,
    ACTIONS(12251), 1,
      sym_operator_identifier,
    STATE(6072), 1,
      sym__soft_identifier,
    STATE(8495), 1,
      sym_identifier,
    STATE(9864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1234), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12249), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [474236] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474272] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [474308] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474344] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474380] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [474416] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474452] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5642), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10122), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [474492] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474528] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474564] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474600] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474672] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474708] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474744] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [474780] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474816] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474852] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [474888] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11447), 1,
      anon_sym_AT,
    STATE(9940), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10529), 1,
      sym_annotation,
    ACTIONS(8487), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(9883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8485), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474930] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12253), 1,
      anon_sym_AT,
    STATE(10551), 1,
      sym_annotation,
    STATE(9884), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8601), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [474970] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6628), 1,
      sym__end_marker,
    STATE(9885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475008] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475080] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475152] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5857), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7750), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [475228] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11016), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [475266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475302] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475338] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6536), 1,
      sym__end_marker,
    STATE(9895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475376] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10475), 1,
      sym__alpha_identifier,
    ACTIONS(10481), 1,
      sym__backquoted_id,
    ACTIONS(10483), 1,
      sym_operator_identifier,
    STATE(602), 1,
      sym_identifier,
    STATE(4191), 1,
      sym__soft_identifier,
    STATE(9896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(10477), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [475426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475462] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10019), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [475498] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475534] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1128), 1,
      sym__alpha_identifier,
    ACTIONS(1150), 1,
      sym__backquoted_id,
    ACTIONS(12258), 1,
      sym_operator_identifier,
    STATE(5283), 1,
      sym__soft_identifier,
    STATE(7845), 1,
      sym_identifier,
    STATE(9900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1138), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12256), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [475580] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10070), 1,
      sym_operator_identifier,
    STATE(1803), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [475632] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5610), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475672] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475708] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [475744] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10276), 1,
      sym_arguments,
    STATE(9905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475782] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1280), 1,
      sym__alpha_identifier,
    ACTIONS(1302), 1,
      sym__backquoted_id,
    ACTIONS(12262), 1,
      sym_operator_identifier,
    STATE(4522), 1,
      sym__soft_identifier,
    STATE(5422), 1,
      sym_identifier,
    STATE(9906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1290), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12260), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [475828] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11635), 1,
      anon_sym_COLON,
    ACTIONS(11639), 1,
      anon_sym_with,
    STATE(9734), 1,
      aux_sym_compound_type_repeat1,
    STATE(11254), 1,
      sym_template_body,
    STATE(11256), 1,
      sym__refinement,
    ACTIONS(7772), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(9907), 2,
      sym_comment,
      sym_block_comment,
    STATE(11233), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7766), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475876] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [475948] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [475984] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8531), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476056] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1744), 1,
      sym__alpha_identifier,
    ACTIONS(1766), 1,
      sym__backquoted_id,
    ACTIONS(12266), 1,
      sym_operator_identifier,
    STATE(6200), 1,
      sym__soft_identifier,
    STATE(9105), 1,
      sym_identifier,
    STATE(9913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1754), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12264), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [476102] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10355), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [476138] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9792), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [476174] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9656), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [476210] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476246] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [476282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [476318] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476354] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10921), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476392] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9660), 1,
      sym_operator_identifier,
    STATE(1799), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [476442] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10015), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [476478] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476514] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476550] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476586] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476622] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9259), 1,
      sym__alpha_identifier,
    ACTIONS(9265), 1,
      sym__backquoted_id,
    ACTIONS(9267), 1,
      sym_operator_identifier,
    ACTIONS(9925), 1,
      anon_sym_EQ,
    STATE(580), 1,
      sym_identifier,
    STATE(4062), 1,
      sym__soft_identifier,
    STATE(9928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9261), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [476674] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476710] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9536), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476782] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9726), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [476818] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(846), 1,
      sym__alpha_identifier,
    ACTIONS(876), 1,
      sym__backquoted_id,
    ACTIONS(12270), 1,
      sym_operator_identifier,
    STATE(5497), 1,
      sym__soft_identifier,
    STATE(9916), 1,
      sym_identifier,
    STATE(9933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(856), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12268), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [476864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476900] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476936] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12272), 1,
      anon_sym_COLON,
    ACTIONS(12275), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(9936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [476976] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12278), 1,
      anon_sym_with,
    STATE(9937), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477014] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477050] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477092] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12281), 1,
      anon_sym_AT,
    STATE(10529), 1,
      sym_annotation,
    ACTIONS(8603), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(9940), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8601), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477132] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1674), 1,
      sym__alpha_identifier,
    ACTIONS(1696), 1,
      sym__backquoted_id,
    ACTIONS(12286), 1,
      sym_operator_identifier,
    STATE(6717), 1,
      sym__soft_identifier,
    STATE(9443), 1,
      sym_identifier,
    STATE(9941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1684), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12284), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [477178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477214] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477250] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477286] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9999), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477322] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8638), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10226), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477394] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12290), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(12288), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [477430] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9987), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477466] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477502] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477538] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10299), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477574] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9981), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477610] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10295), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477646] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9890), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477682] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10332), 1,
      sym__alpha_identifier,
    ACTIONS(10336), 1,
      anon_sym_EQ,
    ACTIONS(10338), 1,
      sym__backquoted_id,
    ACTIONS(10340), 1,
      sym_operator_identifier,
    STATE(586), 1,
      sym_identifier,
    STATE(4180), 1,
      sym__soft_identifier,
    STATE(9956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
    ACTIONS(10334), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [477734] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9894), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477770] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12294), 6,
      sym__simple_multiline_string,
      sym__simple_string,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym_floating_point_literal,
      sym_character_literal,
    ACTIONS(12292), 15,
      anon_sym__,
      anon_sym_given,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_SQUOTE,
      sym__alpha_identifier,
      sym_operator_identifier,
      sym_integer_literal,
      anon_sym_true,
      anon_sym_false,
      sym_null_literal,
  [477806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477842] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477878] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(7882), 6,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477920] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [477956] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 16,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [477992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478064] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9871), 1,
      sym__alpha_identifier,
    ACTIONS(9877), 1,
      sym__backquoted_id,
    ACTIONS(9879), 1,
      sym_operator_identifier,
    ACTIONS(9898), 1,
      anon_sym_EQ,
    STATE(583), 1,
      sym_identifier,
    STATE(4158), 1,
      sym__soft_identifier,
    STATE(9966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9873), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [478116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478152] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478188] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478224] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12296), 1,
      anon_sym_with,
    STATE(9970), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478262] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10898), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 6,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478300] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2080), 1,
      sym__alpha_identifier,
    ACTIONS(2102), 1,
      sym__backquoted_id,
    ACTIONS(12301), 1,
      sym_operator_identifier,
    STATE(4671), 1,
      sym__soft_identifier,
    STATE(6142), 1,
      sym_identifier,
    STATE(9972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2090), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12299), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [478346] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478382] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10242), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [478418] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9364), 1,
      sym_operator_identifier,
    STATE(1752), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8309), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(8307), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [478468] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9977), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [478504] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478540] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8927), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478578] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478614] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478656] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9536), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [478692] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(9982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478734] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10371), 1,
      sym_operator_identifier,
    STATE(1701), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [478786] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9676), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [478822] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5709), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478862] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478898] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1638), 1,
      sym__alpha_identifier,
    ACTIONS(1660), 1,
      sym__backquoted_id,
    ACTIONS(12305), 1,
      sym_operator_identifier,
    STATE(4574), 1,
      sym__soft_identifier,
    STATE(5532), 1,
      sym_identifier,
    STATE(9987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1648), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12303), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [478944] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10359), 1,
      anon_sym_DOT,
    ACTIONS(11915), 1,
      anon_sym_COLON,
    STATE(9988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [478984] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5691), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479024] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9969), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [479060] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479096] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5769), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(9992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10122), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [479136] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9836), 1,
      sym__alpha_identifier,
    ACTIONS(9842), 1,
      sym__backquoted_id,
    ACTIONS(9844), 1,
      sym_operator_identifier,
    ACTIONS(9900), 1,
      anon_sym_EQ,
    STATE(582), 1,
      sym_identifier,
    STATE(4162), 1,
      sym__soft_identifier,
    STATE(9993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9838), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [479188] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10390), 1,
      sym_operator_identifier,
    STATE(1719), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(9994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [479240] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479276] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [479312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9929), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [479348] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1512), 1,
      sym__alpha_identifier,
    ACTIONS(1534), 1,
      sym__backquoted_id,
    ACTIONS(12309), 1,
      sym_operator_identifier,
    STATE(4581), 1,
      sym__soft_identifier,
    STATE(5913), 1,
      sym_identifier,
    STATE(9998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1522), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12307), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [479394] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(9999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [479430] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10220), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [479466] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479502] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8767), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479538] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1336), 1,
      sym__alpha_identifier,
    ACTIONS(1358), 1,
      sym__backquoted_id,
    ACTIONS(12313), 1,
      sym_operator_identifier,
    STATE(5824), 1,
      sym__soft_identifier,
    STATE(8526), 1,
      sym_identifier,
    STATE(10003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(1346), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
    ACTIONS(12311), 10,
      anon_sym_given,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_match,
      anon_sym_try,
      anon_sym_new,
      anon_sym_this,
      anon_sym_extension,
      anon_sym_val,
  [479584] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9949), 1,
      sym_operator_identifier,
    STATE(1742), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8309), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [479636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9955), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [479672] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479708] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9858), 1,
      sym__alpha_identifier,
    ACTIONS(9864), 1,
      sym__backquoted_id,
    ACTIONS(9866), 1,
      sym_operator_identifier,
    STATE(588), 1,
      sym_identifier,
    STATE(4168), 1,
      sym__soft_identifier,
    STATE(10007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 5,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9860), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [479758] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9858), 1,
      sym__alpha_identifier,
    ACTIONS(9864), 1,
      sym__backquoted_id,
    ACTIONS(9866), 1,
      sym_operator_identifier,
    ACTIONS(10257), 1,
      anon_sym_EQ,
    STATE(588), 1,
      sym_identifier,
    STATE(4168), 1,
      sym__soft_identifier,
    STATE(10008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_case,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9860), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [479810] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479846] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10286), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [479882] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479952] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [479987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480022] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11594), 1,
      anon_sym_COLON,
    ACTIONS(11596), 1,
      anon_sym_EQ,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15894), 1,
      aux_sym_val_declaration_repeat1,
    STATE(10015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [480083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480118] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_STAR,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480159] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480194] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(11600), 1,
      anon_sym_EQ,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15898), 1,
      aux_sym_val_declaration_repeat1,
    STATE(10019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [480255] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11614), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480292] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [480362] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [480397] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9471), 1,
      sym__alpha_identifier,
    ACTIONS(9477), 1,
      sym__backquoted_id,
    ACTIONS(9479), 1,
      sym_operator_identifier,
    ACTIONS(10797), 1,
      anon_sym_EQ,
    STATE(584), 1,
      sym_identifier,
    STATE(4160), 1,
      sym__soft_identifier,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(10024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9473), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [480448] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 3,
      anon_sym_while,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(7880), 5,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480489] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10506), 1,
      sym__end_marker,
    STATE(10026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [480526] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480596] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [480666] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [480701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480771] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [480841] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10390), 1,
      sym_operator_identifier,
    STATE(1719), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [480890] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [480925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480960] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    ACTIONS(11218), 1,
      anon_sym_EQ_GT,
    STATE(10039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [480999] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    ACTIONS(11362), 1,
      anon_sym_EQ_GT,
    STATE(10040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481038] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481073] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481108] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10416), 1,
      sym__end_marker,
    STATE(10043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9449), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481145] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9734), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481184] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481219] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11579), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(16029), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [481280] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481385] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(9622), 1,
      sym_operator_identifier,
    ACTIONS(10840), 1,
      anon_sym_EQ,
    STATE(608), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    STATE(10050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [481436] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [481506] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481576] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481646] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12317), 1,
      anon_sym_with,
    STATE(10057), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481718] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11575), 1,
      anon_sym_COMMA,
    ACTIONS(11577), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(16035), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [481779] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    ACTIONS(12320), 1,
      anon_sym_EQ_GT,
    STATE(10060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481888] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10440), 1,
      sym__end_marker,
    STATE(10063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [481960] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [481995] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482030] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482065] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482100] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482176] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482252] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482322] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [482357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482392] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482427] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482462] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_while,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482538] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482573] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482678] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482748] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [482853] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11571), 1,
      anon_sym_COMMA,
    ACTIONS(11573), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15987), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [482914] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(9622), 1,
      sym_operator_identifier,
    ACTIONS(10711), 1,
      anon_sym_EQ,
    STATE(608), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(10091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [482965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483000] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8933), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483039] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10497), 1,
      sym__alpha_identifier,
    ACTIONS(10503), 1,
      sym__backquoted_id,
    ACTIONS(10505), 1,
      sym_operator_identifier,
    STATE(606), 1,
      sym_identifier,
    STATE(4189), 1,
      sym__soft_identifier,
    STATE(10094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(10499), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [483088] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10497), 1,
      sym__alpha_identifier,
    ACTIONS(10501), 1,
      anon_sym_EQ,
    ACTIONS(10503), 1,
      sym__backquoted_id,
    ACTIONS(10505), 1,
      sym_operator_identifier,
    STATE(606), 1,
      sym_identifier,
    STATE(4189), 1,
      sym__soft_identifier,
    STATE(10095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10499), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [483139] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10276), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483213] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11562), 1,
      anon_sym_COLON,
    ACTIONS(11564), 1,
      anon_sym_EQ,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15845), 1,
      aux_sym_val_declaration_repeat1,
    STATE(10098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [483274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483309] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483344] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(10101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [483416] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11558), 1,
      anon_sym_COLON,
    ACTIONS(11560), 1,
      anon_sym_EQ,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15848), 1,
      aux_sym_val_declaration_repeat1,
    STATE(10103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [483477] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483512] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10620), 1,
      anon_sym_RPAREN,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15412), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [483573] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [483678] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [483713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483748] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [483783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483853] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10394), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [483962] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12322), 1,
      anon_sym_COLON,
    ACTIONS(12325), 1,
      anon_sym_LBRACE,
    STATE(11008), 1,
      sym_template_body,
    STATE(10117), 2,
      sym_comment,
      sym_block_comment,
    STATE(11096), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(8900), 4,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8892), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484005] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484075] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9967), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484114] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10533), 1,
      sym_operator_identifier,
    STATE(1729), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8309), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [484165] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    ACTIONS(11551), 1,
      anon_sym_EQ_GT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(17844), 1,
      sym_guard,
    STATE(10122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [484226] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484261] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [484296] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5584), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484335] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484370] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [484440] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8781), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484479] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484514] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484549] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11531), 1,
      anon_sym_COLON,
    ACTIONS(11533), 1,
      anon_sym_EQ,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15848), 1,
      aux_sym_val_declaration_repeat1,
    STATE(10132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [484610] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484645] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484680] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(11159), 1,
      sym__alpha_identifier,
    ACTIONS(11165), 1,
      sym__backquoted_id,
    ACTIONS(11167), 1,
      sym_operator_identifier,
    STATE(622), 1,
      sym_identifier,
    STATE(4205), 1,
      sym__soft_identifier,
    STATE(10135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(9022), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(11161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [484729] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10449), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484768] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11524), 1,
      anon_sym_COLON,
    ACTIONS(11526), 1,
      anon_sym_EQ,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15845), 1,
      aux_sym_val_declaration_repeat1,
    STATE(10137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [484829] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [484899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [484934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [484969] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(7882), 5,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485010] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485080] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485115] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10620), 1,
      anon_sym_RPAREN,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15412), 1,
      aux_sym_case_class_pattern_repeat1,
    ACTIONS(10618), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [485174] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10620), 1,
      anon_sym_RPAREN,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15412), 1,
      aux_sym_case_class_pattern_repeat1,
    ACTIONS(10618), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [485233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485268] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485338] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485414] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485449] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485484] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(7475), 1,
      sym__end_marker,
    STATE(10155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485521] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    ACTIONS(11517), 1,
      anon_sym_EQ_GT,
    STATE(10156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485560] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485595] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(7882), 5,
      anon_sym_while,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [485706] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11519), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485743] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10823), 1,
      sym__alpha_identifier,
    ACTIONS(10827), 1,
      anon_sym_EQ,
    ACTIONS(10829), 1,
      sym__backquoted_id,
    ACTIONS(10831), 1,
      sym_operator_identifier,
    STATE(610), 1,
      sym_identifier,
    STATE(4185), 1,
      sym__soft_identifier,
    STATE(10162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10825), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [485794] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485829] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485899] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12330), 1,
      anon_sym_LPAREN,
    STATE(11121), 1,
      sym__using_parameters_clause,
    STATE(11174), 1,
      sym_parameters,
    STATE(10166), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_extension_definition_repeat1,
    ACTIONS(12328), 16,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [485938] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [485973] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10497), 1,
      sym__alpha_identifier,
    ACTIONS(10503), 1,
      sym__backquoted_id,
    ACTIONS(10505), 1,
      sym_operator_identifier,
    ACTIONS(10818), 1,
      anon_sym_EQ,
    STATE(606), 1,
      sym_identifier,
    STATE(4189), 1,
      sym__soft_identifier,
    STATE(10168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10499), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [486024] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486059] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [486094] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9471), 1,
      sym__alpha_identifier,
    ACTIONS(9477), 1,
      sym__backquoted_id,
    ACTIONS(9479), 1,
      sym_operator_identifier,
    ACTIONS(10816), 1,
      anon_sym_EQ,
    STATE(584), 1,
      sym_identifier,
    STATE(4160), 1,
      sym__soft_identifier,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(10171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 5,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(9473), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [486145] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486180] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486250] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486285] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486320] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486355] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5513), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486394] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8610), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486433] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12333), 1,
      anon_sym_with,
    STATE(10180), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8980), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486470] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12336), 1,
      anon_sym_with,
    STATE(10181), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486507] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11299), 1,
      anon_sym_RPAREN,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15873), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [486568] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9977), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486638] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486708] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486743] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8951), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486782] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486817] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [486852] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [486887] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5928), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486926] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [486961] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10108), 1,
      sym__alpha_identifier,
    ACTIONS(10116), 1,
      sym__backquoted_id,
    ACTIONS(10118), 1,
      sym_operator_identifier,
    STATE(590), 1,
      sym_identifier,
    STATE(4176), 1,
      sym__soft_identifier,
    STATE(10194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10112), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [487010] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487045] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487080] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    ACTIONS(11183), 1,
      anon_sym_EQ_GT,
    STATE(10197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487119] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9076), 1,
      sym__backquoted_id,
    STATE(10198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9074), 19,
      anon_sym_end,
      anon_sym_val,
      anon_sym_AT,
      anon_sym_var,
      anon_sym_opaque,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487154] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [487189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [487259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487294] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11377), 1,
      anon_sym_EQ_GT,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(18342), 1,
      sym_guard,
    STATE(10203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [487355] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_else,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487396] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12339), 1,
      anon_sym_DOT,
    STATE(10205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 4,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487468] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487538] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487573] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [487608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487678] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5814), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487717] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10660), 1,
      sym__end_marker,
    STATE(10214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487754] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10590), 1,
      sym_operator_identifier,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8309), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [487805] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10553), 1,
      sym__alpha_identifier,
    ACTIONS(10557), 1,
      anon_sym_EQ,
    ACTIONS(10559), 1,
      sym__backquoted_id,
    ACTIONS(10561), 1,
      sym_operator_identifier,
    STATE(596), 1,
      sym_identifier,
    STATE(4182), 1,
      sym__soft_identifier,
    STATE(10216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(9022), 4,
      anon_sym_match,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10555), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [487856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487891] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12341), 1,
      anon_sym_with,
    STATE(10218), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [487963] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6091), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488002] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6064), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488076] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488146] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9206), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488185] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488220] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488255] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488290] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10371), 1,
      sym_operator_identifier,
    STATE(1701), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [488339] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488374] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [488409] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9949), 1,
      sym_operator_identifier,
    STATE(1742), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8309), 5,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [488458] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    ACTIONS(11691), 1,
      anon_sym_EQ_GT,
    STATE(10233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488497] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5563), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488536] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488571] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488606] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488641] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10746), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488680] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488750] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11756), 1,
      anon_sym_AT,
    STATE(10282), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10826), 1,
      sym_annotation,
    STATE(10241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(8485), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488791] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488826] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488896] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8171), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [488937] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [488972] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489007] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489042] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489112] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489147] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489182] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489217] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489252] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489287] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(7882), 5,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489328] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10475), 1,
      sym__alpha_identifier,
    ACTIONS(10479), 1,
      anon_sym_EQ,
    ACTIONS(10481), 1,
      sym__backquoted_id,
    ACTIONS(10483), 1,
      sym_operator_identifier,
    STATE(602), 1,
      sym_identifier,
    STATE(4191), 1,
      sym__soft_identifier,
    STATE(10257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_then,
    ACTIONS(9018), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(10477), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [489379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489414] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489455] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489490] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_EQ_GT,
    ACTIONS(7884), 1,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(9331), 1,
      anon_sym_COLON,
    ACTIONS(9333), 1,
      anon_sym_LBRACE,
    ACTIONS(9335), 1,
      anon_sym_with,
    STATE(5130), 1,
      aux_sym_compound_type_repeat1,
    STATE(10320), 1,
      sym_template_body,
    STATE(10321), 1,
      sym__refinement,
    STATE(10124), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(10261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489543] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11478), 1,
      anon_sym_COMMA,
    ACTIONS(11480), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15913), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [489604] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489639] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489674] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10633), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489713] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5721), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10122), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489752] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489787] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6095), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489826] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489861] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [489896] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11466), 1,
      anon_sym_COLON,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(11469), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489937] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12344), 1,
      anon_sym_COLON,
    ACTIONS(7972), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(12347), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 10,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [489978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490013] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [490083] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10253), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490118] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490153] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9505), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490227] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [490262] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490297] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12350), 1,
      anon_sym_AT,
    STATE(10826), 1,
      sym_annotation,
    ACTIONS(8603), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(10282), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8601), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490336] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [490371] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490406] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [490441] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9836), 1,
      sym__alpha_identifier,
    ACTIONS(9842), 1,
      sym__backquoted_id,
    ACTIONS(9844), 1,
      sym_operator_identifier,
    ACTIONS(10701), 1,
      anon_sym_EQ,
    STATE(582), 1,
      sym_identifier,
    STATE(4162), 1,
      sym__soft_identifier,
    STATE(10286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9838), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [490492] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490533] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490568] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10436), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490607] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490642] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11455), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15955), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [490703] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490738] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [490773] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7750), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490808] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490878] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490913] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 20,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [490946] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [490981] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10070), 1,
      sym_operator_identifier,
    STATE(1803), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8309), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491030] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10867), 1,
      sym__alpha_identifier,
    ACTIONS(10871), 1,
      anon_sym_EQ,
    ACTIONS(10873), 1,
      sym__backquoted_id,
    ACTIONS(10875), 1,
      sym_operator_identifier,
    STATE(605), 1,
      sym_identifier,
    STATE(4186), 1,
      sym__soft_identifier,
    STATE(10301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10869), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491081] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [491116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [491151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491186] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491221] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [491256] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491326] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11419), 1,
      anon_sym_COLON,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11429), 1,
      anon_sym_EQ,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15292), 1,
      aux_sym_val_declaration_repeat1,
    STATE(10309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491387] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    ACTIONS(11248), 1,
      anon_sym_EQ_GT,
    STATE(10310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491496] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491531] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    ACTIONS(11453), 1,
      anon_sym_EQ_GT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(17930), 1,
      sym_guard,
    STATE(10314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491592] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491627] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491662] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491697] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10835), 1,
      sym_operator_identifier,
    STATE(1828), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8309), 3,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491748] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 5,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [491818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [491853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491888] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [491923] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11449), 1,
      anon_sym_COLON,
    ACTIONS(11451), 1,
      anon_sym_EQ,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15898), 1,
      aux_sym_val_declaration_repeat1,
    STATE(10324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [491984] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10823), 1,
      sym__alpha_identifier,
    ACTIONS(10829), 1,
      sym__backquoted_id,
    ACTIONS(10831), 1,
      sym_operator_identifier,
    STATE(610), 1,
      sym_identifier,
    STATE(4185), 1,
      sym__soft_identifier,
    STATE(10325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9022), 4,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(10825), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [492033] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11443), 1,
      anon_sym_COLON,
    ACTIONS(11445), 1,
      anon_sym_EQ,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15894), 1,
      aux_sym_val_declaration_repeat1,
    STATE(10326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [492094] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10823), 1,
      sym__alpha_identifier,
    ACTIONS(10829), 1,
      sym__backquoted_id,
    ACTIONS(10831), 1,
      sym_operator_identifier,
    ACTIONS(10865), 1,
      anon_sym_EQ,
    STATE(610), 1,
      sym_identifier,
    STATE(4185), 1,
      sym__soft_identifier,
    STATE(10327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10825), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [492145] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492180] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8880), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492219] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492254] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492289] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11367), 1,
      anon_sym_COMMA,
    ACTIONS(11369), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15557), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [492350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492385] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 4,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8531), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492420] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [492496] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [492531] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
      anon_sym_yield,
  [492636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 4,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8638), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [492706] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10485), 1,
      sym__alpha_identifier,
    ACTIONS(10491), 1,
      anon_sym_EQ,
    ACTIONS(10493), 1,
      sym__backquoted_id,
    ACTIONS(10495), 1,
      sym_operator_identifier,
    STATE(600), 1,
      sym_identifier,
    STATE(4192), 1,
      sym__soft_identifier,
    STATE(10343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10489), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [492757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492792] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492862] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9871), 1,
      sym__alpha_identifier,
    ACTIONS(9877), 1,
      sym__backquoted_id,
    ACTIONS(9879), 1,
      sym_operator_identifier,
    ACTIONS(10781), 1,
      anon_sym_EQ,
    STATE(583), 1,
      sym_identifier,
    STATE(4158), 1,
      sym__soft_identifier,
    STATE(10347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_case,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9873), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [492913] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
      anon_sym_finally,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [492954] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [492989] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6049), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [493063] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493098] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493168] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9563), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493207] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 16,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493277] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11437), 1,
      anon_sym_COLON,
    ACTIONS(11439), 1,
      anon_sym_EQ,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15286), 1,
      aux_sym_val_declaration_repeat1,
    STATE(10358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [493338] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493408] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9761), 1,
      anon_sym_EQ_GT,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(10361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8002), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493447] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [493482] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [493552] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12353), 1,
      anon_sym_RBRACE,
    ACTIONS(12357), 1,
      anon_sym_given,
    ACTIONS(12359), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(14929), 1,
      sym_identifier,
    ACTIONS(12355), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10365), 2,
      sym_comment,
      sym_block_comment,
    STATE(16617), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [493602] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493670] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10332), 1,
      sym__alpha_identifier,
    ACTIONS(10338), 1,
      sym__backquoted_id,
    ACTIONS(10340), 1,
      sym_operator_identifier,
    ACTIONS(10883), 1,
      anon_sym_EQ,
    STATE(586), 1,
      sym_identifier,
    STATE(4180), 1,
      sym__soft_identifier,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(10368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(10334), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [493720] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(11203), 1,
      sym__alpha_identifier,
    ACTIONS(11207), 1,
      anon_sym_EQ,
    ACTIONS(11209), 1,
      sym__backquoted_id,
    ACTIONS(11211), 1,
      sym_operator_identifier,
    STATE(613), 1,
      sym_identifier,
    STATE(4197), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_match,
      anon_sym_else,
    STATE(10369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11205), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [493770] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493804] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5682), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493842] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493876] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493910] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [493944] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [493978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [494012] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [494046] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [494080] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12363), 1,
      sym_operator_identifier,
    ACTIONS(12365), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(12168), 1,
      sym_colon_argument,
    STATE(10379), 2,
      sym_comment,
      sym_block_comment,
    STATE(12167), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16974), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [494132] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [494166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494200] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [494234] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [494268] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494302] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5626), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494340] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9761), 1,
      anon_sym_EQ_GT,
    STATE(10386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494376] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [494410] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494444] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12367), 1,
      sym_operator_identifier,
    ACTIONS(12369), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10743), 1,
      sym_colon_argument,
    STATE(10389), 2,
      sym_comment,
      sym_block_comment,
    STATE(10799), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(17062), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [494496] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494530] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [494564] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494632] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [494666] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494734] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [494802] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9563), 1,
      anon_sym_EQ_GT,
    STATE(10399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494838] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494872] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [494906] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [494940] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10911), 1,
      sym__alpha_identifier,
    ACTIONS(10915), 1,
      anon_sym_EQ,
    ACTIONS(10917), 1,
      sym__backquoted_id,
    ACTIONS(10919), 1,
      sym_operator_identifier,
    STATE(646), 1,
      sym_identifier,
    STATE(4200), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(10403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [494990] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11218), 1,
      anon_sym_EQ_GT,
    STATE(10404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495026] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11297), 1,
      anon_sym_AT,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11176), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11174), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495070] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [495104] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11362), 1,
      anon_sym_EQ_GT,
    STATE(10407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495140] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11633), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [495196] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 5,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495236] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495270] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11297), 1,
      anon_sym_AT,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11145), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11143), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495314] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10925), 1,
      sym__alpha_identifier,
    ACTIONS(10931), 1,
      anon_sym_EQ,
    ACTIONS(10933), 1,
      sym__backquoted_id,
    ACTIONS(10935), 1,
      sym_operator_identifier,
    STATE(628), 1,
      sym_identifier,
    STATE(4202), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_match,
      anon_sym_finally,
    STATE(10412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10929), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [495364] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9734), 1,
      anon_sym_EQ_GT,
    STATE(10413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495400] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495434] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495468] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9726), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [495502] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11145), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11143), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [495542] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11664), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495578] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495612] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495646] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495680] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495714] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12371), 1,
      sym_operator_identifier,
    ACTIONS(12373), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(11163), 1,
      sym_colon_argument,
    STATE(10423), 2,
      sym_comment,
      sym_block_comment,
    STATE(11036), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(17221), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [495766] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12377), 1,
      anon_sym_LBRACK,
    ACTIONS(12379), 1,
      anon_sym_AT,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(12385), 1,
      sym__automatic_semicolon,
    STATE(11141), 1,
      sym_type_parameters,
    STATE(11420), 1,
      sym_annotation,
    STATE(12752), 1,
      aux_sym__class_constructor_repeat1,
    STATE(12754), 1,
      sym_access_modifier,
    STATE(13630), 1,
      sym_class_parameters,
    ACTIONS(12381), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(10424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12375), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [495818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495852] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495886] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495920] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [495954] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10485), 1,
      sym__alpha_identifier,
    ACTIONS(10493), 1,
      sym__backquoted_id,
    ACTIONS(10495), 1,
      sym_operator_identifier,
    STATE(600), 1,
      sym_identifier,
    STATE(4192), 1,
      sym__soft_identifier,
    STATE(10429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10489), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [496002] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12388), 1,
      sym_operator_identifier,
    ACTIONS(12390), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10772), 1,
      sym_colon_argument,
    STATE(10430), 2,
      sym_comment,
      sym_block_comment,
    STATE(10757), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(17104), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [496054] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11145), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11143), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [496094] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12320), 1,
      anon_sym_EQ_GT,
    STATE(10432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496130] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10673), 1,
      sym__end_marker,
    STATE(10433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9656), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [496200] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496234] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496268] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(7882), 4,
      anon_sym_STAR,
      anon_sym_while,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496308] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11196), 1,
      anon_sym_PIPE,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11194), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [496364] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [496398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496432] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [496466] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(11220), 1,
      sym_operator_identifier,
    STATE(1847), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(10442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [496516] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11194), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11196), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [496568] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [496602] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [496670] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10226), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496704] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11194), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11196), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [496756] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10688), 1,
      sym__end_marker,
    STATE(10449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496792] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496826] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496860] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9999), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496894] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_else,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [496968] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497002] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 3,
      anon_sym_STAR,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497042] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10276), 1,
      anon_sym_EQ_GT,
    STATE(10457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497078] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12392), 1,
      sym_operator_identifier,
    ACTIONS(12394), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10653), 1,
      sym_colon_argument,
    STATE(10458), 2,
      sym_comment,
      sym_block_comment,
    STATE(10581), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(17333), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [497130] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12396), 1,
      sym_operator_identifier,
    ACTIONS(12398), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(11335), 1,
      sym_colon_argument,
    STATE(10459), 2,
      sym_comment,
      sym_block_comment,
    STATE(11287), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16952), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [497182] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497216] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [497250] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8933), 1,
      anon_sym_EQ_GT,
    STATE(10462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497286] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [497320] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11176), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11174), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [497360] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [497394] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12400), 1,
      anon_sym_with,
    STATE(10466), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(8980), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497430] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(4952), 1,
      anon_sym_implicit,
    ACTIONS(4958), 1,
      anon_sym_using,
    ACTIONS(4960), 1,
      anon_sym_RPAREN,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(15251), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(10467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [497490] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(2533), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497558] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497592] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12407), 1,
      sym_operator_identifier,
    ACTIONS(12409), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10905), 1,
      sym_colon_argument,
    STATE(10471), 2,
      sym_comment,
      sym_block_comment,
    STATE(10892), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(17389), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [497644] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8880), 1,
      anon_sym_EQ_GT,
    STATE(10472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497680] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [497714] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 3,
      anon_sym_STAR,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497754] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [497788] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8947), 1,
      anon_sym_LPAREN,
    ACTIONS(12411), 1,
      anon_sym_LBRACK,
    ACTIONS(12413), 1,
      anon_sym_POUND,
    STATE(11112), 1,
      aux_sym_annotation_repeat1,
    STATE(11293), 1,
      sym_type_arguments,
    STATE(11499), 1,
      sym_arguments,
    STATE(10476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [497832] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [497866] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497900] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [497934] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12415), 1,
      sym_operator_identifier,
    ACTIONS(12417), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(9963), 1,
      sym_colon_argument,
    STATE(9721), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10480), 2,
      sym_comment,
      sym_block_comment,
    STATE(17040), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [497986] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [498020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10220), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [498054] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10394), 1,
      anon_sym_EQ_GT,
    STATE(10483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498090] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498130] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5681), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498168] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12419), 1,
      sym_operator_identifier,
    ACTIONS(12421), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(9577), 1,
      sym_colon_argument,
    STATE(9453), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10486), 2,
      sym_comment,
      sym_block_comment,
    STATE(17101), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [498220] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10533), 1,
      sym_operator_identifier,
    STATE(1729), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8309), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [498268] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [498302] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12357), 1,
      anon_sym_given,
    ACTIONS(12359), 1,
      sym_operator_identifier,
    ACTIONS(12423), 1,
      anon_sym_RBRACE,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(14929), 1,
      sym_identifier,
    ACTIONS(12355), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10489), 2,
      sym_comment,
      sym_block_comment,
    STATE(16617), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [498352] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8587), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498386] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [498420] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(10911), 1,
      sym__alpha_identifier,
    ACTIONS(10917), 1,
      sym__backquoted_id,
    ACTIONS(10919), 1,
      sym_operator_identifier,
    STATE(646), 1,
      sym_identifier,
    STATE(4200), 1,
      sym__soft_identifier,
    ACTIONS(8305), 2,
      anon_sym_COLON,
      anon_sym_if,
    STATE(10492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9616), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(10913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [498472] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9967), 1,
      anon_sym_EQ_GT,
    STATE(10493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498508] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [498542] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 3,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498582] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12425), 1,
      sym_operator_identifier,
    ACTIONS(12427), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10064), 1,
      sym_colon_argument,
    STATE(10016), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10496), 2,
      sym_comment,
      sym_block_comment,
    STATE(17209), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [498634] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10835), 1,
      sym_operator_identifier,
    STATE(1828), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8309), 3,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [498682] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(11159), 1,
      sym__alpha_identifier,
    ACTIONS(11163), 1,
      anon_sym_EQ,
    ACTIONS(11165), 1,
      sym__backquoted_id,
    ACTIONS(11167), 1,
      sym_operator_identifier,
    STATE(622), 1,
      sym_identifier,
    STATE(4205), 1,
      sym__soft_identifier,
    STATE(10498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_then,
      anon_sym_finally,
    ACTIONS(11161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [498732] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9894), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498766] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12429), 1,
      anon_sym_with,
    STATE(10500), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498802] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12432), 1,
      sym_operator_identifier,
    ACTIONS(12434), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10789), 1,
      sym_colon_argument,
    STATE(10501), 2,
      sym_comment,
      sym_block_comment,
    STATE(10752), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16930), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [498854] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 4,
      anon_sym_DOT,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [498888] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498922] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8781), 1,
      anon_sym_EQ_GT,
    STATE(10504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498958] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12436), 1,
      anon_sym_with,
    ACTIONS(8982), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(10505), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8980), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [498994] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [499028] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9709), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [499062] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10620), 1,
      anon_sym_RPAREN,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15412), 1,
      aux_sym_case_class_pattern_repeat1,
    ACTIONS(10618), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499118] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10449), 1,
      anon_sym_EQ_GT,
    STATE(10509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499154] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9890), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499188] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(11006), 1,
      sym_operator_identifier,
    STATE(1790), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_match,
      anon_sym_finally,
    STATE(10511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499238] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10295), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499272] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(11198), 1,
      sym_operator_identifier,
    STATE(1852), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_match,
      anon_sym_else,
    STATE(10513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499322] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12439), 1,
      anon_sym_implicit,
    ACTIONS(12441), 1,
      anon_sym_using,
    ACTIONS(12443), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(15932), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(10514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499382] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11773), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499438] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12445), 1,
      sym_operator_identifier,
    ACTIONS(12447), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10303), 1,
      sym_colon_argument,
    STATE(10275), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10516), 2,
      sym_comment,
      sym_block_comment,
    STATE(17293), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499490] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10286), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [499558] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499592] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11248), 1,
      anon_sym_EQ_GT,
    STATE(10520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499628] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [499662] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10019), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499696] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12449), 1,
      sym_operator_identifier,
    ACTIONS(12451), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10531), 1,
      sym_colon_argument,
    STATE(10482), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10523), 2,
      sym_comment,
      sym_block_comment,
    STATE(16981), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499748] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9969), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499782] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12453), 1,
      sym_operator_identifier,
    ACTIONS(12455), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(8374), 1,
      sym_colon_argument,
    STATE(8749), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10525), 2,
      sym_comment,
      sym_block_comment,
    STATE(16996), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [499834] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499868] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9929), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499902] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499936] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9076), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(10529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9074), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [499970] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6002), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500008] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11666), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [500042] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9676), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [500076] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500110] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500144] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11744), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [500200] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10332), 1,
      sym__alpha_identifier,
    ACTIONS(10338), 1,
      sym__backquoted_id,
    ACTIONS(10340), 1,
      sym_operator_identifier,
    ACTIONS(10994), 1,
      anon_sym_EQ,
    STATE(586), 1,
      sym_identifier,
    STATE(4180), 1,
      sym__soft_identifier,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(10536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 4,
      anon_sym_match,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10334), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [500250] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12457), 1,
      sym_operator_identifier,
    ACTIONS(12459), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10730), 1,
      sym_colon_argument,
    STATE(10537), 2,
      sym_comment,
      sym_block_comment,
    STATE(10774), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(17230), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [500302] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [500336] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500370] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11517), 1,
      anon_sym_EQ_GT,
    STATE(10540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500406] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10867), 1,
      sym__alpha_identifier,
    ACTIONS(10873), 1,
      sym__backquoted_id,
    ACTIONS(10875), 1,
      sym_operator_identifier,
    STATE(605), 1,
      sym_identifier,
    STATE(4186), 1,
      sym__soft_identifier,
    STATE(10541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10869), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [500454] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500488] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500522] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500556] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10355), 15,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [500624] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [500658] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(10618), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [500714] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8583), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500748] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500782] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500816] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500850] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500884] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9313), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500918] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11176), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11174), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [500958] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [500992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [501026] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12461), 1,
      anon_sym_with,
    STATE(10558), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8980), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501062] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10436), 1,
      anon_sym_EQ_GT,
    STATE(10559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501098] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501138] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501172] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [501206] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501240] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12464), 1,
      sym_operator_identifier,
    ACTIONS(12466), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10906), 1,
      sym_colon_argument,
    STATE(10564), 2,
      sym_comment,
      sym_block_comment,
    STATE(10911), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(17251), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [501292] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8610), 1,
      anon_sym_EQ_GT,
    STATE(10565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501328] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(7882), 4,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501368] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501402] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12468), 1,
      sym_operator_identifier,
    ACTIONS(12470), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(9735), 1,
      sym_colon_argument,
    STATE(9669), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10568), 2,
      sym_comment,
      sym_block_comment,
    STATE(17018), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [501454] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [501488] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501522] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501556] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8585), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 4,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501624] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [501658] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [501692] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12472), 1,
      sym_operator_identifier,
    ACTIONS(12474), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(11130), 1,
      sym_colon_argument,
    STATE(10576), 2,
      sym_comment,
      sym_block_comment,
    STATE(11014), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16863), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [501744] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9792), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501778] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8951), 1,
      anon_sym_EQ_GT,
    STATE(10578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501814] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9505), 1,
      anon_sym_EQ_GT,
    STATE(10579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501850] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12476), 1,
      sym_operator_identifier,
    ACTIONS(12478), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10128), 1,
      sym_colon_argument,
    STATE(10065), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10580), 2,
      sym_comment,
      sym_block_comment,
    STATE(17508), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [501902] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501936] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [501970] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10299), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502004] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12480), 1,
      sym_operator_identifier,
    ACTIONS(12482), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10647), 1,
      sym_colon_argument,
    STATE(10370), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10584), 2,
      sym_comment,
      sym_block_comment,
    STATE(16908), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 4,
      anon_sym_DOT,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [502090] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502124] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502158] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 4,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502192] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11183), 1,
      anon_sym_EQ_GT,
    STATE(10589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502228] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(11008), 1,
      sym_operator_identifier,
    STATE(1722), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502278] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10911), 1,
      sym__alpha_identifier,
    ACTIONS(10917), 1,
      sym__backquoted_id,
    ACTIONS(11010), 1,
      anon_sym_EQ,
    ACTIONS(11012), 1,
      sym_operator_identifier,
    STATE(626), 1,
      sym_identifier,
    STATE(4200), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502328] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10590), 1,
      sym_operator_identifier,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(9022), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502376] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 4,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502410] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502444] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502478] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(7882), 4,
      anon_sym_while,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502518] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502552] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11785), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502608] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11791), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502664] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 3,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_if,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502704] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10718), 1,
      sym__end_marker,
    STATE(10601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502740] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(11145), 1,
      sym__backquoted_id,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11381), 1,
      anon_sym_AT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11143), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502784] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502852] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12484), 1,
      sym_operator_identifier,
    ACTIONS(12486), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(11245), 1,
      sym_colon_argument,
    STATE(10605), 2,
      sym_comment,
      sym_block_comment,
    STATE(11300), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16768), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [502904] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6008), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502942] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [502976] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503010] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5798), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10122), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503082] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10633), 1,
      anon_sym_EQ_GT,
    STATE(10611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503118] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 3,
      anon_sym_case,
      anon_sym_if,
      anon_sym_finally,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503158] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9955), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 6,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(4176), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [503226] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11775), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503316] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7678), 1,
      sym__backquoted_id,
    ACTIONS(12488), 1,
      anon_sym_LBRACK,
    ACTIONS(12490), 1,
      anon_sym_LPAREN,
    ACTIONS(12492), 1,
      anon_sym_POUND,
    STATE(11110), 1,
      aux_sym_annotation_repeat1,
    STATE(11342), 1,
      sym_type_arguments,
    STATE(11560), 1,
      sym_arguments,
    STATE(10617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7676), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503362] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [503396] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12494), 1,
      sym_operator_identifier,
    ACTIONS(12496), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(9403), 1,
      sym_colon_argument,
    STATE(9132), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10619), 2,
      sym_comment,
      sym_block_comment,
    STATE(17272), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [503482] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 4,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503516] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10590), 1,
      sym_operator_identifier,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8309), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_then,
      anon_sym_do,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503564] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [503598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503632] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12498), 1,
      sym_operator_identifier,
    ACTIONS(12500), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(11437), 1,
      sym_colon_argument,
    STATE(10625), 2,
      sym_comment,
      sym_block_comment,
    STATE(11673), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(17636), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [503684] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9981), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503718] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11796), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [503754] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(11176), 1,
      sym__backquoted_id,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11381), 1,
      anon_sym_AT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11174), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503832] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9206), 1,
      anon_sym_EQ_GT,
    STATE(10630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503868] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503902] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9987), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503936] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5742), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [503974] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12502), 1,
      sym_operator_identifier,
    ACTIONS(12504), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(9711), 1,
      sym_colon_argument,
    STATE(9869), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10634), 2,
      sym_comment,
      sym_block_comment,
    STATE(16760), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [504026] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(11031), 1,
      sym_operator_identifier,
    STATE(1702), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [504076] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504110] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504144] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504212] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(11033), 1,
      anon_sym_EQ,
    ACTIONS(11035), 1,
      sym_operator_identifier,
    STATE(621), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [504262] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504296] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11196), 3,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [504350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504384] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504418] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504452] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12361), 1,
      anon_sym_LPAREN,
    ACTIONS(12506), 1,
      sym_operator_identifier,
    ACTIONS(12508), 1,
      sym__indent,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10494), 1,
      sym_colon_argument,
    STATE(10518), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(10646), 2,
      sym_comment,
      sym_block_comment,
    STATE(16837), 3,
      sym_bindings,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [504504] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504538] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12357), 1,
      anon_sym_given,
    ACTIONS(12359), 1,
      sym_operator_identifier,
    ACTIONS(12510), 1,
      anon_sym_RBRACE,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(14929), 1,
      sym_identifier,
    ACTIONS(12355), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10648), 2,
      sym_comment,
      sym_block_comment,
    STATE(16617), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [504588] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10242), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504622] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10015), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504656] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504690] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11691), 1,
      anon_sym_EQ_GT,
    STATE(10652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504726] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504760] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10746), 1,
      anon_sym_EQ_GT,
    STATE(10654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      sym__backquoted_id,
    ACTIONS(8501), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504796] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504830] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504898] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5659), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [504936] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12357), 1,
      anon_sym_given,
    ACTIONS(12359), 1,
      sym_operator_identifier,
    ACTIONS(12512), 1,
      anon_sym_RBRACE,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(14929), 1,
      sym_identifier,
    ACTIONS(12355), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10659), 2,
      sym_comment,
      sym_block_comment,
    STATE(16617), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [504986] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      sym__backquoted_id,
      sym__interpolated_multiline_string_start,
    ACTIONS(7062), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_DQUOTE,
  [505054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505088] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12514), 1,
      anon_sym_implicit,
    ACTIONS(12516), 1,
      anon_sym_using,
    ACTIONS(12518), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(15835), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(10663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [505148] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505182] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505216] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505250] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10742), 1,
      sym__end_marker,
    STATE(10667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9449), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [505286] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505320] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505354] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505387] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5706), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10122), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505424] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(11203), 1,
      sym__alpha_identifier,
    ACTIONS(11209), 1,
      sym__backquoted_id,
    ACTIONS(11211), 1,
      sym_operator_identifier,
    STATE(613), 1,
      sym_identifier,
    STATE(4197), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_match,
      anon_sym_else,
    STATE(10672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11205), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [505471] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505504] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505537] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12520), 1,
      anon_sym_with,
    ACTIONS(8982), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(10675), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8980), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505572] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505638] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5999), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505708] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505741] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9656), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [505774] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505807] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9676), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [505840] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [505873] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(12523), 1,
      anon_sym_LBRACE,
    ACTIONS(12527), 1,
      sym_operator_identifier,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(14251), 1,
      sym_identifier,
    STATE(10685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12525), 3,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_given,
    STATE(14544), 3,
      sym_namespace_wildcard,
      sym_namespace_selectors,
      sym_as_renamed_identifier,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [505920] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10475), 1,
      sym__alpha_identifier,
    ACTIONS(10481), 1,
      sym__backquoted_id,
    ACTIONS(10483), 1,
      sym_operator_identifier,
    ACTIONS(11590), 1,
      anon_sym_EQ,
    STATE(602), 1,
      sym_identifier,
    STATE(4191), 1,
      sym__soft_identifier,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(10686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_while,
      anon_sym_match,
      anon_sym_else,
    ACTIONS(10477), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [505969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506002] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506035] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [506068] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11161), 1,
      sym__end_marker,
    STATE(10690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506103] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506136] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506202] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7694), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(10694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7692), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506235] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 2,
      anon_sym_case,
      anon_sym_EQ,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506274] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11145), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11143), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [506311] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12529), 1,
      anon_sym_LBRACK,
    ACTIONS(12531), 1,
      anon_sym_AT,
    ACTIONS(12533), 1,
      anon_sym_LPAREN,
    ACTIONS(12535), 1,
      anon_sym_POUND,
    STATE(11876), 1,
      sym_type_arguments,
    STATE(11934), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12554), 1,
      sym_annotation,
    STATE(13355), 1,
      sym_arguments,
    STATE(10697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [506358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [506391] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506424] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506490] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(10553), 1,
      sym__alpha_identifier,
    ACTIONS(10559), 1,
      sym__backquoted_id,
    ACTIONS(10561), 1,
      sym_operator_identifier,
    ACTIONS(11581), 1,
      anon_sym_EQ,
    STATE(596), 1,
      sym_identifier,
    STATE(4182), 1,
      sym__soft_identifier,
    STATE(10702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 4,
      anon_sym_while,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(10555), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [506539] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(7882), 3,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506578] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506611] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506644] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12357), 1,
      anon_sym_given,
    ACTIONS(12537), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(14838), 1,
      sym_identifier,
    ACTIONS(12355), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10706), 2,
      sym_comment,
      sym_block_comment,
    STATE(15888), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [506691] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506724] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506757] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(489), 1,
      sym__alpha_identifier,
    ACTIONS(553), 1,
      sym__backquoted_id,
    ACTIONS(12539), 1,
      anon_sym_LBRACE,
    ACTIONS(12543), 1,
      sym_operator_identifier,
    STATE(5518), 1,
      sym__soft_identifier,
    STATE(14412), 1,
      sym_identifier,
    STATE(10709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12541), 3,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_given,
    STATE(14707), 3,
      sym_namespace_wildcard,
      sym_namespace_selectors,
      sym_as_renamed_identifier,
    ACTIONS(677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [506804] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506837] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506870] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10925), 1,
      sym__alpha_identifier,
    ACTIONS(10933), 1,
      sym__backquoted_id,
    ACTIONS(10935), 1,
      sym_operator_identifier,
    STATE(628), 1,
      sym_identifier,
    STATE(4202), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_match,
      anon_sym_finally,
    STATE(10712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10929), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [506917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [506950] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(10590), 1,
      sym_operator_identifier,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_match,
      anon_sym_then,
    STATE(10714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 3,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [506999] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507032] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507065] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12357), 1,
      anon_sym_given,
    ACTIONS(12545), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(14710), 1,
      sym_identifier,
    ACTIONS(12355), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10717), 2,
      sym_comment,
      sym_block_comment,
    STATE(15497), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [507112] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507145] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(11035), 1,
      sym_operator_identifier,
    STATE(621), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [507192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507225] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11579), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(16029), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [507280] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11579), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(16029), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [507335] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10971), 1,
      sym__end_marker,
    STATE(10723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507370] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507403] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507436] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10355), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [507469] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(11031), 1,
      sym_operator_identifier,
    STATE(1702), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [507516] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507582] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507615] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10949), 1,
      sym__end_marker,
    STATE(10731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9449), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [507650] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507716] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507749] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(11220), 1,
      sym_operator_identifier,
    STATE(1847), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(10735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [507796] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507829] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11575), 1,
      anon_sym_COMMA,
    ACTIONS(11577), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(16035), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [507884] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11575), 1,
      anon_sym_COMMA,
    ACTIONS(11577), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(16035), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [507939] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [507972] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508005] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(9614), 1,
      sym__alpha_identifier,
    ACTIONS(9620), 1,
      sym__backquoted_id,
    ACTIONS(9622), 1,
      sym_operator_identifier,
    ACTIONS(11585), 1,
      anon_sym_EQ,
    STATE(608), 1,
      sym_identifier,
    STATE(4178), 1,
      sym__soft_identifier,
    STATE(10741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(9618), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [508054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9726), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [508087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11666), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [508120] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508153] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5874), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10122), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508190] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508223] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(11198), 1,
      sym_operator_identifier,
    STATE(1852), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_match,
      anon_sym_else,
    STATE(10747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [508270] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508336] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11194), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11196), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [508385] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508418] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508451] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508484] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508550] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 2,
      anon_sym_STAR,
      anon_sym_finally,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508589] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508622] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508688] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508721] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11571), 1,
      anon_sym_COMMA,
    ACTIONS(11573), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15987), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [508776] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10984), 1,
      sym__end_marker,
    STATE(10762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9449), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [508844] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11571), 1,
      anon_sym_COMMA,
    ACTIONS(11573), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15987), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [508899] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11478), 1,
      anon_sym_COMMA,
    ACTIONS(11480), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15913), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [508954] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11478), 1,
      anon_sym_COMMA,
    ACTIONS(11480), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15913), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [509009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509042] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509075] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9709), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [509108] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11176), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11174), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [509145] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9313), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509244] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509310] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509343] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12357), 1,
      anon_sym_given,
    ACTIONS(12359), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(14929), 1,
      sym_identifier,
    ACTIONS(12355), 2,
      anon_sym_STAR,
      anon_sym__,
    STATE(10777), 2,
      sym_comment,
      sym_block_comment,
    STATE(16617), 4,
      sym_namespace_wildcard,
      sym__namespace_given_by_type,
      sym_arrow_renamed_identifier,
      sym_as_renamed_identifier,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [509390] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509423] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509456] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509489] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509522] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509555] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509588] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509621] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 2,
      anon_sym_catch,
      anon_sym_finally,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509660] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509693] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(10553), 1,
      sym__alpha_identifier,
    ACTIONS(10559), 1,
      sym__backquoted_id,
    ACTIONS(10561), 1,
      sym_operator_identifier,
    ACTIONS(11504), 1,
      anon_sym_EQ,
    STATE(596), 1,
      sym_identifier,
    STATE(4182), 1,
      sym__soft_identifier,
    STATE(10787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 4,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(10555), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [509742] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509775] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509808] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 2,
      anon_sym_case,
      anon_sym_EQ,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509847] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12547), 1,
      anon_sym_LBRACK,
    ACTIONS(12549), 1,
      anon_sym_AT,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(12555), 1,
      sym__automatic_semicolon,
    STATE(11244), 1,
      sym_type_parameters,
    STATE(11751), 1,
      sym_annotation,
    STATE(13395), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13396), 1,
      sym_access_modifier,
    STATE(13914), 1,
      sym_class_parameters,
    ACTIONS(12551), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(10791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12375), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [509898] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [509931] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(489), 1,
      sym__alpha_identifier,
    ACTIONS(553), 1,
      sym__backquoted_id,
    ACTIONS(12539), 1,
      anon_sym_LBRACE,
    ACTIONS(12543), 1,
      sym_operator_identifier,
    STATE(5518), 1,
      sym__soft_identifier,
    STATE(14412), 1,
      sym_identifier,
    STATE(10793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12541), 3,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_given,
    STATE(14612), 3,
      sym_namespace_wildcard,
      sym_namespace_selectors,
      sym_as_renamed_identifier,
    ACTIONS(677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [509978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510011] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10620), 1,
      anon_sym_RPAREN,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15412), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [510066] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(7882), 3,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510105] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10620), 1,
      anon_sym_RPAREN,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15412), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [510160] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    STATE(10798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7564), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12558), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [510195] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10220), 14,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [510228] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(11535), 1,
      sym__alpha_identifier,
    ACTIONS(11539), 1,
      anon_sym_EQ,
    ACTIONS(11541), 1,
      sym__backquoted_id,
    ACTIONS(11543), 1,
      sym_operator_identifier,
    STATE(645), 1,
      sym_identifier,
    STATE(4209), 1,
      sym__soft_identifier,
    STATE(10800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11537), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [510277] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10911), 1,
      sym__alpha_identifier,
    ACTIONS(10917), 1,
      sym__backquoted_id,
    ACTIONS(11012), 1,
      sym_operator_identifier,
    STATE(626), 1,
      sym_identifier,
    STATE(4200), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [510324] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510390] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [510423] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(11008), 1,
      sym_operator_identifier,
    STATE(1722), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_case,
      anon_sym_match,
    STATE(10805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [510470] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510503] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11299), 1,
      anon_sym_RPAREN,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15873), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [510558] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510591] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12529), 1,
      anon_sym_LBRACK,
    ACTIONS(12531), 1,
      anon_sym_AT,
    ACTIONS(12535), 1,
      anon_sym_POUND,
    ACTIONS(12560), 1,
      anon_sym_LPAREN,
    STATE(11876), 1,
      sym_type_arguments,
    STATE(11934), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12554), 1,
      sym_annotation,
    STATE(13638), 1,
      sym_arguments,
    STATE(10809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [510638] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510704] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8931), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(10812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8929), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8927), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510739] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11299), 1,
      anon_sym_RPAREN,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15873), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [510794] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510827] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(12523), 1,
      anon_sym_LBRACE,
    ACTIONS(12527), 1,
      sym_operator_identifier,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(14251), 1,
      sym_identifier,
    STATE(10815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12525), 3,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_given,
    STATE(14589), 3,
      sym_namespace_wildcard,
      sym_namespace_selectors,
      sym_as_renamed_identifier,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [510874] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(11145), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11427), 1,
      anon_sym_AT,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11143), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510917] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510950] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [510983] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511016] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 2,
      anon_sym_else,
      anon_sym_finally,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511055] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(12169), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11196), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    STATE(10821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [511108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511174] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511207] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511240] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(9074), 15,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511273] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(11176), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11427), 1,
      anon_sym_AT,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11174), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511316] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11367), 1,
      anon_sym_COMMA,
    ACTIONS(11369), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15557), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [511371] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511404] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9403), 1,
      anon_sym_LPAREN,
    ACTIONS(12562), 1,
      anon_sym_LBRACK,
    ACTIONS(12564), 1,
      anon_sym_POUND,
    STATE(11272), 1,
      aux_sym_annotation_repeat1,
    STATE(11544), 1,
      sym_type_arguments,
    STATE(11776), 1,
      sym_arguments,
    STATE(10830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [511447] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11367), 1,
      anon_sym_COMMA,
    ACTIONS(11369), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15557), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [511502] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511535] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511568] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10475), 1,
      sym__alpha_identifier,
    ACTIONS(10481), 1,
      sym__backquoted_id,
    ACTIONS(10483), 1,
      sym_operator_identifier,
    ACTIONS(11512), 1,
      anon_sym_EQ,
    STATE(602), 1,
      sym_identifier,
    STATE(4191), 1,
      sym__soft_identifier,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    STATE(10834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_else,
      anon_sym_do,
    ACTIONS(10477), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [511617] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(11006), 1,
      sym_operator_identifier,
    STATE(1790), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8309), 2,
      anon_sym_match,
      anon_sym_finally,
    STATE(10835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [511664] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10124), 1,
      sym__backquoted_id,
    STATE(5509), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10122), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511701] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    ACTIONS(11551), 1,
      anon_sym_EQ_GT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(17844), 1,
      sym_guard,
    STATE(10837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [511756] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511789] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11000), 1,
      sym__end_marker,
    STATE(10839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511824] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    ACTIONS(11551), 1,
      anon_sym_EQ_GT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(17844), 1,
      sym_guard,
    STATE(10840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [511879] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [511945] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(10911), 1,
      sym__alpha_identifier,
    ACTIONS(10917), 1,
      sym__backquoted_id,
    ACTIONS(10919), 1,
      sym_operator_identifier,
    STATE(646), 1,
      sym_identifier,
    STATE(4200), 1,
      sym__soft_identifier,
    ACTIONS(8305), 2,
      anon_sym_COLON,
      anon_sym_if,
    STATE(10843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9616), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(10913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [511994] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11377), 1,
      anon_sym_EQ_GT,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(18342), 1,
      sym_guard,
    STATE(10844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [512049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512082] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512115] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512148] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512181] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9313), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512214] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512247] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8309), 1,
      anon_sym_match,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(11464), 1,
      sym_operator_identifier,
    STATE(1709), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [512296] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512329] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11455), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15955), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [512384] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5732), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10122), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9315), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(10855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9313), 16,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512454] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512520] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 2,
      anon_sym_case,
      anon_sym_if,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512559] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11455), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15955), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [512614] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(10911), 1,
      sym__alpha_identifier,
    ACTIONS(10917), 1,
      sym__backquoted_id,
    ACTIONS(10919), 1,
      sym_operator_identifier,
    ACTIONS(11318), 1,
      anon_sym_EQ,
    STATE(646), 1,
      sym_identifier,
    STATE(4200), 1,
      sym__soft_identifier,
    STATE(10860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [512663] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512696] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    ACTIONS(11453), 1,
      anon_sym_EQ_GT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(17930), 1,
      sym_guard,
    STATE(10862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [512751] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    ACTIONS(11453), 1,
      anon_sym_EQ_GT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(17930), 1,
      sym_guard,
    STATE(10863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [512806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512839] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10935), 1,
      sym_arguments,
    STATE(10865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7750), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512874] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [512907] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(10911), 1,
      sym__alpha_identifier,
    ACTIONS(10917), 1,
      sym__backquoted_id,
    ACTIONS(10919), 1,
      sym_operator_identifier,
    STATE(646), 1,
      sym_identifier,
    STATE(4200), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_if,
      anon_sym_match,
    STATE(10867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(10913), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [512954] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11377), 1,
      anon_sym_EQ_GT,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(18342), 1,
      sym_guard,
    STATE(10868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [513009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513042] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513075] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513108] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9610), 1,
      anon_sym_LPAREN,
    ACTIONS(12566), 1,
      anon_sym_LBRACK,
    ACTIONS(12568), 1,
      anon_sym_POUND,
    STATE(11278), 1,
      aux_sym_annotation_repeat1,
    STATE(11467), 1,
      sym_type_arguments,
    STATE(12009), 1,
      sym_arguments,
    STATE(10872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [513151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513184] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 2,
      anon_sym_STAR,
      anon_sym_else,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513223] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513256] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513322] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [513355] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513388] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513454] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7972), 1,
      anon_sym_QMARK_EQ_GT,
    ACTIONS(12171), 1,
      anon_sym_EQ_GT,
    STATE(10882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513491] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513557] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(8171), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513596] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513662] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513695] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513728] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513794] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10220), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [513826] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11176), 1,
      sym__backquoted_id,
    ACTIONS(11381), 1,
      anon_sym_AT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(10893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11174), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(10894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [513896] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513960] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [513992] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11773), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514042] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12570), 1,
      anon_sym_LBRACK,
    ACTIONS(12572), 1,
      anon_sym_AT,
    ACTIONS(12574), 1,
      anon_sym_LPAREN,
    ACTIONS(12576), 1,
      anon_sym_POUND,
    STATE(12319), 1,
      sym_type_arguments,
    STATE(12384), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13052), 1,
      sym_annotation,
    STATE(13746), 1,
      sym_arguments,
    STATE(10899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [514088] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(10618), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514138] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9709), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514170] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(10618), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514220] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(10903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514254] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10226), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514286] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11666), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [514318] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10242), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514382] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514414] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514446] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11773), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514496] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514528] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11744), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514578] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514610] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514642] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12578), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [514672] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11737), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514704] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10355), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514768] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514800] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11744), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(10920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514850] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8309), 1,
      anon_sym_match,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(11464), 1,
      sym_operator_identifier,
    STATE(1709), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    STATE(10921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8307), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514896] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12580), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(10922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [514950] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5553), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10122), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [514986] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11787), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515050] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12582), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [515080] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515112] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12584), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(15863), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(10928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [515166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9656), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515198] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12586), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [515228] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(5094), 1,
      anon_sym_RPAREN,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(10931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [515282] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12588), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [515312] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12590), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [515342] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515374] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10253), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515406] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7750), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515438] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 17,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [515468] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11455), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15955), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [515520] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    ACTIONS(11453), 1,
      anon_sym_EQ_GT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(17930), 1,
      sym_guard,
    STATE(10939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [515572] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12592), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [515602] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12594), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [515632] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515664] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515696] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515728] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(11535), 1,
      sym__alpha_identifier,
    ACTIONS(11541), 1,
      sym__backquoted_id,
    ACTIONS(11543), 1,
      sym_operator_identifier,
    STATE(645), 1,
      sym_identifier,
    STATE(4209), 1,
      sym__soft_identifier,
    STATE(10945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(11537), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [515774] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 4,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515806] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(2538), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(2533), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515838] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10220), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515870] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9726), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [515902] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [515966] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 17,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [515996] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516028] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12596), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [516058] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516090] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    ACTIONS(11551), 1,
      anon_sym_EQ_GT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(17844), 1,
      sym_guard,
    STATE(10956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [516142] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(10957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [516174] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516206] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516238] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12598), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [516268] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(6046), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(10961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10124), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(10122), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516304] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12600), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(15945), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(10962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [516358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11815), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516390] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10019), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516422] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516454] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11299), 1,
      anon_sym_RPAREN,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15873), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [516506] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516538] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516570] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11621), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516602] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11326), 1,
      sym__end_marker,
    STATE(10970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516636] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516668] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11367), 1,
      anon_sym_COMMA,
    ACTIONS(11369), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15557), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [516720] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10017), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10015), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516752] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516784] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516816] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_STAR,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516854] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 2,
      anon_sym_LT_COLON,
      anon_sym_EQ,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(10977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7882), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516924] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7882), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516956] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12602), 1,
      anon_sym_LPAREN,
    STATE(11560), 1,
      sym_arguments,
    ACTIONS(8114), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(10980), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8112), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [516992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517024] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11621), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10001), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9999), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517088] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9726), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517120] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11775), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(10985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [517170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9989), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9987), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517202] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7336), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7334), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517234] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9983), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9981), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9709), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [517298] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9656), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [517330] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12605), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [517360] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12607), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [517390] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9979), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9977), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517422] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9517), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517454] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10620), 1,
      anon_sym_RPAREN,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15412), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(10995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [517506] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517538] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517570] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11377), 1,
      anon_sym_EQ_GT,
    ACTIONS(11379), 1,
      anon_sym_if,
    ACTIONS(11383), 1,
      anon_sym_PIPE,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(18342), 1,
      sym_guard,
    STATE(10998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [517622] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9534), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9536), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517654] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517686] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_else,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517724] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9521), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517756] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517788] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9558), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517820] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517852] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [517884] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517916] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9971), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9969), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517948] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9628), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [517980] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518012] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9778), 1,
      anon_sym_LPAREN,
    ACTIONS(12609), 1,
      anon_sym_LBRACK,
    ACTIONS(12611), 1,
      anon_sym_POUND,
    STATE(11684), 1,
      aux_sym_annotation_repeat1,
    STATE(11845), 1,
      sym_type_arguments,
    STATE(12446), 1,
      sym_arguments,
    STATE(11011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [518054] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10383), 1,
      anon_sym_LPAREN,
    ACTIONS(12613), 1,
      anon_sym_LBRACK,
    ACTIONS(12615), 1,
      anon_sym_POUND,
    STATE(11466), 1,
      aux_sym_annotation_repeat1,
    STATE(11962), 1,
      sym_type_arguments,
    STATE(12273), 1,
      sym_arguments,
    STATE(11012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [518096] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7766), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518128] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518160] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9740), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518192] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518224] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11791), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [518274] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12617), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [518328] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 17,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [518358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9957), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9955), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518390] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11775), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(11021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [518440] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518472] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12619), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [518526] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10286), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518558] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11787), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518622] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 3,
      anon_sym_COLON,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518660] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518692] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518724] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518756] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518788] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_EQ,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [518826] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12529), 1,
      anon_sym_LBRACK,
    ACTIONS(12531), 1,
      anon_sym_AT,
    ACTIONS(12535), 1,
      anon_sym_POUND,
    STATE(11876), 1,
      sym_type_arguments,
    STATE(11934), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12554), 1,
      sym_annotation,
    STATE(11033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [518868] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11571), 1,
      anon_sym_COMMA,
    ACTIONS(11573), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15987), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(11034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [518920] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11478), 1,
      anon_sym_COMMA,
    ACTIONS(11480), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(15913), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(11035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [518972] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519004] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(11159), 1,
      sym__alpha_identifier,
    ACTIONS(11165), 1,
      sym__backquoted_id,
    ACTIONS(11167), 1,
      sym_operator_identifier,
    ACTIONS(11751), 1,
      anon_sym_EQ,
    STATE(622), 1,
      sym_identifier,
    STATE(4205), 1,
      sym__soft_identifier,
    STATE(11037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(11161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [519052] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11382), 1,
      aux_sym_compound_type_repeat1,
    STATE(13001), 1,
      sym__refinement,
    STATE(13003), 1,
      sym_template_body,
    STATE(13355), 1,
      sym_arguments,
    STATE(11038), 2,
      sym_comment,
      sym_block_comment,
    STATE(13322), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [519092] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11785), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [519142] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9931), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9929), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519174] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [519206] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12621), 1,
      anon_sym_DOT,
    STATE(11042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [519238] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_finally,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519276] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11176), 1,
      sym__backquoted_id,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11174), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519314] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11785), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [519364] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9676), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [519396] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519428] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9676), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519460] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11145), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11143), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519498] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11145), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11143), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519536] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519568] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9896), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9894), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519600] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9892), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9890), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519632] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(9313), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519664] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11633), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [519714] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519778] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 3,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PIPE,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519816] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519848] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519880] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12623), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [519934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11673), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [519998] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(5016), 1,
      anon_sym_RPAREN,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [520052] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11196), 1,
      anon_sym_PIPE,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11194), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(11065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [520102] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520134] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520198] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520230] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520262] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520294] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520326] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [520358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11737), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520390] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11196), 1,
      anon_sym_PIPE,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11194), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(11075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [520440] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520472] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11575), 1,
      anon_sym_COMMA,
    ACTIONS(11577), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(16035), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(11077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [520524] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520556] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520588] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520620] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11683), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520652] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9794), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9792), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520684] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12629), 1,
      anon_sym_case,
    ACTIONS(12631), 1,
      anon_sym_EQ,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    STATE(11083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12627), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520722] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12635), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [520776] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(5044), 1,
      anon_sym_RPAREN,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [520830] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12639), 1,
      anon_sym_case,
    ACTIONS(12641), 1,
      anon_sym_EQ,
    STATE(11086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12637), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520868] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11687), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520900] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [520932] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11381), 1,
      anon_sym_AT,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11196), 3,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [520980] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9800), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521012] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521044] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521076] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521108] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10610), 1,
      anon_sym_DOT,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11633), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521158] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521190] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521222] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10616), 1,
      anon_sym_AT,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11791), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521272] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9804), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521304] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12643), 1,
      anon_sym_with,
    STATE(11255), 1,
      aux_sym_compound_type_repeat1,
    STATE(13638), 1,
      sym_arguments,
    STATE(13657), 1,
      sym__refinement,
    STATE(13663), 1,
      sym_template_body,
    STATE(11099), 2,
      sym_comment,
      sym_block_comment,
    STATE(13616), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [521346] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12529), 1,
      anon_sym_LBRACK,
    ACTIONS(12533), 1,
      anon_sym_LPAREN,
    ACTIONS(12535), 1,
      anon_sym_POUND,
    STATE(11789), 1,
      aux_sym_annotation_repeat1,
    STATE(11876), 1,
      sym_type_arguments,
    STATE(12538), 1,
      sym_arguments,
    STATE(11100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [521388] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11699), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521420] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9411), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521452] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 4,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521484] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521516] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521548] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12629), 1,
      anon_sym_case,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12645), 1,
      anon_sym_EQ,
    STATE(11106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12627), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521586] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11196), 3,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521634] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    ACTIONS(11579), 1,
      anon_sym_RPAREN,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(16029), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(11108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [521686] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11705), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521718] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12490), 1,
      anon_sym_LPAREN,
    STATE(10980), 1,
      aux_sym_annotation_repeat1,
    STATE(11560), 1,
      sym_arguments,
    ACTIONS(8123), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(11110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8121), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521756] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521788] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8947), 1,
      anon_sym_LPAREN,
    STATE(11173), 1,
      aux_sym_annotation_repeat1,
    STATE(11499), 1,
      sym_arguments,
    STATE(11112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [521824] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9415), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521888] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10299), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521920] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521952] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9419), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [521984] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522016] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522080] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12647), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [522110] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12649), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [522140] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9827), 14,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522172] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12651), 1,
      anon_sym_DOT,
    STATE(11124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522206] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522238] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12653), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(15378), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [522292] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11145), 1,
      sym__backquoted_id,
    ACTIONS(11381), 1,
      anon_sym_AT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11143), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522330] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522362] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11721), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522394] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522426] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11145), 1,
      sym__backquoted_id,
    ACTIONS(11373), 1,
      anon_sym_DOT,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11143), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522464] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11815), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522496] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12639), 1,
      anon_sym_case,
    ACTIONS(12655), 1,
      anon_sym_EQ,
    STATE(11133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12637), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522534] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522598] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(5048), 1,
      anon_sym_RPAREN,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [522652] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_EQ_GT,
      anon_sym_LT_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522684] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12657), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [522738] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522770] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522802] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12379), 1,
      anon_sym_AT,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(12661), 1,
      sym__automatic_semicolon,
    STATE(11470), 1,
      sym_annotation,
    STATE(12670), 1,
      aux_sym__class_constructor_repeat1,
    STATE(12675), 1,
      sym_access_modifier,
    STATE(13630), 1,
      sym_class_parameters,
    ACTIONS(12381), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12659), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [522848] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 3,
      sym__outdent,
      anon_sym_LBRACE,
      sym__backquoted_id,
    ACTIONS(7692), 14,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_with,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522880] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(4982), 1,
      anon_sym_RPAREN,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [522934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [522966] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12664), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [523020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523052] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523084] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11683), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523148] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11687), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523180] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523212] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11293), 1,
      anon_sym_DOT,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11176), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11174), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523250] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523282] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12666), 1,
      anon_sym_LBRACK,
    ACTIONS(12668), 1,
      anon_sym_LPAREN,
    ACTIONS(12670), 1,
      anon_sym_POUND,
    STATE(11846), 1,
      aux_sym_annotation_repeat1,
    STATE(11940), 1,
      sym_type_arguments,
    STATE(12768), 1,
      sym_arguments,
    STATE(11154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [523324] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11673), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523356] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523388] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11297), 1,
      anon_sym_AT,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11176), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11174), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523426] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11699), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523458] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11705), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523490] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11721), 13,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523522] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523554] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(4994), 1,
      anon_sym_RPAREN,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [523608] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523640] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523672] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(10295), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523704] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 12,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_end,
      anon_sym_if,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523736] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(11159), 1,
      sym__alpha_identifier,
    ACTIONS(11165), 1,
      sym__backquoted_id,
    ACTIONS(11167), 1,
      sym_operator_identifier,
    ACTIONS(11628), 1,
      anon_sym_EQ,
    STATE(622), 1,
      sym_identifier,
    STATE(4205), 1,
      sym__soft_identifier,
    STATE(11167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9022), 3,
      anon_sym_while,
      anon_sym_match,
      anon_sym_finally,
    ACTIONS(11161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [523784] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 4,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10355), 13,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_while,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_then,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_do,
  [523816] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523848] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523880] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [523944] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12672), 1,
      anon_sym_LPAREN,
    STATE(11499), 1,
      sym_arguments,
    STATE(11173), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [523978] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12675), 17,
      sym__indent,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_def,
      anon_sym_abstract,
      anon_sym_final,
      anon_sym_sealed,
      anon_sym_implicit,
      anon_sym_lazy,
      anon_sym_override,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_LPAREN,
  [524008] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524040] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 12,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_catch,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524072] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12677), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [524126] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12570), 1,
      anon_sym_LBRACK,
    ACTIONS(12572), 1,
      anon_sym_AT,
    ACTIONS(12576), 1,
      anon_sym_POUND,
    ACTIONS(12679), 1,
      anon_sym_LPAREN,
    STATE(12319), 1,
      sym_type_arguments,
    STATE(12384), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13052), 1,
      sym_annotation,
    STATE(13440), 1,
      sym_arguments,
    STATE(11178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [524172] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    ACTIONS(12681), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [524226] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524258] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11214), 1,
      sym__end_marker,
    STATE(11181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524292] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11145), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11143), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524327] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12683), 1,
      anon_sym_EQ,
    STATE(11183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12627), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524362] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(11184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 5,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524397] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524428] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524490] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11533), 1,
      aux_sym_compound_type_repeat1,
    STATE(13440), 1,
      sym_arguments,
    STATE(13526), 1,
      sym__refinement,
    STATE(13529), 1,
      sym_template_body,
    STATE(11188), 2,
      sym_comment,
      sym_block_comment,
    STATE(13431), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [524529] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524560] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9806), 1,
      sym__backquoted_id,
    STATE(11190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9804), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11683), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524622] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11687), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524653] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11699), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524684] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9802), 1,
      sym__backquoted_id,
    STATE(11194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9800), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8585), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524777] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11705), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524808] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11721), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524839] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524870] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12685), 1,
      anon_sym_end,
    STATE(5488), 1,
      sym__end_marker,
    STATE(11200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [524903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [524965] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12405), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(10198), 1,
      sym_annotation,
    STATE(11530), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13033), 1,
      sym_inline_modifier,
    STATE(16635), 1,
      sym_parameter,
    STATE(18472), 1,
      sym_identifier,
    STATE(11203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525016] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525047] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11787), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525078] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11815), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525140] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8587), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525202] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [525262] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10299), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [525293] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10295), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [525324] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525355] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11596), 1,
      anon_sym_EQ,
    ACTIONS(12687), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525404] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11596), 1,
      anon_sym_EQ,
    ACTIONS(12687), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8583), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525484] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11600), 1,
      anon_sym_EQ,
    ACTIONS(12689), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525533] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11600), 1,
      anon_sym_EQ,
    ACTIONS(12689), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525582] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525613] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11176), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11174), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525648] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11451), 1,
      anon_sym_EQ,
    ACTIONS(12691), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525697] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9829), 1,
      sym__backquoted_id,
    STATE(11223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9827), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525728] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11744), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525775] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525806] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11451), 1,
      anon_sym_EQ,
    ACTIONS(12691), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525855] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11196), 1,
      anon_sym_PIPE,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11194), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(11227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [525902] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525933] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525964] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [525995] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11737), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526026] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [526055] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526086] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10286), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [526117] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12693), 1,
      anon_sym_LBRACK,
    ACTIONS(12695), 1,
      anon_sym_LPAREN,
    ACTIONS(12697), 1,
      anon_sym_POUND,
    STATE(12134), 1,
      aux_sym_annotation_repeat1,
    STATE(12256), 1,
      sym_type_arguments,
    STATE(13151), 1,
      sym_arguments,
    STATE(11235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [526158] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12699), 1,
      anon_sym_with,
    STATE(11439), 1,
      aux_sym_compound_type_repeat1,
    STATE(13746), 1,
      sym_arguments,
    STATE(13930), 1,
      sym__refinement,
    STATE(13932), 1,
      sym_template_body,
    STATE(11236), 2,
      sym_comment,
      sym_block_comment,
    STATE(14051), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [526199] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526230] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [526259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526290] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526321] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [526350] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(7882), 2,
      anon_sym_COLON,
      anon_sym_LT_PERCENT,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12703), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12701), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [526418] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12549), 1,
      anon_sym_AT,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(12705), 1,
      sym__automatic_semicolon,
    STATE(11808), 1,
      sym_annotation,
    STATE(13375), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13376), 1,
      sym_access_modifier,
    STATE(13914), 1,
      sym_class_parameters,
    ACTIONS(12551), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12659), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [526463] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526494] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12710), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12708), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [526525] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7882), 2,
      anon_sym_STAR,
      anon_sym_EQ,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526562] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11445), 1,
      anon_sym_EQ,
    ACTIONS(12712), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [526611] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [526640] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12716), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12714), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [526671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526702] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11445), 1,
      anon_sym_EQ,
    ACTIONS(12712), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [526751] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(10618), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [526798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526829] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12643), 1,
      anon_sym_with,
    STATE(12777), 1,
      aux_sym_compound_type_repeat1,
    STATE(13644), 1,
      sym__refinement,
    STATE(13663), 1,
      sym_template_body,
    STATE(11255), 2,
      sym_comment,
      sym_block_comment,
    STATE(13616), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [526868] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526899] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 4,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12718), 1,
      anon_sym_DOT,
    STATE(11258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [526965] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9800), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [526996] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(10590), 1,
      sym_operator_identifier,
    ACTIONS(11920), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_while,
      anon_sym_match,
    STATE(11260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [527043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11621), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527074] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7882), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527105] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11633), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [527152] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9804), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527183] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10242), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [527214] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12720), 1,
      anon_sym_EQ,
    STATE(11266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12627), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527249] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12722), 1,
      anon_sym_EQ,
    STATE(11267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12637), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527284] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [527313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527344] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10226), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [527375] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8303), 1,
      sym__alpha_identifier,
    ACTIONS(8305), 1,
      anon_sym_COLON,
    ACTIONS(8313), 1,
      sym__backquoted_id,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(10590), 1,
      sym_operator_identifier,
    ACTIONS(11874), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(9022), 2,
      anon_sym_match,
      anon_sym_do,
    STATE(11271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8311), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [527422] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9403), 1,
      anon_sym_LPAREN,
    STATE(11313), 1,
      aux_sym_annotation_repeat1,
    STATE(11776), 1,
      sym_arguments,
    STATE(11272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [527457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527488] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527519] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11176), 1,
      sym__backquoted_id,
    ACTIONS(11427), 1,
      anon_sym_AT,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11174), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527556] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12724), 1,
      anon_sym_LPAREN,
    STATE(12009), 1,
      sym_arguments,
    STATE(11276), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [527589] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9415), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527620] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9610), 1,
      anon_sym_LPAREN,
    STATE(11276), 1,
      aux_sym_annotation_repeat1,
    STATE(12009), 1,
      sym_arguments,
    STATE(11278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [527655] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [527684] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11176), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11174), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527721] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12570), 1,
      anon_sym_LBRACK,
    ACTIONS(12576), 1,
      anon_sym_POUND,
    ACTIONS(12679), 1,
      anon_sym_LPAREN,
    STATE(12112), 1,
      aux_sym_annotation_repeat1,
    STATE(12319), 1,
      sym_type_arguments,
    STATE(13230), 1,
      sym_arguments,
    STATE(11281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [527762] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(12169), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11196), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    STATE(11282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [527809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527840] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [527902] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8517), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527933] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527964] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8501), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [527995] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528026] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9419), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [528057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9415), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [528088] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(12169), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11196), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    STATE(11292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528135] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [528164] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    STATE(11294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7564), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12558), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528197] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12729), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12727), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [528228] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [528290] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [528319] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12733), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12731), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [528412] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12633), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12625), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [528443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12737), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12735), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [528474] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9521), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528505] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 16,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [528534] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12741), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12739), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [528565] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [528596] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [528625] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528656] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11785), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528703] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528734] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9827), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528765] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12743), 1,
      anon_sym_LPAREN,
    STATE(11776), 1,
      sym_arguments,
    STATE(11313), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [528798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9411), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [528829] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528860] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11291), 1,
      anon_sym_COLON,
    ACTIONS(11295), 1,
      anon_sym_STAR,
    ACTIONS(11301), 1,
      anon_sym_PIPE,
    ACTIONS(11303), 1,
      sym_operator_identifier,
    STATE(4272), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11775), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(11316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [528907] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9827), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528938] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11145), 1,
      sym__backquoted_id,
    ACTIONS(11427), 1,
      anon_sym_AT,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11143), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [528975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9515), 1,
      sym__backquoted_id,
    STATE(11319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9517), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529006] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [529035] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [529064] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(12033), 1,
      sym__alpha_identifier,
    ACTIONS(12039), 1,
      sym__backquoted_id,
    ACTIONS(12041), 1,
      sym_operator_identifier,
    STATE(1076), 1,
      sym_identifier,
    STATE(4316), 1,
      sym__soft_identifier,
    ACTIONS(8305), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    STATE(11322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12037), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [529111] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [529140] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [529171] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11145), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11143), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529239] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9517), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529270] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12748), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12746), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [529301] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11588), 1,
      sym__end_marker,
    STATE(11329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9449), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529334] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9519), 1,
      sym__backquoted_id,
    STATE(11330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529365] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [529394] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529425] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(11333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [529456] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [529485] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529516] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5533), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    ACTIONS(10124), 2,
      anon_sym_LBRACE,
      sym__backquoted_id,
    STATE(11336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10122), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9558), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529582] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8465), 1,
      anon_sym_LPAREN,
    ACTIONS(12750), 1,
      anon_sym_LBRACK,
    ACTIONS(12752), 1,
      anon_sym_POUND,
    STATE(11965), 1,
      aux_sym_annotation_repeat1,
    STATE(12107), 1,
      sym_type_arguments,
    STATE(12800), 1,
      sym_arguments,
    STATE(11338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 10,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [529623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [529652] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(11340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [529683] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9804), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529714] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8525), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9800), 13,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529776] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9556), 1,
      sym__backquoted_id,
    STATE(11344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9558), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529807] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
      anon_sym_LT_DASH,
  [529838] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [529867] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 4,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529898] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [529927] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529958] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7766), 13,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_LT_PERCENT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [529989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8002), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530020] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8177), 1,
      anon_sym_EQ,
    STATE(675), 1,
      sym_identifier,
    STATE(4210), 1,
      sym__soft_identifier,
    ACTIONS(8173), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(11352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8171), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530057] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11145), 1,
      sym__backquoted_id,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11143), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530092] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9626), 1,
      sym__backquoted_id,
    STATE(11354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9628), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530123] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7564), 2,
      anon_sym_DOT,
      sym__backquoted_id,
    STATE(11355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12558), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530156] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 16,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [530185] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(5752), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    ACTIONS(10124), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10122), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530220] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9738), 1,
      sym__backquoted_id,
    STATE(11358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9740), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530251] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530282] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12754), 1,
      anon_sym_EQ,
    STATE(11360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12637), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530317] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11439), 1,
      anon_sym_EQ,
    ACTIONS(12756), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530366] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530401] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11371), 1,
      anon_sym_COLON,
    ACTIONS(11375), 1,
      anon_sym_STAR,
    ACTIONS(11385), 1,
      sym_operator_identifier,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11196), 3,
      anon_sym_EQ_GT,
      anon_sym_if,
      anon_sym_PIPE,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530446] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11439), 1,
      anon_sym_EQ,
    ACTIONS(12756), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530495] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11526), 1,
      anon_sym_EQ,
    ACTIONS(12758), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530544] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8541), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530575] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11176), 1,
      sym__backquoted_id,
    STATE(4293), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11174), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530610] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12760), 1,
      anon_sym_EQ,
    STATE(11368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12627), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530645] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530676] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9411), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530707] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11533), 1,
      anon_sym_EQ,
    ACTIONS(12762), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530756] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11533), 1,
      anon_sym_EQ,
    ACTIONS(12762), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530805] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11773), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530852] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11429), 1,
      anon_sym_EQ,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(12764), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8527), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [530932] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11429), 1,
      anon_sym_EQ,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(12764), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [530981] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10859), 1,
      anon_sym_LPAREN,
    ACTIONS(12766), 1,
      anon_sym_LBRACK,
    ACTIONS(12768), 1,
      anon_sym_POUND,
    STATE(11832), 1,
      aux_sym_annotation_repeat1,
    STATE(12233), 1,
      sym_type_arguments,
    STATE(12595), 1,
      sym_arguments,
    STATE(11377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [531022] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8529), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531053] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_finally,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531084] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9419), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531115] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11673), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531146] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12777), 1,
      aux_sym_compound_type_repeat1,
    STATE(12985), 1,
      sym__refinement,
    STATE(13003), 1,
      sym_template_body,
    STATE(11382), 2,
      sym_comment,
      sym_block_comment,
    STATE(13322), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [531183] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12570), 1,
      anon_sym_LBRACK,
    ACTIONS(12572), 1,
      anon_sym_AT,
    ACTIONS(12576), 1,
      anon_sym_POUND,
    STATE(12319), 1,
      sym_type_arguments,
    STATE(12384), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13052), 1,
      sym_annotation,
    STATE(11383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [531224] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11526), 1,
      anon_sym_EQ,
    ACTIONS(12758), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531273] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531304] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11564), 1,
      anon_sym_EQ,
    ACTIONS(12770), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12772), 1,
      anon_sym_DOT,
    STATE(11387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [531384] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9740), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531415] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11564), 1,
      anon_sym_EQ,
    ACTIONS(12770), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531464] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531495] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12774), 1,
      anon_sym_AT,
    STATE(11975), 1,
      sym_annotation,
    ACTIONS(8603), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(11391), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8601), 11,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531530] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11423), 1,
      anon_sym_DOT,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11560), 1,
      anon_sym_EQ,
    ACTIONS(12777), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531579] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531610] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [531639] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11427), 1,
      anon_sym_AT,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11560), 1,
      anon_sym_EQ,
    ACTIONS(12777), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531688] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12779), 1,
      anon_sym_EQ,
    STATE(11396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12637), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    STATE(11397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7766), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531754] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10606), 1,
      anon_sym_COLON,
    ACTIONS(10612), 1,
      anon_sym_STAR,
    ACTIONS(10622), 1,
      anon_sym_PIPE,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(10626), 1,
      sym_operator_identifier,
    STATE(4294), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11791), 2,
      anon_sym_EQ,
      anon_sym_LT_DASH,
    STATE(11398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [531801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7766), 11,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531832] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [531861] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_EQ,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531898] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9628), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8531), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [531960] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 16,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [531989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8638), 13,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_POUND,
      sym__alpha_identifier,
      sym_operator_identifier,
  [532020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 11,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_else,
      sym__alpha_identifier,
      sym_operator_identifier,
  [532051] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12781), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11407), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532095] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12783), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11408), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532139] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11560), 1,
      anon_sym_EQ,
    ACTIONS(12777), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532185] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12785), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11410), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532229] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12787), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11411), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532273] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [532301] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12789), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11413), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532345] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12791), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11414), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532389] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12793), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11415), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532433] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12795), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11416), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532477] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12797), 1,
      sym__alpha_identifier,
    ACTIONS(12799), 1,
      anon_sym_object,
    ACTIONS(12801), 1,
      anon_sym_class,
    ACTIONS(12805), 1,
      sym__backquoted_id,
    ACTIONS(12807), 1,
      sym_operator_identifier,
    STATE(12758), 1,
      sym_identifier,
    STATE(14377), 1,
      sym__soft_identifier,
    STATE(14675), 1,
      sym_simple_enum_case,
    STATE(15600), 1,
      sym_full_enum_case,
    STATE(11417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12803), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532523] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12809), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11418), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9800), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [532597] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(12813), 1,
      sym__automatic_semicolon,
    STATE(12665), 1,
      aux_sym__class_constructor_repeat1,
    STATE(12666), 1,
      sym_access_modifier,
    STATE(13630), 1,
      sym_class_parameters,
    ACTIONS(12381), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12811), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [532637] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [532665] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12816), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11422), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532709] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12818), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11423), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [532781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8694), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [532811] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [532839] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12820), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11427), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532883] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12822), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11428), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [532927] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [532955] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12824), 1,
      anon_sym_DOT,
    STATE(11430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [532985] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [533013] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12826), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11432), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533057] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12828), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11433), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533101] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12830), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11434), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533145] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12832), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11435), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533189] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12834), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11436), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533233] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11668), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(11666), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [533263] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(7062), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [533293] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12699), 1,
      anon_sym_with,
    STATE(13034), 1,
      aux_sym_compound_type_repeat1,
    STATE(13864), 1,
      sym__refinement,
    STATE(13932), 1,
      sym_template_body,
    STATE(11439), 2,
      sym_comment,
      sym_block_comment,
    STATE(14051), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [533331] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12836), 1,
      anon_sym_RPAREN,
    ACTIONS(12838), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15220), 1,
      sym_binding,
    STATE(15424), 1,
      sym_identifier,
    STATE(15431), 1,
      sym_wildcard,
    STATE(11440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533377] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [533405] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12840), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11442), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533449] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12842), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11443), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533493] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(4176), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [533523] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12844), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11445), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533567] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11564), 1,
      anon_sym_EQ,
    ACTIONS(12770), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533613] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(11447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [533643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12848), 1,
      anon_sym_STAR,
    STATE(11448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [533673] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [533701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(4176), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [533731] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12850), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11451), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [533775] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12852), 1,
      anon_sym_LPAREN,
    STATE(12273), 1,
      sym_arguments,
    STATE(11452), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [533807] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [533835] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_COLON,
    ACTIONS(7880), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [533871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7556), 1,
      sym__backquoted_id,
    STATE(11455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8662), 14,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [533901] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(8662), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [533931] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [533959] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12855), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11458), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534003] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534031] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12857), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11460), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534075] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11429), 1,
      anon_sym_EQ,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(12764), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534121] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11533), 1,
      anon_sym_EQ,
    ACTIONS(12762), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534167] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12859), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11463), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534211] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12861), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11464), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534255] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534283] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10383), 1,
      anon_sym_LPAREN,
    STATE(11452), 1,
      aux_sym_annotation_repeat1,
    STATE(12273), 1,
      sym_arguments,
    STATE(11466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [534317] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534345] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8703), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [534375] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12863), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11469), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534419] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(12867), 1,
      sym__automatic_semicolon,
    STATE(12562), 1,
      aux_sym__class_constructor_repeat1,
    STATE(12565), 1,
      sym_access_modifier,
    STATE(13630), 1,
      sym_class_parameters,
    ACTIONS(12381), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12865), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [534459] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7316), 1,
      anon_sym_object,
    ACTIONS(7318), 1,
      anon_sym_class,
    ACTIONS(12870), 1,
      sym__alpha_identifier,
    ACTIONS(12874), 1,
      sym__backquoted_id,
    ACTIONS(12876), 1,
      sym_operator_identifier,
    STATE(12557), 1,
      sym_identifier,
    STATE(14423), 1,
      sym__soft_identifier,
    STATE(14603), 1,
      sym_simple_enum_case,
    STATE(15702), 1,
      sym_full_enum_case,
    STATE(11471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12872), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8687), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [534535] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534563] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12878), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11474), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534607] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12880), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11475), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534651] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12882), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11476), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534695] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534723] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12884), 1,
      anon_sym_DOT,
    STATE(11479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [534781] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11439), 1,
      anon_sym_EQ,
    ACTIONS(12756), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534827] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534855] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [534883] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11526), 1,
      anon_sym_EQ,
    ACTIONS(12758), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534929] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12886), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11484), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [534973] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12888), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11485), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535017] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12890), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11486), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535061] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535089] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12892), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11488), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535133] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12838), 1,
      sym_operator_identifier,
    ACTIONS(12894), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15424), 1,
      sym_identifier,
    STATE(15431), 1,
      sym_wildcard,
    STATE(16644), 1,
      sym_binding,
    STATE(11489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535179] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12896), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11490), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535223] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [535251] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12898), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11492), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535295] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [535323] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12900), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11494), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535367] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12902), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11495), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535411] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8537), 1,
      anon_sym_LPAREN,
    ACTIONS(12904), 1,
      anon_sym_LBRACK,
    ACTIONS(12906), 1,
      anon_sym_POUND,
    STATE(12393), 1,
      aux_sym_annotation_repeat1,
    STATE(12824), 1,
      sym_type_arguments,
    STATE(13391), 1,
      sym_arguments,
    STATE(11496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [535451] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12908), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11497), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535495] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12910), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11498), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535539] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535567] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12912), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11500), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535611] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12914), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11501), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535655] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12916), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11502), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535699] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535727] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12918), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11504), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535771] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12920), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11505), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535815] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12922), 1,
      anon_sym_end,
    STATE(6058), 1,
      sym__end_marker,
    STATE(11506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535847] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [535875] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12924), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11508), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535919] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12926), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11509), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [535963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(11510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [535993] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12928), 1,
      anon_sym_DOT,
    STATE(11511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [536023] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10028), 1,
      anon_sym_LPAREN,
    ACTIONS(12930), 1,
      anon_sym_LBRACK,
    ACTIONS(12932), 1,
      anon_sym_AT,
    ACTIONS(12934), 1,
      anon_sym_POUND,
    STATE(13287), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13303), 1,
      sym_type_arguments,
    STATE(13744), 1,
      sym_annotation,
    STATE(14443), 1,
      sym_arguments,
    STATE(11512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_SEMI,
  [536067] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536095] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12936), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11514), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [536139] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536167] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536195] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11145), 1,
      sym__backquoted_id,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11143), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9674), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9676), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9654), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9656), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536289] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12938), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11520), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [536333] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9018), 1,
      anon_sym_LBRACK,
    ACTIONS(9022), 1,
      anon_sym_match,
    ACTIONS(12033), 1,
      sym__alpha_identifier,
    ACTIONS(12039), 1,
      sym__backquoted_id,
    ACTIONS(12041), 1,
      sym_operator_identifier,
    STATE(1076), 1,
      sym_identifier,
    STATE(4316), 1,
      sym__soft_identifier,
    ACTIONS(8305), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    STATE(11521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12037), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [536377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9804), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536407] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [536435] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(11524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [536465] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536493] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536521] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536549] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12940), 1,
      anon_sym_end,
    STATE(5765), 1,
      sym__end_marker,
    STATE(11528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536581] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12942), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11529), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [536625] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4932), 1,
      anon_sym_AT,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12403), 1,
      anon_sym_inline,
    ACTIONS(12944), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(9016), 1,
      aux_sym_enum_definition_repeat1,
    STATE(10198), 1,
      sym_annotation,
    STATE(13078), 1,
      sym_inline_modifier,
    STATE(18301), 1,
      sym_identifier,
    STATE(11530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 5,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [536673] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12946), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11531), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [536717] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12948), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11532), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [536761] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13034), 1,
      aux_sym_compound_type_repeat1,
    STATE(13513), 1,
      sym__refinement,
    STATE(13529), 1,
      sym_template_body,
    STATE(11533), 2,
      sym_comment,
      sym_block_comment,
    STATE(13431), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [536797] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [536825] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(12169), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    ACTIONS(11196), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    STATE(11535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [536869] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [536897] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9827), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [536927] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    ACTIONS(12930), 1,
      anon_sym_LBRACK,
    ACTIONS(12932), 1,
      anon_sym_AT,
    ACTIONS(12934), 1,
      anon_sym_POUND,
    STATE(9271), 1,
      sym_arguments,
    STATE(13287), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13303), 1,
      sym_type_arguments,
    STATE(13744), 1,
      sym_annotation,
    STATE(11538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_SEMI,
  [536971] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12950), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11539), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537015] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12952), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11540), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537059] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12954), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11541), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537103] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12956), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11542), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537147] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10859), 1,
      anon_sym_LPAREN,
    ACTIONS(12958), 1,
      anon_sym_LBRACK,
    ACTIONS(12960), 1,
      anon_sym_AT,
    ACTIONS(12962), 1,
      anon_sym_POUND,
    STATE(9848), 1,
      sym_arguments,
    STATE(13167), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13279), 1,
      sym_type_arguments,
    STATE(13796), 1,
      sym_annotation,
    STATE(11543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_SEMI,
  [537191] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537219] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12964), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11545), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537263] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12966), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11546), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537335] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(12970), 1,
      anon_sym_COLON,
    ACTIONS(12972), 1,
      anon_sym_extends,
    ACTIONS(12974), 1,
      anon_sym_derives,
    ACTIONS(12976), 1,
      sym__automatic_semicolon,
    STATE(12416), 1,
      sym_extends_clause,
    STATE(13039), 1,
      sym_derives_clause,
    STATE(14780), 1,
      sym__definition_body,
    STATE(14848), 1,
      sym_template_body,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12968), 4,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [537383] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537411] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(7062), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [537441] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12979), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11551), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537485] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537513] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12981), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11553), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537557] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537585] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537613] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11176), 1,
      sym__backquoted_id,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11174), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [537647] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537675] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12983), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11558), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537719] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12985), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11559), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537763] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 3,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(8767), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [537793] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537821] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12987), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11562), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(11563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [537895] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [537923] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12989), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11565), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [537967] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12991), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11566), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538011] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7772), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(7766), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [538041] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12993), 1,
      anon_sym_DOT,
    STATE(11568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [538071] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12995), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11569), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538115] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12997), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11570), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538159] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [538187] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [538215] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(12999), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11573), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538259] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13001), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11574), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538303] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [538331] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [538359] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13003), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11577), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538403] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [538431] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13005), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11579), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538475] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13007), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11580), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538519] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13009), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11581), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538563] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13011), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11582), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538607] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13013), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11583), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538651] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11445), 1,
      anon_sym_EQ,
    ACTIONS(12712), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538697] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13015), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11585), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538741] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13017), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11586), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538785] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13019), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11587), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538829] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9724), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9726), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [538859] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13021), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11589), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538903] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(12970), 1,
      anon_sym_COLON,
    ACTIONS(12972), 1,
      anon_sym_extends,
    ACTIONS(12974), 1,
      anon_sym_derives,
    STATE(12317), 1,
      sym_extends_clause,
    STATE(13022), 1,
      sym_derives_clause,
    STATE(14848), 1,
      sym_template_body,
    STATE(14849), 1,
      sym__definition_body,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13023), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [538949] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13025), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11591), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [538993] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13027), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11592), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9707), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(9709), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [539067] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13029), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11594), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539111] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13031), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11595), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539155] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 15,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [539183] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13033), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11597), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539227] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10357), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10355), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [539257] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12377), 1,
      anon_sym_LBRACK,
    ACTIONS(12379), 1,
      anon_sym_AT,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(12266), 1,
      sym_type_parameters,
    STATE(13014), 1,
      sym_annotation,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14184), 1,
      aux_sym__class_constructor_repeat1,
    STATE(14189), 1,
      sym_access_modifier,
    ACTIONS(12381), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12375), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [539305] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13037), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11600), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539349] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13039), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11601), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539393] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13041), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11602), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539437] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13043), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11603), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539481] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13045), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11604), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539525] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12870), 1,
      sym__alpha_identifier,
    ACTIONS(12874), 1,
      sym__backquoted_id,
    ACTIONS(12876), 1,
      sym_operator_identifier,
    ACTIONS(13047), 1,
      anon_sym_object,
    ACTIONS(13049), 1,
      anon_sym_class,
    STATE(12557), 1,
      sym_identifier,
    STATE(14423), 1,
      sym__soft_identifier,
    STATE(14685), 1,
      sym_simple_enum_case,
    STATE(15720), 1,
      sym_full_enum_case,
    STATE(11605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12872), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539571] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13051), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11606), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539615] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13053), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11607), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539659] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13055), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11608), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539703] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13057), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11609), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539747] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13059), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11610), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539791] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [539819] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [539847] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [539875] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13061), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11614), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539919] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13063), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11615), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [539963] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [539991] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13065), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11617), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540035] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13067), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11618), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540079] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11451), 1,
      anon_sym_EQ,
    ACTIONS(12691), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540125] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13069), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11620), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540169] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13071), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11621), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540213] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11263), 1,
      anon_sym_LPAREN,
    ACTIONS(12958), 1,
      anon_sym_LBRACK,
    ACTIONS(12960), 1,
      anon_sym_AT,
    ACTIONS(12962), 1,
      anon_sym_POUND,
    STATE(13167), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13279), 1,
      sym_type_arguments,
    STATE(13796), 1,
      sym_annotation,
    STATE(14492), 1,
      sym_arguments,
    STATE(11622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 7,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_SEMI,
  [540257] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [540285] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13073), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11624), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [540357] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13075), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11626), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540401] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12838), 1,
      sym_operator_identifier,
    ACTIONS(13077), 1,
      anon_sym_RPAREN,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15424), 1,
      sym_identifier,
    STATE(15431), 1,
      sym_wildcard,
    STATE(16644), 1,
      sym_binding,
    STATE(11627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540447] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13079), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11628), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540491] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7296), 1,
      anon_sym_object,
    ACTIONS(7302), 1,
      anon_sym_class,
    ACTIONS(12797), 1,
      sym__alpha_identifier,
    ACTIONS(12805), 1,
      sym__backquoted_id,
    ACTIONS(12807), 1,
      sym_operator_identifier,
    STATE(12758), 1,
      sym_identifier,
    STATE(14377), 1,
      sym__soft_identifier,
    STATE(14766), 1,
      sym_simple_enum_case,
    STATE(15491), 1,
      sym_full_enum_case,
    STATE(11629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12803), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540537] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13081), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11630), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540581] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [540609] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13083), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11632), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540653] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13085), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11633), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540697] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [540725] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13087), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11635), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540769] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13089), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11636), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [540841] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13091), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11638), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540885] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13093), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11639), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540929] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11600), 1,
      anon_sym_EQ,
    ACTIONS(12689), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [540975] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10604), 1,
      sym__alpha_identifier,
    ACTIONS(10624), 1,
      sym__backquoted_id,
    ACTIONS(11425), 1,
      anon_sym_STAR,
    ACTIONS(11431), 1,
      anon_sym_PIPE,
    ACTIONS(11433), 1,
      sym_operator_identifier,
    ACTIONS(11596), 1,
      anon_sym_EQ,
    ACTIONS(12687), 1,
      anon_sym_COLON,
    STATE(4286), 1,
      sym_identifier,
    STATE(9773), 1,
      sym__soft_identifier,
    STATE(11641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541021] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [541049] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541077] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [541105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9740), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541135] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9628), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541165] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [541193] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13095), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11648), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541237] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541265] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541321] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13097), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11652), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541365] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13099), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11653), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541409] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13101), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11654), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541453] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13103), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11655), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541497] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541525] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13105), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11657), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541569] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 15,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [541597] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [541625] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13107), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11660), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541669] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7562), 1,
      anon_sym_LPAREN,
    ACTIONS(7564), 2,
      anon_sym_DOT,
      sym__backquoted_id,
    STATE(11661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12558), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9558), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541731] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13109), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11663), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541775] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13111), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11664), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541819] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13113), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11665), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541863] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9521), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541893] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__backquoted_id,
    ACTIONS(9517), 12,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [541923] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13115), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11668), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [541967] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [541995] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13117), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11670), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542039] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13119), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11671), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542083] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8513), 1,
      anon_sym_LPAREN,
    ACTIONS(13121), 1,
      anon_sym_LBRACK,
    ACTIONS(13123), 1,
      anon_sym_POUND,
    STATE(12059), 1,
      aux_sym_annotation_repeat1,
    STATE(12636), 1,
      sym_type_arguments,
    STATE(13084), 1,
      sym_arguments,
    STATE(11672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [542123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10222), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_SEMI,
      sym__backquoted_id,
    ACTIONS(10220), 10,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [542153] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(11674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [542183] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [542211] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13125), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11676), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542255] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13127), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11677), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542299] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13129), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11678), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542343] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13131), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11679), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542387] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13133), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11680), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542431] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [542459] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13135), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11682), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542503] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13137), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11683), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542547] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9778), 1,
      anon_sym_LPAREN,
    STATE(11689), 1,
      aux_sym_annotation_repeat1,
    STATE(12446), 1,
      sym_arguments,
    STATE(11684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [542581] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13139), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11685), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542625] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13141), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11686), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542669] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [542697] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13143), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11688), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542741] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13145), 1,
      anon_sym_LPAREN,
    STATE(12446), 1,
      sym_arguments,
    STATE(11689), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [542773] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13148), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11690), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542817] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13150), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11691), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542861] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13152), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11692), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542905] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13154), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11693), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542949] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13156), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11694), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [542993] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13158), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11695), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543037] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13160), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11696), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543081] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13162), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11697), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543125] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13164), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11698), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543169] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 15,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [543197] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13166), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11700), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543241] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    ACTIONS(13168), 1,
      anon_sym_RBRACK,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11701), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543285] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11701), 1,
      sym__backquoted_id,
    STATE(11702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11699), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [543314] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11705), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [543343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11721), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [543372] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10301), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10299), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [543401] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11699), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [543430] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11687), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [543459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11787), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [543488] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11815), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [543517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10297), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10295), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [543546] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 14,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [543573] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11683), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [543602] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12710), 1,
      sym__backquoted_id,
    STATE(11713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12708), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [543631] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13172), 1,
      anon_sym_LBRACK,
    ACTIONS(13174), 1,
      anon_sym_match,
    STATE(5650), 1,
      sym_type_arguments,
    STATE(11714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [543664] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13172), 1,
      anon_sym_LBRACK,
    STATE(5650), 1,
      sym_type_arguments,
    STATE(11715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 12,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [543695] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15917), 1,
      sym__type_parameter,
    STATE(11716), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [543736] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13172), 1,
      anon_sym_LBRACK,
    STATE(5650), 1,
      sym_type_arguments,
    STATE(11717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 12,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [543767] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(13180), 1,
      anon_sym_COLON,
    ACTIONS(13182), 1,
      anon_sym_with,
    STATE(8959), 1,
      sym_template_body,
    STATE(8962), 1,
      sym__refinement,
    STATE(9271), 1,
      sym_arguments,
    STATE(12065), 1,
      aux_sym_compound_type_repeat1,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [543810] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13172), 1,
      anon_sym_LBRACK,
    ACTIONS(13174), 1,
      anon_sym_match,
    STATE(5650), 1,
      sym_type_arguments,
    STATE(11719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [543843] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13172), 1,
      anon_sym_LBRACK,
    STATE(5650), 1,
      sym_type_arguments,
    STATE(11720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 12,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [543874] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [543901] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [543928] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13172), 1,
      anon_sym_LBRACK,
    STATE(5650), 1,
      sym_type_arguments,
    STATE(11723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 12,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [543959] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13190), 1,
      anon_sym_end,
    STATE(6536), 1,
      sym__end_marker,
    STATE(11724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [543990] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13172), 1,
      anon_sym_LBRACK,
    STATE(5650), 1,
      sym_type_arguments,
    STATE(11725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 12,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [544021] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15787), 1,
      sym__type_parameter,
    STATE(11726), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544062] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 14,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [544089] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15773), 1,
      sym__type_parameter,
    STATE(11728), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544130] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15771), 1,
      sym__type_parameter,
    STATE(11729), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544171] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15761), 1,
      sym__type_parameter,
    STATE(11730), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544212] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [544239] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12958), 1,
      anon_sym_LBRACK,
    ACTIONS(12960), 1,
      anon_sym_AT,
    ACTIONS(12962), 1,
      anon_sym_POUND,
    STATE(13167), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13279), 1,
      sym_type_arguments,
    STATE(13796), 1,
      sym_annotation,
    STATE(11732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [544278] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10288), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10286), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [544307] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11737), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [544336] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13194), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(13789), 1,
      sym_identifier,
    STATE(17883), 1,
      sym_stable_identifier,
    STATE(11735), 2,
      sym_comment,
      sym_block_comment,
    STATE(14086), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11621), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [544406] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [544433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(11738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [544462] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [544489] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(7882), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [544518] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9521), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [544547] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [544574] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [544601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13196), 1,
      anon_sym_DOT,
    STATE(11744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [544630] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15752), 1,
      sym__type_parameter,
    STATE(11745), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544671] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [544698] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15742), 1,
      sym__type_parameter,
    STATE(11747), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [544739] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(11673), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [544768] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [544795] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [544822] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(13198), 1,
      sym__automatic_semicolon,
    STATE(13372), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13373), 1,
      sym_access_modifier,
    STATE(13914), 1,
      sym_class_parameters,
    ACTIONS(12551), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12811), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [544861] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [544888] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [544915] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [544942] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [544969] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [544996] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [545023] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [545050] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [545077] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [545104] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545131] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [545158] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [545185] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [545212] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15734), 1,
      sym__type_parameter,
    STATE(11765), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545253] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15725), 1,
      sym__type_parameter,
    STATE(11766), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545294] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545321] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [545348] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545375] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9517), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [545404] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12958), 1,
      anon_sym_LBRACK,
    ACTIONS(12962), 1,
      anon_sym_POUND,
    ACTIONS(13201), 1,
      anon_sym_LPAREN,
    STATE(13279), 1,
      sym_type_arguments,
    STATE(13335), 1,
      aux_sym_annotation_repeat1,
    STATE(13721), 1,
      sym_arguments,
    STATE(11771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 8,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_SEMI,
  [545443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13203), 1,
      anon_sym_STAR,
    STATE(11772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [545472] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13205), 1,
      anon_sym_LPAREN,
    STATE(12768), 1,
      sym_arguments,
    STATE(11773), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [545503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13208), 1,
      anon_sym_DOT,
    STATE(11774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [545532] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10301), 1,
      sym__backquoted_id,
    STATE(11775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10299), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [545561] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [545588] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12703), 1,
      sym__backquoted_id,
    STATE(11777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12701), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [545617] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7556), 1,
      sym__backquoted_id,
    STATE(11778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8662), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [545646] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13210), 1,
      anon_sym_DOT,
    STATE(11779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [545675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10244), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10242), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [545704] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15717), 1,
      sym__type_parameter,
    STATE(11781), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545745] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [545772] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15708), 1,
      sym__type_parameter,
    STATE(11783), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545813] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15699), 1,
      sym__type_parameter,
    STATE(11784), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545854] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10297), 1,
      sym__backquoted_id,
    STATE(11785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10295), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [545883] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15691), 1,
      sym__type_parameter,
    STATE(11786), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545924] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10228), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(10226), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [545953] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15580), 1,
      sym__type_parameter,
    STATE(11788), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [545994] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12533), 1,
      anon_sym_LPAREN,
    STATE(11809), 1,
      aux_sym_annotation_repeat1,
    STATE(12538), 1,
      sym_arguments,
    STATE(11789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [546027] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546054] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546081] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546108] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13212), 1,
      anon_sym_LPAREN,
    STATE(12595), 1,
      sym_arguments,
    STATE(11793), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [546139] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546166] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12192), 1,
      sym__end_marker,
    ACTIONS(9451), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(11796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9449), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [546224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9558), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [546253] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546280] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [546307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546334] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546361] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15681), 1,
      sym__type_parameter,
    STATE(11802), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546402] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9628), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [546431] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9740), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [546460] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15673), 1,
      sym__type_parameter,
    STATE(11805), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546501] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13215), 1,
      anon_sym_AT,
    STATE(12554), 1,
      sym_annotation,
    STATE(11806), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [546532] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15665), 1,
      sym__type_parameter,
    STATE(11807), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546573] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(13218), 1,
      sym__automatic_semicolon,
    STATE(13285), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13286), 1,
      sym_access_modifier,
    STATE(13914), 1,
      sym_class_parameters,
    ACTIONS(12551), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(11808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12865), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [546612] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13221), 1,
      anon_sym_LPAREN,
    STATE(12538), 1,
      sym_arguments,
    STATE(11809), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [546643] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546670] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10288), 1,
      sym__backquoted_id,
    STATE(11811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10286), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [546699] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9419), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [546728] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9415), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [546757] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [546784] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15654), 1,
      sym__type_parameter,
    STATE(11815), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [546825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    STATE(11816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12625), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [546854] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(9411), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [546883] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546910] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546937] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546964] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [546991] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15645), 1,
      sym__type_parameter,
    STATE(11822), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547032] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16036), 1,
      sym__type_parameter,
    STATE(11823), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547100] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547127] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15636), 1,
      sym__type_parameter,
    STATE(11826), 2,
      sym_comment,
      sym_block_comment,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547168] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547195] = 16,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13228), 1,
      anon_sym_LBRACK,
    ACTIONS(13230), 1,
      anon_sym_LT_COLON,
    ACTIONS(13232), 1,
      anon_sym_GT_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(12567), 1,
      sym_type_parameters,
    STATE(13464), 1,
      sym_lower_bound,
    STATE(14197), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14215), 1,
      sym_upper_bound,
    STATE(14673), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(13226), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(11828), 2,
      sym_comment,
      sym_block_comment,
  [547246] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16656), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547287] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16657), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547328] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15359), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547369] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10859), 1,
      anon_sym_LPAREN,
    STATE(11793), 1,
      aux_sym_annotation_repeat1,
    STATE(12595), 1,
      sym_arguments,
    STATE(11832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [547402] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547429] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547456] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12729), 1,
      sym__backquoted_id,
    STATE(11835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12727), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [547485] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12633), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [547514] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547541] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [547568] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15628), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7766), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [547638] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547665] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15621), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547706] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15616), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [547747] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547774] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547801] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12668), 1,
      anon_sym_LPAREN,
    STATE(11773), 1,
      aux_sym_annotation_repeat1,
    STATE(12768), 1,
      sym_arguments,
    STATE(11846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [547834] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13236), 1,
      anon_sym_DOT,
    STATE(11847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [547863] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547890] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547917] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547944] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [547971] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10244), 1,
      sym__backquoted_id,
    STATE(11852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10242), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [548000] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548027] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15605), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548068] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548095] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548122] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10228), 1,
      sym__backquoted_id,
    STATE(11857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10226), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [548151] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 14,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [548178] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 14,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [548205] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [548232] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [548259] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [548286] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [548313] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548340] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15598), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12748), 1,
      sym__backquoted_id,
    STATE(11866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12746), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [548410] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [548437] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548464] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [548491] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [548518] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7854), 1,
      anon_sym_LBRACE,
    ACTIONS(13244), 1,
      anon_sym_COLON,
    STATE(12444), 1,
      aux_sym_compound_type_repeat1,
    STATE(14443), 1,
      sym_arguments,
    STATE(14581), 1,
      sym_template_body,
    STATE(14590), 1,
      sym__refinement,
    STATE(11871), 2,
      sym_comment,
      sym_block_comment,
    STATE(14489), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [548559] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(13246), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(14217), 1,
      sym_identifier,
    STATE(17758), 1,
      sym_stable_identifier,
    STATE(11872), 2,
      sym_comment,
      sym_block_comment,
    STATE(14210), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548600] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12930), 1,
      anon_sym_LBRACK,
    ACTIONS(12932), 1,
      anon_sym_AT,
    ACTIONS(12934), 1,
      anon_sym_POUND,
    STATE(13287), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13303), 1,
      sym_type_arguments,
    STATE(13744), 1,
      sym_annotation,
    STATE(11873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [548639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [548666] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [548693] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [548720] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15586), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548761] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548788] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(13250), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15051), 1,
      sym_identifier,
    STATE(18347), 1,
      sym_stable_identifier,
    STATE(11879), 2,
      sym_comment,
      sym_block_comment,
    STATE(15052), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [548829] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [548856] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548883] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13254), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548910] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13256), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548937] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9417), 1,
      sym__backquoted_id,
    STATE(11884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9419), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [548966] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [548993] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9413), 1,
      sym__backquoted_id,
    STATE(11886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9415), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [549022] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [549049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9409), 1,
      sym__backquoted_id,
    STATE(11888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9411), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [549078] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549105] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549132] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(13246), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(14217), 1,
      sym_identifier,
    STATE(17758), 1,
      sym_stable_identifier,
    STATE(11891), 2,
      sym_comment,
      sym_block_comment,
    STATE(14360), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549173] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15569), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549214] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [549241] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7880), 1,
      sym__outdent,
    ACTIONS(7882), 1,
      anon_sym_case,
    ACTIONS(7884), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [549276] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549303] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(11896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549332] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549359] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [549386] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15563), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549427] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [549454] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549481] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [549508] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15556), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549549] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549576] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13277), 1,
      anon_sym_STAR,
    STATE(11905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549605] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [549632] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15549), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549673] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9515), 1,
      sym__backquoted_id,
    STATE(11909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9517), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [549729] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7808), 1,
      anon_sym_LBRACE,
    ACTIONS(13279), 1,
      anon_sym_COLON,
    STATE(12121), 1,
      aux_sym_compound_type_repeat1,
    STATE(14492), 1,
      sym_arguments,
    STATE(14584), 1,
      sym__refinement,
    STATE(14586), 1,
      sym_template_body,
    STATE(11910), 2,
      sym_comment,
      sym_block_comment,
    STATE(14520), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [549770] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549797] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549824] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [549851] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15540), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549892] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9519), 1,
      sym__backquoted_id,
    STATE(11915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [549921] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11685), 1,
      sym__backquoted_id,
    STATE(11916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11683), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [549950] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15531), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [549991] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550018] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15522), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550059] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550086] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15514), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550127] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550154] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15508), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550195] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(11924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550224] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(13250), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15051), 1,
      sym_identifier,
    STATE(18347), 1,
      sym_stable_identifier,
    STATE(11925), 2,
      sym_comment,
      sym_block_comment,
    STATE(15604), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550265] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15432), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550306] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(11927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550335] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11689), 1,
      sym__backquoted_id,
    STATE(11928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11687), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550364] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15504), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12737), 1,
      sym__backquoted_id,
    STATE(11930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12735), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550434] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12733), 1,
      sym__backquoted_id,
    STATE(11931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12731), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550463] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [550490] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9738), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9740), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550519] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12531), 1,
      anon_sym_AT,
    STATE(11806), 1,
      aux_sym_enum_definition_repeat1,
    STATE(12554), 1,
      sym_annotation,
    STATE(11934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [550552] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11707), 1,
      sym__backquoted_id,
    STATE(11935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11705), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550581] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(13180), 1,
      anon_sym_COLON,
    ACTIONS(13297), 1,
      anon_sym_extends,
    ACTIONS(13299), 1,
      anon_sym_derives,
    ACTIONS(13301), 1,
      sym__automatic_semicolon,
    STATE(12716), 1,
      sym_extends_clause,
    STATE(13640), 1,
      sym_derives_clause,
    STATE(14896), 1,
      sym_template_body,
    STATE(14925), 1,
      sym__definition_body,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12968), 3,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [550628] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15496), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550669] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15490), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [550710] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11723), 1,
      sym__backquoted_id,
    STATE(11939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11721), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550739] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [550766] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [550793] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [550820] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9556), 1,
      sym__backquoted_id,
    STATE(11943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9558), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9626), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9628), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550878] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [550905] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [550932] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9626), 1,
      sym__backquoted_id,
    STATE(11947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9628), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [550961] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15479), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [551002] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9738), 1,
      sym__backquoted_id,
    STATE(11949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9740), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [551031] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [551058] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12716), 1,
      sym__backquoted_id,
    STATE(11951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12714), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [551087] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    ACTIONS(13304), 1,
      anon_sym_LBRACK,
    ACTIONS(13306), 1,
      anon_sym_POUND,
    STATE(12748), 1,
      aux_sym_annotation_repeat1,
    STATE(13394), 1,
      sym_type_arguments,
    STATE(13555), 1,
      sym_arguments,
    STATE(11952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [551126] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15473), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [551167] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15461), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [551208] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9802), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9800), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [551237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9806), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9804), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [551266] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551320] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [551347] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(13312), 1,
      sym__automatic_semicolon,
    STATE(12484), 1,
      aux_sym__function_constructor_repeat1,
    STATE(12485), 1,
      sym_type_parameters,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(11960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 7,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [551388] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(12970), 1,
      anon_sym_COLON,
    ACTIONS(13314), 1,
      anon_sym_with,
    STATE(9848), 1,
      sym_arguments,
    STATE(9867), 1,
      sym__refinement,
    STATE(9878), 1,
      sym_template_body,
    STATE(12115), 1,
      aux_sym_compound_type_repeat1,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [551431] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [551458] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(13180), 1,
      anon_sym_COLON,
    ACTIONS(13297), 1,
      anon_sym_extends,
    ACTIONS(13299), 1,
      anon_sym_derives,
    STATE(12745), 1,
      sym_extends_clause,
    STATE(13625), 1,
      sym_derives_clause,
    STATE(14895), 1,
      sym__definition_body,
    STATE(14896), 1,
      sym_template_body,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(11963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13023), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [551503] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8719), 1,
      anon_sym_LPAREN,
    ACTIONS(13316), 1,
      anon_sym_LBRACK,
    ACTIONS(13318), 1,
      anon_sym_POUND,
    STATE(12763), 1,
      aux_sym_annotation_repeat1,
    STATE(13385), 1,
      sym_type_arguments,
    STATE(13684), 1,
      sym_arguments,
    STATE(11964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [551542] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8465), 1,
      anon_sym_LPAREN,
    STATE(11971), 1,
      aux_sym_annotation_repeat1,
    STATE(12800), 1,
      sym_arguments,
    STATE(11965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [551575] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(11966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [551604] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [551631] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [551658] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(11969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551687] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12741), 1,
      sym__backquoted_id,
    STATE(11970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12739), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [551716] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13320), 1,
      anon_sym_LPAREN,
    STATE(12800), 1,
      sym_arguments,
    STATE(11971), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [551747] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15454), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [551788] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15449), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [551829] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551856] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9076), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(11975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9074), 12,
      anon_sym__,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [551885] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [551912] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551939] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551966] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [551993] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [552020] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11675), 1,
      sym__backquoted_id,
    STATE(11981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11673), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [552049] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [552076] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15441), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552117] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [552144] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [552171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9556), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9558), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [552200] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [552227] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11789), 1,
      sym__backquoted_id,
    STATE(11988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11787), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [552256] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15423), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552297] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9829), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9827), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [552326] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [552353] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [552380] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9519), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [552409] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [552436] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15414), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552477] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15407), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(11996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552518] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(12838), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15424), 1,
      sym_identifier,
    STATE(15431), 1,
      sym_wildcard,
    STATE(16644), 1,
      sym_binding,
    STATE(11997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552561] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13331), 1,
      sym_operator_identifier,
    STATE(5503), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(16613), 1,
      sym__arrow_then_type,
    ACTIONS(13325), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(11998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552602] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9515), 2,
      sym__outdent,
      sym__backquoted_id,
    STATE(11999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9517), 12,
      anon_sym_case,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_QMARK_EQ_GT,
      sym__alpha_identifier,
      sym_operator_identifier,
  [552631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(12000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [552660] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16621), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552701] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15400), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552742] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [552769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11817), 1,
      sym__backquoted_id,
    STATE(12004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11815), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [552798] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15268), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552839] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15394), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552880] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15383), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552921] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15376), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [552962] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [552989] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15365), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553030] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [553057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11739), 1,
      sym__backquoted_id,
    STATE(12012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11737), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [553086] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15358), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553127] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [553154] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15351), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553195] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13333), 1,
      anon_sym_COLON,
    ACTIONS(13336), 1,
      anon_sym_DOT,
    ACTIONS(13338), 1,
      anon_sym_LBRACK,
    ACTIONS(13341), 1,
      anon_sym_LPAREN,
    ACTIONS(13344), 1,
      sym__automatic_semicolon,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14473), 1,
      sym_type_parameters,
    STATE(14475), 1,
      aux_sym__function_constructor_repeat1,
    STATE(12016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 5,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_POUND,
  [553240] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13350), 1,
      sym__indent,
    STATE(12017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13348), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13346), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [553271] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [553298] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [553325] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 14,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [553352] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12710), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12708), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [553381] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12703), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12701), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [553410] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15347), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553451] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15342), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553492] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11623), 1,
      sym__backquoted_id,
    STATE(12025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11621), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [553521] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7880), 1,
      sym__backquoted_id,
    STATE(12026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 13,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_if,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [553550] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12930), 1,
      anon_sym_LBRACK,
    ACTIONS(12934), 1,
      anon_sym_POUND,
    ACTIONS(13352), 1,
      anon_sym_LPAREN,
    STATE(13109), 1,
      aux_sym_annotation_repeat1,
    STATE(13303), 1,
      sym_type_arguments,
    STATE(13742), 1,
      sym_arguments,
    STATE(12027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_SEMI,
  [553589] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 14,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [553616] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15338), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553657] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15330), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553698] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15328), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553739] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13194), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(13789), 1,
      sym_identifier,
    STATE(17883), 1,
      sym_stable_identifier,
    STATE(12032), 2,
      sym_comment,
      sym_block_comment,
    STATE(13788), 2,
      sym_stable_type_identifier,
      sym__type_identifier,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553780] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15323), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553821] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15315), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553862] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15308), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [553903] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13354), 1,
      anon_sym_end,
    STATE(6628), 1,
      sym__end_marker,
    STATE(12036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [553934] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12729), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12727), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [553963] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15305), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554004] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15297), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554045] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15290), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554086] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15281), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554127] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12748), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12746), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [554156] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8869), 1,
      anon_sym_LPAREN,
    ACTIONS(13356), 1,
      anon_sym_LBRACK,
    ACTIONS(13358), 1,
      anon_sym_POUND,
    STATE(12910), 1,
      aux_sym_annotation_repeat1,
    STATE(13312), 1,
      sym_type_arguments,
    STATE(13495), 1,
      sym_arguments,
    STATE(12043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [554195] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12737), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12735), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [554224] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12733), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12731), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [554253] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12716), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12714), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [554282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12741), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym__backquoted_id,
    ACTIONS(12739), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [554311] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(12048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [554340] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15275), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554381] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(10937), 1,
      anon_sym__,
    ACTIONS(10947), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(15272), 1,
      sym__type_parameter,
    STATE(11828), 2,
      sym_identifier,
      sym_wildcard,
    STATE(12050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554422] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8833), 1,
      anon_sym_LPAREN,
    ACTIONS(13360), 1,
      anon_sym_LBRACK,
    ACTIONS(13362), 1,
      anon_sym_POUND,
    STATE(12918), 1,
      aux_sym_annotation_repeat1,
    STATE(13121), 1,
      sym_type_arguments,
    STATE(13609), 1,
      sym_arguments,
    STATE(12051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [554461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13366), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13364), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [554489] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12590), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [554515] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8449), 1,
      sym__alpha_identifier,
    ACTIONS(8457), 1,
      sym__backquoted_id,
    ACTIONS(13368), 1,
      anon_sym_type,
    ACTIONS(13370), 1,
      sym_operator_identifier,
    STATE(5550), 1,
      sym__type_identifier,
    STATE(5831), 1,
      sym__soft_identifier,
    STATE(6035), 1,
      sym_identifier,
    STATE(12054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8453), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554555] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6900), 1,
      sym__alpha_identifier,
    ACTIONS(6914), 1,
      sym__backquoted_id,
    ACTIONS(13372), 1,
      anon_sym_type,
    ACTIONS(13374), 1,
      sym_operator_identifier,
    STATE(4981), 1,
      sym_identifier,
    STATE(5013), 1,
      sym__soft_identifier,
    STATE(5117), 1,
      sym__type_identifier,
    STATE(12055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6910), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554595] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13376), 1,
      anon_sym_LPAREN,
    STATE(13084), 1,
      sym_arguments,
    STATE(12056), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [554625] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13379), 1,
      anon_sym_DOT,
    STATE(12057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [554653] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13381), 1,
      anon_sym_object,
    ACTIONS(13383), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(14150), 1,
      sym_package_identifier,
    STATE(14364), 1,
      sym_identifier,
    STATE(12058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554693] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8513), 1,
      anon_sym_LPAREN,
    STATE(12056), 1,
      aux_sym_annotation_repeat1,
    STATE(13084), 1,
      sym_arguments,
    STATE(12059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [554725] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 13,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [554751] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8211), 1,
      sym__alpha_identifier,
    ACTIONS(8223), 1,
      sym__backquoted_id,
    ACTIONS(13385), 1,
      anon_sym_type,
    ACTIONS(13387), 1,
      sym_operator_identifier,
    STATE(5201), 1,
      sym__type_identifier,
    STATE(5301), 1,
      sym_identifier,
    STATE(5375), 1,
      sym__soft_identifier,
    STATE(12061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8219), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554791] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(13389), 1,
      sym_operator_identifier,
    STATE(10424), 1,
      sym_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11548), 1,
      sym__class_constructor,
    STATE(14622), 1,
      sym__class_definition,
    STATE(12062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554831] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6286), 1,
      sym__alpha_identifier,
    ACTIONS(6296), 1,
      sym__backquoted_id,
    ACTIONS(13391), 1,
      anon_sym_type,
    ACTIONS(13393), 1,
      sym_operator_identifier,
    STATE(6838), 1,
      sym__soft_identifier,
    STATE(6854), 1,
      sym_identifier,
    STATE(7877), 1,
      sym__type_identifier,
    STATE(12063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6292), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554871] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(13389), 1,
      sym_operator_identifier,
    STATE(10424), 1,
      sym_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11548), 1,
      sym__class_constructor,
    STATE(14610), 1,
      sym__class_definition,
    STATE(12064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554911] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(13180), 1,
      anon_sym_COLON,
    ACTIONS(13182), 1,
      anon_sym_with,
    STATE(8959), 1,
      sym_template_body,
    STATE(8998), 1,
      sym__refinement,
    STATE(13815), 1,
      aux_sym_compound_type_repeat1,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [554951] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6754), 1,
      sym__alpha_identifier,
    ACTIONS(6764), 1,
      sym__backquoted_id,
    ACTIONS(13395), 1,
      anon_sym_type,
    ACTIONS(13397), 1,
      sym_operator_identifier,
    STATE(4998), 1,
      sym__soft_identifier,
    STATE(5027), 1,
      sym_identifier,
    STATE(5153), 1,
      sym__type_identifier,
    STATE(12066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6760), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [554991] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7880), 1,
      sym__backquoted_id,
    STATE(12067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7882), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [555019] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(13399), 1,
      anon_sym_type,
    ACTIONS(13401), 1,
      sym_operator_identifier,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(8265), 1,
      sym_identifier,
    STATE(8782), 1,
      sym__type_identifier,
    STATE(12068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555059] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11675), 1,
      sym__backquoted_id,
    STATE(12069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11673), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [555087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11623), 1,
      sym__backquoted_id,
    STATE(12070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11621), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [555115] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13403), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11334), 1,
      sym_identifier,
    STATE(13700), 1,
      sym__type_identifier,
    STATE(15005), 1,
      sym__type_constructor,
    STATE(12071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555155] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11739), 1,
      sym__backquoted_id,
    STATE(12072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11737), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [555183] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11817), 1,
      sym__backquoted_id,
    STATE(12073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11815), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [555211] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(846), 1,
      sym__alpha_identifier,
    ACTIONS(852), 1,
      anon_sym__,
    ACTIONS(876), 1,
      sym__backquoted_id,
    ACTIONS(13405), 1,
      sym_operator_identifier,
    STATE(5497), 1,
      sym__soft_identifier,
    STATE(12074), 2,
      sym_comment,
      sym_block_comment,
    STATE(16615), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(856), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555249] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13407), 1,
      anon_sym_end,
    STATE(7475), 1,
      sym__end_marker,
    STATE(12075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [555279] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12070), 1,
      sym__alpha_identifier,
    ACTIONS(12078), 1,
      sym__backquoted_id,
    ACTIONS(13409), 1,
      anon_sym_type,
    ACTIONS(13411), 1,
      sym_operator_identifier,
    STATE(11859), 1,
      sym__soft_identifier,
    STATE(12048), 1,
      sym_identifier,
    STATE(12137), 1,
      sym__type_identifier,
    STATE(12076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12074), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555319] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6918), 1,
      sym__alpha_identifier,
    ACTIONS(6932), 1,
      sym__backquoted_id,
    ACTIONS(13413), 1,
      anon_sym_type,
    ACTIONS(13415), 1,
      sym_operator_identifier,
    STATE(4714), 1,
      sym__soft_identifier,
    STATE(4754), 1,
      sym_identifier,
    STATE(4976), 1,
      sym__type_identifier,
    STATE(12077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6928), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555359] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11789), 1,
      sym__backquoted_id,
    STATE(12078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11787), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [555387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13417), 1,
      anon_sym_STAR,
    STATE(12079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [555415] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6632), 1,
      sym__alpha_identifier,
    ACTIONS(6646), 1,
      sym__backquoted_id,
    ACTIONS(13419), 1,
      anon_sym_type,
    ACTIONS(13421), 1,
      sym_operator_identifier,
    STATE(6331), 1,
      sym_identifier,
    STATE(6537), 1,
      sym__soft_identifier,
    STATE(7007), 1,
      sym__type_identifier,
    STATE(12080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6642), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555455] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6662), 1,
      sym__alpha_identifier,
    ACTIONS(6672), 1,
      sym__backquoted_id,
    ACTIONS(13423), 1,
      anon_sym_type,
    ACTIONS(13425), 1,
      sym_operator_identifier,
    STATE(4579), 1,
      sym_identifier,
    STATE(4632), 1,
      sym__soft_identifier,
    STATE(4769), 1,
      sym__type_identifier,
    STATE(12081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6668), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555495] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4512), 1,
      sym__alpha_identifier,
    ACTIONS(4524), 1,
      sym__backquoted_id,
    ACTIONS(13427), 1,
      anon_sym_type,
    ACTIONS(13429), 1,
      sym_operator_identifier,
    STATE(4639), 1,
      sym_identifier,
    STATE(4696), 1,
      sym__soft_identifier,
    STATE(4900), 1,
      sym__type_identifier,
    STATE(12082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4520), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555535] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11723), 1,
      sym__backquoted_id,
    STATE(12083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11721), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [555563] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      sym__backquoted_id,
    ACTIONS(13431), 1,
      anon_sym_type,
    ACTIONS(13433), 1,
      sym_operator_identifier,
    STATE(8951), 1,
      sym_identifier,
    STATE(8952), 1,
      sym__type_identifier,
    STATE(9392), 1,
      sym__soft_identifier,
    STATE(12084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8058), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11707), 1,
      sym__backquoted_id,
    STATE(12085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11705), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [555631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11701), 1,
      sym__backquoted_id,
    STATE(12086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11699), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [555659] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(13435), 1,
      anon_sym_type,
    ACTIONS(13437), 1,
      sym_operator_identifier,
    STATE(7061), 1,
      sym_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8070), 1,
      sym__type_identifier,
    STATE(12087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555699] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11689), 1,
      sym__backquoted_id,
    STATE(12088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11687), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [555727] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [555753] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11685), 1,
      sym__backquoted_id,
    STATE(12090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11683), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [555781] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6940), 1,
      sym__alpha_identifier,
    ACTIONS(6954), 1,
      sym__backquoted_id,
    ACTIONS(13439), 1,
      anon_sym_type,
    ACTIONS(13441), 1,
      sym_operator_identifier,
    STATE(6376), 1,
      sym__soft_identifier,
    STATE(6468), 1,
      sym_identifier,
    STATE(7271), 1,
      sym__type_identifier,
    STATE(12091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555821] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13403), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11334), 1,
      sym_identifier,
    STATE(13134), 1,
      sym__type_identifier,
    STATE(14799), 1,
      sym__type_constructor,
    STATE(12092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555861] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [555887] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8259), 1,
      sym__alpha_identifier,
    ACTIONS(8271), 1,
      sym__backquoted_id,
    ACTIONS(13443), 1,
      anon_sym_type,
    ACTIONS(13445), 1,
      sym_operator_identifier,
    STATE(4821), 1,
      sym__type_identifier,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(5068), 1,
      sym_identifier,
    STATE(12094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8267), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555927] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8287), 1,
      sym__alpha_identifier,
    ACTIONS(8299), 1,
      sym__backquoted_id,
    ACTIONS(13447), 1,
      anon_sym_type,
    ACTIONS(13449), 1,
      sym_operator_identifier,
    STATE(4930), 1,
      sym__soft_identifier,
    STATE(5058), 1,
      sym__type_identifier,
    STATE(5067), 1,
      sym_identifier,
    STATE(12095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8295), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [555967] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [555993] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    STATE(12097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12625), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [556021] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [556047] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [556073] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9134), 1,
      anon_sym_LPAREN,
    ACTIONS(13451), 1,
      anon_sym_LBRACK,
    ACTIONS(13453), 1,
      anon_sym_POUND,
    STATE(13200), 1,
      aux_sym_annotation_repeat1,
    STATE(13457), 1,
      sym_type_arguments,
    STATE(13876), 1,
      sym_arguments,
    STATE(12100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [556111] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8469), 1,
      sym__alpha_identifier,
    ACTIONS(8481), 1,
      sym__backquoted_id,
    ACTIONS(13455), 1,
      anon_sym_type,
    ACTIONS(13457), 1,
      sym_operator_identifier,
    STATE(5527), 1,
      sym__soft_identifier,
    STATE(5594), 1,
      sym__type_identifier,
    STATE(6070), 1,
      sym_identifier,
    STATE(12101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8477), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556151] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8143), 1,
      sym__alpha_identifier,
    ACTIONS(8155), 1,
      sym__backquoted_id,
    ACTIONS(13459), 1,
      anon_sym_type,
    ACTIONS(13461), 1,
      sym_operator_identifier,
    STATE(4734), 1,
      sym__soft_identifier,
    STATE(4743), 1,
      sym_identifier,
    STATE(4809), 1,
      sym__type_identifier,
    STATE(12102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8151), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556191] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [556217] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8333), 1,
      sym__alpha_identifier,
    ACTIONS(8341), 1,
      sym__backquoted_id,
    ACTIONS(13463), 1,
      anon_sym_type,
    ACTIONS(13465), 1,
      sym_operator_identifier,
    STATE(5234), 1,
      sym__type_identifier,
    STATE(5309), 1,
      sym__soft_identifier,
    STATE(5320), 1,
      sym_identifier,
    STATE(12104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8337), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556257] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(13467), 1,
      anon_sym_type,
    ACTIONS(13469), 1,
      sym_operator_identifier,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8903), 1,
      sym_identifier,
    STATE(9493), 1,
      sym__type_identifier,
    STATE(12105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556297] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [556323] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [556349] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [556375] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [556401] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7850), 1,
      sym__alpha_identifier,
    ACTIONS(7862), 1,
      sym__backquoted_id,
    ACTIONS(13471), 1,
      anon_sym_type,
    ACTIONS(13473), 1,
      sym_operator_identifier,
    STATE(12664), 1,
      sym__soft_identifier,
    STATE(12837), 1,
      sym_identifier,
    STATE(13351), 1,
      sym__type_identifier,
    STATE(12110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(12111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [556469] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12679), 1,
      anon_sym_LPAREN,
    STATE(12114), 1,
      aux_sym_annotation_repeat1,
    STATE(13230), 1,
      sym_arguments,
    STATE(12112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [556501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [556527] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13475), 1,
      anon_sym_LPAREN,
    STATE(13230), 1,
      sym_arguments,
    STATE(12114), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_SEMI,
  [556557] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(12970), 1,
      anon_sym_COLON,
    ACTIONS(13314), 1,
      anon_sym_with,
    STATE(9614), 1,
      sym__refinement,
    STATE(9878), 1,
      sym_template_body,
    STATE(13805), 1,
      aux_sym_compound_type_repeat1,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7778), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [556597] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12106), 1,
      sym__alpha_identifier,
    ACTIONS(12114), 1,
      sym__backquoted_id,
    ACTIONS(13478), 1,
      anon_sym_type,
    ACTIONS(13480), 1,
      sym_operator_identifier,
    STATE(12966), 1,
      sym_identifier,
    STATE(13264), 1,
      sym__soft_identifier,
    STATE(13426), 1,
      sym__type_identifier,
    STATE(12116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12110), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556637] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8125), 1,
      sym__alpha_identifier,
    ACTIONS(8137), 1,
      sym__backquoted_id,
    ACTIONS(13482), 1,
      anon_sym_type,
    ACTIONS(13484), 1,
      sym_operator_identifier,
    STATE(10101), 1,
      sym_identifier,
    STATE(10153), 1,
      sym__type_identifier,
    STATE(10235), 1,
      sym__soft_identifier,
    STATE(12117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8133), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556677] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [556703] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(13486), 1,
      anon_sym_type,
    ACTIONS(13488), 1,
      sym_operator_identifier,
    STATE(8379), 1,
      sym_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(9420), 1,
      sym__type_identifier,
    STATE(12119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556743] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [556769] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7808), 1,
      anon_sym_LBRACE,
    ACTIONS(13279), 1,
      anon_sym_COLON,
    STATE(13805), 1,
      aux_sym_compound_type_repeat1,
    STATE(14580), 1,
      sym__refinement,
    STATE(14586), 1,
      sym_template_body,
    STATE(12121), 2,
      sym_comment,
      sym_block_comment,
    STATE(14520), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [556807] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(13389), 1,
      sym_operator_identifier,
    STATE(10424), 1,
      sym_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11548), 1,
      sym__class_constructor,
    STATE(14642), 1,
      sym__class_definition,
    STATE(12122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [556847] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13492), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13490), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [556875] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13496), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13494), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [556903] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [556929] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [556955] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [556981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13500), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13498), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [557009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13504), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13502), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [557037] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [557063] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11825), 1,
      sym__alpha_identifier,
    ACTIONS(11833), 1,
      sym__backquoted_id,
    ACTIONS(13506), 1,
      anon_sym_type,
    ACTIONS(13508), 1,
      sym_operator_identifier,
    STATE(11473), 1,
      sym__soft_identifier,
    STATE(11563), 1,
      sym_identifier,
    STATE(11800), 1,
      sym__type_identifier,
    STATE(12131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11829), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557103] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4310), 1,
      sym__alpha_identifier,
    ACTIONS(4328), 1,
      sym__backquoted_id,
    ACTIONS(13510), 1,
      anon_sym_type,
    ACTIONS(13512), 1,
      sym_operator_identifier,
    STATE(4880), 1,
      sym_identifier,
    STATE(5094), 1,
      sym__soft_identifier,
    STATE(5262), 1,
      sym__type_identifier,
    STATE(12132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557143] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(13514), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(12510), 1,
      sym_identifier,
    STATE(13243), 1,
      sym__type_identifier,
    STATE(14844), 1,
      sym__type_constructor,
    STATE(12133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557183] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12695), 1,
      anon_sym_LPAREN,
    STATE(12150), 1,
      aux_sym_annotation_repeat1,
    STATE(13151), 1,
      sym_arguments,
    STATE(12134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [557215] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__alpha_identifier,
    ACTIONS(4480), 1,
      sym__backquoted_id,
    ACTIONS(13516), 1,
      anon_sym_type,
    ACTIONS(13518), 1,
      sym_operator_identifier,
    STATE(5328), 1,
      sym__soft_identifier,
    STATE(5332), 1,
      sym_identifier,
    STATE(5942), 1,
      sym__type_identifier,
    STATE(12135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557255] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9050), 1,
      anon_sym_LPAREN,
    ACTIONS(13520), 1,
      anon_sym_LBRACK,
    ACTIONS(13522), 1,
      anon_sym_POUND,
    STATE(13237), 1,
      aux_sym_annotation_repeat1,
    STATE(13701), 1,
      sym_type_arguments,
    STATE(13972), 1,
      sym_arguments,
    STATE(12136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [557293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [557319] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9409), 1,
      sym__backquoted_id,
    STATE(12138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9411), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [557347] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [557373] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9413), 1,
      sym__backquoted_id,
    STATE(12140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9415), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [557401] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(13524), 1,
      sym_operator_identifier,
    STATE(10791), 1,
      sym_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(11936), 1,
      sym__class_constructor,
    STATE(14893), 1,
      sym__class_definition,
    STATE(12141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9417), 1,
      sym__backquoted_id,
    STATE(12142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9419), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [557469] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13526), 1,
      anon_sym_type,
    ACTIONS(13528), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(10894), 1,
      sym_identifier,
    STATE(11249), 1,
      sym__type_identifier,
    STATE(12143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557509] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(13524), 1,
      sym_operator_identifier,
    STATE(10791), 1,
      sym_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(11936), 1,
      sym__class_constructor,
    STATE(14858), 1,
      sym__class_definition,
    STATE(12144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557549] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(13524), 1,
      sym_operator_identifier,
    STATE(10791), 1,
      sym_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(11936), 1,
      sym__class_constructor,
    STATE(14857), 1,
      sym__class_definition,
    STATE(12145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557589] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(12146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [557617] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6592), 1,
      sym__backquoted_id,
    ACTIONS(13530), 1,
      anon_sym_type,
    ACTIONS(13532), 1,
      sym_operator_identifier,
    STATE(6385), 1,
      sym__soft_identifier,
    STATE(6662), 1,
      sym_identifier,
    STATE(7344), 1,
      sym__type_identifier,
    STATE(12147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6588), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557657] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [557683] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13534), 1,
      anon_sym_LBRACK,
    ACTIONS(13536), 1,
      anon_sym_AT,
    ACTIONS(13538), 1,
      anon_sym_LPAREN,
    ACTIONS(13540), 1,
      anon_sym_POUND,
    STATE(14037), 1,
      aux_sym_enum_definition_repeat1,
    STATE(14054), 1,
      sym_type_arguments,
    STATE(14306), 1,
      sym_annotation,
    STATE(14573), 1,
      sym_arguments,
    STATE(12149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
  [557725] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13542), 1,
      anon_sym_LPAREN,
    STATE(13151), 1,
      sym_arguments,
    STATE(12150), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [557755] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [557781] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12004), 1,
      sym__alpha_identifier,
    ACTIONS(12012), 1,
      sym__backquoted_id,
    ACTIONS(13545), 1,
      anon_sym_type,
    ACTIONS(13547), 1,
      sym_operator_identifier,
    STATE(10937), 1,
      sym__soft_identifier,
    STATE(10957), 1,
      sym_identifier,
    STATE(11238), 1,
      sym__type_identifier,
    STATE(12152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557821] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13549), 1,
      anon_sym_DOT,
    STATE(12153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [557849] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10228), 1,
      sym__backquoted_id,
    STATE(12154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10226), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [557877] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11946), 1,
      sym__alpha_identifier,
    ACTIONS(11954), 1,
      sym__backquoted_id,
    ACTIONS(13551), 1,
      anon_sym_type,
    ACTIONS(13553), 1,
      sym_operator_identifier,
    STATE(11232), 1,
      sym__soft_identifier,
    STATE(11333), 1,
      sym_identifier,
    STATE(11643), 1,
      sym__type_identifier,
    STATE(12155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557917] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11989), 1,
      sym__alpha_identifier,
    ACTIONS(11997), 1,
      sym__backquoted_id,
    ACTIONS(13555), 1,
      anon_sym_type,
    ACTIONS(13557), 1,
      sym_operator_identifier,
    STATE(13101), 1,
      sym_identifier,
    STATE(13272), 1,
      sym__soft_identifier,
    STATE(13576), 1,
      sym__type_identifier,
    STATE(12156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11993), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557957] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(25), 1,
      anon_sym__,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(13559), 1,
      sym_operator_identifier,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(12157), 2,
      sym_comment,
      sym_block_comment,
    STATE(14553), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [557995] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12641), 1,
      anon_sym_EQ,
    STATE(12158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [558025] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12631), 1,
      anon_sym_EQ,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    STATE(12159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [558055] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6336), 1,
      sym__alpha_identifier,
    ACTIONS(6350), 1,
      sym__backquoted_id,
    ACTIONS(13561), 1,
      anon_sym_type,
    ACTIONS(13563), 1,
      sym_operator_identifier,
    STATE(6347), 1,
      sym__soft_identifier,
    STATE(6539), 1,
      sym_identifier,
    STATE(7055), 1,
      sym__type_identifier,
    STATE(12160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6346), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558095] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7064), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(12161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7062), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [558123] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13403), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11334), 1,
      sym_identifier,
    STATE(13134), 1,
      sym__type_identifier,
    STATE(14653), 1,
      sym__type_constructor,
    STATE(12162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558163] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8423), 1,
      sym__alpha_identifier,
    ACTIONS(8431), 1,
      sym__backquoted_id,
    ACTIONS(13565), 1,
      anon_sym_type,
    ACTIONS(13567), 1,
      sym_operator_identifier,
    STATE(7217), 1,
      sym_identifier,
    STATE(7297), 1,
      sym__soft_identifier,
    STATE(7443), 1,
      sym__type_identifier,
    STATE(12163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8427), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10244), 1,
      sym__backquoted_id,
    STATE(12164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10242), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [558231] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4774), 1,
      sym__alpha_identifier,
    ACTIONS(4792), 1,
      sym__backquoted_id,
    ACTIONS(13569), 1,
      anon_sym_type,
    ACTIONS(13571), 1,
      sym_operator_identifier,
    STATE(5656), 1,
      sym_identifier,
    STATE(5800), 1,
      sym__soft_identifier,
    STATE(6384), 1,
      sym__type_identifier,
    STATE(12165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4786), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558271] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4180), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(12166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [558299] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10222), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(12167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10220), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [558327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11668), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(12168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11666), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [558355] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [558381] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13403), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11334), 1,
      sym_identifier,
    STATE(13134), 1,
      sym__type_identifier,
    STATE(14672), 1,
      sym__type_constructor,
    STATE(12170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558421] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13573), 1,
      anon_sym_LBRACK,
    ACTIONS(13575), 1,
      anon_sym_LPAREN,
    ACTIONS(13577), 1,
      sym__automatic_semicolon,
    STATE(13280), 1,
      sym_type_parameters,
    STATE(13281), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14122), 1,
      sym_parameters,
    STATE(14205), 1,
      sym__using_parameters_clause,
    STATE(12171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 6,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [558461] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4214), 1,
      sym__alpha_identifier,
    ACTIONS(4232), 1,
      sym__backquoted_id,
    ACTIONS(13579), 1,
      anon_sym_type,
    ACTIONS(13581), 1,
      sym_operator_identifier,
    STATE(4978), 1,
      sym_identifier,
    STATE(5031), 1,
      sym__soft_identifier,
    STATE(5151), 1,
      sym__type_identifier,
    STATE(12172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4226), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558501] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6518), 1,
      sym__backquoted_id,
    ACTIONS(13583), 1,
      anon_sym_type,
    ACTIONS(13585), 1,
      sym_operator_identifier,
    STATE(7777), 1,
      sym_identifier,
    STATE(7863), 1,
      sym__soft_identifier,
    STATE(8899), 1,
      sym__type_identifier,
    STATE(12173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6514), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558541] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [558567] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7956), 1,
      sym__alpha_identifier,
    ACTIONS(7968), 1,
      sym__backquoted_id,
    ACTIONS(13587), 1,
      anon_sym_type,
    ACTIONS(13589), 1,
      sym_operator_identifier,
    STATE(13521), 1,
      sym__soft_identifier,
    STATE(13621), 1,
      sym_identifier,
    STATE(13802), 1,
      sym__type_identifier,
    STATE(12175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7964), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558607] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8042), 1,
      sym__alpha_identifier,
    ACTIONS(8050), 1,
      sym__backquoted_id,
    ACTIONS(13591), 1,
      anon_sym_type,
    ACTIONS(13593), 1,
      sym_operator_identifier,
    STATE(7769), 1,
      sym__soft_identifier,
    STATE(7855), 1,
      sym_identifier,
    STATE(8006), 1,
      sym__type_identifier,
    STATE(12176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8046), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558647] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4422), 1,
      sym__alpha_identifier,
    ACTIONS(4440), 1,
      sym__backquoted_id,
    ACTIONS(13595), 1,
      anon_sym_type,
    ACTIONS(13597), 1,
      sym_operator_identifier,
    STATE(6399), 1,
      sym__soft_identifier,
    STATE(6517), 1,
      sym_identifier,
    STATE(7399), 1,
      sym__type_identifier,
    STATE(12177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4434), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558687] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4812), 1,
      sym__alpha_identifier,
    ACTIONS(4824), 1,
      sym__backquoted_id,
    ACTIONS(13599), 1,
      anon_sym_type,
    ACTIONS(13601), 1,
      sym_operator_identifier,
    STATE(6330), 1,
      sym__soft_identifier,
    STATE(6746), 1,
      sym_identifier,
    STATE(7454), 1,
      sym__type_identifier,
    STATE(12178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4820), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558727] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [558755] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6996), 1,
      sym__alpha_identifier,
    ACTIONS(7006), 1,
      sym__backquoted_id,
    ACTIONS(13603), 1,
      anon_sym_type,
    ACTIONS(13605), 1,
      sym_operator_identifier,
    STATE(7239), 1,
      sym_identifier,
    STATE(7458), 1,
      sym__soft_identifier,
    STATE(8243), 1,
      sym__type_identifier,
    STATE(12180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7002), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558795] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12683), 1,
      anon_sym_EQ,
    STATE(12181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [558825] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7988), 1,
      sym__alpha_identifier,
    ACTIONS(7996), 1,
      sym__backquoted_id,
    ACTIONS(13607), 1,
      anon_sym_type,
    ACTIONS(13609), 1,
      sym_operator_identifier,
    STATE(6942), 1,
      sym_identifier,
    STATE(7216), 1,
      sym__type_identifier,
    STATE(7258), 1,
      sym__soft_identifier,
    STATE(12182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7992), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558865] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(13514), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(12510), 1,
      sym_identifier,
    STATE(13243), 1,
      sym__type_identifier,
    STATE(14733), 1,
      sym__type_constructor,
    STATE(12183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558905] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6574), 1,
      sym__backquoted_id,
    ACTIONS(13611), 1,
      anon_sym_type,
    ACTIONS(13613), 1,
      sym_operator_identifier,
    STATE(5965), 1,
      sym_identifier,
    STATE(6060), 1,
      sym__soft_identifier,
    STATE(6165), 1,
      sym__type_identifier,
    STATE(12184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6570), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [558945] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12779), 1,
      anon_sym_EQ,
    STATE(12185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [558975] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9707), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(12186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9709), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [559003] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(13524), 1,
      sym_operator_identifier,
    STATE(10791), 1,
      sym_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(11936), 1,
      sym__class_constructor,
    STATE(14955), 1,
      sym__class_definition,
    STATE(12187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559043] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [559069] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12142), 1,
      sym__alpha_identifier,
    ACTIONS(12150), 1,
      sym__backquoted_id,
    ACTIONS(13615), 1,
      anon_sym_type,
    ACTIONS(13617), 1,
      sym_operator_identifier,
    STATE(12598), 1,
      sym_identifier,
    STATE(12655), 1,
      sym__soft_identifier,
    STATE(13356), 1,
      sym__type_identifier,
    STATE(12189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12146), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559109] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4692), 1,
      sym__alpha_identifier,
    ACTIONS(4704), 1,
      sym__backquoted_id,
    ACTIONS(13619), 1,
      anon_sym_type,
    ACTIONS(13621), 1,
      sym_operator_identifier,
    STATE(4547), 1,
      sym__soft_identifier,
    STATE(4571), 1,
      sym_identifier,
    STATE(4724), 1,
      sym__type_identifier,
    STATE(12190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559149] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8371), 1,
      sym__alpha_identifier,
    ACTIONS(8383), 1,
      sym__backquoted_id,
    ACTIONS(13623), 1,
      anon_sym_type,
    ACTIONS(13625), 1,
      sym_operator_identifier,
    STATE(5323), 1,
      sym_identifier,
    STATE(5481), 1,
      sym__soft_identifier,
    STATE(5491), 1,
      sym__type_identifier,
    STATE(12191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8379), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559189] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9724), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(12192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9726), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [559217] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [559243] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 13,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [559269] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9738), 1,
      sym__backquoted_id,
    STATE(12195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9740), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [559297] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9626), 1,
      sym__backquoted_id,
    STATE(12196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9628), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [559325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13627), 1,
      anon_sym_STAR,
    STATE(12197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [559353] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [559379] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10288), 1,
      sym__backquoted_id,
    STATE(12199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10286), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [559407] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 13,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [559433] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [559461] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6268), 1,
      sym__alpha_identifier,
    ACTIONS(6282), 1,
      sym__backquoted_id,
    ACTIONS(13629), 1,
      anon_sym_type,
    ACTIONS(13631), 1,
      sym_operator_identifier,
    STATE(5862), 1,
      sym__soft_identifier,
    STATE(5896), 1,
      sym_identifier,
    STATE(6287), 1,
      sym__type_identifier,
    STATE(12202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6278), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [559527] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9556), 1,
      sym__backquoted_id,
    STATE(12204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9558), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [559555] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12722), 1,
      anon_sym_EQ,
    STATE(12205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [559585] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(13635), 1,
      sym_operator_identifier,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15025), 1,
      sym_identifier,
    ACTIONS(13633), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(12206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7580), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [559649] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6202), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      sym__backquoted_id,
    ACTIONS(13637), 1,
      anon_sym_type,
    ACTIONS(13639), 1,
      sym_operator_identifier,
    STATE(9425), 1,
      sym_identifier,
    STATE(9455), 1,
      sym__soft_identifier,
    STATE(9626), 1,
      sym__type_identifier,
    STATE(12208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6212), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559689] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12720), 1,
      anon_sym_EQ,
    STATE(12209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [559719] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [559745] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9519), 1,
      sym__backquoted_id,
    STATE(12211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9521), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [559773] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [559799] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10357), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(12213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10355), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [559827] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13403), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11334), 1,
      sym_identifier,
    STATE(13700), 1,
      sym__type_identifier,
    STATE(15035), 1,
      sym__type_constructor,
    STATE(12214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559867] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8030), 1,
      sym__alpha_identifier,
    ACTIONS(8038), 1,
      sym__backquoted_id,
    ACTIONS(13641), 1,
      anon_sym_type,
    ACTIONS(13643), 1,
      sym_operator_identifier,
    STATE(8521), 1,
      sym__type_identifier,
    STATE(8568), 1,
      sym_identifier,
    STATE(8625), 1,
      sym__soft_identifier,
    STATE(12215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8034), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [559907] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [559933] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9515), 1,
      sym__backquoted_id,
    STATE(12217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9517), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [559961] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12088), 1,
      sym__alpha_identifier,
    ACTIONS(12096), 1,
      sym__backquoted_id,
    ACTIONS(13645), 1,
      anon_sym_type,
    ACTIONS(13647), 1,
      sym_operator_identifier,
    STATE(12528), 1,
      sym__soft_identifier,
    STATE(12849), 1,
      sym_identifier,
    STATE(13061), 1,
      sym__type_identifier,
    STATE(12218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12092), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560001] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13254), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [560027] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(13649), 1,
      anon_sym_type,
    ACTIONS(13651), 1,
      sym_operator_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11674), 1,
      sym_identifier,
    STATE(11898), 1,
      sym__type_identifier,
    STATE(12220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560067] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [560093] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13403), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11334), 1,
      sym_identifier,
    STATE(13134), 1,
      sym__type_identifier,
    STATE(14711), 1,
      sym__type_constructor,
    STATE(12222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560133] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(13389), 1,
      sym_operator_identifier,
    STATE(10424), 1,
      sym_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11548), 1,
      sym__class_constructor,
    STATE(14644), 1,
      sym__class_definition,
    STATE(12223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560173] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13256), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [560199] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [560225] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8199), 1,
      sym__alpha_identifier,
    ACTIONS(8207), 1,
      sym__backquoted_id,
    ACTIONS(13653), 1,
      anon_sym_type,
    ACTIONS(13655), 1,
      sym_operator_identifier,
    STATE(6914), 1,
      sym__type_identifier,
    STATE(7103), 1,
      sym_identifier,
    STATE(7174), 1,
      sym__soft_identifier,
    STATE(12226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8203), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560265] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [560291] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [560317] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4886), 1,
      sym__alpha_identifier,
    ACTIONS(4904), 1,
      sym__backquoted_id,
    ACTIONS(13657), 1,
      anon_sym_type,
    ACTIONS(13659), 1,
      sym_operator_identifier,
    STATE(4879), 1,
      sym_identifier,
    STATE(5087), 1,
      sym__soft_identifier,
    STATE(5462), 1,
      sym__type_identifier,
    STATE(12229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10297), 1,
      sym__backquoted_id,
    STATE(12230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10295), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [560385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [560411] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [560437] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [560463] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13403), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11334), 1,
      sym_identifier,
    STATE(13700), 1,
      sym__type_identifier,
    STATE(14998), 1,
      sym__type_constructor,
    STATE(12234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560503] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(12235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [560531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [560557] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7916), 1,
      sym__alpha_identifier,
    ACTIONS(7928), 1,
      sym__backquoted_id,
    ACTIONS(13661), 1,
      anon_sym_type,
    ACTIONS(13663), 1,
      sym_operator_identifier,
    STATE(11727), 1,
      sym__soft_identifier,
    STATE(11966), 1,
      sym_identifier,
    STATE(12370), 1,
      sym__type_identifier,
    STATE(12237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7924), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560597] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [560623] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(13389), 1,
      sym_operator_identifier,
    STATE(10424), 1,
      sym_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11548), 1,
      sym__class_constructor,
    STATE(14679), 1,
      sym__class_definition,
    STATE(12239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560663] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4562), 1,
      sym__alpha_identifier,
    ACTIONS(4580), 1,
      sym__backquoted_id,
    ACTIONS(13665), 1,
      anon_sym_type,
    ACTIONS(13667), 1,
      sym_operator_identifier,
    STATE(5868), 1,
      sym__soft_identifier,
    STATE(6062), 1,
      sym_identifier,
    STATE(6595), 1,
      sym__type_identifier,
    STATE(12240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4574), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560703] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12710), 1,
      sym__backquoted_id,
    STATE(12241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12708), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [560731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12703), 1,
      sym__backquoted_id,
    STATE(12242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12701), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [560759] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8437), 1,
      sym__alpha_identifier,
    ACTIONS(8445), 1,
      sym__backquoted_id,
    ACTIONS(13669), 1,
      anon_sym_type,
    ACTIONS(13671), 1,
      sym_operator_identifier,
    STATE(6396), 1,
      sym_identifier,
    STATE(6404), 1,
      sym__soft_identifier,
    STATE(6633), 1,
      sym__type_identifier,
    STATE(12243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8441), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560799] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [560825] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8411), 1,
      sym__alpha_identifier,
    ACTIONS(8419), 1,
      sym__backquoted_id,
    ACTIONS(13673), 1,
      anon_sym_type,
    ACTIONS(13675), 1,
      sym_operator_identifier,
    STATE(8428), 1,
      sym__type_identifier,
    STATE(8632), 1,
      sym_identifier,
    STATE(8883), 1,
      sym__soft_identifier,
    STATE(12245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8415), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10301), 1,
      sym__backquoted_id,
    STATE(12246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10299), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [560893] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [560919] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(13677), 1,
      anon_sym_type,
    ACTIONS(13679), 1,
      sym_operator_identifier,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(5955), 1,
      sym_identifier,
    STATE(6432), 1,
      sym__type_identifier,
    STATE(12248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [560959] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [560985] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7940), 1,
      sym__alpha_identifier,
    ACTIONS(7952), 1,
      sym__backquoted_id,
    ACTIONS(13681), 1,
      anon_sym_type,
    ACTIONS(13683), 1,
      sym_operator_identifier,
    STATE(11524), 1,
      sym_identifier,
    STATE(11669), 1,
      sym__soft_identifier,
    STATE(11739), 1,
      sym__type_identifier,
    STATE(12250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7948), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561025] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4278), 1,
      sym__alpha_identifier,
    ACTIONS(4296), 1,
      sym__backquoted_id,
    ACTIONS(13685), 1,
      anon_sym_type,
    ACTIONS(13687), 1,
      sym_operator_identifier,
    STATE(7091), 1,
      sym_identifier,
    STATE(7385), 1,
      sym__soft_identifier,
    STATE(8045), 1,
      sym__type_identifier,
    STATE(12251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4290), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561065] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8321), 1,
      sym__alpha_identifier,
    ACTIONS(8329), 1,
      sym__backquoted_id,
    ACTIONS(13689), 1,
      anon_sym_type,
    ACTIONS(13691), 1,
      sym_operator_identifier,
    STATE(5601), 1,
      sym__type_identifier,
    STATE(5875), 1,
      sym__soft_identifier,
    STATE(6092), 1,
      sym_identifier,
    STATE(12252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8325), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561105] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13693), 1,
      anon_sym_end,
    STATE(6920), 1,
      sym__end_marker,
    STATE(12253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [561135] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [561161] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6698), 1,
      sym__alpha_identifier,
    ACTIONS(6712), 1,
      sym__backquoted_id,
    ACTIONS(13695), 1,
      anon_sym_type,
    ACTIONS(13697), 1,
      sym_operator_identifier,
    STATE(5215), 1,
      sym__soft_identifier,
    STATE(5387), 1,
      sym_identifier,
    STATE(5658), 1,
      sym__type_identifier,
    STATE(12255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6708), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561201] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [561227] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [561253] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(13524), 1,
      sym_operator_identifier,
    STATE(10791), 1,
      sym_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(11936), 1,
      sym__class_constructor,
    STATE(15045), 1,
      sym__class_definition,
    STATE(12258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561293] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(13514), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(12510), 1,
      sym_identifier,
    STATE(13243), 1,
      sym__type_identifier,
    STATE(14618), 1,
      sym__type_constructor,
    STATE(12259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561333] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [561359] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [561385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [561411] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12760), 1,
      anon_sym_EQ,
    STATE(12263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [561441] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4660), 1,
      sym__alpha_identifier,
    ACTIONS(4678), 1,
      sym__backquoted_id,
    ACTIONS(13699), 1,
      anon_sym_type,
    ACTIONS(13701), 1,
      sym_operator_identifier,
    STATE(4562), 1,
      sym_identifier,
    STATE(4601), 1,
      sym__soft_identifier,
    STATE(4792), 1,
      sym__type_identifier,
    STATE(12264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4672), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561481] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(13524), 1,
      sym_operator_identifier,
    STATE(10791), 1,
      sym_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(11936), 1,
      sym__class_constructor,
    STATE(15056), 1,
      sym__class_definition,
    STATE(12265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561521] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12379), 1,
      anon_sym_AT,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(13065), 1,
      sym_annotation,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14079), 1,
      aux_sym__class_constructor_repeat1,
    STATE(14225), 1,
      sym_access_modifier,
    ACTIONS(12381), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(12266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12659), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [561563] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12586), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [561589] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4342), 1,
      sym__alpha_identifier,
    ACTIONS(4354), 1,
      sym__backquoted_id,
    ACTIONS(13703), 1,
      anon_sym_type,
    ACTIONS(13705), 1,
      sym_operator_identifier,
    STATE(7539), 1,
      sym__soft_identifier,
    STATE(8179), 1,
      sym_identifier,
    STATE(8759), 1,
      sym__type_identifier,
    STATE(12268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4350), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561629] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12588), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [561655] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_do,
      anon_sym_yield,
  [561681] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [561707] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [561733] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [561759] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [561785] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8018), 1,
      sym__alpha_identifier,
    ACTIONS(8026), 1,
      sym__backquoted_id,
    ACTIONS(13707), 1,
      anon_sym_type,
    ACTIONS(13709), 1,
      sym_operator_identifier,
    STATE(7017), 1,
      sym_identifier,
    STATE(7071), 1,
      sym__type_identifier,
    STATE(7330), 1,
      sym__soft_identifier,
    STATE(12275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561825] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4530), 1,
      sym__alpha_identifier,
    ACTIONS(4548), 1,
      sym__backquoted_id,
    ACTIONS(13711), 1,
      anon_sym_type,
    ACTIONS(13713), 1,
      sym_operator_identifier,
    STATE(5882), 1,
      sym__soft_identifier,
    STATE(6021), 1,
      sym_identifier,
    STATE(6727), 1,
      sym__type_identifier,
    STATE(12276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4542), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561865] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [561893] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12754), 1,
      anon_sym_EQ,
    STATE(12278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [561923] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11961), 1,
      sym__alpha_identifier,
    ACTIONS(11969), 1,
      sym__backquoted_id,
    ACTIONS(13715), 1,
      anon_sym_type,
    ACTIONS(13717), 1,
      sym_operator_identifier,
    STATE(12212), 1,
      sym__soft_identifier,
    STATE(12235), 1,
      sym_identifier,
    STATE(12856), 1,
      sym__type_identifier,
    STATE(12279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11965), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [561963] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [561989] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(13719), 1,
      anon_sym_type,
    ACTIONS(13721), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(4321), 1,
      sym_identifier,
    STATE(4325), 1,
      sym__type_identifier,
    STATE(12281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562029] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13725), 1,
      anon_sym_COMMA,
    ACTIONS(13727), 1,
      anon_sym_with,
    STATE(13339), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(13342), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(12282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13723), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [562063] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [562089] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562115] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(13729), 1,
      anon_sym_type,
    ACTIONS(13731), 1,
      sym_operator_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(12000), 1,
      sym_identifier,
    STATE(12312), 1,
      sym__type_identifier,
    STATE(12285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12655), 1,
      anon_sym_EQ,
    STATE(12286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [562185] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [562211] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562237] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12633), 1,
      sym__backquoted_id,
    ACTIONS(12645), 1,
      anon_sym_EQ,
    STATE(12289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12625), 11,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [562267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562293] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(13733), 1,
      anon_sym_type,
    ACTIONS(13735), 1,
      sym_operator_identifier,
    STATE(5281), 1,
      sym_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(5704), 1,
      sym__type_identifier,
    STATE(12291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562333] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562359] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9161), 1,
      anon_sym_LPAREN,
    ACTIONS(13737), 1,
      anon_sym_LBRACK,
    ACTIONS(13739), 1,
      anon_sym_POUND,
    STATE(13293), 1,
      aux_sym_annotation_repeat1,
    STATE(13498), 1,
      sym_type_arguments,
    STATE(13775), 1,
      sym_arguments,
    STATE(12293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [562397] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562423] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562449] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562475] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11883), 1,
      sym__alpha_identifier,
    ACTIONS(11891), 1,
      sym__backquoted_id,
    ACTIONS(13741), 1,
      anon_sym_type,
    ACTIONS(13743), 1,
      sym_operator_identifier,
    STATE(12486), 1,
      sym_identifier,
    STATE(12652), 1,
      sym__soft_identifier,
    STATE(13288), 1,
      sym__type_identifier,
    STATE(12297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11887), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562515] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13256), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562541] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4712), 1,
      sym__alpha_identifier,
    ACTIONS(4730), 1,
      sym__backquoted_id,
    ACTIONS(13745), 1,
      anon_sym_type,
    ACTIONS(13747), 1,
      sym_operator_identifier,
    STATE(6328), 1,
      sym__soft_identifier,
    STATE(6653), 1,
      sym_identifier,
    STATE(7153), 1,
      sym__type_identifier,
    STATE(12299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4724), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562581] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13254), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562607] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [562633] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562659] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8393), 1,
      sym__alpha_identifier,
    ACTIONS(8401), 1,
      sym__backquoted_id,
    ACTIONS(13749), 1,
      anon_sym_type,
    ACTIONS(13751), 1,
      sym_operator_identifier,
    STATE(7599), 1,
      sym__soft_identifier,
    STATE(7642), 1,
      sym__type_identifier,
    STATE(8010), 1,
      sym_identifier,
    STATE(12303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8397), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562699] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12729), 1,
      sym__backquoted_id,
    STATE(12304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12727), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [562727] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562779] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6772), 1,
      sym__alpha_identifier,
    ACTIONS(6786), 1,
      sym__backquoted_id,
    ACTIONS(13753), 1,
      anon_sym_type,
    ACTIONS(13755), 1,
      sym_operator_identifier,
    STATE(6319), 1,
      sym_identifier,
    STATE(6418), 1,
      sym__soft_identifier,
    STATE(7500), 1,
      sym__type_identifier,
    STATE(12307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6782), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [562819] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562871] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [562897] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [562923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [562949] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [562975] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [563001] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [563027] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [563053] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(12970), 1,
      anon_sym_COLON,
    ACTIONS(12974), 1,
      anon_sym_derives,
    STATE(13068), 1,
      sym_derives_clause,
    STATE(14606), 1,
      sym__definition_body,
    STATE(14848), 1,
      sym_template_body,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13757), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [563093] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [563119] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [563145] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [563171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(12321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [563199] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [563225] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [563251] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4594), 1,
      sym__alpha_identifier,
    ACTIONS(4612), 1,
      sym__backquoted_id,
    ACTIONS(13759), 1,
      anon_sym_type,
    ACTIONS(13761), 1,
      sym_operator_identifier,
    STATE(5264), 1,
      sym__soft_identifier,
    STATE(5389), 1,
      sym_identifier,
    STATE(5964), 1,
      sym__type_identifier,
    STATE(12324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563291] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [563317] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6402), 1,
      sym__alpha_identifier,
    ACTIONS(6416), 1,
      sym__backquoted_id,
    ACTIONS(13763), 1,
      anon_sym_type,
    ACTIONS(13765), 1,
      sym_operator_identifier,
    STATE(5895), 1,
      sym__soft_identifier,
    STATE(5906), 1,
      sym_identifier,
    STATE(6723), 1,
      sym__type_identifier,
    STATE(12326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563357] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12118), 1,
      sym__alpha_identifier,
    ACTIONS(12126), 1,
      sym__backquoted_id,
    ACTIONS(13767), 1,
      anon_sym_type,
    ACTIONS(13769), 1,
      sym_operator_identifier,
    STATE(13294), 1,
      sym__soft_identifier,
    STATE(13319), 1,
      sym_identifier,
    STATE(13452), 1,
      sym__type_identifier,
    STATE(12327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12122), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563397] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13771), 1,
      anon_sym_LBRACK,
    ACTIONS(13773), 1,
      anon_sym_match,
    STATE(6538), 1,
      sym_type_arguments,
    STATE(12328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [563429] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12043), 1,
      sym__alpha_identifier,
    ACTIONS(12051), 1,
      sym__backquoted_id,
    ACTIONS(13775), 1,
      anon_sym_type,
    ACTIONS(13777), 1,
      sym_operator_identifier,
    STATE(10903), 1,
      sym_identifier,
    STATE(10946), 1,
      sym__soft_identifier,
    STATE(11286), 1,
      sym__type_identifier,
    STATE(12329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12047), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563469] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13781), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13779), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [563497] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [563523] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(13783), 1,
      anon_sym_type,
    ACTIONS(13785), 1,
      sym_operator_identifier,
    STATE(6857), 1,
      sym_identifier,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7881), 1,
      sym__type_identifier,
    STATE(12332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563563] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [563589] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [563615] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13789), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13787), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [563643] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4182), 1,
      sym__alpha_identifier,
    ACTIONS(4200), 1,
      sym__backquoted_id,
    ACTIONS(13791), 1,
      anon_sym_type,
    ACTIONS(13793), 1,
      sym_operator_identifier,
    STATE(4657), 1,
      sym__soft_identifier,
    STATE(4692), 1,
      sym_identifier,
    STATE(4856), 1,
      sym__type_identifier,
    STATE(12336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4194), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563683] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [563709] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13797), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13795), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [563737] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13801), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13799), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [563765] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [563791] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13805), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13803), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [563819] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(489), 1,
      sym__alpha_identifier,
    ACTIONS(503), 1,
      anon_sym__,
    ACTIONS(553), 1,
      sym__backquoted_id,
    ACTIONS(13807), 1,
      sym_operator_identifier,
    STATE(5518), 1,
      sym__soft_identifier,
    STATE(12342), 2,
      sym_comment,
      sym_block_comment,
    STATE(14832), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [563857] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [563883] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12748), 1,
      sym__backquoted_id,
    STATE(12344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12746), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [563911] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [563937] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13811), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13809), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [563965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [563991] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6610), 1,
      sym__backquoted_id,
    ACTIONS(13813), 1,
      anon_sym_type,
    ACTIONS(13815), 1,
      sym_operator_identifier,
    STATE(7134), 1,
      sym__soft_identifier,
    STATE(7373), 1,
      sym_identifier,
    STATE(7535), 1,
      sym__type_identifier,
    STATE(12348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564031] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564057] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [564083] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [564109] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [564135] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8179), 1,
      sym__alpha_identifier,
    ACTIONS(8187), 1,
      sym__backquoted_id,
    ACTIONS(13817), 1,
      anon_sym_type,
    ACTIONS(13819), 1,
      sym_operator_identifier,
    STATE(6412), 1,
      sym__type_identifier,
    STATE(6716), 1,
      sym_identifier,
    STATE(6730), 1,
      sym__soft_identifier,
    STATE(12353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8183), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12354), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13823), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13821), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [564231] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564257] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13771), 1,
      anon_sym_LBRACK,
    STATE(6538), 1,
      sym_type_arguments,
    STATE(12357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564287] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(13825), 1,
      anon_sym_type,
    ACTIONS(13827), 1,
      sym_operator_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(8825), 1,
      sym_identifier,
    STATE(9480), 1,
      sym__type_identifier,
    STATE(12358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564327] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564353] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(13829), 1,
      anon_sym_type,
    ACTIONS(13831), 1,
      sym_operator_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7392), 1,
      sym_identifier,
    STATE(8165), 1,
      sym__type_identifier,
    STATE(12360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564393] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564419] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12607), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [564445] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13771), 1,
      anon_sym_LBRACK,
    STATE(6538), 1,
      sym_type_arguments,
    STATE(12363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564475] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(13833), 1,
      anon_sym_type,
    ACTIONS(13835), 1,
      sym_operator_identifier,
    STATE(6813), 1,
      sym_identifier,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7929), 1,
      sym__type_identifier,
    STATE(12364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564515] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8084), 1,
      sym__alpha_identifier,
    ACTIONS(8092), 1,
      sym__backquoted_id,
    ACTIONS(13837), 1,
      anon_sym_type,
    ACTIONS(13839), 1,
      sym_operator_identifier,
    STATE(7563), 1,
      sym__type_identifier,
    STATE(7664), 1,
      sym__soft_identifier,
    STATE(7878), 1,
      sym_identifier,
    STATE(12365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8088), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564555] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4750), 1,
      sym__alpha_identifier,
    ACTIONS(4762), 1,
      sym__backquoted_id,
    ACTIONS(13841), 1,
      anon_sym_type,
    ACTIONS(13843), 1,
      sym_operator_identifier,
    STATE(4635), 1,
      sym__soft_identifier,
    STATE(4698), 1,
      sym_identifier,
    STATE(4834), 1,
      sym__type_identifier,
    STATE(12366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4758), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564595] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [564621] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13771), 1,
      anon_sym_LBRACK,
    ACTIONS(13773), 1,
      anon_sym_match,
    STATE(6538), 1,
      sym_type_arguments,
    STATE(12368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564653] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564679] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [564705] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [564731] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13771), 1,
      anon_sym_LBRACK,
    STATE(6538), 1,
      sym_type_arguments,
    STATE(12372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564761] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11922), 1,
      sym__alpha_identifier,
    ACTIONS(11930), 1,
      sym__backquoted_id,
    ACTIONS(13845), 1,
      anon_sym_type,
    ACTIONS(13847), 1,
      sym_operator_identifier,
    STATE(11340), 1,
      sym_identifier,
    STATE(11400), 1,
      sym__soft_identifier,
    STATE(11526), 1,
      sym__type_identifier,
    STATE(12373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11926), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564827] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4830), 1,
      sym__alpha_identifier,
    ACTIONS(4848), 1,
      sym__backquoted_id,
    ACTIONS(13849), 1,
      anon_sym_type,
    ACTIONS(13851), 1,
      sym_operator_identifier,
    STATE(5100), 1,
      sym_identifier,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5864), 1,
      sym__type_identifier,
    STATE(12375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4842), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [564867] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13853), 1,
      anon_sym_LPAREN,
    STATE(13391), 1,
      sym_arguments,
    STATE(12376), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [564897] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13858), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13856), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [564925] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564951] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [564977] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(13524), 1,
      sym_operator_identifier,
    STATE(10791), 1,
      sym_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(11936), 1,
      sym__class_constructor,
    STATE(15107), 1,
      sym__class_definition,
    STATE(12380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565017] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(13514), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(12510), 1,
      sym_identifier,
    STATE(13243), 1,
      sym__type_identifier,
    STATE(14671), 1,
      sym__type_constructor,
    STATE(12381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565057] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565083] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8359), 1,
      sym__alpha_identifier,
    ACTIONS(8367), 1,
      sym__backquoted_id,
    ACTIONS(13860), 1,
      anon_sym_type,
    ACTIONS(13862), 1,
      sym_operator_identifier,
    STATE(6247), 1,
      sym__type_identifier,
    STATE(6267), 1,
      sym_identifier,
    STATE(6353), 1,
      sym__soft_identifier,
    STATE(12383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8363), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565123] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12572), 1,
      anon_sym_AT,
    STATE(12464), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13052), 1,
      sym_annotation,
    STATE(12384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [565155] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6840), 1,
      sym__backquoted_id,
    ACTIONS(13864), 1,
      anon_sym_type,
    ACTIONS(13866), 1,
      sym_operator_identifier,
    STATE(6232), 1,
      sym__soft_identifier,
    STATE(6519), 1,
      sym_identifier,
    STATE(7052), 1,
      sym__type_identifier,
    STATE(12385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6836), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13771), 1,
      anon_sym_LBRACK,
    STATE(6538), 1,
      sym_type_arguments,
    STATE(12386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565225] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565251] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(13868), 1,
      anon_sym_type,
    ACTIONS(13870), 1,
      sym_operator_identifier,
    STATE(4926), 1,
      sym_identifier,
    STATE(5072), 1,
      sym__soft_identifier,
    STATE(5449), 1,
      sym__type_identifier,
    STATE(12388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565291] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565317] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565343] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [565369] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [565395] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8537), 1,
      anon_sym_LPAREN,
    STATE(12376), 1,
      aux_sym_annotation_repeat1,
    STATE(13391), 1,
      sym_arguments,
    STATE(12393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [565427] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6360), 1,
      sym__alpha_identifier,
    ACTIONS(6374), 1,
      sym__backquoted_id,
    ACTIONS(13872), 1,
      anon_sym_type,
    ACTIONS(13874), 1,
      sym_operator_identifier,
    STATE(4752), 1,
      sym_identifier,
    STATE(4788), 1,
      sym__soft_identifier,
    STATE(4909), 1,
      sym__type_identifier,
    STATE(12394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565467] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(846), 1,
      sym__alpha_identifier,
    ACTIONS(852), 1,
      anon_sym__,
    ACTIONS(876), 1,
      sym__backquoted_id,
    ACTIONS(13876), 1,
      sym_operator_identifier,
    STATE(5497), 1,
      sym__soft_identifier,
    STATE(12395), 2,
      sym_comment,
      sym_block_comment,
    STATE(16603), 2,
      sym_identifier,
      sym_wildcard,
    ACTIONS(856), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565505] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565531] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8275), 1,
      sym__alpha_identifier,
    ACTIONS(8283), 1,
      sym__backquoted_id,
    ACTIONS(13878), 1,
      anon_sym_type,
    ACTIONS(13880), 1,
      sym_operator_identifier,
    STATE(6260), 1,
      sym__type_identifier,
    STATE(6327), 1,
      sym__soft_identifier,
    STATE(6715), 1,
      sym_identifier,
    STATE(12397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8279), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565571] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565597] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565651] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9674), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(12401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9676), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [565679] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(13882), 1,
      anon_sym_type,
    ACTIONS(13884), 1,
      sym_operator_identifier,
    STATE(5670), 1,
      sym_identifier,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6314), 1,
      sym__type_identifier,
    STATE(12402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565719] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9654), 2,
      anon_sym_LBRACK,
      sym__backquoted_id,
    STATE(12403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9656), 11,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [565747] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13886), 1,
      anon_sym_LBRACK,
    STATE(6553), 1,
      sym_type_arguments,
    STATE(12404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565777] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4624), 1,
      sym__alpha_identifier,
    ACTIONS(4642), 1,
      sym__backquoted_id,
    ACTIONS(13888), 1,
      anon_sym_type,
    ACTIONS(13890), 1,
      sym_operator_identifier,
    STATE(4445), 1,
      sym__soft_identifier,
    STATE(4478), 1,
      sym_identifier,
    STATE(4548), 1,
      sym__type_identifier,
    STATE(12405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565817] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(8559), 1,
      sym_operator_identifier,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15097), 1,
      sym_identifier,
    ACTIONS(8557), 2,
      anon_sym_val,
      anon_sym_var,
    STATE(12406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7580), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565855] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [565881] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11856), 1,
      sym__alpha_identifier,
    ACTIONS(11864), 1,
      sym__backquoted_id,
    ACTIONS(13892), 1,
      anon_sym_type,
    ACTIONS(13894), 1,
      sym_operator_identifier,
    STATE(7637), 1,
      sym_identifier,
    STATE(8044), 1,
      sym__soft_identifier,
    STATE(8286), 1,
      sym__type_identifier,
    STATE(12408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11860), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565921] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6884), 1,
      sym__alpha_identifier,
    ACTIONS(6894), 1,
      sym__backquoted_id,
    ACTIONS(13896), 1,
      anon_sym_type,
    ACTIONS(13898), 1,
      sym_operator_identifier,
    STATE(6268), 1,
      sym__soft_identifier,
    STATE(6335), 1,
      sym_identifier,
    STATE(6969), 1,
      sym__type_identifier,
    STATE(12409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6890), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [565961] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6378), 1,
      sym__alpha_identifier,
    ACTIONS(6392), 1,
      sym__backquoted_id,
    ACTIONS(13900), 1,
      anon_sym_type,
    ACTIONS(13902), 1,
      sym_operator_identifier,
    STATE(5211), 1,
      sym__soft_identifier,
    STATE(5306), 1,
      sym_identifier,
    STATE(5845), 1,
      sym__type_identifier,
    STATE(12410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566001] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(13904), 1,
      anon_sym_type,
    ACTIONS(13906), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(12111), 1,
      sym_identifier,
    STATE(12613), 1,
      sym__type_identifier,
    STATE(12411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566041] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [566067] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(13908), 1,
      anon_sym_type,
    ACTIONS(13910), 1,
      sym_operator_identifier,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(14036), 1,
      sym_identifier,
    STATE(14058), 1,
      sym__type_identifier,
    STATE(12413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566107] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [566133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13914), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13912), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [566161] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(12970), 1,
      anon_sym_COLON,
    ACTIONS(12974), 1,
      anon_sym_derives,
    ACTIONS(13918), 1,
      sym__automatic_semicolon,
    STATE(13074), 1,
      sym_derives_clause,
    STATE(14740), 1,
      sym__definition_body,
    STATE(14848), 1,
      sym_template_body,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13916), 4,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [566203] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13886), 1,
      anon_sym_LBRACK,
    ACTIONS(13921), 1,
      anon_sym_match,
    STATE(6553), 1,
      sym_type_arguments,
    STATE(12417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566235] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12737), 1,
      sym__backquoted_id,
    STATE(12418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12735), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [566263] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13886), 1,
      anon_sym_LBRACK,
    STATE(6553), 1,
      sym_type_arguments,
    STATE(12419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566293] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13886), 1,
      anon_sym_LBRACK,
    STATE(6553), 1,
      sym_type_arguments,
    STATE(12420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12733), 1,
      sym__backquoted_id,
    STATE(12421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12731), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [566351] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(13389), 1,
      sym_operator_identifier,
    STATE(10424), 1,
      sym_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11548), 1,
      sym__class_constructor,
    STATE(14784), 1,
      sym__class_definition,
    STATE(12422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566391] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13886), 1,
      anon_sym_LBRACK,
    ACTIONS(13921), 1,
      anon_sym_match,
    STATE(6553), 1,
      sym_type_arguments,
    STATE(12423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566423] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566449] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13534), 1,
      anon_sym_LBRACK,
    ACTIONS(13536), 1,
      anon_sym_AT,
    ACTIONS(13540), 1,
      anon_sym_POUND,
    ACTIONS(13923), 1,
      anon_sym_LPAREN,
    STATE(14037), 1,
      aux_sym_enum_definition_repeat1,
    STATE(14054), 1,
      sym_type_arguments,
    STATE(14306), 1,
      sym_annotation,
    STATE(14826), 1,
      sym_arguments,
    STATE(12425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
  [566491] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566517] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(13925), 1,
      anon_sym_type,
    ACTIONS(13927), 1,
      sym_operator_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(12684), 1,
      sym_identifier,
    STATE(13238), 1,
      sym__type_identifier,
    STATE(12427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566557] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11903), 1,
      sym__alpha_identifier,
    ACTIONS(11911), 1,
      sym__backquoted_id,
    ACTIONS(13929), 1,
      anon_sym_type,
    ACTIONS(13931), 1,
      sym_operator_identifier,
    STATE(12194), 1,
      sym__soft_identifier,
    STATE(12445), 1,
      sym_identifier,
    STATE(12660), 1,
      sym__type_identifier,
    STATE(12428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11907), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566597] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [566623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13935), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      sym__backquoted_id,
    ACTIONS(13933), 10,
      anon_sym_COLON,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [566651] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4868), 1,
      sym__alpha_identifier,
    ACTIONS(4880), 1,
      sym__backquoted_id,
    ACTIONS(13937), 1,
      anon_sym_type,
    ACTIONS(13939), 1,
      sym_operator_identifier,
    STATE(5643), 1,
      sym_identifier,
    STATE(5967), 1,
      sym__soft_identifier,
    STATE(6364), 1,
      sym__type_identifier,
    STATE(12431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566691] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(13941), 1,
      anon_sym_type,
    ACTIONS(13943), 1,
      sym_operator_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(8041), 1,
      sym_identifier,
    STATE(8469), 1,
      sym__type_identifier,
    STATE(12432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [566757] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6716), 1,
      sym__alpha_identifier,
    ACTIONS(6730), 1,
      sym__backquoted_id,
    ACTIONS(13945), 1,
      anon_sym_type,
    ACTIONS(13947), 1,
      sym_operator_identifier,
    STATE(6289), 1,
      sym_identifier,
    STATE(6457), 1,
      sym__soft_identifier,
    STATE(7359), 1,
      sym__type_identifier,
    STATE(12434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6726), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566797] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(13949), 1,
      anon_sym_type,
    ACTIONS(13951), 1,
      sym_operator_identifier,
    STATE(5795), 1,
      sym_identifier,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(6258), 1,
      sym__type_identifier,
    STATE(12435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566837] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13886), 1,
      anon_sym_LBRACK,
    STATE(6553), 1,
      sym_type_arguments,
    STATE(12436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [566867] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8159), 1,
      sym__alpha_identifier,
    ACTIONS(8167), 1,
      sym__backquoted_id,
    ACTIONS(13953), 1,
      anon_sym_type,
    ACTIONS(13955), 1,
      sym_operator_identifier,
    STATE(7719), 1,
      sym__type_identifier,
    STATE(7962), 1,
      sym_identifier,
    STATE(8275), 1,
      sym__soft_identifier,
    STATE(12437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8163), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566907] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 13,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [566933] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4390), 1,
      sym__alpha_identifier,
    ACTIONS(4408), 1,
      sym__backquoted_id,
    ACTIONS(13957), 1,
      anon_sym_type,
    ACTIONS(13959), 1,
      sym_operator_identifier,
    STATE(6824), 1,
      sym_identifier,
    STATE(7208), 1,
      sym__soft_identifier,
    STATE(8211), 1,
      sym__type_identifier,
    STATE(12439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4402), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [566973] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 13,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [566999] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4246), 1,
      sym__alpha_identifier,
    ACTIONS(4264), 1,
      sym__backquoted_id,
    ACTIONS(13961), 1,
      anon_sym_type,
    ACTIONS(13963), 1,
      sym_operator_identifier,
    STATE(5208), 1,
      sym__soft_identifier,
    STATE(5292), 1,
      sym_identifier,
    STATE(5922), 1,
      sym__type_identifier,
    STATE(12441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4258), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567039] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13771), 1,
      anon_sym_LBRACK,
    STATE(6538), 1,
      sym_type_arguments,
    STATE(12442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [567069] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [567095] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7854), 1,
      anon_sym_LBRACE,
    ACTIONS(13244), 1,
      anon_sym_COLON,
    STATE(13815), 1,
      aux_sym_compound_type_repeat1,
    STATE(14537), 1,
      sym__refinement,
    STATE(14581), 1,
      sym_template_body,
    STATE(12444), 2,
      sym_comment,
      sym_block_comment,
    STATE(14489), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [567133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(12445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [567161] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [567187] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13403), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11334), 1,
      sym_identifier,
    STATE(13700), 1,
      sym__type_identifier,
    STATE(15186), 1,
      sym__type_constructor,
    STATE(12447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567227] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 13,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [567253] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(13389), 1,
      sym_operator_identifier,
    STATE(10424), 1,
      sym_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11548), 1,
      sym__class_constructor,
    STATE(14843), 1,
      sym__class_definition,
    STATE(12449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [567319] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [567345] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13886), 1,
      anon_sym_LBRACK,
    STATE(6553), 1,
      sym_type_arguments,
    STATE(12452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 11,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [567375] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(13965), 1,
      anon_sym_type,
    ACTIONS(13967), 1,
      sym_operator_identifier,
    STATE(8602), 1,
      sym_identifier,
    STATE(8795), 1,
      sym__soft_identifier,
    STATE(9273), 1,
      sym__type_identifier,
    STATE(12453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567415] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6676), 1,
      sym__alpha_identifier,
    ACTIONS(6686), 1,
      sym__backquoted_id,
    ACTIONS(13969), 1,
      anon_sym_type,
    ACTIONS(13971), 1,
      sym_operator_identifier,
    STATE(7792), 1,
      sym__soft_identifier,
    STATE(8239), 1,
      sym_identifier,
    STATE(8620), 1,
      sym__type_identifier,
    STATE(12454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6682), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567455] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [567481] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(13973), 1,
      anon_sym_type,
    ACTIONS(13975), 1,
      sym_operator_identifier,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(6734), 1,
      sym_identifier,
    STATE(7115), 1,
      sym__type_identifier,
    STATE(12456), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567521] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6528), 1,
      sym__alpha_identifier,
    ACTIONS(6538), 1,
      sym__backquoted_id,
    ACTIONS(13977), 1,
      anon_sym_type,
    ACTIONS(13979), 1,
      sym_operator_identifier,
    STATE(7952), 1,
      sym__soft_identifier,
    STATE(7953), 1,
      sym_identifier,
    STATE(8622), 1,
      sym__type_identifier,
    STATE(12457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6534), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12716), 1,
      sym__backquoted_id,
    STATE(12458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12714), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [567589] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11839), 1,
      sym__alpha_identifier,
    ACTIONS(11847), 1,
      sym__backquoted_id,
    ACTIONS(13981), 1,
      anon_sym_type,
    ACTIONS(13983), 1,
      sym_operator_identifier,
    STATE(12473), 1,
      sym_identifier,
    STATE(12789), 1,
      sym__soft_identifier,
    STATE(13362), 1,
      sym__type_identifier,
    STATE(12459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11843), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567629] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [567657] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12741), 1,
      sym__backquoted_id,
    STATE(12461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12739), 12,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_end,
      anon_sym_EQ,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      anon_sym_PIPE,
      sym__alpha_identifier,
      sym_operator_identifier,
  [567685] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6542), 1,
      sym__alpha_identifier,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(13985), 1,
      anon_sym_type,
    ACTIONS(13987), 1,
      sym_operator_identifier,
    STATE(5780), 1,
      sym__soft_identifier,
    STATE(6071), 1,
      sym_identifier,
    STATE(6257), 1,
      sym__type_identifier,
    STATE(12462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567725] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11934), 1,
      sym__alpha_identifier,
    ACTIONS(11942), 1,
      sym__backquoted_id,
    ACTIONS(13989), 1,
      anon_sym_type,
    ACTIONS(13991), 1,
      sym_operator_identifier,
    STATE(11447), 1,
      sym_identifier,
    STATE(11507), 1,
      sym__soft_identifier,
    STATE(11984), 1,
      sym__type_identifier,
    STATE(12463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11938), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567765] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13993), 1,
      anon_sym_AT,
    STATE(13052), 1,
      sym_annotation,
    STATE(12464), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [567795] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 13,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [567821] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(13996), 1,
      sym_operator_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(12225), 1,
      sym_identifier,
    STATE(12238), 1,
      sym__type_identifier,
    STATE(12466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567858] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13998), 1,
      anon_sym_match,
    ACTIONS(14000), 1,
      sym_operator_identifier,
    STATE(5730), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567895] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14002), 1,
      sym__alpha_identifier,
    ACTIONS(14004), 1,
      anon_sym_LBRACE,
    ACTIONS(14006), 1,
      anon_sym_LBRACK,
    ACTIONS(14010), 1,
      sym__backquoted_id,
    STATE(9099), 1,
      sym__soft_identifier,
    STATE(9152), 1,
      sym_identifier,
    STATE(12468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567932] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14012), 1,
      sym__alpha_identifier,
    ACTIONS(14014), 1,
      anon_sym_LBRACE,
    ACTIONS(14016), 1,
      anon_sym_LBRACK,
    ACTIONS(14020), 1,
      sym__backquoted_id,
    STATE(10078), 1,
      sym_identifier,
    STATE(10230), 1,
      sym__soft_identifier,
    STATE(12469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14018), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [567969] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14022), 1,
      anon_sym_LBRACK,
    ACTIONS(14024), 1,
      anon_sym_match,
    STATE(6863), 1,
      sym_type_arguments,
    STATE(12470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [568000] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4390), 1,
      sym__alpha_identifier,
    ACTIONS(4408), 1,
      sym__backquoted_id,
    ACTIONS(14026), 1,
      sym_operator_identifier,
    STATE(7208), 1,
      sym__soft_identifier,
    STATE(8273), 1,
      sym__type_identifier,
    STATE(8279), 1,
      sym_identifier,
    STATE(12471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4402), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568037] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(12472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [568064] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(12473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [568091] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14028), 1,
      anon_sym_match,
    ACTIONS(14030), 1,
      sym_operator_identifier,
    STATE(6050), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568128] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14032), 1,
      sym__alpha_identifier,
    ACTIONS(14034), 1,
      anon_sym_LBRACE,
    ACTIONS(14036), 1,
      anon_sym_LBRACK,
    ACTIONS(14040), 1,
      sym__backquoted_id,
    STATE(6171), 1,
      sym_identifier,
    STATE(6596), 1,
      sym__soft_identifier,
    STATE(12475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14038), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568165] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14042), 1,
      anon_sym_match,
    ACTIONS(14044), 1,
      sym_operator_identifier,
    STATE(5937), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568202] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14046), 1,
      anon_sym_match,
    ACTIONS(14048), 1,
      sym_operator_identifier,
    STATE(5857), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14022), 1,
      anon_sym_LBRACK,
    STATE(6863), 1,
      sym_type_arguments,
    STATE(12478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [568268] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14022), 1,
      anon_sym_LBRACK,
    STATE(6863), 1,
      sym_type_arguments,
    STATE(12479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [568297] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14050), 1,
      anon_sym_match,
    ACTIONS(14052), 1,
      sym_operator_identifier,
    STATE(6103), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568334] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6528), 1,
      sym__alpha_identifier,
    ACTIONS(6538), 1,
      sym__backquoted_id,
    ACTIONS(14054), 1,
      sym_operator_identifier,
    STATE(7952), 1,
      sym__soft_identifier,
    STATE(8284), 1,
      sym_identifier,
    STATE(8357), 1,
      sym__type_identifier,
    STATE(12481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6534), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568371] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14056), 1,
      anon_sym_match,
    ACTIONS(14058), 1,
      sym_operator_identifier,
    STATE(6049), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568408] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13355), 1,
      sym_arguments,
    STATE(12483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [568435] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(14062), 1,
      sym__automatic_semicolon,
    STATE(12531), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(12484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14060), 7,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [568470] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(14066), 1,
      sym__automatic_semicolon,
    STATE(12642), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(12485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14064), 7,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [568505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(12486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [568532] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14022), 1,
      anon_sym_LBRACK,
    ACTIONS(14024), 1,
      anon_sym_match,
    STATE(6863), 1,
      sym_type_arguments,
    STATE(12487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [568563] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4360), 1,
      sym__alpha_identifier,
    ACTIONS(4378), 1,
      sym__backquoted_id,
    ACTIONS(14068), 1,
      sym_operator_identifier,
    STATE(6576), 1,
      sym__soft_identifier,
    STATE(7214), 1,
      sym__type_identifier,
    STATE(7389), 1,
      sym_identifier,
    STATE(12488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4372), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568600] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11934), 1,
      sym__alpha_identifier,
    ACTIONS(11942), 1,
      sym__backquoted_id,
    ACTIONS(14070), 1,
      sym_operator_identifier,
    STATE(11507), 1,
      sym__soft_identifier,
    STATE(11945), 1,
      sym__type_identifier,
    STATE(11967), 1,
      sym_identifier,
    STATE(12489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11938), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568637] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(14072), 1,
      sym_operator_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11590), 1,
      sym_identifier,
    STATE(14847), 1,
      sym__object_definition,
    STATE(12490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568674] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5120), 1,
      sym__alpha_identifier,
    ACTIONS(5132), 1,
      sym__backquoted_id,
    ACTIONS(14074), 1,
      sym_operator_identifier,
    STATE(7923), 1,
      sym__soft_identifier,
    STATE(8348), 1,
      sym__type_identifier,
    STATE(8465), 1,
      sym_identifier,
    STATE(12491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(5128), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568711] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14076), 1,
      anon_sym_LBRACK,
    STATE(7193), 1,
      sym_type_arguments,
    STATE(12492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [568740] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6676), 1,
      sym__alpha_identifier,
    ACTIONS(6686), 1,
      sym__backquoted_id,
    ACTIONS(14078), 1,
      sym_operator_identifier,
    STATE(7792), 1,
      sym__soft_identifier,
    STATE(8438), 1,
      sym__type_identifier,
    STATE(8466), 1,
      sym_identifier,
    STATE(12493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6682), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568777] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14022), 1,
      anon_sym_LBRACK,
    STATE(6863), 1,
      sym_type_arguments,
    STATE(12494), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [568806] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14050), 1,
      anon_sym_match,
    ACTIONS(14080), 1,
      sym_operator_identifier,
    STATE(6061), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568843] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14082), 1,
      anon_sym_match,
    ACTIONS(14084), 1,
      sym_operator_identifier,
    STATE(5721), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568880] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14022), 1,
      anon_sym_LBRACK,
    STATE(6863), 1,
      sym_type_arguments,
    STATE(12497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [568909] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(13906), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(12111), 1,
      sym_identifier,
    STATE(12613), 1,
      sym__type_identifier,
    STATE(12498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568946] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6542), 1,
      sym__alpha_identifier,
    ACTIONS(6556), 1,
      sym__backquoted_id,
    ACTIONS(14086), 1,
      sym_operator_identifier,
    STATE(5780), 1,
      sym__soft_identifier,
    STATE(6144), 1,
      sym__type_identifier,
    STATE(6170), 1,
      sym_identifier,
    STATE(12499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6552), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [568983] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 12,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [569008] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14042), 1,
      anon_sym_match,
    ACTIONS(14088), 1,
      sym_operator_identifier,
    STATE(5814), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569045] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14076), 1,
      anon_sym_LBRACK,
    STATE(7193), 1,
      sym_type_arguments,
    STATE(12502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [569074] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14076), 1,
      anon_sym_LBRACK,
    ACTIONS(14090), 1,
      anon_sym_match,
    STATE(7193), 1,
      sym_type_arguments,
    STATE(12503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [569105] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14056), 1,
      anon_sym_match,
    ACTIONS(14092), 1,
      sym_operator_identifier,
    STATE(6008), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569142] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6716), 1,
      sym__alpha_identifier,
    ACTIONS(6730), 1,
      sym__backquoted_id,
    ACTIONS(14094), 1,
      sym_operator_identifier,
    STATE(6457), 1,
      sym__soft_identifier,
    STATE(7203), 1,
      sym_identifier,
    STATE(7356), 1,
      sym__type_identifier,
    STATE(12505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6726), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569179] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    ACTIONS(14096), 1,
      anon_sym_LBRACK,
    ACTIONS(14098), 1,
      anon_sym_POUND,
    STATE(13482), 1,
      aux_sym_annotation_repeat1,
    STATE(13958), 1,
      sym_type_arguments,
    STATE(14162), 1,
      sym_arguments,
    STATE(12506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [569216] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(14102), 1,
      sym__automatic_semicolon,
    STATE(12545), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(12507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14100), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [569249] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6300), 1,
      sym__alpha_identifier,
    ACTIONS(6310), 1,
      sym__backquoted_id,
    ACTIONS(14105), 1,
      sym_operator_identifier,
    STATE(8795), 1,
      sym__soft_identifier,
    STATE(9243), 1,
      sym_identifier,
    STATE(9395), 1,
      sym__type_identifier,
    STATE(12508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6306), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569286] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8159), 1,
      sym__alpha_identifier,
    ACTIONS(8167), 1,
      sym__backquoted_id,
    ACTIONS(14107), 1,
      sym_operator_identifier,
    STATE(7723), 1,
      sym__type_identifier,
    STATE(7886), 1,
      sym_identifier,
    STATE(8275), 1,
      sym__soft_identifier,
    STATE(12509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8163), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569323] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [569348] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14109), 1,
      anon_sym_match,
    ACTIONS(14111), 1,
      sym_operator_identifier,
    STATE(5553), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569385] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14056), 1,
      anon_sym_match,
    ACTIONS(14113), 1,
      sym_operator_identifier,
    STATE(6091), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569422] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7458), 1,
      sym__alpha_identifier,
    ACTIONS(7472), 1,
      sym__backquoted_id,
    ACTIONS(14115), 1,
      sym_operator_identifier,
    STATE(12060), 1,
      sym__soft_identifier,
    STATE(13252), 1,
      sym_identifier,
    STATE(13255), 1,
      sym__type_identifier,
    STATE(12513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7468), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569459] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14117), 1,
      anon_sym_match,
    ACTIONS(14119), 1,
      sym_operator_identifier,
    STATE(5691), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569496] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14121), 1,
      sym__alpha_identifier,
    ACTIONS(14125), 1,
      sym__backquoted_id,
    ACTIONS(14127), 1,
      sym_operator_identifier,
    STATE(4325), 1,
      sym__type_identifier,
    STATE(10798), 1,
      sym_identifier,
    STATE(10804), 1,
      sym__soft_identifier,
    STATE(12515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14123), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569533] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8275), 1,
      sym__alpha_identifier,
    ACTIONS(8283), 1,
      sym__backquoted_id,
    ACTIONS(14129), 1,
      sym_operator_identifier,
    STATE(6327), 1,
      sym__soft_identifier,
    STATE(6416), 1,
      sym__type_identifier,
    STATE(6461), 1,
      sym_identifier,
    STATE(12516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8279), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569570] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4246), 1,
      sym__alpha_identifier,
    ACTIONS(4264), 1,
      sym__backquoted_id,
    ACTIONS(14131), 1,
      sym_operator_identifier,
    STATE(5208), 1,
      sym__soft_identifier,
    STATE(5988), 1,
      sym_identifier,
    STATE(6016), 1,
      sym__type_identifier,
    STATE(12517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4258), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569607] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14076), 1,
      anon_sym_LBRACK,
    STATE(7193), 1,
      sym_type_arguments,
    STATE(12518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [569636] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14076), 1,
      anon_sym_LBRACK,
    STATE(7193), 1,
      sym_type_arguments,
    STATE(12519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [569665] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7772), 1,
      sym__backquoted_id,
    ACTIONS(7882), 1,
      anon_sym_EQ_GT,
    ACTIONS(7884), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(12520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7766), 9,
      anon_sym_end,
      anon_sym_match,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [569696] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4624), 1,
      sym__alpha_identifier,
    ACTIONS(4642), 1,
      sym__backquoted_id,
    ACTIONS(14133), 1,
      sym_operator_identifier,
    STATE(4445), 1,
      sym__soft_identifier,
    STATE(4541), 1,
      sym_identifier,
    STATE(4556), 1,
      sym__type_identifier,
    STATE(12521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4636), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569733] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14135), 1,
      anon_sym_STAR,
    STATE(12522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [569760] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14137), 1,
      anon_sym_match,
    ACTIONS(14139), 1,
      sym_operator_identifier,
    STATE(5552), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569797] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13998), 1,
      anon_sym_match,
    ACTIONS(14141), 1,
      sym_operator_identifier,
    STATE(5742), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569834] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [569859] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14143), 1,
      sym__alpha_identifier,
    ACTIONS(14145), 1,
      anon_sym_LBRACE,
    ACTIONS(14147), 1,
      anon_sym_LBRACK,
    ACTIONS(14151), 1,
      sym__backquoted_id,
    STATE(11385), 1,
      sym__soft_identifier,
    STATE(11857), 1,
      sym_identifier,
    STATE(12526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14149), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569896] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14153), 1,
      sym__alpha_identifier,
    ACTIONS(14155), 1,
      anon_sym_LBRACE,
    ACTIONS(14157), 1,
      anon_sym_LBRACK,
    ACTIONS(14161), 1,
      sym__backquoted_id,
    STATE(9819), 1,
      sym__soft_identifier,
    STATE(9924), 1,
      sym_identifier,
    STATE(12527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14159), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569933] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 12,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [569958] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(14163), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11960), 1,
      sym_identifier,
    STATE(14497), 1,
      sym__function_constructor,
    STATE(12529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [569995] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4868), 1,
      sym__alpha_identifier,
    ACTIONS(4880), 1,
      sym__backquoted_id,
    ACTIONS(14165), 1,
      sym_operator_identifier,
    STATE(5967), 1,
      sym__soft_identifier,
    STATE(6409), 1,
      sym_identifier,
    STATE(6434), 1,
      sym__type_identifier,
    STATE(12530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570032] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14169), 1,
      anon_sym_LPAREN,
    ACTIONS(14172), 1,
      sym__automatic_semicolon,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(12531), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__function_constructor_repeat1,
    ACTIONS(14167), 7,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [570065] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [570090] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13403), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11334), 1,
      sym_identifier,
    STATE(12216), 1,
      sym__type_identifier,
    STATE(12533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570127] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14177), 1,
      anon_sym_catch,
    ACTIONS(14179), 1,
      anon_sym_finally,
    STATE(12773), 1,
      sym_finally_clause,
    STATE(13652), 1,
      sym_catch_clause,
    STATE(12534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [570160] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14181), 1,
      anon_sym_match,
    ACTIONS(14183), 1,
      sym_operator_identifier,
    STATE(6003), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570197] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7780), 1,
      sym__alpha_identifier,
    ACTIONS(7788), 1,
      sym__backquoted_id,
    ACTIONS(14185), 1,
      sym_operator_identifier,
    STATE(13836), 1,
      sym__soft_identifier,
    STATE(14057), 1,
      sym__type_identifier,
    STATE(14147), 1,
      sym_identifier,
    STATE(12536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7784), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570234] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6790), 1,
      sym__alpha_identifier,
    ACTIONS(6804), 1,
      sym__backquoted_id,
    ACTIONS(14187), 1,
      sym_operator_identifier,
    STATE(5975), 1,
      sym__soft_identifier,
    STATE(6111), 1,
      sym__type_identifier,
    STATE(6157), 1,
      sym_identifier,
    STATE(12537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6800), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570271] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [570296] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11903), 1,
      sym__alpha_identifier,
    ACTIONS(11911), 1,
      sym__backquoted_id,
    ACTIONS(14189), 1,
      sym_operator_identifier,
    STATE(12194), 1,
      sym__soft_identifier,
    STATE(12629), 1,
      sym__type_identifier,
    STATE(12638), 1,
      sym_identifier,
    STATE(12539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11907), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570333] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11856), 1,
      sym__alpha_identifier,
    ACTIONS(11864), 1,
      sym__backquoted_id,
    ACTIONS(14191), 1,
      sym_operator_identifier,
    STATE(8044), 1,
      sym__soft_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(8719), 1,
      sym__type_identifier,
    STATE(12540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11860), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570370] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(14163), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11960), 1,
      sym_identifier,
    STATE(14296), 1,
      sym__function_constructor,
    STATE(12541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570407] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14193), 1,
      sym__alpha_identifier,
    ACTIONS(14195), 1,
      anon_sym_LBRACE,
    ACTIONS(14197), 1,
      anon_sym_LBRACK,
    ACTIONS(14201), 1,
      sym__backquoted_id,
    STATE(9284), 1,
      sym__soft_identifier,
    STATE(9562), 1,
      sym_identifier,
    STATE(12542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14199), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570444] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14203), 1,
      sym__alpha_identifier,
    ACTIONS(14205), 1,
      anon_sym_LBRACE,
    ACTIONS(14207), 1,
      anon_sym_LBRACK,
    ACTIONS(14211), 1,
      sym__backquoted_id,
    STATE(5813), 1,
      sym__soft_identifier,
    STATE(5887), 1,
      sym_identifier,
    STATE(12543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14209), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570481] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14028), 1,
      anon_sym_match,
    ACTIONS(14213), 1,
      sym_operator_identifier,
    STATE(5702), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570518] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14217), 1,
      anon_sym_LPAREN,
    ACTIONS(14220), 1,
      sym__automatic_semicolon,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(12545), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__class_constructor_repeat1,
    ACTIONS(14215), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [570549] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6420), 1,
      sym__alpha_identifier,
    ACTIONS(6434), 1,
      sym__backquoted_id,
    ACTIONS(14223), 1,
      sym_operator_identifier,
    STATE(5072), 1,
      sym__soft_identifier,
    STATE(5467), 1,
      sym_identifier,
    STATE(5477), 1,
      sym__type_identifier,
    STATE(12546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6430), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570586] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(13514), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(12510), 1,
      sym_identifier,
    STATE(13982), 1,
      sym__type_identifier,
    STATE(12547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570623] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14056), 1,
      anon_sym_match,
    ACTIONS(14225), 1,
      sym_operator_identifier,
    STATE(5928), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570660] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14076), 1,
      anon_sym_LBRACK,
    ACTIONS(14090), 1,
      anon_sym_match,
    STATE(7193), 1,
      sym_type_arguments,
    STATE(12549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [570691] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14227), 1,
      anon_sym_DOT,
    STATE(12550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [570718] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6378), 1,
      sym__alpha_identifier,
    ACTIONS(6392), 1,
      sym__backquoted_id,
    ACTIONS(14229), 1,
      sym_operator_identifier,
    STATE(5211), 1,
      sym__soft_identifier,
    STATE(5902), 1,
      sym_identifier,
    STATE(5923), 1,
      sym__type_identifier,
    STATE(12551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6388), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570755] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [570780] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4830), 1,
      sym__alpha_identifier,
    ACTIONS(4848), 1,
      sym__backquoted_id,
    ACTIONS(14231), 1,
      sym_operator_identifier,
    STATE(5145), 1,
      sym__soft_identifier,
    STATE(5696), 1,
      sym_identifier,
    STATE(5722), 1,
      sym__type_identifier,
    STATE(12553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4842), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570817] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [570842] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14233), 1,
      anon_sym_catch,
    ACTIONS(14235), 1,
      anon_sym_finally,
    STATE(12773), 1,
      sym_finally_clause,
    STATE(13489), 1,
      sym_catch_clause,
    STATE(12555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
  [570875] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6966), 1,
      sym__alpha_identifier,
    ACTIONS(6980), 1,
      sym__backquoted_id,
    ACTIONS(14237), 1,
      sym_operator_identifier,
    STATE(5979), 1,
      sym__soft_identifier,
    STATE(6367), 1,
      sym__type_identifier,
    STATE(6383), 1,
      sym_identifier,
    STATE(12556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6976), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570912] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(14241), 1,
      anon_sym_extends,
    ACTIONS(14243), 1,
      anon_sym_LPAREN,
    STATE(14077), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14677), 1,
      sym_class_parameters,
    STATE(15111), 1,
      sym_extends_clause,
    STATE(15176), 1,
      sym_type_parameters,
    STATE(15732), 1,
      sym__full_enum_def,
    STATE(12557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14239), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [570953] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14245), 1,
      sym__alpha_identifier,
    ACTIONS(14247), 1,
      anon_sym_LBRACE,
    ACTIONS(14249), 1,
      anon_sym_LBRACK,
    ACTIONS(14253), 1,
      sym__backquoted_id,
    STATE(10236), 1,
      sym_identifier,
    STATE(10317), 1,
      sym__soft_identifier,
    STATE(12558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14251), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [570990] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14255), 1,
      anon_sym_match,
    ACTIONS(14257), 1,
      sym_operator_identifier,
    STATE(5693), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571027] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14259), 1,
      sym__alpha_identifier,
    ACTIONS(14261), 1,
      anon_sym_LBRACE,
    ACTIONS(14263), 1,
      anon_sym_LBRACK,
    ACTIONS(14267), 1,
      sym__backquoted_id,
    STATE(7041), 1,
      sym_identifier,
    STATE(7318), 1,
      sym__soft_identifier,
    STATE(12560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14265), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571064] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(14271), 1,
      sym__automatic_semicolon,
    STATE(12545), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(12561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14269), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [571097] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(14276), 1,
      sym__automatic_semicolon,
    STATE(12545), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(12562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14274), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [571130] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6698), 1,
      sym__alpha_identifier,
    ACTIONS(6712), 1,
      sym__backquoted_id,
    ACTIONS(14279), 1,
      sym_operator_identifier,
    STATE(5215), 1,
      sym__soft_identifier,
    STATE(5744), 1,
      sym_identifier,
    STATE(5751), 1,
      sym__type_identifier,
    STATE(12563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6708), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571167] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8359), 1,
      sym__alpha_identifier,
    ACTIONS(8367), 1,
      sym__backquoted_id,
    ACTIONS(14281), 1,
      sym_operator_identifier,
    STATE(6178), 1,
      sym__type_identifier,
    STATE(6353), 1,
      sym__soft_identifier,
    STATE(6566), 1,
      sym_identifier,
    STATE(12564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8363), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571204] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(14285), 1,
      sym__automatic_semicolon,
    STATE(12507), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(12565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14283), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [571237] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(14288), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(12171), 1,
      sym_identifier,
    STATE(14343), 1,
      sym__function_constructor,
    STATE(12566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571274] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13230), 1,
      anon_sym_LT_COLON,
    ACTIONS(13232), 1,
      anon_sym_GT_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(13456), 1,
      sym_lower_bound,
    STATE(14092), 1,
      sym_upper_bound,
    STATE(14096), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14623), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(14290), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(12567), 2,
      sym_comment,
      sym_block_comment,
  [571319] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(14292), 1,
      sym_operator_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(11963), 1,
      sym_identifier,
    STATE(15106), 1,
      sym__object_definition,
    STATE(12568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571356] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14294), 1,
      sym__alpha_identifier,
    ACTIONS(14296), 1,
      anon_sym_LBRACE,
    ACTIONS(14298), 1,
      anon_sym_LBRACK,
    ACTIONS(14302), 1,
      sym__backquoted_id,
    STATE(6852), 1,
      sym__soft_identifier,
    STATE(7199), 1,
      sym_identifier,
    STATE(12569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14300), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571393] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13331), 1,
      sym_operator_identifier,
    ACTIONS(14304), 1,
      anon_sym_match,
    STATE(5503), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571430] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14306), 1,
      anon_sym_DOT,
    STATE(12571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [571457] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14308), 1,
      sym__alpha_identifier,
    ACTIONS(14310), 1,
      anon_sym_LBRACE,
    ACTIONS(14312), 1,
      anon_sym_LBRACK,
    ACTIONS(14316), 1,
      sym__backquoted_id,
    STATE(9919), 1,
      sym__soft_identifier,
    STATE(9945), 1,
      sym_identifier,
    STATE(12572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14314), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571494] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14318), 1,
      anon_sym_match,
    ACTIONS(14320), 1,
      sym_operator_identifier,
    STATE(5837), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571531] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14308), 1,
      sym__alpha_identifier,
    ACTIONS(14316), 1,
      sym__backquoted_id,
    ACTIONS(14322), 1,
      anon_sym_LBRACE,
    ACTIONS(14324), 1,
      anon_sym_LBRACK,
    STATE(9919), 1,
      sym__soft_identifier,
    STATE(9947), 1,
      sym_identifier,
    STATE(12574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14314), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571568] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13998), 1,
      anon_sym_match,
    ACTIONS(14326), 1,
      sym_operator_identifier,
    STATE(5659), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571605] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14328), 1,
      sym__alpha_identifier,
    ACTIONS(14330), 1,
      anon_sym_LBRACE,
    ACTIONS(14332), 1,
      anon_sym_LBRACK,
    ACTIONS(14336), 1,
      sym__backquoted_id,
    STATE(8296), 1,
      sym__soft_identifier,
    STATE(8536), 1,
      sym_identifier,
    STATE(12576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14334), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571642] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(13528), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(10894), 1,
      sym_identifier,
    STATE(11249), 1,
      sym__type_identifier,
    STATE(12577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571679] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6360), 1,
      sym__alpha_identifier,
    ACTIONS(6374), 1,
      sym__backquoted_id,
    ACTIONS(14338), 1,
      sym_operator_identifier,
    STATE(4788), 1,
      sym__soft_identifier,
    STATE(4941), 1,
      sym_identifier,
    STATE(4956), 1,
      sym__type_identifier,
    STATE(12578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6370), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571716] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8179), 1,
      sym__alpha_identifier,
    ACTIONS(8187), 1,
      sym__backquoted_id,
    ACTIONS(14340), 1,
      sym_operator_identifier,
    STATE(6568), 1,
      sym__type_identifier,
    STATE(6613), 1,
      sym_identifier,
    STATE(6730), 1,
      sym__soft_identifier,
    STATE(12579), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8183), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571753] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14342), 1,
      anon_sym_match,
    ACTIONS(14344), 1,
      sym_operator_identifier,
    STATE(5752), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571790] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8084), 1,
      sym__alpha_identifier,
    ACTIONS(8092), 1,
      sym__backquoted_id,
    ACTIONS(14346), 1,
      sym_operator_identifier,
    STATE(7573), 1,
      sym__type_identifier,
    STATE(7664), 1,
      sym__soft_identifier,
    STATE(7684), 1,
      sym_identifier,
    STATE(12581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8088), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571827] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6830), 1,
      sym__alpha_identifier,
    ACTIONS(6840), 1,
      sym__backquoted_id,
    ACTIONS(14348), 1,
      sym_operator_identifier,
    STATE(6232), 1,
      sym__soft_identifier,
    STATE(6957), 1,
      sym_identifier,
    STATE(6991), 1,
      sym__type_identifier,
    STATE(12582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6836), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571864] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14350), 1,
      anon_sym_COMMA,
    ACTIONS(14352), 1,
      anon_sym_with,
    STATE(13648), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(13649), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(12583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13723), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [571897] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14354), 1,
      anon_sym_match,
    ACTIONS(14356), 1,
      sym_operator_identifier,
    STATE(5903), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571934] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14042), 1,
      anon_sym_match,
    ACTIONS(14358), 1,
      sym_operator_identifier,
    STATE(5850), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [571971] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6884), 1,
      sym__alpha_identifier,
    ACTIONS(6894), 1,
      sym__backquoted_id,
    ACTIONS(14360), 1,
      sym_operator_identifier,
    STATE(6268), 1,
      sym__soft_identifier,
    STATE(7296), 1,
      sym__type_identifier,
    STATE(7378), 1,
      sym_identifier,
    STATE(12586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6890), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572008] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4182), 1,
      sym__alpha_identifier,
    ACTIONS(4200), 1,
      sym__backquoted_id,
    ACTIONS(14362), 1,
      sym_operator_identifier,
    STATE(4657), 1,
      sym__soft_identifier,
    STATE(4887), 1,
      sym_identifier,
    STATE(4892), 1,
      sym__type_identifier,
    STATE(12587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4194), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572045] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [572070] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [572095] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [572120] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [572145] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6464), 1,
      sym__alpha_identifier,
    ACTIONS(6478), 1,
      sym__backquoted_id,
    ACTIONS(14364), 1,
      sym_operator_identifier,
    STATE(8811), 1,
      sym__soft_identifier,
    STATE(9135), 1,
      sym_identifier,
    STATE(9464), 1,
      sym__type_identifier,
    STATE(12592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572182] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13998), 1,
      anon_sym_match,
    ACTIONS(14366), 1,
      sym_operator_identifier,
    STATE(5732), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572219] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4712), 1,
      sym__alpha_identifier,
    ACTIONS(4730), 1,
      sym__backquoted_id,
    ACTIONS(14368), 1,
      sym_operator_identifier,
    STATE(6328), 1,
      sym__soft_identifier,
    STATE(6907), 1,
      sym_identifier,
    STATE(6963), 1,
      sym__type_identifier,
    STATE(12594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4724), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572256] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [572281] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11922), 1,
      sym__alpha_identifier,
    ACTIONS(11930), 1,
      sym__backquoted_id,
    ACTIONS(14370), 1,
      sym_operator_identifier,
    STATE(11400), 1,
      sym__soft_identifier,
    STATE(11457), 1,
      sym__type_identifier,
    STATE(11477), 1,
      sym_identifier,
    STATE(12596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11926), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572318] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [572343] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(12598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [572370] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14372), 1,
      anon_sym_match,
    ACTIONS(14374), 1,
      sym_operator_identifier,
    STATE(5626), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572407] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [572432] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14376), 1,
      sym__alpha_identifier,
    ACTIONS(14378), 1,
      anon_sym_LBRACE,
    ACTIONS(14380), 1,
      anon_sym_LBRACK,
    ACTIONS(14384), 1,
      sym__backquoted_id,
    STATE(11550), 1,
      sym__soft_identifier,
    STATE(12154), 1,
      sym_identifier,
    STATE(12601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14382), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572469] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14328), 1,
      sym__alpha_identifier,
    ACTIONS(14336), 1,
      sym__backquoted_id,
    ACTIONS(14386), 1,
      anon_sym_LBRACE,
    ACTIONS(14388), 1,
      anon_sym_LBRACK,
    STATE(8296), 1,
      sym__soft_identifier,
    STATE(8443), 1,
      sym_identifier,
    STATE(12602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14334), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572506] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14042), 1,
      anon_sym_match,
    ACTIONS(14390), 1,
      sym_operator_identifier,
    STATE(5846), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572543] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6490), 1,
      sym__alpha_identifier,
    ACTIONS(6500), 1,
      sym__backquoted_id,
    ACTIONS(14392), 1,
      sym_operator_identifier,
    STATE(7234), 1,
      sym__soft_identifier,
    STATE(7981), 1,
      sym__type_identifier,
    STATE(8007), 1,
      sym_identifier,
    STATE(12604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6496), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572580] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6402), 1,
      sym__alpha_identifier,
    ACTIONS(6416), 1,
      sym__backquoted_id,
    ACTIONS(14394), 1,
      sym_operator_identifier,
    STATE(5895), 1,
      sym__soft_identifier,
    STATE(6138), 1,
      sym_identifier,
    STATE(6774), 1,
      sym__type_identifier,
    STATE(12605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572617] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [572642] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12043), 1,
      sym__alpha_identifier,
    ACTIONS(12051), 1,
      sym__backquoted_id,
    ACTIONS(14396), 1,
      sym_operator_identifier,
    STATE(10946), 1,
      sym__soft_identifier,
    STATE(11351), 1,
      sym_identifier,
    STATE(11378), 1,
      sym__type_identifier,
    STATE(12607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12047), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572679] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [572704] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(14398), 1,
      sym_operator_identifier,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(14152), 1,
      sym_identifier,
    STATE(14587), 1,
      sym__namespace_expression,
    STATE(12609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572741] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6600), 1,
      sym__alpha_identifier,
    ACTIONS(6610), 1,
      sym__backquoted_id,
    ACTIONS(14400), 1,
      sym_operator_identifier,
    STATE(7134), 1,
      sym__soft_identifier,
    STATE(7558), 1,
      sym_identifier,
    STATE(7569), 1,
      sym__type_identifier,
    STATE(12610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572778] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14117), 1,
      anon_sym_match,
    ACTIONS(14402), 1,
      sym_operator_identifier,
    STATE(6018), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572815] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [572840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [572865] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11883), 1,
      sym__alpha_identifier,
    ACTIONS(11891), 1,
      sym__backquoted_id,
    ACTIONS(14404), 1,
      sym_operator_identifier,
    STATE(12652), 1,
      sym__soft_identifier,
    STATE(13309), 1,
      sym_identifier,
    STATE(13324), 1,
      sym__type_identifier,
    STATE(12614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11887), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572902] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14406), 1,
      sym__alpha_identifier,
    ACTIONS(14408), 1,
      anon_sym_LBRACE,
    ACTIONS(14410), 1,
      anon_sym_LBRACK,
    ACTIONS(14414), 1,
      sym__backquoted_id,
    STATE(7670), 1,
      sym_identifier,
    STATE(7824), 1,
      sym__soft_identifier,
    STATE(12615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572939] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14416), 1,
      sym__alpha_identifier,
    ACTIONS(14418), 1,
      anon_sym_LBRACE,
    ACTIONS(14420), 1,
      anon_sym_LBRACK,
    ACTIONS(14424), 1,
      sym__backquoted_id,
    STATE(7319), 1,
      sym_identifier,
    STATE(7377), 1,
      sym__soft_identifier,
    STATE(12616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14422), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [572976] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14426), 1,
      anon_sym_match,
    ACTIONS(14428), 1,
      sym_operator_identifier,
    STATE(5750), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573013] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6318), 1,
      sym__alpha_identifier,
    ACTIONS(6332), 1,
      sym__backquoted_id,
    ACTIONS(14430), 1,
      sym_operator_identifier,
    STATE(7241), 1,
      sym__soft_identifier,
    STATE(7933), 1,
      sym__type_identifier,
    STATE(7959), 1,
      sym_identifier,
    STATE(12618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6328), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573050] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14022), 1,
      anon_sym_LBRACK,
    STATE(6863), 1,
      sym_type_arguments,
    STATE(12619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 10,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [573079] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [573104] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [573129] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13998), 1,
      anon_sym_match,
    ACTIONS(14432), 1,
      sym_operator_identifier,
    STATE(5842), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573166] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14434), 1,
      anon_sym_match,
    ACTIONS(14436), 1,
      sym_operator_identifier,
    STATE(5584), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573203] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [573228] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [573253] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [573278] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14438), 1,
      sym__alpha_identifier,
    ACTIONS(14440), 1,
      anon_sym_LBRACE,
    ACTIONS(14442), 1,
      anon_sym_LBRACK,
    ACTIONS(14446), 1,
      sym__backquoted_id,
    STATE(9390), 1,
      sym__soft_identifier,
    STATE(9479), 1,
      sym_identifier,
    STATE(12627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14444), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573315] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14416), 1,
      sym__alpha_identifier,
    ACTIONS(14424), 1,
      sym__backquoted_id,
    ACTIONS(14448), 1,
      anon_sym_LBRACE,
    ACTIONS(14450), 1,
      anon_sym_LBRACK,
    STATE(6858), 1,
      sym_identifier,
    STATE(7377), 1,
      sym__soft_identifier,
    STATE(12628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14422), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573352] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [573377] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [573402] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12118), 1,
      sym__alpha_identifier,
    ACTIONS(12126), 1,
      sym__backquoted_id,
    ACTIONS(14452), 1,
      sym_operator_identifier,
    STATE(13294), 1,
      sym__soft_identifier,
    STATE(13491), 1,
      sym_identifier,
    STATE(13508), 1,
      sym__type_identifier,
    STATE(12631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12122), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573439] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13254), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [573464] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13256), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [573489] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(14454), 1,
      sym_operator_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11599), 1,
      sym_identifier,
    STATE(14344), 1,
      sym__class_constructor,
    STATE(12634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573526] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4594), 1,
      sym__alpha_identifier,
    ACTIONS(4612), 1,
      sym__backquoted_id,
    ACTIONS(14456), 1,
      sym_operator_identifier,
    STATE(5264), 1,
      sym__soft_identifier,
    STATE(5925), 1,
      sym_identifier,
    STATE(5934), 1,
      sym__type_identifier,
    STATE(12635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4606), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573563] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [573588] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8393), 1,
      sym__alpha_identifier,
    ACTIONS(8401), 1,
      sym__backquoted_id,
    ACTIONS(14458), 1,
      sym_operator_identifier,
    STATE(7542), 1,
      sym__type_identifier,
    STATE(7596), 1,
      sym_identifier,
    STATE(7599), 1,
      sym__soft_identifier,
    STATE(12637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8397), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573625] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [573650] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14460), 1,
      anon_sym_catch,
    ACTIONS(14462), 1,
      anon_sym_finally,
    STATE(11850), 1,
      sym_finally_clause,
    STATE(12970), 1,
      sym_catch_clause,
    STATE(12639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [573683] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [573708] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12870), 1,
      sym__alpha_identifier,
    ACTIONS(12874), 1,
      sym__backquoted_id,
    ACTIONS(14464), 1,
      sym_operator_identifier,
    STATE(14423), 1,
      sym__soft_identifier,
    STATE(14538), 1,
      sym_identifier,
    STATE(15138), 1,
      sym_simple_enum_case,
    STATE(12641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12872), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573745] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(14468), 1,
      sym__automatic_semicolon,
    STATE(12531), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(12642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14466), 7,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [573780] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8018), 1,
      sym__alpha_identifier,
    ACTIONS(8026), 1,
      sym__backquoted_id,
    ACTIONS(14470), 1,
      sym_operator_identifier,
    STATE(6799), 1,
      sym_identifier,
    STATE(6861), 1,
      sym__type_identifier,
    STATE(7330), 1,
      sym__soft_identifier,
    STATE(12643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8022), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573817] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14472), 1,
      anon_sym_match,
    ACTIONS(14474), 1,
      sym_operator_identifier,
    STATE(5660), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573854] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [573879] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13998), 1,
      anon_sym_match,
    ACTIONS(14476), 1,
      sym_operator_identifier,
    STATE(5999), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573916] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14478), 1,
      sym__alpha_identifier,
    ACTIONS(14480), 1,
      anon_sym_LBRACE,
    ACTIONS(14482), 1,
      anon_sym_LBRACK,
    ACTIONS(14486), 1,
      sym__backquoted_id,
    STATE(8700), 1,
      sym_identifier,
    STATE(8900), 1,
      sym__soft_identifier,
    STATE(12647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14484), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573953] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14153), 1,
      sym__alpha_identifier,
    ACTIONS(14161), 1,
      sym__backquoted_id,
    ACTIONS(14488), 1,
      anon_sym_LBRACE,
    ACTIONS(14490), 1,
      anon_sym_LBRACK,
    STATE(9804), 1,
      sym_identifier,
    STATE(9819), 1,
      sym__soft_identifier,
    STATE(12648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14159), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [573990] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14492), 1,
      sym__alpha_identifier,
    ACTIONS(14494), 1,
      anon_sym_LBRACE,
    ACTIONS(14496), 1,
      anon_sym_LBRACK,
    ACTIONS(14500), 1,
      sym__backquoted_id,
    STATE(10904), 1,
      sym_identifier,
    STATE(11069), 1,
      sym__soft_identifier,
    STATE(12649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14498), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574027] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 12,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [574052] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6870), 1,
      sym__alpha_identifier,
    ACTIONS(6880), 1,
      sym__backquoted_id,
    ACTIONS(14502), 1,
      sym_operator_identifier,
    STATE(6925), 1,
      sym__soft_identifier,
    STATE(7749), 1,
      sym_identifier,
    STATE(7860), 1,
      sym__type_identifier,
    STATE(12651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6876), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574089] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 12,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [574114] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14504), 1,
      anon_sym_match,
    ACTIONS(14506), 1,
      sym_operator_identifier,
    STATE(5758), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574151] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [574176] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [574201] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7988), 1,
      sym__alpha_identifier,
    ACTIONS(7996), 1,
      sym__backquoted_id,
    ACTIONS(14508), 1,
      sym_operator_identifier,
    STATE(7157), 1,
      sym_identifier,
    STATE(7176), 1,
      sym__type_identifier,
    STATE(7258), 1,
      sym__soft_identifier,
    STATE(12656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7992), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574238] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(13721), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(4321), 1,
      sym_identifier,
    STATE(4325), 1,
      sym__type_identifier,
    STATE(12657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574275] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [574300] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [574325] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [574350] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14510), 1,
      anon_sym_LBRACK,
    STATE(7044), 1,
      sym_type_arguments,
    STATE(12661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 10,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [574379] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(14512), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(4381), 1,
      sym__type_identifier,
    STATE(4386), 1,
      sym_identifier,
    STATE(12662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574416] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6772), 1,
      sym__alpha_identifier,
    ACTIONS(6786), 1,
      sym__backquoted_id,
    ACTIONS(14514), 1,
      sym_operator_identifier,
    STATE(6418), 1,
      sym__soft_identifier,
    STATE(7474), 1,
      sym__type_identifier,
    STATE(7482), 1,
      sym_identifier,
    STATE(12663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6782), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574453] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [574478] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(14518), 1,
      sym__automatic_semicolon,
    STATE(12545), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(12665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14516), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [574511] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(14523), 1,
      sym__automatic_semicolon,
    STATE(12561), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(12666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14521), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [574544] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14255), 1,
      anon_sym_match,
    ACTIONS(14526), 1,
      sym_operator_identifier,
    STATE(5615), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574581] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8321), 1,
      sym__alpha_identifier,
    ACTIONS(8329), 1,
      sym__backquoted_id,
    ACTIONS(14528), 1,
      sym_operator_identifier,
    STATE(5689), 1,
      sym_identifier,
    STATE(5802), 1,
      sym__type_identifier,
    STATE(5875), 1,
      sym__soft_identifier,
    STATE(12668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8325), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574618] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4278), 1,
      sym__alpha_identifier,
    ACTIONS(4296), 1,
      sym__backquoted_id,
    ACTIONS(14530), 1,
      sym_operator_identifier,
    STATE(7385), 1,
      sym__soft_identifier,
    STATE(8183), 1,
      sym_identifier,
    STATE(8235), 1,
      sym__type_identifier,
    STATE(12669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4290), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574655] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(14534), 1,
      sym__automatic_semicolon,
    STATE(12545), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(12670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14532), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [574688] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14137), 1,
      anon_sym_match,
    ACTIONS(14537), 1,
      sym_operator_identifier,
    STATE(5686), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574725] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14354), 1,
      anon_sym_match,
    ACTIONS(14539), 1,
      sym_operator_identifier,
    STATE(5632), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574762] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [574789] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13998), 1,
      anon_sym_match,
    ACTIONS(14541), 1,
      sym_operator_identifier,
    STATE(6002), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574826] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(12867), 1,
      sym__automatic_semicolon,
    STATE(12562), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(12675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12865), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [574859] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(14288), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(12171), 1,
      sym_identifier,
    STATE(14398), 1,
      sym__function_constructor,
    STATE(12676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574896] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14255), 1,
      anon_sym_match,
    ACTIONS(14543), 1,
      sym_operator_identifier,
    STATE(5921), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574933] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [574960] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6856), 1,
      sym__alpha_identifier,
    ACTIONS(6866), 1,
      sym__backquoted_id,
    ACTIONS(14545), 1,
      sym_operator_identifier,
    STATE(5432), 1,
      sym__soft_identifier,
    STATE(5871), 1,
      sym__type_identifier,
    STATE(5920), 1,
      sym_identifier,
    STATE(12679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6862), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [574997] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [575022] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [575047] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14143), 1,
      sym__alpha_identifier,
    ACTIONS(14151), 1,
      sym__backquoted_id,
    ACTIONS(14547), 1,
      sym_operator_identifier,
    STATE(4325), 1,
      sym__type_identifier,
    STATE(11355), 1,
      sym_identifier,
    STATE(11385), 1,
      sym__soft_identifier,
    STATE(12682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14149), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575084] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4342), 1,
      sym__alpha_identifier,
    ACTIONS(4354), 1,
      sym__backquoted_id,
    ACTIONS(14549), 1,
      sym_operator_identifier,
    STATE(7539), 1,
      sym__soft_identifier,
    STATE(8760), 1,
      sym__type_identifier,
    STATE(8911), 1,
      sym_identifier,
    STATE(12683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4350), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575121] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(12684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [575148] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [575173] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14551), 1,
      anon_sym_DOT,
    STATE(12686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [575200] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14553), 1,
      anon_sym_STAR,
    STATE(12687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [575227] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14555), 1,
      sym__alpha_identifier,
    ACTIONS(14557), 1,
      anon_sym_LBRACE,
    ACTIONS(14559), 1,
      anon_sym_LBRACK,
    ACTIONS(14563), 1,
      sym__backquoted_id,
    STATE(9200), 1,
      sym_identifier,
    STATE(9578), 1,
      sym__soft_identifier,
    STATE(12688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14561), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575264] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14259), 1,
      sym__alpha_identifier,
    ACTIONS(14267), 1,
      sym__backquoted_id,
    ACTIONS(14565), 1,
      anon_sym_LBRACE,
    ACTIONS(14567), 1,
      anon_sym_LBRACK,
    STATE(7318), 1,
      sym__soft_identifier,
    STATE(7391), 1,
      sym_identifier,
    STATE(12689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14265), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575301] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14569), 1,
      anon_sym_match,
    ACTIONS(14571), 1,
      sym_operator_identifier,
    STATE(5642), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575338] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(14454), 1,
      sym_operator_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11599), 1,
      sym_identifier,
    STATE(14298), 1,
      sym__class_constructor,
    STATE(12691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575375] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [575400] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [575425] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11961), 1,
      sym__alpha_identifier,
    ACTIONS(11969), 1,
      sym__backquoted_id,
    ACTIONS(14573), 1,
      sym_operator_identifier,
    STATE(12212), 1,
      sym__soft_identifier,
    STATE(12820), 1,
      sym__type_identifier,
    STATE(12826), 1,
      sym_identifier,
    STATE(12694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11965), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575462] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(14292), 1,
      sym_operator_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(11963), 1,
      sym_identifier,
    STATE(15043), 1,
      sym__object_definition,
    STATE(12695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575499] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7940), 1,
      sym__alpha_identifier,
    ACTIONS(7952), 1,
      sym__backquoted_id,
    ACTIONS(14575), 1,
      sym_operator_identifier,
    STATE(11669), 1,
      sym__soft_identifier,
    STATE(11867), 1,
      sym__type_identifier,
    STATE(11985), 1,
      sym_identifier,
    STATE(12696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7948), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575536] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4562), 1,
      sym__alpha_identifier,
    ACTIONS(4580), 1,
      sym__backquoted_id,
    ACTIONS(14577), 1,
      sym_operator_identifier,
    STATE(5868), 1,
      sym__soft_identifier,
    STATE(6285), 1,
      sym__type_identifier,
    STATE(6382), 1,
      sym_identifier,
    STATE(12697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4574), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575573] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4940), 1,
      sym__alpha_identifier,
    ACTIONS(4962), 1,
      sym__backquoted_id,
    ACTIONS(14579), 1,
      sym_operator_identifier,
    STATE(5839), 1,
      sym__soft_identifier,
    STATE(6189), 1,
      sym_identifier,
    STATE(6431), 1,
      sym__type_identifier,
    STATE(12698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575610] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8030), 1,
      sym__alpha_identifier,
    ACTIONS(8038), 1,
      sym__backquoted_id,
    ACTIONS(14581), 1,
      sym_operator_identifier,
    STATE(8528), 1,
      sym__type_identifier,
    STATE(8625), 1,
      sym__soft_identifier,
    STATE(8634), 1,
      sym_identifier,
    STATE(12699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8034), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575647] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [575672] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [575697] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14372), 1,
      anon_sym_match,
    ACTIONS(14583), 1,
      sym_operator_identifier,
    STATE(6026), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575734] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [575759] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [575784] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(14163), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11960), 1,
      sym_identifier,
    STATE(14565), 1,
      sym__function_constructor,
    STATE(12705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575821] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4750), 1,
      sym__alpha_identifier,
    ACTIONS(4762), 1,
      sym__backquoted_id,
    ACTIONS(14585), 1,
      sym_operator_identifier,
    STATE(4635), 1,
      sym__soft_identifier,
    STATE(4872), 1,
      sym_identifier,
    STATE(4878), 1,
      sym__type_identifier,
    STATE(12706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4758), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575858] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11839), 1,
      sym__alpha_identifier,
    ACTIONS(11847), 1,
      sym__backquoted_id,
    ACTIONS(14587), 1,
      sym_operator_identifier,
    STATE(12789), 1,
      sym__soft_identifier,
    STATE(13378), 1,
      sym__type_identifier,
    STATE(13392), 1,
      sym_identifier,
    STATE(12707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11843), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575895] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4530), 1,
      sym__alpha_identifier,
    ACTIONS(4548), 1,
      sym__backquoted_id,
    ACTIONS(14589), 1,
      sym_operator_identifier,
    STATE(5882), 1,
      sym__soft_identifier,
    STATE(6587), 1,
      sym__type_identifier,
    STATE(6615), 1,
      sym_identifier,
    STATE(12708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4542), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575932] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [575957] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8411), 1,
      sym__alpha_identifier,
    ACTIONS(8419), 1,
      sym__backquoted_id,
    ACTIONS(14591), 1,
      sym_operator_identifier,
    STATE(8580), 1,
      sym__type_identifier,
    STATE(8727), 1,
      sym_identifier,
    STATE(8883), 1,
      sym__soft_identifier,
    STATE(12710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8415), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [575994] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [576019] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14109), 1,
      anon_sym_match,
    ACTIONS(14593), 1,
      sym_operator_identifier,
    STATE(5769), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576056] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [576081] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14372), 1,
      anon_sym_match,
    ACTIONS(14595), 1,
      sym_operator_identifier,
    STATE(5572), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576118] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8199), 1,
      sym__alpha_identifier,
    ACTIONS(8207), 1,
      sym__backquoted_id,
    ACTIONS(14597), 1,
      sym_operator_identifier,
    STATE(6976), 1,
      sym_identifier,
    STATE(6987), 1,
      sym__type_identifier,
    STATE(7174), 1,
      sym__soft_identifier,
    STATE(12715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8203), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576155] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(13180), 1,
      anon_sym_COLON,
    ACTIONS(13299), 1,
      anon_sym_derives,
    ACTIONS(14599), 1,
      sym__automatic_semicolon,
    STATE(13704), 1,
      sym_derives_clause,
    STATE(14896), 1,
      sym_template_body,
    STATE(15001), 1,
      sym__definition_body,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13916), 3,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [576196] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [576221] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(14602), 1,
      sym_operator_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11731), 1,
      sym_identifier,
    STATE(11893), 1,
      sym__type_identifier,
    STATE(12718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576258] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [576285] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14604), 1,
      anon_sym_match,
    ACTIONS(14606), 1,
      sym_operator_identifier,
    STATE(5538), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576322] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [576347] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14608), 1,
      sym__alpha_identifier,
    ACTIONS(14610), 1,
      anon_sym_LBRACE,
    ACTIONS(14612), 1,
      anon_sym_LBRACK,
    ACTIONS(14616), 1,
      sym__backquoted_id,
    STATE(8329), 1,
      sym_identifier,
    STATE(8756), 1,
      sym__soft_identifier,
    STATE(12722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576384] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8437), 1,
      sym__alpha_identifier,
    ACTIONS(8445), 1,
      sym__backquoted_id,
    ACTIONS(14618), 1,
      sym_operator_identifier,
    STATE(6404), 1,
      sym__soft_identifier,
    STATE(6511), 1,
      sym__type_identifier,
    STATE(6555), 1,
      sym_identifier,
    STATE(12723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8441), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576421] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14203), 1,
      sym__alpha_identifier,
    ACTIONS(14211), 1,
      sym__backquoted_id,
    ACTIONS(14620), 1,
      anon_sym_LBRACE,
    ACTIONS(14622), 1,
      anon_sym_LBRACK,
    STATE(5657), 1,
      sym_identifier,
    STATE(5813), 1,
      sym__soft_identifier,
    STATE(12724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14209), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576458] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14624), 1,
      sym__alpha_identifier,
    ACTIONS(14626), 1,
      anon_sym_LBRACE,
    ACTIONS(14628), 1,
      anon_sym_LBRACK,
    ACTIONS(14632), 1,
      sym__backquoted_id,
    STATE(9650), 1,
      sym_identifier,
    STATE(9808), 1,
      sym__soft_identifier,
    STATE(12725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14630), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576495] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [576520] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [576545] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14032), 1,
      sym__alpha_identifier,
    ACTIONS(14040), 1,
      sym__backquoted_id,
    ACTIONS(14634), 1,
      anon_sym_LBRACE,
    ACTIONS(14636), 1,
      anon_sym_LBRACK,
    STATE(6540), 1,
      sym_identifier,
    STATE(6596), 1,
      sym__soft_identifier,
    STATE(12728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14038), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576582] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8681), 1,
      anon_sym_LBRACK,
    ACTIONS(8685), 1,
      anon_sym_POUND,
    ACTIONS(9273), 1,
      anon_sym_LPAREN,
    STATE(4439), 1,
      sym_type_arguments,
    STATE(4529), 1,
      sym_arguments,
    STATE(13448), 1,
      aux_sym_annotation_repeat1,
    STATE(12729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [576619] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [576644] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [576669] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(14072), 1,
      sym_operator_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11590), 1,
      sym_identifier,
    STATE(14643), 1,
      sym__object_definition,
    STATE(12732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576706] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7916), 1,
      sym__alpha_identifier,
    ACTIONS(7928), 1,
      sym__backquoted_id,
    ACTIONS(14638), 1,
      sym_operator_identifier,
    STATE(11727), 1,
      sym__soft_identifier,
    STATE(12262), 1,
      sym_identifier,
    STATE(12301), 1,
      sym__type_identifier,
    STATE(12733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7924), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576743] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [576768] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [576793] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6268), 1,
      sym__alpha_identifier,
    ACTIONS(6282), 1,
      sym__backquoted_id,
    ACTIONS(14640), 1,
      sym_operator_identifier,
    STATE(5862), 1,
      sym__soft_identifier,
    STATE(6188), 1,
      sym__type_identifier,
    STATE(6213), 1,
      sym_identifier,
    STATE(12736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6278), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576830] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13534), 1,
      anon_sym_LBRACK,
    ACTIONS(13538), 1,
      anon_sym_LPAREN,
    ACTIONS(13540), 1,
      anon_sym_POUND,
    STATE(13873), 1,
      aux_sym_annotation_repeat1,
    STATE(14054), 1,
      sym_type_arguments,
    STATE(14381), 1,
      sym_arguments,
    STATE(12737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
  [576867] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14109), 1,
      anon_sym_match,
    ACTIONS(14642), 1,
      sym_operator_identifier,
    STATE(5533), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576904] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4886), 1,
      sym__alpha_identifier,
    ACTIONS(4904), 1,
      sym__backquoted_id,
    ACTIONS(14644), 1,
      sym_operator_identifier,
    STATE(5087), 1,
      sym__soft_identifier,
    STATE(5438), 1,
      sym__type_identifier,
    STATE(5446), 1,
      sym_identifier,
    STATE(12739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4898), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576941] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(14454), 1,
      sym_operator_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11599), 1,
      sym_identifier,
    STATE(14286), 1,
      sym__class_constructor,
    STATE(12740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [576978] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6996), 1,
      sym__alpha_identifier,
    ACTIONS(7006), 1,
      sym__backquoted_id,
    ACTIONS(14646), 1,
      sym_operator_identifier,
    STATE(7458), 1,
      sym__soft_identifier,
    STATE(8030), 1,
      sym_identifier,
    STATE(8071), 1,
      sym__type_identifier,
    STATE(12741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7002), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577015] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14648), 1,
      anon_sym_LPAREN,
    STATE(13555), 1,
      sym_arguments,
    STATE(12742), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [577044] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14651), 1,
      anon_sym_catch,
    ACTIONS(14653), 1,
      anon_sym_finally,
    STATE(11850), 1,
      sym_finally_clause,
    STATE(13042), 1,
      sym_catch_clause,
    STATE(12743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
  [577077] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(489), 1,
      sym__alpha_identifier,
    ACTIONS(553), 1,
      sym__backquoted_id,
    ACTIONS(14655), 1,
      sym_operator_identifier,
    STATE(5518), 1,
      sym__soft_identifier,
    STATE(14357), 1,
      sym_identifier,
    STATE(14704), 1,
      sym__namespace_expression,
    STATE(12744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577114] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(13180), 1,
      anon_sym_COLON,
    ACTIONS(13299), 1,
      anon_sym_derives,
    STATE(13708), 1,
      sym_derives_clause,
    STATE(14896), 1,
      sym_template_body,
    STATE(14981), 1,
      sym__definition_body,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(12745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13757), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [577153] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14304), 1,
      anon_sym_match,
    ACTIONS(14657), 1,
      sym_operator_identifier,
    STATE(5685), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577190] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13998), 1,
      anon_sym_match,
    ACTIONS(14659), 1,
      sym_operator_identifier,
    STATE(6095), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577227] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8855), 1,
      anon_sym_LPAREN,
    STATE(12742), 1,
      aux_sym_annotation_repeat1,
    STATE(13555), 1,
      sym_arguments,
    STATE(12748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [577258] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14608), 1,
      sym__alpha_identifier,
    ACTIONS(14616), 1,
      sym__backquoted_id,
    ACTIONS(14661), 1,
      anon_sym_LBRACE,
    ACTIONS(14663), 1,
      anon_sym_LBRACK,
    STATE(8756), 1,
      sym__soft_identifier,
    STATE(8841), 1,
      sym_identifier,
    STATE(12749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577295] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12142), 1,
      sym__alpha_identifier,
    ACTIONS(12150), 1,
      sym__backquoted_id,
    ACTIONS(14665), 1,
      sym_operator_identifier,
    STATE(12655), 1,
      sym__soft_identifier,
    STATE(13379), 1,
      sym_identifier,
    STATE(13387), 1,
      sym__type_identifier,
    STATE(12750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12146), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577332] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14434), 1,
      anon_sym_match,
    ACTIONS(14667), 1,
      sym_operator_identifier,
    STATE(5559), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577369] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(14671), 1,
      sym__automatic_semicolon,
    STATE(12545), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(12752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14669), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [577402] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14012), 1,
      sym__alpha_identifier,
    ACTIONS(14020), 1,
      sym__backquoted_id,
    ACTIONS(14674), 1,
      anon_sym_LBRACE,
    ACTIONS(14676), 1,
      anon_sym_LBRACK,
    STATE(10230), 1,
      sym__soft_identifier,
    STATE(10284), 1,
      sym_identifier,
    STATE(12753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14018), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577439] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(12813), 1,
      sym__automatic_semicolon,
    STATE(12665), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(12754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12811), 8,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [577472] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [577497] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14434), 1,
      anon_sym_match,
    ACTIONS(14678), 1,
      sym_operator_identifier,
    STATE(5499), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577534] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14680), 1,
      anon_sym_LPAREN,
    STATE(13684), 1,
      sym_arguments,
    STATE(12757), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [577563] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(14683), 1,
      anon_sym_extends,
    ACTIONS(14685), 1,
      anon_sym_LPAREN,
    STATE(14171), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14665), 1,
      sym_class_parameters,
    STATE(15023), 1,
      sym_extends_clause,
    STATE(15113), 1,
      sym_type_parameters,
    STATE(15596), 1,
      sym__full_enum_def,
    STATE(12758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14239), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [577604] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14687), 1,
      sym__alpha_identifier,
    ACTIONS(14689), 1,
      anon_sym_LBRACE,
    ACTIONS(14691), 1,
      anon_sym_LBRACK,
    ACTIONS(14695), 1,
      sym__backquoted_id,
    STATE(9594), 1,
      sym__soft_identifier,
    STATE(9642), 1,
      sym_identifier,
    STATE(12759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14693), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577641] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14002), 1,
      sym__alpha_identifier,
    ACTIONS(14010), 1,
      sym__backquoted_id,
    ACTIONS(14697), 1,
      anon_sym_LBRACE,
    ACTIONS(14699), 1,
      anon_sym_LBRACK,
    STATE(9099), 1,
      sym__soft_identifier,
    STATE(9529), 1,
      sym_identifier,
    STATE(12760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577678] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4660), 1,
      sym__alpha_identifier,
    ACTIONS(4678), 1,
      sym__backquoted_id,
    ACTIONS(14701), 1,
      sym_operator_identifier,
    STATE(4601), 1,
      sym__soft_identifier,
    STATE(4704), 1,
      sym_identifier,
    STATE(4727), 1,
      sym__type_identifier,
    STATE(12761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4672), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577715] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [577740] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8719), 1,
      anon_sym_LPAREN,
    STATE(12757), 1,
      aux_sym_annotation_repeat1,
    STATE(13684), 1,
      sym_arguments,
    STATE(12763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [577771] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [577796] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [577821] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6202), 1,
      sym__alpha_identifier,
    ACTIONS(6216), 1,
      sym__backquoted_id,
    ACTIONS(14703), 1,
      sym_operator_identifier,
    STATE(9455), 1,
      sym__soft_identifier,
    STATE(9601), 1,
      sym__type_identifier,
    STATE(9799), 1,
      sym_identifier,
    STATE(12766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6212), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577858] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [577883] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [577908] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14510), 1,
      anon_sym_LBRACK,
    STATE(7044), 1,
      sym_type_arguments,
    STATE(12769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 10,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [577937] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12058), 1,
      sym__alpha_identifier,
    ACTIONS(12066), 1,
      sym__backquoted_id,
    ACTIONS(14288), 1,
      sym_operator_identifier,
    STATE(11305), 1,
      sym__soft_identifier,
    STATE(12171), 1,
      sym_identifier,
    STATE(14428), 1,
      sym__function_constructor,
    STATE(12770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12062), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [577974] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8042), 1,
      sym__alpha_identifier,
    ACTIONS(8050), 1,
      sym__backquoted_id,
    ACTIONS(14705), 1,
      sym_operator_identifier,
    STATE(7769), 1,
      sym__soft_identifier,
    STATE(7934), 1,
      sym__type_identifier,
    STATE(7950), 1,
      sym_identifier,
    STATE(12771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8046), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578011] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12088), 1,
      sym__alpha_identifier,
    ACTIONS(12096), 1,
      sym__backquoted_id,
    ACTIONS(14707), 1,
      sym_operator_identifier,
    STATE(12528), 1,
      sym__soft_identifier,
    STATE(13082), 1,
      sym__type_identifier,
    STATE(13089), 1,
      sym_identifier,
    STATE(12772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12092), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578048] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [578073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [578098] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14510), 1,
      anon_sym_LBRACK,
    ACTIONS(14709), 1,
      anon_sym_match,
    STATE(7044), 1,
      sym_type_arguments,
    STATE(12775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [578129] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [578154] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14711), 1,
      anon_sym_with,
    STATE(12777), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [578181] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4692), 1,
      sym__alpha_identifier,
    ACTIONS(4704), 1,
      sym__backquoted_id,
    ACTIONS(14714), 1,
      sym_operator_identifier,
    STATE(4547), 1,
      sym__soft_identifier,
    STATE(4745), 1,
      sym_identifier,
    STATE(4764), 1,
      sym__type_identifier,
    STATE(12778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4700), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578218] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14604), 1,
      anon_sym_match,
    ACTIONS(14716), 1,
      sym_operator_identifier,
    STATE(5618), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578255] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14718), 1,
      anon_sym_DOT,
    STATE(12780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [578282] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4812), 1,
      sym__alpha_identifier,
    ACTIONS(4824), 1,
      sym__backquoted_id,
    ACTIONS(14720), 1,
      sym_operator_identifier,
    STATE(6330), 1,
      sym__soft_identifier,
    STATE(7198), 1,
      sym_identifier,
    STATE(7354), 1,
      sym__type_identifier,
    STATE(12781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4820), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578319] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14255), 1,
      anon_sym_match,
    ACTIONS(14722), 1,
      sym_operator_identifier,
    STATE(5513), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578356] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11946), 1,
      sym__alpha_identifier,
    ACTIONS(11954), 1,
      sym__backquoted_id,
    ACTIONS(14724), 1,
      sym_operator_identifier,
    STATE(11232), 1,
      sym__soft_identifier,
    STATE(11441), 1,
      sym__type_identifier,
    STATE(11503), 1,
      sym_identifier,
    STATE(12783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578393] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14726), 1,
      sym__alpha_identifier,
    ACTIONS(14728), 1,
      anon_sym_LBRACE,
    ACTIONS(14730), 1,
      anon_sym_LBRACK,
    ACTIONS(14734), 1,
      sym__backquoted_id,
    STATE(8415), 1,
      sym_identifier,
    STATE(8644), 1,
      sym__soft_identifier,
    STATE(12784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14732), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578430] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6336), 1,
      sym__alpha_identifier,
    ACTIONS(6350), 1,
      sym__backquoted_id,
    ACTIONS(14736), 1,
      sym_operator_identifier,
    STATE(6347), 1,
      sym__soft_identifier,
    STATE(7089), 1,
      sym_identifier,
    STATE(7104), 1,
      sym__type_identifier,
    STATE(12785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6346), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578467] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4214), 1,
      sym__alpha_identifier,
    ACTIONS(4232), 1,
      sym__backquoted_id,
    ACTIONS(14738), 1,
      sym_operator_identifier,
    STATE(5031), 1,
      sym__soft_identifier,
    STATE(5147), 1,
      sym__type_identifier,
    STATE(5159), 1,
      sym_identifier,
    STATE(12786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4226), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578504] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [578529] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [578554] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [578579] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7956), 1,
      sym__alpha_identifier,
    ACTIONS(7968), 1,
      sym__backquoted_id,
    ACTIONS(14740), 1,
      sym_operator_identifier,
    STATE(13521), 1,
      sym__soft_identifier,
    STATE(13806), 1,
      sym__type_identifier,
    STATE(13877), 1,
      sym_identifier,
    STATE(12790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7964), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578616] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4422), 1,
      sym__alpha_identifier,
    ACTIONS(4440), 1,
      sym__backquoted_id,
    ACTIONS(14742), 1,
      sym_operator_identifier,
    STATE(6399), 1,
      sym__soft_identifier,
    STATE(7423), 1,
      sym_identifier,
    STATE(7438), 1,
      sym__type_identifier,
    STATE(12791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4434), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578653] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6560), 1,
      sym__alpha_identifier,
    ACTIONS(6574), 1,
      sym__backquoted_id,
    ACTIONS(14744), 1,
      sym_operator_identifier,
    STATE(6060), 1,
      sym__soft_identifier,
    STATE(6146), 1,
      sym__type_identifier,
    STATE(6176), 1,
      sym_identifier,
    STATE(12792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6570), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578690] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14354), 1,
      anon_sym_match,
    ACTIONS(14746), 1,
      sym_operator_identifier,
    STATE(5684), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578727] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14748), 1,
      anon_sym_end,
    STATE(7742), 1,
      sym__end_marker,
    STATE(12794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [578756] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [578781] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12004), 1,
      sym__alpha_identifier,
    ACTIONS(12012), 1,
      sym__backquoted_id,
    ACTIONS(14750), 1,
      sym_operator_identifier,
    STATE(10937), 1,
      sym__soft_identifier,
    STATE(11279), 1,
      sym_identifier,
    STATE(11308), 1,
      sym__type_identifier,
    STATE(12796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578818] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(14752), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(13552), 1,
      sym_identifier,
    STATE(15701), 1,
      sym__function_constructor,
    STATE(12797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578855] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [578880] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4774), 1,
      sym__alpha_identifier,
    ACTIONS(4792), 1,
      sym__backquoted_id,
    ACTIONS(14754), 1,
      sym_operator_identifier,
    STATE(5800), 1,
      sym__soft_identifier,
    STATE(6692), 1,
      sym_identifier,
    STATE(6757), 1,
      sym__type_identifier,
    STATE(12799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4786), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578917] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [578942] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(14163), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11960), 1,
      sym_identifier,
    STATE(14331), 1,
      sym__function_constructor,
    STATE(12801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [578979] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(14292), 1,
      sym_operator_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(11963), 1,
      sym_identifier,
    STATE(14865), 1,
      sym__object_definition,
    STATE(12802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579016] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14478), 1,
      sym__alpha_identifier,
    ACTIONS(14486), 1,
      sym__backquoted_id,
    ACTIONS(14756), 1,
      anon_sym_LBRACE,
    ACTIONS(14758), 1,
      anon_sym_LBRACK,
    STATE(8553), 1,
      sym_identifier,
    STATE(8900), 1,
      sym__soft_identifier,
    STATE(12803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14484), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579053] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6504), 1,
      sym__alpha_identifier,
    ACTIONS(6518), 1,
      sym__backquoted_id,
    ACTIONS(14760), 1,
      sym_operator_identifier,
    STATE(7863), 1,
      sym__soft_identifier,
    STATE(8912), 1,
      sym__type_identifier,
    STATE(8935), 1,
      sym_identifier,
    STATE(12804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6514), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579090] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14372), 1,
      anon_sym_match,
    ACTIONS(14762), 1,
      sym_operator_identifier,
    STATE(5563), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579127] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14492), 1,
      sym__alpha_identifier,
    ACTIONS(14500), 1,
      sym__backquoted_id,
    ACTIONS(14764), 1,
      anon_sym_LBRACE,
    ACTIONS(14766), 1,
      anon_sym_LBRACK,
    STATE(10983), 1,
      sym_identifier,
    STATE(11069), 1,
      sym__soft_identifier,
    STATE(12806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14498), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579164] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [579189] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14768), 1,
      anon_sym_LBRACK,
    ACTIONS(14770), 1,
      anon_sym_AT,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(14774), 1,
      anon_sym_POUND,
    STATE(14062), 1,
      sym_type_arguments,
    STATE(14071), 1,
      aux_sym_enum_definition_repeat1,
    STATE(14594), 1,
      sym_annotation,
    STATE(18478), 1,
      sym_arguments,
    STATE(12808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_with,
  [579230] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13998), 1,
      anon_sym_match,
    ACTIONS(14776), 1,
      sym_operator_identifier,
    STATE(6064), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [579292] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [579317] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [579342] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11989), 1,
      sym__alpha_identifier,
    ACTIONS(11997), 1,
      sym__backquoted_id,
    ACTIONS(14778), 1,
      sym_operator_identifier,
    STATE(13272), 1,
      sym__soft_identifier,
    STATE(13653), 1,
      sym_identifier,
    STATE(13659), 1,
      sym__type_identifier,
    STATE(12813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11993), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579379] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(489), 1,
      sym__alpha_identifier,
    ACTIONS(553), 1,
      sym__backquoted_id,
    ACTIONS(14655), 1,
      sym_operator_identifier,
    STATE(5518), 1,
      sym__soft_identifier,
    STATE(14357), 1,
      sym_identifier,
    STATE(14449), 1,
      sym__namespace_expression,
    STATE(12814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579416] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(489), 1,
      sym__alpha_identifier,
    ACTIONS(553), 1,
      sym__backquoted_id,
    ACTIONS(14655), 1,
      sym_operator_identifier,
    STATE(5518), 1,
      sym__soft_identifier,
    STATE(14357), 1,
      sym_identifier,
    STATE(14448), 1,
      sym__namespace_expression,
    STATE(12815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579453] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8125), 1,
      sym__alpha_identifier,
    ACTIONS(8137), 1,
      sym__backquoted_id,
    ACTIONS(14780), 1,
      sym_operator_identifier,
    STATE(10235), 1,
      sym__soft_identifier,
    STATE(10296), 1,
      sym__type_identifier,
    STATE(10353), 1,
      sym_identifier,
    STATE(12816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8133), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579490] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [579515] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8371), 1,
      sym__alpha_identifier,
    ACTIONS(8383), 1,
      sym__backquoted_id,
    ACTIONS(14782), 1,
      sym_operator_identifier,
    STATE(5405), 1,
      sym_identifier,
    STATE(5418), 1,
      sym__type_identifier,
    STATE(5481), 1,
      sym__soft_identifier,
    STATE(12818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8379), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579552] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [579577] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [579602] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6900), 1,
      sym__alpha_identifier,
    ACTIONS(6914), 1,
      sym__backquoted_id,
    ACTIONS(14784), 1,
      sym_operator_identifier,
    STATE(5013), 1,
      sym__soft_identifier,
    STATE(5170), 1,
      sym_identifier,
    STATE(5183), 1,
      sym__type_identifier,
    STATE(12821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6910), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [579664] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14510), 1,
      anon_sym_LBRACK,
    STATE(7044), 1,
      sym_type_arguments,
    STATE(12823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 10,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [579693] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [579718] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14510), 1,
      anon_sym_LBRACK,
    STATE(7044), 1,
      sym_type_arguments,
    STATE(12825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 10,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [579747] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [579772] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14084), 1,
      sym_operator_identifier,
    ACTIONS(14786), 1,
      anon_sym_match,
    STATE(5721), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579809] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [579834] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14510), 1,
      anon_sym_LBRACK,
    ACTIONS(14709), 1,
      anon_sym_match,
    STATE(7044), 1,
      sym_type_arguments,
    STATE(12829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [579865] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14788), 1,
      sym__alpha_identifier,
    ACTIONS(14790), 1,
      anon_sym_LBRACE,
    ACTIONS(14792), 1,
      anon_sym_LBRACK,
    ACTIONS(14796), 1,
      sym__backquoted_id,
    STATE(6357), 1,
      sym__soft_identifier,
    STATE(6630), 1,
      sym_identifier,
    STATE(12830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14794), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579902] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14193), 1,
      sym__alpha_identifier,
    ACTIONS(14201), 1,
      sym__backquoted_id,
    ACTIONS(14798), 1,
      anon_sym_LBRACE,
    ACTIONS(14800), 1,
      anon_sym_LBRACK,
    STATE(9284), 1,
      sym__soft_identifier,
    STATE(9484), 1,
      sym_identifier,
    STATE(12831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14199), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [579939] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [579964] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [579989] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14434), 1,
      anon_sym_match,
    ACTIONS(14802), 1,
      sym_operator_identifier,
    STATE(5681), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580026] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11825), 1,
      sym__alpha_identifier,
    ACTIONS(11833), 1,
      sym__backquoted_id,
    ACTIONS(14804), 1,
      sym_operator_identifier,
    STATE(11473), 1,
      sym__soft_identifier,
    STATE(11844), 1,
      sym_identifier,
    STATE(11849), 1,
      sym__type_identifier,
    STATE(12835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11829), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580063] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12157), 1,
      sym__alpha_identifier,
    ACTIONS(12165), 1,
      sym__backquoted_id,
    ACTIONS(14292), 1,
      sym_operator_identifier,
    STATE(11658), 1,
      sym__soft_identifier,
    STATE(11963), 1,
      sym_identifier,
    STATE(14943), 1,
      sym__object_definition,
    STATE(12836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12161), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580100] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(12837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [580127] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8423), 1,
      sym__alpha_identifier,
    ACTIONS(8431), 1,
      sym__backquoted_id,
    ACTIONS(14806), 1,
      sym_operator_identifier,
    STATE(7297), 1,
      sym__soft_identifier,
    STATE(7394), 1,
      sym_identifier,
    STATE(7422), 1,
      sym__type_identifier,
    STATE(12838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8427), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580164] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 12,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580189] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14808), 1,
      sym__alpha_identifier,
    ACTIONS(14810), 1,
      anon_sym_LBRACE,
    ACTIONS(14812), 1,
      anon_sym_LBRACK,
    ACTIONS(14816), 1,
      sym__backquoted_id,
    STATE(7866), 1,
      sym__soft_identifier,
    STATE(8158), 1,
      sym_identifier,
    STATE(12840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14814), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580226] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14472), 1,
      anon_sym_match,
    ACTIONS(14818), 1,
      sym_operator_identifier,
    STATE(5885), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580263] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14820), 1,
      anon_sym_end,
    STATE(7890), 1,
      sym__end_marker,
    STATE(12842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [580292] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6578), 1,
      sym__alpha_identifier,
    ACTIONS(6592), 1,
      sym__backquoted_id,
    ACTIONS(14822), 1,
      sym_operator_identifier,
    STATE(6385), 1,
      sym__soft_identifier,
    STATE(7365), 1,
      sym_identifier,
    STATE(7379), 1,
      sym__type_identifier,
    STATE(12843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6588), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580329] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(14752), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(13552), 1,
      sym_identifier,
    STATE(15686), 1,
      sym__function_constructor,
    STATE(12844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580366] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14824), 1,
      sym__alpha_identifier,
    ACTIONS(14826), 1,
      anon_sym_LBRACE,
    ACTIONS(14828), 1,
      anon_sym_LBRACK,
    ACTIONS(14832), 1,
      sym__backquoted_id,
    STATE(8008), 1,
      sym__soft_identifier,
    STATE(8274), 1,
      sym_identifier,
    STATE(12845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14830), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580403] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14824), 1,
      sym__alpha_identifier,
    ACTIONS(14832), 1,
      sym__backquoted_id,
    ACTIONS(14834), 1,
      anon_sym_LBRACE,
    ACTIONS(14836), 1,
      anon_sym_LBRACK,
    STATE(8008), 1,
      sym__soft_identifier,
    STATE(8266), 1,
      sym_identifier,
    STATE(12846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14830), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580440] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7850), 1,
      sym__alpha_identifier,
    ACTIONS(7862), 1,
      sym__backquoted_id,
    ACTIONS(14838), 1,
      sym_operator_identifier,
    STATE(12664), 1,
      sym__soft_identifier,
    STATE(13276), 1,
      sym__type_identifier,
    STATE(13313), 1,
      sym_identifier,
    STATE(12847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7858), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580477] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(14072), 1,
      sym_operator_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11590), 1,
      sym_identifier,
    STATE(15239), 1,
      sym__object_definition,
    STATE(12848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580514] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(12849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [580541] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14840), 1,
      anon_sym_LBRACK,
    STATE(13591), 1,
      sym_access_qualifier,
    STATE(12850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9299), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [580570] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14842), 1,
      anon_sym_match,
    ACTIONS(14844), 1,
      sym_operator_identifier,
    STATE(6012), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580607] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6228), 1,
      sym__alpha_identifier,
    ACTIONS(6242), 1,
      sym__backquoted_id,
    ACTIONS(14846), 1,
      sym_operator_identifier,
    STATE(8670), 1,
      sym__soft_identifier,
    STATE(9091), 1,
      sym_identifier,
    STATE(9192), 1,
      sym__type_identifier,
    STATE(12852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6238), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580644] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14056), 1,
      anon_sym_match,
    ACTIONS(14848), 1,
      sym_operator_identifier,
    STATE(5610), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580681] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(14072), 1,
      sym_operator_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11590), 1,
      sym_identifier,
    STATE(14819), 1,
      sym__object_definition,
    STATE(12854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580718] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13534), 1,
      anon_sym_LBRACK,
    ACTIONS(13536), 1,
      anon_sym_AT,
    ACTIONS(13540), 1,
      anon_sym_POUND,
    STATE(14037), 1,
      aux_sym_enum_definition_repeat1,
    STATE(14054), 1,
      sym_type_arguments,
    STATE(14306), 1,
      sym_annotation,
    STATE(12855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [580755] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [580780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12590), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [580805] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4310), 1,
      sym__alpha_identifier,
    ACTIONS(4328), 1,
      sym__backquoted_id,
    ACTIONS(14850), 1,
      sym_operator_identifier,
    STATE(5094), 1,
      sym__soft_identifier,
    STATE(5294), 1,
      sym_identifier,
    STATE(5318), 1,
      sym__type_identifier,
    STATE(12858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4322), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580842] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8143), 1,
      sym__alpha_identifier,
    ACTIONS(8155), 1,
      sym__backquoted_id,
    ACTIONS(14852), 1,
      sym_operator_identifier,
    STATE(4677), 1,
      sym__type_identifier,
    STATE(4734), 1,
      sym__soft_identifier,
    STATE(4793), 1,
      sym_identifier,
    STATE(12859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8151), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580879] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14177), 1,
      anon_sym_catch,
    ACTIONS(14854), 1,
      anon_sym_finally,
    STATE(12249), 1,
      sym_finally_clause,
    STATE(13516), 1,
      sym_catch_clause,
    STATE(12860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [580912] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [580937] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14376), 1,
      sym__alpha_identifier,
    ACTIONS(14384), 1,
      sym__backquoted_id,
    ACTIONS(14856), 1,
      sym_operator_identifier,
    STATE(4325), 1,
      sym__type_identifier,
    STATE(11550), 1,
      sym__soft_identifier,
    STATE(11661), 1,
      sym_identifier,
    STATE(12862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14382), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [580974] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14438), 1,
      sym__alpha_identifier,
    ACTIONS(14446), 1,
      sym__backquoted_id,
    ACTIONS(14858), 1,
      anon_sym_LBRACE,
    ACTIONS(14860), 1,
      anon_sym_LBRACK,
    STATE(9001), 1,
      sym_identifier,
    STATE(9390), 1,
      sym__soft_identifier,
    STATE(12863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14444), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581011] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8287), 1,
      sym__alpha_identifier,
    ACTIONS(8299), 1,
      sym__backquoted_id,
    ACTIONS(14862), 1,
      sym_operator_identifier,
    STATE(4930), 1,
      sym__soft_identifier,
    STATE(5070), 1,
      sym_identifier,
    STATE(5078), 1,
      sym__type_identifier,
    STATE(12864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8295), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581048] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14864), 1,
      sym__alpha_identifier,
    ACTIONS(14866), 1,
      anon_sym_LBRACE,
    ACTIONS(14868), 1,
      anon_sym_LBRACK,
    ACTIONS(14872), 1,
      sym__backquoted_id,
    STATE(11332), 1,
      sym__soft_identifier,
    STATE(11787), 1,
      sym_identifier,
    STATE(12865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14870), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581085] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8054), 1,
      sym__alpha_identifier,
    ACTIONS(8062), 1,
      sym__backquoted_id,
    ACTIONS(14874), 1,
      sym_operator_identifier,
    STATE(9187), 1,
      sym_identifier,
    STATE(9392), 1,
      sym__soft_identifier,
    STATE(9580), 1,
      sym__type_identifier,
    STATE(12866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8058), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581122] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14569), 1,
      anon_sym_match,
    ACTIONS(14876), 1,
      sym_operator_identifier,
    STATE(5912), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581159] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14864), 1,
      sym__alpha_identifier,
    ACTIONS(14872), 1,
      sym__backquoted_id,
    ACTIONS(14878), 1,
      sym_operator_identifier,
    STATE(4325), 1,
      sym__type_identifier,
    STATE(11294), 1,
      sym_identifier,
    STATE(11332), 1,
      sym__soft_identifier,
    STATE(12868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14870), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581196] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6184), 1,
      sym__alpha_identifier,
    ACTIONS(6194), 1,
      sym__backquoted_id,
    ACTIONS(14880), 1,
      sym_operator_identifier,
    STATE(8315), 1,
      sym__soft_identifier,
    STATE(8986), 1,
      sym_identifier,
    STATE(9428), 1,
      sym__type_identifier,
    STATE(12869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6190), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581233] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4462), 1,
      sym__alpha_identifier,
    ACTIONS(4480), 1,
      sym__backquoted_id,
    ACTIONS(14882), 1,
      sym_operator_identifier,
    STATE(5328), 1,
      sym__soft_identifier,
    STATE(6054), 1,
      sym__type_identifier,
    STATE(6078), 1,
      sym_identifier,
    STATE(12870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4474), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581270] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8469), 1,
      sym__alpha_identifier,
    ACTIONS(8481), 1,
      sym__backquoted_id,
    ACTIONS(14884), 1,
      sym_operator_identifier,
    STATE(5527), 1,
      sym__soft_identifier,
    STATE(5598), 1,
      sym__type_identifier,
    STATE(5870), 1,
      sym_identifier,
    STATE(12871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8477), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581307] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13998), 1,
      anon_sym_match,
    ACTIONS(14886), 1,
      sym_operator_identifier,
    STATE(5682), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581344] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14888), 1,
      anon_sym_with,
    STATE(12968), 1,
      aux_sym_compound_type_repeat1,
    STATE(14746), 1,
      sym_template_body,
    STATE(14761), 1,
      sym__refinement,
    STATE(14826), 1,
      sym_arguments,
    STATE(12873), 2,
      sym_comment,
      sym_block_comment,
    STATE(14824), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [581381] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4512), 1,
      sym__alpha_identifier,
    ACTIONS(4524), 1,
      sym__backquoted_id,
    ACTIONS(14890), 1,
      sym_operator_identifier,
    STATE(4696), 1,
      sym__soft_identifier,
    STATE(4870), 1,
      sym_identifier,
    STATE(5049), 1,
      sym__type_identifier,
    STATE(12874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4520), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581418] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [581443] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12586), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [581468] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12588), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [581493] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(13331), 1,
      sym_operator_identifier,
    ACTIONS(14892), 1,
      anon_sym_match,
    STATE(5503), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581530] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(12879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [581557] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14426), 1,
      anon_sym_match,
    ACTIONS(14894), 1,
      sym_operator_identifier,
    STATE(5639), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581594] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12106), 1,
      sym__alpha_identifier,
    ACTIONS(12114), 1,
      sym__backquoted_id,
    ACTIONS(14896), 1,
      sym_operator_identifier,
    STATE(13264), 1,
      sym__soft_identifier,
    STATE(13449), 1,
      sym_identifier,
    STATE(13535), 1,
      sym__type_identifier,
    STATE(12881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12110), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581631] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14788), 1,
      sym__alpha_identifier,
    ACTIONS(14796), 1,
      sym__backquoted_id,
    ACTIONS(14898), 1,
      anon_sym_LBRACE,
    ACTIONS(14900), 1,
      anon_sym_LBRACK,
    STATE(6357), 1,
      sym__soft_identifier,
    STATE(6437), 1,
      sym_identifier,
    STATE(12882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14794), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581668] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [581695] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(14163), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11960), 1,
      sym_identifier,
    STATE(14394), 1,
      sym__function_constructor,
    STATE(12884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581732] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8259), 1,
      sym__alpha_identifier,
    ACTIONS(8271), 1,
      sym__backquoted_id,
    ACTIONS(14902), 1,
      sym_operator_identifier,
    STATE(4895), 1,
      sym__type_identifier,
    STATE(4939), 1,
      sym__soft_identifier,
    STATE(5059), 1,
      sym_identifier,
    STATE(12885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8267), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581769] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [581796] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14510), 1,
      anon_sym_LBRACK,
    STATE(7044), 1,
      sym_type_arguments,
    STATE(12887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 10,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [581825] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6662), 1,
      sym__alpha_identifier,
    ACTIONS(6672), 1,
      sym__backquoted_id,
    ACTIONS(14904), 1,
      sym_operator_identifier,
    STATE(4632), 1,
      sym__soft_identifier,
    STATE(4802), 1,
      sym_identifier,
    STATE(4812), 1,
      sym__type_identifier,
    STATE(12888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6668), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581862] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [581887] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [581912] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14354), 1,
      anon_sym_match,
    ACTIONS(14906), 1,
      sym_operator_identifier,
    STATE(5709), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [581949] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [581974] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6438), 1,
      sym__alpha_identifier,
    ACTIONS(6452), 1,
      sym__backquoted_id,
    ACTIONS(14908), 1,
      sym_operator_identifier,
    STATE(7350), 1,
      sym__soft_identifier,
    STATE(8081), 1,
      sym__type_identifier,
    STATE(8200), 1,
      sym_identifier,
    STATE(12893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6448), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582011] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6940), 1,
      sym__alpha_identifier,
    ACTIONS(6954), 1,
      sym__backquoted_id,
    ACTIONS(14910), 1,
      sym_operator_identifier,
    STATE(6376), 1,
      sym__soft_identifier,
    STATE(7306), 1,
      sym_identifier,
    STATE(7311), 1,
      sym__type_identifier,
    STATE(12894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6950), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582048] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [582073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [582098] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14504), 1,
      anon_sym_match,
    ACTIONS(14912), 1,
      sym_operator_identifier,
    STATE(5760), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582135] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6632), 1,
      sym__alpha_identifier,
    ACTIONS(6646), 1,
      sym__backquoted_id,
    ACTIONS(14914), 1,
      sym_operator_identifier,
    STATE(6537), 1,
      sym__soft_identifier,
    STATE(6808), 1,
      sym_identifier,
    STATE(6893), 1,
      sym__type_identifier,
    STATE(12898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6642), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582172] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8211), 1,
      sym__alpha_identifier,
    ACTIONS(8223), 1,
      sym__backquoted_id,
    ACTIONS(14916), 1,
      sym_operator_identifier,
    STATE(5235), 1,
      sym__type_identifier,
    STATE(5251), 1,
      sym_identifier,
    STATE(5375), 1,
      sym__soft_identifier,
    STATE(12899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8219), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582209] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14808), 1,
      sym__alpha_identifier,
    ACTIONS(14816), 1,
      sym__backquoted_id,
    ACTIONS(14918), 1,
      anon_sym_LBRACE,
    ACTIONS(14920), 1,
      anon_sym_LBRACK,
    STATE(7707), 1,
      sym_identifier,
    STATE(7866), 1,
      sym__soft_identifier,
    STATE(12900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14814), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582246] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14406), 1,
      sym__alpha_identifier,
    ACTIONS(14414), 1,
      sym__backquoted_id,
    ACTIONS(14922), 1,
      anon_sym_LBRACE,
    ACTIONS(14924), 1,
      anon_sym_LBRACK,
    STATE(7709), 1,
      sym_identifier,
    STATE(7824), 1,
      sym__soft_identifier,
    STATE(12901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582283] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14109), 1,
      anon_sym_match,
    ACTIONS(14926), 1,
      sym_operator_identifier,
    STATE(6046), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582320] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6754), 1,
      sym__alpha_identifier,
    ACTIONS(6764), 1,
      sym__backquoted_id,
    ACTIONS(14928), 1,
      sym_operator_identifier,
    STATE(4998), 1,
      sym__soft_identifier,
    STATE(5116), 1,
      sym__type_identifier,
    STATE(5124), 1,
      sym_identifier,
    STATE(12903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6760), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582357] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8333), 1,
      sym__alpha_identifier,
    ACTIONS(8341), 1,
      sym__backquoted_id,
    ACTIONS(14930), 1,
      sym_operator_identifier,
    STATE(5274), 1,
      sym__type_identifier,
    STATE(5279), 1,
      sym_identifier,
    STATE(5309), 1,
      sym__soft_identifier,
    STATE(12904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8337), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582394] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [582419] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12797), 1,
      sym__alpha_identifier,
    ACTIONS(12805), 1,
      sym__backquoted_id,
    ACTIONS(14932), 1,
      sym_operator_identifier,
    STATE(14377), 1,
      sym__soft_identifier,
    STATE(14514), 1,
      sym_identifier,
    STATE(14879), 1,
      sym_simple_enum_case,
    STATE(12906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12803), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582456] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14687), 1,
      sym__alpha_identifier,
    ACTIONS(14695), 1,
      sym__backquoted_id,
    ACTIONS(14934), 1,
      anon_sym_LBRACE,
    ACTIONS(14936), 1,
      anon_sym_LBRACK,
    STATE(9594), 1,
      sym__soft_identifier,
    STATE(9930), 1,
      sym_identifier,
    STATE(12907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14693), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582493] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14294), 1,
      sym__alpha_identifier,
    ACTIONS(14302), 1,
      sym__backquoted_id,
    ACTIONS(14938), 1,
      anon_sym_LBRACE,
    ACTIONS(14940), 1,
      anon_sym_LBRACK,
    STATE(6852), 1,
      sym__soft_identifier,
    STATE(6977), 1,
      sym_identifier,
    STATE(12908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14300), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582530] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14942), 1,
      anon_sym_LPAREN,
    STATE(13495), 1,
      sym_arguments,
    STATE(12909), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [582559] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8869), 1,
      anon_sym_LPAREN,
    STATE(12909), 1,
      aux_sym_annotation_repeat1,
    STATE(13495), 1,
      sym_arguments,
    STATE(12910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [582590] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14945), 1,
      anon_sym_LPAREN,
    STATE(13609), 1,
      sym_arguments,
    STATE(12911), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [582619] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14948), 1,
      sym__alpha_identifier,
    ACTIONS(14950), 1,
      anon_sym_LBRACE,
    ACTIONS(14952), 1,
      anon_sym_LBRACK,
    ACTIONS(14956), 1,
      sym__backquoted_id,
    STATE(10447), 1,
      sym_identifier,
    STATE(10526), 1,
      sym__soft_identifier,
    STATE(12912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582656] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14245), 1,
      sym__alpha_identifier,
    ACTIONS(14253), 1,
      sym__backquoted_id,
    ACTIONS(14958), 1,
      anon_sym_LBRACE,
    ACTIONS(14960), 1,
      anon_sym_LBRACK,
    STATE(10187), 1,
      sym_identifier,
    STATE(10317), 1,
      sym__soft_identifier,
    STATE(12913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14251), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582693] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14948), 1,
      sym__alpha_identifier,
    ACTIONS(14956), 1,
      sym__backquoted_id,
    ACTIONS(14962), 1,
      anon_sym_LBRACE,
    ACTIONS(14964), 1,
      anon_sym_LBRACK,
    STATE(10452), 1,
      sym_identifier,
    STATE(10526), 1,
      sym__soft_identifier,
    STATE(12914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582730] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12607), 12,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_AT,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [582755] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(14163), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(11960), 1,
      sym_identifier,
    STATE(14557), 1,
      sym__function_constructor,
    STATE(12916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582792] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14318), 1,
      anon_sym_match,
    ACTIONS(14966), 1,
      sym_operator_identifier,
    STATE(5726), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582829] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8833), 1,
      anon_sym_LPAREN,
    STATE(12911), 1,
      aux_sym_annotation_repeat1,
    STATE(13609), 1,
      sym_arguments,
    STATE(12918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [582860] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14968), 1,
      anon_sym_match,
    ACTIONS(14970), 1,
      sym_operator_identifier,
    STATE(5509), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582897] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [582922] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12921), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [582947] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6254), 1,
      sym__alpha_identifier,
    ACTIONS(6264), 1,
      sym__backquoted_id,
    ACTIONS(14972), 1,
      sym_operator_identifier,
    STATE(8141), 1,
      sym__soft_identifier,
    STATE(8663), 1,
      sym_identifier,
    STATE(8936), 1,
      sym__type_identifier,
    STATE(12922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6260), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [582984] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14555), 1,
      sym__alpha_identifier,
    ACTIONS(14563), 1,
      sym__backquoted_id,
    ACTIONS(14974), 1,
      anon_sym_LBRACE,
    ACTIONS(14976), 1,
      anon_sym_LBRACK,
    STATE(9065), 1,
      sym_identifier,
    STATE(9578), 1,
      sym__soft_identifier,
    STATE(12923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14561), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583021] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14121), 1,
      sym__alpha_identifier,
    ACTIONS(14125), 1,
      sym__backquoted_id,
    ACTIONS(14978), 1,
      anon_sym_LBRACE,
    ACTIONS(14980), 1,
      anon_sym_LBRACK,
    STATE(10804), 1,
      sym__soft_identifier,
    STATE(11270), 1,
      sym_identifier,
    STATE(12924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14123), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583058] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14624), 1,
      sym__alpha_identifier,
    ACTIONS(14632), 1,
      sym__backquoted_id,
    ACTIONS(14982), 1,
      anon_sym_LBRACE,
    ACTIONS(14984), 1,
      anon_sym_LBRACK,
    STATE(9808), 1,
      sym__soft_identifier,
    STATE(9872), 1,
      sym_identifier,
    STATE(12925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14630), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583095] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14109), 1,
      anon_sym_match,
    ACTIONS(14986), 1,
      sym_operator_identifier,
    STATE(5706), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583132] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14109), 1,
      anon_sym_match,
    ACTIONS(14988), 1,
      sym_operator_identifier,
    STATE(5874), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14990), 1,
      anon_sym_DOT,
    STATE(12928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [583196] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8449), 1,
      sym__alpha_identifier,
    ACTIONS(8457), 1,
      sym__backquoted_id,
    ACTIONS(14992), 1,
      sym_operator_identifier,
    STATE(5534), 1,
      sym_identifier,
    STATE(5585), 1,
      sym__type_identifier,
    STATE(5831), 1,
      sym__soft_identifier,
    STATE(12929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8453), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583233] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12070), 1,
      sym__alpha_identifier,
    ACTIONS(12078), 1,
      sym__backquoted_id,
    ACTIONS(14994), 1,
      sym_operator_identifier,
    STATE(11859), 1,
      sym__soft_identifier,
    STATE(12099), 1,
      sym__type_identifier,
    STATE(12108), 1,
      sym_identifier,
    STATE(12930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12074), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583270] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14233), 1,
      anon_sym_catch,
    ACTIONS(14996), 1,
      anon_sym_finally,
    STATE(12249), 1,
      sym_finally_clause,
    STATE(13476), 1,
      sym_catch_clause,
    STATE(12931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
  [583303] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6286), 1,
      sym__alpha_identifier,
    ACTIONS(6296), 1,
      sym__backquoted_id,
    ACTIONS(14998), 1,
      sym_operator_identifier,
    STATE(6838), 1,
      sym__soft_identifier,
    STATE(8017), 1,
      sym__type_identifier,
    STATE(8156), 1,
      sym_identifier,
    STATE(12932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6292), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583340] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6918), 1,
      sym__alpha_identifier,
    ACTIONS(6932), 1,
      sym__backquoted_id,
    ACTIONS(15000), 1,
      sym_operator_identifier,
    STATE(4714), 1,
      sym__soft_identifier,
    STATE(4832), 1,
      sym_identifier,
    STATE(5019), 1,
      sym__type_identifier,
    STATE(12933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(6928), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(12934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [583404] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(14398), 1,
      sym_operator_identifier,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(14152), 1,
      sym_identifier,
    STATE(14370), 1,
      sym__namespace_expression,
    STATE(12935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583441] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(14398), 1,
      sym_operator_identifier,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(14152), 1,
      sym_identifier,
    STATE(14368), 1,
      sym__namespace_expression,
    STATE(12936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583478] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(14072), 1,
      sym_operator_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11590), 1,
      sym_identifier,
    STATE(14656), 1,
      sym__object_definition,
    STATE(12937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583515] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [583540] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [583565] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [583590] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [583615] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13323), 1,
      sym__alpha_identifier,
    ACTIONS(13329), 1,
      sym__backquoted_id,
    ACTIONS(14109), 1,
      anon_sym_match,
    ACTIONS(15002), 1,
      sym_operator_identifier,
    STATE(5798), 1,
      sym_identifier,
    STATE(12995), 1,
      sym__soft_identifier,
    STATE(12942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13327), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583652] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12016), 1,
      sym__alpha_identifier,
    ACTIONS(12024), 1,
      sym__backquoted_id,
    ACTIONS(14454), 1,
      sym_operator_identifier,
    STATE(11321), 1,
      sym__soft_identifier,
    STATE(11599), 1,
      sym_identifier,
    STATE(14335), 1,
      sym__class_constructor,
    STATE(12943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12020), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583689] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15004), 1,
      anon_sym_DOT,
    STATE(12944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [583716] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 12,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [583741] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14726), 1,
      sym__alpha_identifier,
    ACTIONS(14734), 1,
      sym__backquoted_id,
    ACTIONS(15006), 1,
      anon_sym_LBRACE,
    ACTIONS(15008), 1,
      anon_sym_LBRACK,
    STATE(8644), 1,
      sym__soft_identifier,
    STATE(8858), 1,
      sym_identifier,
    STATE(12946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14732), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583778] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(14752), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(13552), 1,
      sym_identifier,
    STATE(15698), 1,
      sym__function_constructor,
    STATE(12947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583815] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 12,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [583840] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13224), 1,
      aux_sym_compound_type_repeat1,
    STATE(14469), 1,
      sym__refinement,
    STATE(14485), 1,
      sym_template_body,
    STATE(14573), 1,
      sym_arguments,
    STATE(12949), 2,
      sym_comment,
      sym_block_comment,
    STATE(14568), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7752), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [583875] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [583899] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [583923] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15010), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16675), 1,
      sym_identifier,
    STATE(12952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [583957] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15014), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(12953), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [583999] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14624), 1,
      sym__alpha_identifier,
    ACTIONS(14632), 1,
      sym__backquoted_id,
    ACTIONS(15016), 1,
      sym_operator_identifier,
    STATE(9808), 1,
      sym__soft_identifier,
    STATE(9832), 1,
      sym_identifier,
    STATE(12954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14630), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [584033] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [584057] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [584081] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7644), 1,
      anon_sym_case,
    ACTIONS(7646), 1,
      anon_sym_object,
    ACTIONS(7648), 1,
      anon_sym_given,
    ACTIONS(7650), 1,
      anon_sym_class,
    ACTIONS(7652), 1,
      anon_sym_trait,
    ACTIONS(7654), 1,
      anon_sym_val,
    ACTIONS(7656), 1,
      anon_sym_var,
    ACTIONS(7658), 1,
      anon_sym_type,
    ACTIONS(7660), 1,
      anon_sym_def,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    STATE(18503), 1,
      sym_opaque_modifier,
    STATE(12957), 2,
      sym_comment,
      sym_block_comment,
  [584125] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [584149] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [584173] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [584197] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [584221] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15018), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(12962), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [584263] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [584287] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14768), 1,
      anon_sym_LBRACK,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(14774), 1,
      anon_sym_POUND,
    STATE(14062), 1,
      sym_type_arguments,
    STATE(14253), 1,
      aux_sym_annotation_repeat1,
    STATE(14554), 1,
      sym_arguments,
    STATE(12964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7678), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
  [584323] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15020), 1,
      anon_sym_catch,
    ACTIONS(15022), 1,
      anon_sym_finally,
    STATE(13939), 1,
      sym_catch_clause,
    STATE(14073), 1,
      sym_finally_clause,
    STATE(12965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [584355] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(12966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [584381] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15024), 1,
      anon_sym_catch,
    ACTIONS(15026), 1,
      anon_sym_finally,
    STATE(13812), 1,
      sym_catch_clause,
    STATE(13949), 1,
      sym_finally_clause,
    STATE(12967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
  [584413] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14888), 1,
      anon_sym_with,
    STATE(14315), 1,
      aux_sym_compound_type_repeat1,
    STATE(14746), 1,
      sym_template_body,
    STATE(14851), 1,
      sym__refinement,
    STATE(12968), 2,
      sym_comment,
      sym_block_comment,
    STATE(14824), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [584447] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [584471] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14462), 1,
      anon_sym_finally,
    STATE(11889), 1,
      sym_finally_clause,
    STATE(12970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 9,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_do,
      anon_sym_yield,
  [584499] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15028), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(12971), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [584541] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15030), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(12972), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [584583] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [584607] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15032), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(12974), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [584649] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15034), 1,
      anon_sym_LBRACK,
    STATE(7669), 1,
      sym_type_arguments,
    STATE(12975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [584677] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15036), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16550), 1,
      sym_identifier,
    STATE(12976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [584711] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15038), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(12977), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [584753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [584777] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [584801] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15040), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(12980), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [584843] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14726), 1,
      sym__alpha_identifier,
    ACTIONS(14734), 1,
      sym__backquoted_id,
    ACTIONS(15042), 1,
      sym_operator_identifier,
    STATE(8644), 1,
      sym__soft_identifier,
    STATE(8894), 1,
      sym_identifier,
    STATE(12981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14732), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [584877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(12982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [584903] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15044), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(12983), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [584945] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15046), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(12984), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [584987] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [585011] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [585035] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4180), 2,
      anon_sym_LPAREN,
      sym__backquoted_id,
    STATE(12987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4176), 9,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [585061] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15048), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(12988), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [585103] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15050), 1,
      anon_sym_STAR,
    STATE(12989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [585129] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15052), 1,
      anon_sym_catch,
    ACTIONS(15054), 1,
      anon_sym_finally,
    STATE(11850), 1,
      sym_finally_clause,
    STATE(13470), 1,
      sym_catch_clause,
    STATE(12990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [585161] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(846), 1,
      sym__alpha_identifier,
    ACTIONS(876), 1,
      sym__backquoted_id,
    ACTIONS(15056), 1,
      sym_operator_identifier,
    STATE(5497), 1,
      sym__soft_identifier,
    STATE(18470), 1,
      sym_identifier,
    STATE(12991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(856), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [585195] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15058), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16631), 1,
      sym_identifier,
    STATE(12992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [585229] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15060), 1,
      anon_sym_catch,
    ACTIONS(15062), 1,
      anon_sym_finally,
    STATE(13164), 1,
      sym_finally_clause,
    STATE(13442), 1,
      sym_catch_clause,
    STATE(12993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
  [585261] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15064), 1,
      anon_sym_catch,
    ACTIONS(15066), 1,
      anon_sym_finally,
    STATE(13797), 1,
      sym_finally_clause,
    STATE(13814), 1,
      sym_catch_clause,
    STATE(12994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [585293] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7064), 2,
      anon_sym_LPAREN,
      sym__backquoted_id,
    STATE(12995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7062), 9,
      anon_sym__,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [585319] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7644), 1,
      anon_sym_case,
    ACTIONS(7646), 1,
      anon_sym_object,
    ACTIONS(7650), 1,
      anon_sym_class,
    ACTIONS(7652), 1,
      anon_sym_trait,
    ACTIONS(7654), 1,
      anon_sym_val,
    ACTIONS(7656), 1,
      anon_sym_var,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(7746), 1,
      anon_sym_type,
    ACTIONS(7748), 1,
      anon_sym_def,
    ACTIONS(7756), 1,
      anon_sym_given,
    STATE(17982), 1,
      sym_opaque_modifier,
    STATE(12996), 2,
      sym_comment,
      sym_block_comment,
  [585363] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15034), 1,
      anon_sym_LBRACK,
    STATE(7669), 1,
      sym_type_arguments,
    STATE(12997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [585391] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15068), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(12998), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [585433] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15034), 1,
      anon_sym_LBRACK,
    ACTIONS(15070), 1,
      anon_sym_match,
    STATE(7669), 1,
      sym_type_arguments,
    STATE(12999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [585463] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15072), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13000), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [585505] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [585529] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14032), 1,
      sym__alpha_identifier,
    ACTIONS(14040), 1,
      sym__backquoted_id,
    ACTIONS(15074), 1,
      sym_operator_identifier,
    STATE(6475), 1,
      sym_identifier,
    STATE(6596), 1,
      sym__soft_identifier,
    STATE(13002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14038), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [585563] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [585587] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585611] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14948), 1,
      sym__alpha_identifier,
    ACTIONS(14956), 1,
      sym__backquoted_id,
    ACTIONS(15076), 1,
      sym_operator_identifier,
    STATE(10526), 1,
      sym__soft_identifier,
    STATE(10613), 1,
      sym_identifier,
    STATE(13005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14954), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [585645] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15078), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13006), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [585687] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585711] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [585735] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15034), 1,
      anon_sym_LBRACK,
    STATE(7669), 1,
      sym_type_arguments,
    STATE(13009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [585763] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15034), 1,
      anon_sym_LBRACK,
    STATE(7669), 1,
      sym_type_arguments,
    STATE(13010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [585791] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(15080), 1,
      anon_sym_case,
    ACTIONS(15082), 1,
      anon_sym_object,
    ACTIONS(15084), 1,
      anon_sym_given,
    ACTIONS(15086), 1,
      anon_sym_class,
    ACTIONS(15088), 1,
      anon_sym_trait,
    ACTIONS(15090), 1,
      anon_sym_val,
    ACTIONS(15092), 1,
      anon_sym_var,
    ACTIONS(15094), 1,
      anon_sym_type,
    ACTIONS(15096), 1,
      anon_sym_def,
    STATE(18360), 1,
      sym_opaque_modifier,
    STATE(13011), 2,
      sym_comment,
      sym_block_comment,
  [585835] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15098), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13012), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [585877] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15034), 1,
      anon_sym_LBRACK,
    ACTIONS(15070), 1,
      anon_sym_match,
    STATE(7669), 1,
      sym_type_arguments,
    STATE(13013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [585907] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14226), 1,
      sym_access_modifier,
    STATE(14227), 1,
      aux_sym__class_constructor_repeat1,
    ACTIONS(12381), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(13014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12811), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [585943] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15100), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13015), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [585985] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15102), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13016), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [586027] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [586051] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14308), 1,
      sym__alpha_identifier,
    ACTIONS(14316), 1,
      sym__backquoted_id,
    ACTIONS(15104), 1,
      sym_operator_identifier,
    STATE(9919), 1,
      sym__soft_identifier,
    STATE(10005), 1,
      sym_identifier,
    STATE(13018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14314), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [586085] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15106), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13019), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [586127] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15108), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13020), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [586169] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11973), 1,
      sym__alpha_identifier,
    ACTIONS(11979), 1,
      sym__backquoted_id,
    ACTIONS(15110), 1,
      sym_operator_identifier,
    STATE(10298), 1,
      sym__soft_identifier,
    STATE(13779), 1,
      sym_identifier,
    STATE(13021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [586203] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(12970), 1,
      anon_sym_COLON,
    STATE(14608), 1,
      sym__definition_body,
    STATE(14848), 1,
      sym_template_body,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15112), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [586237] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [586261] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15114), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16661), 1,
      sym_identifier,
    STATE(13024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [586295] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15116), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16597), 1,
      sym_identifier,
    STATE(13025), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [586329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [586353] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15118), 1,
      anon_sym_catch,
    ACTIONS(15120), 1,
      anon_sym_finally,
    STATE(13627), 1,
      sym_catch_clause,
    STATE(13651), 1,
      sym_finally_clause,
    STATE(13027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [586385] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15122), 1,
      anon_sym_catch,
    ACTIONS(15124), 1,
      anon_sym_finally,
    STATE(13045), 1,
      sym_finally_clause,
    STATE(13767), 1,
      sym_catch_clause,
    STATE(13028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [586417] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14328), 1,
      sym__alpha_identifier,
    ACTIONS(14336), 1,
      sym__backquoted_id,
    ACTIONS(15126), 1,
      sym_operator_identifier,
    STATE(8296), 1,
      sym__soft_identifier,
    STATE(8423), 1,
      sym_identifier,
    STATE(13029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14334), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [586451] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15128), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13030), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [586493] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14808), 1,
      sym__alpha_identifier,
    ACTIONS(14816), 1,
      sym__backquoted_id,
    ACTIONS(15130), 1,
      sym_operator_identifier,
    STATE(7734), 1,
      sym_identifier,
    STATE(7866), 1,
      sym__soft_identifier,
    STATE(13031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14814), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [586527] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [586551] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(12944), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(18301), 1,
      sym_identifier,
    STATE(13033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [586585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15132), 1,
      anon_sym_with,
    STATE(13034), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [586611] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [586635] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15135), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13036), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [586677] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7654), 1,
      anon_sym_val,
    ACTIONS(7656), 1,
      anon_sym_var,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(7718), 1,
      anon_sym_case,
    ACTIONS(7720), 1,
      anon_sym_object,
    ACTIONS(7724), 1,
      anon_sym_class,
    ACTIONS(7726), 1,
      anon_sym_trait,
    ACTIONS(7728), 1,
      anon_sym_type,
    ACTIONS(7730), 1,
      anon_sym_def,
    ACTIONS(7734), 1,
      anon_sym_given,
    STATE(17967), 1,
      sym_opaque_modifier,
    STATE(13037), 2,
      sym_comment,
      sym_block_comment,
  [586721] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15020), 1,
      anon_sym_catch,
    ACTIONS(15137), 1,
      anon_sym_finally,
    STATE(13797), 1,
      sym_finally_clause,
    STATE(14005), 1,
      sym_catch_clause,
    STATE(13038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [586753] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(12970), 1,
      anon_sym_COLON,
    ACTIONS(15141), 1,
      sym__automatic_semicolon,
    STATE(14748), 1,
      sym__definition_body,
    STATE(14848), 1,
      sym_template_body,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13039), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15139), 4,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [586789] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [586813] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14153), 1,
      sym__alpha_identifier,
    ACTIONS(14161), 1,
      sym__backquoted_id,
    ACTIONS(15144), 1,
      sym_operator_identifier,
    STATE(9819), 1,
      sym__soft_identifier,
    STATE(9944), 1,
      sym_identifier,
    STATE(13041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14159), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [586847] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14653), 1,
      anon_sym_finally,
    STATE(11889), 1,
      sym_finally_clause,
    STATE(13042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
  [586875] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [586899] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [586923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [586947] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(15090), 1,
      anon_sym_val,
    ACTIONS(15092), 1,
      anon_sym_var,
    ACTIONS(15146), 1,
      anon_sym_case,
    ACTIONS(15148), 1,
      anon_sym_object,
    ACTIONS(15150), 1,
      anon_sym_given,
    ACTIONS(15152), 1,
      anon_sym_class,
    ACTIONS(15154), 1,
      anon_sym_trait,
    ACTIONS(15156), 1,
      anon_sym_type,
    ACTIONS(15158), 1,
      anon_sym_def,
    STATE(17934), 1,
      sym_opaque_modifier,
    STATE(13046), 2,
      sym_comment,
      sym_block_comment,
  [586991] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(13047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15160), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [587021] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [587045] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15162), 1,
      anon_sym_catch,
    ACTIONS(15164), 1,
      anon_sym_finally,
    STATE(12249), 1,
      sym_finally_clause,
    STATE(13777), 1,
      sym_catch_clause,
    STATE(13049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [587077] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15024), 1,
      anon_sym_catch,
    ACTIONS(15166), 1,
      anon_sym_finally,
    STATE(13422), 1,
      sym_finally_clause,
    STATE(13803), 1,
      sym_catch_clause,
    STATE(13050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
  [587109] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15034), 1,
      anon_sym_LBRACK,
    STATE(7669), 1,
      sym_type_arguments,
    STATE(13051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [587137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [587161] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15168), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16642), 1,
      sym_identifier,
    STATE(13053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [587195] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(15168), 1,
      sym_operator_identifier,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15114), 1,
      sym_identifier,
    STATE(13054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7580), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [587229] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15170), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13055), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [587271] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14012), 1,
      sym__alpha_identifier,
    ACTIONS(14020), 1,
      sym__backquoted_id,
    ACTIONS(15172), 1,
      sym_operator_identifier,
    STATE(10112), 1,
      sym_identifier,
    STATE(10230), 1,
      sym__soft_identifier,
    STATE(13056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14018), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [587305] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [587329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [587353] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [587377] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15174), 1,
      anon_sym_catch,
    ACTIONS(15176), 1,
      anon_sym_finally,
    STATE(13499), 1,
      sym_catch_clause,
    STATE(13651), 1,
      sym_finally_clause,
    STATE(13060), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [587409] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [587433] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15178), 1,
      anon_sym_end,
    STATE(8450), 1,
      sym__end_marker,
    STATE(13062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [587461] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [587485] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(8559), 1,
      sym_operator_identifier,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15097), 1,
      sym_identifier,
    STATE(13064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7580), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [587519] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14142), 1,
      aux_sym__class_constructor_repeat1,
    STATE(14145), 1,
      sym_access_modifier,
    ACTIONS(12381), 2,
      anon_sym_private,
      anon_sym_protected,
    STATE(13065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12865), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [587555] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    ACTIONS(15182), 1,
      anon_sym_match,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(13066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [587585] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15162), 1,
      anon_sym_catch,
    ACTIONS(15184), 1,
      anon_sym_finally,
    STATE(12773), 1,
      sym_finally_clause,
    STATE(13830), 1,
      sym_catch_clause,
    STATE(13067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [587617] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(12970), 1,
      anon_sym_COLON,
    STATE(14717), 1,
      sym__definition_body,
    STATE(14848), 1,
      sym_template_body,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15186), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [587651] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [587675] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15188), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16610), 1,
      sym_identifier,
    STATE(13070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [587709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12607), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [587733] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15190), 1,
      anon_sym_catch,
    ACTIONS(15192), 1,
      anon_sym_finally,
    STATE(13045), 1,
      sym_finally_clause,
    STATE(14019), 1,
      sym_catch_clause,
    STATE(13072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [587765] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14294), 1,
      sym__alpha_identifier,
    ACTIONS(14302), 1,
      sym__backquoted_id,
    ACTIONS(15194), 1,
      sym_operator_identifier,
    STATE(6852), 1,
      sym__soft_identifier,
    STATE(7148), 1,
      sym_identifier,
    STATE(13073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14300), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [587799] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(12970), 1,
      anon_sym_COLON,
    ACTIONS(15198), 1,
      sym__automatic_semicolon,
    STATE(14601), 1,
      sym__definition_body,
    STATE(14848), 1,
      sym_template_body,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15196), 4,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [587835] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [587859] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15201), 1,
      anon_sym_LBRACK,
    ACTIONS(15203), 1,
      anon_sym_match,
    STATE(7710), 1,
      sym_type_arguments,
    STATE(13076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [587889] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13077), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [587913] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15205), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(18181), 1,
      sym_identifier,
    STATE(13078), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [587947] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [587971] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    ACTIONS(15182), 1,
      anon_sym_match,
    ACTIONS(15209), 1,
      anon_sym_if,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(14593), 1,
      sym_guard,
    STATE(13080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15207), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [588005] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [588029] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [588053] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [588077] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588101] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [588125] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13440), 1,
      sym_arguments,
    STATE(13086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [588151] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [588175] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15201), 1,
      anon_sym_LBRACK,
    STATE(7710), 1,
      sym_type_arguments,
    STATE(13088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588203] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [588227] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [588251] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [588275] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13092), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [588299] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [588323] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [588347] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [588371] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15211), 1,
      anon_sym_LPAREN,
    STATE(13742), 1,
      sym_arguments,
    STATE(13096), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_SEMI,
  [588399] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [588423] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15201), 1,
      anon_sym_LBRACK,
    ACTIONS(15203), 1,
      anon_sym_match,
    STATE(7710), 1,
      sym_type_arguments,
    STATE(13098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588453] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(13099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15214), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [588483] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(13100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15216), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [588513] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(13101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [588539] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [588563] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [588589] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [588613] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [588637] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15218), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13106), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [588679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15220), 1,
      anon_sym_DOT,
    STATE(13107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [588705] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15222), 1,
      anon_sym_catch,
    ACTIONS(15224), 1,
      anon_sym_finally,
    STATE(12407), 1,
      sym_finally_clause,
    STATE(13505), 1,
      sym_catch_clause,
    STATE(13108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [588737] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13352), 1,
      anon_sym_LPAREN,
    STATE(13096), 1,
      aux_sym_annotation_repeat1,
    STATE(13742), 1,
      sym_arguments,
    STATE(13109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_SEMI,
  [588767] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [588791] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14478), 1,
      sym__alpha_identifier,
    ACTIONS(14486), 1,
      sym__backquoted_id,
    ACTIONS(15226), 1,
      sym_operator_identifier,
    STATE(8745), 1,
      sym_identifier,
    STATE(8900), 1,
      sym__soft_identifier,
    STATE(13111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14484), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [588825] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15228), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16526), 1,
      sym_identifier,
    STATE(13112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [588859] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15201), 1,
      anon_sym_LBRACK,
    STATE(7710), 1,
      sym_type_arguments,
    STATE(13113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [588887] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(13114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [588915] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15230), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16627), 1,
      sym_identifier,
    STATE(13115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [588949] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [588973] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [588997] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15232), 1,
      anon_sym_STAR,
    STATE(13118), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [589023] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15234), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16547), 1,
      sym_identifier,
    STATE(13119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [589057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589083] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13121), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589107] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15236), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13122), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [589149] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13123), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [589175] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589199] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589223] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589247] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589273] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [589297] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589321] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15238), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13130), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [589363] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [589387] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589411] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [589435] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(15242), 1,
      anon_sym_LT_COLON,
    ACTIONS(15244), 1,
      anon_sym_GT_COLON,
    STATE(13778), 1,
      sym_type_parameters,
    STATE(14280), 1,
      sym_lower_bound,
    STATE(14529), 1,
      sym_upper_bound,
    STATE(13134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15240), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [589471] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [589495] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589519] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(846), 1,
      sym__alpha_identifier,
    ACTIONS(876), 1,
      sym__backquoted_id,
    ACTIONS(15246), 1,
      sym_operator_identifier,
    STATE(5497), 1,
      sym__soft_identifier,
    STATE(17951), 1,
      sym_identifier,
    STATE(13137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(856), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [589553] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589577] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589601] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589625] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15248), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13141), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [589667] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15250), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13142), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [589709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [589733] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(13635), 1,
      sym_operator_identifier,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15025), 1,
      sym_identifier,
    STATE(13144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7580), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [589767] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14788), 1,
      sym__alpha_identifier,
    ACTIONS(14796), 1,
      sym__backquoted_id,
    ACTIONS(15252), 1,
      sym_operator_identifier,
    STATE(6281), 1,
      sym_identifier,
    STATE(6357), 1,
      sym__soft_identifier,
    STATE(13145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14794), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [589801] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    ACTIONS(15182), 1,
      anon_sym_match,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(13146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [589831] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [589855] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [589879] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589903] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [589927] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [589951] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [589975] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15254), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16591), 1,
      sym_identifier,
    STATE(13153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [590009] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [590033] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [590057] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [590081] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15256), 1,
      anon_sym_catch,
    ACTIONS(15258), 1,
      anon_sym_finally,
    STATE(12407), 1,
      sym_finally_clause,
    STATE(13703), 1,
      sym_catch_clause,
    STATE(13157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [590113] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [590137] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14608), 1,
      sym__alpha_identifier,
    ACTIONS(14616), 1,
      sym__backquoted_id,
    ACTIONS(15260), 1,
      sym_operator_identifier,
    STATE(8756), 1,
      sym__soft_identifier,
    STATE(8877), 1,
      sym_identifier,
    STATE(13159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14614), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [590171] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13160), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [590195] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [590219] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [590243] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [590267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [590291] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15262), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16557), 1,
      sym_identifier,
    STATE(13165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [590325] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(9445), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16413), 1,
      sym_identifier,
    STATE(13166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [590359] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12960), 1,
      anon_sym_AT,
    STATE(13190), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13796), 1,
      sym_annotation,
    STATE(13167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [590389] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [590413] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [590437] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12588), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [590461] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13171), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [590485] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15201), 1,
      anon_sym_LBRACK,
    STATE(7710), 1,
      sym_type_arguments,
    STATE(13172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [590513] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12586), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [590537] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [590561] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [590585] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15264), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16554), 1,
      sym_identifier,
    STATE(13176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [590619] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [590643] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [590667] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [590691] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [590715] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15201), 1,
      anon_sym_LBRACK,
    STATE(7710), 1,
      sym_type_arguments,
    STATE(13181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [590743] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15064), 1,
      anon_sym_catch,
    ACTIONS(15266), 1,
      anon_sym_finally,
    STATE(13903), 1,
      sym_catch_clause,
    STATE(14073), 1,
      sym_finally_clause,
    STATE(13182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [590775] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(13183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [590803] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15268), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13184), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [590845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [590869] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [590893] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [590917] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    ACTIONS(15182), 1,
      anon_sym_match,
    ACTIONS(15209), 1,
      anon_sym_if,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(14531), 1,
      sym_guard,
    STATE(13188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15270), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [590951] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [590975] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15272), 1,
      anon_sym_AT,
    STATE(13796), 1,
      sym_annotation,
    STATE(13190), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [591003] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [591027] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(13192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15275), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [591057] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15277), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16546), 1,
      sym_identifier,
    STATE(13193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591091] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15122), 1,
      anon_sym_catch,
    ACTIONS(15279), 1,
      anon_sym_finally,
    STATE(12875), 1,
      sym_finally_clause,
    STATE(13730), 1,
      sym_catch_clause,
    STATE(13194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [591123] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14438), 1,
      sym__alpha_identifier,
    ACTIONS(14446), 1,
      sym__backquoted_id,
    ACTIONS(15281), 1,
      sym_operator_identifier,
    STATE(9080), 1,
      sym_identifier,
    STATE(9390), 1,
      sym__soft_identifier,
    STATE(13195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14444), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591157] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15283), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13196), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [591199] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15285), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16506), 1,
      sym_identifier,
    STATE(13197), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591233] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15287), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16565), 1,
      sym_identifier,
    STATE(13198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591267] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15289), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13199), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [591309] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9134), 1,
      anon_sym_LPAREN,
    STATE(13206), 1,
      aux_sym_annotation_repeat1,
    STATE(13876), 1,
      sym_arguments,
    STATE(13200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [591339] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(489), 1,
      sym__alpha_identifier,
    ACTIONS(553), 1,
      sym__backquoted_id,
    ACTIONS(15291), 1,
      sym_operator_identifier,
    STATE(5518), 1,
      sym__soft_identifier,
    STATE(14545), 1,
      sym_identifier,
    STATE(13201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(677), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591373] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(846), 1,
      sym__alpha_identifier,
    ACTIONS(876), 1,
      sym__backquoted_id,
    ACTIONS(15293), 1,
      sym_operator_identifier,
    STATE(5497), 1,
      sym__soft_identifier,
    STATE(17859), 1,
      sym_identifier,
    STATE(13202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(856), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591407] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15295), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16538), 1,
      sym_identifier,
    STATE(13203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591441] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    ACTIONS(15297), 1,
      sym_operator_identifier,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(14940), 1,
      sym_identifier,
    STATE(13204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7580), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591475] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [591499] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15299), 1,
      anon_sym_LPAREN,
    STATE(13876), 1,
      sym_arguments,
    STATE(13206), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [591527] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(15090), 1,
      anon_sym_val,
    ACTIONS(15092), 1,
      anon_sym_var,
    ACTIONS(15146), 1,
      anon_sym_case,
    ACTIONS(15148), 1,
      anon_sym_object,
    ACTIONS(15152), 1,
      anon_sym_class,
    ACTIONS(15154), 1,
      anon_sym_trait,
    ACTIONS(15156), 1,
      anon_sym_type,
    ACTIONS(15158), 1,
      anon_sym_def,
    ACTIONS(15302), 1,
      anon_sym_given,
    STATE(17934), 1,
      sym_opaque_modifier,
    STATE(13207), 2,
      sym_comment,
      sym_block_comment,
  [591571] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14824), 1,
      sym__alpha_identifier,
    ACTIONS(14832), 1,
      sym__backquoted_id,
    ACTIONS(15304), 1,
      sym_operator_identifier,
    STATE(8008), 1,
      sym__soft_identifier,
    STATE(8175), 1,
      sym_identifier,
    STATE(13208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14830), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591605] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15306), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16530), 1,
      sym_identifier,
    STATE(13209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13256), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [591663] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12590), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [591687] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13254), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [591711] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15308), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16520), 1,
      sym_identifier,
    STATE(13213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591745] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [591769] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14687), 1,
      sym__alpha_identifier,
    ACTIONS(14695), 1,
      sym__backquoted_id,
    ACTIONS(15310), 1,
      sym_operator_identifier,
    STATE(9594), 1,
      sym__soft_identifier,
    STATE(9595), 1,
      sym_identifier,
    STATE(13215), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14693), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591803] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [591827] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15312), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16536), 1,
      sym_identifier,
    STATE(13217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591861] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15190), 1,
      anon_sym_catch,
    ACTIONS(15314), 1,
      anon_sym_finally,
    STATE(12875), 1,
      sym_finally_clause,
    STATE(14008), 1,
      sym_catch_clause,
    STATE(13218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [591893] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14245), 1,
      sym__alpha_identifier,
    ACTIONS(14253), 1,
      sym__backquoted_id,
    ACTIONS(15316), 1,
      sym_operator_identifier,
    STATE(10176), 1,
      sym_identifier,
    STATE(10317), 1,
      sym__soft_identifier,
    STATE(13219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14251), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591927] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(9293), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16680), 1,
      sym_identifier,
    STATE(13220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [591961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [591987] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(13222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [592015] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15318), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16523), 1,
      sym_identifier,
    STATE(13223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [592049] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14315), 1,
      aux_sym_compound_type_repeat1,
    STATE(14485), 1,
      sym_template_body,
    STATE(14535), 1,
      sym__refinement,
    STATE(13224), 2,
      sym_comment,
      sym_block_comment,
    STATE(14568), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    ACTIONS(7778), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [592081] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(13225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 9,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [592109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [592135] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7644), 1,
      anon_sym_case,
    ACTIONS(7646), 1,
      anon_sym_object,
    ACTIONS(7650), 1,
      anon_sym_class,
    ACTIONS(7652), 1,
      anon_sym_trait,
    ACTIONS(7654), 1,
      anon_sym_val,
    ACTIONS(7656), 1,
      anon_sym_var,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(7744), 1,
      anon_sym_given,
    ACTIONS(7746), 1,
      anon_sym_type,
    ACTIONS(7748), 1,
      anon_sym_def,
    STATE(17982), 1,
      sym_opaque_modifier,
    STATE(13227), 2,
      sym_comment,
      sym_block_comment,
  [592179] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [592203] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15320), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16495), 1,
      sym_identifier,
    STATE(13229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [592237] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [592261] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    ACTIONS(15322), 1,
      anon_sym_EQ,
    STATE(14025), 1,
      aux_sym_compound_type_repeat1,
    STATE(16667), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    STATE(18478), 1,
      sym_arguments,
    STATE(13231), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [592303] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [592327] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15324), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16515), 1,
      sym_identifier,
    STATE(13233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [592361] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7654), 1,
      anon_sym_val,
    ACTIONS(7656), 1,
      anon_sym_var,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(7718), 1,
      anon_sym_case,
    ACTIONS(7720), 1,
      anon_sym_object,
    ACTIONS(7722), 1,
      anon_sym_given,
    ACTIONS(7724), 1,
      anon_sym_class,
    ACTIONS(7726), 1,
      anon_sym_trait,
    ACTIONS(7728), 1,
      anon_sym_type,
    ACTIONS(7730), 1,
      anon_sym_def,
    STATE(17967), 1,
      sym_opaque_modifier,
    STATE(13234), 2,
      sym_comment,
      sym_block_comment,
  [592405] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [592429] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15326), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16508), 1,
      sym_identifier,
    STATE(13236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [592463] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9050), 1,
      anon_sym_LPAREN,
    STATE(13239), 1,
      aux_sym_annotation_repeat1,
    STATE(13972), 1,
      sym_arguments,
    STATE(13237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [592493] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [592517] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15328), 1,
      anon_sym_LPAREN,
    STATE(13972), 1,
      sym_arguments,
    STATE(13239), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [592545] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14492), 1,
      sym__alpha_identifier,
    ACTIONS(14500), 1,
      sym__backquoted_id,
    ACTIONS(15331), 1,
      sym_operator_identifier,
    STATE(11020), 1,
      sym_identifier,
    STATE(11069), 1,
      sym__soft_identifier,
    STATE(13240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14498), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [592579] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15333), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16504), 1,
      sym_identifier,
    STATE(13241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [592613] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15335), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16479), 1,
      sym_identifier,
    STATE(13242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [592647] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13573), 1,
      anon_sym_LBRACK,
    ACTIONS(15337), 1,
      anon_sym_LT_COLON,
    ACTIONS(15339), 1,
      anon_sym_GT_COLON,
    STATE(13841), 1,
      sym_type_parameters,
    STATE(14390), 1,
      sym_lower_bound,
    STATE(14739), 1,
      sym_upper_bound,
    STATE(13243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15240), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [592683] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(15341), 1,
      sym__automatic_semicolon,
    STATE(13291), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13914), 1,
      sym_class_parameters,
    STATE(13244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14100), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [592715] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [592739] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15344), 1,
      anon_sym_DOT,
    STATE(13246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [592765] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [592789] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [592813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [592837] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [592861] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15346), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16499), 1,
      sym_identifier,
    STATE(13251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [592895] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [592919] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [592943] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [592967] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [592991] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15348), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16480), 1,
      sym_identifier,
    STATE(13256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [593025] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [593049] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [593073] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14555), 1,
      sym__alpha_identifier,
    ACTIONS(14563), 1,
      sym__backquoted_id,
    ACTIONS(15350), 1,
      sym_operator_identifier,
    STATE(9257), 1,
      sym_identifier,
    STATE(9578), 1,
      sym__soft_identifier,
    STATE(13259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14561), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [593107] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15352), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16493), 1,
      sym_identifier,
    STATE(13260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [593141] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      sym__alpha_identifier,
    ACTIONS(83), 1,
      sym__backquoted_id,
    ACTIONS(15110), 1,
      sym_operator_identifier,
    STATE(4608), 1,
      sym__soft_identifier,
    STATE(13779), 1,
      sym_identifier,
    STATE(13261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7572), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [593175] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [593199] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15354), 1,
      anon_sym_LPAREN,
    STATE(13775), 1,
      sym_arguments,
    STATE(13263), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [593227] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13264), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [593251] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(9437), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16573), 1,
      sym_identifier,
    STATE(13265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [593285] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [593309] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [593333] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [593357] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15357), 1,
      anon_sym_end,
    STATE(8431), 1,
      sym__end_marker,
    STATE(13269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [593385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [593409] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15359), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16486), 1,
      sym_identifier,
    STATE(13271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [593443] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [593467] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15361), 1,
      anon_sym_LPAREN,
    ACTIONS(15364), 1,
      sym__automatic_semicolon,
    STATE(14122), 1,
      sym_parameters,
    STATE(14205), 1,
      sym__using_parameters_clause,
    STATE(13273), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__function_constructor_repeat1,
    ACTIONS(14167), 6,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [593499] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14203), 1,
      sym__alpha_identifier,
    ACTIONS(14211), 1,
      sym__backquoted_id,
    ACTIONS(15367), 1,
      sym_operator_identifier,
    STATE(5628), 1,
      sym_identifier,
    STATE(5813), 1,
      sym__soft_identifier,
    STATE(13274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14209), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [593533] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [593557] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [593581] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13277), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [593605] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15369), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16473), 1,
      sym_identifier,
    STATE(13278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [593639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13279), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 11,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [593663] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13575), 1,
      anon_sym_LPAREN,
    ACTIONS(15371), 1,
      sym__automatic_semicolon,
    STATE(13332), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14122), 1,
      sym_parameters,
    STATE(14205), 1,
      sym__using_parameters_clause,
    STATE(13280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14064), 6,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [593697] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13575), 1,
      anon_sym_LPAREN,
    ACTIONS(15373), 1,
      sym__automatic_semicolon,
    STATE(13273), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14122), 1,
      sym_parameters,
    STATE(14205), 1,
      sym__using_parameters_clause,
    STATE(13281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14060), 6,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [593731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 11,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [593755] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15375), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16476), 1,
      sym_identifier,
    STATE(13283), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [593789] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(15377), 1,
      sym__automatic_semicolon,
    STATE(13291), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13914), 1,
      sym_class_parameters,
    STATE(13284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14269), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [593821] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(15380), 1,
      sym__automatic_semicolon,
    STATE(13291), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13914), 1,
      sym_class_parameters,
    STATE(13285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14274), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [593853] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(15383), 1,
      sym__automatic_semicolon,
    STATE(13244), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13914), 1,
      sym_class_parameters,
    STATE(13286), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14283), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [593885] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12932), 1,
      anon_sym_AT,
    STATE(13333), 1,
      aux_sym_enum_definition_repeat1,
    STATE(13744), 1,
      sym_annotation,
    STATE(13287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [593915] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [593939] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(13289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [593965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [593989] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15386), 1,
      anon_sym_LPAREN,
    ACTIONS(15389), 1,
      sym__automatic_semicolon,
    STATE(13914), 1,
      sym_class_parameters,
    STATE(13291), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__class_constructor_repeat1,
    ACTIONS(14215), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [594019] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15392), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16448), 1,
      sym_identifier,
    STATE(13292), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [594053] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9161), 1,
      anon_sym_LPAREN,
    STATE(13263), 1,
      aux_sym_annotation_repeat1,
    STATE(13775), 1,
      sym_arguments,
    STATE(13293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [594083] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [594107] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [594131] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15394), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16471), 1,
      sym_identifier,
    STATE(13296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [594165] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [594189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13298), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [594213] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [594237] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13300), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 11,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [594261] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [594285] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [594309] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [594333] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13304), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [594357] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(9587), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16653), 1,
      sym_identifier,
    STATE(13305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [594391] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [594415] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [594439] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(15080), 1,
      anon_sym_case,
    ACTIONS(15082), 1,
      anon_sym_object,
    ACTIONS(15086), 1,
      anon_sym_class,
    ACTIONS(15088), 1,
      anon_sym_trait,
    ACTIONS(15090), 1,
      anon_sym_val,
    ACTIONS(15092), 1,
      anon_sym_var,
    ACTIONS(15396), 1,
      anon_sym_given,
    ACTIONS(15398), 1,
      anon_sym_type,
    ACTIONS(15400), 1,
      anon_sym_def,
    STATE(17987), 1,
      sym_opaque_modifier,
    STATE(13308), 2,
      sym_comment,
      sym_block_comment,
  [594483] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [594507] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [594531] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15402), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16468), 1,
      sym_identifier,
    STATE(13311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [594565] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [594589] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [594613] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [594637] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13315), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [594661] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [594685] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15404), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16438), 1,
      sym_identifier,
    STATE(13317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [594719] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [594743] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(13319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [594769] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14416), 1,
      sym__alpha_identifier,
    ACTIONS(14424), 1,
      sym__backquoted_id,
    ACTIONS(15406), 1,
      sym_operator_identifier,
    STATE(6878), 1,
      sym_identifier,
    STATE(7377), 1,
      sym__soft_identifier,
    STATE(13320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14422), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [594803] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15408), 1,
      anon_sym_DOT,
    STATE(13321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [594829] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [594853] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13638), 1,
      sym_arguments,
    STATE(13323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [594879] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [594903] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [594927] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15410), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16455), 1,
      sym_identifier,
    STATE(13326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [594961] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13327), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [594985] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [595009] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15412), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16457), 1,
      sym_identifier,
    STATE(13329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595043] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14406), 1,
      sym__alpha_identifier,
    ACTIONS(14414), 1,
      sym__backquoted_id,
    ACTIONS(15414), 1,
      sym_operator_identifier,
    STATE(7649), 1,
      sym_identifier,
    STATE(7824), 1,
      sym__soft_identifier,
    STATE(13330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14412), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595077] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15416), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16445), 1,
      sym_identifier,
    STATE(13331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595111] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13575), 1,
      anon_sym_LPAREN,
    ACTIONS(15418), 1,
      sym__automatic_semicolon,
    STATE(13273), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14122), 1,
      sym_parameters,
    STATE(14205), 1,
      sym__using_parameters_clause,
    STATE(13332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14466), 6,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [595145] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15420), 1,
      anon_sym_AT,
    STATE(13744), 1,
      sym_annotation,
    STATE(13333), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595173] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15423), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16425), 1,
      sym_identifier,
    STATE(13334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595207] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13201), 1,
      anon_sym_LPAREN,
    STATE(13337), 1,
      aux_sym_annotation_repeat1,
    STATE(13721), 1,
      sym_arguments,
    STATE(13335), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 8,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_SEMI,
  [595237] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [595261] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15425), 1,
      anon_sym_LPAREN,
    STATE(13721), 1,
      sym_arguments,
    STATE(13337), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 8,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_SEMI,
  [595289] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [595313] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13725), 1,
      anon_sym_COMMA,
    STATE(13353), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(13339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15428), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595341] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [595365] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [595389] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13727), 1,
      anon_sym_with,
    STATE(13354), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(13342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15428), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595417] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15430), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16403), 1,
      sym_identifier,
    STATE(13343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595451] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13344), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 11,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [595475] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14259), 1,
      sym__alpha_identifier,
    ACTIONS(14267), 1,
      sym__backquoted_id,
    ACTIONS(15432), 1,
      sym_operator_identifier,
    STATE(7053), 1,
      sym_identifier,
    STATE(7318), 1,
      sym__soft_identifier,
    STATE(13345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14265), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595509] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15434), 1,
      anon_sym_end,
    STATE(8294), 1,
      sym__end_marker,
    STATE(13346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [595537] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7662), 1,
      anon_sym_opaque,
    ACTIONS(15080), 1,
      anon_sym_case,
    ACTIONS(15082), 1,
      anon_sym_object,
    ACTIONS(15086), 1,
      anon_sym_class,
    ACTIONS(15088), 1,
      anon_sym_trait,
    ACTIONS(15090), 1,
      anon_sym_val,
    ACTIONS(15092), 1,
      anon_sym_var,
    ACTIONS(15398), 1,
      anon_sym_type,
    ACTIONS(15400), 1,
      anon_sym_def,
    ACTIONS(15436), 1,
      anon_sym_given,
    STATE(17987), 1,
      sym_opaque_modifier,
    STATE(13347), 2,
      sym_comment,
      sym_block_comment,
  [595581] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15438), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16434), 1,
      sym_identifier,
    STATE(13348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595615] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15440), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16420), 1,
      sym_identifier,
    STATE(13349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595649] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15442), 1,
      anon_sym_end,
    STATE(8829), 1,
      sym__end_marker,
    STATE(13350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [595677] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13351), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [595701] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15444), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16383), 1,
      sym_identifier,
    STATE(13352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595735] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15448), 1,
      anon_sym_COMMA,
    STATE(13353), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat1,
    ACTIONS(15446), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15453), 1,
      anon_sym_with,
    STATE(13354), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat2,
    ACTIONS(15451), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595787] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [595811] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [595835] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15456), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16389), 1,
      sym_identifier,
    STATE(13357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595869] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15458), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16410), 1,
      sym_identifier,
    STATE(13358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595903] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15460), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16430), 1,
      sym_identifier,
    STATE(13359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595937] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [595961] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14002), 1,
      sym__alpha_identifier,
    ACTIONS(14010), 1,
      sym__backquoted_id,
    ACTIONS(15462), 1,
      sym_operator_identifier,
    STATE(9099), 1,
      sym__soft_identifier,
    STATE(9216), 1,
      sym_identifier,
    STATE(13361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14008), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [595995] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [596019] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 11,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [596043] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [596067] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15464), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16399), 1,
      sym_identifier,
    STATE(13365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [596101] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15466), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16443), 1,
      sym_identifier,
    STATE(13366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [596135] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [596159] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [596183] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [596207] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15468), 1,
      anon_sym_LBRACK,
    STATE(14000), 1,
      sym_access_qualifier,
    STATE(13370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9299), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [596235] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [596259] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(15470), 1,
      sym__automatic_semicolon,
    STATE(13291), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13914), 1,
      sym_class_parameters,
    STATE(13372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14516), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [596291] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(15473), 1,
      sym__automatic_semicolon,
    STATE(13284), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13914), 1,
      sym_class_parameters,
    STATE(13373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14521), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [596323] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [596347] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(15476), 1,
      sym__automatic_semicolon,
    STATE(13291), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13914), 1,
      sym_class_parameters,
    STATE(13375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14532), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [596379] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(13218), 1,
      sym__automatic_semicolon,
    STATE(13285), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13914), 1,
      sym_class_parameters,
    STATE(13376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12865), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [596411] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [596435] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [596459] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [596483] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [596507] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [596531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [596555] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15479), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16401), 1,
      sym_identifier,
    STATE(13383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [596589] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(9407), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16462), 1,
      sym_identifier,
    STATE(13384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [596623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [596647] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [596671] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [596695] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [596719] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15481), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16390), 1,
      sym_identifier,
    STATE(13389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [596753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [596777] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [596801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [596825] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14193), 1,
      sym__alpha_identifier,
    ACTIONS(14201), 1,
      sym__backquoted_id,
    ACTIONS(15483), 1,
      sym_operator_identifier,
    STATE(9284), 1,
      sym__soft_identifier,
    STATE(9498), 1,
      sym_identifier,
    STATE(13393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14199), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [596859] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [596883] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(15485), 1,
      sym__automatic_semicolon,
    STATE(13291), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13914), 1,
      sym_class_parameters,
    STATE(13395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14669), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [596915] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12553), 1,
      anon_sym_LPAREN,
    ACTIONS(13198), 1,
      sym__automatic_semicolon,
    STATE(13372), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13914), 1,
      sym_class_parameters,
    STATE(13396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12811), 7,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_SEMI,
  [596947] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [596971] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [596995] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_catch,
      anon_sym_finally,
  [597019] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [597043] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [597067] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
      anon_sym_finally,
  [597091] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15201), 1,
      anon_sym_LBRACK,
    STATE(7710), 1,
      sym_type_arguments,
    STATE(13403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 9,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597119] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9287), 1,
      sym__alpha_identifier,
    ACTIONS(9291), 1,
      sym__backquoted_id,
    ACTIONS(15488), 1,
      sym_operator_identifier,
    STATE(4183), 1,
      sym__soft_identifier,
    STATE(16416), 1,
      sym_identifier,
    STATE(13404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9289), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [597153] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13405), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 11,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_LT_COLON,
      anon_sym_if,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_SEMI,
  [597177] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15490), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597200] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15497), 1,
      anon_sym_SEMI,
    ACTIONS(15500), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13407), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_catch,
      anon_sym_finally,
  [597229] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597252] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15503), 1,
      anon_sym_STAR,
    STATE(13409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [597277] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [597300] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15505), 1,
      anon_sym_LBRACK,
    STATE(8442), 1,
      sym_type_arguments,
    STATE(13411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [597327] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597350] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13575), 1,
      anon_sym_LPAREN,
    STATE(14181), 1,
      sym_parameters,
    STATE(14205), 1,
      sym__using_parameters_clause,
    STATE(13413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15160), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [597379] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597402] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [597425] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597448] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597471] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597494] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [597517] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597540] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15507), 1,
      anon_sym_LBRACK,
    STATE(8864), 1,
      sym_type_arguments,
    STATE(13421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [597567] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597590] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [597613] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597636] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597659] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597682] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597705] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597728] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15505), 1,
      anon_sym_LBRACK,
    ACTIONS(15509), 1,
      anon_sym_match,
    STATE(8442), 1,
      sym_type_arguments,
    STATE(13429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [597757] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597803] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15511), 1,
      anon_sym_DOT,
    STATE(13432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [597828] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15513), 1,
      anon_sym_LBRACK,
    STATE(8708), 1,
      sym_type_arguments,
    STATE(13433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [597855] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597878] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597901] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13436), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15515), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597924] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597949] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15518), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [597972] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [597995] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13440), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [598018] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13441), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598041] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15062), 1,
      anon_sym_finally,
    STATE(13136), 1,
      sym_finally_clause,
    STATE(13442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_catch,
  [598068] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [598091] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15505), 1,
      anon_sym_LBRACK,
    STATE(8442), 1,
      sym_type_arguments,
    STATE(13444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [598118] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15505), 1,
      anon_sym_LBRACK,
    STATE(8442), 1,
      sym_type_arguments,
    STATE(13445), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [598145] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13446), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598168] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598191] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9273), 1,
      anon_sym_LPAREN,
    STATE(4529), 1,
      sym_arguments,
    STATE(13462), 1,
      aux_sym_annotation_repeat1,
    STATE(13448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [598220] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598243] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [598266] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598289] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [598312] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13453), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [598335] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15520), 1,
      anon_sym_catch,
    ACTIONS(15522), 1,
      anon_sym_finally,
    STATE(13854), 1,
      sym_catch_clause,
    STATE(13962), 1,
      sym_finally_clause,
    STATE(13454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [598366] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [598389] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13230), 1,
      anon_sym_LT_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(14134), 1,
      sym_upper_bound,
    STATE(14136), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14703), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(15524), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13456), 2,
      sym_comment,
      sym_block_comment,
  [598428] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598451] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15505), 1,
      anon_sym_LBRACK,
    ACTIONS(15509), 1,
      anon_sym_match,
    STATE(8442), 1,
      sym_type_arguments,
    STATE(13458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [598480] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15526), 1,
      anon_sym_catch,
    ACTIONS(15528), 1,
      anon_sym_finally,
    STATE(12773), 1,
      sym_finally_clause,
    STATE(14063), 1,
      sym_catch_clause,
    STATE(13459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [598511] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13460), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598534] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13461), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598557] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15530), 1,
      anon_sym_LPAREN,
    STATE(4529), 1,
      sym_arguments,
    STATE(13462), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [598584] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598609] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13230), 1,
      anon_sym_LT_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(14111), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14118), 1,
      sym_upper_bound,
    STATE(14698), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(15533), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(13464), 2,
      sym_comment,
      sym_block_comment,
  [598648] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598673] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15513), 1,
      anon_sym_LBRACK,
    ACTIONS(15535), 1,
      anon_sym_match,
    STATE(8708), 1,
      sym_type_arguments,
    STATE(13466), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [598702] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13256), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598725] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598748] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13254), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [598771] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15054), 1,
      anon_sym_finally,
    STATE(11889), 1,
      sym_finally_clause,
    STATE(13470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
  [598798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(13471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [598823] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15507), 1,
      anon_sym_LBRACK,
    ACTIONS(15537), 1,
      anon_sym_match,
    STATE(8864), 1,
      sym_type_arguments,
    STATE(13472), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [598852] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13473), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [598875] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [598898] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15539), 1,
      anon_sym_DOT,
    STATE(13475), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [598923] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14996), 1,
      anon_sym_finally,
    STATE(12309), 1,
      sym_finally_clause,
    STATE(13476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
  [598950] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13477), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [598973] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13746), 1,
      sym_arguments,
    STATE(13478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [598998] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15507), 1,
      anon_sym_LBRACK,
    STATE(8864), 1,
      sym_type_arguments,
    STATE(13479), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [599025] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15507), 1,
      anon_sym_LBRACK,
    STATE(8864), 1,
      sym_type_arguments,
    STATE(13480), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [599052] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [599075] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    STATE(13494), 1,
      aux_sym_annotation_repeat1,
    STATE(14162), 1,
      sym_arguments,
    STATE(13482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [599104] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [599127] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15541), 1,
      anon_sym_STAR,
    STATE(13484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [599152] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [599175] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13254), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [599198] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13256), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [599221] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14215), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [599244] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14235), 1,
      anon_sym_finally,
    STATE(12730), 1,
      sym_finally_clause,
    STATE(13489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
  [599271] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13490), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [599294] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [599317] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [599340] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(13493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [599365] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15543), 1,
      anon_sym_LPAREN,
    STATE(14162), 1,
      sym_arguments,
    STATE(13494), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [599392] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [599415] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [599438] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15546), 1,
      anon_sym_catch,
    ACTIONS(15548), 1,
      anon_sym_finally,
    STATE(12407), 1,
      sym_finally_clause,
    STATE(13942), 1,
      sym_catch_clause,
    STATE(13497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [599469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [599492] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15176), 1,
      anon_sym_finally,
    STATE(13666), 1,
      sym_finally_clause,
    STATE(13499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
  [599519] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15550), 1,
      anon_sym_end,
    STATE(9263), 1,
      sym__end_marker,
    STATE(13500), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [599546] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [599569] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15552), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [599592] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13503), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [599615] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13504), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15555), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [599638] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15224), 1,
      anon_sym_finally,
    STATE(12295), 1,
      sym_finally_clause,
    STATE(13505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_do,
      anon_sym_yield,
  [599665] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13506), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [599688] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [599711] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13508), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [599734] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13509), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [599757] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13510), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [599780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13511), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [599803] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [599826] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [599849] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15557), 1,
      anon_sym_SEMI,
    ACTIONS(15560), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 6,
      sym__automatic_semicolon,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [599878] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13515), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 10,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [599901] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14854), 1,
      anon_sym_finally,
    STATE(12309), 1,
      sym_finally_clause,
    STATE(13516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [599928] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15565), 1,
      anon_sym_SEMI,
    ACTIONS(15568), 1,
      anon_sym_else,
    STATE(13517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [599955] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13518), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [599978] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7578), 1,
      sym__alpha_identifier,
    ACTIONS(7598), 1,
      sym__backquoted_id,
    STATE(14873), 1,
      sym__soft_identifier,
    STATE(15646), 1,
      sym_identifier,
    STATE(13519), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7580), 6,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
  [600009] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15571), 1,
      anon_sym_catch,
    ACTIONS(15573), 1,
      anon_sym_finally,
    STATE(13962), 1,
      sym_finally_clause,
    STATE(14002), 1,
      sym_catch_clause,
    STATE(13520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [600040] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13521), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 10,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [600063] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15575), 1,
      anon_sym_catch,
    ACTIONS(15577), 1,
      anon_sym_finally,
    STATE(12875), 1,
      sym_finally_clause,
    STATE(14170), 1,
      sym_catch_clause,
    STATE(13522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [600094] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13523), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [600117] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [600140] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15507), 1,
      anon_sym_LBRACK,
    ACTIONS(15537), 1,
      anon_sym_match,
    STATE(8864), 1,
      sym_type_arguments,
    STATE(13525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [600169] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [600192] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [600215] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13528), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [600238] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [600261] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [600284] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [600307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [600330] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13533), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [600353] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [600376] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [600399] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [600422] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15513), 1,
      anon_sym_LBRACK,
    STATE(8708), 1,
      sym_type_arguments,
    STATE(13537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [600449] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15579), 1,
      anon_sym_LBRACK,
    STATE(8844), 1,
      sym_type_arguments,
    STATE(13538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [600476] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15579), 1,
      anon_sym_LBRACK,
    STATE(8844), 1,
      sym_type_arguments,
    STATE(13539), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [600503] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [600526] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15581), 1,
      anon_sym_catch,
    ACTIONS(15583), 1,
      anon_sym_finally,
    STATE(14115), 1,
      sym_catch_clause,
    STATE(14239), 1,
      sym_finally_clause,
    STATE(13541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [600557] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15507), 1,
      anon_sym_LBRACK,
    STATE(8864), 1,
      sym_type_arguments,
    STATE(13542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [600584] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [600607] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [600630] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [600653] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [600676] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14768), 1,
      anon_sym_LBRACK,
    ACTIONS(14770), 1,
      anon_sym_AT,
    ACTIONS(14774), 1,
      anon_sym_POUND,
    STATE(14062), 1,
      sym_type_arguments,
    STATE(14071), 1,
      aux_sym_enum_definition_repeat1,
    STATE(14594), 1,
      sym_annotation,
    STATE(13547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_LPAREN,
  [600711] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [600734] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13549), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [600757] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15585), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [600780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15588), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [600803] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(15590), 1,
      sym__automatic_semicolon,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14248), 1,
      sym_type_parameters,
    STATE(14249), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13552), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13308), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [600840] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15592), 1,
      anon_sym_end,
    STATE(9073), 1,
      sym__end_marker,
    STATE(13553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [600867] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15594), 1,
      anon_sym_STAR,
    STATE(13554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [600892] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [600915] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13556), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [600938] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15596), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [600961] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15599), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [600984] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15601), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601007] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13560), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15603), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601030] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13561), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12607), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601053] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [601076] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13563), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [601099] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15605), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601122] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [601145] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13566), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [601168] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13567), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15608), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601191] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15610), 1,
      anon_sym_end,
    STATE(9383), 1,
      sym__end_marker,
    STATE(13568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [601218] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [601241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [601264] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13571), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601287] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15579), 1,
      anon_sym_LBRACK,
    ACTIONS(15612), 1,
      anon_sym_match,
    STATE(8844), 1,
      sym_type_arguments,
    STATE(13572), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [601316] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [601339] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [601362] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [601408] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15614), 1,
      anon_sym_catch,
    ACTIONS(15616), 1,
      anon_sym_finally,
    STATE(11850), 1,
      sym_finally_clause,
    STATE(13784), 1,
      sym_catch_clause,
    STATE(13577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [601439] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601462] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15618), 1,
      anon_sym_with,
    STATE(13579), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat2,
    ACTIONS(15451), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15621), 1,
      anon_sym_COMMA,
    STATE(13580), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat1,
    ACTIONS(15446), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601512] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15526), 1,
      anon_sym_catch,
    ACTIONS(15624), 1,
      anon_sym_finally,
    STATE(12249), 1,
      sym_finally_clause,
    STATE(14075), 1,
      sym_catch_clause,
    STATE(13581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [601543] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [601566] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4176), 1,
      anon_sym_COLON,
    ACTIONS(4178), 1,
      sym__backquoted_id,
    STATE(13583), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4174), 8,
      anon_sym_end,
      anon_sym_opaque,
      anon_sym_inline,
      anon_sym_infix,
      anon_sym_open,
      anon_sym_transparent,
      sym__alpha_identifier,
      sym_operator_identifier,
  [601593] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [601616] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [601639] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15626), 1,
      anon_sym_catch,
    ACTIONS(15628), 1,
      anon_sym_finally,
    STATE(14167), 1,
      sym_catch_clause,
    STATE(14239), 1,
      sym_finally_clause,
    STATE(13586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [601670] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [601693] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15579), 1,
      anon_sym_LBRACK,
    STATE(8844), 1,
      sym_type_arguments,
    STATE(13588), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [601720] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [601743] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [601766] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10643), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601789] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [601812] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15630), 1,
      anon_sym_SEMI,
    ACTIONS(15633), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 6,
      sym__automatic_semicolon,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [601841] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15635), 1,
      anon_sym_SEMI,
    ACTIONS(15638), 1,
      anon_sym_else,
    STATE(13594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [601868] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15626), 1,
      anon_sym_catch,
    ACTIONS(15640), 1,
      anon_sym_finally,
    STATE(14240), 1,
      sym_catch_clause,
    STATE(14417), 1,
      sym_finally_clause,
    STATE(13595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [601899] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [601922] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13597), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [601945] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [601968] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15505), 1,
      anon_sym_LBRACK,
    STATE(8442), 1,
      sym_type_arguments,
    STATE(13599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [601995] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [602018] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [602041] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13602), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [602064] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [602087] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [602110] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [602133] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13575), 1,
      anon_sym_LPAREN,
    STATE(14181), 1,
      sym_parameters,
    STATE(14205), 1,
      sym__using_parameters_clause,
    STATE(13606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15275), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [602162] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13607), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [602185] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [602208] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [602231] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12588), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602254] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13611), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [602277] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [602302] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15642), 1,
      anon_sym_STAR,
    STATE(13613), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [602327] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [602350] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12586), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602373] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602396] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(13617), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [602421] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [602444] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13619), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602467] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15513), 1,
      anon_sym_LBRACK,
    ACTIONS(15535), 1,
      anon_sym_match,
    STATE(8708), 1,
      sym_type_arguments,
    STATE(13620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [602496] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(13621), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [602521] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602544] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13623), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [602567] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13624), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [602592] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(13180), 1,
      anon_sym_COLON,
    STATE(14896), 1,
      sym_template_body,
    STATE(14982), 1,
      sym__definition_body,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15112), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [602625] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [602648] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15120), 1,
      anon_sym_finally,
    STATE(13666), 1,
      sym_finally_clause,
    STATE(13627), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
  [602675] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13628), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [602698] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602721] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15644), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602744] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13631), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [602767] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [602790] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12590), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [602836] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [602859] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13636), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [602882] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15507), 1,
      anon_sym_LBRACK,
    STATE(8864), 1,
      sym_type_arguments,
    STATE(13637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [602909] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13638), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602932] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [602955] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(13180), 1,
      anon_sym_COLON,
    ACTIONS(15646), 1,
      sym__automatic_semicolon,
    STATE(14896), 1,
      sym_template_body,
    STATE(15003), 1,
      sym__definition_body,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13640), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15139), 3,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [602990] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13641), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [603013] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [603036] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [603059] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [603082] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15505), 1,
      anon_sym_LBRACK,
    STATE(8442), 1,
      sym_type_arguments,
    STATE(13645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [603109] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [603132] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [603155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14352), 1,
      anon_sym_with,
    STATE(13579), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(13648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15428), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [603182] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14350), 1,
      anon_sym_COMMA,
    STATE(13580), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(13649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15428), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [603209] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15575), 1,
      anon_sym_catch,
    ACTIONS(15649), 1,
      anon_sym_finally,
    STATE(13045), 1,
      sym_finally_clause,
    STATE(14074), 1,
      sym_catch_clause,
    STATE(13650), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [603240] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13651), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [603263] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14179), 1,
      anon_sym_finally,
    STATE(12730), 1,
      sym_finally_clause,
    STATE(13652), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
      anon_sym_yield,
  [603290] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [603313] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13654), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [603336] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [603359] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [603382] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13657), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [603405] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [603428] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [603451] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [603474] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [603497] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13662), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [603520] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13663), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [603543] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13664), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [603566] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [603589] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13666), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [603612] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [603635] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13668), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [603658] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13669), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [603681] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [603704] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [603727] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [603750] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13673), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [603773] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [603796] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [603819] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15579), 1,
      anon_sym_LBRACK,
    ACTIONS(15612), 1,
      anon_sym_match,
    STATE(8844), 1,
      sym_type_arguments,
    STATE(13676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [603848] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [603871] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13678), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_finally,
  [603894] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(13679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [603919] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13680), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [603942] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [603965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [603988] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [604011] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13684), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [604034] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [604057] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15579), 1,
      anon_sym_LBRACK,
    STATE(8844), 1,
      sym_type_arguments,
    STATE(13686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [604084] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [604107] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [604130] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13689), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10715), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [604153] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13690), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 10,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [604176] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [604199] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [604222] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13693), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [604245] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15513), 1,
      anon_sym_LBRACK,
    STATE(8708), 1,
      sym_type_arguments,
    STATE(13694), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [604272] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [604295] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [604320] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13697), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 10,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_POUND,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [604343] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12560), 1,
      anon_sym_LPAREN,
    STATE(14190), 1,
      sym_arguments,
    STATE(13698), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15651), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_SEMI,
  [604370] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13699), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [604393] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7466), 1,
      anon_sym_LBRACK,
    ACTIONS(15653), 1,
      anon_sym_LT_COLON,
    ACTIONS(15655), 1,
      anon_sym_GT_COLON,
    STATE(14098), 1,
      sym_type_parameters,
    STATE(14529), 1,
      sym_upper_bound,
    STATE(14530), 1,
      sym_lower_bound,
    STATE(13700), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15240), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_EQ,
      anon_sym_SEMI,
  [604428] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_else,
  [604451] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [604474] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15258), 1,
      anon_sym_finally,
    STATE(12295), 1,
      sym_finally_clause,
    STATE(13703), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_catch,
  [604501] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(13180), 1,
      anon_sym_COLON,
    ACTIONS(15657), 1,
      sym__automatic_semicolon,
    STATE(14896), 1,
      sym_template_body,
    STATE(15080), 1,
      sym__definition_body,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15196), 3,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [604536] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15581), 1,
      anon_sym_catch,
    ACTIONS(15660), 1,
      anon_sym_finally,
    STATE(14133), 1,
      sym_catch_clause,
    STATE(14417), 1,
      sym_finally_clause,
    STATE(13705), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [604567] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15662), 1,
      anon_sym_SEMI,
    ACTIONS(15665), 1,
      anon_sym_else,
    STATE(13706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_catch,
      anon_sym_finally,
  [604594] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9616), 8,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [604619] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(13180), 1,
      anon_sym_COLON,
    STATE(14896), 1,
      sym_template_body,
    STATE(15069), 1,
      sym__definition_body,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(13708), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15186), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [604652] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13575), 1,
      anon_sym_LPAREN,
    STATE(14181), 1,
      sym_parameters,
    STATE(14205), 1,
      sym__using_parameters_clause,
    STATE(13709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15214), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [604681] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15513), 1,
      anon_sym_LBRACK,
    STATE(8708), 1,
      sym_type_arguments,
    STATE(13710), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 8,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [604708] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13575), 1,
      anon_sym_LPAREN,
    STATE(14181), 1,
      sym_parameters,
    STATE(14205), 1,
      sym__using_parameters_clause,
    STATE(13711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15216), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [604737] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15579), 1,
      anon_sym_LBRACK,
    STATE(8844), 1,
      sym_type_arguments,
    STATE(13712), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [604764] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15667), 1,
      anon_sym_SEMI,
    ACTIONS(15670), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13713), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_catch,
      anon_sym_finally,
  [604793] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15672), 1,
      anon_sym_SEMI,
    ACTIONS(15675), 1,
      anon_sym_else,
    STATE(13714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 8,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_catch,
      anon_sym_finally,
  [604820] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13715), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 10,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [604843] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [604866] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 10,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [604889] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15678), 1,
      anon_sym_LBRACK,
    STATE(9203), 1,
      sym_type_arguments,
    STATE(13718), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [604915] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [604937] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [604959] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 9,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [604981] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13722), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [605003] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [605025] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [605047] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [605069] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13726), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [605091] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [605113] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15680), 1,
      anon_sym_SEMI,
    ACTIONS(15683), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_catch,
      anon_sym_finally,
  [605141] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15685), 1,
      anon_sym_LBRACK,
    STATE(9156), 1,
      sym_type_arguments,
    STATE(13729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [605167] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15279), 1,
      anon_sym_finally,
    STATE(12726), 1,
      sym_finally_clause,
    STATE(13730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [605193] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13731), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [605215] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [605237] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [605259] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [605281] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [605303] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [605325] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [605347] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [605369] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [605391] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [605413] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [605435] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [605457] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15687), 1,
      anon_sym_SEMI,
    ACTIONS(15690), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_catch,
      anon_sym_finally,
  [605485] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13744), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [605507] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [605529] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [605551] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [605573] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15209), 1,
      anon_sym_if,
    STATE(13921), 1,
      aux_sym_enumerator_repeat1,
    STATE(14426), 1,
      sym_guard,
    STATE(13748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15693), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [605601] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [605625] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13750), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [605647] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15695), 1,
      anon_sym_catch,
    ACTIONS(15697), 1,
      anon_sym_finally,
    STATE(13422), 1,
      sym_finally_clause,
    STATE(14295), 1,
      sym_catch_clause,
    STATE(13751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [605677] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15699), 1,
      anon_sym_STAR,
    STATE(13752), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [605701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13753), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [605725] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15701), 1,
      anon_sym_catch,
    ACTIONS(15703), 1,
      anon_sym_finally,
    STATE(13045), 1,
      sym_finally_clause,
    STATE(14322), 1,
      sym_catch_clause,
    STATE(13754), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [605755] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13755), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [605779] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13756), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [605801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13757), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [605823] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13758), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [605845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [605867] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [605889] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [605911] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [605933] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13763), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [605955] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [605977] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15705), 1,
      anon_sym_SEMI,
    ACTIONS(15708), 1,
      anon_sym_else,
    STATE(13765), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [606003] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15711), 1,
      anon_sym_catch,
    ACTIONS(15713), 1,
      anon_sym_finally,
    STATE(13793), 1,
      sym_finally_clause,
    STATE(14127), 1,
      sym_catch_clause,
    STATE(13766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [606033] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15124), 1,
      anon_sym_finally,
    STATE(13097), 1,
      sym_finally_clause,
    STATE(13767), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [606059] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13768), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [606081] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [606103] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [606127] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15685), 1,
      anon_sym_LBRACK,
    ACTIONS(15715), 1,
      anon_sym_match,
    STATE(9156), 1,
      sym_type_arguments,
    STATE(13771), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [606155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15717), 1,
      anon_sym_LBRACK,
    STATE(9004), 1,
      sym_type_arguments,
    STATE(13772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [606181] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15717), 1,
      anon_sym_LBRACK,
    STATE(9004), 1,
      sym_type_arguments,
    STATE(13773), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [606207] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [606229] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13775), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_finally,
  [606251] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13776), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [606273] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15164), 1,
      anon_sym_finally,
    STATE(12309), 1,
      sym_finally_clause,
    STATE(13777), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [606299] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15242), 1,
      anon_sym_LT_COLON,
    ACTIONS(15244), 1,
      anon_sym_GT_COLON,
    STATE(14355), 1,
      sym_lower_bound,
    STATE(14464), 1,
      sym_upper_bound,
    STATE(13778), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15719), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [606329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13779), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15721), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
  [606351] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15723), 1,
      anon_sym_SEMI,
    ACTIONS(15726), 1,
      anon_sym_else,
    STATE(13780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 7,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [606377] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15728), 1,
      anon_sym_SEMI,
    ACTIONS(15731), 1,
      anon_sym_else,
    STATE(13781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [606403] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15733), 1,
      anon_sym_SEMI,
    ACTIONS(15736), 1,
      anon_sym_else,
    STATE(13782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_finally,
  [606429] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [606451] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15616), 1,
      anon_sym_finally,
    STATE(11889), 1,
      sym_finally_clause,
    STATE(13784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
  [606477] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15738), 1,
      anon_sym_SEMI,
    ACTIONS(15741), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      sym__automatic_semicolon,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [606505] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15744), 1,
      anon_sym_SEMI,
    ACTIONS(15747), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_finally,
  [606533] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15749), 1,
      anon_sym_SEMI,
    ACTIONS(15752), 1,
      anon_sym_else,
    STATE(13787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_finally,
  [606559] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15757), 1,
      anon_sym_COMMA,
    STATE(13886), 1,
      aux_sym_derives_clause_repeat1,
    STATE(13788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15755), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [606585] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15759), 1,
      anon_sym_DOT,
    STATE(13789), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [606609] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [606631] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15761), 1,
      anon_sym_SEMI,
    ACTIONS(15764), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13791), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
  [606659] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15767), 1,
      anon_sym_SEMI,
    ACTIONS(15770), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13792), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_finally,
  [606687] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [606709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13794), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [606731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13795), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13254), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [606753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13796), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 9,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [606775] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [606797] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [606819] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [606841] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13800), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [606863] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [606885] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13802), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [606907] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15166), 1,
      anon_sym_finally,
    STATE(13428), 1,
      sym_finally_clause,
    STATE(13803), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
  [606933] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13174), 1,
      anon_sym_match,
    ACTIONS(15717), 1,
      anon_sym_LBRACK,
    STATE(9004), 1,
      sym_type_arguments,
    STATE(13804), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [606961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15773), 1,
      anon_sym_with,
    STATE(13805), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [606985] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13806), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [607007] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13807), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [607029] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15490), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607051] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13809), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14215), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13810), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [607095] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13811), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [607119] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15026), 1,
      anon_sym_finally,
    STATE(13734), 1,
      sym_finally_clause,
    STATE(13812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
  [607145] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13813), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [607167] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15066), 1,
      anon_sym_finally,
    STATE(13981), 1,
      sym_finally_clause,
    STATE(13814), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [607193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15776), 1,
      anon_sym_with,
    STATE(13815), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607217] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13256), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [607239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15678), 1,
      anon_sym_LBRACK,
    STATE(9203), 1,
      sym_type_arguments,
    STATE(13817), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [607265] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13818), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [607287] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15779), 1,
      anon_sym_catch,
    ACTIONS(15781), 1,
      anon_sym_finally,
    STATE(13422), 1,
      sym_finally_clause,
    STATE(14414), 1,
      sym_catch_clause,
    STATE(13819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [607317] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12574), 1,
      anon_sym_LPAREN,
    STATE(14392), 1,
      sym_arguments,
    STATE(13820), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15651), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_SEMI,
  [607343] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13821), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [607365] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [607387] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13823), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15605), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607409] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15695), 1,
      anon_sym_catch,
    ACTIONS(15783), 1,
      anon_sym_finally,
    STATE(13949), 1,
      sym_finally_clause,
    STATE(14307), 1,
      sym_catch_clause,
    STATE(13824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [607439] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13825), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [607461] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15785), 1,
      anon_sym_SEMI,
    ACTIONS(15788), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_catch,
      anon_sym_finally,
  [607489] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13827), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15515), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607511] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15717), 1,
      anon_sym_LBRACK,
    STATE(9004), 1,
      sym_type_arguments,
    STATE(13828), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [607537] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13829), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [607561] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15184), 1,
      anon_sym_finally,
    STATE(12730), 1,
      sym_finally_clause,
    STATE(13830), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [607587] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15678), 1,
      anon_sym_LBRACK,
    ACTIONS(15790), 1,
      anon_sym_match,
    STATE(9203), 1,
      sym_type_arguments,
    STATE(13831), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_finally,
  [607615] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [607639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12582), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607661] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15792), 1,
      anon_sym_SEMI,
    ACTIONS(15794), 1,
      anon_sym_else,
    STATE(13834), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
  [607687] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13835), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [607709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13836), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [607731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13837), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13256), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [607753] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15796), 1,
      anon_sym_SEMI,
    ACTIONS(15799), 1,
      anon_sym_else,
    STATE(13838), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [607779] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13254), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [607801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [607823] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15337), 1,
      anon_sym_LT_COLON,
    ACTIONS(15339), 1,
      anon_sym_GT_COLON,
    STATE(14427), 1,
      sym_lower_bound,
    STATE(14648), 1,
      sym_upper_bound,
    STATE(13841), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15719), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [607853] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13842), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15601), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [607875] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [607897] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [607919] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [607941] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13846), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [607963] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [607985] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [608007] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [608029] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15678), 1,
      anon_sym_LBRACK,
    STATE(9203), 1,
      sym_type_arguments,
    STATE(13850), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [608055] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15596), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608077] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [608099] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13853), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [608121] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15522), 1,
      anon_sym_finally,
    STATE(13845), 1,
      sym_finally_clause,
    STATE(13854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
  [608147] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13855), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [608169] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13856), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [608191] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [608213] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [608235] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [608257] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13860), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11685), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [608279] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13861), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13256), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [608301] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13862), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [608323] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [608345] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13864), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608367] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [608389] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13866), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608411] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13867), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13254), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [608433] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13868), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [608455] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13869), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7880), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [608477] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13870), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [608499] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13871), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [608521] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13872), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [608543] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13538), 1,
      anon_sym_LPAREN,
    STATE(13943), 1,
      aux_sym_annotation_repeat1,
    STATE(14381), 1,
      sym_arguments,
    STATE(13873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
  [608571] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13874), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11623), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [608593] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13875), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608615] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13876), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [608637] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [608659] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13878), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [608681] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15802), 1,
      anon_sym_SEMI,
    ACTIONS(15805), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      sym__automatic_semicolon,
      anon_sym_if,
      anon_sym_finally,
      anon_sym_do,
      anon_sym_yield,
  [608709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [608731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13881), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [608753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13882), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [608775] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13883), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [608797] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13884), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [608819] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(13885), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [608843] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15757), 1,
      anon_sym_COMMA,
    STATE(14039), 1,
      aux_sym_derives_clause_repeat1,
    STATE(13886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15807), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [608869] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13887), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [608891] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13888), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15608), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608913] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13889), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12647), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [608935] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [608957] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13891), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [608979] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13892), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [609001] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [609023] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15685), 1,
      anon_sym_LBRACK,
    STATE(9156), 1,
      sym_type_arguments,
    STATE(13894), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [609049] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [609071] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [609093] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13897), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10715), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609115] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13898), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13899), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [609159] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13900), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15809), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609181] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [609203] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13902), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [609225] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15266), 1,
      anon_sym_finally,
    STATE(14099), 1,
      sym_finally_clause,
    STATE(13903), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [609251] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13904), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [609273] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13905), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [609295] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(13906), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [609319] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13907), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [609341] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13908), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [609363] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13909), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13910), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [609407] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13911), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9417), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [609429] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13912), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [609451] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13913), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [609473] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13914), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15644), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609495] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13915), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11707), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [609517] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15717), 1,
      anon_sym_LBRACK,
    STATE(9004), 1,
      sym_type_arguments,
    STATE(13916), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [609543] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13917), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [609567] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15811), 1,
      anon_sym_SEMI,
    ACTIONS(15813), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
  [609595] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13919), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609617] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13920), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [609639] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15817), 1,
      anon_sym_if,
    STATE(14426), 1,
      sym_guard,
    STATE(13921), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enumerator_repeat1,
    ACTIONS(15815), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [609665] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13922), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [609687] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13923), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [609709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13924), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [609731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [609753] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13926), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [609775] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13927), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [609799] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15717), 1,
      anon_sym_LBRACK,
    STATE(9004), 1,
      sym_type_arguments,
    STATE(13928), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [609825] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13929), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [609847] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13930), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609869] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13931), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15588), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609891] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13932), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609913] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15678), 1,
      anon_sym_LBRACK,
    STATE(9203), 1,
      sym_type_arguments,
    STATE(13933), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [609939] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15678), 1,
      anon_sym_LBRACK,
    STATE(9203), 1,
      sym_type_arguments,
    STATE(13934), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [609965] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13935), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [609987] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13936), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [610009] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13937), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11689), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [610031] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [610053] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15022), 1,
      anon_sym_finally,
    STATE(14099), 1,
      sym_finally_clause,
    STATE(13939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [610079] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13940), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [610101] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13941), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [610123] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15548), 1,
      anon_sym_finally,
    STATE(12295), 1,
      sym_finally_clause,
    STATE(13942), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
  [610149] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15820), 1,
      anon_sym_LPAREN,
    STATE(14381), 1,
      sym_arguments,
    STATE(13943), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
  [610175] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13944), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [610197] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13945), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [610219] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13946), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9413), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [610241] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15685), 1,
      anon_sym_LBRACK,
    STATE(9156), 1,
      sym_type_arguments,
    STATE(13947), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [610267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13948), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15603), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610289] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13949), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [610311] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13336), 1,
      anon_sym_DOT,
    STATE(13950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [610335] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15823), 1,
      anon_sym_catch,
    ACTIONS(15825), 1,
      anon_sym_finally,
    STATE(14386), 1,
      sym_finally_clause,
    STATE(14422), 1,
      sym_catch_clause,
    STATE(13951), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [610365] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [610389] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13953), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [610411] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13174), 1,
      anon_sym_match,
    ACTIONS(15717), 1,
      anon_sym_LBRACK,
    STATE(9004), 1,
      sym_type_arguments,
    STATE(13954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_finally,
  [610439] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610461] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13956), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9409), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [610483] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13957), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12592), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610505] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13958), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [610527] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13959), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15599), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610549] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13960), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [610571] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13961), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [610593] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13962), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [610615] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13963), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12605), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610637] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13964), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14167), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610659] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13965), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [610681] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15827), 1,
      anon_sym_catch,
    ACTIONS(15829), 1,
      anon_sym_finally,
    STATE(13164), 1,
      sym_finally_clause,
    STATE(14234), 1,
      sym_catch_clause,
    STATE(13966), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [610711] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15685), 1,
      anon_sym_LBRACK,
    ACTIONS(15715), 1,
      anon_sym_match,
    STATE(9156), 1,
      sym_type_arguments,
    STATE(13967), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [610739] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12594), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [610761] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [610783] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15823), 1,
      anon_sym_catch,
    ACTIONS(15831), 1,
      anon_sym_finally,
    STATE(14151), 1,
      sym_finally_clause,
    STATE(14403), 1,
      sym_catch_clause,
    STATE(13970), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [610813] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15833), 1,
      anon_sym_catch,
    ACTIONS(15835), 1,
      anon_sym_finally,
    STATE(12407), 1,
      sym_finally_clause,
    STATE(14257), 1,
      sym_catch_clause,
    STATE(13971), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [610843] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13972), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_else,
  [610865] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15837), 1,
      anon_sym_SEMI,
    ACTIONS(15840), 1,
      anon_sym_else,
    STATE(13973), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [610891] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13974), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [610913] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15842), 1,
      anon_sym_LBRACK,
    STATE(9560), 1,
      sym_type_arguments,
    STATE(13975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [610939] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15844), 1,
      anon_sym_SEMI,
    ACTIONS(15847), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
  [610967] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15849), 1,
      anon_sym_SEMI,
    ACTIONS(15852), 1,
      anon_sym_else,
    STATE(13977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [610993] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13978), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [611015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(13979), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [611039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [611063] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [611085] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [611107] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13983), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611129] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15842), 1,
      anon_sym_LBRACK,
    ACTIONS(15855), 1,
      anon_sym_match,
    STATE(9560), 1,
      sym_type_arguments,
    STATE(13984), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
  [611157] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13985), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12649), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611179] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13986), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [611201] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13987), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611223] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13988), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [611245] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13989), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15552), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13990), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [611289] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13991), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15555), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611311] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13992), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [611333] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13993), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [611355] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13994), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    STATE(13995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [611401] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12578), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611423] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15585), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611445] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15857), 1,
      anon_sym_SEMI,
    ACTIONS(15860), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(13998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_catch,
      anon_sym_finally,
  [611473] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13999), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611495] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14000), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10643), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611517] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15863), 1,
      anon_sym_SEMI,
    ACTIONS(15866), 1,
      anon_sym_else,
    STATE(14001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [611543] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15573), 1,
      anon_sym_finally,
    STATE(13845), 1,
      sym_finally_clause,
    STATE(14002), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
  [611569] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15518), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_extends,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611591] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14004), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11701), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [611613] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15137), 1,
      anon_sym_finally,
    STATE(13981), 1,
      sym_finally_clause,
    STATE(14005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [611639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14006), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [611661] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14007), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [611683] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15314), 1,
      anon_sym_finally,
    STATE(12726), 1,
      sym_finally_clause,
    STATE(14008), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [611709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14009), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [611731] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15626), 1,
      anon_sym_catch,
    ACTIONS(15868), 1,
      anon_sym_finally,
    STATE(14402), 1,
      sym_catch_clause,
    STATE(14417), 1,
      sym_finally_clause,
    STATE(14010), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [611761] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15678), 1,
      anon_sym_LBRACK,
    ACTIONS(15790), 1,
      anon_sym_match,
    STATE(9203), 1,
      sym_type_arguments,
    STATE(14011), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_finally,
  [611789] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14012), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [611813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14013), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [611835] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14014), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11817), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [611857] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14015), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_POUND,
  [611879] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14016), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 9,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [611901] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15870), 1,
      anon_sym_end,
    STATE(9932), 1,
      sym__end_marker,
    STATE(14017), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [611927] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14018), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11739), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [611949] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15192), 1,
      anon_sym_finally,
    STATE(13097), 1,
      sym_finally_clause,
    STATE(14019), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [611975] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15872), 1,
      anon_sym_end,
    STATE(9779), 1,
      sym__end_marker,
    STATE(14020), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9451), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [612001] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15685), 1,
      anon_sym_LBRACK,
    STATE(9156), 1,
      sym_type_arguments,
    STATE(14021), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [612027] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14022), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [612049] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15842), 1,
      anon_sym_LBRACK,
    STATE(9560), 1,
      sym_type_arguments,
    STATE(14023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [612075] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15779), 1,
      anon_sym_catch,
    ACTIONS(15874), 1,
      anon_sym_finally,
    STATE(13949), 1,
      sym_finally_clause,
    STATE(14372), 1,
      sym_catch_clause,
    STATE(14024), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [612105] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7462), 1,
      anon_sym_LBRACE,
    ACTIONS(15012), 1,
      anon_sym_COLON,
    STATE(14731), 1,
      aux_sym_compound_type_repeat1,
    STATE(16648), 1,
      sym__refinement,
    STATE(16668), 1,
      sym_template_body,
    ACTIONS(7778), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(14025), 2,
      sym_comment,
      sym_block_comment,
    STATE(16682), 2,
      sym__indented_template_body,
      sym__braced_template_body,
  [612139] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15685), 1,
      anon_sym_LBRACK,
    STATE(9156), 1,
      sym_type_arguments,
    STATE(14026), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 7,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [612165] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15876), 1,
      anon_sym_STAR,
    STATE(14027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [612189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11789), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [612211] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15878), 1,
      anon_sym_catch,
    ACTIONS(15880), 1,
      anon_sym_finally,
    STATE(13164), 1,
      sym_finally_clause,
    STATE(14272), 1,
      sym_catch_clause,
    STATE(14029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [612241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_then,
      anon_sym_do,
  [612263] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15575), 1,
      anon_sym_catch,
    ACTIONS(15882), 1,
      anon_sym_finally,
    STATE(13045), 1,
      sym_finally_clause,
    STATE(14384), 1,
      sym_catch_clause,
    STATE(14031), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [612293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14032), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [612315] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15842), 1,
      anon_sym_LBRACK,
    ACTIONS(15855), 1,
      anon_sym_match,
    STATE(9560), 1,
      sym_type_arguments,
    STATE(14033), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
  [612343] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14034), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12598), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [612365] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12596), 9,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [612387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7564), 1,
      anon_sym_DOT,
    STATE(14036), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [612411] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13536), 1,
      anon_sym_AT,
    STATE(14045), 1,
      aux_sym_enum_definition_repeat1,
    STATE(14306), 1,
      sym_annotation,
    STATE(14037), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [612439] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [612461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15886), 1,
      anon_sym_COMMA,
    STATE(14039), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_derives_clause_repeat1,
    ACTIONS(15884), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [612485] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15889), 1,
      anon_sym_STAR,
    STATE(14040), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [612509] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14041), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [612531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [612553] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15701), 1,
      anon_sym_catch,
    ACTIONS(15891), 1,
      anon_sym_finally,
    STATE(12875), 1,
      sym_finally_clause,
    STATE(14401), 1,
      sym_catch_clause,
    STATE(14043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [612583] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14044), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11723), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [612605] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15893), 1,
      anon_sym_AT,
    STATE(14306), 1,
      sym_annotation,
    STATE(14045), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [612631] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15896), 1,
      anon_sym_SEMI,
    ACTIONS(15899), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
      anon_sym_catch,
      anon_sym_finally,
  [612659] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14047), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 9,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [612681] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15902), 1,
      anon_sym_SEMI,
    ACTIONS(15905), 1,
      anon_sym_else,
    STATE(14048), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [612707] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15842), 1,
      anon_sym_LBRACK,
    STATE(9560), 1,
      sym_type_arguments,
    STATE(14049), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [612733] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15842), 1,
      anon_sym_LBRACK,
    STATE(9560), 1,
      sym_type_arguments,
    STATE(14050), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [612759] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [612781] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15908), 1,
      anon_sym_SEMI,
    ACTIONS(15911), 1,
      anon_sym_else,
    STATE(14052), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
      anon_sym_finally,
  [612807] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 9,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [612829] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14054), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 9,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [612851] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
  [612874] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15914), 1,
      anon_sym_SEMI,
    ACTIONS(15917), 1,
      anon_sym_else,
    STATE(14056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
  [612899] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7832), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [612920] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14058), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7576), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [612941] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15920), 1,
      anon_sym_LBRACK,
    STATE(9636), 1,
      sym_type_arguments,
    STATE(14059), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [612966] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(14556), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14803), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(15922), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14060), 2,
      sym_comment,
      sym_block_comment,
  [612999] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15924), 1,
      anon_sym_SEMI,
    ACTIONS(15927), 1,
      anon_sym_else,
    STATE(14061), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
  [613024] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14062), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7982), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [613045] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15528), 1,
      anon_sym_finally,
    STATE(12730), 1,
      sym_finally_clause,
    STATE(14063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [613070] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14064), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7898), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [613091] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15930), 1,
      anon_sym_SEMI,
    ACTIONS(15933), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14065), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
      anon_sym_finally,
  [613118] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [613139] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15935), 1,
      anon_sym_SEMI,
    ACTIONS(15938), 1,
      anon_sym_else,
    STATE(14067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_finally,
  [613164] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15940), 1,
      anon_sym_COMMA,
    ACTIONS(15942), 1,
      anon_sym_with,
    STATE(14338), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14474), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14068), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13723), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [613193] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [613214] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15944), 1,
      anon_sym_LBRACK,
    STATE(9861), 1,
      sym_type_arguments,
    STATE(14070), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [613239] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14770), 1,
      anon_sym_AT,
    STATE(14121), 1,
      aux_sym_enum_definition_repeat1,
    STATE(14594), 1,
      sym_annotation,
    STATE(14071), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8487), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
  [613266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15946), 1,
      anon_sym_COLON,
    STATE(14072), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15948), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [613289] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14073), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [613310] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15649), 1,
      anon_sym_finally,
    STATE(13097), 1,
      sym_finally_clause,
    STATE(14074), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [613335] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15624), 1,
      anon_sym_finally,
    STATE(12309), 1,
      sym_finally_clause,
    STATE(14075), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [613360] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14076), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7892), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [613381] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14243), 1,
      anon_sym_LPAREN,
    ACTIONS(15950), 1,
      anon_sym_extends,
    ACTIONS(15954), 1,
      sym__automatic_semicolon,
    STATE(14304), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14677), 1,
      sym_class_parameters,
    STATE(15728), 1,
      sym_extends_clause,
    ACTIONS(15952), 2,
      sym__outdent,
      anon_sym_SEMI,
    STATE(14077), 2,
      sym_comment,
      sym_block_comment,
  [613414] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14685), 1,
      anon_sym_LPAREN,
    ACTIONS(15959), 1,
      anon_sym_extends,
    ACTIONS(15961), 1,
      sym__automatic_semicolon,
    STATE(14327), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14665), 1,
      sym_class_parameters,
    STATE(15677), 1,
      sym_extends_clause,
    ACTIONS(15957), 2,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(14078), 2,
      sym_comment,
      sym_block_comment,
  [613447] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(12545), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14532), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [613476] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12605), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [613497] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14081), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [613518] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15964), 1,
      anon_sym_SEMI,
    ACTIONS(15967), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14082), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_finally,
  [613545] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14083), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [613566] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14084), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [613587] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15969), 1,
      anon_sym_SEMI,
    ACTIONS(15972), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14085), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
      anon_sym_finally,
  [613614] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14086), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15975), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [613635] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14087), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [613656] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15977), 1,
      anon_sym_SEMI,
    ACTIONS(15980), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14088), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_finally,
  [613683] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [613704] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12594), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [613725] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14091), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [613746] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(14136), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14703), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(15524), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14092), 2,
      sym_comment,
      sym_block_comment,
  [613779] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15983), 1,
      anon_sym_SEMI,
    ACTIONS(15986), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14093), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_finally,
  [613806] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14094), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [613827] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    ACTIONS(15990), 1,
      anon_sym_match,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(14095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
  [613854] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(14556), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14703), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(15524), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14096), 2,
      sym_comment,
      sym_block_comment,
  [613887] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14097), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [613908] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15653), 1,
      anon_sym_LT_COLON,
    ACTIONS(15655), 1,
      anon_sym_GT_COLON,
    STATE(14463), 1,
      sym_lower_bound,
    STATE(14464), 1,
      sym_upper_bound,
    STATE(14098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15719), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_EQ,
      anon_sym_SEMI,
  [613937] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14099), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [613958] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    ACTIONS(15182), 1,
      anon_sym_match,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(14664), 1,
      aux_sym__block_repeat1,
    ACTIONS(15992), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(15994), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14100), 2,
      sym_comment,
      sym_block_comment,
  [613989] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15996), 1,
      anon_sym_SEMI,
    ACTIONS(15999), 1,
      anon_sym_else,
    STATE(14101), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
  [614014] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14102), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [614035] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [614056] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14104), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12592), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [614077] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [614098] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    ACTIONS(15990), 1,
      anon_sym_match,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(14744), 1,
      aux_sym__block_repeat1,
    ACTIONS(15992), 2,
      sym__outdent,
      anon_sym_case,
    ACTIONS(16001), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14106), 2,
      sym_comment,
      sym_block_comment,
  [614129] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [614150] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [614171] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14109), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [614192] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [614213] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(14556), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14705), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(16003), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14111), 2,
      sym_comment,
      sym_block_comment,
  [614246] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14112), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [614267] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(16005), 1,
      sym__automatic_semicolon,
    STATE(12531), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14113), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14466), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [614298] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14114), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [614319] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15583), 1,
      anon_sym_finally,
    STATE(14182), 1,
      sym_finally_clause,
    STATE(14115), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [614344] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14116), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [614367] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14117), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7796), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [614388] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(14132), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14705), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(16003), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14118), 2,
      sym_comment,
      sym_block_comment,
  [614421] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7912), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [614442] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16007), 1,
      anon_sym_SEMI,
    ACTIONS(16010), 1,
      anon_sym_else,
    STATE(14120), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
  [614467] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16013), 1,
      anon_sym_AT,
    STATE(14594), 1,
      sym_annotation,
    STATE(14121), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_definition_repeat1,
    ACTIONS(8603), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
  [614492] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15809), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [614513] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16016), 1,
      anon_sym_COMMA,
    STATE(14123), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_derives_clause_repeat1,
    ACTIONS(15884), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [614536] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14124), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12596), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [614557] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14125), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_finally,
  [614580] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15944), 1,
      anon_sym_LBRACK,
    STATE(9861), 1,
      sym_type_arguments,
    STATE(14126), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [614605] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15713), 1,
      anon_sym_finally,
    STATE(13878), 1,
      sym_finally_clause,
    STATE(14127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 6,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_catch,
  [614630] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15944), 1,
      anon_sym_LBRACK,
    STATE(9861), 1,
      sym_type_arguments,
    STATE(14128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [614655] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16019), 1,
      anon_sym_SEMI,
    ACTIONS(16022), 1,
      anon_sym_else,
    STATE(14129), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_do,
      anon_sym_yield,
  [614680] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14130), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12598), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [614701] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(12545), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14269), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [614730] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(14556), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14777), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(16024), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14132), 2,
      sym_comment,
      sym_block_comment,
  [614763] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15660), 1,
      anon_sym_finally,
    STATE(14276), 1,
      sym_finally_clause,
    STATE(14133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [614788] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(14060), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14771), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(16026), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14134), 2,
      sym_comment,
      sym_block_comment,
  [614821] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14135), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [614844] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(14556), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14771), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(16026), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14136), 2,
      sym_comment,
      sym_block_comment,
  [614877] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14137), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [614898] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16028), 1,
      anon_sym_LPAREN,
    STATE(14554), 1,
      sym_arguments,
    STATE(14138), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_annotation_repeat1,
    ACTIONS(8114), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
  [614923] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13773), 1,
      anon_sym_match,
    ACTIONS(15944), 1,
      anon_sym_LBRACK,
    STATE(9861), 1,
      sym_type_arguments,
    STATE(14139), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [614950] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14140), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13254), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [614971] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [614992] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(12545), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14142), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14274), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [615021] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14143), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [615042] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16033), 1,
      anon_sym_DOT,
    STATE(14264), 1,
      aux_sym_package_identifier_repeat1,
    STATE(14144), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16031), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [615067] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14178), 1,
      aux_sym__class_constructor_repeat1,
    STATE(14145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14283), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [615096] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16035), 1,
      anon_sym_COMMA,
    STATE(14123), 1,
      aux_sym_derives_clause_repeat1,
    STATE(14146), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15807), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [615121] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14147), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [615142] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16037), 1,
      anon_sym_SEMI,
    ACTIONS(16040), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14148), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      sym__automatic_semicolon,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
  [615169] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14149), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [615190] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(12970), 1,
      anon_sym_COLON,
    STATE(15240), 1,
      sym_template_body,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(14150), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16043), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [615219] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [615240] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16047), 1,
      anon_sym_DOT,
    STATE(14144), 1,
      aux_sym_package_identifier_repeat1,
    STATE(14152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16045), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [615265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15920), 1,
      anon_sym_LBRACK,
    STATE(9636), 1,
      sym_type_arguments,
    STATE(14153), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [615290] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
  [615313] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14155), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7870), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [615334] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14156), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [615355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14157), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [615380] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16051), 1,
      anon_sym_SEMI,
    ACTIONS(16054), 1,
      anon_sym_else,
    STATE(14158), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
  [615405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14159), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_else,
  [615428] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14243), 1,
      anon_sym_LPAREN,
    ACTIONS(15950), 1,
      anon_sym_extends,
    ACTIONS(16057), 1,
      sym__automatic_semicolon,
    STATE(14304), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14677), 1,
      sym_class_parameters,
    STATE(15730), 1,
      sym_extends_clause,
    ACTIONS(15957), 2,
      sym__outdent,
      anon_sym_SEMI,
    STATE(14160), 2,
      sym_comment,
      sym_block_comment,
  [615461] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14161), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [615486] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14162), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [615507] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16060), 1,
      anon_sym_with,
    STATE(14396), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14482), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14163), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13723), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [615534] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16062), 1,
      anon_sym_SEMI,
    ACTIONS(16065), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14164), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
  [615561] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16068), 1,
      anon_sym_SEMI,
    ACTIONS(16071), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14165), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_finally,
  [615588] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14166), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [615613] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15628), 1,
      anon_sym_finally,
    STATE(14182), 1,
      sym_finally_clause,
    STATE(14167), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [615638] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14168), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [615659] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16074), 1,
      anon_sym_SEMI,
    ACTIONS(16077), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14169), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
  [615686] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15577), 1,
      anon_sym_finally,
    STATE(12726), 1,
      sym_finally_clause,
    STATE(14170), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [615711] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14685), 1,
      anon_sym_LPAREN,
    ACTIONS(15959), 1,
      anon_sym_extends,
    ACTIONS(16079), 1,
      sym__automatic_semicolon,
    STATE(14327), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14665), 1,
      sym_class_parameters,
    STATE(15656), 1,
      sym_extends_clause,
    ACTIONS(15952), 2,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(14171), 2,
      sym_comment,
      sym_block_comment,
  [615744] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15944), 1,
      anon_sym_LBRACK,
    STATE(9861), 1,
      sym_type_arguments,
    STATE(14172), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [615769] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14173), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [615790] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(14174), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [615815] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(14175), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [615840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14176), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [615861] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14177), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [615882] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(12545), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14178), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14100), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [615911] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [615932] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13921), 1,
      anon_sym_match,
    ACTIONS(15920), 1,
      anon_sym_LBRACK,
    STATE(9636), 1,
      sym_type_arguments,
    STATE(14180), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [615959] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14181), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14167), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [615980] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14182), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [616001] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14183), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [616022] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(12545), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14184), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14669), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [616051] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14185), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13256), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [616072] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16082), 1,
      anon_sym_SEMI,
    ACTIONS(16085), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_catch,
      anon_sym_finally,
  [616099] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14187), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [616120] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14188), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [616141] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14227), 1,
      aux_sym__class_constructor_repeat1,
    STATE(14189), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12811), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [616170] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14190), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16088), 8,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_SEMI,
  [616191] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15920), 1,
      anon_sym_LBRACK,
    STATE(9636), 1,
      sym_type_arguments,
    STATE(14191), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [616216] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14192), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7824), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [616237] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14193), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [616260] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16090), 1,
      anon_sym_STAR,
    STATE(14194), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [616283] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14195), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12582), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [616304] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16092), 1,
      anon_sym_SEMI,
    ACTIONS(16095), 1,
      anon_sym_else,
    STATE(14196), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
  [616329] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(14556), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14698), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(15533), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14197), 2,
      sym_comment,
      sym_block_comment,
  [616362] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 5,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [616389] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14199), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12649), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [616410] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14200), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [616431] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16099), 1,
      anon_sym_SEMI,
    ACTIONS(16101), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14201), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
  [616458] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15944), 1,
      anon_sym_LBRACK,
    STATE(9861), 1,
      sym_type_arguments,
    STATE(14202), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [616483] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14203), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [616504] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(14204), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [616529] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14205), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12647), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [616550] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16103), 1,
      anon_sym_SEMI,
    ACTIONS(16106), 1,
      anon_sym_else,
    STATE(14206), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
  [616575] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14207), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [616596] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14208), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [616617] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14209), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [616638] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16035), 1,
      anon_sym_COMMA,
    STATE(14146), 1,
      aux_sym_derives_clause_repeat1,
    STATE(14210), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15755), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [616663] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14211), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [616684] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14212), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [616705] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14213), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [616726] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14214), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [616747] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    ACTIONS(13234), 1,
      anon_sym_LT_PERCENT,
    STATE(14111), 1,
      aux_sym__type_parameter_repeat1,
    STATE(14698), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15110), 1,
      sym_view_bound,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(15533), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14215), 2,
      sym_comment,
      sym_block_comment,
  [616780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14216), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [616801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16108), 1,
      anon_sym_DOT,
    STATE(14217), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [616824] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14218), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [616845] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14219), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 6,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [616870] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15920), 1,
      anon_sym_LBRACK,
    STATE(9636), 1,
      sym_type_arguments,
    STATE(14220), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [616895] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14221), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [616916] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16110), 1,
      anon_sym_SEMI,
    ACTIONS(16112), 1,
      anon_sym_else,
    STATE(14222), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
  [616941] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14223), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [616962] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    STATE(14224), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [616985] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14142), 1,
      aux_sym__class_constructor_repeat1,
    STATE(14225), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12865), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [617014] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14131), 1,
      aux_sym__class_constructor_repeat1,
    STATE(14226), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14521), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [617043] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12383), 1,
      anon_sym_LPAREN,
    ACTIONS(13035), 1,
      sym__automatic_semicolon,
    STATE(12545), 1,
      aux_sym__class_constructor_repeat1,
    STATE(13630), 1,
      sym_class_parameters,
    STATE(14227), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14516), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_derives,
  [617072] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14228), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7556), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [617093] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14229), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [617114] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9616), 1,
      anon_sym_COLON,
    STATE(14230), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [617137] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16116), 1,
      anon_sym_SEMI,
    ACTIONS(16119), 1,
      anon_sym_else,
    STATE(14231), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
  [617162] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16122), 1,
      anon_sym_COMMA,
    ACTIONS(16124), 1,
      anon_sym_with,
    STATE(14512), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14517), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14232), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13723), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
      anon_sym_LPAREN,
  [617191] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15920), 1,
      anon_sym_LBRACK,
    STATE(9636), 1,
      sym_type_arguments,
    STATE(14233), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [617216] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15829), 1,
      anon_sym_finally,
    STATE(13136), 1,
      sym_finally_clause,
    STATE(14234), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 6,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
      anon_sym_do,
  [617241] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16126), 1,
      anon_sym_SEMI,
    ACTIONS(16129), 1,
      anon_sym_else,
    STATE(14235), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [617266] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14236), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [617287] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14237), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [617308] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14238), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_EQ,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [617329] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [617350] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15640), 1,
      anon_sym_finally,
    STATE(14276), 1,
      sym_finally_clause,
    STATE(14240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [617375] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    ACTIONS(15990), 1,
      anon_sym_match,
    ACTIONS(16132), 1,
      anon_sym_if,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(15724), 1,
      sym_guard,
    STATE(14241), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15270), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [617406] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14242), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7800), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [617427] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16134), 1,
      anon_sym_SEMI,
    ACTIONS(16137), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14243), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_catch,
      anon_sym_finally,
  [617454] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16139), 1,
      anon_sym_SEMI,
    ACTIONS(16142), 1,
      anon_sym_else,
    STATE(14244), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [617479] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16060), 1,
      anon_sym_with,
    ACTIONS(16144), 1,
      anon_sym_COMMA,
    STATE(14396), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14447), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14245), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13723), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [617508] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16146), 1,
      anon_sym_SEMI,
    ACTIONS(16149), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14246), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
  [617535] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16152), 1,
      anon_sym_SEMI,
    ACTIONS(16155), 1,
      anon_sym_else,
    STATE(14247), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_RPAREN,
  [617560] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(16158), 1,
      sym__automatic_semicolon,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14113), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14248), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14064), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [617591] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(16160), 1,
      sym__automatic_semicolon,
    STATE(12531), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14249), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14060), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [617622] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14250), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [617643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16162), 1,
      anon_sym_as,
    STATE(14251), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15721), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
  [617666] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14252), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [617687] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    STATE(14138), 1,
      aux_sym_annotation_repeat1,
    STATE(14554), 1,
      sym_arguments,
    STATE(14253), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8123), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
  [617714] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14254), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [617735] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13773), 1,
      anon_sym_match,
    ACTIONS(15944), 1,
      anon_sym_LBRACK,
    STATE(9861), 1,
      sym_type_arguments,
    STATE(14255), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_catch,
      anon_sym_finally,
  [617762] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13921), 1,
      anon_sym_match,
    ACTIONS(15920), 1,
      anon_sym_LBRACK,
    STATE(9636), 1,
      sym_type_arguments,
    STATE(14256), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_finally,
  [617789] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15835), 1,
      anon_sym_finally,
    STATE(12295), 1,
      sym_finally_clause,
    STATE(14257), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_catch,
  [617814] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    ACTIONS(15990), 1,
      anon_sym_match,
    ACTIONS(16132), 1,
      anon_sym_if,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(15704), 1,
      sym_guard,
    STATE(14258), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15207), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [617845] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    ACTIONS(15990), 1,
      anon_sym_match,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(14259), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
  [617872] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15942), 1,
      anon_sym_with,
    STATE(14338), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14576), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14260), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13723), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [617899] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14261), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12578), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [617920] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14262), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13254), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [617941] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14263), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13256), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [617962] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16164), 1,
      anon_sym_DOT,
    STATE(14264), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_package_identifier_repeat1,
    ACTIONS(15721), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [617985] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14265), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 8,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [618006] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14266), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [618027] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14267), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_finally,
  [618050] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14268), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 5,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [618077] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16167), 1,
      anon_sym_SEMI,
    ACTIONS(16170), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14269), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 4,
      sym__automatic_semicolon,
      anon_sym_if,
      anon_sym_do,
      anon_sym_yield,
  [618104] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14270), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7846), 8,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_POUND,
  [618125] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(14271), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [618150] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15880), 1,
      anon_sym_finally,
    STATE(13136), 1,
      sym_finally_clause,
    STATE(14272), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 6,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_catch,
  [618175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14273), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
      anon_sym_finally,
  [618198] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14274), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 8,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_finally,
      anon_sym_do,
  [618219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16172), 1,
      anon_sym_DOT,
    STATE(14292), 1,
      aux_sym_package_identifier_repeat1,
    STATE(14275), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16031), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [618243] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14276), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [618263] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16176), 1,
      anon_sym_COMMA,
    STATE(14277), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_import_declaration_repeat1,
    ACTIONS(16174), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [618285] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16179), 1,
      anon_sym_LBRACE,
    ACTIONS(16183), 1,
      anon_sym_EQ,
    STATE(14880), 1,
      sym_block,
    STATE(14278), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16181), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [618311] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16185), 1,
      anon_sym_DOT,
    STATE(14279), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_package_identifier_repeat1,
    ACTIONS(15721), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [618333] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15242), 1,
      anon_sym_LT_COLON,
    STATE(14462), 1,
      sym_upper_bound,
    STATE(14280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16188), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [618357] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    ACTIONS(15182), 1,
      anon_sym_match,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(14281), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16190), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [618383] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9018), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14282), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9616), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_if,
      anon_sym_SEMI,
  [618405] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    ACTIONS(15182), 1,
      anon_sym_match,
    ACTIONS(16192), 1,
      anon_sym_RBRACE,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(15157), 1,
      aux_sym__enum_block_repeat1,
    ACTIONS(16194), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14283), 2,
      sym_comment,
      sym_block_comment,
  [618435] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16196), 1,
      anon_sym_SEMI,
    ACTIONS(16198), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14284), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [618461] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16200), 1,
      anon_sym_SEMI,
    ACTIONS(16202), 1,
      anon_sym_else,
    STATE(14285), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [618485] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16204), 1,
      anon_sym_COLON,
    ACTIONS(16206), 1,
      anon_sym_LBRACE,
    ACTIONS(16208), 1,
      anon_sym_extends,
    ACTIONS(16210), 1,
      anon_sym_derives,
    STATE(14828), 1,
      sym_extends_clause,
    STATE(15053), 1,
      sym_enum_body,
    STATE(15881), 1,
      sym_derives_clause,
    STATE(14286), 2,
      sym_comment,
      sym_block_comment,
  [618517] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16212), 1,
      anon_sym_catch,
    ACTIONS(16214), 1,
      anon_sym_finally,
    STATE(14151), 1,
      sym_finally_clause,
    STATE(14769), 1,
      sym_catch_clause,
    STATE(14287), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [618545] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14288), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 5,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [618567] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16216), 1,
      anon_sym_LBRACK,
    STATE(10083), 1,
      sym_type_arguments,
    STATE(14289), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [618591] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16216), 1,
      anon_sym_LBRACK,
    STATE(10083), 1,
      sym_type_arguments,
    STATE(14290), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [618615] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14291), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16218), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [618635] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16220), 1,
      anon_sym_DOT,
    STATE(14292), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_package_identifier_repeat1,
    ACTIONS(15721), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [618657] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16223), 1,
      anon_sym_SEMI,
    ACTIONS(16226), 1,
      anon_sym_else,
    STATE(14293), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
  [618681] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16228), 1,
      anon_sym_SEMI,
    ACTIONS(16231), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14294), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
  [618707] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15697), 1,
      anon_sym_finally,
    STATE(13428), 1,
      sym_finally_clause,
    STATE(14295), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [618731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16233), 1,
      anon_sym_COLON,
    STATE(14296), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16235), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [618753] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14090), 1,
      anon_sym_match,
    ACTIONS(16216), 1,
      anon_sym_LBRACK,
    STATE(10083), 1,
      sym_type_arguments,
    STATE(14297), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_else,
  [618779] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16208), 1,
      anon_sym_extends,
    ACTIONS(16210), 1,
      anon_sym_derives,
    ACTIONS(16237), 1,
      anon_sym_COLON,
    ACTIONS(16239), 1,
      anon_sym_LBRACE,
    STATE(14791), 1,
      sym_extends_clause,
    STATE(14797), 1,
      sym_enum_body,
    STATE(15477), 1,
      sym_derives_clause,
    STATE(14298), 2,
      sym_comment,
      sym_block_comment,
  [618811] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14299), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 5,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [618833] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16241), 1,
      anon_sym_with,
    STATE(14300), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat2,
    ACTIONS(15451), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [618855] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16244), 1,
      anon_sym_LBRACK,
    STATE(10186), 1,
      sym_type_arguments,
    STATE(14301), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [618879] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16246), 1,
      anon_sym_SEMI,
    ACTIONS(16249), 1,
      anon_sym_else,
    STATE(14302), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
  [618903] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16252), 1,
      anon_sym_SEMI,
    ACTIONS(16255), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14303), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
  [618929] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16260), 1,
      anon_sym_LPAREN,
    ACTIONS(16263), 1,
      sym__automatic_semicolon,
    STATE(14677), 1,
      sym_class_parameters,
    ACTIONS(16258), 3,
      sym__outdent,
      anon_sym_extends,
      anon_sym_SEMI,
    STATE(14304), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__full_enum_def_repeat1,
  [618955] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16266), 1,
      anon_sym_SEMI,
    ACTIONS(16269), 1,
      anon_sym_else,
    STATE(14305), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [618979] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14306), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [618999] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15783), 1,
      anon_sym_finally,
    STATE(13734), 1,
      sym_finally_clause,
    STATE(14307), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
      anon_sym_do,
  [619023] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14573), 1,
      sym_arguments,
    STATE(14308), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [619045] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16272), 1,
      anon_sym_SEMI,
    ACTIONS(16275), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14309), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_finally,
  [619071] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14090), 1,
      anon_sym_match,
    ACTIONS(16216), 1,
      anon_sym_LBRACK,
    STATE(10083), 1,
      sym_type_arguments,
    STATE(14310), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_else,
  [619097] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14311), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [619117] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14312), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [619137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14313), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [619157] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14314), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [619177] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16277), 1,
      anon_sym_with,
    STATE(14315), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
    ACTIONS(8982), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [619199] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16280), 1,
      anon_sym_SEMI,
    ACTIONS(16283), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14316), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
  [619225] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16285), 1,
      anon_sym_SEMI,
    ACTIONS(16288), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14317), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_finally,
  [619251] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16244), 1,
      anon_sym_LBRACK,
    STATE(10186), 1,
      sym_type_arguments,
    STATE(14318), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13192), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [619275] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14319), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [619295] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16216), 1,
      anon_sym_LBRACK,
    STATE(10083), 1,
      sym_type_arguments,
    STATE(14320), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [619319] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16291), 1,
      anon_sym_SEMI,
    ACTIONS(16294), 1,
      anon_sym_else,
    STATE(14321), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [619343] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15703), 1,
      anon_sym_finally,
    STATE(13097), 1,
      sym_finally_clause,
    STATE(14322), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [619367] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16297), 1,
      anon_sym_SEMI,
    ACTIONS(16300), 1,
      anon_sym_else,
    STATE(14323), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
  [619391] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14324), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16303), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [619411] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16244), 1,
      anon_sym_LBRACK,
    STATE(10186), 1,
      sym_type_arguments,
    STATE(14325), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [619435] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16305), 1,
      anon_sym_SEMI,
    ACTIONS(16308), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14326), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
  [619461] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16311), 1,
      anon_sym_LPAREN,
    ACTIONS(16314), 1,
      sym__automatic_semicolon,
    STATE(14665), 1,
      sym_class_parameters,
    ACTIONS(16258), 3,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_SEMI,
    STATE(14327), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__full_enum_def_repeat1,
  [619487] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14024), 1,
      anon_sym_match,
    ACTIONS(16244), 1,
      anon_sym_LBRACK,
    STATE(10186), 1,
      sym_type_arguments,
    STATE(14328), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_finally,
  [619513] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16317), 1,
      anon_sym_SEMI,
    ACTIONS(16320), 1,
      anon_sym_else,
    STATE(14329), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
  [619537] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16322), 1,
      anon_sym_SEMI,
    ACTIONS(16325), 1,
      anon_sym_else,
    STATE(14330), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
  [619561] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16328), 1,
      anon_sym_COLON,
    STATE(14331), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16330), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [619583] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14332), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [619603] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14333), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13275), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [619623] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16332), 1,
      anon_sym_SEMI,
    ACTIONS(16335), 1,
      anon_sym_else,
    STATE(14334), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
  [619647] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16208), 1,
      anon_sym_extends,
    ACTIONS(16210), 1,
      anon_sym_derives,
    ACTIONS(16237), 1,
      anon_sym_COLON,
    ACTIONS(16239), 1,
      anon_sym_LBRACE,
    STATE(14805), 1,
      sym_enum_body,
    STATE(14809), 1,
      sym_extends_clause,
    STATE(15238), 1,
      sym_derives_clause,
    STATE(14335), 2,
      sym_comment,
      sym_block_comment,
  [619679] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16337), 1,
      anon_sym_catch,
    ACTIONS(16339), 1,
      anon_sym_finally,
    STATE(13793), 1,
      sym_finally_clause,
    STATE(14562), 1,
      sym_catch_clause,
    STATE(14336), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [619707] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14337), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [619727] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15942), 1,
      anon_sym_with,
    STATE(14300), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14338), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15428), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [619751] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16341), 1,
      anon_sym_SEMI,
    ACTIONS(16344), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14339), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_do,
  [619777] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16347), 1,
      anon_sym_SEMI,
    ACTIONS(16349), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14340), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      anon_sym_while,
      anon_sym_catch,
      anon_sym_finally,
  [619803] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16351), 1,
      anon_sym_SEMI,
    ACTIONS(16353), 1,
      anon_sym_else,
    STATE(14341), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_finally,
  [619827] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16212), 1,
      anon_sym_catch,
    ACTIONS(16355), 1,
      anon_sym_finally,
    STATE(14386), 1,
      sym_finally_clause,
    STATE(14616), 1,
      sym_catch_clause,
    STATE(14342), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [619855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16357), 1,
      anon_sym_COLON,
    STATE(14343), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16359), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [619877] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16204), 1,
      anon_sym_COLON,
    ACTIONS(16206), 1,
      anon_sym_LBRACE,
    ACTIONS(16208), 1,
      anon_sym_extends,
    ACTIONS(16210), 1,
      anon_sym_derives,
    STATE(14724), 1,
      sym_extends_clause,
    STATE(14890), 1,
      sym_enum_body,
    STATE(15827), 1,
      sym_derives_clause,
    STATE(14344), 2,
      sym_comment,
      sym_block_comment,
  [619909] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16361), 1,
      anon_sym_LBRACE,
    ACTIONS(16363), 1,
      anon_sym_EQ,
    STATE(14736), 1,
      sym_block,
    STATE(14345), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16181), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [619935] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16365), 1,
      anon_sym_SEMI,
    ACTIONS(16368), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14346), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
  [619961] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14347), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [619981] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14348), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [620001] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16244), 1,
      anon_sym_LBRACK,
    STATE(10186), 1,
      sym_type_arguments,
    STATE(14349), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [620025] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16244), 1,
      anon_sym_LBRACK,
    STATE(10186), 1,
      sym_type_arguments,
    STATE(14350), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_finally,
  [620049] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    ACTIONS(15990), 1,
      anon_sym_match,
    ACTIONS(15992), 1,
      sym__outdent,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(14891), 1,
      aux_sym__block_repeat1,
    ACTIONS(16371), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14351), 2,
      sym_comment,
      sym_block_comment,
  [620079] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14352), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [620099] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14492), 1,
      sym_arguments,
    STATE(14353), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [620121] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    ACTIONS(15182), 1,
      anon_sym_match,
    ACTIONS(15992), 1,
      anon_sym_RBRACE,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(14889), 1,
      aux_sym__block_repeat1,
    ACTIONS(16373), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14354), 2,
      sym_comment,
      sym_block_comment,
  [620151] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15242), 1,
      anon_sym_LT_COLON,
    STATE(14585), 1,
      sym_upper_bound,
    STATE(14355), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16375), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [620175] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14356), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [620195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16377), 1,
      anon_sym_DOT,
    STATE(14275), 1,
      aux_sym_package_identifier_repeat1,
    STATE(14357), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16045), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [620219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16379), 1,
      anon_sym_SEMI,
    ACTIONS(16382), 1,
      anon_sym_else,
    STATE(14358), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
  [620243] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14359), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [620263] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14360), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15975), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [620283] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16387), 1,
      anon_sym_COMMA,
    STATE(14277), 1,
      aux_sym_import_declaration_repeat1,
    STATE(14361), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16385), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [620307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14362), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [620327] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16387), 1,
      anon_sym_COMMA,
    STATE(14277), 1,
      aux_sym_import_declaration_repeat1,
    STATE(14363), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16389), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [620351] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16393), 1,
      anon_sym_DOT,
    STATE(14367), 1,
      aux_sym_package_identifier_repeat1,
    STATE(14364), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16391), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [620375] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14443), 1,
      sym_arguments,
    STATE(14365), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [620397] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16395), 1,
      anon_sym_catch,
    ACTIONS(16397), 1,
      anon_sym_finally,
    STATE(13793), 1,
      sym_finally_clause,
    STATE(14547), 1,
      sym_catch_clause,
    STATE(14366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [620425] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16393), 1,
      anon_sym_DOT,
    STATE(14279), 1,
      aux_sym_package_identifier_repeat1,
    STATE(14367), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16399), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [620449] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16387), 1,
      anon_sym_COMMA,
    STATE(14363), 1,
      aux_sym_import_declaration_repeat1,
    STATE(14368), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16401), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [620473] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14369), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
  [620495] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16387), 1,
      anon_sym_COMMA,
    STATE(14361), 1,
      aux_sym_import_declaration_repeat1,
    STATE(14370), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16403), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [620519] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16405), 1,
      anon_sym_catch,
    ACTIONS(16407), 1,
      anon_sym_finally,
    STATE(14386), 1,
      sym_finally_clause,
    STATE(14702), 1,
      sym_catch_clause,
    STATE(14371), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [620547] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15874), 1,
      anon_sym_finally,
    STATE(13734), 1,
      sym_finally_clause,
    STATE(14372), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [620571] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14373), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [620591] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14374), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13281), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [620611] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14375), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [620631] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16409), 1,
      anon_sym_SEMI,
    ACTIONS(16412), 1,
      anon_sym_else,
    STATE(14376), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [620655] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14377), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [620675] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16415), 1,
      anon_sym_SEMI,
    ACTIONS(16418), 1,
      anon_sym_else,
    STATE(14378), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_match,
  [620699] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16420), 1,
      anon_sym_SEMI,
    ACTIONS(16422), 1,
      anon_sym_else,
    STATE(14379), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [620723] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14380), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13273), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [620743] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14381), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 7,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [620763] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14382), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [620783] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14383), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [620803] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15882), 1,
      anon_sym_finally,
    STATE(13097), 1,
      sym_finally_clause,
    STATE(14384), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [620827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13289), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14385), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13287), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
  [620849] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14386), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [620869] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14387), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13271), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [620889] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16405), 1,
      anon_sym_catch,
    ACTIONS(16424), 1,
      anon_sym_finally,
    STATE(14151), 1,
      sym_finally_clause,
    STATE(14692), 1,
      sym_catch_clause,
    STATE(14388), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14175), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [620917] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14389), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [620937] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15337), 1,
      anon_sym_LT_COLON,
    STATE(14647), 1,
      sym_upper_bound,
    STATE(14390), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16188), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [620961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13294), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14391), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13292), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_if,
      anon_sym_SEMI,
  [620983] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14392), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16088), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_derives,
      anon_sym_SEMI,
  [621003] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14393), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [621023] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16426), 1,
      anon_sym_COLON,
    STATE(14394), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16359), 6,
      sym__automatic_semicolon,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [621045] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14395), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13285), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [621065] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16060), 1,
      anon_sym_with,
    STATE(14405), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14396), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15428), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [621089] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14397), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [621109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16428), 1,
      anon_sym_COLON,
    STATE(14398), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16235), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [621131] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14399), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12846), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [621151] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14400), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16430), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
      anon_sym_SEMI,
  [621171] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15891), 1,
      anon_sym_finally,
    STATE(12726), 1,
      sym_finally_clause,
    STATE(14401), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [621195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15868), 1,
      anon_sym_finally,
    STATE(14276), 1,
      sym_finally_clause,
    STATE(14402), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_SEMI,
  [621219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15831), 1,
      anon_sym_finally,
    STATE(14214), 1,
      sym_finally_clause,
    STATE(14403), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [621243] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14404), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13283), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [621263] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16432), 1,
      anon_sym_with,
    STATE(14405), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat2,
    ACTIONS(15451), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [621285] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14406), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9018), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [621305] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    ACTIONS(15990), 1,
      anon_sym_match,
    ACTIONS(16192), 1,
      sym__outdent,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(15061), 1,
      aux_sym__enum_block_repeat1,
    ACTIONS(16435), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14407), 2,
      sym_comment,
      sym_block_comment,
  [621335] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14408), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13242), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [621355] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    ACTIONS(15990), 1,
      anon_sym_match,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(14409), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16190), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [621381] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14410), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13240), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [621401] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14411), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16437), 7,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [621421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16439), 1,
      anon_sym_as,
    STATE(14412), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15721), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
  [621443] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16216), 1,
      anon_sym_LBRACK,
    STATE(10083), 1,
      sym_type_arguments,
    STATE(14413), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [621467] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15781), 1,
      anon_sym_finally,
    STATE(13428), 1,
      sym_finally_clause,
    STATE(14414), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 5,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_SEMI,
      anon_sym_else,
  [621491] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14415), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13248), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [621511] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14024), 1,
      anon_sym_match,
    ACTIONS(16244), 1,
      anon_sym_LBRACK,
    STATE(10186), 1,
      sym_type_arguments,
    STATE(14416), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_finally,
  [621537] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14417), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LBRACK,
      anon_sym_if,
      anon_sym_match,
      anon_sym_SEMI,
  [621557] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16441), 1,
      anon_sym_SEMI,
    ACTIONS(16444), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14418), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
  [621583] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14419), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13252), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [621603] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14420), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13258), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [621623] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16446), 1,
      anon_sym_SEMI,
    ACTIONS(16449), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14421), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_then,
  [621649] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15825), 1,
      anon_sym_finally,
    STATE(14424), 1,
      sym_finally_clause,
    STATE(14422), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 5,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
  [621673] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14423), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 7,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [621693] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14424), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13260), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [621713] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16452), 1,
      anon_sym_SEMI,
    ACTIONS(16455), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14425), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      anon_sym_while,
      anon_sym_catch,
      anon_sym_finally,
  [621739] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14426), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16458), 7,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_if,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [621759] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15337), 1,
      anon_sym_LT_COLON,
    STATE(14630), 1,
      sym_upper_bound,
    STATE(14427), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16375), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [621783] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16460), 1,
      anon_sym_COLON,
    STATE(14428), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16330), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [621805] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14429), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13262), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [621825] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14430), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13264), 7,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [621845] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16462), 1,
      anon_sym_SEMI,
    ACTIONS(16464), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14431), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15492), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_then,
  [621871] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13268), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14432), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13266), 5,
      anon_sym_COMMA,
      anon_sym_while,
      anon_sym_RPAREN,
      anon_sym_then,
      anon_sym_do,
  [621893] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14433), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [621912] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14434), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [621931] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9688), 1,
      anon_sym_LPAREN,
    STATE(15179), 1,
      sym_arguments,
    STATE(14435), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15651), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [621954] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16468), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16284), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14436), 2,
      sym_comment,
      sym_block_comment,
  [621983] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14437), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16218), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [622002] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14438), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
  [622021] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16470), 1,
      anon_sym_SEMI,
    ACTIONS(16472), 1,
      anon_sym_else,
    STATE(14439), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 4,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_finally,
  [622044] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16474), 1,
      anon_sym_SEMI,
    ACTIONS(16476), 1,
      anon_sym_else,
    ACTIONS(15492), 2,
      anon_sym_while,
      anon_sym_finally,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14440), 2,
      sym_comment,
      sym_block_comment,
  [622069] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16478), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16168), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14441), 2,
      sym_comment,
      sym_block_comment,
  [622098] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14442), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [622117] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14443), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [622136] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16132), 1,
      anon_sym_if,
    STATE(14513), 1,
      aux_sym_enumerator_repeat1,
    STATE(14859), 1,
      sym_guard,
    STATE(14444), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15693), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [622161] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16480), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16285), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14445), 2,
      sym_comment,
      sym_block_comment,
  [622190] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16482), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15935), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14446), 2,
      sym_comment,
      sym_block_comment,
  [622219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16144), 1,
      anon_sym_COMMA,
    STATE(14461), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14447), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15428), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [622242] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16484), 1,
      anon_sym_COMMA,
    STATE(14487), 1,
      aux_sym_import_declaration_repeat1,
    STATE(14448), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16403), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16484), 1,
      anon_sym_COMMA,
    STATE(14486), 1,
      aux_sym_import_declaration_repeat1,
    STATE(14449), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16401), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [622288] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14450), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [622307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14451), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [622326] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10859), 1,
      anon_sym_LPAREN,
    STATE(14901), 1,
      sym_arguments,
    STATE(14452), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15651), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [622349] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16486), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15935), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14453), 2,
      sym_comment,
      sym_block_comment,
  [622378] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14454), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12586), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
  [622397] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14455), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12588), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
  [622416] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16488), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15902), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14456), 2,
      sym_comment,
      sym_block_comment,
  [622445] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16490), 1,
      anon_sym_SEMI,
    ACTIONS(16493), 1,
      anon_sym_else,
    STATE(14457), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 4,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_finally,
  [622468] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14458), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12607), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
  [622487] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14459), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15599), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [622506] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16496), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15503), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14460), 2,
      sym_comment,
      sym_block_comment,
  [622535] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16498), 1,
      anon_sym_COMMA,
    STATE(14461), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat1,
    ACTIONS(15446), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [622556] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14462), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16501), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [622575] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15653), 1,
      anon_sym_LT_COLON,
    STATE(14585), 1,
      sym_upper_bound,
    STATE(14463), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16375), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_EQ,
      anon_sym_SEMI,
  [622598] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14464), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16375), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [622617] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16361), 1,
      anon_sym_LBRACE,
    ACTIONS(16503), 1,
      anon_sym_EQ,
    STATE(14736), 1,
      sym_block,
    STATE(14465), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16181), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [622642] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16505), 1,
      anon_sym_SEMI,
    ACTIONS(16508), 1,
      anon_sym_else,
    ACTIONS(15492), 2,
      anon_sym_while,
      anon_sym_finally,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14466), 2,
      sym_comment,
      sym_block_comment,
  [622667] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16179), 1,
      anon_sym_LBRACE,
    ACTIONS(16511), 1,
      anon_sym_EQ,
    STATE(14880), 1,
      sym_block,
    STATE(14467), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16181), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [622692] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14468), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [622711] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14469), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [622730] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14470), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16513), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [622749] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16515), 1,
      anon_sym_SEMI,
    ACTIONS(16518), 1,
      anon_sym_else,
    STATE(14471), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
  [622772] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16521), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16151), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14472), 2,
      sym_comment,
      sym_block_comment,
  [622801] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(16523), 1,
      anon_sym_COLON,
    ACTIONS(16525), 1,
      sym__automatic_semicolon,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14539), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14473), 2,
      sym_comment,
      sym_block_comment,
  [622830] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15940), 1,
      anon_sym_COMMA,
    STATE(14500), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14474), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15428), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [622853] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(16527), 1,
      anon_sym_COLON,
    ACTIONS(16529), 1,
      sym__automatic_semicolon,
    STATE(12531), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14475), 2,
      sym_comment,
      sym_block_comment,
  [622882] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14476), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [622901] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16531), 1,
      anon_sym_LBRACE,
    ACTIONS(16535), 1,
      sym__interpolation_identifier,
    ACTIONS(16533), 2,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
    STATE(14477), 2,
      sym_comment,
      sym_block_comment,
    STATE(16626), 2,
      sym_block,
      sym__aliased_interpolation_identifier,
  [622926] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14478), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [622945] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(16537), 1,
      anon_sym_COLON,
    ACTIONS(16539), 1,
      sym__automatic_semicolon,
    STATE(12531), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14479), 2,
      sym_comment,
      sym_block_comment,
  [622974] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16541), 1,
      anon_sym_SEMI,
    ACTIONS(16544), 1,
      anon_sym_else,
    ACTIONS(15492), 2,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14480), 2,
      sym_comment,
      sym_block_comment,
  [622999] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14481), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16547), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [623018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14461), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14482), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15428), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [623039] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16549), 1,
      anon_sym_SEMI,
    ACTIONS(16552), 1,
      anon_sym_else,
    STATE(14483), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 4,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
  [623062] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14484), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16555), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [623081] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14485), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [623100] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16484), 1,
      anon_sym_COMMA,
    STATE(14549), 1,
      aux_sym_import_declaration_repeat1,
    STATE(14486), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16389), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [623123] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16484), 1,
      anon_sym_COMMA,
    STATE(14549), 1,
      aux_sym_import_declaration_repeat1,
    STATE(14487), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16385), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [623146] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14488), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [623165] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14489), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [623184] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16557), 1,
      anon_sym_LBRACE,
    ACTIONS(16561), 1,
      sym__interpolation_identifier,
    ACTIONS(16559), 2,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
    STATE(14490), 2,
      sym_comment,
      sym_block_comment,
    STATE(16605), 2,
      sym_block,
      sym__aliased_interpolation_identifier,
  [623209] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16563), 1,
      anon_sym_SEMI,
    ACTIONS(16566), 1,
      anon_sym_else,
    ACTIONS(15492), 2,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14491), 2,
      sym_comment,
      sym_block_comment,
  [623234] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14492), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [623253] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14493), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [623272] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16568), 1,
      anon_sym_SEMI,
    ACTIONS(16571), 1,
      anon_sym_else,
    ACTIONS(15492), 2,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14494), 2,
      sym_comment,
      sym_block_comment,
  [623297] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [623316] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14496), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15599), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [623335] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16574), 1,
      anon_sym_COLON,
    STATE(14497), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16235), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_SEMI,
  [623356] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16576), 1,
      anon_sym_SEMI,
    ACTIONS(16579), 1,
      anon_sym_else,
    STATE(14498), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_match,
  [623379] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15182), 1,
      anon_sym_match,
    ACTIONS(16581), 1,
      anon_sym_LBRACK,
    STATE(10632), 1,
      sym_type_arguments,
    STATE(14499), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13184), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [623404] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16583), 1,
      anon_sym_COMMA,
    STATE(14500), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat1,
    ACTIONS(15446), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [623425] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14501), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [623444] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14502), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [623463] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16586), 1,
      anon_sym_SEMI,
    ACTIONS(16589), 1,
      anon_sym_else,
    ACTIONS(15492), 2,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14503), 2,
      sym_comment,
      sym_block_comment,
  [623488] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16591), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15995), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14504), 2,
      sym_comment,
      sym_block_comment,
  [623517] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14505), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(12590), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_GT_COLON,
      anon_sym_LT_PERCENT,
  [623536] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16593), 1,
      anon_sym_SEMI,
    ACTIONS(16596), 1,
      anon_sym_else,
    ACTIONS(15492), 2,
      sym__automatic_semicolon,
      sym__outdent,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14506), 2,
      sym_comment,
      sym_block_comment,
  [623561] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14507), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16598), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [623580] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16600), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15935), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14508), 2,
      sym_comment,
      sym_block_comment,
  [623609] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16602), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16069), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14509), 2,
      sym_comment,
      sym_block_comment,
  [623638] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16604), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16311), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14510), 2,
      sym_comment,
      sym_block_comment,
  [623667] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16606), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15693), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14511), 2,
      sym_comment,
      sym_block_comment,
  [623696] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16122), 1,
      anon_sym_COMMA,
    STATE(14563), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14512), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15428), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
      anon_sym_LPAREN,
  [623719] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16608), 1,
      anon_sym_if,
    STATE(14859), 1,
      sym_guard,
    ACTIONS(15815), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    STATE(14513), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enumerator_repeat1,
  [623742] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14683), 1,
      anon_sym_extends,
    STATE(15023), 1,
      sym_extends_clause,
    STATE(14514), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14239), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [623765] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16611), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15841), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14515), 2,
      sym_comment,
      sym_block_comment,
  [623794] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14516), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16303), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [623813] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16124), 1,
      anon_sym_with,
    STATE(14561), 1,
      aux_sym__constructor_applications_repeat2,
    STATE(14517), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15428), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
      anon_sym_LPAREN,
  [623836] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16613), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16204), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14518), 2,
      sym_comment,
      sym_block_comment,
  [623865] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16615), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16349), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14519), 2,
      sym_comment,
      sym_block_comment,
  [623894] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14520), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [623913] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16617), 1,
      anon_sym_SEMI,
    ACTIONS(16619), 1,
      anon_sym_else,
    ACTIONS(15492), 2,
      anon_sym_finally,
      anon_sym_do,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14521), 2,
      sym_comment,
      sym_block_comment,
  [623938] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16621), 1,
      anon_sym_SEMI,
    ACTIONS(16623), 1,
      anon_sym_else,
    STATE(14522), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 4,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_finally,
      anon_sym_do,
  [623961] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16625), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16011), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14523), 2,
      sym_comment,
      sym_block_comment,
  [623990] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16361), 1,
      anon_sym_LBRACE,
    ACTIONS(16627), 1,
      anon_sym_EQ,
    STATE(14736), 1,
      sym_block,
    STATE(14524), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16181), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [624015] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(14525), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15160), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [624040] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14526), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [624059] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15182), 1,
      anon_sym_match,
    ACTIONS(16581), 1,
      anon_sym_LBRACK,
    STATE(10632), 1,
      sym_type_arguments,
    STATE(14527), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16629), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [624084] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16631), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16256), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14528), 2,
      sym_comment,
      sym_block_comment,
  [624113] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14529), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16188), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [624132] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15653), 1,
      anon_sym_LT_COLON,
    STATE(14462), 1,
      sym_upper_bound,
    STATE(14530), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16188), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_EQ,
      anon_sym_SEMI,
  [624155] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14531), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16633), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [624174] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14532), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [624193] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16635), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16070), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14533), 2,
      sym_comment,
      sym_block_comment,
  [624222] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14534), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [624241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14535), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [624260] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14536), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
  [624279] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14537), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [624298] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14241), 1,
      anon_sym_extends,
    STATE(15111), 1,
      sym_extends_clause,
    STATE(14538), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(14239), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [624321] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(16637), 1,
      anon_sym_COLON,
    ACTIONS(16639), 1,
      sym__automatic_semicolon,
    STATE(12531), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14539), 2,
      sym_comment,
      sym_block_comment,
  [624350] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14826), 1,
      sym_arguments,
    STATE(14540), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [624371] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16581), 1,
      anon_sym_LBRACK,
    STATE(10632), 1,
      sym_type_arguments,
    STATE(14541), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13178), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
  [624394] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16581), 1,
      anon_sym_LBRACK,
    STATE(10632), 1,
      sym_type_arguments,
    STATE(14542), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13176), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
  [624417] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14543), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [624436] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16641), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [624455] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14545), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15721), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_SEMI,
  [624474] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14546), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
  [624493] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16397), 1,
      anon_sym_finally,
    STATE(13878), 1,
      sym_finally_clause,
    STATE(14547), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 4,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_catch,
      anon_sym_do,
  [624516] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15182), 1,
      anon_sym_match,
    ACTIONS(16581), 1,
      anon_sym_LBRACK,
    STATE(10632), 1,
      sym_type_arguments,
    STATE(14548), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13170), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [624541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16643), 1,
      anon_sym_COMMA,
    STATE(14549), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_import_declaration_repeat1,
    ACTIONS(16174), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [624562] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14550), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [624581] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14551), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [624600] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16646), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15261), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14552), 2,
      sym_comment,
      sym_block_comment,
  [624629] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14553), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16648), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [624648] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14554), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8435), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
  [624667] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14555), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16650), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [624686] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16654), 1,
      anon_sym_LT_PERCENT,
    STATE(15110), 1,
      sym_view_bound,
    ACTIONS(16652), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14556), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__type_parameter_repeat1,
  [624709] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16657), 1,
      anon_sym_COLON,
    STATE(14557), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16359), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_SEMI,
  [624730] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14558), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16437), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [624749] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    ACTIONS(15990), 1,
      anon_sym_match,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(14559), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16659), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [624774] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16661), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16141), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14560), 2,
      sym_comment,
      sym_block_comment,
  [624803] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16663), 1,
      anon_sym_with,
    STATE(14561), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat2,
    ACTIONS(15451), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
      anon_sym_LPAREN,
  [624824] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16339), 1,
      anon_sym_finally,
    STATE(13878), 1,
      sym_finally_clause,
    STATE(14562), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 4,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
      anon_sym_catch,
  [624847] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16666), 1,
      anon_sym_COMMA,
    STATE(14563), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__constructor_applications_repeat1,
    ACTIONS(15446), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
      anon_sym_LPAREN,
  [624868] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14564), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16430), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_LT_COLON,
      anon_sym_EQ,
      anon_sym_SEMI,
  [624887] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16669), 1,
      anon_sym_COLON,
    STATE(14565), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16330), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_SEMI,
  [624908] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16671), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16139), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14566), 2,
      sym_comment,
      sym_block_comment,
  [624937] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16673), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16336), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14567), 2,
      sym_comment,
      sym_block_comment,
  [624966] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14568), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [624985] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    ACTIONS(15182), 1,
      anon_sym_match,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(14569), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16659), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [625010] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16581), 1,
      anon_sym_LBRACK,
    STATE(10632), 1,
      sym_type_arguments,
    STATE(14570), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13186), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
  [625033] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16675), 1,
      anon_sym_COMMA,
    ACTIONS(16677), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15455), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14571), 2,
      sym_comment,
      sym_block_comment,
  [625062] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16679), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16210), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14572), 2,
      sym_comment,
      sym_block_comment,
  [625091] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14573), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [625110] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16681), 1,
      anon_sym_SEMI,
    ACTIONS(16684), 1,
      anon_sym_else,
    STATE(14574), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_LBRACK,
      anon_sym_match,
  [625133] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14575), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [625152] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14500), 1,
      aux_sym__constructor_applications_repeat1,
    STATE(14576), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15428), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [625173] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(14577), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15214), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [625198] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(14578), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15216), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [625223] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16686), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16229), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14579), 2,
      sym_comment,
      sym_block_comment,
  [625252] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14580), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [625271] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14581), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [625290] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(14582), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15275), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [625315] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16688), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15765), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14583), 2,
      sym_comment,
      sym_block_comment,
  [625344] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14584), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [625363] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14585), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16690), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [625382] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14586), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [625401] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14587), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16692), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [625420] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(16694), 1,
      anon_sym_COLON,
    ACTIONS(16696), 1,
      sym__automatic_semicolon,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14479), 1,
      aux_sym__function_constructor_repeat1,
    STATE(14588), 2,
      sym_comment,
      sym_block_comment,
  [625449] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14589), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16698), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [625468] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14590), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 6,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_with,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [625487] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14591), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(5136), 6,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [625506] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16700), 1,
      anon_sym_SEMI,
    ACTIONS(16703), 1,
      anon_sym_else,
    STATE(14592), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_match,
  [625529] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14593), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15270), 6,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_do,
      anon_sym_yield,
  [625548] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14594), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9076), 6,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
  [625567] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16581), 1,
      anon_sym_LBRACK,
    STATE(10632), 1,
      sym_type_arguments,
    STATE(14595), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13188), 4,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_match,
      anon_sym_SEMI,
  [625590] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(16705), 1,
      anon_sym_COLON,
    ACTIONS(16707), 1,
      sym__automatic_semicolon,
    STATE(12531), 1,
      aux_sym__function_constructor_repeat1,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13900), 1,
      sym_parameters,
    STATE(14596), 2,
      sym_comment,
      sym_block_comment,
  [625619] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16466), 1,
      anon_sym_COMMA,
    ACTIONS(16709), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16365), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(14597), 2,
      sym_comment,
      sym_block_comment,
  [625648] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14598), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16711), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [625666] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16713), 1,
      anon_sym_COMMA,
    ACTIONS(16715), 1,
      anon_sym_RPAREN,
    STATE(15476), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14599), 2,
      sym_comment,
      sym_block_comment,
  [625692] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7694), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_with,
      anon_sym_LPAREN,
  [625710] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14601), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16717), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [625728] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16719), 1,
      anon_sym_COMMA,
    ACTIONS(16721), 1,
      anon_sym_RPAREN,
    STATE(15361), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14602), 2,
      sym_comment,
      sym_block_comment,
  [625754] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16723), 1,
      anon_sym_COMMA,
    STATE(14682), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14603), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16725), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [625776] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16727), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [625794] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14605), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16729), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [625812] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14606), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16731), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [625830] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16733), 1,
      anon_sym_COMMA,
    ACTIONS(16735), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16235), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14607), 2,
      sym_comment,
      sym_block_comment,
  [625856] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14608), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16737), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [625874] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14609), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16739), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [625892] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14610), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16741), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [625910] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16743), 1,
      anon_sym_COMMA,
    ACTIONS(16745), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15548), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14611), 2,
      sym_comment,
      sym_block_comment,
  [625936] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14612), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16641), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [625954] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16747), 1,
      anon_sym_COMMA,
    ACTIONS(16749), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15631), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14613), 2,
      sym_comment,
      sym_block_comment,
  [625980] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13923), 1,
      anon_sym_LPAREN,
    STATE(15495), 1,
      sym_arguments,
    STATE(14614), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15651), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
  [626002] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14615), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16751), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626020] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16355), 1,
      anon_sym_finally,
    STATE(14424), 1,
      sym_finally_clause,
    STATE(14616), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [626042] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16753), 1,
      anon_sym_COMMA,
    ACTIONS(16755), 1,
      anon_sym_RPAREN,
    STATE(15307), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14617), 2,
      sym_comment,
      sym_block_comment,
  [626068] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16759), 1,
      anon_sym_EQ,
    STATE(14618), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16757), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [626088] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16761), 1,
      anon_sym_COMMA,
    ACTIONS(16763), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16017), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14619), 2,
      sym_comment,
      sym_block_comment,
  [626114] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14620), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16765), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626132] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16767), 1,
      anon_sym_COMMA,
    ACTIONS(16769), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15595), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14621), 2,
      sym_comment,
      sym_block_comment,
  [626158] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14622), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16771), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626176] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    STATE(14680), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(15524), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14623), 2,
      sym_comment,
      sym_block_comment,
  [626200] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16773), 1,
      anon_sym_COMMA,
    ACTIONS(16775), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15530), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14624), 2,
      sym_comment,
      sym_block_comment,
  [626226] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14625), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16777), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626244] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14626), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9519), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [626262] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16779), 1,
      anon_sym_COMMA,
    ACTIONS(16781), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16305), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14627), 2,
      sym_comment,
      sym_block_comment,
  [626288] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16783), 1,
      anon_sym_COMMA,
    ACTIONS(16785), 1,
      anon_sym_RPAREN,
    STATE(15325), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14628), 2,
      sym_comment,
      sym_block_comment,
  [626314] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14629), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16777), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626332] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14630), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16690), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [626350] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16787), 1,
      anon_sym_COMMA,
    ACTIONS(16789), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16196), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14631), 2,
      sym_comment,
      sym_block_comment,
  [626376] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14632), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16791), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626394] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14633), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16791), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626412] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14634), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16793), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626430] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14635), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16795), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16190), 2,
      sym__outdent,
      anon_sym_case,
    ACTIONS(16797), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14636), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__block_repeat1,
  [626468] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14637), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8705), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [626486] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16800), 1,
      anon_sym_COMMA,
    ACTIONS(16802), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15915), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14638), 2,
      sym_comment,
      sym_block_comment,
  [626512] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14639), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16804), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626530] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16806), 1,
      anon_sym_COMMA,
    ACTIONS(16808), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15754), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14640), 2,
      sym_comment,
      sym_block_comment,
  [626556] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16810), 1,
      anon_sym_COMMA,
    ACTIONS(16812), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15648), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14641), 2,
      sym_comment,
      sym_block_comment,
  [626582] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14642), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16814), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626600] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14643), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16816), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626618] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14644), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16818), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626636] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14645), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16820), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626654] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16822), 1,
      anon_sym_COMMA,
    ACTIONS(16824), 1,
      anon_sym_RPAREN,
    STATE(15276), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14646), 2,
      sym_comment,
      sym_block_comment,
  [626680] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14647), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16501), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [626698] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14648), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16375), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [626716] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14649), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16430), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_COLON,
      anon_sym_LT_PERCENT,
  [626734] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16826), 1,
      anon_sym_SEMI,
    ACTIONS(16830), 1,
      sym__automatic_semicolon,
    STATE(14750), 1,
      aux_sym_enumerators_repeat1,
    ACTIONS(16828), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(14650), 2,
      sym_comment,
      sym_block_comment,
  [626758] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16832), 1,
      anon_sym_COMMA,
    ACTIONS(16834), 1,
      anon_sym_RPAREN,
    STATE(15271), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14651), 2,
      sym_comment,
      sym_block_comment,
  [626784] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16836), 1,
      anon_sym_COMMA,
    ACTIONS(16838), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16088), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14652), 2,
      sym_comment,
      sym_block_comment,
  [626810] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16842), 1,
      anon_sym_EQ,
    STATE(14653), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16840), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626830] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    ACTIONS(16844), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14654), 2,
      sym_comment,
      sym_block_comment,
  [626854] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14655), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8696), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [626872] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16846), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626890] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6322), 1,
      anon_sym_LBRACE,
    ACTIONS(13180), 1,
      anon_sym_COLON,
    STATE(14980), 1,
      sym_template_body,
    STATE(9146), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(14657), 2,
      sym_comment,
      sym_block_comment,
  [626914] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16848), 1,
      anon_sym_SEMI,
    ACTIONS(16850), 1,
      anon_sym_else,
    STATE(14658), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [626936] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14659), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16852), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [626954] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14660), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15599), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_derives,
      anon_sym_LPAREN,
  [626972] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14661), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15608), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [626990] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15492), 1,
      anon_sym_while,
    ACTIONS(16854), 1,
      anon_sym_SEMI,
    ACTIONS(16856), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14662), 2,
      sym_comment,
      sym_block_comment,
  [627014] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16858), 1,
      anon_sym_COMMA,
    ACTIONS(16860), 1,
      anon_sym_RPAREN,
    STATE(15512), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14663), 2,
      sym_comment,
      sym_block_comment,
  [627040] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14693), 1,
      aux_sym__block_repeat1,
    ACTIONS(659), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(16862), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14664), 2,
      sym_comment,
      sym_block_comment,
  [627062] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14665), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16864), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [627080] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16866), 1,
      anon_sym_COMMA,
    ACTIONS(16868), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15769), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14666), 2,
      sym_comment,
      sym_block_comment,
  [627106] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16872), 1,
      anon_sym_COMMA,
    STATE(14758), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14667), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16870), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [627128] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16874), 1,
      anon_sym_COMMA,
    ACTIONS(16876), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15584), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14668), 2,
      sym_comment,
      sym_block_comment,
  [627154] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16878), 1,
      anon_sym_COMMA,
    ACTIONS(16880), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16180), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14669), 2,
      sym_comment,
      sym_block_comment,
  [627180] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14670), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16882), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [627198] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16884), 1,
      anon_sym_EQ,
    STATE(14671), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16840), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [627218] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16886), 1,
      anon_sym_EQ,
    STATE(14672), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16757), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [627238] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    STATE(14680), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(15533), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14673), 2,
      sym_comment,
      sym_block_comment,
  [627262] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14674), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15601), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [627280] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16872), 1,
      anon_sym_COMMA,
    STATE(14759), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14675), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16870), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [627302] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14676), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16513), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [627320] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16864), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [627338] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16888), 1,
      anon_sym_COMMA,
    ACTIONS(16890), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16148), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14678), 2,
      sym_comment,
      sym_block_comment,
  [627364] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14679), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16892), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [627382] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16894), 1,
      anon_sym_COLON,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(16897), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14680), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__type_parameter_repeat2,
  [627404] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14681), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16899), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [627422] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16723), 1,
      anon_sym_COMMA,
    STATE(14715), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14682), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16870), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [627444] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16723), 1,
      anon_sym_COMMA,
    STATE(14715), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14683), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16901), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [627466] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16903), 1,
      anon_sym_COMMA,
    ACTIONS(16905), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16078), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14684), 2,
      sym_comment,
      sym_block_comment,
  [627492] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16723), 1,
      anon_sym_COMMA,
    STATE(14683), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16870), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [627514] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14686), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16907), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [627532] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14687), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [627550] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14688), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(8689), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [627568] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16909), 1,
      anon_sym_COMMA,
    ACTIONS(16911), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15577), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14689), 2,
      sym_comment,
      sym_block_comment,
  [627594] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16913), 1,
      anon_sym_COMMA,
    ACTIONS(16915), 1,
      anon_sym_RPAREN,
    STATE(15222), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14690), 2,
      sym_comment,
      sym_block_comment,
  [627620] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16917), 1,
      anon_sym_SEMI,
    ACTIONS(16920), 1,
      anon_sym_else,
    STATE(14691), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [627642] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16424), 1,
      anon_sym_finally,
    STATE(14214), 1,
      sym_finally_clause,
    STATE(14692), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [627664] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16190), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(16923), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14693), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__block_repeat1,
  [627684] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16926), 1,
      anon_sym_COMMA,
    ACTIONS(16928), 1,
      anon_sym_RPAREN,
    STATE(15234), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14694), 2,
      sym_comment,
      sym_block_comment,
  [627710] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16930), 1,
      anon_sym_COMMA,
    ACTIONS(16932), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16377), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14695), 2,
      sym_comment,
      sym_block_comment,
  [627736] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14696), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15601), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [627754] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15492), 1,
      anon_sym_do,
    ACTIONS(16934), 1,
      anon_sym_SEMI,
    ACTIONS(16937), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14697), 2,
      sym_comment,
      sym_block_comment,
  [627778] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    STATE(14680), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(16003), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14698), 2,
      sym_comment,
      sym_block_comment,
  [627802] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16940), 1,
      anon_sym_COMMA,
    ACTIONS(16942), 1,
      anon_sym_RPAREN,
    STATE(15494), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14699), 2,
      sym_comment,
      sym_block_comment,
  [627828] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16547), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    ACTIONS(16944), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14700), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enumerators_repeat1,
  [627848] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14701), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16650), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [627866] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16407), 1,
      anon_sym_finally,
    STATE(14424), 1,
      sym_finally_clause,
    STATE(14702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [627888] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    STATE(14680), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(16026), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14703), 2,
      sym_comment,
      sym_block_comment,
  [627912] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16692), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [627930] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    STATE(14680), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(16024), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14705), 2,
      sym_comment,
      sym_block_comment,
  [627954] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14706), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9515), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [627972] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14707), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16698), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [627990] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16947), 1,
      anon_sym_COMMA,
    ACTIONS(16949), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15594), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14708), 2,
      sym_comment,
      sym_block_comment,
  [628016] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16951), 1,
      anon_sym_SEMI,
    ACTIONS(16954), 1,
      anon_sym_else,
    STATE(14709), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 3,
      anon_sym_LBRACK,
      anon_sym_while,
      anon_sym_match,
  [628038] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16957), 1,
      anon_sym_RBRACE,
    ACTIONS(16959), 1,
      anon_sym_COMMA,
    ACTIONS(16961), 1,
      anon_sym_EQ_GT,
    ACTIONS(16963), 1,
      anon_sym_as,
    STATE(15611), 1,
      aux_sym_namespace_selectors_repeat1,
    STATE(14710), 2,
      sym_comment,
      sym_block_comment,
  [628064] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16967), 1,
      anon_sym_EQ,
    STATE(14711), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16965), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628084] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15492), 1,
      anon_sym_while,
    ACTIONS(16969), 1,
      anon_sym_SEMI,
    ACTIONS(16972), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14712), 2,
      sym_comment,
      sym_block_comment,
  [628108] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15492), 1,
      anon_sym_do,
    ACTIONS(16975), 1,
      anon_sym_SEMI,
    ACTIONS(16977), 1,
      anon_sym_else,
    ACTIONS(15494), 2,
      anon_sym_LBRACK,
      anon_sym_match,
    STATE(14713), 2,
      sym_comment,
      sym_block_comment,
  [628132] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14714), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7752), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [628150] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16979), 1,
      anon_sym_COMMA,
    ACTIONS(16982), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
    STATE(14715), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_case_definitions_repeat1,
  [628170] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14716), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16984), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628188] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14717), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16986), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628206] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16988), 1,
      anon_sym_COMMA,
    ACTIONS(16990), 1,
      anon_sym_RPAREN,
    STATE(15204), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14718), 2,
      sym_comment,
      sym_block_comment,
  [628232] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16992), 1,
      anon_sym_COMMA,
    ACTIONS(16994), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15999), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14719), 2,
      sym_comment,
      sym_block_comment,
  [628258] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16996), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628276] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14721), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15588), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [628294] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(16998), 1,
      anon_sym_COMMA,
    ACTIONS(17000), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16125), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14722), 2,
      sym_comment,
      sym_block_comment,
  [628320] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14723), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17002), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628338] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16204), 1,
      anon_sym_COLON,
    ACTIONS(16206), 1,
      anon_sym_LBRACE,
    ACTIONS(16210), 1,
      anon_sym_derives,
    STATE(14975), 1,
      sym_enum_body,
    STATE(15859), 1,
      sym_derives_clause,
    STATE(14724), 2,
      sym_comment,
      sym_block_comment,
  [628364] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14725), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17004), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628382] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17006), 1,
      anon_sym_COMMA,
    ACTIONS(17008), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16208), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14726), 2,
      sym_comment,
      sym_block_comment,
  [628408] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14727), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15518), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [628426] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17010), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628444] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14729), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17012), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628462] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17014), 1,
      anon_sym_COMMA,
    ACTIONS(17016), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15541), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14730), 2,
      sym_comment,
      sym_block_comment,
  [628488] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17018), 1,
      anon_sym_with,
    ACTIONS(8982), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
    STATE(14731), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compound_type_repeat1,
  [628508] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17021), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628526] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17023), 1,
      anon_sym_EQ,
    STATE(14733), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16965), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [628546] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14734), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17025), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628564] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14735), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17027), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628582] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14736), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17029), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628600] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14737), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16598), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [628618] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14738), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17031), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628636] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14739), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16188), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_EQ,
      anon_sym_SEMI,
  [628654] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14740), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17033), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628672] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14741), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15603), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [628690] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17035), 1,
      anon_sym_SEMI,
    ACTIONS(17037), 1,
      anon_sym_else,
    STATE(14742), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15563), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [628712] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14743), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17039), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628730] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14636), 1,
      aux_sym__block_repeat1,
    ACTIONS(659), 2,
      sym__outdent,
      anon_sym_case,
    ACTIONS(17041), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14744), 2,
      sym_comment,
      sym_block_comment,
  [628752] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14745), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17043), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628770] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14746), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9802), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [628788] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14747), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15588), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [628806] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14748), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17045), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628824] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14749), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17047), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628842] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16826), 1,
      anon_sym_SEMI,
    ACTIONS(17049), 1,
      sym__automatic_semicolon,
    STATE(14802), 1,
      aux_sym_enumerators_repeat1,
    ACTIONS(7274), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(14750), 2,
      sym_comment,
      sym_block_comment,
  [628866] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14751), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17051), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [628884] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17053), 1,
      anon_sym_COMMA,
    ACTIONS(17055), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15791), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14752), 2,
      sym_comment,
      sym_block_comment,
  [628910] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    ACTIONS(17057), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14753), 2,
      sym_comment,
      sym_block_comment,
  [628934] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17059), 1,
      anon_sym_COMMA,
    ACTIONS(17061), 1,
      anon_sym_RPAREN,
    STATE(15440), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14754), 2,
      sym_comment,
      sym_block_comment,
  [628960] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17063), 1,
      anon_sym_COMMA,
    ACTIONS(17065), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15662), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14755), 2,
      sym_comment,
      sym_block_comment,
  [628986] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17067), 1,
      anon_sym_SEMI,
    ACTIONS(17069), 1,
      sym__automatic_semicolon,
    STATE(14700), 1,
      aux_sym_enumerators_repeat1,
    ACTIONS(7274), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    STATE(14756), 2,
      sym_comment,
      sym_block_comment,
  [629010] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17071), 1,
      anon_sym_COMMA,
    ACTIONS(17073), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15639), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14757), 2,
      sym_comment,
      sym_block_comment,
  [629036] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17075), 1,
      anon_sym_COMMA,
    ACTIONS(16982), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
    STATE(14758), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enum_case_definitions_repeat1,
  [629056] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16872), 1,
      anon_sym_COMMA,
    STATE(14758), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14759), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16901), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [629078] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17078), 1,
      anon_sym_COLON,
    STATE(14760), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15948), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
      anon_sym_SEMI,
  [629098] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14761), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9806), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [629116] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14762), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15518), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [629134] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14744), 1,
      aux_sym__block_repeat1,
    ACTIONS(15992), 2,
      sym__outdent,
      anon_sym_case,
    ACTIONS(16001), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14763), 2,
      sym_comment,
      sym_block_comment,
  [629156] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14764), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17080), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [629174] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17082), 1,
      anon_sym_COMMA,
    ACTIONS(17084), 1,
      anon_sym_RPAREN,
    STATE(15379), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14765), 2,
      sym_comment,
      sym_block_comment,
  [629200] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16872), 1,
      anon_sym_COMMA,
    STATE(14667), 1,
      aux_sym_enum_case_definitions_repeat1,
    STATE(14766), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16725), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [629222] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17086), 1,
      anon_sym_COMMA,
    ACTIONS(17088), 1,
      anon_sym_RPAREN,
    STATE(15195), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14767), 2,
      sym_comment,
      sym_block_comment,
  [629248] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17090), 1,
      anon_sym_COMMA,
    ACTIONS(17092), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16135), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14768), 2,
      sym_comment,
      sym_block_comment,
  [629274] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16214), 1,
      anon_sym_finally,
    STATE(14214), 1,
      sym_finally_clause,
    STATE(14769), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(13238), 3,
      anon_sym_LBRACK,
      anon_sym_match,
      anon_sym_do,
  [629296] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14770), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16555), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [629314] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    STATE(14680), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(15922), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14771), 2,
      sym_comment,
      sym_block_comment,
  [629338] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14772), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(5136), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [629356] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17094), 1,
      anon_sym_COMMA,
    ACTIONS(17096), 1,
      anon_sym_RPAREN,
    STATE(15505), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14773), 2,
      sym_comment,
      sym_block_comment,
  [629382] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14774), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15608), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [629400] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17098), 1,
      anon_sym_COMMA,
    ACTIONS(17100), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15743), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14775), 2,
      sym_comment,
      sym_block_comment,
  [629426] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17102), 1,
      anon_sym_COMMA,
    ACTIONS(17104), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16312), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14776), 2,
      sym_comment,
      sym_block_comment,
  [629452] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    STATE(14680), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(17106), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14777), 2,
      sym_comment,
      sym_block_comment,
  [629476] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    ACTIONS(17108), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14778), 2,
      sym_comment,
      sym_block_comment,
  [629500] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    ACTIONS(17110), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14779), 2,
      sym_comment,
      sym_block_comment,
  [629524] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14780), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17112), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [629542] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14781), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15555), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [629560] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14782), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15603), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [629578] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14783), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(11675), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [629596] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14784), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17114), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [629614] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14785), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17116), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [629632] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14786), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17118), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [629650] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14787), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17120), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [629668] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14788), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17122), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [629686] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    ACTIONS(17124), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14789), 2,
      sym_comment,
      sym_block_comment,
  [629710] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14790), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15490), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [629728] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16210), 1,
      anon_sym_derives,
    ACTIONS(16237), 1,
      anon_sym_COLON,
    ACTIONS(16239), 1,
      anon_sym_LBRACE,
    STATE(14639), 1,
      sym_enum_body,
    STATE(15575), 1,
      sym_derives_clause,
    STATE(14791), 2,
      sym_comment,
      sym_block_comment,
  [629754] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17126), 1,
      anon_sym_COMMA,
    ACTIONS(17128), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16320), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14792), 2,
      sym_comment,
      sym_block_comment,
  [629780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14793), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17130), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [629798] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17132), 1,
      anon_sym_COMMA,
    ACTIONS(17134), 1,
      anon_sym_RPAREN,
    STATE(15397), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14794), 2,
      sym_comment,
      sym_block_comment,
  [629824] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17136), 1,
      anon_sym_COMMA,
    ACTIONS(17138), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15688), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14795), 2,
      sym_comment,
      sym_block_comment,
  [629850] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17140), 1,
      anon_sym_COMMA,
    ACTIONS(17142), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15869), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14796), 2,
      sym_comment,
      sym_block_comment,
  [629876] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14797), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17144), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [629894] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14798), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9556), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [629912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17148), 1,
      anon_sym_EQ,
    STATE(14799), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17146), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [629932] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17150), 1,
      anon_sym_COMMA,
    ACTIONS(17152), 1,
      anon_sym_RPAREN,
    STATE(15404), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14800), 2,
      sym_comment,
      sym_block_comment,
  [629958] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14801), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17154), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [629976] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16547), 2,
      anon_sym_do,
      anon_sym_yield,
    ACTIONS(17156), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14802), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enumerators_repeat1,
  [629996] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13224), 1,
      anon_sym_COLON,
    STATE(14680), 1,
      aux_sym__type_parameter_repeat2,
    STATE(15366), 1,
      sym_context_bound,
    ACTIONS(17159), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(14803), 2,
      sym_comment,
      sym_block_comment,
  [630020] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    ACTIONS(17161), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14804), 2,
      sym_comment,
      sym_block_comment,
  [630044] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14805), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17163), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [630062] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17165), 1,
      anon_sym_COMMA,
    ACTIONS(17167), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16239), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14806), 2,
      sym_comment,
      sym_block_comment,
  [630088] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17169), 1,
      anon_sym_COMMA,
    ACTIONS(17171), 1,
      anon_sym_RPAREN,
    STATE(15278), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14807), 2,
      sym_comment,
      sym_block_comment,
  [630114] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14808), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [630132] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16210), 1,
      anon_sym_derives,
    ACTIONS(16237), 1,
      anon_sym_COLON,
    ACTIONS(16239), 1,
      anon_sym_LBRACE,
    STATE(14609), 1,
      sym_enum_body,
    STATE(15341), 1,
      sym_derives_clause,
    STATE(14809), 2,
      sym_comment,
      sym_block_comment,
  [630158] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    ACTIONS(17175), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14810), 2,
      sym_comment,
      sym_block_comment,
  [630182] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17177), 1,
      anon_sym_COMMA,
    ACTIONS(17179), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16374), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14811), 2,
      sym_comment,
      sym_block_comment,
  [630208] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14812), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17173), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [630226] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17181), 1,
      anon_sym_COMMA,
    ACTIONS(17183), 1,
      anon_sym_RPAREN,
    STATE(15469), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14813), 2,
      sym_comment,
      sym_block_comment,
  [630252] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17185), 1,
      anon_sym_COMMA,
    ACTIONS(17187), 1,
      anon_sym_RPAREN,
    STATE(15515), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14814), 2,
      sym_comment,
      sym_block_comment,
  [630278] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14815), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17189), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [630296] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14816), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17191), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [630314] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17193), 1,
      anon_sym_COMMA,
    ACTIONS(17195), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15921), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14817), 2,
      sym_comment,
      sym_block_comment,
  [630340] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    ACTIONS(17197), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14818), 2,
      sym_comment,
      sym_block_comment,
  [630364] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14819), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17199), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [630382] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    ACTIONS(17201), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14820), 2,
      sym_comment,
      sym_block_comment,
  [630406] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    ACTIONS(17203), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14821), 2,
      sym_comment,
      sym_block_comment,
  [630430] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14822), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9626), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [630448] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14664), 1,
      aux_sym__block_repeat1,
    ACTIONS(15992), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    ACTIONS(15994), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14823), 2,
      sym_comment,
      sym_block_comment,
  [630470] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14824), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9738), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [630488] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17205), 1,
      anon_sym_COMMA,
    ACTIONS(17207), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16361), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14825), 2,
      sym_comment,
      sym_block_comment,
  [630514] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14826), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10255), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [630532] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17067), 1,
      anon_sym_SEMI,
    ACTIONS(17209), 1,
      sym__automatic_semicolon,
    STATE(14756), 1,
      aux_sym_enumerators_repeat1,
    ACTIONS(16828), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    STATE(14827), 2,
      sym_comment,
      sym_block_comment,
  [630556] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16204), 1,
      anon_sym_COLON,
    ACTIONS(16206), 1,
      anon_sym_LBRACE,
    ACTIONS(16210), 1,
      anon_sym_derives,
    STATE(15103), 1,
      sym_enum_body,
    STATE(15895), 1,
      sym_derives_clause,
    STATE(14828), 2,
      sym_comment,
      sym_block_comment,
  [630582] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17211), 1,
      anon_sym_COMMA,
    ACTIONS(17213), 1,
      anon_sym_RPAREN,
    STATE(15416), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14829), 2,
      sym_comment,
      sym_block_comment,
  [630608] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17215), 1,
      anon_sym_COMMA,
    ACTIONS(17217), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15715), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14830), 2,
      sym_comment,
      sym_block_comment,
  [630634] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    ACTIONS(17219), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14831), 2,
      sym_comment,
      sym_block_comment,
  [630658] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14832), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16648), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [630676] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14833), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15603), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [630694] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17221), 1,
      anon_sym_COMMA,
    ACTIONS(17223), 1,
      anon_sym_RPAREN,
    STATE(15314), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14834), 2,
      sym_comment,
      sym_block_comment,
  [630720] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    ACTIONS(17225), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14835), 2,
      sym_comment,
      sym_block_comment,
  [630744] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17227), 1,
      anon_sym_COMMA,
    ACTIONS(17229), 1,
      anon_sym_RPAREN,
    STATE(15415), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14836), 2,
      sym_comment,
      sym_block_comment,
  [630770] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17231), 1,
      anon_sym_COMMA,
    ACTIONS(17233), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15958), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14837), 2,
      sym_comment,
      sym_block_comment,
  [630796] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16961), 1,
      anon_sym_EQ_GT,
    ACTIONS(16963), 1,
      anon_sym_as,
    ACTIONS(17235), 1,
      anon_sym_RBRACE,
    ACTIONS(17237), 1,
      anon_sym_COMMA,
    STATE(15908), 1,
      aux_sym_namespace_selectors_repeat1,
    STATE(14838), 2,
      sym_comment,
      sym_block_comment,
  [630822] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14839), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15490), 5,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [630840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14840), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17239), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [630858] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17241), 1,
      anon_sym_COMMA,
    ACTIONS(17243), 1,
      anon_sym_RPAREN,
    STATE(15433), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14841), 2,
      sym_comment,
      sym_block_comment,
  [630884] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17245), 1,
      anon_sym_COMMA,
    ACTIONS(17247), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(16248), 1,
      aux_sym_tuple_type_repeat1,
    STATE(14842), 2,
      sym_comment,
      sym_block_comment,
  [630910] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14843), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17249), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [630928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17251), 1,
      anon_sym_EQ,
    STATE(14844), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17146), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [630948] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14845), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15555), 5,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_extends,
      anon_sym_LPAREN,
      anon_sym_SEMI,
  [630966] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17253), 1,
      anon_sym_COMMA,
    ACTIONS(17255), 1,
      anon_sym_RPAREN,
    STATE(15368), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14846), 2,
      sym_comment,
      sym_block_comment,
  [630992] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14847), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17257), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [631010] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14848), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17259), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [631028] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14849), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17261), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [631046] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6232), 1,
      anon_sym_LBRACE,
    ACTIONS(12970), 1,
      anon_sym_COLON,
    STATE(14605), 1,
      sym_template_body,
    STATE(6773), 2,
      sym__indented_template_body,
      sym__braced_template_body,
    STATE(14850), 2,
      sym_comment,
      sym_block_comment,
  [631070] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14851), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9829), 5,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_derives,
      anon_sym_LPAREN,
  [631088] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14852), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17263), 5,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [631106] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16646), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14853), 2,
      sym_comment,
      sym_block_comment,
  [631129] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14854), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(4180), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
  [631146] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15992), 1,
      sym__outdent,
    STATE(14891), 1,
      aux_sym__block_repeat1,
    ACTIONS(16371), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14855), 2,
      sym_comment,
      sym_block_comment,
  [631167] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17265), 1,
      anon_sym_LBRACE,
    ACTIONS(17267), 1,
      sym__indent,
    STATE(13655), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14856), 2,
      sym_comment,
      sym_block_comment,
  [631188] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14857), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16771), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [631205] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14858), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16741), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [631222] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14859), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16458), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_if,
      anon_sym_SEMI,
  [631239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17269), 1,
      anon_sym_LBRACE,
    ACTIONS(17271), 1,
      sym__indent,
    STATE(12764), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14860), 2,
      sym_comment,
      sym_block_comment,
  [631260] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17273), 1,
      anon_sym_RBRACE,
    ACTIONS(17275), 1,
      anon_sym_case,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14861), 2,
      sym_comment,
      sym_block_comment,
  [631283] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17279), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14862), 2,
      sym_comment,
      sym_block_comment,
  [631306] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14863), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16882), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [631323] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16478), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14864), 2,
      sym_comment,
      sym_block_comment,
  [631346] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14865), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16846), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [631363] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17281), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14866), 2,
      sym_comment,
      sym_block_comment,
  [631386] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17283), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14867), 2,
      sym_comment,
      sym_block_comment,
  [631409] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17285), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14868), 2,
      sym_comment,
      sym_block_comment,
  [631432] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16635), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14869), 2,
      sym_comment,
      sym_block_comment,
  [631455] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17287), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14870), 2,
      sym_comment,
      sym_block_comment,
  [631478] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17291), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(14871), 2,
      sym_comment,
      sym_block_comment,
  [631501] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17293), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14872), 2,
      sym_comment,
      sym_block_comment,
  [631524] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14873), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7064), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RPAREN,
  [631541] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17295), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(14874), 2,
      sym_comment,
      sym_block_comment,
  [631564] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17297), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14875), 2,
      sym_comment,
      sym_block_comment,
  [631587] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17299), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14876), 2,
      sym_comment,
      sym_block_comment,
  [631610] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14877), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16751), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [631627] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17301), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(14878), 2,
      sym_comment,
      sym_block_comment,
  [631650] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14879), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16982), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [631667] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14880), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17029), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [631684] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17303), 1,
      anon_sym_RBRACE,
    ACTIONS(17305), 1,
      anon_sym_case,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14881), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_indented_cases_repeat1,
  [631705] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17265), 1,
      anon_sym_LBRACE,
    ACTIONS(17267), 1,
      sym__indent,
    STATE(13696), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14882), 2,
      sym_comment,
      sym_block_comment,
  [631726] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17308), 1,
      anon_sym_LBRACE,
    ACTIONS(17310), 1,
      sym__indent,
    STATE(12396), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14883), 2,
      sym_comment,
      sym_block_comment,
  [631747] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17312), 1,
      anon_sym_RBRACE,
    STATE(15036), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14884), 2,
      sym_comment,
      sym_block_comment,
  [631770] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17314), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14885), 2,
      sym_comment,
      sym_block_comment,
  [631793] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14886), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17039), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [631810] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17269), 1,
      anon_sym_LBRACE,
    ACTIONS(17271), 1,
      sym__indent,
    STATE(12719), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14887), 2,
      sym_comment,
      sym_block_comment,
  [631831] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17316), 1,
      anon_sym_RBRACE,
    STATE(14937), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14888), 2,
      sym_comment,
      sym_block_comment,
  [631854] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(659), 1,
      anon_sym_RBRACE,
    STATE(15072), 1,
      aux_sym__block_repeat1,
    ACTIONS(17318), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14889), 2,
      sym_comment,
      sym_block_comment,
  [631875] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14890), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17163), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [631892] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(659), 1,
      sym__outdent,
    STATE(14978), 1,
      aux_sym__block_repeat1,
    ACTIONS(17320), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14891), 2,
      sym_comment,
      sym_block_comment,
  [631913] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17303), 1,
      sym__outdent,
    ACTIONS(17322), 1,
      anon_sym_case,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14892), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_indented_cases_repeat1,
  [631934] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14893), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16814), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [631951] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(17325), 1,
      anon_sym_COLON,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(14894), 2,
      sym_comment,
      sym_block_comment,
  [631974] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14895), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17261), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [631991] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14896), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17259), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [632008] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17327), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14897), 2,
      sym_comment,
      sym_block_comment,
  [632031] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17331), 1,
      anon_sym_EQ,
    ACTIONS(17329), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14898), 2,
      sym_comment,
      sym_block_comment,
  [632052] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17333), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14899), 2,
      sym_comment,
      sym_block_comment,
  [632075] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(17335), 1,
      anon_sym_COLON,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(14900), 2,
      sym_comment,
      sym_block_comment,
  [632098] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14901), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16088), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [632115] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17337), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(14902), 2,
      sym_comment,
      sym_block_comment,
  [632138] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17339), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(14903), 2,
      sym_comment,
      sym_block_comment,
  [632161] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17341), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14904), 2,
      sym_comment,
      sym_block_comment,
  [632184] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17343), 1,
      anon_sym_RBRACE,
    STATE(15190), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14905), 2,
      sym_comment,
      sym_block_comment,
  [632207] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17345), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14906), 2,
      sym_comment,
      sym_block_comment,
  [632230] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17349), 1,
      anon_sym_EQ,
    ACTIONS(17347), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14907), 2,
      sym_comment,
      sym_block_comment,
  [632251] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17351), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(14908), 2,
      sym_comment,
      sym_block_comment,
  [632274] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16686), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14909), 2,
      sym_comment,
      sym_block_comment,
  [632297] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17353), 1,
      anon_sym_LBRACE,
    ACTIONS(17355), 1,
      sym__indent,
    STATE(14055), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14910), 2,
      sym_comment,
      sym_block_comment,
  [632318] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16591), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14911), 2,
      sym_comment,
      sym_block_comment,
  [632341] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17357), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14912), 2,
      sym_comment,
      sym_block_comment,
  [632364] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(17359), 1,
      anon_sym_COLON,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(14913), 2,
      sym_comment,
      sym_block_comment,
  [632387] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17361), 1,
      anon_sym_RBRACE,
    STATE(14926), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14914), 2,
      sym_comment,
      sym_block_comment,
  [632410] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17363), 1,
      anon_sym_LBRACE,
    ACTIONS(17365), 1,
      sym__indent,
    STATE(14369), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14915), 2,
      sym_comment,
      sym_block_comment,
  [632431] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17369), 1,
      anon_sym_EQ,
    ACTIONS(17367), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14916), 2,
      sym_comment,
      sym_block_comment,
  [632452] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17371), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14917), 2,
      sym_comment,
      sym_block_comment,
  [632475] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14918), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17154), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [632492] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17373), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14919), 2,
      sym_comment,
      sym_block_comment,
  [632515] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(463), 1,
      ts_builtin_sym_end,
    STATE(15034), 1,
      aux_sym_compilation_unit_repeat1,
    ACTIONS(17375), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14920), 2,
      sym_comment,
      sym_block_comment,
  [632536] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17377), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14921), 2,
      sym_comment,
      sym_block_comment,
  [632559] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17379), 1,
      anon_sym_SEMI,
    ACTIONS(17381), 1,
      sym__automatic_semicolon,
    ACTIONS(17383), 1,
      sym__outdent,
    STATE(15155), 1,
      aux_sym_enumerators_repeat1,
    STATE(14922), 2,
      sym_comment,
      sym_block_comment,
  [632582] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17385), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14923), 2,
      sym_comment,
      sym_block_comment,
  [632605] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17387), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14924), 2,
      sym_comment,
      sym_block_comment,
  [632628] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14925), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17112), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [632645] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17389), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14926), 2,
      sym_comment,
      sym_block_comment,
  [632668] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17391), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14927), 2,
      sym_comment,
      sym_block_comment,
  [632691] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17393), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14928), 2,
      sym_comment,
      sym_block_comment,
  [632714] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16961), 1,
      anon_sym_EQ_GT,
    ACTIONS(16963), 1,
      anon_sym_as,
    ACTIONS(17395), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(14929), 2,
      sym_comment,
      sym_block_comment,
  [632735] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17397), 1,
      anon_sym_LBRACE,
    ACTIONS(17399), 1,
      sym__indent,
    STATE(14254), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14930), 2,
      sym_comment,
      sym_block_comment,
  [632756] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17401), 1,
      anon_sym_LBRACE,
    ACTIONS(17403), 1,
      sym__indent,
    STATE(13871), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14931), 2,
      sym_comment,
      sym_block_comment,
  [632777] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17405), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(14932), 2,
      sym_comment,
      sym_block_comment,
  [632800] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17407), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14933), 2,
      sym_comment,
      sym_block_comment,
  [632823] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17409), 1,
      anon_sym_LBRACE,
    ACTIONS(17411), 1,
      sym__indent,
    STATE(13057), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14934), 2,
      sym_comment,
      sym_block_comment,
  [632844] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17413), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14935), 2,
      sym_comment,
      sym_block_comment,
  [632867] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16192), 1,
      sym__outdent,
    STATE(15061), 1,
      aux_sym__enum_block_repeat1,
    ACTIONS(16435), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14936), 2,
      sym_comment,
      sym_block_comment,
  [632888] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17415), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14937), 2,
      sym_comment,
      sym_block_comment,
  [632911] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14938), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17025), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [632928] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14939), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17021), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [632945] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17417), 1,
      anon_sym_COLON,
    ACTIONS(17421), 1,
      anon_sym_EQ,
    ACTIONS(17419), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14940), 2,
      sym_comment,
      sym_block_comment,
  [632966] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17363), 1,
      anon_sym_LBRACE,
    ACTIONS(17365), 1,
      sym__indent,
    STATE(14408), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14941), 2,
      sym_comment,
      sym_block_comment,
  [632987] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17423), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14942), 2,
      sym_comment,
      sym_block_comment,
  [633010] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14943), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17199), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [633027] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17308), 1,
      anon_sym_LBRACE,
    ACTIONS(17310), 1,
      sym__indent,
    STATE(12277), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14944), 2,
      sym_comment,
      sym_block_comment,
  [633048] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17425), 1,
      anon_sym_RBRACE,
    STATE(15166), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14945), 2,
      sym_comment,
      sym_block_comment,
  [633071] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17427), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14946), 2,
      sym_comment,
      sym_block_comment,
  [633094] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17431), 1,
      anon_sym_EQ,
    ACTIONS(17429), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14947), 2,
      sym_comment,
      sym_block_comment,
  [633115] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17433), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14948), 2,
      sym_comment,
      sym_block_comment,
  [633138] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17435), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14949), 2,
      sym_comment,
      sym_block_comment,
  [633161] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14950), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(10021), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [633178] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17439), 1,
      anon_sym_COMMA,
    ACTIONS(17437), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    STATE(14951), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_identifiers_repeat1,
  [633197] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14952), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16907), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [633214] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17353), 1,
      anon_sym_LBRACE,
    ACTIONS(17355), 1,
      sym__indent,
    STATE(14083), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14953), 2,
      sym_comment,
      sym_block_comment,
  [633235] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14954), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16899), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [633252] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14955), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16892), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [633269] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17442), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14956), 2,
      sym_comment,
      sym_block_comment,
  [633292] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17401), 1,
      anon_sym_LBRACE,
    ACTIONS(17403), 1,
      sym__indent,
    STATE(13749), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14957), 2,
      sym_comment,
      sym_block_comment,
  [633313] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17444), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14958), 2,
      sym_comment,
      sym_block_comment,
  [633336] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17446), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14959), 2,
      sym_comment,
      sym_block_comment,
  [633359] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17448), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14960), 2,
      sym_comment,
      sym_block_comment,
  [633382] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17397), 1,
      anon_sym_LBRACE,
    ACTIONS(17399), 1,
      sym__indent,
    STATE(14125), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14961), 2,
      sym_comment,
      sym_block_comment,
  [633403] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17450), 1,
      anon_sym_RBRACE,
    STATE(14899), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14962), 2,
      sym_comment,
      sym_block_comment,
  [633426] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17452), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14963), 2,
      sym_comment,
      sym_block_comment,
  [633449] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17454), 1,
      anon_sym_COMMA,
    ACTIONS(17456), 1,
      anon_sym_RPAREN,
    STATE(15984), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(14964), 2,
      sym_comment,
      sym_block_comment,
  [633472] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17458), 1,
      anon_sym_RBRACE,
    STATE(15183), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14965), 2,
      sym_comment,
      sym_block_comment,
  [633495] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17460), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14966), 2,
      sym_comment,
      sym_block_comment,
  [633518] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17462), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14967), 2,
      sym_comment,
      sym_block_comment,
  [633541] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14968), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16765), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [633558] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14969), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17464), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_do,
      anon_sym_yield,
  [633575] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17466), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(14970), 2,
      sym_comment,
      sym_block_comment,
  [633598] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(463), 1,
      ts_builtin_sym_end,
    STATE(14987), 1,
      aux_sym_compilation_unit_repeat1,
    ACTIONS(17375), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14971), 2,
      sym_comment,
      sym_block_comment,
  [633619] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17468), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14972), 2,
      sym_comment,
      sym_block_comment,
  [633642] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17470), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(14973), 2,
      sym_comment,
      sym_block_comment,
  [633665] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17474), 1,
      anon_sym_EQ,
    ACTIONS(17472), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(14974), 2,
      sym_comment,
      sym_block_comment,
  [633686] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14975), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16739), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [633703] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14976), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16727), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [633720] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14977), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16190), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [633737] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16190), 1,
      sym__outdent,
    ACTIONS(17476), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14978), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__block_repeat1,
  [633756] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16631), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14979), 2,
      sym_comment,
      sym_block_comment,
  [633779] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14980), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16729), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [633796] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14981), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16731), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [633813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14982), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16737), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [633830] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17479), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14983), 2,
      sym_comment,
      sym_block_comment,
  [633853] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16521), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14984), 2,
      sym_comment,
      sym_block_comment,
  [633876] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17481), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(14985), 2,
      sym_comment,
      sym_block_comment,
  [633899] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17483), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(14986), 2,
      sym_comment,
      sym_block_comment,
  [633922] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17485), 1,
      ts_builtin_sym_end,
    ACTIONS(17487), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(14987), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_compilation_unit_repeat1,
  [633941] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17490), 1,
      anon_sym_LBRACE,
    ACTIONS(17492), 1,
      sym__indent,
    STATE(14397), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(14988), 2,
      sym_comment,
      sym_block_comment,
  [633962] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17494), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14989), 2,
      sym_comment,
      sym_block_comment,
  [633985] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17496), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14990), 2,
      sym_comment,
      sym_block_comment,
  [634008] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16488), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(14991), 2,
      sym_comment,
      sym_block_comment,
  [634031] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17498), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(14992), 2,
      sym_comment,
      sym_block_comment,
  [634054] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17500), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14993), 2,
      sym_comment,
      sym_block_comment,
  [634077] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17502), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(14994), 2,
      sym_comment,
      sym_block_comment,
  [634100] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14995), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16996), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [634117] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14996), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16190), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_SEMI,
  [634134] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14997), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17002), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [634151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17504), 1,
      anon_sym_EQ,
    STATE(14998), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16965), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [634170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17506), 1,
      anon_sym_COMMA,
    ACTIONS(15884), 2,
      anon_sym_COLON,
      anon_sym_LBRACE,
    STATE(14999), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_derives_clause_repeat1,
  [634189] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16661), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15000), 2,
      sym_comment,
      sym_block_comment,
  [634212] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15001), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17033), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [634229] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17509), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15002), 2,
      sym_comment,
      sym_block_comment,
  [634252] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15003), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17045), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [634269] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17511), 1,
      anon_sym_case,
    ACTIONS(17514), 1,
      sym__outdent,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15004), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__indented_type_cases_repeat1,
  [634290] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17516), 1,
      anon_sym_EQ,
    STATE(15005), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17146), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [634309] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17518), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15006), 2,
      sym_comment,
      sym_block_comment,
  [634332] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17520), 1,
      anon_sym_RBRACE,
    STATE(15189), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15007), 2,
      sym_comment,
      sym_block_comment,
  [634355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17522), 1,
      anon_sym_LBRACE,
    ACTIONS(17524), 1,
      sym__indent,
    STATE(13960), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15008), 2,
      sym_comment,
      sym_block_comment,
  [634376] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17526), 1,
      anon_sym_LBRACE,
    ACTIONS(17528), 1,
      sym__indent,
    STATE(12260), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15009), 2,
      sym_comment,
      sym_block_comment,
  [634397] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16659), 1,
      anon_sym_RBRACE,
    ACTIONS(17530), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(15010), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__enum_block_repeat1,
  [634416] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17533), 1,
      anon_sym_RBRACE,
    STATE(15104), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15011), 2,
      sym_comment,
      sym_block_comment,
  [634439] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17535), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15012), 2,
      sym_comment,
      sym_block_comment,
  [634462] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17537), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15013), 2,
      sym_comment,
      sym_block_comment,
  [634485] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17539), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15014), 2,
      sym_comment,
      sym_block_comment,
  [634508] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17541), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15015), 2,
      sym_comment,
      sym_block_comment,
  [634531] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17543), 1,
      anon_sym_LBRACE,
    ACTIONS(17545), 1,
      sym__indent,
    STATE(14193), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15016), 2,
      sym_comment,
      sym_block_comment,
  [634552] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17547), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15017), 2,
      sym_comment,
      sym_block_comment,
  [634575] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17526), 1,
      anon_sym_LBRACE,
    ACTIONS(17528), 1,
      sym__indent,
    STATE(12354), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15018), 2,
      sym_comment,
      sym_block_comment,
  [634596] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17549), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15019), 2,
      sym_comment,
      sym_block_comment,
  [634619] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17551), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15020), 2,
      sym_comment,
      sym_block_comment,
  [634642] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17553), 1,
      anon_sym_RBRACE,
    STATE(14960), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15021), 2,
      sym_comment,
      sym_block_comment,
  [634665] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17555), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15022), 2,
      sym_comment,
      sym_block_comment,
  [634688] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15023), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17557), 4,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [634705] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16547), 1,
      sym__outdent,
    ACTIONS(17559), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(15024), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_enumerators_repeat1,
  [634724] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17562), 1,
      anon_sym_COLON,
    ACTIONS(17566), 1,
      anon_sym_EQ,
    ACTIONS(17564), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15025), 2,
      sym_comment,
      sym_block_comment,
  [634745] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17570), 1,
      anon_sym_EQ,
    ACTIONS(17568), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15026), 2,
      sym_comment,
      sym_block_comment,
  [634766] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15027), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17173), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [634783] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15028), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17173), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [634800] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15029), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17191), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [634817] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15030), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16513), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_PERCENT,
  [634834] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17522), 1,
      anon_sym_LBRACE,
    ACTIONS(17524), 1,
      sym__indent,
    STATE(13952), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15031), 2,
      sym_comment,
      sym_block_comment,
  [634855] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17572), 1,
      anon_sym_RBRACE,
    STATE(15158), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15032), 2,
      sym_comment,
      sym_block_comment,
  [634878] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17574), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15033), 2,
      sym_comment,
      sym_block_comment,
  [634901] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(455), 1,
      ts_builtin_sym_end,
    STATE(14987), 1,
      aux_sym_compilation_unit_repeat1,
    ACTIONS(17576), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(15034), 2,
      sym_comment,
      sym_block_comment,
  [634922] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17578), 1,
      anon_sym_EQ,
    STATE(15035), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16840), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [634941] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17580), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15036), 2,
      sym_comment,
      sym_block_comment,
  [634964] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17543), 1,
      anon_sym_LBRACE,
    ACTIONS(17545), 1,
      sym__indent,
    STATE(14274), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15037), 2,
      sym_comment,
      sym_block_comment,
  [634985] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15038), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17010), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635002] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17582), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15039), 2,
      sym_comment,
      sym_block_comment,
  [635025] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17584), 1,
      anon_sym_COLON,
    ACTIONS(17588), 1,
      anon_sym_EQ,
    ACTIONS(17586), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15040), 2,
      sym_comment,
      sym_block_comment,
  [635046] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17592), 1,
      anon_sym_COMMA,
    STATE(14951), 1,
      aux_sym_identifiers_repeat1,
    ACTIONS(17590), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    STATE(15041), 2,
      sym_comment,
      sym_block_comment,
  [635067] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15042), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17263), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635084] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15043), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17257), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635101] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17409), 1,
      anon_sym_LBRACE,
    ACTIONS(17411), 1,
      sym__indent,
    STATE(13123), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15044), 2,
      sym_comment,
      sym_block_comment,
  [635122] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15045), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17249), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635139] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15046), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17239), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635156] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17594), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15047), 2,
      sym_comment,
      sym_block_comment,
  [635179] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17596), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15048), 2,
      sym_comment,
      sym_block_comment,
  [635202] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16192), 1,
      anon_sym_RBRACE,
    STATE(15157), 1,
      aux_sym__enum_block_repeat1,
    ACTIONS(16194), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(15049), 2,
      sym_comment,
      sym_block_comment,
  [635223] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17598), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15050), 2,
      sym_comment,
      sym_block_comment,
  [635246] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17600), 1,
      anon_sym_DOT,
    STATE(15051), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7562), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
  [635265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17602), 1,
      anon_sym_COMMA,
    STATE(15142), 1,
      aux_sym_derives_clause_repeat1,
    ACTIONS(15755), 2,
      anon_sym_COLON,
      anon_sym_LBRACE,
    STATE(15052), 2,
      sym_comment,
      sym_block_comment,
  [635286] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15053), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17144), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635303] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16606), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15054), 2,
      sym_comment,
      sym_block_comment,
  [635326] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15055), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17122), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635343] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15056), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17114), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635360] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15057), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17189), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635377] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17604), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15058), 2,
      sym_comment,
      sym_block_comment,
  [635400] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17606), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15059), 2,
      sym_comment,
      sym_block_comment,
  [635423] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17608), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15060), 2,
      sym_comment,
      sym_block_comment,
  [635446] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(679), 1,
      sym__outdent,
    STATE(15115), 1,
      aux_sym__enum_block_repeat1,
    ACTIONS(17610), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(15061), 2,
      sym_comment,
      sym_block_comment,
  [635467] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17612), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15062), 2,
      sym_comment,
      sym_block_comment,
  [635490] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15063), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17080), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635507] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16496), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15064), 2,
      sym_comment,
      sym_block_comment,
  [635530] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17614), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15065), 2,
      sym_comment,
      sym_block_comment,
  [635553] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15066), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17012), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635570] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15067), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17616), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_do,
      anon_sym_yield,
  [635587] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17618), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15068), 2,
      sym_comment,
      sym_block_comment,
  [635610] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15069), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16986), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635627] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17620), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15070), 2,
      sym_comment,
      sym_block_comment,
  [635650] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16679), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15071), 2,
      sym_comment,
      sym_block_comment,
  [635673] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16190), 1,
      anon_sym_RBRACE,
    ACTIONS(17622), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(15072), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__block_repeat1,
  [635692] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17625), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15073), 2,
      sym_comment,
      sym_block_comment,
  [635715] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17627), 1,
      anon_sym_LBRACE,
    ACTIONS(17629), 1,
      sym__indent,
    STATE(13414), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15074), 2,
      sym_comment,
      sym_block_comment,
  [635736] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17631), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15075), 2,
      sym_comment,
      sym_block_comment,
  [635759] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17633), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15076), 2,
      sym_comment,
      sym_block_comment,
  [635782] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17635), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15077), 2,
      sym_comment,
      sym_block_comment,
  [635805] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(17637), 1,
      anon_sym_COLON,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(15078), 2,
      sym_comment,
      sym_block_comment,
  [635828] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15079), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17004), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635845] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15080), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16717), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [635862] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17639), 1,
      anon_sym_RBRACE,
    STATE(14868), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15081), 2,
      sym_comment,
      sym_block_comment,
  [635885] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17490), 1,
      anon_sym_LBRACE,
    ACTIONS(17492), 1,
      sym__indent,
    STATE(14432), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15082), 2,
      sym_comment,
      sym_block_comment,
  [635906] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17641), 1,
      anon_sym_LBRACE,
    ACTIONS(17643), 1,
      sym__indent,
    STATE(13927), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15083), 2,
      sym_comment,
      sym_block_comment,
  [635927] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17627), 1,
      anon_sym_LBRACE,
    ACTIONS(17629), 1,
      sym__indent,
    STATE(13437), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15084), 2,
      sym_comment,
      sym_block_comment,
  [635948] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17645), 1,
      anon_sym_RBRACE,
    STATE(14861), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15085), 2,
      sym_comment,
      sym_block_comment,
  [635971] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(17647), 1,
      anon_sym_COLON,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(15086), 2,
      sym_comment,
      sym_block_comment,
  [635994] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16480), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15087), 2,
      sym_comment,
      sym_block_comment,
  [636017] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16486), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15088), 2,
      sym_comment,
      sym_block_comment,
  [636040] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15089), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16777), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636057] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15090), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16777), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636074] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17649), 1,
      anon_sym_COMMA,
    ACTIONS(17652), 2,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(15091), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_tuple_type_repeat1,
  [636093] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17656), 1,
      anon_sym_EQ,
    ACTIONS(17654), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15092), 2,
      sym_comment,
      sym_block_comment,
  [636114] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17658), 1,
      anon_sym_RBRACE,
    STATE(15059), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15093), 2,
      sym_comment,
      sym_block_comment,
  [636137] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16671), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15094), 2,
      sym_comment,
      sym_block_comment,
  [636160] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15095), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16791), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636177] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15096), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16791), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636194] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17660), 1,
      anon_sym_COLON,
    ACTIONS(17664), 1,
      anon_sym_EQ,
    ACTIONS(17662), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15097), 2,
      sym_comment,
      sym_block_comment,
  [636215] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15098), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16793), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636232] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17666), 1,
      anon_sym_RBRACE,
    STATE(14935), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15099), 2,
      sym_comment,
      sym_block_comment,
  [636255] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15100), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16795), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636272] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17668), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15101), 2,
      sym_comment,
      sym_block_comment,
  [636295] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17670), 1,
      anon_sym_LBRACE,
    ACTIONS(17672), 1,
      sym__indent,
    STATE(13127), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15102), 2,
      sym_comment,
      sym_block_comment,
  [636316] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15103), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16804), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636333] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17674), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15104), 2,
      sym_comment,
      sym_block_comment,
  [636356] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15105), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16711), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636373] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15106), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16816), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636390] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15107), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16818), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636407] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15108), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16820), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636424] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15992), 1,
      anon_sym_RBRACE,
    STATE(14889), 1,
      aux_sym__block_repeat1,
    ACTIONS(16373), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(15109), 2,
      sym_comment,
      sym_block_comment,
  [636445] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15110), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17676), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_PERCENT,
  [636462] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15111), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17557), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [636479] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17678), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15112), 2,
      sym_comment,
      sym_block_comment,
  [636502] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14685), 1,
      anon_sym_LPAREN,
    ACTIONS(17680), 1,
      sym__automatic_semicolon,
    STATE(14078), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14665), 1,
      sym_class_parameters,
    STATE(15113), 2,
      sym_comment,
      sym_block_comment,
  [636525] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17682), 1,
      anon_sym_COLON,
    ACTIONS(17685), 1,
      anon_sym_COMMA,
    ACTIONS(17688), 1,
      anon_sym_EQ,
    STATE(15041), 1,
      aux_sym_identifiers_repeat1,
    STATE(15114), 2,
      sym_comment,
      sym_block_comment,
  [636548] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16659), 1,
      sym__outdent,
    ACTIONS(17690), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(15115), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__enum_block_repeat1,
  [636567] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17693), 1,
      anon_sym_LBRACE,
    ACTIONS(17695), 1,
      sym__indent,
    STATE(11856), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15116), 2,
      sym_comment,
      sym_block_comment,
  [636588] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17697), 1,
      anon_sym_COMMA,
    ACTIONS(17699), 1,
      anon_sym_RPAREN,
    STATE(15532), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15117), 2,
      sym_comment,
      sym_block_comment,
  [636611] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17701), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15118), 2,
      sym_comment,
      sym_block_comment,
  [636634] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15119), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17703), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LT_PERCENT,
  [636651] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17705), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15120), 2,
      sym_comment,
      sym_block_comment,
  [636674] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(17707), 1,
      anon_sym_COMMA,
    ACTIONS(17709), 1,
      anon_sym_RPAREN,
    STATE(15893), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15121), 2,
      sym_comment,
      sym_block_comment,
  [636697] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15122), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16984), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636714] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17711), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15123), 2,
      sym_comment,
      sym_block_comment,
  [636737] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17713), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15124), 2,
      sym_comment,
      sym_block_comment,
  [636760] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17715), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15125), 2,
      sym_comment,
      sym_block_comment,
  [636783] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17717), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15126), 2,
      sym_comment,
      sym_block_comment,
  [636806] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15127), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17027), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636823] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15128), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17031), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636840] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17719), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15129), 2,
      sym_comment,
      sym_block_comment,
  [636863] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17721), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15130), 2,
      sym_comment,
      sym_block_comment,
  [636886] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15131), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17130), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636903] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15132), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17043), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636920] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15133), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17047), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636937] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15134), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17051), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636954] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16625), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15135), 2,
      sym_comment,
      sym_block_comment,
  [636977] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15136), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16852), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [636994] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(17723), 1,
      anon_sym_COLON,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(15137), 2,
      sym_comment,
      sym_block_comment,
  [637017] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15138), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16982), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [637034] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(17725), 1,
      anon_sym_COLON,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(15139), 2,
      sym_comment,
      sym_block_comment,
  [637057] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    ACTIONS(17727), 1,
      anon_sym_COLON,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(15140), 2,
      sym_comment,
      sym_block_comment,
  [637080] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15141), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(9315), 4,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_with,
      anon_sym_LPAREN,
  [637097] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17602), 1,
      anon_sym_COMMA,
    STATE(14999), 1,
      aux_sym_derives_clause_repeat1,
    ACTIONS(15807), 2,
      anon_sym_COLON,
      anon_sym_LBRACE,
    STATE(15142), 2,
      sym_comment,
      sym_block_comment,
  [637118] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17729), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15143), 2,
      sym_comment,
      sym_block_comment,
  [637141] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17693), 1,
      anon_sym_LBRACE,
    ACTIONS(17695), 1,
      sym__indent,
    STATE(11896), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15144), 2,
      sym_comment,
      sym_block_comment,
  [637162] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15145), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17116), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [637179] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17731), 1,
      anon_sym_RBRACE,
    STATE(15058), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15146), 2,
      sym_comment,
      sym_block_comment,
  [637202] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17733), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15147), 2,
      sym_comment,
      sym_block_comment,
  [637225] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(483), 1,
      ts_builtin_sym_end,
    STATE(14971), 1,
      aux_sym_compilation_unit_repeat1,
    ACTIONS(17735), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(15148), 2,
      sym_comment,
      sym_block_comment,
  [637246] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17737), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15149), 2,
      sym_comment,
      sym_block_comment,
  [637269] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17670), 1,
      anon_sym_LBRACE,
    ACTIONS(17672), 1,
      sym__indent,
    STATE(13152), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15150), 2,
      sym_comment,
      sym_block_comment,
  [637290] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15151), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17118), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [637307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15152), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(7280), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_do,
      anon_sym_yield,
  [637324] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17641), 1,
      anon_sym_LBRACE,
    ACTIONS(17643), 1,
      sym__indent,
    STATE(13764), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15153), 2,
      sym_comment,
      sym_block_comment,
  [637345] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15154), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17120), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_case,
      anon_sym_SEMI,
  [637362] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7292), 1,
      sym__outdent,
    ACTIONS(17379), 1,
      anon_sym_SEMI,
    ACTIONS(17739), 1,
      sym__automatic_semicolon,
    STATE(15024), 1,
      aux_sym_enumerators_repeat1,
    STATE(15155), 2,
      sym_comment,
      sym_block_comment,
  [637385] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17741), 1,
      anon_sym_LBRACE,
    ACTIONS(17743), 1,
      sym__indent,
    STATE(13953), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15156), 2,
      sym_comment,
      sym_block_comment,
  [637406] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(679), 1,
      anon_sym_RBRACE,
    STATE(15010), 1,
      aux_sym__enum_block_repeat1,
    ACTIONS(17745), 2,
      sym__automatic_semicolon,
      anon_sym_SEMI,
    STATE(15157), 2,
      sym_comment,
      sym_block_comment,
  [637427] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17747), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15158), 2,
      sym_comment,
      sym_block_comment,
  [637450] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17749), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15159), 2,
      sym_comment,
      sym_block_comment,
  [637473] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17751), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15160), 2,
      sym_comment,
      sym_block_comment,
  [637496] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17753), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15161), 2,
      sym_comment,
      sym_block_comment,
  [637519] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16468), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15162), 2,
      sym_comment,
      sym_block_comment,
  [637542] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17755), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15163), 2,
      sym_comment,
      sym_block_comment,
  [637565] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17757), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15164), 2,
      sym_comment,
      sym_block_comment,
  [637588] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17759), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15165), 2,
      sym_comment,
      sym_block_comment,
  [637611] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17761), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15166), 2,
      sym_comment,
      sym_block_comment,
  [637634] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17763), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15167), 2,
      sym_comment,
      sym_block_comment,
  [637657] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17741), 1,
      anon_sym_LBRACE,
    ACTIONS(17743), 1,
      sym__indent,
    STATE(13917), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15168), 2,
      sym_comment,
      sym_block_comment,
  [637678] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17765), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15169), 2,
      sym_comment,
      sym_block_comment,
  [637701] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17767), 1,
      anon_sym_RBRACE,
    STATE(15068), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15170), 2,
      sym_comment,
      sym_block_comment,
  [637724] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17769), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15171), 2,
      sym_comment,
      sym_block_comment,
  [637747] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17771), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15172), 2,
      sym_comment,
      sym_block_comment,
  [637770] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17773), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15173), 2,
      sym_comment,
      sym_block_comment,
  [637793] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17775), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15174), 2,
      sym_comment,
      sym_block_comment,
  [637816] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17777), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15175), 2,
      sym_comment,
      sym_block_comment,
  [637839] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14243), 1,
      anon_sym_LPAREN,
    ACTIONS(17779), 1,
      sym__automatic_semicolon,
    STATE(14160), 1,
      aux_sym__full_enum_def_repeat1,
    STATE(14677), 1,
      sym_class_parameters,
    STATE(15176), 2,
      sym_comment,
      sym_block_comment,
  [637862] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16604), 1,
      anon_sym_RPAREN,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15177), 2,
      sym_comment,
      sym_block_comment,
  [637885] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    ACTIONS(17781), 1,
      sym__outdent,
    STATE(15004), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15178), 2,
      sym_comment,
      sym_block_comment,
  [637908] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15179), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16088), 4,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [637925] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17783), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15180), 2,
      sym_comment,
      sym_block_comment,
  [637948] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17785), 1,
      anon_sym_RBRACE,
    STATE(14966), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15181), 2,
      sym_comment,
      sym_block_comment,
  [637971] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17787), 1,
      anon_sym_LBRACE,
    ACTIONS(17789), 1,
      sym__indent,
    STATE(12934), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15182), 2,
      sym_comment,
      sym_block_comment,
  [637992] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17791), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15183), 2,
      sym_comment,
      sym_block_comment,
  [638015] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17793), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15184), 2,
      sym_comment,
      sym_block_comment,
  [638038] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(17795), 1,
      anon_sym_while,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15185), 2,
      sym_comment,
      sym_block_comment,
  [638061] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17797), 1,
      anon_sym_EQ,
    STATE(15186), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16757), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [638080] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17787), 1,
      anon_sym_LBRACE,
    ACTIONS(17789), 1,
      sym__indent,
    STATE(12890), 2,
      sym_indented_cases,
      sym_case_block,
    STATE(15187), 2,
      sym_comment,
      sym_block_comment,
  [638101] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17799), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15188), 2,
      sym_comment,
      sym_block_comment,
  [638124] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17801), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15189), 2,
      sym_comment,
      sym_block_comment,
  [638147] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17275), 1,
      anon_sym_case,
    ACTIONS(17803), 1,
      anon_sym_RBRACE,
    STATE(14881), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16684), 1,
      sym_case_clause,
    STATE(15190), 2,
      sym_comment,
      sym_block_comment,
  [638170] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    ACTIONS(17805), 1,
      sym__outdent,
    STATE(14892), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15191), 2,
      sym_comment,
      sym_block_comment,
  [638193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5914), 1,
      anon_sym_RBRACK,
    ACTIONS(17807), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15192), 2,
      sym_comment,
      sym_block_comment,
  [638213] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(17811), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15193), 2,
      sym_comment,
      sym_block_comment,
  [638233] = 5,
    ACTIONS(17815), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17817), 1,
      anon_sym_STAR_SLASH,
    STATE(15203), 1,
      aux_sym_block_comment_repeat1,
    ACTIONS(17813), 2,
      anon_sym_SLASH_SLASH,
      aux_sym_block_comment_token1,
    STATE(15194), 2,
      sym_comment,
      sym_block_comment,
  [638251] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5622), 1,
      anon_sym_RPAREN,
    ACTIONS(17819), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15195), 2,
      sym_comment,
      sym_block_comment,
  [638271] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5154), 1,
      anon_sym_RBRACK,
    ACTIONS(17821), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15196), 2,
      sym_comment,
      sym_block_comment,
  [638291] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15065), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15197), 2,
      sym_comment,
      sym_block_comment,
  [638311] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15198), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16629), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [638327] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11818), 1,
      sym__arrow_then_type,
    ACTIONS(17823), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15199), 2,
      sym_comment,
      sym_block_comment,
  [638345] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17825), 1,
      anon_sym_COMMA,
    ACTIONS(17827), 1,
      anon_sym_RPAREN,
    STATE(15487), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15200), 2,
      sym_comment,
      sym_block_comment,
  [638365] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17829), 1,
      anon_sym_COMMA,
    ACTIONS(17831), 1,
      anon_sym_RBRACK,
    STATE(15205), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15201), 2,
      sym_comment,
      sym_block_comment,
  [638385] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17833), 1,
      anon_sym_COMMA,
    ACTIONS(17835), 1,
      anon_sym_RBRACK,
    STATE(15256), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15202), 2,
      sym_comment,
      sym_block_comment,
  [638405] = 5,
    ACTIONS(17815), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17837), 1,
      anon_sym_STAR_SLASH,
    STATE(15235), 1,
      aux_sym_block_comment_repeat1,
    ACTIONS(17813), 2,
      anon_sym_SLASH_SLASH,
      aux_sym_block_comment_token1,
    STATE(15203), 2,
      sym_comment,
      sym_block_comment,
  [638423] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5662), 1,
      anon_sym_RPAREN,
    ACTIONS(17839), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15204), 2,
      sym_comment,
      sym_block_comment,
  [638443] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5148), 1,
      anon_sym_RBRACK,
    ACTIONS(17841), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15205), 2,
      sym_comment,
      sym_block_comment,
  [638463] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(17843), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15206), 2,
      sym_comment,
      sym_block_comment,
  [638483] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5404), 1,
      anon_sym_RBRACK,
    ACTIONS(17845), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15207), 2,
      sym_comment,
      sym_block_comment,
  [638503] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7752), 1,
      anon_sym_with,
    ACTIONS(14772), 1,
      anon_sym_LPAREN,
    STATE(18478), 1,
      sym_arguments,
    STATE(15208), 2,
      sym_comment,
      sym_block_comment,
  [638523] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17847), 1,
      anon_sym_COMMA,
    ACTIONS(17849), 1,
      anon_sym_RPAREN,
    STATE(15404), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15209), 2,
      sym_comment,
      sym_block_comment,
  [638543] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16581), 1,
      anon_sym_LBRACK,
    STATE(10632), 1,
      sym_type_arguments,
    STATE(15210), 2,
      sym_comment,
      sym_block_comment,
  [638563] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17851), 1,
      anon_sym_COMMA,
    ACTIONS(17853), 1,
      anon_sym_RBRACK,
    STATE(15217), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15211), 2,
      sym_comment,
      sym_block_comment,
  [638583] = 6,
    ACTIONS(17815), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17855), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(17857), 1,
      sym__comment_text,
    ACTIONS(17859), 1,
      anon_sym_GT,
    STATE(18534), 1,
      sym_using_directive,
    STATE(15212), 2,
      sym_comment,
      sym_block_comment,
  [638603] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(17861), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15213), 2,
      sym_comment,
      sym_block_comment,
  [638623] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17863), 1,
      anon_sym_COMMA,
    ACTIONS(17865), 1,
      anon_sym_RBRACK,
    STATE(15196), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15214), 2,
      sym_comment,
      sym_block_comment,
  [638643] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5674), 1,
      anon_sym_RPAREN,
    ACTIONS(17867), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15215), 2,
      sym_comment,
      sym_block_comment,
  [638663] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17869), 1,
      anon_sym_COMMA,
    ACTIONS(17871), 1,
      anon_sym_RPAREN,
    STATE(15451), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15216), 2,
      sym_comment,
      sym_block_comment,
  [638683] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5190), 1,
      anon_sym_RBRACK,
    ACTIONS(17873), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15217), 2,
      sym_comment,
      sym_block_comment,
  [638703] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16361), 1,
      anon_sym_LBRACE,
    ACTIONS(16627), 1,
      anon_sym_EQ,
    STATE(14736), 1,
      sym_block,
    STATE(15218), 2,
      sym_comment,
      sym_block_comment,
  [638723] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17861), 1,
      sym__interpolated_string_end,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15219), 2,
      sym_comment,
      sym_block_comment,
  [638743] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17877), 1,
      anon_sym_COMMA,
    ACTIONS(17879), 1,
      anon_sym_RPAREN,
    STATE(15335), 1,
      aux_sym_bindings_repeat1,
    STATE(15220), 2,
      sym_comment,
      sym_block_comment,
  [638763] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17843), 1,
      sym__interpolated_string_end,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15221), 2,
      sym_comment,
      sym_block_comment,
  [638783] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6030), 1,
      anon_sym_RPAREN,
    ACTIONS(17881), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15222), 2,
      sym_comment,
      sym_block_comment,
  [638803] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5226), 1,
      anon_sym_RBRACK,
    ACTIONS(17883), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15223), 2,
      sym_comment,
      sym_block_comment,
  [638823] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5188), 1,
      anon_sym_RPAREN,
    ACTIONS(17885), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15224), 2,
      sym_comment,
      sym_block_comment,
  [638843] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4210), 1,
      sym__indent,
    STATE(6968), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15225), 2,
      sym_comment,
      sym_block_comment,
  [638861] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17887), 1,
      anon_sym_COMMA,
    ACTIONS(17889), 1,
      anon_sym_RPAREN,
    STATE(15523), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15226), 2,
      sym_comment,
      sym_block_comment,
  [638881] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(17891), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15227), 2,
      sym_comment,
      sym_block_comment,
  [638901] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(14902), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15228), 2,
      sym_comment,
      sym_block_comment,
  [638921] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17893), 1,
      anon_sym_COMMA,
    ACTIONS(17895), 1,
      anon_sym_RBRACK,
    STATE(15223), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15229), 2,
      sym_comment,
      sym_block_comment,
  [638941] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17897), 1,
      anon_sym_COMMA,
    ACTIONS(17899), 1,
      anon_sym_RBRACK,
    STATE(15236), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15230), 2,
      sym_comment,
      sym_block_comment,
  [638961] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(17901), 1,
      sym__interpolated_multiline_string_end,
    STATE(15312), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15231), 2,
      sym_comment,
      sym_block_comment,
  [638981] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(17901), 1,
      sym__interpolated_string_end,
    STATE(15322), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15232), 2,
      sym_comment,
      sym_block_comment,
  [639001] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17903), 1,
      anon_sym_COMMA,
    ACTIONS(17905), 1,
      anon_sym_RPAREN,
    STATE(15440), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15233), 2,
      sym_comment,
      sym_block_comment,
  [639021] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5776), 1,
      anon_sym_RPAREN,
    ACTIONS(17907), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15234), 2,
      sym_comment,
      sym_block_comment,
  [639041] = 4,
    ACTIONS(17815), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17912), 1,
      anon_sym_STAR_SLASH,
    ACTIONS(17909), 2,
      anon_sym_SLASH_SLASH,
      aux_sym_block_comment_token1,
    STATE(15235), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_block_comment_repeat1,
  [639057] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5284), 1,
      anon_sym_RBRACK,
    ACTIONS(17914), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15236), 2,
      sym_comment,
      sym_block_comment,
  [639077] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17916), 1,
      anon_sym_LPAREN,
    ACTIONS(17918), 1,
      sym__automatic_semicolon,
    STATE(13488), 1,
      sym_class_parameters,
    STATE(15237), 2,
      sym_comment,
      sym_block_comment,
  [639097] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16237), 1,
      anon_sym_COLON,
    ACTIONS(16239), 1,
      anon_sym_LBRACE,
    STATE(14604), 1,
      sym_enum_body,
    STATE(15238), 2,
      sym_comment,
      sym_block_comment,
  [639117] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15239), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17920), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [639133] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15240), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17922), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [639149] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5310), 1,
      anon_sym_RBRACK,
    ACTIONS(17924), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15241), 2,
      sym_comment,
      sym_block_comment,
  [639169] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5286), 1,
      anon_sym_RPAREN,
    ACTIONS(17926), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15242), 2,
      sym_comment,
      sym_block_comment,
  [639189] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(17928), 1,
      sym__interpolated_multiline_string_end,
    STATE(15213), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15243), 2,
      sym_comment,
      sym_block_comment,
  [639209] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17930), 1,
      anon_sym_COMMA,
    ACTIONS(17932), 1,
      anon_sym_RBRACK,
    STATE(15369), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15244), 2,
      sym_comment,
      sym_block_comment,
  [639229] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17934), 1,
      anon_sym_COMMA,
    ACTIONS(17936), 1,
      anon_sym_RPAREN,
    STATE(15368), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15245), 2,
      sym_comment,
      sym_block_comment,
  [639249] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(17928), 1,
      sym__interpolated_string_end,
    STATE(15219), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15246), 2,
      sym_comment,
      sym_block_comment,
  [639269] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17938), 1,
      anon_sym_COMMA,
    ACTIONS(17940), 1,
      anon_sym_RBRACK,
    STATE(15241), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15247), 2,
      sym_comment,
      sym_block_comment,
  [639289] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17942), 1,
      anon_sym_COMMA,
    ACTIONS(17944), 1,
      anon_sym_RPAREN,
    STATE(15476), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15248), 2,
      sym_comment,
      sym_block_comment,
  [639309] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17946), 1,
      anon_sym_COMMA,
    ACTIONS(17948), 1,
      anon_sym_RBRACK,
    STATE(15255), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15249), 2,
      sym_comment,
      sym_block_comment,
  [639329] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17950), 1,
      anon_sym_COMMA,
    ACTIONS(17952), 1,
      anon_sym_RPAREN,
    STATE(16235), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15250), 2,
      sym_comment,
      sym_block_comment,
  [639349] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12653), 1,
      anon_sym_RPAREN,
    ACTIONS(17954), 1,
      anon_sym_COMMA,
    STATE(15395), 1,
      aux_sym_parameters_repeat1,
    STATE(15251), 2,
      sym_comment,
      sym_block_comment,
  [639369] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17956), 1,
      anon_sym_COMMA,
    ACTIONS(17958), 1,
      anon_sym_RPAREN,
    STATE(15398), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15252), 2,
      sym_comment,
      sym_block_comment,
  [639389] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5772), 1,
      anon_sym_RPAREN,
    ACTIONS(17960), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15253), 2,
      sym_comment,
      sym_block_comment,
  [639409] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8651), 1,
      sym__arrow_then_type,
    ACTIONS(17962), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15254), 2,
      sym_comment,
      sym_block_comment,
  [639427] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5358), 1,
      anon_sym_RBRACK,
    ACTIONS(17964), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15255), 2,
      sym_comment,
      sym_block_comment,
  [639447] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5280), 1,
      anon_sym_RBRACK,
    ACTIONS(17966), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15256), 2,
      sym_comment,
      sym_block_comment,
  [639467] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17968), 1,
      anon_sym_COMMA,
    ACTIONS(17970), 1,
      anon_sym_RPAREN,
    STATE(16320), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15257), 2,
      sym_comment,
      sym_block_comment,
  [639487] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12508), 1,
      sym__indent,
    STATE(10488), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15258), 2,
      sym_comment,
      sym_block_comment,
  [639505] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5642), 1,
      anon_sym_RBRACK,
    ACTIONS(17972), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15259), 2,
      sym_comment,
      sym_block_comment,
  [639525] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5566), 1,
      anon_sym_RPAREN,
    ACTIONS(17974), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15260), 2,
      sym_comment,
      sym_block_comment,
  [639545] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17976), 1,
      anon_sym_COMMA,
    ACTIONS(17978), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15261), 2,
      sym_comment,
      sym_block_comment,
  [639565] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(16589), 1,
      sym__arrow_then_type,
    ACTIONS(17980), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15262), 2,
      sym_comment,
      sym_block_comment,
  [639583] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17982), 1,
      anon_sym_COMMA,
    ACTIONS(17984), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15263), 2,
      sym_comment,
      sym_block_comment,
  [639603] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17986), 1,
      anon_sym_COMMA,
    ACTIONS(17988), 1,
      anon_sym_RPAREN,
    STATE(15559), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15264), 2,
      sym_comment,
      sym_block_comment,
  [639623] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17990), 1,
      anon_sym_COMMA,
    ACTIONS(17992), 1,
      anon_sym_RBRACK,
    STATE(15259), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15265), 2,
      sym_comment,
      sym_block_comment,
  [639643] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17994), 1,
      anon_sym_COMMA,
    ACTIONS(17996), 1,
      anon_sym_RPAREN,
    STATE(15494), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15266), 2,
      sym_comment,
      sym_block_comment,
  [639663] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17998), 1,
      anon_sym_COMMA,
    ACTIONS(18000), 1,
      anon_sym_RBRACK,
    STATE(15273), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15267), 2,
      sym_comment,
      sym_block_comment,
  [639683] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18002), 1,
      anon_sym_COMMA,
    ACTIONS(18004), 1,
      anon_sym_RBRACK,
    STATE(15263), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15268), 2,
      sym_comment,
      sym_block_comment,
  [639703] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18006), 1,
      anon_sym_COMMA,
    ACTIONS(18008), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15269), 2,
      sym_comment,
      sym_block_comment,
  [639723] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18010), 1,
      anon_sym_COMMA,
    ACTIONS(18012), 1,
      anon_sym_RPAREN,
    STATE(15584), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15270), 2,
      sym_comment,
      sym_block_comment,
  [639743] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5836), 1,
      anon_sym_RPAREN,
    ACTIONS(18014), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15271), 2,
      sym_comment,
      sym_block_comment,
  [639763] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18016), 1,
      anon_sym_COMMA,
    ACTIONS(18018), 1,
      anon_sym_RBRACK,
    STATE(15269), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15272), 2,
      sym_comment,
      sym_block_comment,
  [639783] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5428), 1,
      anon_sym_RBRACK,
    ACTIONS(18020), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15273), 2,
      sym_comment,
      sym_block_comment,
  [639803] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18022), 1,
      anon_sym_COMMA,
    ACTIONS(18024), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15274), 2,
      sym_comment,
      sym_block_comment,
  [639823] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18026), 1,
      anon_sym_COMMA,
    ACTIONS(18028), 1,
      anon_sym_RBRACK,
    STATE(15274), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15275), 2,
      sym_comment,
      sym_block_comment,
  [639843] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5902), 1,
      anon_sym_RPAREN,
    ACTIONS(18030), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15276), 2,
      sym_comment,
      sym_block_comment,
  [639863] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5448), 1,
      anon_sym_RBRACK,
    ACTIONS(18032), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15277), 2,
      sym_comment,
      sym_block_comment,
  [639883] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5568), 1,
      anon_sym_RPAREN,
    ACTIONS(18034), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15278), 2,
      sym_comment,
      sym_block_comment,
  [639903] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18036), 1,
      anon_sym_COMMA,
    ACTIONS(18038), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15279), 2,
      sym_comment,
      sym_block_comment,
  [639923] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15280), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17485), 3,
      sym__automatic_semicolon,
      ts_builtin_sym_end,
      anon_sym_SEMI,
  [639939] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18040), 1,
      anon_sym_COMMA,
    ACTIONS(18042), 1,
      anon_sym_RBRACK,
    STATE(15279), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15281), 2,
      sym_comment,
      sym_block_comment,
  [639959] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18044), 1,
      anon_sym_COMMA,
    ACTIONS(18046), 1,
      anon_sym_RPAREN,
    STATE(15314), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15282), 2,
      sym_comment,
      sym_block_comment,
  [639979] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18048), 1,
      anon_sym_COMMA,
    ACTIONS(18050), 1,
      anon_sym_RBRACK,
    STATE(15277), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15283), 2,
      sym_comment,
      sym_block_comment,
  [639999] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18052), 1,
      anon_sym_COMMA,
    ACTIONS(18054), 1,
      anon_sym_RPAREN,
    STATE(15512), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15284), 2,
      sym_comment,
      sym_block_comment,
  [640019] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18056), 1,
      anon_sym_COMMA,
    ACTIONS(18058), 1,
      anon_sym_RBRACK,
    STATE(15291), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15285), 2,
      sym_comment,
      sym_block_comment,
  [640039] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    ACTIONS(18060), 1,
      anon_sym_COLON,
    STATE(15443), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15286), 2,
      sym_comment,
      sym_block_comment,
  [640059] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18062), 1,
      anon_sym_COMMA,
    ACTIONS(18064), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15287), 2,
      sym_comment,
      sym_block_comment,
  [640079] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    ACTIONS(18066), 1,
      anon_sym_COLON,
    STATE(15443), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15288), 2,
      sym_comment,
      sym_block_comment,
  [640099] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5140), 1,
      anon_sym_RPAREN,
    ACTIONS(18068), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15289), 2,
      sym_comment,
      sym_block_comment,
  [640119] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18070), 1,
      anon_sym_COMMA,
    ACTIONS(18072), 1,
      anon_sym_RBRACK,
    STATE(15287), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15290), 2,
      sym_comment,
      sym_block_comment,
  [640139] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5498), 1,
      anon_sym_RBRACK,
    ACTIONS(18074), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15291), 2,
      sym_comment,
      sym_block_comment,
  [640159] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    ACTIONS(18076), 1,
      anon_sym_COLON,
    STATE(15443), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15292), 2,
      sym_comment,
      sym_block_comment,
  [640179] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18078), 1,
      anon_sym_COMMA,
    ACTIONS(18080), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15293), 2,
      sym_comment,
      sym_block_comment,
  [640199] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    ACTIONS(18082), 1,
      anon_sym_COLON,
    STATE(15443), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15294), 2,
      sym_comment,
      sym_block_comment,
  [640219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5506), 1,
      anon_sym_RBRACK,
    ACTIONS(18084), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15295), 2,
      sym_comment,
      sym_block_comment,
  [640239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5794), 1,
      anon_sym_RPAREN,
    ACTIONS(18086), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15296), 2,
      sym_comment,
      sym_block_comment,
  [640259] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18088), 1,
      anon_sym_COMMA,
    ACTIONS(18090), 1,
      anon_sym_RBRACK,
    STATE(15293), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15297), 2,
      sym_comment,
      sym_block_comment,
  [640279] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18092), 1,
      anon_sym_COMMA,
    ACTIONS(18094), 1,
      anon_sym_RBRACK,
    STATE(15450), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15298), 2,
      sym_comment,
      sym_block_comment,
  [640299] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18096), 1,
      anon_sym_COMMA,
    ACTIONS(18098), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15299), 2,
      sym_comment,
      sym_block_comment,
  [640319] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18100), 1,
      anon_sym_COMMA,
    ACTIONS(18102), 1,
      anon_sym_RPAREN,
    STATE(15278), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15300), 2,
      sym_comment,
      sym_block_comment,
  [640339] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18104), 1,
      anon_sym_COMMA,
    ACTIONS(18106), 1,
      anon_sym_RBRACK,
    STATE(15295), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15301), 2,
      sym_comment,
      sym_block_comment,
  [640359] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18108), 1,
      anon_sym_COMMA,
    ACTIONS(18110), 1,
      anon_sym_RPAREN,
    STATE(15530), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15302), 2,
      sym_comment,
      sym_block_comment,
  [640379] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18112), 1,
      anon_sym_COMMA,
    ACTIONS(18114), 1,
      anon_sym_RBRACK,
    STATE(15309), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15303), 2,
      sym_comment,
      sym_block_comment,
  [640399] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(14927), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15304), 2,
      sym_comment,
      sym_block_comment,
  [640419] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18116), 1,
      anon_sym_COMMA,
    ACTIONS(18118), 1,
      anon_sym_RBRACK,
    STATE(15299), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15305), 2,
      sym_comment,
      sym_block_comment,
  [640439] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18120), 1,
      anon_sym_COMMA,
    ACTIONS(18122), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15306), 2,
      sym_comment,
      sym_block_comment,
  [640459] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5904), 1,
      anon_sym_RPAREN,
    ACTIONS(18124), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15307), 2,
      sym_comment,
      sym_block_comment,
  [640479] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18126), 1,
      anon_sym_COMMA,
    ACTIONS(18128), 1,
      anon_sym_RBRACK,
    STATE(15306), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15308), 2,
      sym_comment,
      sym_block_comment,
  [640499] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5576), 1,
      anon_sym_RBRACK,
    ACTIONS(18130), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15309), 2,
      sym_comment,
      sym_block_comment,
  [640519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18132), 1,
      anon_sym_DOLLAR,
    STATE(15310), 2,
      sym_comment,
      sym_block_comment,
    STATE(16640), 2,
      sym__dollar_escape,
      sym_interpolation,
  [640537] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18134), 1,
      anon_sym_COMMA,
    ACTIONS(18136), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15311), 2,
      sym_comment,
      sym_block_comment,
  [640557] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18138), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15312), 2,
      sym_comment,
      sym_block_comment,
  [640577] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5586), 1,
      anon_sym_RBRACK,
    ACTIONS(18140), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15313), 2,
      sym_comment,
      sym_block_comment,
  [640597] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5492), 1,
      anon_sym_RPAREN,
    ACTIONS(18142), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15314), 2,
      sym_comment,
      sym_block_comment,
  [640617] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18144), 1,
      anon_sym_COMMA,
    ACTIONS(18146), 1,
      anon_sym_RBRACK,
    STATE(15311), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15315), 2,
      sym_comment,
      sym_block_comment,
  [640637] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18148), 1,
      anon_sym_DOLLAR,
    STATE(15316), 2,
      sym_comment,
      sym_block_comment,
    STATE(16639), 2,
      sym__dollar_escape,
      sym_interpolation,
  [640655] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18150), 1,
      anon_sym_COMMA,
    ACTIONS(18152), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15317), 2,
      sym_comment,
      sym_block_comment,
  [640675] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18154), 1,
      anon_sym_COMMA,
    ACTIONS(18156), 1,
      anon_sym_RPAREN,
    STATE(15195), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15318), 2,
      sym_comment,
      sym_block_comment,
  [640695] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18158), 1,
      anon_sym_COMMA,
    ACTIONS(18160), 1,
      anon_sym_RBRACK,
    STATE(15313), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15319), 2,
      sym_comment,
      sym_block_comment,
  [640715] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18162), 1,
      anon_sym_COMMA,
    ACTIONS(18164), 1,
      anon_sym_RPAREN,
    STATE(15548), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15320), 2,
      sym_comment,
      sym_block_comment,
  [640735] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18166), 1,
      anon_sym_COMMA,
    ACTIONS(18168), 1,
      anon_sym_RBRACK,
    STATE(15327), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15321), 2,
      sym_comment,
      sym_block_comment,
  [640755] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(18138), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15322), 2,
      sym_comment,
      sym_block_comment,
  [640775] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18170), 1,
      anon_sym_COMMA,
    ACTIONS(18172), 1,
      anon_sym_RBRACK,
    STATE(15317), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15323), 2,
      sym_comment,
      sym_block_comment,
  [640795] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18174), 1,
      sym__interpolated_multiline_string_end,
    STATE(15456), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15324), 2,
      sym_comment,
      sym_block_comment,
  [640815] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5958), 1,
      anon_sym_RPAREN,
    ACTIONS(18176), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15325), 2,
      sym_comment,
      sym_block_comment,
  [640835] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18178), 1,
      anon_sym_COMMA,
    ACTIONS(18180), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15326), 2,
      sym_comment,
      sym_block_comment,
  [640855] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5626), 1,
      anon_sym_RBRACK,
    ACTIONS(18182), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15327), 2,
      sym_comment,
      sym_block_comment,
  [640875] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18184), 1,
      anon_sym_COMMA,
    ACTIONS(18186), 1,
      anon_sym_RBRACK,
    STATE(15326), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15328), 2,
      sym_comment,
      sym_block_comment,
  [640895] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18188), 1,
      anon_sym_COMMA,
    ACTIONS(18190), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15329), 2,
      sym_comment,
      sym_block_comment,
  [640915] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18192), 1,
      anon_sym_COMMA,
    ACTIONS(18194), 1,
      anon_sym_RBRACK,
    STATE(15329), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15330), 2,
      sym_comment,
      sym_block_comment,
  [640935] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5688), 1,
      anon_sym_RBRACK,
    ACTIONS(18196), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15331), 2,
      sym_comment,
      sym_block_comment,
  [640955] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5972), 1,
      anon_sym_RPAREN,
    ACTIONS(18198), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15332), 2,
      sym_comment,
      sym_block_comment,
  [640975] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7714), 1,
      anon_sym_RPAREN,
    ACTIONS(18200), 1,
      anon_sym_COMMA,
    STATE(15488), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15333), 2,
      sym_comment,
      sym_block_comment,
  [640995] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18202), 1,
      anon_sym_COMMA,
    ACTIONS(18204), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15334), 2,
      sym_comment,
      sym_block_comment,
  [641015] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13077), 1,
      anon_sym_RPAREN,
    ACTIONS(18206), 1,
      anon_sym_COMMA,
    STATE(15434), 1,
      aux_sym_bindings_repeat1,
    STATE(15335), 2,
      sym_comment,
      sym_block_comment,
  [641035] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18208), 1,
      anon_sym_COMMA,
    ACTIONS(18210), 1,
      anon_sym_RPAREN,
    STATE(15204), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15336), 2,
      sym_comment,
      sym_block_comment,
  [641055] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18212), 1,
      anon_sym_COMMA,
    ACTIONS(18214), 1,
      anon_sym_RBRACK,
    STATE(15331), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15337), 2,
      sym_comment,
      sym_block_comment,
  [641075] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18216), 1,
      anon_sym_COMMA,
    ACTIONS(18218), 1,
      anon_sym_RBRACK,
    STATE(15334), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15338), 2,
      sym_comment,
      sym_block_comment,
  [641095] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18220), 1,
      anon_sym_COMMA,
    ACTIONS(18222), 1,
      anon_sym_RBRACK,
    STATE(15345), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15339), 2,
      sym_comment,
      sym_block_comment,
  [641115] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18224), 1,
      anon_sym_COMMA,
    ACTIONS(18226), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15340), 2,
      sym_comment,
      sym_block_comment,
  [641135] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16237), 1,
      anon_sym_COLON,
    ACTIONS(16239), 1,
      anon_sym_LBRACE,
    STATE(14729), 1,
      sym_enum_body,
    STATE(15341), 2,
      sym_comment,
      sym_block_comment,
  [641155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18228), 1,
      anon_sym_COMMA,
    ACTIONS(18230), 1,
      anon_sym_RBRACK,
    STATE(15340), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15342), 2,
      sym_comment,
      sym_block_comment,
  [641175] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6178), 1,
      anon_sym_RPAREN,
    ACTIONS(18232), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15343), 2,
      sym_comment,
      sym_block_comment,
  [641195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18234), 1,
      anon_sym_COMMA,
    ACTIONS(18236), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15344), 2,
      sym_comment,
      sym_block_comment,
  [641215] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5666), 1,
      anon_sym_RBRACK,
    ACTIONS(18238), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15345), 2,
      sym_comment,
      sym_block_comment,
  [641235] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(18174), 1,
      sym__interpolated_string_end,
    STATE(15472), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15346), 2,
      sym_comment,
      sym_block_comment,
  [641255] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18240), 1,
      anon_sym_COMMA,
    ACTIONS(18242), 1,
      anon_sym_RBRACK,
    STATE(15344), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15347), 2,
      sym_comment,
      sym_block_comment,
  [641275] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18244), 1,
      anon_sym_COMMA,
    ACTIONS(18246), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15348), 2,
      sym_comment,
      sym_block_comment,
  [641295] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5678), 1,
      anon_sym_RBRACK,
    ACTIONS(18248), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15349), 2,
      sym_comment,
      sym_block_comment,
  [641315] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6020), 1,
      anon_sym_RPAREN,
    ACTIONS(18250), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15350), 2,
      sym_comment,
      sym_block_comment,
  [641335] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18252), 1,
      anon_sym_COMMA,
    ACTIONS(18254), 1,
      anon_sym_RBRACK,
    STATE(15348), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15351), 2,
      sym_comment,
      sym_block_comment,
  [641355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(18256), 1,
      sym__interpolated_string_end,
    STATE(15221), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15352), 2,
      sym_comment,
      sym_block_comment,
  [641375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18258), 1,
      anon_sym_COMMA,
    ACTIONS(18260), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15353), 2,
      sym_comment,
      sym_block_comment,
  [641395] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18262), 1,
      anon_sym_COMMA,
    ACTIONS(18264), 1,
      anon_sym_RPAREN,
    STATE(15613), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15354), 2,
      sym_comment,
      sym_block_comment,
  [641415] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18266), 1,
      anon_sym_COMMA,
    ACTIONS(18268), 1,
      anon_sym_RBRACK,
    STATE(15349), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15355), 2,
      sym_comment,
      sym_block_comment,
  [641435] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18270), 1,
      anon_sym_COMMA,
    ACTIONS(18272), 1,
      anon_sym_RPAREN,
    STATE(15594), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15356), 2,
      sym_comment,
      sym_block_comment,
  [641455] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18274), 1,
      anon_sym_COMMA,
    ACTIONS(18276), 1,
      anon_sym_RBRACK,
    STATE(15363), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15357), 2,
      sym_comment,
      sym_block_comment,
  [641475] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18278), 1,
      anon_sym_COMMA,
    ACTIONS(18280), 1,
      anon_sym_RBRACK,
    STATE(15353), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15358), 2,
      sym_comment,
      sym_block_comment,
  [641495] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18282), 1,
      anon_sym_COMMA,
    ACTIONS(18284), 1,
      anon_sym_RBRACK,
    STATE(15509), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15359), 2,
      sym_comment,
      sym_block_comment,
  [641515] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18286), 1,
      anon_sym_COMMA,
    ACTIONS(18288), 1,
      anon_sym_RPAREN,
    STATE(16077), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15360), 2,
      sym_comment,
      sym_block_comment,
  [641535] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6036), 1,
      anon_sym_RPAREN,
    ACTIONS(18290), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15361), 2,
      sym_comment,
      sym_block_comment,
  [641555] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18292), 1,
      anon_sym_COMMA,
    ACTIONS(18294), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15362), 2,
      sym_comment,
      sym_block_comment,
  [641575] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5716), 1,
      anon_sym_RBRACK,
    ACTIONS(18296), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15363), 2,
      sym_comment,
      sym_block_comment,
  [641595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13300), 1,
      sym__arrow_then_type,
    ACTIONS(18298), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15364), 2,
      sym_comment,
      sym_block_comment,
  [641613] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18300), 1,
      anon_sym_COMMA,
    ACTIONS(18302), 1,
      anon_sym_RBRACK,
    STATE(15362), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15365), 2,
      sym_comment,
      sym_block_comment,
  [641633] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15366), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(18304), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [641649] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5728), 1,
      anon_sym_RBRACK,
    ACTIONS(18306), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15367), 2,
      sym_comment,
      sym_block_comment,
  [641669] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5346), 1,
      anon_sym_RPAREN,
    ACTIONS(18308), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15368), 2,
      sym_comment,
      sym_block_comment,
  [641689] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18310), 1,
      anon_sym_COMMA,
    ACTIONS(18312), 1,
      anon_sym_RBRACK,
    STATE(15517), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15369), 2,
      sym_comment,
      sym_block_comment,
  [641709] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18314), 1,
      anon_sym_COMMA,
    ACTIONS(18316), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15370), 2,
      sym_comment,
      sym_block_comment,
  [641729] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18256), 1,
      sym__interpolated_multiline_string_end,
    STATE(15206), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15371), 2,
      sym_comment,
      sym_block_comment,
  [641749] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18318), 1,
      anon_sym_COMMA,
    ACTIONS(18320), 1,
      anon_sym_RPAREN,
    STATE(15234), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15372), 2,
      sym_comment,
      sym_block_comment,
  [641769] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18322), 1,
      anon_sym_COMMA,
    ACTIONS(18324), 1,
      anon_sym_RBRACK,
    STATE(15367), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15373), 2,
      sym_comment,
      sym_block_comment,
  [641789] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18326), 1,
      anon_sym_COMMA,
    ACTIONS(18328), 1,
      anon_sym_RPAREN,
    STATE(15639), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15374), 2,
      sym_comment,
      sym_block_comment,
  [641809] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18330), 1,
      anon_sym_COMMA,
    ACTIONS(18332), 1,
      anon_sym_RBRACK,
    STATE(15381), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15375), 2,
      sym_comment,
      sym_block_comment,
  [641829] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18334), 1,
      anon_sym_COMMA,
    ACTIONS(18336), 1,
      anon_sym_RBRACK,
    STATE(15370), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15376), 2,
      sym_comment,
      sym_block_comment,
  [641849] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15161), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15377), 2,
      sym_comment,
      sym_block_comment,
  [641869] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12677), 1,
      anon_sym_RPAREN,
    ACTIONS(18338), 1,
      anon_sym_COMMA,
    STATE(15521), 1,
      aux_sym_parameters_repeat1,
    STATE(15378), 2,
      sym_comment,
      sym_block_comment,
  [641889] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6002), 1,
      anon_sym_RPAREN,
    ACTIONS(18340), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15379), 2,
      sym_comment,
      sym_block_comment,
  [641909] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18342), 1,
      anon_sym_COMMA,
    ACTIONS(18344), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15380), 2,
      sym_comment,
      sym_block_comment,
  [641929] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5782), 1,
      anon_sym_RBRACK,
    ACTIONS(18346), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15381), 2,
      sym_comment,
      sym_block_comment,
  [641949] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4766), 1,
      sym__indent,
    STATE(7027), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15382), 2,
      sym_comment,
      sym_block_comment,
  [641967] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18348), 1,
      anon_sym_COMMA,
    ACTIONS(18350), 1,
      anon_sym_RBRACK,
    STATE(15380), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15383), 2,
      sym_comment,
      sym_block_comment,
  [641987] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18352), 1,
      anon_sym_COMMA,
    ACTIONS(18354), 1,
      anon_sym_RPAREN,
    STATE(15524), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15384), 2,
      sym_comment,
      sym_block_comment,
  [642007] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5786), 1,
      anon_sym_RBRACK,
    ACTIONS(18356), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15385), 2,
      sym_comment,
      sym_block_comment,
  [642027] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5734), 1,
      anon_sym_RPAREN,
    ACTIONS(18358), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15386), 2,
      sym_comment,
      sym_block_comment,
  [642047] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17699), 1,
      anon_sym_RPAREN,
    ACTIONS(18360), 1,
      anon_sym_COMMA,
    STATE(15528), 1,
      aux_sym_parameters_repeat1,
    STATE(15387), 2,
      sym_comment,
      sym_block_comment,
  [642067] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18362), 1,
      anon_sym_COMMA,
    ACTIONS(18364), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15388), 2,
      sym_comment,
      sym_block_comment,
  [642087] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17697), 1,
      anon_sym_COMMA,
    ACTIONS(17699), 1,
      anon_sym_RPAREN,
    STATE(15532), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15389), 2,
      sym_comment,
      sym_block_comment,
  [642107] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18366), 1,
      anon_sym_COMMA,
    ACTIONS(18368), 1,
      anon_sym_RPAREN,
    STATE(15271), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15390), 2,
      sym_comment,
      sym_block_comment,
  [642127] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18370), 1,
      anon_sym_COMMA,
    ACTIONS(18372), 1,
      anon_sym_RBRACK,
    STATE(15385), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15391), 2,
      sym_comment,
      sym_block_comment,
  [642147] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18374), 1,
      anon_sym_COMMA,
    ACTIONS(18376), 1,
      anon_sym_RPAREN,
    STATE(15688), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15392), 2,
      sym_comment,
      sym_block_comment,
  [642167] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18378), 1,
      anon_sym_COMMA,
    ACTIONS(18380), 1,
      anon_sym_RBRACK,
    STATE(15399), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15393), 2,
      sym_comment,
      sym_block_comment,
  [642187] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18382), 1,
      anon_sym_COMMA,
    ACTIONS(18384), 1,
      anon_sym_RBRACK,
    STATE(15388), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15394), 2,
      sym_comment,
      sym_block_comment,
  [642207] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12677), 1,
      anon_sym_RPAREN,
    ACTIONS(18338), 1,
      anon_sym_COMMA,
    STATE(15542), 1,
      aux_sym_parameters_repeat1,
    STATE(15395), 2,
      sym_comment,
      sym_block_comment,
  [642227] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18386), 1,
      anon_sym_COMMA,
    ACTIONS(18388), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15396), 2,
      sym_comment,
      sym_block_comment,
  [642247] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6168), 1,
      anon_sym_RPAREN,
    ACTIONS(18390), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15397), 2,
      sym_comment,
      sym_block_comment,
  [642267] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6028), 1,
      anon_sym_RPAREN,
    ACTIONS(18392), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15398), 2,
      sym_comment,
      sym_block_comment,
  [642287] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5846), 1,
      anon_sym_RBRACK,
    ACTIONS(18394), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15399), 2,
      sym_comment,
      sym_block_comment,
  [642307] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18396), 1,
      anon_sym_COMMA,
    ACTIONS(18398), 1,
      anon_sym_RBRACK,
    STATE(15396), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15400), 2,
      sym_comment,
      sym_block_comment,
  [642327] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5502), 1,
      anon_sym_RBRACK,
    ACTIONS(18400), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15401), 2,
      sym_comment,
      sym_block_comment,
  [642347] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18402), 1,
      anon_sym_COMMA,
    ACTIONS(18404), 1,
      anon_sym_RBRACK,
    STATE(15643), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15402), 2,
      sym_comment,
      sym_block_comment,
  [642367] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5868), 1,
      anon_sym_RBRACK,
    ACTIONS(18406), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15403), 2,
      sym_comment,
      sym_block_comment,
  [642387] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5184), 1,
      anon_sym_RPAREN,
    ACTIONS(18408), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15404), 2,
      sym_comment,
      sym_block_comment,
  [642407] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18410), 1,
      anon_sym_COMMA,
    ACTIONS(18412), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15405), 2,
      sym_comment,
      sym_block_comment,
  [642427] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13310), 1,
      anon_sym_LPAREN,
    STATE(13889), 1,
      sym__using_parameters_clause,
    STATE(13964), 1,
      sym_parameters,
    STATE(15406), 2,
      sym_comment,
      sym_block_comment,
  [642447] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18414), 1,
      anon_sym_COMMA,
    ACTIONS(18416), 1,
      anon_sym_RBRACK,
    STATE(15405), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15407), 2,
      sym_comment,
      sym_block_comment,
  [642467] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18418), 1,
      anon_sym_COMMA,
    ACTIONS(18420), 1,
      anon_sym_RPAREN,
    STATE(15307), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15408), 2,
      sym_comment,
      sym_block_comment,
  [642487] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18422), 1,
      anon_sym_COMMA,
    ACTIONS(18424), 1,
      anon_sym_RBRACK,
    STATE(15403), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15409), 2,
      sym_comment,
      sym_block_comment,
  [642507] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18426), 1,
      anon_sym_COMMA,
    ACTIONS(18428), 1,
      anon_sym_RPAREN,
    STATE(15715), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15410), 2,
      sym_comment,
      sym_block_comment,
  [642527] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18430), 1,
      anon_sym_COMMA,
    ACTIONS(18432), 1,
      anon_sym_RBRACK,
    STATE(15417), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15411), 2,
      sym_comment,
      sym_block_comment,
  [642547] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(18434), 1,
      anon_sym_RPAREN,
    STATE(15551), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15412), 2,
      sym_comment,
      sym_block_comment,
  [642567] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18436), 1,
      anon_sym_COMMA,
    ACTIONS(18438), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15413), 2,
      sym_comment,
      sym_block_comment,
  [642587] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18440), 1,
      anon_sym_COMMA,
    ACTIONS(18442), 1,
      anon_sym_RBRACK,
    STATE(15413), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15414), 2,
      sym_comment,
      sym_block_comment,
  [642607] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6100), 1,
      anon_sym_RPAREN,
    ACTIONS(18444), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15415), 2,
      sym_comment,
      sym_block_comment,
  [642627] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5752), 1,
      anon_sym_RPAREN,
    ACTIONS(18446), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15416), 2,
      sym_comment,
      sym_block_comment,
  [642647] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5908), 1,
      anon_sym_RBRACK,
    ACTIONS(18448), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15417), 2,
      sym_comment,
      sym_block_comment,
  [642667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(18450), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15418), 2,
      sym_comment,
      sym_block_comment,
  [642685] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18452), 1,
      anon_sym_COMMA,
    ACTIONS(18454), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15419), 2,
      sym_comment,
      sym_block_comment,
  [642705] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(18456), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15420), 2,
      sym_comment,
      sym_block_comment,
  [642725] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5922), 1,
      anon_sym_RBRACK,
    ACTIONS(18458), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15421), 2,
      sym_comment,
      sym_block_comment,
  [642745] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5654), 1,
      anon_sym_RPAREN,
    ACTIONS(18460), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15422), 2,
      sym_comment,
      sym_block_comment,
  [642765] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18462), 1,
      anon_sym_COMMA,
    ACTIONS(18464), 1,
      anon_sym_RBRACK,
    STATE(15419), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15423), 2,
      sym_comment,
      sym_block_comment,
  [642785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18466), 1,
      anon_sym_COLON,
    ACTIONS(18468), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15424), 2,
      sym_comment,
      sym_block_comment,
  [642803] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(14932), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15425), 2,
      sym_comment,
      sym_block_comment,
  [642823] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18470), 1,
      anon_sym_COMMA,
    ACTIONS(18472), 1,
      anon_sym_RPAREN,
    STATE(15325), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15426), 2,
      sym_comment,
      sym_block_comment,
  [642843] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18474), 1,
      anon_sym_COMMA,
    ACTIONS(18476), 1,
      anon_sym_RBRACK,
    STATE(15421), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15427), 2,
      sym_comment,
      sym_block_comment,
  [642863] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18478), 1,
      anon_sym_COMMA,
    ACTIONS(18480), 1,
      anon_sym_RPAREN,
    STATE(15743), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15428), 2,
      sym_comment,
      sym_block_comment,
  [642883] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18482), 1,
      anon_sym_COMMA,
    ACTIONS(18484), 1,
      anon_sym_RBRACK,
    STATE(15435), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15429), 2,
      sym_comment,
      sym_block_comment,
  [642903] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18486), 1,
      anon_sym_COMMA,
    ACTIONS(18488), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15430), 2,
      sym_comment,
      sym_block_comment,
  [642923] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18490), 1,
      anon_sym_COLON,
    ACTIONS(18492), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15431), 2,
      sym_comment,
      sym_block_comment,
  [642941] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18494), 1,
      anon_sym_COMMA,
    ACTIONS(18496), 1,
      anon_sym_RBRACK,
    STATE(15430), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15432), 2,
      sym_comment,
      sym_block_comment,
  [642961] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5968), 1,
      anon_sym_RPAREN,
    ACTIONS(18498), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15433), 2,
      sym_comment,
      sym_block_comment,
  [642981] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18500), 1,
      anon_sym_COMMA,
    ACTIONS(18503), 1,
      anon_sym_RPAREN,
    STATE(15434), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_bindings_repeat1,
  [642999] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5980), 1,
      anon_sym_RBRACK,
    ACTIONS(18505), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15435), 2,
      sym_comment,
      sym_block_comment,
  [643019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(18507), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15436), 2,
      sym_comment,
      sym_block_comment,
  [643037] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18509), 1,
      anon_sym_COMMA,
    ACTIONS(18511), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15437), 2,
      sym_comment,
      sym_block_comment,
  [643057] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18456), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15438), 2,
      sym_comment,
      sym_block_comment,
  [643077] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5996), 1,
      anon_sym_RBRACK,
    ACTIONS(18513), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15439), 2,
      sym_comment,
      sym_block_comment,
  [643097] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5256), 1,
      anon_sym_RPAREN,
    ACTIONS(18515), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15440), 2,
      sym_comment,
      sym_block_comment,
  [643117] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18517), 1,
      anon_sym_COMMA,
    ACTIONS(18519), 1,
      anon_sym_RBRACK,
    STATE(15437), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15441), 2,
      sym_comment,
      sym_block_comment,
  [643137] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18521), 1,
      anon_sym_COMMA,
    ACTIONS(18523), 1,
      anon_sym_RBRACK,
    STATE(15401), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15442), 2,
      sym_comment,
      sym_block_comment,
  [643157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18525), 1,
      anon_sym_COLON,
    ACTIONS(18527), 1,
      anon_sym_COMMA,
    STATE(15443), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_val_declaration_repeat1,
  [643175] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18530), 1,
      anon_sym_COMMA,
    ACTIONS(18532), 1,
      anon_sym_RPAREN,
    STATE(15361), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15444), 2,
      sym_comment,
      sym_block_comment,
  [643195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18534), 1,
      anon_sym_COMMA,
    ACTIONS(18536), 1,
      anon_sym_RBRACK,
    STATE(15439), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15445), 2,
      sym_comment,
      sym_block_comment,
  [643215] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18538), 1,
      anon_sym_COMMA,
    ACTIONS(18540), 1,
      anon_sym_RPAREN,
    STATE(15769), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15446), 2,
      sym_comment,
      sym_block_comment,
  [643235] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18542), 1,
      anon_sym_COMMA,
    ACTIONS(18544), 1,
      anon_sym_RBRACK,
    STATE(15453), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15447), 2,
      sym_comment,
      sym_block_comment,
  [643255] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18546), 1,
      anon_sym_COMMA,
    ACTIONS(18548), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15448), 2,
      sym_comment,
      sym_block_comment,
  [643275] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18550), 1,
      anon_sym_COMMA,
    ACTIONS(18552), 1,
      anon_sym_RBRACK,
    STATE(15448), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15449), 2,
      sym_comment,
      sym_block_comment,
  [643295] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5412), 1,
      anon_sym_RBRACK,
    ACTIONS(18554), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15450), 2,
      sym_comment,
      sym_block_comment,
  [643315] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5172), 1,
      anon_sym_RPAREN,
    ACTIONS(18556), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15451), 2,
      sym_comment,
      sym_block_comment,
  [643335] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18558), 1,
      anon_sym_COMMA,
    ACTIONS(18560), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15452), 2,
      sym_comment,
      sym_block_comment,
  [643355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6044), 1,
      anon_sym_RBRACK,
    ACTIONS(18562), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15453), 2,
      sym_comment,
      sym_block_comment,
  [643375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18564), 1,
      anon_sym_COMMA,
    ACTIONS(18566), 1,
      anon_sym_RBRACK,
    STATE(15452), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15454), 2,
      sym_comment,
      sym_block_comment,
  [643395] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4030), 1,
      anon_sym_RPAREN,
    ACTIONS(18568), 1,
      anon_sym_COMMA,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15455), 2,
      sym_comment,
      sym_block_comment,
  [643415] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18570), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15456), 2,
      sym_comment,
      sym_block_comment,
  [643435] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6066), 1,
      anon_sym_RBRACK,
    ACTIONS(18572), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15457), 2,
      sym_comment,
      sym_block_comment,
  [643455] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5316), 1,
      anon_sym_RPAREN,
    ACTIONS(18574), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15458), 2,
      sym_comment,
      sym_block_comment,
  [643475] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18576), 1,
      anon_sym_COMMA,
    ACTIONS(18578), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15459), 2,
      sym_comment,
      sym_block_comment,
  [643495] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4358), 1,
      sym__indent,
    STATE(10556), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15460), 2,
      sym_comment,
      sym_block_comment,
  [643513] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18580), 1,
      anon_sym_COMMA,
    ACTIONS(18582), 1,
      anon_sym_RBRACK,
    STATE(15459), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15461), 2,
      sym_comment,
      sym_block_comment,
  [643533] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18584), 1,
      anon_sym_COMMA,
    ACTIONS(18586), 1,
      anon_sym_RPAREN,
    STATE(15379), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15462), 2,
      sym_comment,
      sym_block_comment,
  [643553] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18588), 1,
      anon_sym_COMMA,
    ACTIONS(18590), 1,
      anon_sym_RBRACK,
    STATE(15457), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15463), 2,
      sym_comment,
      sym_block_comment,
  [643573] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18592), 1,
      anon_sym_COMMA,
    ACTIONS(18594), 1,
      anon_sym_RPAREN,
    STATE(15791), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15464), 2,
      sym_comment,
      sym_block_comment,
  [643593] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18596), 1,
      anon_sym_COMMA,
    ACTIONS(18598), 1,
      anon_sym_RBRACK,
    STATE(15471), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15465), 2,
      sym_comment,
      sym_block_comment,
  [643613] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15129), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15466), 2,
      sym_comment,
      sym_block_comment,
  [643633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18600), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18603), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_interpolated_string_repeat2,
  [643651] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18605), 1,
      anon_sym_COMMA,
    ACTIONS(18607), 1,
      anon_sym_RBRACK,
    STATE(15511), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15468), 2,
      sym_comment,
      sym_block_comment,
  [643671] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5604), 1,
      anon_sym_RPAREN,
    ACTIONS(18609), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15469), 2,
      sym_comment,
      sym_block_comment,
  [643691] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18611), 1,
      anon_sym_COMMA,
    ACTIONS(18613), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15470), 2,
      sym_comment,
      sym_block_comment,
  [643711] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6146), 1,
      anon_sym_RBRACK,
    ACTIONS(18615), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15471), 2,
      sym_comment,
      sym_block_comment,
  [643731] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(18570), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15472), 2,
      sym_comment,
      sym_block_comment,
  [643751] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18617), 1,
      anon_sym_COMMA,
    ACTIONS(18619), 1,
      anon_sym_RBRACK,
    STATE(15470), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15473), 2,
      sym_comment,
      sym_block_comment,
  [643771] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18621), 1,
      sym__interpolated_string_middle,
    ACTIONS(18624), 1,
      sym__interpolated_string_end,
    STATE(15474), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_interpolated_string_repeat1,
  [643789] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6158), 1,
      anon_sym_RBRACK,
    ACTIONS(18626), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15475), 2,
      sym_comment,
      sym_block_comment,
  [643809] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5312), 1,
      anon_sym_RPAREN,
    ACTIONS(18628), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15476), 2,
      sym_comment,
      sym_block_comment,
  [643829] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16237), 1,
      anon_sym_COLON,
    ACTIONS(16239), 1,
      anon_sym_LBRACE,
    STATE(14598), 1,
      sym_enum_body,
    STATE(15477), 2,
      sym_comment,
      sym_block_comment,
  [643849] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18630), 1,
      anon_sym_COMMA,
    ACTIONS(18632), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15478), 2,
      sym_comment,
      sym_block_comment,
  [643869] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18634), 1,
      anon_sym_COMMA,
    ACTIONS(18636), 1,
      anon_sym_RBRACK,
    STATE(15478), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15479), 2,
      sym_comment,
      sym_block_comment,
  [643889] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18638), 1,
      anon_sym_COMMA,
    ACTIONS(18640), 1,
      anon_sym_RPAREN,
    STATE(15397), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15480), 2,
      sym_comment,
      sym_block_comment,
  [643909] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18642), 1,
      anon_sym_COMMA,
    ACTIONS(18644), 1,
      anon_sym_RBRACK,
    STATE(15475), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15481), 2,
      sym_comment,
      sym_block_comment,
  [643929] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18646), 1,
      anon_sym_COMMA,
    ACTIONS(18648), 1,
      anon_sym_RPAREN,
    STATE(15343), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15482), 2,
      sym_comment,
      sym_block_comment,
  [643949] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18650), 1,
      anon_sym_COMMA,
    ACTIONS(18652), 1,
      anon_sym_RBRACK,
    STATE(15489), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15483), 2,
      sym_comment,
      sym_block_comment,
  [643969] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7794), 1,
      anon_sym_RPAREN,
    ACTIONS(18654), 1,
      anon_sym_COMMA,
    STATE(15581), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15484), 2,
      sym_comment,
      sym_block_comment,
  [643989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17225), 1,
      anon_sym_RPAREN,
    ACTIONS(18656), 1,
      anon_sym_COMMA,
    STATE(15485), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_tuple_expression_repeat1,
  [644007] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18659), 1,
      anon_sym_COMMA,
    ACTIONS(18661), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15486), 2,
      sym_comment,
      sym_block_comment,
  [644027] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5156), 1,
      anon_sym_RPAREN,
    ACTIONS(18663), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15487), 2,
      sym_comment,
      sym_block_comment,
  [644047] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7802), 1,
      anon_sym_RPAREN,
    ACTIONS(18665), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15488), 2,
      sym_comment,
      sym_block_comment,
  [644067] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6166), 1,
      anon_sym_RBRACK,
    ACTIONS(18667), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15489), 2,
      sym_comment,
      sym_block_comment,
  [644087] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18669), 1,
      anon_sym_COMMA,
    ACTIONS(18671), 1,
      anon_sym_RBRACK,
    STATE(15486), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15490), 2,
      sym_comment,
      sym_block_comment,
  [644107] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15491), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16725), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [644123] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18673), 1,
      anon_sym_COMMA,
    ACTIONS(18675), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15492), 2,
      sym_comment,
      sym_block_comment,
  [644143] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6150), 1,
      anon_sym_RBRACK,
    ACTIONS(18677), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15493), 2,
      sym_comment,
      sym_block_comment,
  [644163] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5384), 1,
      anon_sym_RPAREN,
    ACTIONS(18679), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15494), 2,
      sym_comment,
      sym_block_comment,
  [644183] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15495), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16088), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_derives,
  [644199] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18681), 1,
      anon_sym_COMMA,
    ACTIONS(18683), 1,
      anon_sym_RBRACK,
    STATE(15492), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15496), 2,
      sym_comment,
      sym_block_comment,
  [644219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16957), 1,
      anon_sym_RBRACE,
    ACTIONS(16959), 1,
      anon_sym_COMMA,
    STATE(15611), 1,
      aux_sym_namespace_selectors_repeat1,
    STATE(15497), 2,
      sym_comment,
      sym_block_comment,
  [644239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18685), 1,
      anon_sym_COMMA,
    ACTIONS(18687), 1,
      anon_sym_RPAREN,
    STATE(15415), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15498), 2,
      sym_comment,
      sym_block_comment,
  [644259] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18689), 1,
      anon_sym_COMMA,
    ACTIONS(18691), 1,
      anon_sym_RBRACK,
    STATE(15493), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15499), 2,
      sym_comment,
      sym_block_comment,
  [644279] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18693), 1,
      anon_sym_COMMA,
    ACTIONS(18695), 1,
      anon_sym_RPAREN,
    STATE(15869), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15500), 2,
      sym_comment,
      sym_block_comment,
  [644299] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18697), 1,
      anon_sym_COMMA,
    ACTIONS(18699), 1,
      anon_sym_RBRACK,
    STATE(15507), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15501), 2,
      sym_comment,
      sym_block_comment,
  [644319] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18701), 1,
      anon_sym_COMMA,
    ACTIONS(18703), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15502), 2,
      sym_comment,
      sym_block_comment,
  [644339] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18705), 1,
      anon_sym_COMMA,
    ACTIONS(18707), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15503), 2,
      sym_comment,
      sym_block_comment,
  [644359] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18709), 1,
      anon_sym_COMMA,
    ACTIONS(18711), 1,
      anon_sym_RBRACK,
    STATE(15502), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15504), 2,
      sym_comment,
      sym_block_comment,
  [644379] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5610), 1,
      anon_sym_RPAREN,
    ACTIONS(18713), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15505), 2,
      sym_comment,
      sym_block_comment,
  [644399] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18715), 1,
      anon_sym_COMMA,
    ACTIONS(18717), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15506), 2,
      sym_comment,
      sym_block_comment,
  [644419] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6084), 1,
      anon_sym_RBRACK,
    ACTIONS(18719), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15507), 2,
      sym_comment,
      sym_block_comment,
  [644439] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18721), 1,
      anon_sym_COMMA,
    ACTIONS(18723), 1,
      anon_sym_RBRACK,
    STATE(15506), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15508), 2,
      sym_comment,
      sym_block_comment,
  [644459] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18725), 1,
      anon_sym_COMMA,
    ACTIONS(18727), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15509), 2,
      sym_comment,
      sym_block_comment,
  [644479] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18729), 1,
      anon_sym_COMMA,
    ACTIONS(18731), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15510), 2,
      sym_comment,
      sym_block_comment,
  [644499] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5458), 1,
      anon_sym_RBRACK,
    ACTIONS(18733), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15511), 2,
      sym_comment,
      sym_block_comment,
  [644519] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5476), 1,
      anon_sym_RPAREN,
    ACTIONS(18735), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15512), 2,
      sym_comment,
      sym_block_comment,
  [644539] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15513), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(18737), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [644555] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18739), 1,
      anon_sym_COMMA,
    ACTIONS(18741), 1,
      anon_sym_RBRACK,
    STATE(15510), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15514), 2,
      sym_comment,
      sym_block_comment,
  [644575] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6180), 1,
      anon_sym_RPAREN,
    ACTIONS(18743), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15515), 2,
      sym_comment,
      sym_block_comment,
  [644595] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18745), 1,
      anon_sym_COMMA,
    ACTIONS(18747), 1,
      anon_sym_RPAREN,
    STATE(15433), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15516), 2,
      sym_comment,
      sym_block_comment,
  [644615] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18749), 1,
      anon_sym_COMMA,
    ACTIONS(18752), 1,
      anon_sym_RBRACK,
    STATE(15517), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_type_parameters_repeat1,
  [644633] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18754), 1,
      anon_sym_COMMA,
    ACTIONS(18756), 1,
      anon_sym_RPAREN,
    STATE(15289), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15518), 2,
      sym_comment,
      sym_block_comment,
  [644653] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18758), 1,
      anon_sym_COMMA,
    ACTIONS(18760), 1,
      anon_sym_RBRACK,
    STATE(15525), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15519), 2,
      sym_comment,
      sym_block_comment,
  [644673] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18762), 1,
      anon_sym_COMMA,
    ACTIONS(18764), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15520), 2,
      sym_comment,
      sym_block_comment,
  [644693] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12681), 1,
      anon_sym_RPAREN,
    ACTIONS(18766), 1,
      anon_sym_COMMA,
    STATE(15542), 1,
      aux_sym_parameters_repeat1,
    STATE(15521), 2,
      sym_comment,
      sym_block_comment,
  [644713] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18768), 1,
      anon_sym_COMMA,
    ACTIONS(18770), 1,
      anon_sym_RBRACK,
    STATE(15520), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15522), 2,
      sym_comment,
      sym_block_comment,
  [644733] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5262), 1,
      anon_sym_RPAREN,
    ACTIONS(18772), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15523), 2,
      sym_comment,
      sym_block_comment,
  [644753] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5030), 1,
      anon_sym_RPAREN,
    ACTIONS(18774), 1,
      anon_sym_COMMA,
    STATE(15635), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15524), 2,
      sym_comment,
      sym_block_comment,
  [644773] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5966), 1,
      anon_sym_RBRACK,
    ACTIONS(18776), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15525), 2,
      sym_comment,
      sym_block_comment,
  [644793] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14018), 1,
      sym__arrow_then_type,
    ACTIONS(18778), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15526), 2,
      sym_comment,
      sym_block_comment,
  [644811] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18780), 1,
      anon_sym_COMMA,
    ACTIONS(18782), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15527), 2,
      sym_comment,
      sym_block_comment,
  [644831] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4982), 1,
      anon_sym_RPAREN,
    ACTIONS(18784), 1,
      anon_sym_COMMA,
    STATE(15542), 1,
      aux_sym_parameters_repeat1,
    STATE(15528), 2,
      sym_comment,
      sym_block_comment,
  [644851] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5926), 1,
      anon_sym_RBRACK,
    ACTIONS(18786), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15529), 2,
      sym_comment,
      sym_block_comment,
  [644871] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5536), 1,
      anon_sym_RPAREN,
    ACTIONS(18788), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15530), 2,
      sym_comment,
      sym_block_comment,
  [644891] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18790), 1,
      anon_sym_COMMA,
    ACTIONS(18792), 1,
      anon_sym_RBRACK,
    STATE(15527), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15531), 2,
      sym_comment,
      sym_block_comment,
  [644911] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4982), 1,
      anon_sym_RPAREN,
    ACTIONS(18794), 1,
      anon_sym_COMMA,
    STATE(15635), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15532), 2,
      sym_comment,
      sym_block_comment,
  [644931] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17656), 1,
      anon_sym_EQ,
    ACTIONS(17654), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15533), 2,
      sym_comment,
      sym_block_comment,
  [644949] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18796), 1,
      anon_sym_COMMA,
    ACTIONS(18798), 1,
      anon_sym_RPAREN,
    STATE(15664), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15534), 2,
      sym_comment,
      sym_block_comment,
  [644969] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18800), 1,
      anon_sym_COMMA,
    ACTIONS(18802), 1,
      anon_sym_RBRACK,
    STATE(15529), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15535), 2,
      sym_comment,
      sym_block_comment,
  [644989] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18804), 1,
      anon_sym_COMMA,
    ACTIONS(18806), 1,
      anon_sym_RPAREN,
    STATE(15915), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15536), 2,
      sym_comment,
      sym_block_comment,
  [645009] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18808), 1,
      anon_sym_COMMA,
    ACTIONS(18810), 1,
      anon_sym_RBRACK,
    STATE(15543), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15537), 2,
      sym_comment,
      sym_block_comment,
  [645029] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18812), 1,
      anon_sym_COMMA,
    ACTIONS(18814), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15538), 2,
      sym_comment,
      sym_block_comment,
  [645049] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18816), 1,
      anon_sym_COMMA,
    ACTIONS(18818), 1,
      anon_sym_RPAREN,
    STATE(16208), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15539), 2,
      sym_comment,
      sym_block_comment,
  [645069] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18820), 1,
      anon_sym_COMMA,
    ACTIONS(18822), 1,
      anon_sym_RBRACK,
    STATE(15538), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15540), 2,
      sym_comment,
      sym_block_comment,
  [645089] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5450), 1,
      anon_sym_RPAREN,
    ACTIONS(18824), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15541), 2,
      sym_comment,
      sym_block_comment,
  [645109] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18826), 1,
      anon_sym_COMMA,
    ACTIONS(18829), 1,
      anon_sym_RPAREN,
    STATE(15542), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_parameters_repeat1,
  [645127] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5862), 1,
      anon_sym_RBRACK,
    ACTIONS(18831), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15543), 2,
      sym_comment,
      sym_block_comment,
  [645147] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15544), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17652), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [645163] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18833), 1,
      anon_sym_COMMA,
    ACTIONS(18835), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15545), 2,
      sym_comment,
      sym_block_comment,
  [645183] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(14973), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15546), 2,
      sym_comment,
      sym_block_comment,
  [645203] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5810), 1,
      anon_sym_RBRACK,
    ACTIONS(18837), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15547), 2,
      sym_comment,
      sym_block_comment,
  [645223] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5594), 1,
      anon_sym_RPAREN,
    ACTIONS(18839), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15548), 2,
      sym_comment,
      sym_block_comment,
  [645243] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18841), 1,
      anon_sym_COMMA,
    ACTIONS(18843), 1,
      anon_sym_RBRACK,
    STATE(15545), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15549), 2,
      sym_comment,
      sym_block_comment,
  [645263] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18845), 1,
      anon_sym_COMMA,
    ACTIONS(18847), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15550), 2,
      sym_comment,
      sym_block_comment,
  [645283] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11775), 1,
      anon_sym_RPAREN,
    ACTIONS(18849), 1,
      anon_sym_COMMA,
    STATE(15551), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_case_class_pattern_repeat1,
  [645301] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18852), 1,
      anon_sym_COMMA,
    ACTIONS(18854), 1,
      anon_sym_RPAREN,
    STATE(15469), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15552), 2,
      sym_comment,
      sym_block_comment,
  [645321] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18856), 1,
      anon_sym_COMMA,
    ACTIONS(18858), 1,
      anon_sym_RBRACK,
    STATE(15547), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15553), 2,
      sym_comment,
      sym_block_comment,
  [645341] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18860), 1,
      anon_sym_COMMA,
    ACTIONS(18862), 1,
      anon_sym_RPAREN,
    STATE(15253), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15554), 2,
      sym_comment,
      sym_block_comment,
  [645361] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18864), 1,
      anon_sym_COMMA,
    ACTIONS(18866), 1,
      anon_sym_RBRACK,
    STATE(15561), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15555), 2,
      sym_comment,
      sym_block_comment,
  [645381] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18868), 1,
      anon_sym_COMMA,
    ACTIONS(18870), 1,
      anon_sym_RBRACK,
    STATE(15550), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15556), 2,
      sym_comment,
      sym_block_comment,
  [645401] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7436), 1,
      anon_sym_RPAREN,
    ACTIONS(18872), 1,
      anon_sym_COMMA,
    STATE(15551), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15557), 2,
      sym_comment,
      sym_block_comment,
  [645421] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(18874), 1,
      sym__interpolated_string_end,
    STATE(15420), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15558), 2,
      sym_comment,
      sym_block_comment,
  [645441] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5410), 1,
      anon_sym_RPAREN,
    ACTIONS(18876), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15559), 2,
      sym_comment,
      sym_block_comment,
  [645461] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18878), 1,
      anon_sym_COMMA,
    ACTIONS(18880), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15560), 2,
      sym_comment,
      sym_block_comment,
  [645481] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5726), 1,
      anon_sym_RBRACK,
    ACTIONS(18882), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15561), 2,
      sym_comment,
      sym_block_comment,
  [645501] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7802), 1,
      anon_sym_RPAREN,
    ACTIONS(18665), 1,
      anon_sym_COMMA,
    STATE(15582), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15562), 2,
      sym_comment,
      sym_block_comment,
  [645521] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18884), 1,
      anon_sym_COMMA,
    ACTIONS(18886), 1,
      anon_sym_RBRACK,
    STATE(15560), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15563), 2,
      sym_comment,
      sym_block_comment,
  [645541] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4558), 1,
      sym__indent,
    STATE(9372), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15564), 2,
      sym_comment,
      sym_block_comment,
  [645559] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5718), 1,
      anon_sym_RBRACK,
    ACTIONS(18888), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15565), 2,
      sym_comment,
      sym_block_comment,
  [645579] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5974), 1,
      anon_sym_RPAREN,
    ACTIONS(18890), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15566), 2,
      sym_comment,
      sym_block_comment,
  [645599] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18892), 1,
      anon_sym_COMMA,
    ACTIONS(18894), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15567), 2,
      sym_comment,
      sym_block_comment,
  [645619] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18874), 1,
      sym__interpolated_multiline_string_end,
    STATE(15438), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15568), 2,
      sym_comment,
      sym_block_comment,
  [645639] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18896), 1,
      anon_sym_COMMA,
    ACTIONS(18898), 1,
      anon_sym_RBRACK,
    STATE(15567), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15569), 2,
      sym_comment,
      sym_block_comment,
  [645659] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18900), 1,
      anon_sym_COMMA,
    ACTIONS(18902), 1,
      anon_sym_RPAREN,
    STATE(15505), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15570), 2,
      sym_comment,
      sym_block_comment,
  [645679] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18904), 1,
      anon_sym_COMMA,
    ACTIONS(18906), 1,
      anon_sym_RBRACK,
    STATE(15565), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15571), 2,
      sym_comment,
      sym_block_comment,
  [645699] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18908), 1,
      anon_sym_COMMA,
    ACTIONS(18910), 1,
      anon_sym_RPAREN,
    STATE(15215), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15572), 2,
      sym_comment,
      sym_block_comment,
  [645719] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18912), 1,
      anon_sym_COMMA,
    ACTIONS(18914), 1,
      anon_sym_RBRACK,
    STATE(15579), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15573), 2,
      sym_comment,
      sym_block_comment,
  [645739] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(18916), 1,
      sym__interpolated_multiline_string_end,
    STATE(15710), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15574), 2,
      sym_comment,
      sym_block_comment,
  [645759] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16237), 1,
      anon_sym_COLON,
    ACTIONS(16239), 1,
      anon_sym_LBRACE,
    STATE(14749), 1,
      sym_enum_body,
    STATE(15575), 2,
      sym_comment,
      sym_block_comment,
  [645779] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18918), 1,
      anon_sym_COMMA,
    ACTIONS(18920), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15576), 2,
      sym_comment,
      sym_block_comment,
  [645799] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5198), 1,
      anon_sym_RPAREN,
    ACTIONS(18922), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15577), 2,
      sym_comment,
      sym_block_comment,
  [645819] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7888), 1,
      anon_sym_RPAREN,
    ACTIONS(18924), 1,
      anon_sym_COMMA,
    STATE(15652), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15578), 2,
      sym_comment,
      sym_block_comment,
  [645839] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5592), 1,
      anon_sym_RBRACK,
    ACTIONS(18926), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15579), 2,
      sym_comment,
      sym_block_comment,
  [645859] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18928), 1,
      anon_sym_COMMA,
    ACTIONS(18930), 1,
      anon_sym_RBRACK,
    STATE(15576), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15580), 2,
      sym_comment,
      sym_block_comment,
  [645879] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7888), 1,
      anon_sym_RPAREN,
    ACTIONS(18924), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15581), 2,
      sym_comment,
      sym_block_comment,
  [645899] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7984), 1,
      anon_sym_RPAREN,
    ACTIONS(18932), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15582), 2,
      sym_comment,
      sym_block_comment,
  [645919] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5560), 1,
      anon_sym_RBRACK,
    ACTIONS(18934), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15583), 2,
      sym_comment,
      sym_block_comment,
  [645939] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5638), 1,
      anon_sym_RPAREN,
    ACTIONS(18936), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15584), 2,
      sym_comment,
      sym_block_comment,
  [645959] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18938), 1,
      anon_sym_COMMA,
    ACTIONS(18940), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15585), 2,
      sym_comment,
      sym_block_comment,
  [645979] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18942), 1,
      anon_sym_COMMA,
    ACTIONS(18944), 1,
      anon_sym_RBRACK,
    STATE(15585), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15586), 2,
      sym_comment,
      sym_block_comment,
  [645999] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(18916), 1,
      sym__interpolated_string_end,
    STATE(15712), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15587), 2,
      sym_comment,
      sym_block_comment,
  [646019] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18946), 1,
      anon_sym_COMMA,
    ACTIONS(18948), 1,
      anon_sym_RPAREN,
    STATE(15541), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15588), 2,
      sym_comment,
      sym_block_comment,
  [646039] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18950), 1,
      anon_sym_COMMA,
    ACTIONS(18952), 1,
      anon_sym_RBRACK,
    STATE(15583), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15589), 2,
      sym_comment,
      sym_block_comment,
  [646059] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18954), 1,
      anon_sym_COMMA,
    ACTIONS(18956), 1,
      anon_sym_RPAREN,
    STATE(15958), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15590), 2,
      sym_comment,
      sym_block_comment,
  [646079] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18958), 1,
      anon_sym_COMMA,
    ACTIONS(18960), 1,
      anon_sym_RBRACK,
    STATE(15597), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15591), 2,
      sym_comment,
      sym_block_comment,
  [646099] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18962), 1,
      anon_sym_COMMA,
    ACTIONS(18965), 1,
      anon_sym_RPAREN,
    STATE(15592), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_class_parameters_repeat1,
  [646117] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18967), 1,
      anon_sym_COMMA,
    ACTIONS(18969), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15593), 2,
      sym_comment,
      sym_block_comment,
  [646137] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5918), 1,
      anon_sym_RPAREN,
    ACTIONS(18971), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15594), 2,
      sym_comment,
      sym_block_comment,
  [646157] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5192), 1,
      anon_sym_RPAREN,
    ACTIONS(18973), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15595), 2,
      sym_comment,
      sym_block_comment,
  [646177] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15596), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(18975), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [646193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5414), 1,
      anon_sym_RBRACK,
    ACTIONS(18977), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15597), 2,
      sym_comment,
      sym_block_comment,
  [646213] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18979), 1,
      anon_sym_COMMA,
    ACTIONS(18981), 1,
      anon_sym_RBRACK,
    STATE(15593), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15598), 2,
      sym_comment,
      sym_block_comment,
  [646233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15599), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16659), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [646249] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15600), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16870), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [646265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5386), 1,
      anon_sym_RBRACK,
    ACTIONS(18983), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15601), 2,
      sym_comment,
      sym_block_comment,
  [646285] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5320), 1,
      anon_sym_RPAREN,
    ACTIONS(18985), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15602), 2,
      sym_comment,
      sym_block_comment,
  [646305] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18987), 1,
      anon_sym_COMMA,
    ACTIONS(18989), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15603), 2,
      sym_comment,
      sym_block_comment,
  [646325] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15604), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15975), 3,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_COMMA,
  [646341] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18991), 1,
      anon_sym_COMMA,
    ACTIONS(18993), 1,
      anon_sym_RBRACK,
    STATE(15603), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15605), 2,
      sym_comment,
      sym_block_comment,
  [646361] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18995), 1,
      anon_sym_COMMA,
    ACTIONS(18997), 1,
      anon_sym_RPAREN,
    STATE(15577), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15606), 2,
      sym_comment,
      sym_block_comment,
  [646381] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18999), 1,
      anon_sym_COMMA,
    ACTIONS(19001), 1,
      anon_sym_RBRACK,
    STATE(15601), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15607), 2,
      sym_comment,
      sym_block_comment,
  [646401] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19003), 1,
      anon_sym_COMMA,
    ACTIONS(19005), 1,
      anon_sym_RPAREN,
    STATE(16017), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15608), 2,
      sym_comment,
      sym_block_comment,
  [646421] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19007), 1,
      anon_sym_COMMA,
    ACTIONS(19009), 1,
      anon_sym_RBRACK,
    STATE(15615), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15609), 2,
      sym_comment,
      sym_block_comment,
  [646441] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15507), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(8864), 1,
      sym_type_arguments,
    STATE(15610), 2,
      sym_comment,
      sym_block_comment,
  [646461] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12353), 1,
      anon_sym_RBRACE,
    ACTIONS(19011), 1,
      anon_sym_COMMA,
    STATE(15667), 1,
      aux_sym_namespace_selectors_repeat1,
    STATE(15611), 2,
      sym_comment,
      sym_block_comment,
  [646481] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19013), 1,
      anon_sym_COMMA,
    ACTIONS(19015), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15612), 2,
      sym_comment,
      sym_block_comment,
  [646501] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5712), 1,
      anon_sym_RPAREN,
    ACTIONS(19017), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15613), 2,
      sym_comment,
      sym_block_comment,
  [646521] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12504), 1,
      sym__indent,
    STATE(9909), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15614), 2,
      sym_comment,
      sym_block_comment,
  [646539] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5180), 1,
      anon_sym_RBRACK,
    ACTIONS(19019), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15615), 2,
      sym_comment,
      sym_block_comment,
  [646559] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19021), 1,
      anon_sym_COMMA,
    ACTIONS(19023), 1,
      anon_sym_RBRACK,
    STATE(15612), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15616), 2,
      sym_comment,
      sym_block_comment,
  [646579] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19025), 1,
      anon_sym_COMMA,
    ACTIONS(19027), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15617), 2,
      sym_comment,
      sym_block_comment,
  [646599] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19029), 1,
      anon_sym_COMMA,
    ACTIONS(19031), 1,
      anon_sym_RPAREN,
    STATE(16047), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15618), 2,
      sym_comment,
      sym_block_comment,
  [646619] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5146), 1,
      anon_sym_RBRACK,
    ACTIONS(19033), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15619), 2,
      sym_comment,
      sym_block_comment,
  [646639] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19035), 1,
      anon_sym_COMMA,
    ACTIONS(19037), 1,
      anon_sym_RBRACK,
    STATE(15714), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15620), 2,
      sym_comment,
      sym_block_comment,
  [646659] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19039), 1,
      anon_sym_COMMA,
    ACTIONS(19041), 1,
      anon_sym_RBRACK,
    STATE(15617), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15621), 2,
      sym_comment,
      sym_block_comment,
  [646679] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19043), 1,
      anon_sym_COMMA,
    ACTIONS(19046), 1,
      anon_sym_RBRACK,
    STATE(15622), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_type_lambda_repeat1,
  [646697] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19048), 1,
      anon_sym_COMMA,
    ACTIONS(19050), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15623), 2,
      sym_comment,
      sym_block_comment,
  [646717] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19052), 1,
      anon_sym_COMMA,
    ACTIONS(19054), 1,
      anon_sym_RPAREN,
    STATE(15595), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15624), 2,
      sym_comment,
      sym_block_comment,
  [646737] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19056), 1,
      anon_sym_COMMA,
    ACTIONS(19058), 1,
      anon_sym_RBRACK,
    STATE(15619), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15625), 2,
      sym_comment,
      sym_block_comment,
  [646757] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(19060), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15626), 2,
      sym_comment,
      sym_block_comment,
  [646775] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19063), 1,
      anon_sym_COMMA,
    ACTIONS(19065), 1,
      anon_sym_RBRACK,
    STATE(15633), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15627), 2,
      sym_comment,
      sym_block_comment,
  [646795] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19067), 1,
      anon_sym_COMMA,
    ACTIONS(19069), 1,
      anon_sym_RBRACK,
    STATE(15623), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15628), 2,
      sym_comment,
      sym_block_comment,
  [646815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13423), 1,
      sym__arrow_then_type,
    ACTIONS(19071), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15629), 2,
      sym_comment,
      sym_block_comment,
  [646833] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19073), 1,
      anon_sym_COMMA,
    ACTIONS(19075), 1,
      anon_sym_RPAREN,
    STATE(15224), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15630), 2,
      sym_comment,
      sym_block_comment,
  [646853] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5314), 1,
      anon_sym_RPAREN,
    ACTIONS(19077), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15631), 2,
      sym_comment,
      sym_block_comment,
  [646873] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(14878), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15632), 2,
      sym_comment,
      sym_block_comment,
  [646893] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5250), 1,
      anon_sym_RBRACK,
    ACTIONS(19079), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15633), 2,
      sym_comment,
      sym_block_comment,
  [646913] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19081), 1,
      anon_sym_COMMA,
    ACTIONS(19083), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15634), 2,
      sym_comment,
      sym_block_comment,
  [646933] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19085), 1,
      anon_sym_COMMA,
    ACTIONS(19088), 1,
      anon_sym_RPAREN,
    STATE(15635), 3,
      sym_comment,
      sym_block_comment,
      aux_sym__using_parameters_clause_repeat1,
  [646951] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19090), 1,
      anon_sym_COMMA,
    ACTIONS(19092), 1,
      anon_sym_RBRACK,
    STATE(15634), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15636), 2,
      sym_comment,
      sym_block_comment,
  [646971] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16114), 1,
      anon_sym_STAR,
    ACTIONS(19088), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15637), 2,
      sym_comment,
      sym_block_comment,
  [646989] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5260), 1,
      anon_sym_RBRACK,
    ACTIONS(19094), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15638), 2,
      sym_comment,
      sym_block_comment,
  [647009] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5740), 1,
      anon_sym_RPAREN,
    ACTIONS(19096), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15639), 2,
      sym_comment,
      sym_block_comment,
  [647029] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17474), 1,
      anon_sym_EQ,
    ACTIONS(17472), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15640), 2,
      sym_comment,
      sym_block_comment,
  [647047] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19098), 1,
      anon_sym_COMMA,
    ACTIONS(19100), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15641), 2,
      sym_comment,
      sym_block_comment,
  [647067] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19102), 1,
      anon_sym_COMMA,
    ACTIONS(19104), 1,
      anon_sym_RPAREN,
    STATE(15631), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15642), 2,
      sym_comment,
      sym_block_comment,
  [647087] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5174), 1,
      anon_sym_RBRACK,
    ACTIONS(19106), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15643), 2,
      sym_comment,
      sym_block_comment,
  [647107] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19108), 1,
      anon_sym_COMMA,
    ACTIONS(19110), 1,
      anon_sym_RBRACK,
    STATE(15650), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15644), 2,
      sym_comment,
      sym_block_comment,
  [647127] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19112), 1,
      anon_sym_COMMA,
    ACTIONS(19114), 1,
      anon_sym_RBRACK,
    STATE(15641), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15645), 2,
      sym_comment,
      sym_block_comment,
  [647147] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15646), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(17437), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_EQ,
  [647163] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19116), 1,
      anon_sym_COMMA,
    ACTIONS(19118), 1,
      anon_sym_RBRACK,
    STATE(15638), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15647), 2,
      sym_comment,
      sym_block_comment,
  [647183] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5424), 1,
      anon_sym_RPAREN,
    ACTIONS(19120), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15648), 2,
      sym_comment,
      sym_block_comment,
  [647203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17570), 1,
      anon_sym_EQ,
    ACTIONS(17568), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15649), 2,
      sym_comment,
      sym_block_comment,
  [647221] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5326), 1,
      anon_sym_RBRACK,
    ACTIONS(19122), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15650), 2,
      sym_comment,
      sym_block_comment,
  [647241] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19124), 1,
      anon_sym_COMMA,
    ACTIONS(19126), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15651), 2,
      sym_comment,
      sym_block_comment,
  [647261] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7792), 1,
      anon_sym_RPAREN,
    ACTIONS(19128), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15652), 2,
      sym_comment,
      sym_block_comment,
  [647281] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19130), 1,
      anon_sym_COMMA,
    ACTIONS(19132), 1,
      anon_sym_RPAREN,
    STATE(15242), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15653), 2,
      sym_comment,
      sym_block_comment,
  [647301] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19134), 1,
      anon_sym_COMMA,
    ACTIONS(19136), 1,
      anon_sym_RBRACK,
    STATE(15651), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15654), 2,
      sym_comment,
      sym_block_comment,
  [647321] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17431), 1,
      anon_sym_EQ,
    ACTIONS(17429), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15655), 2,
      sym_comment,
      sym_block_comment,
  [647339] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15656), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(19138), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [647355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5394), 1,
      anon_sym_RBRACK,
    ACTIONS(19140), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15657), 2,
      sym_comment,
      sym_block_comment,
  [647375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5672), 1,
      anon_sym_RBRACK,
    ACTIONS(19142), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15658), 2,
      sym_comment,
      sym_block_comment,
  [647395] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19144), 1,
      anon_sym_COMMA,
    ACTIONS(19146), 1,
      anon_sym_RPAREN,
    STATE(15648), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15659), 2,
      sym_comment,
      sym_block_comment,
  [647415] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19148), 1,
      anon_sym_COMMA,
    ACTIONS(19150), 1,
      anon_sym_RBRACK,
    STATE(15666), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15660), 2,
      sym_comment,
      sym_block_comment,
  [647435] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19152), 1,
      anon_sym_COMMA,
    ACTIONS(19154), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15661), 2,
      sym_comment,
      sym_block_comment,
  [647455] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5608), 1,
      anon_sym_RPAREN,
    ACTIONS(19156), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15662), 2,
      sym_comment,
      sym_block_comment,
  [647475] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5224), 1,
      anon_sym_RPAREN,
    ACTIONS(19158), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15663), 2,
      sym_comment,
      sym_block_comment,
  [647495] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5870), 1,
      anon_sym_RPAREN,
    ACTIONS(19160), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15664), 2,
      sym_comment,
      sym_block_comment,
  [647515] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19162), 1,
      anon_sym_COMMA,
    ACTIONS(19164), 1,
      anon_sym_RBRACK,
    STATE(15661), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15665), 2,
      sym_comment,
      sym_block_comment,
  [647535] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5432), 1,
      anon_sym_RBRACK,
    ACTIONS(19166), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15666), 2,
      sym_comment,
      sym_block_comment,
  [647555] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17395), 1,
      anon_sym_RBRACE,
    ACTIONS(19168), 1,
      anon_sym_COMMA,
    STATE(15667), 3,
      sym_comment,
      sym_block_comment,
      aux_sym_namespace_selectors_repeat1,
  [647573] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15143), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15668), 2,
      sym_comment,
      sym_block_comment,
  [647593] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19171), 1,
      anon_sym_COMMA,
    ACTIONS(19173), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15669), 2,
      sym_comment,
      sym_block_comment,
  [647613] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19175), 1,
      anon_sym_COMMA,
    ACTIONS(19177), 1,
      anon_sym_RBRACK,
    STATE(15657), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15670), 2,
      sym_comment,
      sym_block_comment,
  [647633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17369), 1,
      anon_sym_EQ,
    ACTIONS(17367), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15671), 2,
      sym_comment,
      sym_block_comment,
  [647651] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19179), 1,
      anon_sym_COMMA,
    ACTIONS(19181), 1,
      anon_sym_RPAREN,
    STATE(16135), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15672), 2,
      sym_comment,
      sym_block_comment,
  [647671] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19183), 1,
      anon_sym_COMMA,
    ACTIONS(19185), 1,
      anon_sym_RBRACK,
    STATE(15669), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15673), 2,
      sym_comment,
      sym_block_comment,
  [647691] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19187), 1,
      anon_sym_COMMA,
    ACTIONS(19189), 1,
      anon_sym_RBRACK,
    STATE(15678), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15674), 2,
      sym_comment,
      sym_block_comment,
  [647711] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7866), 1,
      anon_sym_RPAREN,
    ACTIONS(19191), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15675), 2,
      sym_comment,
      sym_block_comment,
  [647731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17349), 1,
      anon_sym_EQ,
    ACTIONS(17347), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15676), 2,
      sym_comment,
      sym_block_comment,
  [647749] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15677), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(19193), 3,
      sym__automatic_semicolon,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [647765] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5520), 1,
      anon_sym_RBRACK,
    ACTIONS(19195), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15678), 2,
      sym_comment,
      sym_block_comment,
  [647785] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19197), 1,
      anon_sym_COMMA,
    ACTIONS(19199), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15679), 2,
      sym_comment,
      sym_block_comment,
  [647805] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19201), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15680), 2,
      sym_comment,
      sym_block_comment,
  [647825] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19203), 1,
      anon_sym_COMMA,
    ACTIONS(19205), 1,
      anon_sym_RBRACK,
    STATE(15679), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15681), 2,
      sym_comment,
      sym_block_comment,
  [647845] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17331), 1,
      anon_sym_EQ,
    ACTIONS(17329), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(15682), 2,
      sym_comment,
      sym_block_comment,
  [647863] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5524), 1,
      anon_sym_RBRACK,
    ACTIONS(19207), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15683), 2,
      sym_comment,
      sym_block_comment,
  [647883] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7984), 1,
      anon_sym_RPAREN,
    ACTIONS(18932), 1,
      anon_sym_COMMA,
    STATE(15675), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15684), 2,
      sym_comment,
      sym_block_comment,
  [647903] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19209), 1,
      anon_sym_COMMA,
    ACTIONS(19211), 1,
      anon_sym_RBRACK,
    STATE(15689), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15685), 2,
      sym_comment,
      sym_block_comment,
  [647923] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19213), 1,
      anon_sym_COLON,
    ACTIONS(16359), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(15686), 2,
      sym_comment,
      sym_block_comment,
  [647941] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19215), 1,
      anon_sym_COMMA,
    ACTIONS(19217), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15687), 2,
      sym_comment,
      sym_block_comment,
  [647961] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5802), 1,
      anon_sym_RPAREN,
    ACTIONS(19219), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15688), 2,
      sym_comment,
      sym_block_comment,
  [647981] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5570), 1,
      anon_sym_RBRACK,
    ACTIONS(19221), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15689), 2,
      sym_comment,
      sym_block_comment,
  [648001] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19201), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15690), 2,
      sym_comment,
      sym_block_comment,
  [648021] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19223), 1,
      anon_sym_COMMA,
    ACTIONS(19225), 1,
      anon_sym_RBRACK,
    STATE(15687), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15691), 2,
      sym_comment,
      sym_block_comment,
  [648041] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19227), 1,
      anon_sym_COMMA,
    ACTIONS(19229), 1,
      anon_sym_RBRACK,
    STATE(15658), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15692), 2,
      sym_comment,
      sym_block_comment,
  [648061] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19231), 1,
      anon_sym_COMMA,
    ACTIONS(19233), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15693), 2,
      sym_comment,
      sym_block_comment,
  [648081] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19235), 1,
      anon_sym_COMMA,
    ACTIONS(19237), 1,
      anon_sym_RBRACK,
    STATE(15683), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15694), 2,
      sym_comment,
      sym_block_comment,
  [648101] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15695), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16547), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [648117] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19239), 1,
      anon_sym_COMMA,
    ACTIONS(19241), 1,
      anon_sym_RBRACK,
    STATE(15700), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15696), 2,
      sym_comment,
      sym_block_comment,
  [648137] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19243), 1,
      anon_sym_COMMA,
    ACTIONS(19245), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15697), 2,
      sym_comment,
      sym_block_comment,
  [648157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19247), 1,
      anon_sym_COLON,
    ACTIONS(16330), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(15698), 2,
      sym_comment,
      sym_block_comment,
  [648175] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19249), 1,
      anon_sym_COMMA,
    ACTIONS(19251), 1,
      anon_sym_RBRACK,
    STATE(15697), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15699), 2,
      sym_comment,
      sym_block_comment,
  [648195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5578), 1,
      anon_sym_RBRACK,
    ACTIONS(19253), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15700), 2,
      sym_comment,
      sym_block_comment,
  [648215] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19255), 1,
      anon_sym_COLON,
    ACTIONS(16235), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(15701), 2,
      sym_comment,
      sym_block_comment,
  [648233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15702), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16725), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [648249] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19257), 1,
      anon_sym_COMMA,
    ACTIONS(19259), 1,
      anon_sym_RPAREN,
    STATE(15260), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15703), 2,
      sym_comment,
      sym_block_comment,
  [648269] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15704), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(15270), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [648285] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19261), 1,
      anon_sym_COMMA,
    ACTIONS(19263), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15705), 2,
      sym_comment,
      sym_block_comment,
  [648305] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19265), 1,
      anon_sym_COMMA,
    ACTIONS(19267), 1,
      anon_sym_RBRACK,
    STATE(15735), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15706), 2,
      sym_comment,
      sym_block_comment,
  [648325] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19269), 1,
      anon_sym_COMMA,
    ACTIONS(19271), 1,
      anon_sym_RBRACK,
    STATE(15711), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15707), 2,
      sym_comment,
      sym_block_comment,
  [648345] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19273), 1,
      anon_sym_COMMA,
    ACTIONS(19275), 1,
      anon_sym_RBRACK,
    STATE(15705), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15708), 2,
      sym_comment,
      sym_block_comment,
  [648365] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15164), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15709), 2,
      sym_comment,
      sym_block_comment,
  [648385] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19277), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15710), 2,
      sym_comment,
      sym_block_comment,
  [648405] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5700), 1,
      anon_sym_RBRACK,
    ACTIONS(19279), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15711), 2,
      sym_comment,
      sym_block_comment,
  [648425] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19277), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15712), 2,
      sym_comment,
      sym_block_comment,
  [648445] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19281), 1,
      anon_sym_COMMA,
    ACTIONS(19283), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15713), 2,
      sym_comment,
      sym_block_comment,
  [648465] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5646), 1,
      anon_sym_RBRACK,
    ACTIONS(19285), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15714), 2,
      sym_comment,
      sym_block_comment,
  [648485] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5890), 1,
      anon_sym_RPAREN,
    ACTIONS(19287), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15715), 2,
      sym_comment,
      sym_block_comment,
  [648505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13174), 1,
      sym__arrow_then_type,
    ACTIONS(19289), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15716), 2,
      sym_comment,
      sym_block_comment,
  [648523] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19291), 1,
      anon_sym_COMMA,
    ACTIONS(19293), 1,
      anon_sym_RBRACK,
    STATE(15713), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15717), 2,
      sym_comment,
      sym_block_comment,
  [648543] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19295), 1,
      anon_sym_COMMA,
    ACTIONS(19297), 1,
      anon_sym_RBRACK,
    STATE(15722), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15718), 2,
      sym_comment,
      sym_block_comment,
  [648563] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15719), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16659), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [648579] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15720), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16870), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [648595] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5388), 1,
      anon_sym_RPAREN,
    ACTIONS(19299), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15721), 2,
      sym_comment,
      sym_block_comment,
  [648615] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5690), 1,
      anon_sym_RBRACK,
    ACTIONS(19301), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15722), 2,
      sym_comment,
      sym_block_comment,
  [648635] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19303), 1,
      anon_sym_COMMA,
    ACTIONS(19305), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15723), 2,
      sym_comment,
      sym_block_comment,
  [648655] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15724), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(16633), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [648671] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19307), 1,
      anon_sym_COMMA,
    ACTIONS(19309), 1,
      anon_sym_RBRACK,
    STATE(15723), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15725), 2,
      sym_comment,
      sym_block_comment,
  [648691] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19311), 1,
      anon_sym_COMMA,
    ACTIONS(19313), 1,
      anon_sym_RPAREN,
    STATE(16113), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15726), 2,
      sym_comment,
      sym_block_comment,
  [648711] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19315), 1,
      anon_sym_COMMA,
    ACTIONS(19317), 1,
      anon_sym_RPAREN,
    STATE(16196), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15727), 2,
      sym_comment,
      sym_block_comment,
  [648731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15728), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(19138), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [648747] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19319), 1,
      anon_sym_COMMA,
    ACTIONS(19321), 1,
      anon_sym_RBRACK,
    STATE(15733), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15729), 2,
      sym_comment,
      sym_block_comment,
  [648767] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15730), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(19193), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [648783] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19323), 1,
      anon_sym_COMMA,
    ACTIONS(19325), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15731), 2,
      sym_comment,
      sym_block_comment,
  [648803] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(15732), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(18975), 3,
      sym__automatic_semicolon,
      sym__outdent,
      anon_sym_SEMI,
  [648819] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5762), 1,
      anon_sym_RBRACK,
    ACTIONS(19327), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15733), 2,
      sym_comment,
      sym_block_comment,
  [648839] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19329), 1,
      anon_sym_COMMA,
    ACTIONS(19331), 1,
      anon_sym_RBRACK,
    STATE(15731), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15734), 2,
      sym_comment,
      sym_block_comment,
  [648859] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5200), 1,
      anon_sym_RBRACK,
    ACTIONS(19333), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15735), 2,
      sym_comment,
      sym_block_comment,
  [648879] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19335), 1,
      sym__interpolated_string_end,
    STATE(15680), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15736), 2,
      sym_comment,
      sym_block_comment,
  [648899] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4590), 1,
      sym__indent,
    STATE(9081), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15737), 2,
      sym_comment,
      sym_block_comment,
  [648917] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5780), 1,
      anon_sym_RBRACK,
    ACTIONS(19337), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15738), 2,
      sym_comment,
      sym_block_comment,
  [648937] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19339), 1,
      anon_sym_COMMA,
    ACTIONS(19341), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15739), 2,
      sym_comment,
      sym_block_comment,
  [648957] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19343), 1,
      anon_sym_COMMA,
    ACTIONS(19345), 1,
      anon_sym_RBRACK,
    STATE(15744), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15740), 2,
      sym_comment,
      sym_block_comment,
  [648977] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19335), 1,
      sym__interpolated_multiline_string_end,
    STATE(15690), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15741), 2,
      sym_comment,
      sym_block_comment,
  [648997] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19347), 1,
      anon_sym_COMMA,
    ACTIONS(19349), 1,
      anon_sym_RBRACK,
    STATE(15739), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15742), 2,
      sym_comment,
      sym_block_comment,
  [649017] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6122), 1,
      anon_sym_RPAREN,
    ACTIONS(19351), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15743), 2,
      sym_comment,
      sym_block_comment,
  [649037] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5798), 1,
      anon_sym_RBRACK,
    ACTIONS(19353), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15744), 2,
      sym_comment,
      sym_block_comment,
  [649057] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15201), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(7710), 1,
      sym_type_arguments,
    STATE(15745), 2,
      sym_comment,
      sym_block_comment,
  [649077] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4652), 1,
      sym__indent,
    STATE(6055), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15746), 2,
      sym_comment,
      sym_block_comment,
  [649095] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19355), 1,
      anon_sym_COMMA,
    ACTIONS(19357), 1,
      anon_sym_RPAREN,
    STATE(15996), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15747), 2,
      sym_comment,
      sym_block_comment,
  [649115] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19359), 1,
      anon_sym_COMMA,
    ACTIONS(19361), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15748), 2,
      sym_comment,
      sym_block_comment,
  [649135] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19363), 1,
      anon_sym_COMMA,
    ACTIONS(19365), 1,
      anon_sym_RBRACK,
    STATE(15738), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15749), 2,
      sym_comment,
      sym_block_comment,
  [649155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5888), 1,
      anon_sym_RBRACK,
    ACTIONS(19367), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15750), 2,
      sym_comment,
      sym_block_comment,
  [649175] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19369), 1,
      anon_sym_COMMA,
    ACTIONS(19371), 1,
      anon_sym_RBRACK,
    STATE(15755), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15751), 2,
      sym_comment,
      sym_block_comment,
  [649195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19373), 1,
      anon_sym_COMMA,
    ACTIONS(19375), 1,
      anon_sym_RBRACK,
    STATE(15748), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15752), 2,
      sym_comment,
      sym_block_comment,
  [649215] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15165), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15753), 2,
      sym_comment,
      sym_block_comment,
  [649235] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5472), 1,
      anon_sym_RPAREN,
    ACTIONS(19377), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15754), 2,
      sym_comment,
      sym_block_comment,
  [649255] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5860), 1,
      anon_sym_RBRACK,
    ACTIONS(19379), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15755), 2,
      sym_comment,
      sym_block_comment,
  [649275] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15178), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15756), 2,
      sym_comment,
      sym_block_comment,
  [649295] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19381), 1,
      anon_sym_COMMA,
    ACTIONS(19383), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15757), 2,
      sym_comment,
      sym_block_comment,
  [649315] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19385), 1,
      anon_sym_COMMA,
    ACTIONS(19387), 1,
      anon_sym_RPAREN,
    STATE(15296), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15758), 2,
      sym_comment,
      sym_block_comment,
  [649335] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19389), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15759), 2,
      sym_comment,
      sym_block_comment,
  [649355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19391), 1,
      anon_sym_COMMA,
    ACTIONS(19393), 1,
      anon_sym_RBRACK,
    STATE(15763), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15760), 2,
      sym_comment,
      sym_block_comment,
  [649375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19395), 1,
      anon_sym_COMMA,
    ACTIONS(19397), 1,
      anon_sym_RBRACK,
    STATE(15757), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15761), 2,
      sym_comment,
      sym_block_comment,
  [649395] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19389), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15762), 2,
      sym_comment,
      sym_block_comment,
  [649415] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5916), 1,
      anon_sym_RBRACK,
    ACTIONS(19399), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15763), 2,
      sym_comment,
      sym_block_comment,
  [649435] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19401), 1,
      anon_sym_COMMA,
    ACTIONS(19403), 1,
      anon_sym_RBRACK,
    STATE(15750), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15764), 2,
      sym_comment,
      sym_block_comment,
  [649455] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19405), 1,
      anon_sym_COMMA,
    ACTIONS(19407), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15765), 2,
      sym_comment,
      sym_block_comment,
  [649475] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5956), 1,
      anon_sym_RBRACK,
    ACTIONS(19409), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15766), 2,
      sym_comment,
      sym_block_comment,
  [649495] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19411), 1,
      anon_sym_COMMA,
    ACTIONS(19413), 1,
      anon_sym_RBRACK,
    STATE(15770), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15767), 2,
      sym_comment,
      sym_block_comment,
  [649515] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19415), 1,
      anon_sym_COMMA,
    ACTIONS(19417), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15768), 2,
      sym_comment,
      sym_block_comment,
  [649535] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6016), 1,
      anon_sym_RPAREN,
    ACTIONS(19419), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15769), 2,
      sym_comment,
      sym_block_comment,
  [649555] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5976), 1,
      anon_sym_RBRACK,
    ACTIONS(19421), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15770), 2,
      sym_comment,
      sym_block_comment,
  [649575] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19423), 1,
      anon_sym_COMMA,
    ACTIONS(19425), 1,
      anon_sym_RBRACK,
    STATE(15768), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15771), 2,
      sym_comment,
      sym_block_comment,
  [649595] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19427), 1,
      anon_sym_COMMA,
    ACTIONS(19429), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15772), 2,
      sym_comment,
      sym_block_comment,
  [649615] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19431), 1,
      anon_sym_COMMA,
    ACTIONS(19433), 1,
      anon_sym_RBRACK,
    STATE(15772), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15773), 2,
      sym_comment,
      sym_block_comment,
  [649635] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19435), 1,
      anon_sym_COMMA,
    ACTIONS(19437), 1,
      anon_sym_RBRACK,
    STATE(15777), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15774), 2,
      sym_comment,
      sym_block_comment,
  [649655] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19439), 1,
      anon_sym_COMMA,
    ACTIONS(19441), 1,
      anon_sym_RBRACK,
    STATE(15799), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15775), 2,
      sym_comment,
      sym_block_comment,
  [649675] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19443), 1,
      anon_sym_COMMA,
    ACTIONS(19445), 1,
      anon_sym_RBRACK,
    STATE(15766), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15776), 2,
      sym_comment,
      sym_block_comment,
  [649695] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6022), 1,
      anon_sym_RBRACK,
    ACTIONS(19447), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15777), 2,
      sym_comment,
      sym_block_comment,
  [649715] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13892), 1,
      sym__arrow_then_type,
    ACTIONS(19449), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15778), 2,
      sym_comment,
      sym_block_comment,
  [649733] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19451), 1,
      anon_sym_COMMA,
    ACTIONS(19453), 1,
      anon_sym_RPAREN,
    STATE(16166), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15779), 2,
      sym_comment,
      sym_block_comment,
  [649753] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19455), 1,
      anon_sym_COMMA,
    ACTIONS(19457), 1,
      anon_sym_RBRACK,
    STATE(15782), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15780), 2,
      sym_comment,
      sym_block_comment,
  [649773] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19459), 1,
      anon_sym_COMMA,
    ACTIONS(19461), 1,
      anon_sym_RPAREN,
    STATE(15332), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15781), 2,
      sym_comment,
      sym_block_comment,
  [649793] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6046), 1,
      anon_sym_RBRACK,
    ACTIONS(19463), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15782), 2,
      sym_comment,
      sym_block_comment,
  [649813] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5246), 1,
      anon_sym_RPAREN,
    ACTIONS(19465), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15783), 2,
      sym_comment,
      sym_block_comment,
  [649833] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19467), 1,
      anon_sym_COMMA,
    ACTIONS(19469), 1,
      anon_sym_RBRACK,
    STATE(15786), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15784), 2,
      sym_comment,
      sym_block_comment,
  [649853] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19471), 1,
      anon_sym_COMMA,
    ACTIONS(19473), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15785), 2,
      sym_comment,
      sym_block_comment,
  [649873] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6080), 1,
      anon_sym_RBRACK,
    ACTIONS(19475), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15786), 2,
      sym_comment,
      sym_block_comment,
  [649893] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19477), 1,
      anon_sym_COMMA,
    ACTIONS(19479), 1,
      anon_sym_RBRACK,
    STATE(15785), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15787), 2,
      sym_comment,
      sym_block_comment,
  [649913] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19481), 1,
      anon_sym_COMMA,
    ACTIONS(19483), 1,
      anon_sym_RBRACK,
    STATE(15790), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15788), 2,
      sym_comment,
      sym_block_comment,
  [649933] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6102), 1,
      anon_sym_RBRACK,
    ACTIONS(19485), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15789), 2,
      sym_comment,
      sym_block_comment,
  [649953] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6110), 1,
      anon_sym_RBRACK,
    ACTIONS(19487), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15790), 2,
      sym_comment,
      sym_block_comment,
  [649973] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6088), 1,
      anon_sym_RPAREN,
    ACTIONS(19489), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15791), 2,
      sym_comment,
      sym_block_comment,
  [649993] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19491), 1,
      anon_sym_COMMA,
    ACTIONS(19493), 1,
      anon_sym_RBRACK,
    STATE(15794), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15792), 2,
      sym_comment,
      sym_block_comment,
  [650013] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19495), 1,
      sym__interpolated_string_end,
    STATE(15759), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15793), 2,
      sym_comment,
      sym_block_comment,
  [650033] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6126), 1,
      anon_sym_RBRACK,
    ACTIONS(19497), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15794), 2,
      sym_comment,
      sym_block_comment,
  [650053] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15180), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(8262), 1,
      sym_type_arguments,
    STATE(15795), 2,
      sym_comment,
      sym_block_comment,
  [650073] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19499), 1,
      anon_sym_COMMA,
    ACTIONS(19501), 1,
      anon_sym_RBRACK,
    STATE(15798), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15796), 2,
      sym_comment,
      sym_block_comment,
  [650093] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19503), 1,
      anon_sym_COMMA,
    ACTIONS(19505), 1,
      anon_sym_RBRACK,
    STATE(15789), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15797), 2,
      sym_comment,
      sym_block_comment,
  [650113] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6154), 1,
      anon_sym_RBRACK,
    ACTIONS(19507), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15798), 2,
      sym_comment,
      sym_block_comment,
  [650133] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5302), 1,
      anon_sym_RBRACK,
    ACTIONS(19509), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15799), 2,
      sym_comment,
      sym_block_comment,
  [650153] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19511), 1,
      anon_sym_COMMA,
    ACTIONS(19513), 1,
      anon_sym_RBRACK,
    STATE(15802), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15800), 2,
      sym_comment,
      sym_block_comment,
  [650173] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19515), 1,
      anon_sym_COMMA,
    ACTIONS(19517), 1,
      anon_sym_RPAREN,
    STATE(16248), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15801), 2,
      sym_comment,
      sym_block_comment,
  [650193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6164), 1,
      anon_sym_RBRACK,
    ACTIONS(19519), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15802), 2,
      sym_comment,
      sym_block_comment,
  [650213] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16361), 1,
      anon_sym_LBRACE,
    ACTIONS(16503), 1,
      anon_sym_EQ,
    STATE(14736), 1,
      sym_block,
    STATE(15803), 2,
      sym_comment,
      sym_block_comment,
  [650233] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19521), 1,
      anon_sym_COMMA,
    ACTIONS(19523), 1,
      anon_sym_RBRACK,
    STATE(15806), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15804), 2,
      sym_comment,
      sym_block_comment,
  [650253] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(19525), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15805), 2,
      sym_comment,
      sym_block_comment,
  [650273] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6054), 1,
      anon_sym_RBRACK,
    ACTIONS(19527), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15806), 2,
      sym_comment,
      sym_block_comment,
  [650293] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19495), 1,
      sym__interpolated_multiline_string_end,
    STATE(15762), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15807), 2,
      sym_comment,
      sym_block_comment,
  [650313] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19529), 1,
      anon_sym_COMMA,
    ACTIONS(19531), 1,
      anon_sym_RBRACK,
    STATE(15810), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15808), 2,
      sym_comment,
      sym_block_comment,
  [650333] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6042), 1,
      anon_sym_RBRACK,
    ACTIONS(19533), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15809), 2,
      sym_comment,
      sym_block_comment,
  [650353] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5938), 1,
      anon_sym_RBRACK,
    ACTIONS(19535), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15810), 2,
      sym_comment,
      sym_block_comment,
  [650373] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5306), 1,
      anon_sym_RPAREN,
    ACTIONS(19537), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15811), 2,
      sym_comment,
      sym_block_comment,
  [650393] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19539), 1,
      anon_sym_COMMA,
    ACTIONS(19541), 1,
      anon_sym_RBRACK,
    STATE(15814), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15812), 2,
      sym_comment,
      sym_block_comment,
  [650413] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12482), 1,
      sym__indent,
    STATE(10427), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15813), 2,
      sym_comment,
      sym_block_comment,
  [650431] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6006), 1,
      anon_sym_RBRACK,
    ACTIONS(19543), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15814), 2,
      sym_comment,
      sym_block_comment,
  [650451] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13886), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(6553), 1,
      sym_type_arguments,
    STATE(15815), 2,
      sym_comment,
      sym_block_comment,
  [650471] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19545), 1,
      anon_sym_COMMA,
    ACTIONS(19547), 1,
      anon_sym_RBRACK,
    STATE(15818), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15816), 2,
      sym_comment,
      sym_block_comment,
  [650491] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19549), 1,
      anon_sym_COMMA,
    ACTIONS(19551), 1,
      anon_sym_RBRACK,
    STATE(15809), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15817), 2,
      sym_comment,
      sym_block_comment,
  [650511] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5970), 1,
      anon_sym_RBRACK,
    ACTIONS(19553), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15818), 2,
      sym_comment,
      sym_block_comment,
  [650531] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19555), 1,
      sym__interpolated_multiline_string_end,
    STATE(15853), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15819), 2,
      sym_comment,
      sym_block_comment,
  [650551] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19557), 1,
      anon_sym_COMMA,
    ACTIONS(19559), 1,
      anon_sym_RBRACK,
    STATE(15822), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15820), 2,
      sym_comment,
      sym_block_comment,
  [650571] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19561), 1,
      anon_sym_COMMA,
    ACTIONS(19563), 1,
      anon_sym_RPAREN,
    STATE(15350), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15821), 2,
      sym_comment,
      sym_block_comment,
  [650591] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5954), 1,
      anon_sym_RBRACK,
    ACTIONS(19565), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15822), 2,
      sym_comment,
      sym_block_comment,
  [650611] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19567), 1,
      anon_sym_COMMA,
    ACTIONS(19569), 1,
      anon_sym_RPAREN,
    STATE(16374), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15823), 2,
      sym_comment,
      sym_block_comment,
  [650631] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19571), 1,
      anon_sym_COMMA,
    ACTIONS(19573), 1,
      anon_sym_RBRACK,
    STATE(15826), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15824), 2,
      sym_comment,
      sym_block_comment,
  [650651] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19575), 1,
      anon_sym_LPAREN,
    ACTIONS(19577), 1,
      sym__automatic_semicolon,
    STATE(13809), 1,
      sym_class_parameters,
    STATE(15825), 2,
      sym_comment,
      sym_block_comment,
  [650671] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5882), 1,
      anon_sym_RBRACK,
    ACTIONS(19579), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15826), 2,
      sym_comment,
      sym_block_comment,
  [650691] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16204), 1,
      anon_sym_COLON,
    ACTIONS(16206), 1,
      anon_sym_LBRACE,
    STATE(14976), 1,
      sym_enum_body,
    STATE(15827), 2,
      sym_comment,
      sym_block_comment,
  [650711] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19581), 1,
      anon_sym_COMMA,
    ACTIONS(19583), 1,
      anon_sym_RBRACK,
    STATE(15830), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15828), 2,
      sym_comment,
      sym_block_comment,
  [650731] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5856), 1,
      anon_sym_RBRACK,
    ACTIONS(19585), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15829), 2,
      sym_comment,
      sym_block_comment,
  [650751] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5854), 1,
      anon_sym_RBRACK,
    ACTIONS(19587), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15830), 2,
      sym_comment,
      sym_block_comment,
  [650771] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5558), 1,
      anon_sym_RPAREN,
    ACTIONS(19589), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15831), 2,
      sym_comment,
      sym_block_comment,
  [650791] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19591), 1,
      anon_sym_COMMA,
    ACTIONS(19593), 1,
      anon_sym_RBRACK,
    STATE(15834), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15832), 2,
      sym_comment,
      sym_block_comment,
  [650811] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19595), 1,
      anon_sym_COMMA,
    ACTIONS(19597), 1,
      anon_sym_RBRACK,
    STATE(15861), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15833), 2,
      sym_comment,
      sym_block_comment,
  [650831] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5832), 1,
      anon_sym_RBRACK,
    ACTIONS(19599), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15834), 2,
      sym_comment,
      sym_block_comment,
  [650851] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12584), 1,
      anon_sym_RPAREN,
    ACTIONS(19601), 1,
      anon_sym_COMMA,
    STATE(15866), 1,
      aux_sym_parameters_repeat1,
    STATE(15835), 2,
      sym_comment,
      sym_block_comment,
  [650871] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19603), 1,
      anon_sym_COMMA,
    ACTIONS(19605), 1,
      anon_sym_RBRACK,
    STATE(15829), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15836), 2,
      sym_comment,
      sym_block_comment,
  [650891] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19607), 1,
      anon_sym_COMMA,
    ACTIONS(19609), 1,
      anon_sym_RPAREN,
    STATE(15868), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15837), 2,
      sym_comment,
      sym_block_comment,
  [650911] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19611), 1,
      anon_sym_COMMA,
    ACTIONS(19613), 1,
      anon_sym_RPAREN,
    STATE(15386), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15838), 2,
      sym_comment,
      sym_block_comment,
  [650931] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12072), 1,
      sym__arrow_then_type,
    ACTIONS(19615), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15839), 2,
      sym_comment,
      sym_block_comment,
  [650949] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4508), 1,
      sym__indent,
    STATE(10917), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15840), 2,
      sym_comment,
      sym_block_comment,
  [650967] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19617), 1,
      anon_sym_COMMA,
    ACTIONS(19619), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15841), 2,
      sym_comment,
      sym_block_comment,
  [650987] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5698), 1,
      anon_sym_RBRACK,
    ACTIONS(19621), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15842), 2,
      sym_comment,
      sym_block_comment,
  [651007] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5864), 1,
      anon_sym_RPAREN,
    ACTIONS(19623), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15843), 2,
      sym_comment,
      sym_block_comment,
  [651027] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6090), 1,
      anon_sym_RBRACK,
    ACTIONS(19625), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15844), 2,
      sym_comment,
      sym_block_comment,
  [651047] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    ACTIONS(19627), 1,
      anon_sym_COLON,
    STATE(15443), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15845), 2,
      sym_comment,
      sym_block_comment,
  [651067] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    ACTIONS(19629), 1,
      anon_sym_COLON,
    STATE(15443), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15846), 2,
      sym_comment,
      sym_block_comment,
  [651087] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19631), 1,
      anon_sym_COMMA,
    ACTIONS(19633), 1,
      anon_sym_RBRACK,
    STATE(15842), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15847), 2,
      sym_comment,
      sym_block_comment,
  [651107] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    ACTIONS(19635), 1,
      anon_sym_COLON,
    STATE(15443), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15848), 2,
      sym_comment,
      sym_block_comment,
  [651127] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    ACTIONS(19637), 1,
      anon_sym_COLON,
    STATE(15443), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15849), 2,
      sym_comment,
      sym_block_comment,
  [651147] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19639), 1,
      anon_sym_COMMA,
    ACTIONS(19641), 1,
      anon_sym_RBRACK,
    STATE(15875), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15850), 2,
      sym_comment,
      sym_block_comment,
  [651167] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19643), 1,
      anon_sym_COMMA,
    ACTIONS(19645), 1,
      anon_sym_RPAREN,
    STATE(15422), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15851), 2,
      sym_comment,
      sym_block_comment,
  [651187] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(14917), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15852), 2,
      sym_comment,
      sym_block_comment,
  [651207] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19647), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15853), 2,
      sym_comment,
      sym_block_comment,
  [651227] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19647), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15854), 2,
      sym_comment,
      sym_block_comment,
  [651247] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5436), 1,
      anon_sym_RBRACK,
    ACTIONS(19649), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15855), 2,
      sym_comment,
      sym_block_comment,
  [651267] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5542), 1,
      anon_sym_RPAREN,
    ACTIONS(19651), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15856), 2,
      sym_comment,
      sym_block_comment,
  [651287] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6114), 1,
      anon_sym_RPAREN,
    ACTIONS(19653), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15857), 2,
      sym_comment,
      sym_block_comment,
  [651307] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7634), 1,
      anon_sym_RPAREN,
    ACTIONS(19655), 1,
      anon_sym_COMMA,
    STATE(15886), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15858), 2,
      sym_comment,
      sym_block_comment,
  [651327] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16204), 1,
      anon_sym_COLON,
    ACTIONS(16206), 1,
      anon_sym_LBRACE,
    STATE(15066), 1,
      sym_enum_body,
    STATE(15859), 2,
      sym_comment,
      sym_block_comment,
  [651347] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19657), 1,
      anon_sym_COMMA,
    ACTIONS(19659), 1,
      anon_sym_RBRACK,
    STATE(15855), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15860), 2,
      sym_comment,
      sym_block_comment,
  [651367] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19661), 1,
      anon_sym_COMMA,
    ACTIONS(19663), 1,
      anon_sym_RBRACK,
    STATE(15517), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15861), 2,
      sym_comment,
      sym_block_comment,
  [651387] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19665), 1,
      anon_sym_COMMA,
    ACTIONS(19667), 1,
      anon_sym_RPAREN,
    STATE(16305), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15862), 2,
      sym_comment,
      sym_block_comment,
  [651407] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12617), 1,
      anon_sym_RPAREN,
    ACTIONS(19669), 1,
      anon_sym_COMMA,
    STATE(15890), 1,
      aux_sym_parameters_repeat1,
    STATE(15863), 2,
      sym_comment,
      sym_block_comment,
  [651427] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17709), 1,
      anon_sym_RPAREN,
    ACTIONS(19671), 1,
      anon_sym_COMMA,
    STATE(15891), 1,
      aux_sym_parameters_repeat1,
    STATE(15864), 2,
      sym_comment,
      sym_block_comment,
  [651447] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17707), 1,
      anon_sym_COMMA,
    ACTIONS(17709), 1,
      anon_sym_RPAREN,
    STATE(15893), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15865), 2,
      sym_comment,
      sym_block_comment,
  [651467] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12617), 1,
      anon_sym_RPAREN,
    ACTIONS(19669), 1,
      anon_sym_COMMA,
    STATE(15542), 1,
      aux_sym_parameters_repeat1,
    STATE(15866), 2,
      sym_comment,
      sym_block_comment,
  [651487] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5334), 1,
      anon_sym_RBRACK,
    ACTIONS(19673), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15867), 2,
      sym_comment,
      sym_block_comment,
  [651507] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5408), 1,
      anon_sym_RPAREN,
    ACTIONS(19675), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15868), 2,
      sym_comment,
      sym_block_comment,
  [651527] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6138), 1,
      anon_sym_RPAREN,
    ACTIONS(19677), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15869), 2,
      sym_comment,
      sym_block_comment,
  [651547] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19679), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15870), 2,
      sym_comment,
      sym_block_comment,
  [651567] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13575), 1,
      anon_sym_LPAREN,
    STATE(14181), 1,
      sym_parameters,
    STATE(14205), 1,
      sym__using_parameters_clause,
    STATE(15871), 2,
      sym_comment,
      sym_block_comment,
  [651587] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19681), 1,
      anon_sym_COMMA,
    ACTIONS(19683), 1,
      anon_sym_RBRACK,
    STATE(15867), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15872), 2,
      sym_comment,
      sym_block_comment,
  [651607] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(19685), 1,
      anon_sym_RPAREN,
    STATE(15551), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15873), 2,
      sym_comment,
      sym_block_comment,
  [651627] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19555), 1,
      sym__interpolated_string_end,
    STATE(15854), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15874), 2,
      sym_comment,
      sym_block_comment,
  [651647] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5366), 1,
      anon_sym_RBRACK,
    ACTIONS(19687), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15875), 2,
      sym_comment,
      sym_block_comment,
  [651667] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19689), 1,
      anon_sym_COMMA,
    ACTIONS(19691), 1,
      anon_sym_RPAREN,
    STATE(15458), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15876), 2,
      sym_comment,
      sym_block_comment,
  [651687] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(19693), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15877), 2,
      sym_comment,
      sym_block_comment,
  [651707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4242), 1,
      sym__indent,
    STATE(8060), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15878), 2,
      sym_comment,
      sym_block_comment,
  [651725] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19695), 1,
      anon_sym_COMMA,
    ACTIONS(19697), 1,
      anon_sym_RBRACK,
    STATE(15925), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15879), 2,
      sym_comment,
      sym_block_comment,
  [651745] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19679), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15880), 2,
      sym_comment,
      sym_block_comment,
  [651765] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16204), 1,
      anon_sym_COLON,
    ACTIONS(16206), 1,
      anon_sym_LBRACE,
    STATE(15105), 1,
      sym_enum_body,
    STATE(15881), 2,
      sym_comment,
      sym_block_comment,
  [651785] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19699), 1,
      anon_sym_COMMA,
    ACTIONS(19701), 1,
      anon_sym_RBRACK,
    STATE(15844), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15882), 2,
      sym_comment,
      sym_block_comment,
  [651805] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7830), 1,
      anon_sym_RPAREN,
    ACTIONS(19703), 1,
      anon_sym_COMMA,
    STATE(15904), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15883), 2,
      sym_comment,
      sym_block_comment,
  [651825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(8651), 1,
      sym__arrow_then_type,
    ACTIONS(19705), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15884), 2,
      sym_comment,
      sym_block_comment,
  [651843] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7798), 1,
      anon_sym_RPAREN,
    ACTIONS(19707), 1,
      anon_sym_COMMA,
    STATE(15907), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15885), 2,
      sym_comment,
      sym_block_comment,
  [651863] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7798), 1,
      anon_sym_RPAREN,
    ACTIONS(19707), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15886), 2,
      sym_comment,
      sym_block_comment,
  [651883] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5244), 1,
      anon_sym_RBRACK,
    ACTIONS(19709), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15887), 2,
      sym_comment,
      sym_block_comment,
  [651903] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17235), 1,
      anon_sym_RBRACE,
    ACTIONS(17237), 1,
      anon_sym_COMMA,
    STATE(15908), 1,
      aux_sym_namespace_selectors_repeat1,
    STATE(15888), 2,
      sym_comment,
      sym_block_comment,
  [651923] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5978), 1,
      anon_sym_RPAREN,
    ACTIONS(19711), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15889), 2,
      sym_comment,
      sym_block_comment,
  [651943] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12664), 1,
      anon_sym_RPAREN,
    ACTIONS(19713), 1,
      anon_sym_COMMA,
    STATE(15542), 1,
      aux_sym_parameters_repeat1,
    STATE(15890), 2,
      sym_comment,
      sym_block_comment,
  [651963] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4994), 1,
      anon_sym_RPAREN,
    ACTIONS(19715), 1,
      anon_sym_COMMA,
    STATE(15542), 1,
      aux_sym_parameters_repeat1,
    STATE(15891), 2,
      sym_comment,
      sym_block_comment,
  [651983] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19717), 1,
      anon_sym_COMMA,
    ACTIONS(19719), 1,
      anon_sym_RBRACK,
    STATE(15887), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15892), 2,
      sym_comment,
      sym_block_comment,
  [652003] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4994), 1,
      anon_sym_RPAREN,
    ACTIONS(19721), 1,
      anon_sym_COMMA,
    STATE(15635), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15893), 2,
      sym_comment,
      sym_block_comment,
  [652023] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    ACTIONS(19723), 1,
      anon_sym_COLON,
    STATE(15443), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15894), 2,
      sym_comment,
      sym_block_comment,
  [652043] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16204), 1,
      anon_sym_COLON,
    ACTIONS(16206), 1,
      anon_sym_LBRACE,
    STATE(15133), 1,
      sym_enum_body,
    STATE(15895), 2,
      sym_comment,
      sym_block_comment,
  [652063] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    ACTIONS(19725), 1,
      anon_sym_COLON,
    STATE(15443), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15896), 2,
      sym_comment,
      sym_block_comment,
  [652083] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7914), 1,
      anon_sym_RPAREN,
    ACTIONS(19727), 1,
      anon_sym_COMMA,
    STATE(15910), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15897), 2,
      sym_comment,
      sym_block_comment,
  [652103] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    ACTIONS(19729), 1,
      anon_sym_COLON,
    STATE(15443), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15898), 2,
      sym_comment,
      sym_block_comment,
  [652123] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19731), 1,
      anon_sym_COMMA,
    ACTIONS(19733), 1,
      anon_sym_RPAREN,
    STATE(16361), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15899), 2,
      sym_comment,
      sym_block_comment,
  [652143] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12315), 1,
      anon_sym_COMMA,
    ACTIONS(19735), 1,
      anon_sym_COLON,
    STATE(15443), 1,
      aux_sym_val_declaration_repeat1,
    STATE(15900), 2,
      sym_comment,
      sym_block_comment,
  [652163] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19737), 1,
      anon_sym_COMMA,
    ACTIONS(19739), 1,
      anon_sym_RBRACK,
    STATE(15956), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15901), 2,
      sym_comment,
      sym_block_comment,
  [652183] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19741), 1,
      anon_sym_COMMA,
    ACTIONS(19743), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15902), 2,
      sym_comment,
      sym_block_comment,
  [652203] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13986), 1,
      sym__arrow_then_type,
    ACTIONS(19745), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15903), 2,
      sym_comment,
      sym_block_comment,
  [652221] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7914), 1,
      anon_sym_RPAREN,
    ACTIONS(19727), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15904), 2,
      sym_comment,
      sym_block_comment,
  [652241] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15125), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15905), 2,
      sym_comment,
      sym_block_comment,
  [652261] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(15047), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15906), 2,
      sym_comment,
      sym_block_comment,
  [652281] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7908), 1,
      anon_sym_RPAREN,
    ACTIONS(19747), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15907), 2,
      sym_comment,
      sym_block_comment,
  [652301] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12512), 1,
      anon_sym_RBRACE,
    ACTIONS(19749), 1,
      anon_sym_COMMA,
    STATE(15667), 1,
      aux_sym_namespace_selectors_repeat1,
    STATE(15908), 2,
      sym_comment,
      sym_block_comment,
  [652321] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7890), 1,
      anon_sym_RPAREN,
    ACTIONS(19751), 1,
      anon_sym_COMMA,
    STATE(15911), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15909), 2,
      sym_comment,
      sym_block_comment,
  [652341] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7848), 1,
      anon_sym_RPAREN,
    ACTIONS(19753), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15910), 2,
      sym_comment,
      sym_block_comment,
  [652361] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7886), 1,
      anon_sym_RPAREN,
    ACTIONS(19755), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15911), 2,
      sym_comment,
      sym_block_comment,
  [652381] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5158), 1,
      anon_sym_RBRACK,
    ACTIONS(19757), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15912), 2,
      sym_comment,
      sym_block_comment,
  [652401] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7430), 1,
      anon_sym_RPAREN,
    ACTIONS(19759), 1,
      anon_sym_COMMA,
    STATE(15551), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15913), 2,
      sym_comment,
      sym_block_comment,
  [652421] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15914), 2,
      sym_comment,
      sym_block_comment,
  [652441] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5912), 1,
      anon_sym_RPAREN,
    ACTIONS(19761), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15915), 2,
      sym_comment,
      sym_block_comment,
  [652461] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19763), 1,
      anon_sym_COMMA,
    ACTIONS(19765), 1,
      anon_sym_RPAREN,
    STATE(16148), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15916), 2,
      sym_comment,
      sym_block_comment,
  [652481] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19767), 1,
      anon_sym_COMMA,
    ACTIONS(19769), 1,
      anon_sym_RBRACK,
    STATE(15929), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15917), 2,
      sym_comment,
      sym_block_comment,
  [652501] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16179), 1,
      anon_sym_LBRACE,
    ACTIONS(16511), 1,
      anon_sym_EQ,
    STATE(14880), 1,
      sym_block,
    STATE(15918), 2,
      sym_comment,
      sym_block_comment,
  [652521] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19771), 1,
      anon_sym_COMMA,
    ACTIONS(19773), 1,
      anon_sym_RBRACK,
    STATE(15912), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15919), 2,
      sym_comment,
      sym_block_comment,
  [652541] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19775), 1,
      sym__interpolated_string_end,
    STATE(15870), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15920), 2,
      sym_comment,
      sym_block_comment,
  [652561] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5812), 1,
      anon_sym_RPAREN,
    ACTIONS(19777), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15921), 2,
      sym_comment,
      sym_block_comment,
  [652581] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19775), 1,
      sym__interpolated_multiline_string_end,
    STATE(15880), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15922), 2,
      sym_comment,
      sym_block_comment,
  [652601] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19779), 1,
      anon_sym_COMMA,
    ACTIONS(19781), 1,
      anon_sym_RPAREN,
    STATE(16377), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15923), 2,
      sym_comment,
      sym_block_comment,
  [652621] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19783), 1,
      sym__interpolated_multiline_string_end,
    STATE(15193), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15924), 2,
      sym_comment,
      sym_block_comment,
  [652641] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5444), 1,
      anon_sym_RBRACK,
    ACTIONS(19785), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15925), 2,
      sym_comment,
      sym_block_comment,
  [652661] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(14967), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(15926), 2,
      sym_comment,
      sym_block_comment,
  [652681] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19783), 1,
      sym__interpolated_string_end,
    STATE(15941), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15927), 2,
      sym_comment,
      sym_block_comment,
  [652701] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19787), 1,
      anon_sym_COMMA,
    ACTIONS(19789), 1,
      anon_sym_RBRACK,
    STATE(15944), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15928), 2,
      sym_comment,
      sym_block_comment,
  [652721] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19791), 1,
      anon_sym_COMMA,
    ACTIONS(19793), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(15929), 2,
      sym_comment,
      sym_block_comment,
  [652741] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15172), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(15930), 2,
      sym_comment,
      sym_block_comment,
  [652761] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12434), 1,
      sym__indent,
    STATE(10767), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15931), 2,
      sym_comment,
      sym_block_comment,
  [652779] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12600), 1,
      anon_sym_RPAREN,
    ACTIONS(19795), 1,
      anon_sym_COMMA,
    STATE(15951), 1,
      aux_sym_parameters_repeat1,
    STATE(15932), 2,
      sym_comment,
      sym_block_comment,
  [652799] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19797), 1,
      anon_sym_COMMA,
    ACTIONS(19799), 1,
      anon_sym_RPAREN,
    STATE(15953), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15933), 2,
      sym_comment,
      sym_block_comment,
  [652819] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11493), 1,
      sym__arrow_then_type,
    ACTIONS(19801), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15934), 2,
      sym_comment,
      sym_block_comment,
  [652837] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19803), 1,
      anon_sym_COMMA,
    ACTIONS(19805), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15935), 2,
      sym_comment,
      sym_block_comment,
  [652857] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15920), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9636), 1,
      sym_type_arguments,
    STATE(15936), 2,
      sym_comment,
      sym_block_comment,
  [652877] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19807), 1,
      anon_sym_COMMA,
    ACTIONS(19809), 1,
      anon_sym_RBRACK,
    STATE(15957), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15937), 2,
      sym_comment,
      sym_block_comment,
  [652897] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5282), 1,
      anon_sym_RBRACK,
    ACTIONS(19811), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15938), 2,
      sym_comment,
      sym_block_comment,
  [652917] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19813), 1,
      anon_sym_COMMA,
    ACTIONS(19815), 1,
      anon_sym_RBRACK,
    STATE(15207), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15939), 2,
      sym_comment,
      sym_block_comment,
  [652937] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5756), 1,
      anon_sym_RPAREN,
    ACTIONS(19817), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15940), 2,
      sym_comment,
      sym_block_comment,
  [652957] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17811), 1,
      sym__interpolated_string_end,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15941), 2,
      sym_comment,
      sym_block_comment,
  [652977] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(19819), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(15942), 2,
      sym_comment,
      sym_block_comment,
  [652997] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19821), 1,
      anon_sym_COMMA,
    ACTIONS(19823), 1,
      anon_sym_RBRACK,
    STATE(15938), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15943), 2,
      sym_comment,
      sym_block_comment,
  [653017] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19825), 1,
      anon_sym_COMMA,
    ACTIONS(19827), 1,
      anon_sym_RBRACK,
    STATE(15517), 1,
      aux_sym_type_parameters_repeat1,
    STATE(15944), 2,
      sym_comment,
      sym_block_comment,
  [653037] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12619), 1,
      anon_sym_RPAREN,
    ACTIONS(19829), 1,
      anon_sym_COMMA,
    STATE(15981), 1,
      aux_sym_parameters_repeat1,
    STATE(15945), 2,
      sym_comment,
      sym_block_comment,
  [653057] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17456), 1,
      anon_sym_RPAREN,
    ACTIONS(19831), 1,
      anon_sym_COMMA,
    STATE(15982), 1,
      aux_sym_parameters_repeat1,
    STATE(15946), 2,
      sym_comment,
      sym_block_comment,
  [653077] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19833), 1,
      anon_sym_COMMA,
    ACTIONS(19835), 1,
      anon_sym_RPAREN,
    STATE(16312), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15947), 2,
      sym_comment,
      sym_block_comment,
  [653097] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17454), 1,
      anon_sym_COMMA,
    ACTIONS(17456), 1,
      anon_sym_RPAREN,
    STATE(15984), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15948), 2,
      sym_comment,
      sym_block_comment,
  [653117] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4418), 1,
      sym__indent,
    STATE(10222), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15949), 2,
      sym_comment,
      sym_block_comment,
  [653135] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6000), 1,
      anon_sym_RBRACK,
    ACTIONS(19837), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15950), 2,
      sym_comment,
      sym_block_comment,
  [653155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12619), 1,
      anon_sym_RPAREN,
    ACTIONS(19829), 1,
      anon_sym_COMMA,
    STATE(15542), 1,
      aux_sym_parameters_repeat1,
    STATE(15951), 2,
      sym_comment,
      sym_block_comment,
  [653175] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19839), 1,
      anon_sym_COMMA,
    ACTIONS(19841), 1,
      anon_sym_RPAREN,
    STATE(16125), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15952), 2,
      sym_comment,
      sym_block_comment,
  [653195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5164), 1,
      anon_sym_RPAREN,
    ACTIONS(19843), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15953), 2,
      sym_comment,
      sym_block_comment,
  [653215] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5684), 1,
      anon_sym_RPAREN,
    ACTIONS(19845), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15954), 2,
      sym_comment,
      sym_block_comment,
  [653235] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(19847), 1,
      anon_sym_RPAREN,
    STATE(15551), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15955), 2,
      sym_comment,
      sym_block_comment,
  [653255] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5360), 1,
      anon_sym_RBRACK,
    ACTIONS(19849), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15956), 2,
      sym_comment,
      sym_block_comment,
  [653275] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5176), 1,
      anon_sym_RBRACK,
    ACTIONS(19851), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15957), 2,
      sym_comment,
      sym_block_comment,
  [653295] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5528), 1,
      anon_sym_RPAREN,
    ACTIONS(19853), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15958), 2,
      sym_comment,
      sym_block_comment,
  [653315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11493), 1,
      sym__arrow_then_type,
    ACTIONS(19855), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15959), 2,
      sym_comment,
      sym_block_comment,
  [653333] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4748), 1,
      sym__indent,
    STATE(9914), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(15960), 2,
      sym_comment,
      sym_block_comment,
  [653351] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7910), 1,
      anon_sym_RPAREN,
    ACTIONS(19857), 1,
      anon_sym_COMMA,
    STATE(15988), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15961), 2,
      sym_comment,
      sym_block_comment,
  [653371] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11902), 1,
      sym__arrow_then_type,
    ACTIONS(19859), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15962), 2,
      sym_comment,
      sym_block_comment,
  [653389] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11824), 1,
      sym__arrow_then_type,
    ACTIONS(19861), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15963), 2,
      sym_comment,
      sym_block_comment,
  [653407] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13566), 1,
      sym__arrow_then_type,
    ACTIONS(19863), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15964), 2,
      sym_comment,
      sym_block_comment,
  [653425] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13380), 1,
      sym__arrow_then_type,
    ACTIONS(19865), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15965), 2,
      sym_comment,
      sym_block_comment,
  [653443] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12414), 1,
      sym__arrow_then_type,
    ACTIONS(19867), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15966), 2,
      sym_comment,
      sym_block_comment,
  [653461] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13643), 1,
      sym__arrow_then_type,
    ACTIONS(19869), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15967), 2,
      sym_comment,
      sym_block_comment,
  [653479] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13543), 1,
      sym__arrow_then_type,
    ACTIONS(19871), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15968), 2,
      sym_comment,
      sym_block_comment,
  [653497] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11612), 1,
      sym__arrow_then_type,
    ACTIONS(19873), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15969), 2,
      sym_comment,
      sym_block_comment,
  [653515] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12390), 1,
      sym__arrow_then_type,
    ACTIONS(19875), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15970), 2,
      sym_comment,
      sym_block_comment,
  [653533] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12776), 1,
      sym__arrow_then_type,
    ACTIONS(19877), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15971), 2,
      sym_comment,
      sym_block_comment,
  [653551] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13986), 1,
      sym__arrow_then_type,
    ACTIONS(19879), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15972), 2,
      sym_comment,
      sym_block_comment,
  [653569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13892), 1,
      sym__arrow_then_type,
    ACTIONS(19881), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15973), 2,
      sym_comment,
      sym_block_comment,
  [653587] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13174), 1,
      sym__arrow_then_type,
    ACTIONS(19883), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15974), 2,
      sym_comment,
      sym_block_comment,
  [653605] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(14018), 1,
      sym__arrow_then_type,
    ACTIONS(19885), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15975), 2,
      sym_comment,
      sym_block_comment,
  [653623] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11818), 1,
      sym__arrow_then_type,
    ACTIONS(19887), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15976), 2,
      sym_comment,
      sym_block_comment,
  [653641] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13300), 1,
      sym__arrow_then_type,
    ACTIONS(19889), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15977), 2,
      sym_comment,
      sym_block_comment,
  [653659] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13423), 1,
      sym__arrow_then_type,
    ACTIONS(19891), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15978), 2,
      sym_comment,
      sym_block_comment,
  [653677] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19893), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(15979), 2,
      sym_comment,
      sym_block_comment,
  [653697] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7910), 1,
      anon_sym_RPAREN,
    ACTIONS(19857), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15980), 2,
      sym_comment,
      sym_block_comment,
  [653717] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12623), 1,
      anon_sym_RPAREN,
    ACTIONS(19895), 1,
      anon_sym_COMMA,
    STATE(15542), 1,
      aux_sym_parameters_repeat1,
    STATE(15981), 2,
      sym_comment,
      sym_block_comment,
  [653737] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5016), 1,
      anon_sym_RPAREN,
    ACTIONS(19897), 1,
      anon_sym_COMMA,
    STATE(15542), 1,
      aux_sym_parameters_repeat1,
    STATE(15982), 2,
      sym_comment,
      sym_block_comment,
  [653757] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19899), 1,
      anon_sym_COMMA,
    ACTIONS(19901), 1,
      anon_sym_RPAREN,
    STATE(16239), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15983), 2,
      sym_comment,
      sym_block_comment,
  [653777] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5016), 1,
      anon_sym_RPAREN,
    ACTIONS(19903), 1,
      anon_sym_COMMA,
    STATE(15635), 1,
      aux_sym__using_parameters_clause_repeat1,
    STATE(15984), 2,
      sym_comment,
      sym_block_comment,
  [653797] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19905), 1,
      anon_sym_COMMA,
    ACTIONS(19907), 1,
      anon_sym_RBRACK,
    STATE(16006), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15985), 2,
      sym_comment,
      sym_block_comment,
  [653817] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19893), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(15986), 2,
      sym_comment,
      sym_block_comment,
  [653837] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7404), 1,
      anon_sym_RPAREN,
    ACTIONS(19909), 1,
      anon_sym_COMMA,
    STATE(15551), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(15987), 2,
      sym_comment,
      sym_block_comment,
  [653857] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7890), 1,
      anon_sym_RPAREN,
    ACTIONS(19751), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15988), 2,
      sym_comment,
      sym_block_comment,
  [653877] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19911), 1,
      anon_sym_COMMA,
    ACTIONS(19913), 1,
      anon_sym_RBRACK,
    STATE(15950), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15989), 2,
      sym_comment,
      sym_block_comment,
  [653897] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7908), 1,
      anon_sym_RPAREN,
    ACTIONS(19747), 1,
      anon_sym_COMMA,
    STATE(15991), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15990), 2,
      sym_comment,
      sym_block_comment,
  [653917] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7896), 1,
      anon_sym_RPAREN,
    ACTIONS(19915), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15991), 2,
      sym_comment,
      sym_block_comment,
  [653937] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7762), 1,
      anon_sym_RPAREN,
    ACTIONS(19917), 1,
      anon_sym_COMMA,
    STATE(15980), 1,
      aux_sym_class_parameters_repeat1,
    STATE(15992), 2,
      sym_comment,
      sym_block_comment,
  [653957] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15944), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9861), 1,
      sym_type_arguments,
    STATE(15993), 2,
      sym_comment,
      sym_block_comment,
  [653977] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5470), 1,
      anon_sym_RBRACK,
    ACTIONS(19919), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15994), 2,
      sym_comment,
      sym_block_comment,
  [653997] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19921), 1,
      anon_sym_COMMA,
    ACTIONS(19923), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(15995), 2,
      sym_comment,
      sym_block_comment,
  [654017] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5290), 1,
      anon_sym_RPAREN,
    ACTIONS(19925), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15996), 2,
      sym_comment,
      sym_block_comment,
  [654037] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16361), 1,
      anon_sym_LBRACE,
    ACTIONS(16363), 1,
      anon_sym_EQ,
    STATE(14736), 1,
      sym_block,
    STATE(15997), 2,
      sym_comment,
      sym_block_comment,
  [654057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12776), 1,
      sym__arrow_then_type,
    ACTIONS(19927), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(15998), 2,
      sym_comment,
      sym_block_comment,
  [654075] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5668), 1,
      anon_sym_RPAREN,
    ACTIONS(19929), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(15999), 2,
      sym_comment,
      sym_block_comment,
  [654095] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19931), 1,
      anon_sym_COMMA,
    ACTIONS(19933), 1,
      anon_sym_RBRACK,
    STATE(15994), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16000), 2,
      sym_comment,
      sym_block_comment,
  [654115] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19935), 1,
      anon_sym_COMMA,
    ACTIONS(19937), 1,
      anon_sym_RPAREN,
    STATE(16223), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16001), 2,
      sym_comment,
      sym_block_comment,
  [654135] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19939), 1,
      sym__interpolated_multiline_string_end,
    STATE(16018), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16002), 2,
      sym_comment,
      sym_block_comment,
  [654155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19939), 1,
      sym__interpolated_string_end,
    STATE(16019), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16003), 2,
      sym_comment,
      sym_block_comment,
  [654175] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19941), 1,
      anon_sym_COMMA,
    ACTIONS(19943), 1,
      anon_sym_RPAREN,
    STATE(16180), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16004), 2,
      sym_comment,
      sym_block_comment,
  [654195] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19945), 1,
      anon_sym_COMMA,
    ACTIONS(19947), 1,
      anon_sym_RBRACK,
    STATE(16060), 1,
      aux_sym_type_parameters_repeat1,
    STATE(16005), 2,
      sym_comment,
      sym_block_comment,
  [654215] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5564), 1,
      anon_sym_RBRACK,
    ACTIONS(19949), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16006), 2,
      sym_comment,
      sym_block_comment,
  [654235] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19951), 1,
      sym__interpolated_string_end,
    STATE(15979), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16007), 2,
      sym_comment,
      sym_block_comment,
  [654255] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19953), 1,
      anon_sym_COMMA,
    ACTIONS(19955), 1,
      anon_sym_RPAREN,
    STATE(16023), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16008), 2,
      sym_comment,
      sym_block_comment,
  [654275] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19951), 1,
      sym__interpolated_multiline_string_end,
    STATE(15986), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16009), 2,
      sym_comment,
      sym_block_comment,
  [654295] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12012), 1,
      sym__arrow_then_type,
    ACTIONS(19957), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16010), 2,
      sym_comment,
      sym_block_comment,
  [654313] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19959), 1,
      anon_sym_COMMA,
    ACTIONS(19961), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16011), 2,
      sym_comment,
      sym_block_comment,
  [654333] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(19963), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16012), 2,
      sym_comment,
      sym_block_comment,
  [654353] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12394), 1,
      sym__indent,
    STATE(10519), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16013), 2,
      sym_comment,
      sym_block_comment,
  [654371] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15039), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16014), 2,
      sym_comment,
      sym_block_comment,
  [654391] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5562), 1,
      anon_sym_RBRACK,
    ACTIONS(19965), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16015), 2,
      sym_comment,
      sym_block_comment,
  [654411] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15678), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9203), 1,
      sym_type_arguments,
    STATE(16016), 2,
      sym_comment,
      sym_block_comment,
  [654431] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5304), 1,
      anon_sym_RPAREN,
    ACTIONS(19967), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16017), 2,
      sym_comment,
      sym_block_comment,
  [654451] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(19969), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16018), 2,
      sym_comment,
      sym_block_comment,
  [654471] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(19969), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16019), 2,
      sym_comment,
      sym_block_comment,
  [654491] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19971), 1,
      anon_sym_COMMA,
    ACTIONS(19973), 1,
      anon_sym_RBRACK,
    STATE(16015), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16020), 2,
      sym_comment,
      sym_block_comment,
  [654511] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7740), 1,
      anon_sym_RPAREN,
    ACTIONS(19975), 1,
      anon_sym_COMMA,
    STATE(16034), 1,
      aux_sym_class_parameters_repeat1,
    STATE(16021), 2,
      sym_comment,
      sym_block_comment,
  [654531] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19977), 1,
      anon_sym_COMMA,
    ACTIONS(19979), 1,
      anon_sym_RBRACK,
    STATE(16031), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16022), 2,
      sym_comment,
      sym_block_comment,
  [654551] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5376), 1,
      anon_sym_RPAREN,
    ACTIONS(19981), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16023), 2,
      sym_comment,
      sym_block_comment,
  [654571] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19983), 1,
      anon_sym_COMMA,
    ACTIONS(19985), 1,
      anon_sym_RPAREN,
    STATE(16088), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16024), 2,
      sym_comment,
      sym_block_comment,
  [654591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12398), 1,
      sym__indent,
    STATE(11309), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16025), 2,
      sym_comment,
      sym_block_comment,
  [654609] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12486), 1,
      sym__indent,
    STATE(11359), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16026), 2,
      sym_comment,
      sym_block_comment,
  [654627] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5808), 1,
      anon_sym_RBRACK,
    ACTIONS(19987), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16027), 2,
      sym_comment,
      sym_block_comment,
  [654647] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(14904), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16028), 2,
      sym_comment,
      sym_block_comment,
  [654667] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    ACTIONS(19989), 1,
      anon_sym_RPAREN,
    STATE(15551), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(16029), 2,
      sym_comment,
      sym_block_comment,
  [654687] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(15171), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16030), 2,
      sym_comment,
      sym_block_comment,
  [654707] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5402), 1,
      anon_sym_RBRACK,
    ACTIONS(19991), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16031), 2,
      sym_comment,
      sym_block_comment,
  [654727] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4828), 1,
      sym__indent,
    STATE(9693), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16032), 2,
      sym_comment,
      sym_block_comment,
  [654745] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7836), 1,
      anon_sym_RPAREN,
    ACTIONS(19993), 1,
      anon_sym_COMMA,
    STATE(16038), 1,
      aux_sym_class_parameters_repeat1,
    STATE(16033), 2,
      sym_comment,
      sym_block_comment,
  [654765] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7836), 1,
      anon_sym_RPAREN,
    ACTIONS(19993), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(16034), 2,
      sym_comment,
      sym_block_comment,
  [654785] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7384), 1,
      anon_sym_RPAREN,
    ACTIONS(19995), 1,
      anon_sym_COMMA,
    STATE(15551), 1,
      aux_sym_case_class_pattern_repeat1,
    STATE(16035), 2,
      sym_comment,
      sym_block_comment,
  [654805] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19997), 1,
      anon_sym_COMMA,
    ACTIONS(19999), 1,
      anon_sym_RBRACK,
    STATE(16041), 1,
      aux_sym_type_lambda_repeat1,
    STATE(16036), 2,
      sym_comment,
      sym_block_comment,
  [654825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4274), 1,
      sym__indent,
    STATE(8555), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16037), 2,
      sym_comment,
      sym_block_comment,
  [654843] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7834), 1,
      anon_sym_RPAREN,
    ACTIONS(20001), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(16038), 2,
      sym_comment,
      sym_block_comment,
  [654863] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5648), 1,
      anon_sym_RBRACK,
    ACTIONS(20003), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16039), 2,
      sym_comment,
      sym_block_comment,
  [654883] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7834), 1,
      anon_sym_RPAREN,
    ACTIONS(20001), 1,
      anon_sym_COMMA,
    STATE(16043), 1,
      aux_sym_class_parameters_repeat1,
    STATE(16040), 2,
      sym_comment,
      sym_block_comment,
  [654903] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20005), 1,
      anon_sym_COMMA,
    ACTIONS(20007), 1,
      anon_sym_RBRACK,
    STATE(15622), 1,
      aux_sym_type_lambda_repeat1,
    STATE(16041), 2,
      sym_comment,
      sym_block_comment,
  [654923] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15062), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16042), 2,
      sym_comment,
      sym_block_comment,
  [654943] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7826), 1,
      anon_sym_RPAREN,
    ACTIONS(20009), 1,
      anon_sym_COMMA,
    STATE(15592), 1,
      aux_sym_class_parameters_repeat1,
    STATE(16043), 2,
      sym_comment,
      sym_block_comment,
  [654963] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5838), 1,
      anon_sym_RPAREN,
    ACTIONS(20011), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16044), 2,
      sym_comment,
      sym_block_comment,
  [654983] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13771), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(6538), 1,
      sym_type_arguments,
    STATE(16045), 2,
      sym_comment,
      sym_block_comment,
  [655003] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20013), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16046), 2,
      sym_comment,
      sym_block_comment,
  [655023] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6040), 1,
      anon_sym_RPAREN,
    ACTIONS(20015), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16047), 2,
      sym_comment,
      sym_block_comment,
  [655043] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16179), 1,
      anon_sym_LBRACE,
    ACTIONS(16183), 1,
      anon_sym_EQ,
    STATE(14880), 1,
      sym_block,
    STATE(16048), 2,
      sym_comment,
      sym_block_comment,
  [655063] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20017), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16049), 2,
      sym_comment,
      sym_block_comment,
  [655083] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20019), 1,
      anon_sym_COMMA,
    ACTIONS(20021), 1,
      anon_sym_RBRACK,
    STATE(16039), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16050), 2,
      sym_comment,
      sym_block_comment,
  [655103] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11493), 1,
      sym__arrow_then_type,
    ACTIONS(20023), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16051), 2,
      sym_comment,
      sym_block_comment,
  [655121] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11902), 1,
      sym__arrow_then_type,
    ACTIONS(20025), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16052), 2,
      sym_comment,
      sym_block_comment,
  [655139] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11824), 1,
      sym__arrow_then_type,
    ACTIONS(20027), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16053), 2,
      sym_comment,
      sym_block_comment,
  [655157] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13380), 1,
      sym__arrow_then_type,
    ACTIONS(20029), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16054), 2,
      sym_comment,
      sym_block_comment,
  [655175] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12414), 1,
      sym__arrow_then_type,
    ACTIONS(20031), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16055), 2,
      sym_comment,
      sym_block_comment,
  [655193] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11612), 1,
      sym__arrow_then_type,
    ACTIONS(20033), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16056), 2,
      sym_comment,
      sym_block_comment,
  [655211] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12390), 1,
      sym__arrow_then_type,
    ACTIONS(20035), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16057), 2,
      sym_comment,
      sym_block_comment,
  [655229] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11818), 1,
      sym__arrow_then_type,
    ACTIONS(20037), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16058), 2,
      sym_comment,
      sym_block_comment,
  [655247] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20039), 1,
      anon_sym_COMMA,
    ACTIONS(20041), 1,
      anon_sym_RPAREN,
    STATE(15940), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16059), 2,
      sym_comment,
      sym_block_comment,
  [655267] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20043), 1,
      anon_sym_COMMA,
    ACTIONS(20045), 1,
      anon_sym_RBRACK,
    STATE(15517), 1,
      aux_sym_type_parameters_repeat1,
    STATE(16060), 2,
      sym_comment,
      sym_block_comment,
  [655287] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20047), 1,
      sym__interpolated_multiline_string_end,
    STATE(16072), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16061), 2,
      sym_comment,
      sym_block_comment,
  [655307] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20049), 1,
      anon_sym_COMMA,
    ACTIONS(20051), 1,
      anon_sym_RPAREN,
    STATE(15999), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16062), 2,
      sym_comment,
      sym_block_comment,
  [655327] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20047), 1,
      sym__interpolated_string_end,
    STATE(16074), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16063), 2,
      sym_comment,
      sym_block_comment,
  [655347] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20053), 1,
      anon_sym_COMMA,
    ACTIONS(20055), 1,
      anon_sym_RBRACK,
    STATE(16076), 1,
      aux_sym_type_parameters_repeat1,
    STATE(16064), 2,
      sym_comment,
      sym_block_comment,
  [655367] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20017), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16065), 2,
      sym_comment,
      sym_block_comment,
  [655387] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20057), 1,
      anon_sym_COMMA,
    ACTIONS(20059), 1,
      anon_sym_RPAREN,
    STATE(16118), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16066), 2,
      sym_comment,
      sym_block_comment,
  [655407] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20061), 1,
      anon_sym_COMMA,
    ACTIONS(20063), 1,
      anon_sym_RBRACK,
    STATE(16027), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16067), 2,
      sym_comment,
      sym_block_comment,
  [655427] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11902), 1,
      sym__arrow_then_type,
    ACTIONS(20065), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16068), 2,
      sym_comment,
      sym_block_comment,
  [655445] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20067), 1,
      anon_sym_COMMA,
    ACTIONS(20069), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16069), 2,
      sym_comment,
      sym_block_comment,
  [655465] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20071), 1,
      anon_sym_COMMA,
    ACTIONS(20073), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16070), 2,
      sym_comment,
      sym_block_comment,
  [655485] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20075), 1,
      anon_sym_COMMA,
    ACTIONS(20077), 1,
      anon_sym_RBRACK,
    STATE(16082), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16071), 2,
      sym_comment,
      sym_block_comment,
  [655505] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20079), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16072), 2,
      sym_comment,
      sym_block_comment,
  [655525] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12447), 1,
      sym__indent,
    STATE(10336), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16073), 2,
      sym_comment,
      sym_block_comment,
  [655543] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20079), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16074), 2,
      sym_comment,
      sym_block_comment,
  [655563] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5796), 1,
      anon_sym_RBRACK,
    ACTIONS(20081), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16075), 2,
      sym_comment,
      sym_block_comment,
  [655583] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20083), 1,
      anon_sym_COMMA,
    ACTIONS(20085), 1,
      anon_sym_RBRACK,
    STATE(15517), 1,
      aux_sym_type_parameters_repeat1,
    STATE(16076), 2,
      sym_comment,
      sym_block_comment,
  [655603] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5182), 1,
      anon_sym_RPAREN,
    ACTIONS(20087), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16077), 2,
      sym_comment,
      sym_block_comment,
  [655623] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5254), 1,
      anon_sym_RPAREN,
    ACTIONS(20089), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16078), 2,
      sym_comment,
      sym_block_comment,
  [655643] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20091), 1,
      anon_sym_COMMA,
    ACTIONS(20093), 1,
      anon_sym_RBRACK,
    STATE(16091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16079), 2,
      sym_comment,
      sym_block_comment,
  [655663] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20095), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16080), 2,
      sym_comment,
      sym_block_comment,
  [655683] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20097), 1,
      anon_sym_COMMA,
    ACTIONS(20099), 1,
      anon_sym_RBRACK,
    STATE(16075), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16081), 2,
      sym_comment,
      sym_block_comment,
  [655703] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5510), 1,
      anon_sym_RBRACK,
    ACTIONS(20101), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16082), 2,
      sym_comment,
      sym_block_comment,
  [655723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12500), 1,
      sym__indent,
    STATE(11598), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16083), 2,
      sym_comment,
      sym_block_comment,
  [655741] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15842), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9560), 1,
      sym_type_arguments,
    STATE(16084), 2,
      sym_comment,
      sym_block_comment,
  [655761] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20103), 1,
      anon_sym_COMMA,
    ACTIONS(20105), 1,
      anon_sym_RPAREN,
    STATE(15921), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16085), 2,
      sym_comment,
      sym_block_comment,
  [655781] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15505), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(8442), 1,
      sym_type_arguments,
    STATE(16086), 2,
      sym_comment,
      sym_block_comment,
  [655801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12390), 1,
      sym__arrow_then_type,
    ACTIONS(20107), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16087), 2,
      sym_comment,
      sym_block_comment,
  [655819] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5584), 1,
      anon_sym_RPAREN,
    ACTIONS(20109), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16088), 2,
      sym_comment,
      sym_block_comment,
  [655839] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(15160), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16089), 2,
      sym_comment,
      sym_block_comment,
  [655859] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20111), 1,
      anon_sym_COMMA,
    ACTIONS(20113), 1,
      anon_sym_RPAREN,
    STATE(16277), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16090), 2,
      sym_comment,
      sym_block_comment,
  [655879] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5790), 1,
      anon_sym_RBRACK,
    ACTIONS(20115), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16091), 2,
      sym_comment,
      sym_block_comment,
  [655899] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20117), 1,
      sym__interpolated_string_end,
    STATE(16049), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16092), 2,
      sym_comment,
      sym_block_comment,
  [655919] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20119), 1,
      sym__interpolated_multiline_string_end,
    STATE(16114), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16093), 2,
      sym_comment,
      sym_block_comment,
  [655939] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20119), 1,
      sym__interpolated_string_end,
    STATE(16115), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16094), 2,
      sym_comment,
      sym_block_comment,
  [655959] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20121), 1,
      anon_sym_COMMA,
    ACTIONS(20123), 1,
      anon_sym_RBRACK,
    STATE(16117), 1,
      aux_sym_type_parameters_repeat1,
    STATE(16095), 2,
      sym_comment,
      sym_block_comment,
  [655979] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20125), 1,
      anon_sym_COMMA,
    ACTIONS(20127), 1,
      anon_sym_RPAREN,
    STATE(16179), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16096), 2,
      sym_comment,
      sym_block_comment,
  [655999] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15013), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16097), 2,
      sym_comment,
      sym_block_comment,
  [656019] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11824), 1,
      sym__arrow_then_type,
    ACTIONS(20129), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16098), 2,
      sym_comment,
      sym_block_comment,
  [656037] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20117), 1,
      sym__interpolated_multiline_string_end,
    STATE(16065), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16099), 2,
      sym_comment,
      sym_block_comment,
  [656057] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12365), 1,
      sym__indent,
    STATE(12213), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16100), 2,
      sym_comment,
      sym_block_comment,
  [656075] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12496), 1,
      sym__indent,
    STATE(8960), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16101), 2,
      sym_comment,
      sym_block_comment,
  [656093] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20131), 1,
      anon_sym_COMMA,
    ACTIONS(20133), 1,
      anon_sym_RBRACK,
    STATE(16120), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16102), 2,
      sym_comment,
      sym_block_comment,
  [656113] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5932), 1,
      anon_sym_RBRACK,
    ACTIONS(20135), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16103), 2,
      sym_comment,
      sym_block_comment,
  [656133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11493), 1,
      sym__arrow_then_type,
    ACTIONS(20137), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16104), 2,
      sym_comment,
      sym_block_comment,
  [656151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11902), 1,
      sym__arrow_then_type,
    ACTIONS(20139), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16105), 2,
      sym_comment,
      sym_block_comment,
  [656169] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11824), 1,
      sym__arrow_then_type,
    ACTIONS(20141), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16106), 2,
      sym_comment,
      sym_block_comment,
  [656187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13380), 1,
      sym__arrow_then_type,
    ACTIONS(20143), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16107), 2,
      sym_comment,
      sym_block_comment,
  [656205] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12414), 1,
      sym__arrow_then_type,
    ACTIONS(20145), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16108), 2,
      sym_comment,
      sym_block_comment,
  [656223] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11612), 1,
      sym__arrow_then_type,
    ACTIONS(20147), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16109), 2,
      sym_comment,
      sym_block_comment,
  [656241] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12390), 1,
      sym__arrow_then_type,
    ACTIONS(20149), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16110), 2,
      sym_comment,
      sym_block_comment,
  [656259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11818), 1,
      sym__arrow_then_type,
    ACTIONS(20151), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16111), 2,
      sym_comment,
      sym_block_comment,
  [656277] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15034), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(7669), 1,
      sym_type_arguments,
    STATE(16112), 2,
      sym_comment,
      sym_block_comment,
  [656297] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5706), 1,
      anon_sym_RPAREN,
    ACTIONS(20153), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16113), 2,
      sym_comment,
      sym_block_comment,
  [656317] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20155), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16114), 2,
      sym_comment,
      sym_block_comment,
  [656337] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20155), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16115), 2,
      sym_comment,
      sym_block_comment,
  [656357] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20157), 1,
      anon_sym_COMMA,
    ACTIONS(20159), 1,
      anon_sym_RBRACK,
    STATE(16103), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16116), 2,
      sym_comment,
      sym_block_comment,
  [656377] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20161), 1,
      anon_sym_COMMA,
    ACTIONS(20163), 1,
      anon_sym_RBRACK,
    STATE(15517), 1,
      aux_sym_type_parameters_repeat1,
    STATE(16117), 2,
      sym_comment,
      sym_block_comment,
  [656397] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5500), 1,
      anon_sym_RPAREN,
    ACTIONS(20165), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16118), 2,
      sym_comment,
      sym_block_comment,
  [656417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4772), 1,
      sym__indent,
    STATE(9361), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16119), 2,
      sym_comment,
      sym_block_comment,
  [656435] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5618), 1,
      anon_sym_RBRACK,
    ACTIONS(20167), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16120), 2,
      sym_comment,
      sym_block_comment,
  [656455] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4688), 1,
      sym__indent,
    STATE(6221), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16121), 2,
      sym_comment,
      sym_block_comment,
  [656473] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20169), 1,
      anon_sym_COMMA,
    ACTIONS(20171), 1,
      anon_sym_RPAREN,
    STATE(15566), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16122), 2,
      sym_comment,
      sym_block_comment,
  [656493] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5530), 1,
      anon_sym_RBRACK,
    ACTIONS(20173), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16123), 2,
      sym_comment,
      sym_block_comment,
  [656513] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(14985), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16124), 2,
      sym_comment,
      sym_block_comment,
  [656533] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5550), 1,
      anon_sym_RPAREN,
    ACTIONS(20175), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16125), 2,
      sym_comment,
      sym_block_comment,
  [656553] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15988), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9925), 1,
      sym_type_arguments,
    STATE(16126), 2,
      sym_comment,
      sym_block_comment,
  [656573] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20177), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16127), 2,
      sym_comment,
      sym_block_comment,
  [656593] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20177), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16128), 2,
      sym_comment,
      sym_block_comment,
  [656613] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(14994), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16129), 2,
      sym_comment,
      sym_block_comment,
  [656633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12466), 1,
      sym__indent,
    STATE(10944), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16130), 2,
      sym_comment,
      sym_block_comment,
  [656651] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20179), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16131), 2,
      sym_comment,
      sym_block_comment,
  [656671] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20181), 1,
      sym__interpolated_multiline_string_end,
    STATE(16145), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16132), 2,
      sym_comment,
      sym_block_comment,
  [656691] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6176), 1,
      anon_sym_RBRACK,
    ACTIONS(20183), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16133), 2,
      sym_comment,
      sym_block_comment,
  [656711] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20181), 1,
      sym__interpolated_string_end,
    STATE(16146), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16134), 2,
      sym_comment,
      sym_block_comment,
  [656731] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5420), 1,
      anon_sym_RPAREN,
    ACTIONS(20185), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16135), 2,
      sym_comment,
      sym_block_comment,
  [656751] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20187), 1,
      anon_sym_COMMA,
    ACTIONS(20189), 1,
      anon_sym_RPAREN,
    STATE(16263), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16136), 2,
      sym_comment,
      sym_block_comment,
  [656771] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11493), 1,
      sym__arrow_then_type,
    ACTIONS(20191), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16137), 2,
      sym_comment,
      sym_block_comment,
  [656789] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20193), 1,
      anon_sym_COMMA,
    ACTIONS(20195), 1,
      anon_sym_RBRACK,
    STATE(16133), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16138), 2,
      sym_comment,
      sym_block_comment,
  [656809] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20197), 1,
      anon_sym_COMMA,
    ACTIONS(20199), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16139), 2,
      sym_comment,
      sym_block_comment,
  [656829] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(15124), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16140), 2,
      sym_comment,
      sym_block_comment,
  [656849] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20201), 1,
      anon_sym_COMMA,
    ACTIONS(20203), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16141), 2,
      sym_comment,
      sym_block_comment,
  [656869] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20205), 1,
      anon_sym_COMMA,
    ACTIONS(20207), 1,
      anon_sym_RBRACK,
    STATE(16123), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16142), 2,
      sym_comment,
      sym_block_comment,
  [656889] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20209), 1,
      anon_sym_COMMA,
    ACTIONS(20211), 1,
      anon_sym_RBRACK,
    STATE(16150), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16143), 2,
      sym_comment,
      sym_block_comment,
  [656909] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20213), 1,
      anon_sym_COMMA,
    ACTIONS(20215), 1,
      anon_sym_RPAREN,
    STATE(15515), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16144), 2,
      sym_comment,
      sym_block_comment,
  [656929] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20217), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16145), 2,
      sym_comment,
      sym_block_comment,
  [656949] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20217), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16146), 2,
      sym_comment,
      sym_block_comment,
  [656969] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(14871), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16147), 2,
      sym_comment,
      sym_block_comment,
  [656989] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6134), 1,
      anon_sym_RPAREN,
    ACTIONS(20219), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16148), 2,
      sym_comment,
      sym_block_comment,
  [657009] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20221), 1,
      anon_sym_COMMA,
    ACTIONS(20223), 1,
      anon_sym_RPAREN,
    STATE(15889), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16149), 2,
      sym_comment,
      sym_block_comment,
  [657029] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5710), 1,
      anon_sym_RBRACK,
    ACTIONS(20225), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16150), 2,
      sym_comment,
      sym_block_comment,
  [657049] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20227), 1,
      anon_sym_COMMA,
    ACTIONS(20229), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16151), 2,
      sym_comment,
      sym_block_comment,
  [657069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11612), 1,
      sym__arrow_then_type,
    ACTIONS(20231), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16152), 2,
      sym_comment,
      sym_block_comment,
  [657087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11493), 1,
      sym__arrow_then_type,
    ACTIONS(20233), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16153), 2,
      sym_comment,
      sym_block_comment,
  [657105] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11902), 1,
      sym__arrow_then_type,
    ACTIONS(20235), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16154), 2,
      sym_comment,
      sym_block_comment,
  [657123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13380), 1,
      sym__arrow_then_type,
    ACTIONS(20237), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16155), 2,
      sym_comment,
      sym_block_comment,
  [657141] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12478), 1,
      sym__indent,
    STATE(10035), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16156), 2,
      sym_comment,
      sym_block_comment,
  [657159] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20239), 1,
      anon_sym_COMMA,
    ACTIONS(20241), 1,
      anon_sym_RPAREN,
    STATE(15416), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16157), 2,
      sym_comment,
      sym_block_comment,
  [657179] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16216), 1,
      anon_sym_LBRACK,
    STATE(10083), 1,
      sym_type_arguments,
    STATE(16158), 2,
      sym_comment,
      sym_block_comment,
  [657199] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20243), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16159), 2,
      sym_comment,
      sym_block_comment,
  [657219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20245), 1,
      anon_sym_COMMA,
    ACTIONS(20247), 1,
      anon_sym_RPAREN,
    STATE(16334), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16160), 2,
      sym_comment,
      sym_block_comment,
  [657239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20249), 1,
      sym__interpolated_multiline_string_end,
    STATE(16173), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16161), 2,
      sym_comment,
      sym_block_comment,
  [657259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12459), 1,
      sym__indent,
    STATE(10824), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16162), 2,
      sym_comment,
      sym_block_comment,
  [657277] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20249), 1,
      sym__interpolated_string_end,
    STATE(16175), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16163), 2,
      sym_comment,
      sym_block_comment,
  [657297] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6052), 1,
      anon_sym_RBRACK,
    ACTIONS(20251), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16164), 2,
      sym_comment,
      sym_block_comment,
  [657317] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20253), 1,
      anon_sym_COMMA,
    ACTIONS(20255), 1,
      anon_sym_RPAREN,
    STATE(16291), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16165), 2,
      sym_comment,
      sym_block_comment,
  [657337] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5910), 1,
      anon_sym_RPAREN,
    ACTIONS(20257), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16166), 2,
      sym_comment,
      sym_block_comment,
  [657357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11734), 1,
      sym__arrow_then_type,
    ACTIONS(20259), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16167), 2,
      sym_comment,
      sym_block_comment,
  [657375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20261), 1,
      anon_sym_COMMA,
    ACTIONS(20263), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16168), 2,
      sym_comment,
      sym_block_comment,
  [657395] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20265), 1,
      anon_sym_COMMA,
    ACTIONS(20267), 1,
      anon_sym_RBRACK,
    STATE(16164), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16169), 2,
      sym_comment,
      sym_block_comment,
  [657415] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20269), 1,
      anon_sym_COMMA,
    ACTIONS(20271), 1,
      anon_sym_RBRACK,
    STATE(16181), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16170), 2,
      sym_comment,
      sym_block_comment,
  [657435] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20273), 1,
      anon_sym_COMMA,
    ACTIONS(20275), 1,
      anon_sym_RBRACK,
    STATE(16182), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16171), 2,
      sym_comment,
      sym_block_comment,
  [657455] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20277), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16172), 2,
      sym_comment,
      sym_block_comment,
  [657475] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20279), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16173), 2,
      sym_comment,
      sym_block_comment,
  [657495] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20281), 1,
      anon_sym_COMMA,
    ACTIONS(20283), 1,
      anon_sym_RPAREN,
    STATE(15222), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16174), 2,
      sym_comment,
      sym_block_comment,
  [657515] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20279), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16175), 2,
      sym_comment,
      sym_block_comment,
  [657535] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20285), 1,
      sym__interpolated_string_end,
    STATE(16127), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16176), 2,
      sym_comment,
      sym_block_comment,
  [657555] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(14948), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16177), 2,
      sym_comment,
      sym_block_comment,
  [657575] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20285), 1,
      sym__interpolated_multiline_string_end,
    STATE(16128), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16178), 2,
      sym_comment,
      sym_block_comment,
  [657595] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5602), 1,
      anon_sym_RPAREN,
    ACTIONS(20287), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16179), 2,
      sym_comment,
      sym_block_comment,
  [657615] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5494), 1,
      anon_sym_RPAREN,
    ACTIONS(20289), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16180), 2,
      sym_comment,
      sym_block_comment,
  [657635] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6010), 1,
      anon_sym_RBRACK,
    ACTIONS(20291), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16181), 2,
      sym_comment,
      sym_block_comment,
  [657655] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5840), 1,
      anon_sym_RBRACK,
    ACTIONS(20293), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16182), 2,
      sym_comment,
      sym_block_comment,
  [657675] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4504), 1,
      sym__indent,
    STATE(8448), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16183), 2,
      sym_comment,
      sym_block_comment,
  [657693] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(14903), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16184), 2,
      sym_comment,
      sym_block_comment,
  [657713] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12455), 1,
      sym__indent,
    STATE(8664), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16185), 2,
      sym_comment,
      sym_block_comment,
  [657731] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(20295), 1,
      anon_sym_LBRACK,
    STATE(10986), 1,
      sym_type_arguments,
    STATE(16186), 2,
      sym_comment,
      sym_block_comment,
  [657751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12474), 1,
      sym__indent,
    STATE(10981), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16187), 2,
      sym_comment,
      sym_block_comment,
  [657769] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5298), 1,
      anon_sym_RBRACK,
    ACTIONS(20297), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16188), 2,
      sym_comment,
      sym_block_comment,
  [657789] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12427), 1,
      sym__indent,
    STATE(10038), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16189), 2,
      sym_comment,
      sym_block_comment,
  [657807] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11493), 1,
      sym__arrow_then_type,
    ACTIONS(20299), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16190), 2,
      sym_comment,
      sym_block_comment,
  [657825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11902), 1,
      sym__arrow_then_type,
    ACTIONS(20301), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16191), 2,
      sym_comment,
      sym_block_comment,
  [657843] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20303), 1,
      sym__interpolated_multiline_string_end,
    STATE(16201), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16192), 2,
      sym_comment,
      sym_block_comment,
  [657863] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20303), 1,
      sym__interpolated_string_end,
    STATE(16202), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16193), 2,
      sym_comment,
      sym_block_comment,
  [657883] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20305), 1,
      anon_sym_COMMA,
    ACTIONS(20307), 1,
      anon_sym_RPAREN,
    STATE(16346), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16194), 2,
      sym_comment,
      sym_block_comment,
  [657903] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11231), 1,
      sym__arrow_then_type,
    ACTIONS(20309), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16195), 2,
      sym_comment,
      sym_block_comment,
  [657921] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5680), 1,
      anon_sym_RPAREN,
    ACTIONS(20311), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16196), 2,
      sym_comment,
      sym_block_comment,
  [657941] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5982), 1,
      anon_sym_RPAREN,
    ACTIONS(20313), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16197), 2,
      sym_comment,
      sym_block_comment,
  [657961] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20315), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16198), 2,
      sym_comment,
      sym_block_comment,
  [657981] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20317), 1,
      anon_sym_COMMA,
    ACTIONS(20319), 1,
      anon_sym_RBRACK,
    STATE(15192), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16199), 2,
      sym_comment,
      sym_block_comment,
  [658001] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20321), 1,
      anon_sym_COMMA,
    ACTIONS(20323), 1,
      anon_sym_RBRACK,
    STATE(16211), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16200), 2,
      sym_comment,
      sym_block_comment,
  [658021] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20325), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16201), 2,
      sym_comment,
      sym_block_comment,
  [658041] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20325), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16202), 2,
      sym_comment,
      sym_block_comment,
  [658061] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20327), 1,
      anon_sym_COMMA,
    ACTIONS(20329), 1,
      anon_sym_RPAREN,
    STATE(15276), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16203), 2,
      sym_comment,
      sym_block_comment,
  [658081] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20331), 1,
      anon_sym_COMMA,
    ACTIONS(20333), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16204), 2,
      sym_comment,
      sym_block_comment,
  [658101] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20315), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16205), 2,
      sym_comment,
      sym_block_comment,
  [658121] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20335), 1,
      anon_sym_COMMA,
    ACTIONS(20337), 1,
      anon_sym_RBRACK,
    STATE(16188), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16206), 2,
      sym_comment,
      sym_block_comment,
  [658141] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20339), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16207), 2,
      sym_comment,
      sym_block_comment,
  [658161] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5516), 1,
      anon_sym_RPAREN,
    ACTIONS(20341), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16208), 2,
      sym_comment,
      sym_block_comment,
  [658181] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(14908), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16209), 2,
      sym_comment,
      sym_block_comment,
  [658201] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20343), 1,
      anon_sym_COMMA,
    ACTIONS(20345), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16210), 2,
      sym_comment,
      sym_block_comment,
  [658221] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5964), 1,
      anon_sym_RBRACK,
    ACTIONS(20347), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16211), 2,
      sym_comment,
      sym_block_comment,
  [658241] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(15017), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16212), 2,
      sym_comment,
      sym_block_comment,
  [658261] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4864), 1,
      sym__indent,
    STATE(8187), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16213), 2,
      sym_comment,
      sym_block_comment,
  [658279] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12409), 1,
      sym__indent,
    STATE(11168), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16214), 2,
      sym_comment,
      sym_block_comment,
  [658297] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20349), 1,
      anon_sym_COMMA,
    ACTIONS(20351), 1,
      anon_sym_RPAREN,
    STATE(15857), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16215), 2,
      sym_comment,
      sym_block_comment,
  [658317] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5766), 1,
      anon_sym_RBRACK,
    ACTIONS(20353), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16216), 2,
      sym_comment,
      sym_block_comment,
  [658337] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14076), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(7193), 1,
      sym_type_arguments,
    STATE(16217), 2,
      sym_comment,
      sym_block_comment,
  [658357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11074), 1,
      sym__arrow_then_type,
    ACTIONS(20355), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16218), 2,
      sym_comment,
      sym_block_comment,
  [658375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(14970), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16219), 2,
      sym_comment,
      sym_block_comment,
  [658395] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20357), 1,
      anon_sym_COMMA,
    ACTIONS(20359), 1,
      anon_sym_RPAREN,
    STATE(16078), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16220), 2,
      sym_comment,
      sym_block_comment,
  [658415] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20361), 1,
      sym__interpolated_multiline_string_end,
    STATE(16232), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16221), 2,
      sym_comment,
      sym_block_comment,
  [658435] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20361), 1,
      sym__interpolated_string_end,
    STATE(16233), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16222), 2,
      sym_comment,
      sym_block_comment,
  [658455] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5990), 1,
      anon_sym_RPAREN,
    ACTIONS(20363), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16223), 2,
      sym_comment,
      sym_block_comment,
  [658475] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20365), 1,
      anon_sym_COMMA,
    ACTIONS(20367), 1,
      anon_sym_RPAREN,
    STATE(16329), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16224), 2,
      sym_comment,
      sym_block_comment,
  [658495] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11493), 1,
      sym__arrow_then_type,
    ACTIONS(20369), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16225), 2,
      sym_comment,
      sym_block_comment,
  [658513] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11902), 1,
      sym__arrow_then_type,
    ACTIONS(20371), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16226), 2,
      sym_comment,
      sym_block_comment,
  [658531] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11493), 1,
      sym__arrow_then_type,
    ACTIONS(20373), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16227), 2,
      sym_comment,
      sym_block_comment,
  [658549] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20375), 1,
      anon_sym_COMMA,
    ACTIONS(20377), 1,
      anon_sym_RBRACK,
    STATE(16216), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16228), 2,
      sym_comment,
      sym_block_comment,
  [658569] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20379), 1,
      anon_sym_COMMA,
    ACTIONS(20381), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16229), 2,
      sym_comment,
      sym_block_comment,
  [658589] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20383), 1,
      sym__interpolated_string_end,
    STATE(16198), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16230), 2,
      sym_comment,
      sym_block_comment,
  [658609] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20385), 1,
      anon_sym_COMMA,
    ACTIONS(20387), 1,
      anon_sym_RBRACK,
    STATE(16240), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16231), 2,
      sym_comment,
      sym_block_comment,
  [658629] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20389), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16232), 2,
      sym_comment,
      sym_block_comment,
  [658649] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20389), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16233), 2,
      sym_comment,
      sym_block_comment,
  [658669] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(14933), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16234), 2,
      sym_comment,
      sym_block_comment,
  [658689] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5418), 1,
      anon_sym_RPAREN,
    ACTIONS(20391), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16235), 2,
      sym_comment,
      sym_block_comment,
  [658709] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20383), 1,
      sym__interpolated_multiline_string_end,
    STATE(16205), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16236), 2,
      sym_comment,
      sym_block_comment,
  [658729] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20393), 1,
      anon_sym_COMMA,
    ACTIONS(20395), 1,
      anon_sym_RBRACK,
    STATE(16249), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16237), 2,
      sym_comment,
      sym_block_comment,
  [658749] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20397), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16238), 2,
      sym_comment,
      sym_block_comment,
  [658769] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5370), 1,
      anon_sym_RPAREN,
    ACTIONS(20399), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16239), 2,
      sym_comment,
      sym_block_comment,
  [658789] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6092), 1,
      anon_sym_RBRACK,
    ACTIONS(20401), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16240), 2,
      sym_comment,
      sym_block_comment,
  [658809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4740), 1,
      sym__indent,
    STATE(9798), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16241), 2,
      sym_comment,
      sym_block_comment,
  [658827] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20403), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16242), 2,
      sym_comment,
      sym_block_comment,
  [658847] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4496), 1,
      sym__indent,
    STATE(6664), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16243), 2,
      sym_comment,
      sym_block_comment,
  [658865] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15513), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(8708), 1,
      sym_type_arguments,
    STATE(16244), 2,
      sym_comment,
      sym_block_comment,
  [658885] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5628), 1,
      anon_sym_RBRACK,
    ACTIONS(20405), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16245), 2,
      sym_comment,
      sym_block_comment,
  [658905] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15685), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9156), 1,
      sym_type_arguments,
    STATE(16246), 2,
      sym_comment,
      sym_block_comment,
  [658925] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(15130), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16247), 2,
      sym_comment,
      sym_block_comment,
  [658945] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6116), 1,
      anon_sym_RPAREN,
    ACTIONS(20407), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16248), 2,
      sym_comment,
      sym_block_comment,
  [658965] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6074), 1,
      anon_sym_RBRACK,
    ACTIONS(20409), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16249), 2,
      sym_comment,
      sym_block_comment,
  [658985] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20411), 1,
      sym__interpolated_multiline_string_end,
    STATE(16259), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16250), 2,
      sym_comment,
      sym_block_comment,
  [659005] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20411), 1,
      sym__interpolated_string_end,
    STATE(16261), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16251), 2,
      sym_comment,
      sym_block_comment,
  [659025] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20413), 1,
      anon_sym_COMMA,
    ACTIONS(20415), 1,
      anon_sym_RBRACK,
    STATE(16245), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16252), 2,
      sym_comment,
      sym_block_comment,
  [659045] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20417), 1,
      anon_sym_COMMA,
    ACTIONS(20419), 1,
      anon_sym_RPAREN,
    STATE(16267), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16253), 2,
      sym_comment,
      sym_block_comment,
  [659065] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15060), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16254), 2,
      sym_comment,
      sym_block_comment,
  [659085] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(10916), 1,
      sym__arrow_then_type,
    ACTIONS(20421), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16255), 2,
      sym_comment,
      sym_block_comment,
  [659103] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20423), 1,
      anon_sym_COMMA,
    ACTIONS(20425), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16256), 2,
      sym_comment,
      sym_block_comment,
  [659123] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12470), 1,
      sym__indent,
    STATE(9644), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16257), 2,
      sym_comment,
      sym_block_comment,
  [659141] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20427), 1,
      anon_sym_COMMA,
    ACTIONS(20429), 1,
      anon_sym_RBRACK,
    STATE(16265), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16258), 2,
      sym_comment,
      sym_block_comment,
  [659161] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20431), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16259), 2,
      sym_comment,
      sym_block_comment,
  [659181] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(11493), 1,
      sym__arrow_then_type,
    ACTIONS(20433), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16260), 2,
      sym_comment,
      sym_block_comment,
  [659199] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20431), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16261), 2,
      sym_comment,
      sym_block_comment,
  [659219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20435), 1,
      anon_sym_COMMA,
    ACTIONS(20437), 1,
      anon_sym_RPAREN,
    STATE(15662), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16262), 2,
      sym_comment,
      sym_block_comment,
  [659239] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5702), 1,
      anon_sym_RPAREN,
    ACTIONS(20439), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16263), 2,
      sym_comment,
      sym_block_comment,
  [659259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4460), 1,
      sym__indent,
    STATE(8859), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16264), 2,
      sym_comment,
      sym_block_comment,
  [659277] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6130), 1,
      anon_sym_RBRACK,
    ACTIONS(20441), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16265), 2,
      sym_comment,
      sym_block_comment,
  [659297] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5220), 1,
      anon_sym_RBRACK,
    ACTIONS(20443), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16266), 2,
      sym_comment,
      sym_block_comment,
  [659317] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6152), 1,
      anon_sym_RPAREN,
    ACTIONS(20445), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16267), 2,
      sym_comment,
      sym_block_comment,
  [659337] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4306), 1,
      sym__indent,
    STATE(10244), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16268), 2,
      sym_comment,
      sym_block_comment,
  [659355] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20447), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16269), 2,
      sym_comment,
      sym_block_comment,
  [659375] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20447), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16270), 2,
      sym_comment,
      sym_block_comment,
  [659395] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15579), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(8844), 1,
      sym_type_arguments,
    STATE(16271), 2,
      sym_comment,
      sym_block_comment,
  [659415] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4450), 1,
      sym__indent,
    STATE(9986), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16272), 2,
      sym_comment,
      sym_block_comment,
  [659433] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20449), 1,
      anon_sym_COMMA,
    ACTIONS(20451), 1,
      anon_sym_RPAREN,
    STATE(15843), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16273), 2,
      sym_comment,
      sym_block_comment,
  [659453] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5496), 1,
      anon_sym_RBRACK,
    ACTIONS(20453), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16274), 2,
      sym_comment,
      sym_block_comment,
  [659473] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20455), 1,
      anon_sym_COMMA,
    ACTIONS(20457), 1,
      anon_sym_RBRACK,
    STATE(16266), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16275), 2,
      sym_comment,
      sym_block_comment,
  [659493] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20459), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16276), 2,
      sym_comment,
      sym_block_comment,
  [659513] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5770), 1,
      anon_sym_RPAREN,
    ACTIONS(20461), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16277), 2,
      sym_comment,
      sym_block_comment,
  [659533] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20463), 1,
      sym__interpolated_multiline_string_end,
    STATE(16330), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16278), 2,
      sym_comment,
      sym_block_comment,
  [659553] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20463), 1,
      sym__interpolated_string_end,
    STATE(16290), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16279), 2,
      sym_comment,
      sym_block_comment,
  [659573] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20465), 1,
      anon_sym_COMMA,
    ACTIONS(20467), 1,
      anon_sym_RBRACK,
    STATE(16274), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16280), 2,
      sym_comment,
      sym_block_comment,
  [659593] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(15188), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16281), 2,
      sym_comment,
      sym_block_comment,
  [659613] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20469), 1,
      anon_sym_COMMA,
    ACTIONS(20471), 1,
      anon_sym_RPAREN,
    STATE(16197), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16282), 2,
      sym_comment,
      sym_block_comment,
  [659633] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(18013), 1,
      sym__arrow_then_type,
    ACTIONS(20473), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16283), 2,
      sym_comment,
      sym_block_comment,
  [659651] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20475), 1,
      anon_sym_COMMA,
    ACTIONS(20477), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16284), 2,
      sym_comment,
      sym_block_comment,
  [659671] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20479), 1,
      anon_sym_COMMA,
    ACTIONS(20481), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16285), 2,
      sym_comment,
      sym_block_comment,
  [659691] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20483), 1,
      anon_sym_COMMA,
    ACTIONS(20485), 1,
      anon_sym_RPAREN,
    STATE(15754), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16286), 2,
      sym_comment,
      sym_block_comment,
  [659711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13543), 1,
      sym__arrow_then_type,
    ACTIONS(20487), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16287), 2,
      sym_comment,
      sym_block_comment,
  [659729] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15175), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16288), 2,
      sym_comment,
      sym_block_comment,
  [659749] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20489), 1,
      anon_sym_COMMA,
    ACTIONS(20491), 1,
      anon_sym_RBRACK,
    STATE(16295), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16289), 2,
      sym_comment,
      sym_block_comment,
  [659769] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20493), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16290), 2,
      sym_comment,
      sym_block_comment,
  [659789] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5828), 1,
      anon_sym_RPAREN,
    ACTIONS(20495), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16291), 2,
      sym_comment,
      sym_block_comment,
  [659809] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20497), 1,
      anon_sym_COMMA,
    ACTIONS(20499), 1,
      anon_sym_RPAREN,
    STATE(15783), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16292), 2,
      sym_comment,
      sym_block_comment,
  [659829] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(14874), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16293), 2,
      sym_comment,
      sym_block_comment,
  [659849] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20501), 1,
      sym__interpolated_string_end,
    STATE(16269), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16294), 2,
      sym_comment,
      sym_block_comment,
  [659869] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5962), 1,
      anon_sym_RBRACK,
    ACTIONS(20503), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16295), 2,
      sym_comment,
      sym_block_comment,
  [659889] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12373), 1,
      sym__indent,
    STATE(10996), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16296), 2,
      sym_comment,
      sym_block_comment,
  [659907] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20501), 1,
      sym__interpolated_multiline_string_end,
    STATE(16270), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16297), 2,
      sym_comment,
      sym_block_comment,
  [659927] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20505), 1,
      anon_sym_COMMA,
    ACTIONS(20507), 1,
      anon_sym_RBRACK,
    STATE(16316), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16298), 2,
      sym_comment,
      sym_block_comment,
  [659947] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15717), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(9004), 1,
      sym_type_arguments,
    STATE(16299), 2,
      sym_comment,
      sym_block_comment,
  [659967] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14510), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(7044), 1,
      sym_type_arguments,
    STATE(16300), 2,
      sym_comment,
      sym_block_comment,
  [659987] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4456), 1,
      sym__indent,
    STATE(9586), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16301), 2,
      sym_comment,
      sym_block_comment,
  [660005] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(15180), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16302), 2,
      sym_comment,
      sym_block_comment,
  [660025] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5364), 1,
      anon_sym_RBRACK,
    ACTIONS(20509), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16303), 2,
      sym_comment,
      sym_block_comment,
  [660045] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20511), 1,
      sym__interpolated_multiline_string_end,
    STATE(16317), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16304), 2,
      sym_comment,
      sym_block_comment,
  [660065] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5426), 1,
      anon_sym_RPAREN,
    ACTIONS(20513), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16305), 2,
      sym_comment,
      sym_block_comment,
  [660085] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20511), 1,
      sym__interpolated_string_end,
    STATE(16319), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16306), 2,
      sym_comment,
      sym_block_comment,
  [660105] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20515), 1,
      anon_sym_COMMA,
    ACTIONS(20517), 1,
      anon_sym_RPAREN,
    STATE(16044), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16307), 2,
      sym_comment,
      sym_block_comment,
  [660125] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20519), 1,
      anon_sym_COMMA,
    ACTIONS(20521), 1,
      anon_sym_RBRACK,
    STATE(16303), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16308), 2,
      sym_comment,
      sym_block_comment,
  [660145] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20523), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16309), 2,
      sym_comment,
      sym_block_comment,
  [660165] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13566), 1,
      sym__arrow_then_type,
    ACTIONS(20525), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16310), 2,
      sym_comment,
      sym_block_comment,
  [660183] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20527), 1,
      anon_sym_COMMA,
    ACTIONS(20529), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16311), 2,
      sym_comment,
      sym_block_comment,
  [660203] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5294), 1,
      anon_sym_RPAREN,
    ACTIONS(20531), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16312), 2,
      sym_comment,
      sym_block_comment,
  [660223] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20533), 1,
      anon_sym_COMMA,
    ACTIONS(20535), 1,
      anon_sym_RPAREN,
    STATE(15602), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16313), 2,
      sym_comment,
      sym_block_comment,
  [660243] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(14867), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16314), 2,
      sym_comment,
      sym_block_comment,
  [660263] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20537), 1,
      anon_sym_COMMA,
    ACTIONS(20539), 1,
      anon_sym_RBRACK,
    STATE(16323), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16315), 2,
      sym_comment,
      sym_block_comment,
  [660283] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5788), 1,
      anon_sym_RBRACK,
    ACTIONS(20541), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16316), 2,
      sym_comment,
      sym_block_comment,
  [660303] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20543), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16317), 2,
      sym_comment,
      sym_block_comment,
  [660323] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12451), 1,
      sym__indent,
    STATE(10546), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16318), 2,
      sym_comment,
      sym_block_comment,
  [660341] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20543), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16319), 2,
      sym_comment,
      sym_block_comment,
  [660361] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5296), 1,
      anon_sym_RPAREN,
    ACTIONS(20545), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16320), 2,
      sym_comment,
      sym_block_comment,
  [660381] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15163), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16321), 2,
      sym_comment,
      sym_block_comment,
  [660401] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20547), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16322), 2,
      sym_comment,
      sym_block_comment,
  [660421] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5820), 1,
      anon_sym_RBRACK,
    ACTIONS(20549), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16323), 2,
      sym_comment,
      sym_block_comment,
  [660441] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4528), 1,
      sym__indent,
    STATE(6916), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16324), 2,
      sym_comment,
      sym_block_comment,
  [660459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12417), 1,
      sym__indent,
    STATE(9797), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16325), 2,
      sym_comment,
      sym_block_comment,
  [660477] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16097), 1,
      anon_sym_match,
    ACTIONS(16244), 1,
      anon_sym_LBRACK,
    STATE(10186), 1,
      sym_type_arguments,
    STATE(16326), 2,
      sym_comment,
      sym_block_comment,
  [660497] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5368), 1,
      anon_sym_RBRACK,
    ACTIONS(20551), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16327), 2,
      sym_comment,
      sym_block_comment,
  [660517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12390), 1,
      sym__indent,
    STATE(10729), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16328), 2,
      sym_comment,
      sym_block_comment,
  [660535] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(6078), 1,
      anon_sym_RPAREN,
    ACTIONS(20553), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16329), 2,
      sym_comment,
      sym_block_comment,
  [660555] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20493), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16330), 2,
      sym_comment,
      sym_block_comment,
  [660575] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20555), 1,
      sym__interpolated_string_end,
    STATE(16343), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16331), 2,
      sym_comment,
      sym_block_comment,
  [660595] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5248), 1,
      anon_sym_RBRACK,
    ACTIONS(20557), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16332), 2,
      sym_comment,
      sym_block_comment,
  [660615] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20559), 1,
      anon_sym_COMMA,
    ACTIONS(20561), 1,
      anon_sym_RPAREN,
    STATE(15954), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16333), 2,
      sym_comment,
      sym_block_comment,
  [660635] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5490), 1,
      anon_sym_RPAREN,
    ACTIONS(20563), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16334), 2,
      sym_comment,
      sym_block_comment,
  [660655] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13380), 1,
      sym__arrow_then_type,
    ACTIONS(20565), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16335), 2,
      sym_comment,
      sym_block_comment,
  [660673] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20567), 1,
      anon_sym_COMMA,
    ACTIONS(20569), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16336), 2,
      sym_comment,
      sym_block_comment,
  [660693] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20571), 1,
      anon_sym_COMMA,
    ACTIONS(20573), 1,
      anon_sym_RBRACK,
    STATE(16332), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16337), 2,
      sym_comment,
      sym_block_comment,
  [660713] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20575), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16338), 2,
      sym_comment,
      sym_block_comment,
  [660733] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20577), 1,
      anon_sym_COMMA,
    ACTIONS(20579), 1,
      anon_sym_RBRACK,
    STATE(16350), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16339), 2,
      sym_comment,
      sym_block_comment,
  [660753] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20581), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16340), 2,
      sym_comment,
      sym_block_comment,
  [660773] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20583), 1,
      anon_sym_COMMA,
    ACTIONS(20585), 1,
      anon_sym_RPAREN,
    STATE(15663), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16341), 2,
      sym_comment,
      sym_block_comment,
  [660793] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20587), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16342), 2,
      sym_comment,
      sym_block_comment,
  [660813] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20581), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16343), 2,
      sym_comment,
      sym_block_comment,
  [660833] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20589), 1,
      anon_sym_COMMA,
    ACTIONS(20591), 1,
      anon_sym_RPAREN,
    STATE(15831), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16344), 2,
      sym_comment,
      sym_block_comment,
  [660853] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20575), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16345), 2,
      sym_comment,
      sym_block_comment,
  [660873] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5942), 1,
      anon_sym_RPAREN,
    ACTIONS(20593), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16346), 2,
      sym_comment,
      sym_block_comment,
  [660893] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(14946), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16347), 2,
      sym_comment,
      sym_block_comment,
  [660913] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20595), 1,
      anon_sym_COMMA,
    ACTIONS(20597), 1,
      anon_sym_RBRACK,
    STATE(16327), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16348), 2,
      sym_comment,
      sym_block_comment,
  [660933] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20599), 1,
      anon_sym_COMMA,
    ACTIONS(20601), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16349), 2,
      sym_comment,
      sym_block_comment,
  [660953] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5664), 1,
      anon_sym_RBRACK,
    ACTIONS(20603), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16350), 2,
      sym_comment,
      sym_block_comment,
  [660973] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12421), 1,
      sym__indent,
    STATE(9229), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16351), 2,
      sym_comment,
      sym_block_comment,
  [660991] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4338), 1,
      sym__indent,
    STATE(7725), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16352), 2,
      sym_comment,
      sym_block_comment,
  [661009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(13643), 1,
      sym__arrow_then_type,
    ACTIONS(20605), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16353), 2,
      sym_comment,
      sym_block_comment,
  [661027] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(15073), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16354), 2,
      sym_comment,
      sym_block_comment,
  [661047] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13172), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(5650), 1,
      sym_type_arguments,
    STATE(16355), 2,
      sym_comment,
      sym_block_comment,
  [661067] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20607), 1,
      anon_sym_COMMA,
    ACTIONS(20609), 1,
      anon_sym_RBRACK,
    STATE(16382), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16356), 2,
      sym_comment,
      sym_block_comment,
  [661087] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20555), 1,
      sym__interpolated_multiline_string_end,
    STATE(16340), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16357), 2,
      sym_comment,
      sym_block_comment,
  [661107] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20611), 1,
      sym__interpolated_multiline_string_end,
    STATE(16369), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16358), 2,
      sym_comment,
      sym_block_comment,
  [661127] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5238), 1,
      anon_sym_RBRACK,
    ACTIONS(20613), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16359), 2,
      sym_comment,
      sym_block_comment,
  [661147] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20611), 1,
      sym__interpolated_string_end,
    STATE(16371), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16360), 2,
      sym_comment,
      sym_block_comment,
  [661167] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5242), 1,
      anon_sym_RPAREN,
    ACTIONS(20615), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16361), 2,
      sym_comment,
      sym_block_comment,
  [661187] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20617), 1,
      anon_sym_COMMA,
    ACTIONS(20619), 1,
      anon_sym_RPAREN,
    STATE(15856), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16362), 2,
      sym_comment,
      sym_block_comment,
  [661207] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(12414), 1,
      sym__arrow_then_type,
    ACTIONS(20621), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16363), 2,
      sym_comment,
      sym_block_comment,
  [661225] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20623), 1,
      anon_sym_COMMA,
    ACTIONS(20625), 1,
      anon_sym_RPAREN,
    STATE(15721), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16364), 2,
      sym_comment,
      sym_block_comment,
  [661245] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20627), 1,
      anon_sym_COMMA,
    ACTIONS(20629), 1,
      anon_sym_RPAREN,
    STATE(15485), 1,
      aux_sym_tuple_expression_repeat1,
    STATE(16365), 2,
      sym_comment,
      sym_block_comment,
  [661265] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20631), 1,
      anon_sym_COMMA,
    ACTIONS(20633), 1,
      anon_sym_RBRACK,
    STATE(16359), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16366), 2,
      sym_comment,
      sym_block_comment,
  [661285] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20635), 1,
      sym__interpolated_string_end,
    STATE(16338), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16367), 2,
      sym_comment,
      sym_block_comment,
  [661305] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20637), 1,
      anon_sym_COMMA,
    ACTIONS(20639), 1,
      anon_sym_RBRACK,
    STATE(16378), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16368), 2,
      sym_comment,
      sym_block_comment,
  [661325] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20641), 1,
      sym__interpolated_multiline_string_end,
    STATE(15467), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16369), 2,
      sym_comment,
      sym_block_comment,
  [661345] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20643), 1,
      anon_sym_COMMA,
    ACTIONS(20645), 1,
      anon_sym_RPAREN,
    STATE(15811), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16370), 2,
      sym_comment,
      sym_block_comment,
  [661365] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17875), 1,
      sym__interpolated_string_middle,
    ACTIONS(20641), 1,
      sym__interpolated_string_end,
    STATE(15474), 1,
      aux_sym_interpolated_string_repeat1,
    STATE(16371), 2,
      sym_comment,
      sym_block_comment,
  [661385] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17809), 1,
      sym__interpolated_multiline_string_middle,
    ACTIONS(20635), 1,
      sym__interpolated_multiline_string_end,
    STATE(16345), 1,
      aux_sym_interpolated_string_repeat2,
    STATE(16372), 2,
      sym_comment,
      sym_block_comment,
  [661405] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17289), 1,
      anon_sym_case,
    STATE(14986), 1,
      aux_sym__indented_type_cases_repeat1,
    STATE(16618), 1,
      sym_type_case_clause,
    STATE(16373), 2,
      sym_comment,
      sym_block_comment,
  [661425] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5416), 1,
      anon_sym_RPAREN,
    ACTIONS(20647), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16374), 2,
      sym_comment,
      sym_block_comment,
  [661445] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16049), 1,
      anon_sym_LBRACK,
    ACTIONS(20649), 1,
      anon_sym_match,
    STATE(9949), 1,
      sym_type_arguments,
    STATE(16375), 2,
      sym_comment,
      sym_block_comment,
  [661465] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14022), 1,
      anon_sym_LBRACK,
    ACTIONS(16097), 1,
      anon_sym_match,
    STATE(6863), 1,
      sym_type_arguments,
    STATE(16376), 2,
      sym_comment,
      sym_block_comment,
  [661485] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5162), 1,
      anon_sym_RPAREN,
    ACTIONS(20651), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16377), 2,
      sym_comment,
      sym_block_comment,
  [661505] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5526), 1,
      anon_sym_RBRACK,
    ACTIONS(20653), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16378), 2,
      sym_comment,
      sym_block_comment,
  [661525] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12369), 1,
      sym__indent,
    STATE(10726), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16379), 2,
      sym_comment,
      sym_block_comment,
  [661543] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17277), 1,
      anon_sym_case,
    STATE(15077), 1,
      aux_sym_indented_cases_repeat1,
    STATE(16612), 1,
      sym_case_clause,
    STATE(16380), 2,
      sym_comment,
      sym_block_comment,
  [661563] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4490), 1,
      sym__indent,
    STATE(8404), 2,
      sym_indented_block,
      sym_indented_cases,
    STATE(16381), 2,
      sym_comment,
      sym_block_comment,
  [661581] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5682), 1,
      anon_sym_RBRACK,
    ACTIONS(20655), 1,
      anon_sym_COMMA,
    STATE(15091), 1,
      aux_sym_tuple_type_repeat1,
    STATE(16382), 2,
      sym_comment,
      sym_block_comment,
  [661601] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20657), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16383), 2,
      sym_comment,
      sym_block_comment,
  [661616] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20659), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16384), 2,
      sym_comment,
      sym_block_comment,
  [661631] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20661), 1,
      sym__indent,
    STATE(13523), 1,
      sym__indented_type_cases,
    STATE(16385), 2,
      sym_comment,
      sym_block_comment,
  [661648] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20663), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16386), 2,
      sym_comment,
      sym_block_comment,
  [661663] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20665), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16387), 2,
      sym_comment,
      sym_block_comment,
  [661678] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20667), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16388), 2,
      sym_comment,
      sym_block_comment,
  [661693] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20669), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16389), 2,
      sym_comment,
      sym_block_comment,
  [661708] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20671), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16390), 2,
      sym_comment,
      sym_block_comment,
  [661723] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20673), 1,
      anon_sym_LPAREN,
    STATE(14066), 1,
      sym_parenthesized_expression,
    STATE(16391), 2,
      sym_comment,
      sym_block_comment,
  [661740] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20675), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16392), 2,
      sym_comment,
      sym_block_comment,
  [661755] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20677), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16393), 2,
      sym_comment,
      sym_block_comment,
  [661770] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20679), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16394), 2,
      sym_comment,
      sym_block_comment,
  [661785] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20681), 1,
      sym__indent,
    STATE(13614), 1,
      sym__indented_type_cases,
    STATE(16395), 2,
      sym_comment,
      sym_block_comment,
  [661802] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20683), 1,
      anon_sym_LPAREN,
    STATE(12337), 1,
      sym_parenthesized_expression,
    STATE(16396), 2,
      sym_comment,
      sym_block_comment,
  [661819] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20685), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16397), 2,
      sym_comment,
      sym_block_comment,
  [661834] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20687), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16398), 2,
      sym_comment,
      sym_block_comment,
  [661849] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20689), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16399), 2,
      sym_comment,
      sym_block_comment,
  [661864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20691), 1,
      anon_sym_LPAREN,
    STATE(13702), 1,
      sym_parenthesized_expression,
    STATE(16400), 2,
      sym_comment,
      sym_block_comment,
  [661881] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20693), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16401), 2,
      sym_comment,
      sym_block_comment,
  [661896] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20695), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16402), 2,
      sym_comment,
      sym_block_comment,
  [661911] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20697), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16403), 2,
      sym_comment,
      sym_block_comment,
  [661926] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20699), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16404), 2,
      sym_comment,
      sym_block_comment,
  [661941] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20701), 1,
      sym__indent,
    STATE(11132), 1,
      sym__indented_type_cases,
    STATE(16405), 2,
      sym_comment,
      sym_block_comment,
  [661958] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20703), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16406), 2,
      sym_comment,
      sym_block_comment,
  [661973] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20705), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16407), 2,
      sym_comment,
      sym_block_comment,
  [661988] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20707), 1,
      sym__indent,
    STATE(12313), 1,
      sym__indented_type_cases,
    STATE(16408), 2,
      sym_comment,
      sym_block_comment,
  [662005] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20709), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16409), 2,
      sym_comment,
      sym_block_comment,
  [662020] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20711), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16410), 2,
      sym_comment,
      sym_block_comment,
  [662035] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20713), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16411), 2,
      sym_comment,
      sym_block_comment,
  [662050] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20715), 1,
      anon_sym_LPAREN,
    STATE(14105), 1,
      sym_parenthesized_expression,
    STATE(16412), 2,
      sym_comment,
      sym_block_comment,
  [662067] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20717), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16413), 2,
      sym_comment,
      sym_block_comment,
  [662082] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20719), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16414), 2,
      sym_comment,
      sym_block_comment,
  [662097] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20721), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16415), 2,
      sym_comment,
      sym_block_comment,
  [662112] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20723), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16416), 2,
      sym_comment,
      sym_block_comment,
  [662127] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20725), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16417), 2,
      sym_comment,
      sym_block_comment,
  [662142] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20727), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16418), 2,
      sym_comment,
      sym_block_comment,
  [662157] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20729), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16419), 2,
      sym_comment,
      sym_block_comment,
  [662172] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20731), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16420), 2,
      sym_comment,
      sym_block_comment,
  [662187] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20733), 1,
      sym__indent,
    STATE(13397), 1,
      sym__indented_type_cases,
    STATE(16421), 2,
      sym_comment,
      sym_block_comment,
  [662204] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20735), 1,
      anon_sym_LPAREN,
    STATE(14203), 1,
      sym_parenthesized_expression,
    STATE(16422), 2,
      sym_comment,
      sym_block_comment,
  [662221] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20737), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16423), 2,
      sym_comment,
      sym_block_comment,
  [662236] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20739), 1,
      anon_sym_LPAREN,
    STATE(13434), 1,
      sym_parenthesized_expression,
    STATE(16424), 2,
      sym_comment,
      sym_block_comment,
  [662253] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20741), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16425), 2,
      sym_comment,
      sym_block_comment,
  [662268] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20743), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16426), 2,
      sym_comment,
      sym_block_comment,
  [662283] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20745), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16427), 2,
      sym_comment,
      sym_block_comment,
  [662298] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20747), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16428), 2,
      sym_comment,
      sym_block_comment,
  [662313] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20749), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16429), 2,
      sym_comment,
      sym_block_comment,
  [662328] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20751), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16430), 2,
      sym_comment,
      sym_block_comment,
  [662343] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20753), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16431), 2,
      sym_comment,
      sym_block_comment,
  [662358] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20755), 1,
      sym__indent,
    STATE(11687), 1,
      sym__indented_type_cases,
    STATE(16432), 2,
      sym_comment,
      sym_block_comment,
  [662375] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20757), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16433), 2,
      sym_comment,
      sym_block_comment,
  [662390] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20759), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16434), 2,
      sym_comment,
      sym_block_comment,
  [662405] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20761), 1,
      sym__indent,
    STATE(13618), 1,
      sym__indented_type_cases,
    STATE(16435), 2,
      sym_comment,
      sym_block_comment,
  [662422] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20763), 1,
      anon_sym_LPAREN,
    STATE(13129), 1,
      sym_parenthesized_expression,
    STATE(16436), 2,
      sym_comment,
      sym_block_comment,
  [662439] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20765), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16437), 2,
      sym_comment,
      sym_block_comment,
  [662454] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20767), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16438), 2,
      sym_comment,
      sym_block_comment,
  [662469] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20769), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16439), 2,
      sym_comment,
      sym_block_comment,
  [662484] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20771), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16440), 2,
      sym_comment,
      sym_block_comment,
  [662499] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20773), 1,
      sym__indent,
    STATE(18010), 1,
      sym__indented_type_cases,
    STATE(16441), 2,
      sym_comment,
      sym_block_comment,
  [662516] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20775), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16442), 2,
      sym_comment,
      sym_block_comment,
  [662531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20777), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16443), 2,
      sym_comment,
      sym_block_comment,
  [662546] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20779), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16444), 2,
      sym_comment,
      sym_block_comment,
  [662561] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20781), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16445), 2,
      sym_comment,
      sym_block_comment,
  [662576] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20783), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16446), 2,
      sym_comment,
      sym_block_comment,
  [662591] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20785), 1,
      anon_sym_LPAREN,
    STATE(12940), 1,
      sym_parenthesized_expression,
    STATE(16447), 2,
      sym_comment,
      sym_block_comment,
  [662608] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20787), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16448), 2,
      sym_comment,
      sym_block_comment,
  [662623] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20789), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16449), 2,
      sym_comment,
      sym_block_comment,
  [662638] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20791), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16450), 2,
      sym_comment,
      sym_block_comment,
  [662653] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20793), 1,
      sym__indent,
    STATE(10963), 1,
      sym__indented_type_cases,
    STATE(16451), 2,
      sym_comment,
      sym_block_comment,
  [662670] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20795), 1,
      anon_sym_LPAREN,
    STATE(13925), 1,
      sym_parenthesized_expression,
    STATE(16452), 2,
      sym_comment,
      sym_block_comment,
  [662687] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20797), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16453), 2,
      sym_comment,
      sym_block_comment,
  [662702] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20799), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16454), 2,
      sym_comment,
      sym_block_comment,
  [662717] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20801), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16455), 2,
      sym_comment,
      sym_block_comment,
  [662732] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20803), 1,
      anon_sym_LPAREN,
    STATE(11895), 1,
      sym_parenthesized_expression,
    STATE(16456), 2,
      sym_comment,
      sym_block_comment,
  [662749] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20805), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16457), 2,
      sym_comment,
      sym_block_comment,
  [662764] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20807), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16458), 2,
      sym_comment,
      sym_block_comment,
  [662779] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20809), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16459), 2,
      sym_comment,
      sym_block_comment,
  [662794] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20811), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16460), 2,
      sym_comment,
      sym_block_comment,
  [662809] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20813), 1,
      sym__indent,
    STATE(12356), 1,
      sym__indented_type_cases,
    STATE(16461), 2,
      sym_comment,
      sym_block_comment,
  [662826] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20815), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16462), 2,
      sym_comment,
      sym_block_comment,
  [662841] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20817), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16463), 2,
      sym_comment,
      sym_block_comment,
  [662856] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20819), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16464), 2,
      sym_comment,
      sym_block_comment,
  [662871] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20821), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16465), 2,
      sym_comment,
      sym_block_comment,
  [662886] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20823), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16466), 2,
      sym_comment,
      sym_block_comment,
  [662901] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20825), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16467), 2,
      sym_comment,
      sym_block_comment,
  [662916] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20827), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16468), 2,
      sym_comment,
      sym_block_comment,
  [662931] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20829), 1,
      sym__indent,
    STATE(11207), 1,
      sym__indented_type_cases,
    STATE(16469), 2,
      sym_comment,
      sym_block_comment,
  [662948] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20831), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16470), 2,
      sym_comment,
      sym_block_comment,
  [662963] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20833), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16471), 2,
      sym_comment,
      sym_block_comment,
  [662978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20835), 1,
      anon_sym_LPAREN,
    STATE(13835), 1,
      sym_parenthesized_expression,
    STATE(16472), 2,
      sym_comment,
      sym_block_comment,
  [662995] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20837), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16473), 2,
      sym_comment,
      sym_block_comment,
  [663010] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20839), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16474), 2,
      sym_comment,
      sym_block_comment,
  [663025] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20841), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16475), 2,
      sym_comment,
      sym_block_comment,
  [663040] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20843), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16476), 2,
      sym_comment,
      sym_block_comment,
  [663055] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20845), 1,
      sym__indent,
    STATE(11709), 1,
      sym__indented_type_cases,
    STATE(16477), 2,
      sym_comment,
      sym_block_comment,
  [663072] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20847), 1,
      anon_sym_LPAREN,
    STATE(13922), 1,
      sym_parenthesized_expression,
    STATE(16478), 2,
      sym_comment,
      sym_block_comment,
  [663089] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20849), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16479), 2,
      sym_comment,
      sym_block_comment,
  [663104] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20851), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16480), 2,
      sym_comment,
      sym_block_comment,
  [663119] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20853), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16481), 2,
      sym_comment,
      sym_block_comment,
  [663134] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20855), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16482), 2,
      sym_comment,
      sym_block_comment,
  [663149] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20857), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16483), 2,
      sym_comment,
      sym_block_comment,
  [663164] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20859), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16484), 2,
      sym_comment,
      sym_block_comment,
  [663179] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20861), 1,
      sym__indent,
    STATE(12795), 1,
      sym__indented_type_cases,
    STATE(16485), 2,
      sym_comment,
      sym_block_comment,
  [663196] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20863), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16486), 2,
      sym_comment,
      sym_block_comment,
  [663211] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20865), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16487), 2,
      sym_comment,
      sym_block_comment,
  [663226] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20867), 1,
      sym__indent,
    STATE(11911), 1,
      sym__indented_type_cases,
    STATE(16488), 2,
      sym_comment,
      sym_block_comment,
  [663243] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20869), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16489), 2,
      sym_comment,
      sym_block_comment,
  [663258] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20871), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16490), 2,
      sym_comment,
      sym_block_comment,
  [663273] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20873), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16491), 2,
      sym_comment,
      sym_block_comment,
  [663288] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20875), 1,
      anon_sym_LPAREN,
    STATE(12721), 1,
      sym_parenthesized_expression,
    STATE(16492), 2,
      sym_comment,
      sym_block_comment,
  [663305] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20877), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16493), 2,
      sym_comment,
      sym_block_comment,
  [663320] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20879), 1,
      anon_sym_COLON,
    ACTIONS(20881), 1,
      anon_sym_EQ,
    STATE(16494), 2,
      sym_comment,
      sym_block_comment,
  [663337] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20883), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16495), 2,
      sym_comment,
      sym_block_comment,
  [663352] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20885), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16496), 2,
      sym_comment,
      sym_block_comment,
  [663367] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20887), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16497), 2,
      sym_comment,
      sym_block_comment,
  [663382] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20889), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16498), 2,
      sym_comment,
      sym_block_comment,
  [663397] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20891), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16499), 2,
      sym_comment,
      sym_block_comment,
  [663412] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20893), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16500), 2,
      sym_comment,
      sym_block_comment,
  [663427] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20895), 1,
      sym__indent,
    STATE(11799), 1,
      sym__indented_type_cases,
    STATE(16501), 2,
      sym_comment,
      sym_block_comment,
  [663444] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20897), 1,
      anon_sym_LPAREN,
    STATE(14348), 1,
      sym_parenthesized_expression,
    STATE(16502), 2,
      sym_comment,
      sym_block_comment,
  [663461] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20899), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16503), 2,
      sym_comment,
      sym_block_comment,
  [663476] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20901), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16504), 2,
      sym_comment,
      sym_block_comment,
  [663491] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20903), 1,
      anon_sym_COLON,
    ACTIONS(20905), 1,
      anon_sym_EQ,
    STATE(16505), 2,
      sym_comment,
      sym_block_comment,
  [663508] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20907), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16506), 2,
      sym_comment,
      sym_block_comment,
  [663523] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20909), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16507), 2,
      sym_comment,
      sym_block_comment,
  [663538] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20911), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16508), 2,
      sym_comment,
      sym_block_comment,
  [663553] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20913), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16509), 2,
      sym_comment,
      sym_block_comment,
  [663568] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20915), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16510), 2,
      sym_comment,
      sym_block_comment,
  [663583] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20917), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16511), 2,
      sym_comment,
      sym_block_comment,
  [663598] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20919), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16512), 2,
      sym_comment,
      sym_block_comment,
  [663613] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20921), 1,
      sym__indent,
    STATE(13840), 1,
      sym__indented_type_cases,
    STATE(16513), 2,
      sym_comment,
      sym_block_comment,
  [663630] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20923), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16514), 2,
      sym_comment,
      sym_block_comment,
  [663645] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20925), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16515), 2,
      sym_comment,
      sym_block_comment,
  [663660] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20927), 1,
      sym__indent,
    STATE(12004), 1,
      sym__indented_type_cases,
    STATE(16516), 2,
      sym_comment,
      sym_block_comment,
  [663677] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20929), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16517), 2,
      sym_comment,
      sym_block_comment,
  [663692] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20931), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16518), 2,
      sym_comment,
      sym_block_comment,
  [663707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20933), 1,
      anon_sym_LPAREN,
    STATE(13913), 1,
      sym_parenthesized_expression,
    STATE(16519), 2,
      sym_comment,
      sym_block_comment,
  [663724] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20935), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16520), 2,
      sym_comment,
      sym_block_comment,
  [663739] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20937), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16521), 2,
      sym_comment,
      sym_block_comment,
  [663754] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20939), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16522), 2,
      sym_comment,
      sym_block_comment,
  [663769] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20941), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16523), 2,
      sym_comment,
      sym_block_comment,
  [663784] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20943), 1,
      anon_sym_COLON,
    ACTIONS(20945), 1,
      anon_sym_EQ,
    STATE(16524), 2,
      sym_comment,
      sym_block_comment,
  [663801] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20947), 1,
      anon_sym_COLON,
    ACTIONS(20949), 1,
      anon_sym_EQ,
    STATE(16525), 2,
      sym_comment,
      sym_block_comment,
  [663818] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20951), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16526), 2,
      sym_comment,
      sym_block_comment,
  [663833] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20953), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16527), 2,
      sym_comment,
      sym_block_comment,
  [663848] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20955), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16528), 2,
      sym_comment,
      sym_block_comment,
  [663863] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20957), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16529), 2,
      sym_comment,
      sym_block_comment,
  [663878] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20959), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16530), 2,
      sym_comment,
      sym_block_comment,
  [663893] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20961), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16531), 2,
      sym_comment,
      sym_block_comment,
  [663908] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20963), 1,
      sym__indent,
    STATE(11631), 1,
      sym__indented_type_cases,
    STATE(16532), 2,
      sym_comment,
      sym_block_comment,
  [663925] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20965), 1,
      sym__indent,
    STATE(14014), 1,
      sym__indented_type_cases,
    STATE(16533), 2,
      sym_comment,
      sym_block_comment,
  [663942] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20967), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16534), 2,
      sym_comment,
      sym_block_comment,
  [663957] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20969), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16535), 2,
      sym_comment,
      sym_block_comment,
  [663972] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20971), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16536), 2,
      sym_comment,
      sym_block_comment,
  [663987] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20973), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16537), 2,
      sym_comment,
      sym_block_comment,
  [664002] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20975), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16538), 2,
      sym_comment,
      sym_block_comment,
  [664017] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20977), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16539), 2,
      sym_comment,
      sym_block_comment,
  [664032] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20979), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16540), 2,
      sym_comment,
      sym_block_comment,
  [664047] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20981), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16541), 2,
      sym_comment,
      sym_block_comment,
  [664062] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20983), 1,
      anon_sym_LPAREN,
    STATE(12284), 1,
      sym_parenthesized_expression,
    STATE(16542), 2,
      sym_comment,
      sym_block_comment,
  [664079] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20985), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16543), 2,
      sym_comment,
      sym_block_comment,
  [664094] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20987), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16544), 2,
      sym_comment,
      sym_block_comment,
  [664109] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20989), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16545), 2,
      sym_comment,
      sym_block_comment,
  [664124] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20991), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16546), 2,
      sym_comment,
      sym_block_comment,
  [664139] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20993), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16547), 2,
      sym_comment,
      sym_block_comment,
  [664154] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20995), 1,
      anon_sym_COLON,
    ACTIONS(20997), 1,
      anon_sym_EQ,
    STATE(16548), 2,
      sym_comment,
      sym_block_comment,
  [664171] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(20999), 1,
      anon_sym_COLON,
    ACTIONS(21001), 1,
      anon_sym_EQ,
    STATE(16549), 2,
      sym_comment,
      sym_block_comment,
  [664188] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21003), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16550), 2,
      sym_comment,
      sym_block_comment,
  [664203] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21005), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16551), 2,
      sym_comment,
      sym_block_comment,
  [664218] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21007), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16552), 2,
      sym_comment,
      sym_block_comment,
  [664233] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21009), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16553), 2,
      sym_comment,
      sym_block_comment,
  [664248] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21011), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16554), 2,
      sym_comment,
      sym_block_comment,
  [664263] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21013), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16555), 2,
      sym_comment,
      sym_block_comment,
  [664278] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21015), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16556), 2,
      sym_comment,
      sym_block_comment,
  [664293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21017), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16557), 2,
      sym_comment,
      sym_block_comment,
  [664308] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21019), 1,
      sym__indent,
    STATE(12073), 1,
      sym__indented_type_cases,
    STATE(16558), 2,
      sym_comment,
      sym_block_comment,
  [664325] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21021), 1,
      anon_sym_object,
    ACTIONS(21023), 1,
      anon_sym_class,
    STATE(16559), 2,
      sym_comment,
      sym_block_comment,
  [664342] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21025), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16560), 2,
      sym_comment,
      sym_block_comment,
  [664357] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21027), 1,
      anon_sym_LPAREN,
    STATE(14430), 1,
      sym_parenthesized_expression,
    STATE(16561), 2,
      sym_comment,
      sym_block_comment,
  [664374] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21029), 1,
      sym__indent,
    STATE(14995), 1,
      sym_with_template_body,
    STATE(16562), 2,
      sym_comment,
      sym_block_comment,
  [664391] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7720), 1,
      anon_sym_object,
    ACTIONS(7724), 1,
      anon_sym_class,
    STATE(16563), 2,
      sym_comment,
      sym_block_comment,
  [664408] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21031), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16564), 2,
      sym_comment,
      sym_block_comment,
  [664423] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21033), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16565), 2,
      sym_comment,
      sym_block_comment,
  [664438] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21035), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16566), 2,
      sym_comment,
      sym_block_comment,
  [664453] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15148), 1,
      anon_sym_object,
    ACTIONS(15152), 1,
      anon_sym_class,
    STATE(16567), 2,
      sym_comment,
      sym_block_comment,
  [664470] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21037), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16568), 2,
      sym_comment,
      sym_block_comment,
  [664485] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21039), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16569), 2,
      sym_comment,
      sym_block_comment,
  [664500] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21041), 1,
      sym__indent,
    STATE(13161), 1,
      sym__indented_type_cases,
    STATE(16570), 2,
      sym_comment,
      sym_block_comment,
  [664517] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21043), 1,
      anon_sym_COLON,
    ACTIONS(21045), 1,
      anon_sym_EQ,
    STATE(16571), 2,
      sym_comment,
      sym_block_comment,
  [664534] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21047), 1,
      anon_sym_COLON,
    ACTIONS(21049), 1,
      anon_sym_EQ,
    STATE(16572), 2,
      sym_comment,
      sym_block_comment,
  [664551] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21051), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16573), 2,
      sym_comment,
      sym_block_comment,
  [664566] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21053), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16574), 2,
      sym_comment,
      sym_block_comment,
  [664581] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21055), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16575), 2,
      sym_comment,
      sym_block_comment,
  [664596] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9409), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16576), 2,
      sym_comment,
      sym_block_comment,
  [664611] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9417), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16577), 2,
      sym_comment,
      sym_block_comment,
  [664626] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9413), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16578), 2,
      sym_comment,
      sym_block_comment,
  [664641] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11675), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16579), 2,
      sym_comment,
      sym_block_comment,
  [664656] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11817), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16580), 2,
      sym_comment,
      sym_block_comment,
  [664671] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9979), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(16581), 2,
      sym_comment,
      sym_block_comment,
  [664686] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11685), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16582), 2,
      sym_comment,
      sym_block_comment,
  [664701] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11689), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16583), 2,
      sym_comment,
      sym_block_comment,
  [664716] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11701), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16584), 2,
      sym_comment,
      sym_block_comment,
  [664731] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11707), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16585), 2,
      sym_comment,
      sym_block_comment,
  [664746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21057), 1,
      sym__indent,
    STATE(13855), 1,
      sym__indented_type_cases,
    STATE(16586), 2,
      sym_comment,
      sym_block_comment,
  [664763] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11723), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16587), 2,
      sym_comment,
      sym_block_comment,
  [664778] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9979), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(16588), 2,
      sym_comment,
      sym_block_comment,
  [664793] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11739), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16589), 2,
      sym_comment,
      sym_block_comment,
  [664808] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11623), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16590), 2,
      sym_comment,
      sym_block_comment,
  [664823] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21059), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16591), 2,
      sym_comment,
      sym_block_comment,
  [664838] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21061), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16592), 2,
      sym_comment,
      sym_block_comment,
  [664853] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7880), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16593), 2,
      sym_comment,
      sym_block_comment,
  [664868] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21063), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16594), 2,
      sym_comment,
      sym_block_comment,
  [664883] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21065), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16595), 2,
      sym_comment,
      sym_block_comment,
  [664898] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21067), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16596), 2,
      sym_comment,
      sym_block_comment,
  [664913] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21069), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16597), 2,
      sym_comment,
      sym_block_comment,
  [664928] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11789), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16598), 2,
      sym_comment,
      sym_block_comment,
  [664943] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10021), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(16599), 2,
      sym_comment,
      sym_block_comment,
  [664958] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15948), 1,
      anon_sym_EQ_GT,
    ACTIONS(21071), 1,
      anon_sym_COLON,
    STATE(16600), 2,
      sym_comment,
      sym_block_comment,
  [664975] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10021), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(16601), 2,
      sym_comment,
      sym_block_comment,
  [664990] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16303), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(16602), 2,
      sym_comment,
      sym_block_comment,
  [665005] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16648), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(16603), 2,
      sym_comment,
      sym_block_comment,
  [665020] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16437), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(16604), 2,
      sym_comment,
      sym_block_comment,
  [665035] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21073), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(16605), 2,
      sym_comment,
      sym_block_comment,
  [665050] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21075), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(16606), 2,
      sym_comment,
      sym_block_comment,
  [665065] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21077), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(16607), 2,
      sym_comment,
      sym_block_comment,
  [665080] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16218), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(16608), 2,
      sym_comment,
      sym_block_comment,
  [665095] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(5136), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(16609), 2,
      sym_comment,
      sym_block_comment,
  [665110] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21079), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16610), 2,
      sym_comment,
      sym_block_comment,
  [665125] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21081), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16611), 2,
      sym_comment,
      sym_block_comment,
  [665140] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21083), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16612), 2,
      sym_comment,
      sym_block_comment,
  [665155] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21085), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16613), 2,
      sym_comment,
      sym_block_comment,
  [665170] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21087), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16614), 2,
      sym_comment,
      sym_block_comment,
  [665185] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21089), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(16615), 2,
      sym_comment,
      sym_block_comment,
  [665200] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21091), 1,
      sym__indent,
    STATE(11782), 1,
      sym__indented_type_cases,
    STATE(16616), 2,
      sym_comment,
      sym_block_comment,
  [665217] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17395), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(16617), 2,
      sym_comment,
      sym_block_comment,
  [665232] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21093), 2,
      sym__outdent,
      anon_sym_case,
    STATE(16618), 2,
      sym_comment,
      sym_block_comment,
  [665247] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21095), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16619), 2,
      sym_comment,
      sym_block_comment,
  [665262] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(19088), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(16620), 2,
      sym_comment,
      sym_block_comment,
  [665277] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21097), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(16621), 2,
      sym_comment,
      sym_block_comment,
  [665292] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9515), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16622), 2,
      sym_comment,
      sym_block_comment,
  [665307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21099), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16623), 2,
      sym_comment,
      sym_block_comment,
  [665322] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21101), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    STATE(16624), 2,
      sym_comment,
      sym_block_comment,
  [665337] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18965), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(16625), 2,
      sym_comment,
      sym_block_comment,
  [665352] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21073), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(16626), 2,
      sym_comment,
      sym_block_comment,
  [665367] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21103), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16627), 2,
      sym_comment,
      sym_block_comment,
  [665382] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21105), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16628), 2,
      sym_comment,
      sym_block_comment,
  [665397] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21107), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16629), 2,
      sym_comment,
      sym_block_comment,
  [665412] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21109), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16630), 2,
      sym_comment,
      sym_block_comment,
  [665427] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21111), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16631), 2,
      sym_comment,
      sym_block_comment,
  [665442] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21075), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(16632), 2,
      sym_comment,
      sym_block_comment,
  [665457] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21077), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(16633), 2,
      sym_comment,
      sym_block_comment,
  [665472] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21113), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16634), 2,
      sym_comment,
      sym_block_comment,
  [665487] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18829), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(16635), 2,
      sym_comment,
      sym_block_comment,
  [665502] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21115), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16636), 2,
      sym_comment,
      sym_block_comment,
  [665517] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21117), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(16637), 2,
      sym_comment,
      sym_block_comment,
  [665532] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9519), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16638), 2,
      sym_comment,
      sym_block_comment,
  [665547] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18624), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(16639), 2,
      sym_comment,
      sym_block_comment,
  [665562] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18603), 2,
      sym__interpolated_multiline_string_middle,
      sym__interpolated_multiline_string_end,
    STATE(16640), 2,
      sym_comment,
      sym_block_comment,
  [665577] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21119), 1,
      anon_sym_EQ_GT,
    ACTIONS(21121), 1,
      anon_sym_QMARK_EQ_GT,
    STATE(16641), 2,
      sym_comment,
      sym_block_comment,
  [665594] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21123), 2,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(16642), 2,
      sym_comment,
      sym_block_comment,
  [665609] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18507), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(16643), 2,
      sym_comment,
      sym_block_comment,
  [665624] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18503), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(16644), 2,
      sym_comment,
      sym_block_comment,
  [665639] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21125), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16645), 2,
      sym_comment,
      sym_block_comment,
  [665654] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(18450), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(16646), 2,
      sym_comment,
      sym_block_comment,
  [665669] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21127), 1,
      sym__indent,
    STATE(16580), 1,
      sym__indented_type_cases,
    STATE(16647), 2,
      sym_comment,
      sym_block_comment,
  [665686] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9829), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16648), 2,
      sym_comment,
      sym_block_comment,
  [665701] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21129), 1,
      sym__indent,
    STATE(8931), 1,
      sym__indented_type_cases,
    STATE(16649), 2,
      sym_comment,
      sym_block_comment,
  [665718] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21121), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16650), 2,
      sym_comment,
      sym_block_comment,
  [665733] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21131), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16651), 2,
      sym_comment,
      sym_block_comment,
  [665748] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21133), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16652), 2,
      sym_comment,
      sym_block_comment,
  [665763] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21135), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16653), 2,
      sym_comment,
      sym_block_comment,
  [665778] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21137), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(16654), 2,
      sym_comment,
      sym_block_comment,
  [665793] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21139), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(16655), 2,
      sym_comment,
      sym_block_comment,
  [665808] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21141), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(16656), 2,
      sym_comment,
      sym_block_comment,
  [665823] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21143), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(16657), 2,
      sym_comment,
      sym_block_comment,
  [665838] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9556), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16658), 2,
      sym_comment,
      sym_block_comment,
  [665853] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21081), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    STATE(16659), 2,
      sym_comment,
      sym_block_comment,
  [665868] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21145), 1,
      anon_sym_object,
    ACTIONS(21147), 1,
      anon_sym_class,
    STATE(16660), 2,
      sym_comment,
      sym_block_comment,
  [665885] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21149), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16661), 2,
      sym_comment,
      sym_block_comment,
  [665900] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21151), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16662), 2,
      sym_comment,
      sym_block_comment,
  [665915] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21153), 1,
      sym__indent,
    STATE(13186), 1,
      sym__indented_type_cases,
    STATE(16663), 2,
      sym_comment,
      sym_block_comment,
  [665932] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21155), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16664), 2,
      sym_comment,
      sym_block_comment,
  [665947] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21157), 1,
      anon_sym_LPAREN,
    STATE(13110), 1,
      sym_parenthesized_expression,
    STATE(16665), 2,
      sym_comment,
      sym_block_comment,
  [665964] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21159), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16666), 2,
      sym_comment,
      sym_block_comment,
  [665979] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9806), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16667), 2,
      sym_comment,
      sym_block_comment,
  [665994] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9802), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16668), 2,
      sym_comment,
      sym_block_comment,
  [666009] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21161), 1,
      sym__indent,
    STATE(14720), 1,
      sym_with_template_body,
    STATE(16669), 2,
      sym_comment,
      sym_block_comment,
  [666026] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21163), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(16670), 2,
      sym_comment,
      sym_block_comment,
  [666041] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21165), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(16671), 2,
      sym_comment,
      sym_block_comment,
  [666056] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21167), 1,
      sym__indent,
    STATE(13565), 1,
      sym__indented_type_cases,
    STATE(16672), 2,
      sym_comment,
      sym_block_comment,
  [666073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9626), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16673), 2,
      sym_comment,
      sym_block_comment,
  [666088] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21169), 2,
      sym__interpolated_string_middle,
      sym__interpolated_string_end,
    STATE(16674), 2,
      sym_comment,
      sym_block_comment,
  [666103] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21171), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16675), 2,
      sym_comment,
      sym_block_comment,
  [666118] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21173), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16676), 2,
      sym_comment,
      sym_block_comment,
  [666133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15082), 1,
      anon_sym_object,
    ACTIONS(15086), 1,
      anon_sym_class,
    STATE(16677), 2,
      sym_comment,
      sym_block_comment,
  [666150] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21175), 1,
      anon_sym_COLON,
    ACTIONS(21177), 1,
      anon_sym_EQ,
    STATE(16678), 2,
      sym_comment,
      sym_block_comment,
  [666167] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21179), 1,
      anon_sym_COLON,
    ACTIONS(21181), 1,
      anon_sym_EQ,
    STATE(16679), 2,
      sym_comment,
      sym_block_comment,
  [666184] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21183), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16680), 2,
      sym_comment,
      sym_block_comment,
  [666199] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21185), 2,
      anon_sym_do,
      anon_sym_yield,
    STATE(16681), 2,
      sym_comment,
      sym_block_comment,
  [666214] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9738), 2,
      anon_sym_with,
      anon_sym_LPAREN,
    STATE(16682), 2,
      sym_comment,
      sym_block_comment,
  [666229] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21187), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16683), 2,
      sym_comment,
      sym_block_comment,
  [666244] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21083), 2,
      anon_sym_RBRACE,
      anon_sym_case,
    STATE(16684), 2,
      sym_comment,
      sym_block_comment,
  [666259] = 3,
    ACTIONS(17815), 1,
      anon_sym_SLASH_STAR,
    STATE(16685), 2,
      sym_comment,
      sym_block_comment,
    ACTIONS(21189), 3,
      anon_sym_SLASH_SLASH,
      aux_sym_block_comment_token1,
      anon_sym_STAR_SLASH,
  [666272] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21191), 2,
      anon_sym_EQ_GT,
      anon_sym_QMARK_EQ_GT,
    STATE(16686), 2,
      sym_comment,
      sym_block_comment,
  [666287] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7646), 1,
      anon_sym_object,
    ACTIONS(7650), 1,
      anon_sym_class,
    STATE(16687), 2,
      sym_comment,
      sym_block_comment,
  [666304] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21193), 1,
      anon_sym_EQ_GT_GT,
    STATE(16688), 2,
      sym_comment,
      sym_block_comment,
  [666318] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21195), 1,
      anon_sym_EQ_GT_GT,
    STATE(16689), 2,
      sym_comment,
      sym_block_comment,
  [666332] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21197), 1,
      anon_sym_else,
    STATE(16690), 2,
      sym_comment,
      sym_block_comment,
  [666346] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21199), 1,
      sym__outdent,
    STATE(16691), 2,
      sym_comment,
      sym_block_comment,
  [666360] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21201), 1,
      anon_sym_RPAREN,
    STATE(16692), 2,
      sym_comment,
      sym_block_comment,
  [666374] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21203), 1,
      anon_sym_EQ_GT,
    STATE(16693), 2,
      sym_comment,
      sym_block_comment,
  [666388] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21205), 1,
      anon_sym_else,
    STATE(16694), 2,
      sym_comment,
      sym_block_comment,
  [666402] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21207), 1,
      anon_sym_EQ_GT_GT,
    STATE(16695), 2,
      sym_comment,
      sym_block_comment,
  [666416] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21209), 1,
      anon_sym_EQ_GT_GT,
    STATE(16696), 2,
      sym_comment,
      sym_block_comment,
  [666430] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21211), 1,
      anon_sym_EQ_GT_GT,
    STATE(16697), 2,
      sym_comment,
      sym_block_comment,
  [666444] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21213), 1,
      anon_sym_EQ_GT_GT,
    STATE(16698), 2,
      sym_comment,
      sym_block_comment,
  [666458] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21215), 1,
      sym__outdent,
    STATE(16699), 2,
      sym_comment,
      sym_block_comment,
  [666472] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21217), 1,
      anon_sym_COLON,
    STATE(16700), 2,
      sym_comment,
      sym_block_comment,
  [666486] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10466), 1,
      anon_sym_DOT,
    STATE(16701), 2,
      sym_comment,
      sym_block_comment,
  [666500] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21219), 1,
      anon_sym_RPAREN,
    STATE(16702), 2,
      sym_comment,
      sym_block_comment,
  [666514] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21221), 1,
      anon_sym_RBRACK,
    STATE(16703), 2,
      sym_comment,
      sym_block_comment,
  [666528] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21221), 1,
      anon_sym_RBRACE,
    STATE(16704), 2,
      sym_comment,
      sym_block_comment,
  [666542] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21223), 1,
      anon_sym_RPAREN,
    STATE(16705), 2,
      sym_comment,
      sym_block_comment,
  [666556] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21223), 1,
      anon_sym_RBRACE,
    STATE(16706), 2,
      sym_comment,
      sym_block_comment,
  [666570] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21225), 1,
      sym__outdent,
    STATE(16707), 2,
      sym_comment,
      sym_block_comment,
  [666584] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21227), 1,
      anon_sym_RBRACE,
    STATE(16708), 2,
      sym_comment,
      sym_block_comment,
  [666598] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21229), 1,
      anon_sym_do,
    STATE(16709), 2,
      sym_comment,
      sym_block_comment,
  [666612] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21231), 1,
      anon_sym_RBRACE,
    STATE(16710), 2,
      sym_comment,
      sym_block_comment,
  [666626] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21233), 1,
      anon_sym_EQ_GT,
    STATE(16711), 2,
      sym_comment,
      sym_block_comment,
  [666640] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21235), 1,
      anon_sym_else,
    STATE(16712), 2,
      sym_comment,
      sym_block_comment,
  [666654] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21237), 1,
      anon_sym_EQ_GT_GT,
    STATE(16713), 2,
      sym_comment,
      sym_block_comment,
  [666668] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21239), 1,
      anon_sym_EQ_GT_GT,
    STATE(16714), 2,
      sym_comment,
      sym_block_comment,
  [666682] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21241), 1,
      anon_sym_EQ_GT_GT,
    STATE(16715), 2,
      sym_comment,
      sym_block_comment,
  [666696] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21243), 1,
      anon_sym_EQ_GT_GT,
    STATE(16716), 2,
      sym_comment,
      sym_block_comment,
  [666710] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21245), 1,
      sym__outdent,
    STATE(16717), 2,
      sym_comment,
      sym_block_comment,
  [666724] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21247), 1,
      anon_sym_RPAREN,
    STATE(16718), 2,
      sym_comment,
      sym_block_comment,
  [666738] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21249), 1,
      anon_sym_COLON,
    STATE(16719), 2,
      sym_comment,
      sym_block_comment,
  [666752] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11659), 1,
      anon_sym_DOT,
    STATE(16720), 2,
      sym_comment,
      sym_block_comment,
  [666766] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21251), 1,
      anon_sym_else,
    STATE(16721), 2,
      sym_comment,
      sym_block_comment,
  [666780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21253), 1,
      sym__outdent,
    STATE(16722), 2,
      sym_comment,
      sym_block_comment,
  [666794] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21255), 1,
      anon_sym_RPAREN,
    STATE(16723), 2,
      sym_comment,
      sym_block_comment,
  [666808] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21257), 1,
      anon_sym_RBRACK,
    STATE(16724), 2,
      sym_comment,
      sym_block_comment,
  [666822] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21259), 1,
      sym__outdent,
    STATE(16725), 2,
      sym_comment,
      sym_block_comment,
  [666836] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21261), 1,
      anon_sym_RPAREN,
    STATE(16726), 2,
      sym_comment,
      sym_block_comment,
  [666850] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21261), 1,
      anon_sym_RBRACE,
    STATE(16727), 2,
      sym_comment,
      sym_block_comment,
  [666864] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21263), 1,
      sym__outdent,
    STATE(16728), 2,
      sym_comment,
      sym_block_comment,
  [666878] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21265), 1,
      anon_sym_RBRACE,
    STATE(16729), 2,
      sym_comment,
      sym_block_comment,
  [666892] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21267), 1,
      anon_sym_EQ_GT,
    STATE(16730), 2,
      sym_comment,
      sym_block_comment,
  [666906] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21269), 1,
      anon_sym_RPAREN,
    STATE(16731), 2,
      sym_comment,
      sym_block_comment,
  [666920] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21271), 1,
      anon_sym_RBRACE,
    STATE(16732), 2,
      sym_comment,
      sym_block_comment,
  [666934] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21273), 1,
      anon_sym_EQ_GT_GT,
    STATE(16733), 2,
      sym_comment,
      sym_block_comment,
  [666948] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21275), 1,
      sym__outdent,
    STATE(16734), 2,
      sym_comment,
      sym_block_comment,
  [666962] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21277), 1,
      anon_sym_EQ_GT_GT,
    STATE(16735), 2,
      sym_comment,
      sym_block_comment,
  [666976] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21279), 1,
      anon_sym_EQ_GT_GT,
    STATE(16736), 2,
      sym_comment,
      sym_block_comment,
  [666990] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21281), 1,
      anon_sym_EQ_GT_GT,
    STATE(16737), 2,
      sym_comment,
      sym_block_comment,
  [667004] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21269), 1,
      anon_sym_RBRACE,
    STATE(16738), 2,
      sym_comment,
      sym_block_comment,
  [667018] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11641), 1,
      anon_sym_DOT,
    STATE(16739), 2,
      sym_comment,
      sym_block_comment,
  [667032] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21283), 1,
      anon_sym_do,
    STATE(16740), 2,
      sym_comment,
      sym_block_comment,
  [667046] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21285), 1,
      anon_sym_RBRACE,
    STATE(16741), 2,
      sym_comment,
      sym_block_comment,
  [667060] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21287), 1,
      anon_sym_COLON,
    STATE(16742), 2,
      sym_comment,
      sym_block_comment,
  [667074] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11275), 1,
      anon_sym_DOT,
    STATE(16743), 2,
      sym_comment,
      sym_block_comment,
  [667088] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21289), 1,
      anon_sym_COLON,
    STATE(16744), 2,
      sym_comment,
      sym_block_comment,
  [667102] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21291), 1,
      anon_sym_else,
    STATE(16745), 2,
      sym_comment,
      sym_block_comment,
  [667116] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21293), 1,
      anon_sym_RBRACK,
    STATE(16746), 2,
      sym_comment,
      sym_block_comment,
  [667130] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21295), 1,
      anon_sym_else,
    STATE(16747), 2,
      sym_comment,
      sym_block_comment,
  [667144] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21297), 1,
      anon_sym_RPAREN,
    STATE(16748), 2,
      sym_comment,
      sym_block_comment,
  [667158] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21299), 1,
      anon_sym_RBRACE,
    STATE(16749), 2,
      sym_comment,
      sym_block_comment,
  [667172] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21301), 1,
      anon_sym_else,
    STATE(16750), 2,
      sym_comment,
      sym_block_comment,
  [667186] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21299), 1,
      anon_sym_RBRACK,
    STATE(16751), 2,
      sym_comment,
      sym_block_comment,
  [667200] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21303), 1,
      anon_sym_EQ_GT_GT,
    STATE(16752), 2,
      sym_comment,
      sym_block_comment,
  [667214] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21305), 1,
      sym__outdent,
    STATE(16753), 2,
      sym_comment,
      sym_block_comment,
  [667228] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21307), 1,
      anon_sym_EQ_GT_GT,
    STATE(16754), 2,
      sym_comment,
      sym_block_comment,
  [667242] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21309), 1,
      anon_sym_EQ_GT_GT,
    STATE(16755), 2,
      sym_comment,
      sym_block_comment,
  [667256] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21311), 1,
      anon_sym_RPAREN,
    STATE(16756), 2,
      sym_comment,
      sym_block_comment,
  [667270] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21313), 1,
      anon_sym_EQ_GT_GT,
    STATE(16757), 2,
      sym_comment,
      sym_block_comment,
  [667284] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21315), 1,
      anon_sym_RBRACK,
    STATE(16758), 2,
      sym_comment,
      sym_block_comment,
  [667298] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21315), 1,
      anon_sym_RBRACE,
    STATE(16759), 2,
      sym_comment,
      sym_block_comment,
  [667312] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21317), 1,
      anon_sym_EQ_GT,
    STATE(16760), 2,
      sym_comment,
      sym_block_comment,
  [667326] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21319), 1,
      anon_sym_RBRACK,
    STATE(16761), 2,
      sym_comment,
      sym_block_comment,
  [667340] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21319), 1,
      anon_sym_RBRACE,
    STATE(16762), 2,
      sym_comment,
      sym_block_comment,
  [667354] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21321), 1,
      anon_sym_EQ_GT_GT,
    STATE(16763), 2,
      sym_comment,
      sym_block_comment,
  [667368] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21323), 1,
      anon_sym_RPAREN,
    STATE(16764), 2,
      sym_comment,
      sym_block_comment,
  [667382] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21325), 1,
      anon_sym_EQ_GT_GT,
    STATE(16765), 2,
      sym_comment,
      sym_block_comment,
  [667396] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21327), 1,
      anon_sym_EQ_GT_GT,
    STATE(16766), 2,
      sym_comment,
      sym_block_comment,
  [667410] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21329), 1,
      anon_sym_EQ_GT_GT,
    STATE(16767), 2,
      sym_comment,
      sym_block_comment,
  [667424] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21331), 1,
      anon_sym_EQ_GT,
    STATE(16768), 2,
      sym_comment,
      sym_block_comment,
  [667438] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21333), 1,
      anon_sym_RPAREN,
    STATE(16769), 2,
      sym_comment,
      sym_block_comment,
  [667452] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21335), 1,
      anon_sym_COLON,
    STATE(16770), 2,
      sym_comment,
      sym_block_comment,
  [667466] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11236), 1,
      anon_sym_DOT,
    STATE(16771), 2,
      sym_comment,
      sym_block_comment,
  [667480] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21333), 1,
      anon_sym_RBRACE,
    STATE(16772), 2,
      sym_comment,
      sym_block_comment,
  [667494] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21337), 1,
      sym__outdent,
    STATE(16773), 2,
      sym_comment,
      sym_block_comment,
  [667508] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21339), 1,
      sym__outdent,
    STATE(16774), 2,
      sym_comment,
      sym_block_comment,
  [667522] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21341), 1,
      anon_sym_else,
    STATE(16775), 2,
      sym_comment,
      sym_block_comment,
  [667536] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21343), 1,
      anon_sym_RBRACE,
    STATE(16776), 2,
      sym_comment,
      sym_block_comment,
  [667550] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21257), 1,
      anon_sym_RBRACE,
    STATE(16777), 2,
      sym_comment,
      sym_block_comment,
  [667564] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21345), 1,
      anon_sym_RPAREN,
    STATE(16778), 2,
      sym_comment,
      sym_block_comment,
  [667578] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21347), 1,
      sym__outdent,
    STATE(16779), 2,
      sym_comment,
      sym_block_comment,
  [667592] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21349), 1,
      anon_sym_else,
    STATE(16780), 2,
      sym_comment,
      sym_block_comment,
  [667606] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21351), 1,
      anon_sym_do,
    STATE(16781), 2,
      sym_comment,
      sym_block_comment,
  [667620] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21353), 1,
      anon_sym_do,
    STATE(16782), 2,
      sym_comment,
      sym_block_comment,
  [667634] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21355), 1,
      anon_sym_RBRACE,
    STATE(16783), 2,
      sym_comment,
      sym_block_comment,
  [667648] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21357), 1,
      anon_sym_RBRACE,
    STATE(16784), 2,
      sym_comment,
      sym_block_comment,
  [667662] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21359), 1,
      anon_sym_else,
    STATE(16785), 2,
      sym_comment,
      sym_block_comment,
  [667676] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21361), 1,
      sym__outdent,
    STATE(16786), 2,
      sym_comment,
      sym_block_comment,
  [667690] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21363), 1,
      anon_sym_EQ_GT,
    STATE(16787), 2,
      sym_comment,
      sym_block_comment,
  [667704] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11414), 1,
      anon_sym_DOT,
    STATE(16788), 2,
      sym_comment,
      sym_block_comment,
  [667718] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21365), 1,
      anon_sym_RPAREN,
    STATE(16789), 2,
      sym_comment,
      sym_block_comment,
  [667732] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21367), 1,
      anon_sym_EQ_GT_GT,
    STATE(16790), 2,
      sym_comment,
      sym_block_comment,
  [667746] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21369), 1,
      anon_sym_COLON,
    STATE(16791), 2,
      sym_comment,
      sym_block_comment,
  [667760] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21371), 1,
      anon_sym_EQ_GT_GT,
    STATE(16792), 2,
      sym_comment,
      sym_block_comment,
  [667774] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21373), 1,
      anon_sym_EQ_GT_GT,
    STATE(16793), 2,
      sym_comment,
      sym_block_comment,
  [667788] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21375), 1,
      anon_sym_EQ_GT_GT,
    STATE(16794), 2,
      sym_comment,
      sym_block_comment,
  [667802] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21377), 1,
      sym__outdent,
    STATE(16795), 2,
      sym_comment,
      sym_block_comment,
  [667816] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21379), 1,
      anon_sym_else,
    STATE(16796), 2,
      sym_comment,
      sym_block_comment,
  [667830] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21381), 1,
      anon_sym_COLON,
    STATE(16797), 2,
      sym_comment,
      sym_block_comment,
  [667844] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10549), 1,
      anon_sym_DOT,
    STATE(16798), 2,
      sym_comment,
      sym_block_comment,
  [667858] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21383), 1,
      anon_sym_EQ_GT_GT,
    STATE(16799), 2,
      sym_comment,
      sym_block_comment,
  [667872] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21385), 1,
      anon_sym_EQ_GT_GT,
    STATE(16800), 2,
      sym_comment,
      sym_block_comment,
  [667886] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21387), 1,
      sym__outdent,
    STATE(16801), 2,
      sym_comment,
      sym_block_comment,
  [667900] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21389), 1,
      anon_sym_EQ_GT_GT,
    STATE(16802), 2,
      sym_comment,
      sym_block_comment,
  [667914] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21391), 1,
      anon_sym_EQ_GT_GT,
    STATE(16803), 2,
      sym_comment,
      sym_block_comment,
  [667928] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21393), 1,
      anon_sym_RPAREN,
    STATE(16804), 2,
      sym_comment,
      sym_block_comment,
  [667942] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21395), 1,
      anon_sym_RPAREN,
    STATE(16805), 2,
      sym_comment,
      sym_block_comment,
  [667956] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21397), 1,
      anon_sym_RBRACK,
    STATE(16806), 2,
      sym_comment,
      sym_block_comment,
  [667970] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21397), 1,
      anon_sym_RBRACE,
    STATE(16807), 2,
      sym_comment,
      sym_block_comment,
  [667984] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21399), 1,
      anon_sym_RBRACE,
    STATE(16808), 2,
      sym_comment,
      sym_block_comment,
  [667998] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21293), 1,
      anon_sym_RBRACE,
    STATE(16809), 2,
      sym_comment,
      sym_block_comment,
  [668012] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21401), 1,
      anon_sym_EQ_GT,
    STATE(16810), 2,
      sym_comment,
      sym_block_comment,
  [668026] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21403), 1,
      anon_sym_RPAREN,
    STATE(16811), 2,
      sym_comment,
      sym_block_comment,
  [668040] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21405), 1,
      anon_sym_EQ_GT,
    STATE(16812), 2,
      sym_comment,
      sym_block_comment,
  [668054] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21403), 1,
      anon_sym_RBRACE,
    STATE(16813), 2,
      sym_comment,
      sym_block_comment,
  [668068] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21407), 1,
      sym__outdent,
    STATE(16814), 2,
      sym_comment,
      sym_block_comment,
  [668082] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21409), 1,
      anon_sym_EQ_GT_GT,
    STATE(16815), 2,
      sym_comment,
      sym_block_comment,
  [668096] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21399), 1,
      anon_sym_RBRACK,
    STATE(16816), 2,
      sym_comment,
      sym_block_comment,
  [668110] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21411), 1,
      anon_sym_EQ_GT_GT,
    STATE(16817), 2,
      sym_comment,
      sym_block_comment,
  [668124] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21413), 1,
      anon_sym_EQ_GT_GT,
    STATE(16818), 2,
      sym_comment,
      sym_block_comment,
  [668138] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21415), 1,
      anon_sym_EQ_GT_GT,
    STATE(16819), 2,
      sym_comment,
      sym_block_comment,
  [668152] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21417), 1,
      anon_sym_RPAREN,
    STATE(16820), 2,
      sym_comment,
      sym_block_comment,
  [668166] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21419), 1,
      sym__outdent,
    STATE(16821), 2,
      sym_comment,
      sym_block_comment,
  [668180] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21421), 1,
      anon_sym_COLON,
    STATE(16822), 2,
      sym_comment,
      sym_block_comment,
  [668194] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11783), 1,
      anon_sym_DOT,
    STATE(16823), 2,
      sym_comment,
      sym_block_comment,
  [668208] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21423), 1,
      anon_sym_RBRACE,
    STATE(16824), 2,
      sym_comment,
      sym_block_comment,
  [668222] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21425), 1,
      anon_sym_RPAREN,
    STATE(16825), 2,
      sym_comment,
      sym_block_comment,
  [668236] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21427), 1,
      anon_sym_RPAREN,
    STATE(16826), 2,
      sym_comment,
      sym_block_comment,
  [668250] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21429), 1,
      sym__outdent,
    STATE(16827), 2,
      sym_comment,
      sym_block_comment,
  [668264] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21431), 1,
      anon_sym_else,
    STATE(16828), 2,
      sym_comment,
      sym_block_comment,
  [668278] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21433), 1,
      anon_sym_do,
    STATE(16829), 2,
      sym_comment,
      sym_block_comment,
  [668292] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21435), 1,
      anon_sym_do,
    STATE(16830), 2,
      sym_comment,
      sym_block_comment,
  [668306] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21437), 1,
      anon_sym_RBRACE,
    STATE(16831), 2,
      sym_comment,
      sym_block_comment,
  [668320] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10675), 1,
      anon_sym_DOT,
    STATE(16832), 2,
      sym_comment,
      sym_block_comment,
  [668334] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21439), 1,
      anon_sym_else,
    STATE(16833), 2,
      sym_comment,
      sym_block_comment,
  [668348] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21441), 1,
      sym__outdent,
    STATE(16834), 2,
      sym_comment,
      sym_block_comment,
  [668362] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21443), 1,
      anon_sym_COLON,
    STATE(16835), 2,
      sym_comment,
      sym_block_comment,
  [668376] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21445), 1,
      anon_sym_RPAREN,
    STATE(16836), 2,
      sym_comment,
      sym_block_comment,
  [668390] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21447), 1,
      anon_sym_EQ_GT,
    STATE(16837), 2,
      sym_comment,
      sym_block_comment,
  [668404] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21449), 1,
      anon_sym_RBRACE,
    STATE(16838), 2,
      sym_comment,
      sym_block_comment,
  [668418] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21451), 1,
      anon_sym_else,
    STATE(16839), 2,
      sym_comment,
      sym_block_comment,
  [668432] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21453), 1,
      anon_sym_EQ_GT_GT,
    STATE(16840), 2,
      sym_comment,
      sym_block_comment,
  [668446] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21455), 1,
      sym__outdent,
    STATE(16841), 2,
      sym_comment,
      sym_block_comment,
  [668460] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21457), 1,
      anon_sym_EQ_GT_GT,
    STATE(16842), 2,
      sym_comment,
      sym_block_comment,
  [668474] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21459), 1,
      anon_sym_EQ_GT_GT,
    STATE(16843), 2,
      sym_comment,
      sym_block_comment,
  [668488] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21461), 1,
      anon_sym_EQ_GT_GT,
    STATE(16844), 2,
      sym_comment,
      sym_block_comment,
  [668502] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21463), 1,
      anon_sym_EQ_GT_GT,
    STATE(16845), 2,
      sym_comment,
      sym_block_comment,
  [668516] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21465), 1,
      anon_sym_EQ_GT_GT,
    STATE(16846), 2,
      sym_comment,
      sym_block_comment,
  [668530] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21467), 1,
      anon_sym_COLON,
    STATE(16847), 2,
      sym_comment,
      sym_block_comment,
  [668544] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13196), 1,
      anon_sym_DOT,
    STATE(16848), 2,
      sym_comment,
      sym_block_comment,
  [668558] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21469), 1,
      sym__outdent,
    STATE(16849), 2,
      sym_comment,
      sym_block_comment,
  [668572] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21471), 1,
      anon_sym_EQ_GT_GT,
    STATE(16850), 2,
      sym_comment,
      sym_block_comment,
  [668586] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21473), 1,
      anon_sym_EQ_GT_GT,
    STATE(16851), 2,
      sym_comment,
      sym_block_comment,
  [668600] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21475), 1,
      anon_sym_RPAREN,
    STATE(16852), 2,
      sym_comment,
      sym_block_comment,
  [668614] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21477), 1,
      anon_sym_RBRACE,
    STATE(16853), 2,
      sym_comment,
      sym_block_comment,
  [668628] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21479), 1,
      anon_sym_RBRACK,
    STATE(16854), 2,
      sym_comment,
      sym_block_comment,
  [668642] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21479), 1,
      anon_sym_RBRACE,
    STATE(16855), 2,
      sym_comment,
      sym_block_comment,
  [668656] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21481), 1,
      anon_sym_RBRACK,
    STATE(16856), 2,
      sym_comment,
      sym_block_comment,
  [668670] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21481), 1,
      anon_sym_RBRACE,
    STATE(16857), 2,
      sym_comment,
      sym_block_comment,
  [668684] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21477), 1,
      anon_sym_RPAREN,
    STATE(16858), 2,
      sym_comment,
      sym_block_comment,
  [668698] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21483), 1,
      anon_sym_RPAREN,
    STATE(16859), 2,
      sym_comment,
      sym_block_comment,
  [668712] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21483), 1,
      anon_sym_RBRACE,
    STATE(16860), 2,
      sym_comment,
      sym_block_comment,
  [668726] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21485), 1,
      sym__outdent,
    STATE(16861), 2,
      sym_comment,
      sym_block_comment,
  [668740] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21487), 1,
      anon_sym_EQ_GT,
    STATE(16862), 2,
      sym_comment,
      sym_block_comment,
  [668754] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21489), 1,
      anon_sym_EQ_GT,
    STATE(16863), 2,
      sym_comment,
      sym_block_comment,
  [668768] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21491), 1,
      anon_sym_RPAREN,
    STATE(16864), 2,
      sym_comment,
      sym_block_comment,
  [668782] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21493), 1,
      anon_sym_RPAREN,
    STATE(16865), 2,
      sym_comment,
      sym_block_comment,
  [668796] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21495), 1,
      anon_sym_EQ_GT_GT,
    STATE(16866), 2,
      sym_comment,
      sym_block_comment,
  [668810] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21497), 1,
      anon_sym_EQ_GT_GT,
    STATE(16867), 2,
      sym_comment,
      sym_block_comment,
  [668824] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21499), 1,
      anon_sym_EQ_GT_GT,
    STATE(16868), 2,
      sym_comment,
      sym_block_comment,
  [668838] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21501), 1,
      anon_sym_RBRACE,
    STATE(16869), 2,
      sym_comment,
      sym_block_comment,
  [668852] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21503), 1,
      sym__outdent,
    STATE(16870), 2,
      sym_comment,
      sym_block_comment,
  [668866] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21505), 1,
      anon_sym_COLON,
    STATE(16871), 2,
      sym_comment,
      sym_block_comment,
  [668880] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9630), 1,
      anon_sym_DOT,
    STATE(16872), 2,
      sym_comment,
      sym_block_comment,
  [668894] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21507), 1,
      anon_sym_else,
    STATE(16873), 2,
      sym_comment,
      sym_block_comment,
  [668908] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21509), 1,
      anon_sym_RPAREN,
    STATE(16874), 2,
      sym_comment,
      sym_block_comment,
  [668922] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21511), 1,
      sym__outdent,
    STATE(16875), 2,
      sym_comment,
      sym_block_comment,
  [668936] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21513), 1,
      anon_sym_do,
    STATE(16876), 2,
      sym_comment,
      sym_block_comment,
  [668950] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21515), 1,
      anon_sym_else,
    STATE(16877), 2,
      sym_comment,
      sym_block_comment,
  [668964] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21517), 1,
      anon_sym_RBRACE,
    STATE(16878), 2,
      sym_comment,
      sym_block_comment,
  [668978] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21519), 1,
      anon_sym_do,
    STATE(16879), 2,
      sym_comment,
      sym_block_comment,
  [668992] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21521), 1,
      anon_sym_else,
    STATE(16880), 2,
      sym_comment,
      sym_block_comment,
  [669006] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21523), 1,
      sym__outdent,
    STATE(16881), 2,
      sym_comment,
      sym_block_comment,
  [669020] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21525), 1,
      anon_sym_RBRACE,
    STATE(16882), 2,
      sym_comment,
      sym_block_comment,
  [669034] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21527), 1,
      anon_sym_RPAREN,
    STATE(16883), 2,
      sym_comment,
      sym_block_comment,
  [669048] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21395), 1,
      anon_sym_RBRACE,
    STATE(16884), 2,
      sym_comment,
      sym_block_comment,
  [669062] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21529), 1,
      anon_sym_else,
    STATE(16885), 2,
      sym_comment,
      sym_block_comment,
  [669076] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21531), 1,
      anon_sym_EQ_GT,
    STATE(16886), 2,
      sym_comment,
      sym_block_comment,
  [669090] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10783), 1,
      anon_sym_DOT,
    STATE(16887), 2,
      sym_comment,
      sym_block_comment,
  [669104] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21533), 1,
      anon_sym_COLON,
    STATE(16888), 2,
      sym_comment,
      sym_block_comment,
  [669118] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21535), 1,
      anon_sym_EQ_GT_GT,
    STATE(16889), 2,
      sym_comment,
      sym_block_comment,
  [669132] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21537), 1,
      anon_sym_EQ_GT_GT,
    STATE(16890), 2,
      sym_comment,
      sym_block_comment,
  [669146] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21539), 1,
      anon_sym_EQ_GT_GT,
    STATE(16891), 2,
      sym_comment,
      sym_block_comment,
  [669160] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21541), 1,
      anon_sym_EQ_GT_GT,
    STATE(16892), 2,
      sym_comment,
      sym_block_comment,
  [669174] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21543), 1,
      sym__outdent,
    STATE(16893), 2,
      sym_comment,
      sym_block_comment,
  [669188] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21545), 1,
      anon_sym_RBRACE,
    STATE(16894), 2,
      sym_comment,
      sym_block_comment,
  [669202] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21547), 1,
      anon_sym_COLON,
    STATE(16895), 2,
      sym_comment,
      sym_block_comment,
  [669216] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8646), 1,
      anon_sym_DOT,
    STATE(16896), 2,
      sym_comment,
      sym_block_comment,
  [669230] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21545), 1,
      anon_sym_RPAREN,
    STATE(16897), 2,
      sym_comment,
      sym_block_comment,
  [669244] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21549), 1,
      anon_sym_RPAREN,
    STATE(16898), 2,
      sym_comment,
      sym_block_comment,
  [669258] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21551), 1,
      anon_sym_RPAREN,
    STATE(16899), 2,
      sym_comment,
      sym_block_comment,
  [669272] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21553), 1,
      anon_sym_RBRACK,
    STATE(16900), 2,
      sym_comment,
      sym_block_comment,
  [669286] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21553), 1,
      anon_sym_RBRACE,
    STATE(16901), 2,
      sym_comment,
      sym_block_comment,
  [669300] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21555), 1,
      anon_sym_RBRACK,
    STATE(16902), 2,
      sym_comment,
      sym_block_comment,
  [669314] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21555), 1,
      anon_sym_RBRACE,
    STATE(16903), 2,
      sym_comment,
      sym_block_comment,
  [669328] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21557), 1,
      anon_sym_EQ_GT_GT,
    STATE(16904), 2,
      sym_comment,
      sym_block_comment,
  [669342] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21559), 1,
      anon_sym_RPAREN,
    STATE(16905), 2,
      sym_comment,
      sym_block_comment,
  [669356] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21559), 1,
      anon_sym_RBRACE,
    STATE(16906), 2,
      sym_comment,
      sym_block_comment,
  [669370] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21561), 1,
      sym__outdent,
    STATE(16907), 2,
      sym_comment,
      sym_block_comment,
  [669384] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21563), 1,
      anon_sym_EQ_GT,
    STATE(16908), 2,
      sym_comment,
      sym_block_comment,
  [669398] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21565), 1,
      anon_sym_EQ_GT_GT,
    STATE(16909), 2,
      sym_comment,
      sym_block_comment,
  [669412] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21567), 1,
      anon_sym_EQ_GT_GT,
    STATE(16910), 2,
      sym_comment,
      sym_block_comment,
  [669426] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21569), 1,
      anon_sym_EQ_GT_GT,
    STATE(16911), 2,
      sym_comment,
      sym_block_comment,
  [669440] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21571), 1,
      anon_sym_EQ_GT_GT,
    STATE(16912), 2,
      sym_comment,
      sym_block_comment,
  [669454] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21573), 1,
      anon_sym_EQ_GT_GT,
    STATE(16913), 2,
      sym_comment,
      sym_block_comment,
  [669468] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21575), 1,
      anon_sym_EQ_GT_GT,
    STATE(16914), 2,
      sym_comment,
      sym_block_comment,
  [669482] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21577), 1,
      anon_sym_RBRACE,
    STATE(16915), 2,
      sym_comment,
      sym_block_comment,
  [669496] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21579), 1,
      anon_sym_EQ_GT_GT,
    STATE(16916), 2,
      sym_comment,
      sym_block_comment,
  [669510] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21071), 1,
      anon_sym_COLON,
    STATE(16917), 2,
      sym_comment,
      sym_block_comment,
  [669524] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9244), 1,
      anon_sym_DOT,
    STATE(16918), 2,
      sym_comment,
      sym_block_comment,
  [669538] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21581), 1,
      sym__outdent,
    STATE(16919), 2,
      sym_comment,
      sym_block_comment,
  [669552] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21583), 1,
      anon_sym_EQ_GT,
    STATE(16920), 2,
      sym_comment,
      sym_block_comment,
  [669566] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21585), 1,
      anon_sym_else,
    STATE(16921), 2,
      sym_comment,
      sym_block_comment,
  [669580] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21587), 1,
      anon_sym_do,
    STATE(16922), 2,
      sym_comment,
      sym_block_comment,
  [669594] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21589), 1,
      anon_sym_RPAREN,
    STATE(16923), 2,
      sym_comment,
      sym_block_comment,
  [669608] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21591), 1,
      anon_sym_RBRACE,
    STATE(16924), 2,
      sym_comment,
      sym_block_comment,
  [669622] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21593), 1,
      sym__outdent,
    STATE(16925), 2,
      sym_comment,
      sym_block_comment,
  [669636] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21595), 1,
      anon_sym_else,
    STATE(16926), 2,
      sym_comment,
      sym_block_comment,
  [669650] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21597), 1,
      sym__outdent,
    STATE(16927), 2,
      sym_comment,
      sym_block_comment,
  [669664] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21599), 1,
      anon_sym_else,
    STATE(16928), 2,
      sym_comment,
      sym_block_comment,
  [669678] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21601), 1,
      anon_sym_RPAREN,
    STATE(16929), 2,
      sym_comment,
      sym_block_comment,
  [669692] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21603), 1,
      anon_sym_EQ_GT,
    STATE(16930), 2,
      sym_comment,
      sym_block_comment,
  [669706] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21605), 1,
      anon_sym_do,
    STATE(16931), 2,
      sym_comment,
      sym_block_comment,
  [669720] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21607), 1,
      anon_sym_else,
    STATE(16932), 2,
      sym_comment,
      sym_block_comment,
  [669734] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21609), 1,
      anon_sym_EQ_GT_GT,
    STATE(16933), 2,
      sym_comment,
      sym_block_comment,
  [669748] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21611), 1,
      anon_sym_EQ_GT_GT,
    STATE(16934), 2,
      sym_comment,
      sym_block_comment,
  [669762] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21613), 1,
      anon_sym_EQ_GT_GT,
    STATE(16935), 2,
      sym_comment,
      sym_block_comment,
  [669776] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21615), 1,
      anon_sym_EQ_GT_GT,
    STATE(16936), 2,
      sym_comment,
      sym_block_comment,
  [669790] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21617), 1,
      anon_sym_RBRACE,
    STATE(16937), 2,
      sym_comment,
      sym_block_comment,
  [669804] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21619), 1,
      sym__outdent,
    STATE(16938), 2,
      sym_comment,
      sym_block_comment,
  [669818] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21621), 1,
      anon_sym_COLON,
    STATE(16939), 2,
      sym_comment,
      sym_block_comment,
  [669832] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10906), 1,
      anon_sym_DOT,
    STATE(16940), 2,
      sym_comment,
      sym_block_comment,
  [669846] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21623), 1,
      sym__outdent,
    STATE(16941), 2,
      sym_comment,
      sym_block_comment,
  [669860] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21625), 1,
      anon_sym_RBRACE,
    STATE(16942), 2,
      sym_comment,
      sym_block_comment,
  [669874] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21625), 1,
      anon_sym_RPAREN,
    STATE(16943), 2,
      sym_comment,
      sym_block_comment,
  [669888] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21627), 1,
      anon_sym_RPAREN,
    STATE(16944), 2,
      sym_comment,
      sym_block_comment,
  [669902] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21629), 1,
      anon_sym_RPAREN,
    STATE(16945), 2,
      sym_comment,
      sym_block_comment,
  [669916] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21631), 1,
      anon_sym_RBRACK,
    STATE(16946), 2,
      sym_comment,
      sym_block_comment,
  [669930] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21631), 1,
      anon_sym_RBRACE,
    STATE(16947), 2,
      sym_comment,
      sym_block_comment,
  [669944] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21633), 1,
      anon_sym_RBRACK,
    STATE(16948), 2,
      sym_comment,
      sym_block_comment,
  [669958] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21633), 1,
      anon_sym_RBRACE,
    STATE(16949), 2,
      sym_comment,
      sym_block_comment,
  [669972] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11569), 1,
      anon_sym_DOT,
    STATE(16950), 2,
      sym_comment,
      sym_block_comment,
  [669986] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21635), 1,
      anon_sym_RPAREN,
    STATE(16951), 2,
      sym_comment,
      sym_block_comment,
  [670000] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21637), 1,
      anon_sym_EQ_GT,
    STATE(16952), 2,
      sym_comment,
      sym_block_comment,
  [670014] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21635), 1,
      anon_sym_RBRACE,
    STATE(16953), 2,
      sym_comment,
      sym_block_comment,
  [670028] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21639), 1,
      sym__outdent,
    STATE(16954), 2,
      sym_comment,
      sym_block_comment,
  [670042] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21641), 1,
      anon_sym_EQ_GT_GT,
    STATE(16955), 2,
      sym_comment,
      sym_block_comment,
  [670056] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21643), 1,
      anon_sym_EQ_GT_GT,
    STATE(16956), 2,
      sym_comment,
      sym_block_comment,
  [670070] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21645), 1,
      anon_sym_EQ_GT_GT,
    STATE(16957), 2,
      sym_comment,
      sym_block_comment,
  [670084] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21647), 1,
      anon_sym_EQ_GT_GT,
    STATE(16958), 2,
      sym_comment,
      sym_block_comment,
  [670098] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21649), 1,
      anon_sym_COLON,
    STATE(16959), 2,
      sym_comment,
      sym_block_comment,
  [670112] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21651), 1,
      sym__outdent,
    STATE(16960), 2,
      sym_comment,
      sym_block_comment,
  [670126] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21653), 1,
      anon_sym_COLON,
    STATE(16961), 2,
      sym_comment,
      sym_block_comment,
  [670140] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10727), 1,
      anon_sym_DOT,
    STATE(16962), 2,
      sym_comment,
      sym_block_comment,
  [670154] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21655), 1,
      anon_sym_RBRACE,
    STATE(16963), 2,
      sym_comment,
      sym_block_comment,
  [670168] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21657), 1,
      anon_sym_else,
    STATE(16964), 2,
      sym_comment,
      sym_block_comment,
  [670182] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21659), 1,
      anon_sym_EQ_GT_GT,
    STATE(16965), 2,
      sym_comment,
      sym_block_comment,
  [670196] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21661), 1,
      anon_sym_EQ_GT_GT,
    STATE(16966), 2,
      sym_comment,
      sym_block_comment,
  [670210] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21663), 1,
      anon_sym_EQ_GT_GT,
    STATE(16967), 2,
      sym_comment,
      sym_block_comment,
  [670224] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21665), 1,
      anon_sym_do,
    STATE(16968), 2,
      sym_comment,
      sym_block_comment,
  [670238] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21667), 1,
      anon_sym_EQ_GT_GT,
    STATE(16969), 2,
      sym_comment,
      sym_block_comment,
  [670252] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21669), 1,
      anon_sym_RBRACE,
    STATE(16970), 2,
      sym_comment,
      sym_block_comment,
  [670266] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21671), 1,
      anon_sym_RBRACE,
    STATE(16971), 2,
      sym_comment,
      sym_block_comment,
  [670280] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21673), 1,
      anon_sym_else,
    STATE(16972), 2,
      sym_comment,
      sym_block_comment,
  [670294] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21675), 1,
      sym__outdent,
    STATE(16973), 2,
      sym_comment,
      sym_block_comment,
  [670308] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21677), 1,
      anon_sym_EQ_GT,
    STATE(16974), 2,
      sym_comment,
      sym_block_comment,
  [670322] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21679), 1,
      anon_sym_RPAREN,
    STATE(16975), 2,
      sym_comment,
      sym_block_comment,
  [670336] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21681), 1,
      anon_sym_RPAREN,
    STATE(16976), 2,
      sym_comment,
      sym_block_comment,
  [670350] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21683), 1,
      anon_sym_EQ_GT_GT,
    STATE(16977), 2,
      sym_comment,
      sym_block_comment,
  [670364] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21685), 1,
      anon_sym_EQ_GT_GT,
    STATE(16978), 2,
      sym_comment,
      sym_block_comment,
  [670378] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21687), 1,
      anon_sym_EQ_GT_GT,
    STATE(16979), 2,
      sym_comment,
      sym_block_comment,
  [670392] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21689), 1,
      anon_sym_EQ_GT_GT,
    STATE(16980), 2,
      sym_comment,
      sym_block_comment,
  [670406] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21691), 1,
      anon_sym_EQ_GT,
    STATE(16981), 2,
      sym_comment,
      sym_block_comment,
  [670420] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21693), 1,
      anon_sym_else,
    STATE(16982), 2,
      sym_comment,
      sym_block_comment,
  [670434] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21695), 1,
      anon_sym_COLON,
    STATE(16983), 2,
      sym_comment,
      sym_block_comment,
  [670448] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10090), 1,
      anon_sym_DOT,
    STATE(16984), 2,
      sym_comment,
      sym_block_comment,
  [670462] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21697), 1,
      sym__outdent,
    STATE(16985), 2,
      sym_comment,
      sym_block_comment,
  [670476] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21699), 1,
      anon_sym_else,
    STATE(16986), 2,
      sym_comment,
      sym_block_comment,
  [670490] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21701), 1,
      sym__outdent,
    STATE(16987), 2,
      sym_comment,
      sym_block_comment,
  [670504] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21703), 1,
      anon_sym_do,
    STATE(16988), 2,
      sym_comment,
      sym_block_comment,
  [670518] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21705), 1,
      anon_sym_RBRACE,
    STATE(16989), 2,
      sym_comment,
      sym_block_comment,
  [670532] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21707), 1,
      anon_sym_RPAREN,
    STATE(16990), 2,
      sym_comment,
      sym_block_comment,
  [670546] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21709), 1,
      sym__outdent,
    STATE(16991), 2,
      sym_comment,
      sym_block_comment,
  [670560] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21711), 1,
      anon_sym_RBRACK,
    STATE(16992), 2,
      sym_comment,
      sym_block_comment,
  [670574] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21711), 1,
      anon_sym_RBRACE,
    STATE(16993), 2,
      sym_comment,
      sym_block_comment,
  [670588] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21713), 1,
      anon_sym_RBRACK,
    STATE(16994), 2,
      sym_comment,
      sym_block_comment,
  [670602] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21713), 1,
      anon_sym_RBRACE,
    STATE(16995), 2,
      sym_comment,
      sym_block_comment,
  [670616] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21715), 1,
      anon_sym_EQ_GT,
    STATE(16996), 2,
      sym_comment,
      sym_block_comment,
  [670630] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21509), 1,
      anon_sym_RBRACE,
    STATE(16997), 2,
      sym_comment,
      sym_block_comment,
  [670644] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21671), 1,
      anon_sym_RPAREN,
    STATE(16998), 2,
      sym_comment,
      sym_block_comment,
  [670658] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21717), 1,
      anon_sym_EQ_GT_GT,
    STATE(16999), 2,
      sym_comment,
      sym_block_comment,
  [670672] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21719), 1,
      anon_sym_EQ_GT_GT,
    STATE(17000), 2,
      sym_comment,
      sym_block_comment,
  [670686] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21721), 1,
      anon_sym_EQ_GT_GT,
    STATE(17001), 2,
      sym_comment,
      sym_block_comment,
  [670700] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21723), 1,
      anon_sym_EQ_GT_GT,
    STATE(17002), 2,
      sym_comment,
      sym_block_comment,
  [670714] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21725), 1,
      anon_sym_RBRACE,
    STATE(17003), 2,
      sym_comment,
      sym_block_comment,
  [670728] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21727), 1,
      sym__outdent,
    STATE(17004), 2,
      sym_comment,
      sym_block_comment,
  [670742] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21729), 1,
      anon_sym_COLON,
    STATE(17005), 2,
      sym_comment,
      sym_block_comment,
  [670756] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11746), 1,
      anon_sym_DOT,
    STATE(17006), 2,
      sym_comment,
      sym_block_comment,
  [670770] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21731), 1,
      anon_sym_RPAREN,
    STATE(17007), 2,
      sym_comment,
      sym_block_comment,
  [670784] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21733), 1,
      sym__outdent,
    STATE(17008), 2,
      sym_comment,
      sym_block_comment,
  [670798] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21735), 1,
      anon_sym_RBRACE,
    STATE(17009), 2,
      sym_comment,
      sym_block_comment,
  [670812] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21737), 1,
      anon_sym_else,
    STATE(17010), 2,
      sym_comment,
      sym_block_comment,
  [670826] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12651), 1,
      anon_sym_DOT,
    STATE(17011), 2,
      sym_comment,
      sym_block_comment,
  [670840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17078), 1,
      anon_sym_COLON,
    STATE(17012), 2,
      sym_comment,
      sym_block_comment,
  [670854] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21739), 1,
      anon_sym_RPAREN,
    STATE(17013), 2,
      sym_comment,
      sym_block_comment,
  [670868] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21741), 1,
      anon_sym_do,
    STATE(17014), 2,
      sym_comment,
      sym_block_comment,
  [670882] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21743), 1,
      sym__outdent,
    STATE(17015), 2,
      sym_comment,
      sym_block_comment,
  [670896] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21745), 1,
      anon_sym_RBRACE,
    STATE(17016), 2,
      sym_comment,
      sym_block_comment,
  [670910] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21747), 1,
      sym__outdent,
    STATE(17017), 2,
      sym_comment,
      sym_block_comment,
  [670924] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21749), 1,
      anon_sym_EQ_GT,
    STATE(17018), 2,
      sym_comment,
      sym_block_comment,
  [670938] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21751), 1,
      anon_sym_else,
    STATE(17019), 2,
      sym_comment,
      sym_block_comment,
  [670952] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21753), 1,
      sym__outdent,
    STATE(17020), 2,
      sym_comment,
      sym_block_comment,
  [670966] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21755), 1,
      anon_sym_EQ_GT_GT,
    STATE(17021), 2,
      sym_comment,
      sym_block_comment,
  [670980] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21757), 1,
      anon_sym_EQ_GT_GT,
    STATE(17022), 2,
      sym_comment,
      sym_block_comment,
  [670994] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21759), 1,
      anon_sym_EQ_GT_GT,
    STATE(17023), 2,
      sym_comment,
      sym_block_comment,
  [671008] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21761), 1,
      anon_sym_EQ_GT_GT,
    STATE(17024), 2,
      sym_comment,
      sym_block_comment,
  [671022] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21763), 1,
      anon_sym_EQ_GT_GT,
    STATE(17025), 2,
      sym_comment,
      sym_block_comment,
  [671036] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21765), 1,
      anon_sym_RPAREN,
    STATE(17026), 2,
      sym_comment,
      sym_block_comment,
  [671050] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21767), 1,
      anon_sym_COLON,
    STATE(17027), 2,
      sym_comment,
      sym_block_comment,
  [671064] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11459), 1,
      anon_sym_DOT,
    STATE(17028), 2,
      sym_comment,
      sym_block_comment,
  [671078] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21769), 1,
      anon_sym_EQ_GT_GT,
    STATE(17029), 2,
      sym_comment,
      sym_block_comment,
  [671092] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21771), 1,
      anon_sym_else,
    STATE(17030), 2,
      sym_comment,
      sym_block_comment,
  [671106] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21773), 1,
      anon_sym_EQ_GT_GT,
    STATE(17031), 2,
      sym_comment,
      sym_block_comment,
  [671120] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21775), 1,
      anon_sym_EQ_GT_GT,
    STATE(17032), 2,
      sym_comment,
      sym_block_comment,
  [671134] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21777), 1,
      sym__outdent,
    STATE(17033), 2,
      sym_comment,
      sym_block_comment,
  [671148] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21779), 1,
      anon_sym_do,
    STATE(17034), 2,
      sym_comment,
      sym_block_comment,
  [671162] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21781), 1,
      anon_sym_EQ_GT,
    STATE(17035), 2,
      sym_comment,
      sym_block_comment,
  [671176] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21783), 1,
      anon_sym_RPAREN,
    STATE(17036), 2,
      sym_comment,
      sym_block_comment,
  [671190] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21785), 1,
      anon_sym_else,
    STATE(17037), 2,
      sym_comment,
      sym_block_comment,
  [671204] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21787), 1,
      anon_sym_RBRACK,
    STATE(17038), 2,
      sym_comment,
      sym_block_comment,
  [671218] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21787), 1,
      anon_sym_RBRACE,
    STATE(17039), 2,
      sym_comment,
      sym_block_comment,
  [671232] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21789), 1,
      anon_sym_EQ_GT,
    STATE(17040), 2,
      sym_comment,
      sym_block_comment,
  [671246] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21791), 1,
      anon_sym_RBRACK,
    STATE(17041), 2,
      sym_comment,
      sym_block_comment,
  [671260] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21791), 1,
      anon_sym_RBRACE,
    STATE(17042), 2,
      sym_comment,
      sym_block_comment,
  [671274] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21793), 1,
      anon_sym_EQ_GT_GT,
    STATE(17043), 2,
      sym_comment,
      sym_block_comment,
  [671288] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21795), 1,
      anon_sym_EQ_GT_GT,
    STATE(17044), 2,
      sym_comment,
      sym_block_comment,
  [671302] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21797), 1,
      anon_sym_EQ_GT_GT,
    STATE(17045), 2,
      sym_comment,
      sym_block_comment,
  [671316] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21799), 1,
      anon_sym_EQ_GT_GT,
    STATE(17046), 2,
      sym_comment,
      sym_block_comment,
  [671330] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21801), 1,
      anon_sym_RBRACE,
    STATE(17047), 2,
      sym_comment,
      sym_block_comment,
  [671344] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21803), 1,
      anon_sym_RPAREN,
    STATE(17048), 2,
      sym_comment,
      sym_block_comment,
  [671358] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21805), 1,
      anon_sym_COLON,
    STATE(17049), 2,
      sym_comment,
      sym_block_comment,
  [671372] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11392), 1,
      anon_sym_DOT,
    STATE(17050), 2,
      sym_comment,
      sym_block_comment,
  [671386] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21803), 1,
      anon_sym_RBRACE,
    STATE(17051), 2,
      sym_comment,
      sym_block_comment,
  [671400] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21807), 1,
      sym__outdent,
    STATE(17052), 2,
      sym_comment,
      sym_block_comment,
  [671414] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21809), 1,
      sym__outdent,
    STATE(17053), 2,
      sym_comment,
      sym_block_comment,
  [671428] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9054), 1,
      anon_sym_DOT,
    STATE(17054), 2,
      sym_comment,
      sym_block_comment,
  [671442] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21811), 1,
      anon_sym_RBRACE,
    STATE(17055), 2,
      sym_comment,
      sym_block_comment,
  [671456] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21725), 1,
      anon_sym_RPAREN,
    STATE(17056), 2,
      sym_comment,
      sym_block_comment,
  [671470] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21813), 1,
      anon_sym_RPAREN,
    STATE(17057), 2,
      sym_comment,
      sym_block_comment,
  [671484] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21815), 1,
      sym__outdent,
    STATE(17058), 2,
      sym_comment,
      sym_block_comment,
  [671498] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21817), 1,
      anon_sym_else,
    STATE(17059), 2,
      sym_comment,
      sym_block_comment,
  [671512] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21819), 1,
      anon_sym_do,
    STATE(17060), 2,
      sym_comment,
      sym_block_comment,
  [671526] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21821), 1,
      sym__outdent,
    STATE(17061), 2,
      sym_comment,
      sym_block_comment,
  [671540] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21823), 1,
      anon_sym_EQ_GT,
    STATE(17062), 2,
      sym_comment,
      sym_block_comment,
  [671554] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21825), 1,
      anon_sym_RBRACE,
    STATE(17063), 2,
      sym_comment,
      sym_block_comment,
  [671568] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21827), 1,
      anon_sym_EQ_GT_GT,
    STATE(17064), 2,
      sym_comment,
      sym_block_comment,
  [671582] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21829), 1,
      anon_sym_EQ_GT_GT,
    STATE(17065), 2,
      sym_comment,
      sym_block_comment,
  [671596] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21831), 1,
      anon_sym_EQ_GT_GT,
    STATE(17066), 2,
      sym_comment,
      sym_block_comment,
  [671610] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21833), 1,
      anon_sym_EQ_GT_GT,
    STATE(17067), 2,
      sym_comment,
      sym_block_comment,
  [671624] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21835), 1,
      anon_sym_RPAREN,
    STATE(17068), 2,
      sym_comment,
      sym_block_comment,
  [671638] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21837), 1,
      anon_sym_else,
    STATE(17069), 2,
      sym_comment,
      sym_block_comment,
  [671652] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21839), 1,
      anon_sym_COLON,
    STATE(17070), 2,
      sym_comment,
      sym_block_comment,
  [671666] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10434), 1,
      anon_sym_DOT,
    STATE(17071), 2,
      sym_comment,
      sym_block_comment,
  [671680] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21841), 1,
      sym__outdent,
    STATE(17072), 2,
      sym_comment,
      sym_block_comment,
  [671694] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21843), 1,
      sym__outdent,
    STATE(17073), 2,
      sym_comment,
      sym_block_comment,
  [671708] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21845), 1,
      anon_sym_RPAREN,
    STATE(17074), 2,
      sym_comment,
      sym_block_comment,
  [671722] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21847), 1,
      anon_sym_else,
    STATE(17075), 2,
      sym_comment,
      sym_block_comment,
  [671736] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21849), 1,
      anon_sym_else,
    STATE(17076), 2,
      sym_comment,
      sym_block_comment,
  [671750] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12824), 1,
      anon_sym_DOT,
    STATE(17077), 2,
      sym_comment,
      sym_block_comment,
  [671764] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21851), 1,
      anon_sym_COLON,
    STATE(17078), 2,
      sym_comment,
      sym_block_comment,
  [671778] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21853), 1,
      sym__outdent,
    STATE(17079), 2,
      sym_comment,
      sym_block_comment,
  [671792] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21855), 1,
      anon_sym_do,
    STATE(17080), 2,
      sym_comment,
      sym_block_comment,
  [671806] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21857), 1,
      anon_sym_EQ_GT_GT,
    STATE(17081), 2,
      sym_comment,
      sym_block_comment,
  [671820] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21859), 1,
      anon_sym_RPAREN,
    STATE(17082), 2,
      sym_comment,
      sym_block_comment,
  [671834] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21861), 1,
      anon_sym_EQ_GT,
    STATE(17083), 2,
      sym_comment,
      sym_block_comment,
  [671848] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21863), 1,
      anon_sym_EQ_GT_GT,
    STATE(17084), 2,
      sym_comment,
      sym_block_comment,
  [671862] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21865), 1,
      anon_sym_EQ_GT_GT,
    STATE(17085), 2,
      sym_comment,
      sym_block_comment,
  [671876] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21867), 1,
      anon_sym_EQ_GT_GT,
    STATE(17086), 2,
      sym_comment,
      sym_block_comment,
  [671890] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21869), 1,
      anon_sym_EQ_GT_GT,
    STATE(17087), 2,
      sym_comment,
      sym_block_comment,
  [671904] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21871), 1,
      anon_sym_EQ_GT_GT,
    STATE(17088), 2,
      sym_comment,
      sym_block_comment,
  [671918] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21873), 1,
      anon_sym_EQ_GT_GT,
    STATE(17089), 2,
      sym_comment,
      sym_block_comment,
  [671932] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21875), 1,
      anon_sym_RBRACK,
    STATE(17090), 2,
      sym_comment,
      sym_block_comment,
  [671946] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21877), 1,
      anon_sym_COLON,
    STATE(17091), 2,
      sym_comment,
      sym_block_comment,
  [671960] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9624), 1,
      anon_sym_DOT,
    STATE(17092), 2,
      sym_comment,
      sym_block_comment,
  [671974] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21875), 1,
      anon_sym_RBRACE,
    STATE(17093), 2,
      sym_comment,
      sym_block_comment,
  [671988] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21879), 1,
      anon_sym_RBRACK,
    STATE(17094), 2,
      sym_comment,
      sym_block_comment,
  [672002] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21879), 1,
      anon_sym_RBRACE,
    STATE(17095), 2,
      sym_comment,
      sym_block_comment,
  [672016] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21881), 1,
      anon_sym_EQ_GT_GT,
    STATE(17096), 2,
      sym_comment,
      sym_block_comment,
  [672030] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21883), 1,
      anon_sym_RPAREN,
    STATE(17097), 2,
      sym_comment,
      sym_block_comment,
  [672044] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21883), 1,
      anon_sym_RBRACE,
    STATE(17098), 2,
      sym_comment,
      sym_block_comment,
  [672058] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21885), 1,
      sym__outdent,
    STATE(17099), 2,
      sym_comment,
      sym_block_comment,
  [672072] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21887), 1,
      anon_sym_RBRACE,
    STATE(17100), 2,
      sym_comment,
      sym_block_comment,
  [672086] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21889), 1,
      anon_sym_EQ_GT,
    STATE(17101), 2,
      sym_comment,
      sym_block_comment,
  [672100] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21891), 1,
      anon_sym_RBRACE,
    STATE(17102), 2,
      sym_comment,
      sym_block_comment,
  [672114] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21893), 1,
      sym__outdent,
    STATE(17103), 2,
      sym_comment,
      sym_block_comment,
  [672128] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21895), 1,
      anon_sym_EQ_GT,
    STATE(17104), 2,
      sym_comment,
      sym_block_comment,
  [672142] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21897), 1,
      anon_sym_RBRACE,
    STATE(17105), 2,
      sym_comment,
      sym_block_comment,
  [672156] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21899), 1,
      anon_sym_EQ_GT_GT,
    STATE(17106), 2,
      sym_comment,
      sym_block_comment,
  [672170] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21901), 1,
      anon_sym_EQ_GT_GT,
    STATE(17107), 2,
      sym_comment,
      sym_block_comment,
  [672184] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21903), 1,
      anon_sym_EQ_GT_GT,
    STATE(17108), 2,
      sym_comment,
      sym_block_comment,
  [672198] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21905), 1,
      anon_sym_EQ_GT_GT,
    STATE(17109), 2,
      sym_comment,
      sym_block_comment,
  [672212] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21897), 1,
      anon_sym_RPAREN,
    STATE(17110), 2,
      sym_comment,
      sym_block_comment,
  [672226] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21907), 1,
      anon_sym_RPAREN,
    STATE(17111), 2,
      sym_comment,
      sym_block_comment,
  [672240] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21909), 1,
      anon_sym_COLON,
    STATE(17112), 2,
      sym_comment,
      sym_block_comment,
  [672254] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10444), 1,
      anon_sym_DOT,
    STATE(17113), 2,
      sym_comment,
      sym_block_comment,
  [672268] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21911), 1,
      anon_sym_do,
    STATE(17114), 2,
      sym_comment,
      sym_block_comment,
  [672282] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21913), 1,
      sym__outdent,
    STATE(17115), 2,
      sym_comment,
      sym_block_comment,
  [672296] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21915), 1,
      anon_sym_RBRACE,
    STATE(17116), 2,
      sym_comment,
      sym_block_comment,
  [672310] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21917), 1,
      anon_sym_else,
    STATE(17117), 2,
      sym_comment,
      sym_block_comment,
  [672324] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21919), 1,
      anon_sym_else,
    STATE(17118), 2,
      sym_comment,
      sym_block_comment,
  [672338] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21921), 1,
      sym__outdent,
    STATE(17119), 2,
      sym_comment,
      sym_block_comment,
  [672352] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21923), 1,
      anon_sym_RPAREN,
    STATE(17120), 2,
      sym_comment,
      sym_block_comment,
  [672366] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21925), 1,
      anon_sym_RPAREN,
    STATE(17121), 2,
      sym_comment,
      sym_block_comment,
  [672380] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21927), 1,
      sym__outdent,
    STATE(17122), 2,
      sym_comment,
      sym_block_comment,
  [672394] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21929), 1,
      anon_sym_else,
    STATE(17123), 2,
      sym_comment,
      sym_block_comment,
  [672408] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21931), 1,
      anon_sym_else,
    STATE(17124), 2,
      sym_comment,
      sym_block_comment,
  [672422] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21933), 1,
      anon_sym_EQ_GT,
    STATE(17125), 2,
      sym_comment,
      sym_block_comment,
  [672436] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21935), 1,
      anon_sym_do,
    STATE(17126), 2,
      sym_comment,
      sym_block_comment,
  [672450] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21937), 1,
      anon_sym_EQ_GT_GT,
    STATE(17127), 2,
      sym_comment,
      sym_block_comment,
  [672464] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21939), 1,
      anon_sym_EQ_GT_GT,
    STATE(17128), 2,
      sym_comment,
      sym_block_comment,
  [672478] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21941), 1,
      anon_sym_EQ_GT_GT,
    STATE(17129), 2,
      sym_comment,
      sym_block_comment,
  [672492] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21943), 1,
      anon_sym_EQ_GT_GT,
    STATE(17130), 2,
      sym_comment,
      sym_block_comment,
  [672506] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21945), 1,
      anon_sym_RBRACK,
    STATE(17131), 2,
      sym_comment,
      sym_block_comment,
  [672520] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21947), 1,
      anon_sym_RPAREN,
    STATE(17132), 2,
      sym_comment,
      sym_block_comment,
  [672534] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21949), 1,
      anon_sym_COLON,
    STATE(17133), 2,
      sym_comment,
      sym_block_comment,
  [672548] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10760), 1,
      anon_sym_DOT,
    STATE(17134), 2,
      sym_comment,
      sym_block_comment,
  [672562] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21951), 1,
      anon_sym_COLON,
    STATE(17135), 2,
      sym_comment,
      sym_block_comment,
  [672576] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21953), 1,
      anon_sym_RPAREN,
    STATE(17136), 2,
      sym_comment,
      sym_block_comment,
  [672590] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21955), 1,
      anon_sym_RBRACE,
    STATE(17137), 2,
      sym_comment,
      sym_block_comment,
  [672604] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21957), 1,
      sym__outdent,
    STATE(17138), 2,
      sym_comment,
      sym_block_comment,
  [672618] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21959), 1,
      anon_sym_RBRACK,
    STATE(17139), 2,
      sym_comment,
      sym_block_comment,
  [672632] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21959), 1,
      anon_sym_RBRACE,
    STATE(17140), 2,
      sym_comment,
      sym_block_comment,
  [672646] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21961), 1,
      anon_sym_else,
    STATE(17141), 2,
      sym_comment,
      sym_block_comment,
  [672660] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21945), 1,
      anon_sym_RBRACE,
    STATE(17142), 2,
      sym_comment,
      sym_block_comment,
  [672674] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21963), 1,
      anon_sym_RBRACE,
    STATE(17143), 2,
      sym_comment,
      sym_block_comment,
  [672688] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21965), 1,
      anon_sym_RPAREN,
    STATE(17144), 2,
      sym_comment,
      sym_block_comment,
  [672702] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21965), 1,
      anon_sym_RBRACE,
    STATE(17145), 2,
      sym_comment,
      sym_block_comment,
  [672716] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21967), 1,
      anon_sym_EQ_GT,
    STATE(17146), 2,
      sym_comment,
      sym_block_comment,
  [672730] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21969), 1,
      sym__outdent,
    STATE(17147), 2,
      sym_comment,
      sym_block_comment,
  [672744] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21971), 1,
      anon_sym_EQ_GT_GT,
    STATE(17148), 2,
      sym_comment,
      sym_block_comment,
  [672758] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21973), 1,
      anon_sym_EQ_GT_GT,
    STATE(17149), 2,
      sym_comment,
      sym_block_comment,
  [672772] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21975), 1,
      anon_sym_EQ_GT_GT,
    STATE(17150), 2,
      sym_comment,
      sym_block_comment,
  [672786] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21977), 1,
      anon_sym_EQ_GT_GT,
    STATE(17151), 2,
      sym_comment,
      sym_block_comment,
  [672800] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21979), 1,
      anon_sym_EQ_GT_GT,
    STATE(17152), 2,
      sym_comment,
      sym_block_comment,
  [672814] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21981), 1,
      anon_sym_EQ_GT_GT,
    STATE(17153), 2,
      sym_comment,
      sym_block_comment,
  [672828] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21983), 1,
      anon_sym_COLON,
    STATE(17154), 2,
      sym_comment,
      sym_block_comment,
  [672842] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11246), 1,
      anon_sym_DOT,
    STATE(17155), 2,
      sym_comment,
      sym_block_comment,
  [672856] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21985), 1,
      anon_sym_RBRACE,
    STATE(17156), 2,
      sym_comment,
      sym_block_comment,
  [672870] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21987), 1,
      anon_sym_EQ_GT_GT,
    STATE(17157), 2,
      sym_comment,
      sym_block_comment,
  [672884] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21989), 1,
      anon_sym_EQ_GT_GT,
    STATE(17158), 2,
      sym_comment,
      sym_block_comment,
  [672898] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21963), 1,
      anon_sym_RPAREN,
    STATE(17159), 2,
      sym_comment,
      sym_block_comment,
  [672912] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21991), 1,
      anon_sym_EQ_GT,
    STATE(17160), 2,
      sym_comment,
      sym_block_comment,
  [672926] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21993), 1,
      anon_sym_do,
    STATE(17161), 2,
      sym_comment,
      sym_block_comment,
  [672940] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21995), 1,
      anon_sym_RPAREN,
    STATE(17162), 2,
      sym_comment,
      sym_block_comment,
  [672954] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21997), 1,
      anon_sym_RBRACE,
    STATE(17163), 2,
      sym_comment,
      sym_block_comment,
  [672968] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21999), 1,
      sym__outdent,
    STATE(17164), 2,
      sym_comment,
      sym_block_comment,
  [672982] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22001), 1,
      anon_sym_else,
    STATE(17165), 2,
      sym_comment,
      sym_block_comment,
  [672996] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22003), 1,
      sym__outdent,
    STATE(17166), 2,
      sym_comment,
      sym_block_comment,
  [673010] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22005), 1,
      anon_sym_EQ_GT,
    STATE(17167), 2,
      sym_comment,
      sym_block_comment,
  [673024] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22007), 1,
      anon_sym_else,
    STATE(17168), 2,
      sym_comment,
      sym_block_comment,
  [673038] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22009), 1,
      anon_sym_EQ_GT_GT,
    STATE(17169), 2,
      sym_comment,
      sym_block_comment,
  [673052] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22011), 1,
      anon_sym_EQ_GT_GT,
    STATE(17170), 2,
      sym_comment,
      sym_block_comment,
  [673066] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22013), 1,
      anon_sym_EQ_GT_GT,
    STATE(17171), 2,
      sym_comment,
      sym_block_comment,
  [673080] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22015), 1,
      anon_sym_EQ_GT_GT,
    STATE(17172), 2,
      sym_comment,
      sym_block_comment,
  [673094] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22017), 1,
      anon_sym_RPAREN,
    STATE(17173), 2,
      sym_comment,
      sym_block_comment,
  [673108] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22019), 1,
      anon_sym_RPAREN,
    STATE(17174), 2,
      sym_comment,
      sym_block_comment,
  [673122] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22021), 1,
      anon_sym_COLON,
    STATE(17175), 2,
      sym_comment,
      sym_block_comment,
  [673136] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10958), 1,
      anon_sym_DOT,
    STATE(17176), 2,
      sym_comment,
      sym_block_comment,
  [673150] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22023), 1,
      anon_sym_else,
    STATE(17177), 2,
      sym_comment,
      sym_block_comment,
  [673164] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22025), 1,
      sym__outdent,
    STATE(17178), 2,
      sym_comment,
      sym_block_comment,
  [673178] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22027), 1,
      anon_sym_else,
    STATE(17179), 2,
      sym_comment,
      sym_block_comment,
  [673192] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22029), 1,
      sym__outdent,
    STATE(17180), 2,
      sym_comment,
      sym_block_comment,
  [673206] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22031), 1,
      anon_sym_do,
    STATE(17181), 2,
      sym_comment,
      sym_block_comment,
  [673220] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22033), 1,
      anon_sym_RBRACE,
    STATE(17182), 2,
      sym_comment,
      sym_block_comment,
  [673234] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22035), 1,
      anon_sym_RPAREN,
    STATE(17183), 2,
      sym_comment,
      sym_block_comment,
  [673248] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22037), 1,
      sym__outdent,
    STATE(17184), 2,
      sym_comment,
      sym_block_comment,
  [673262] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22039), 1,
      anon_sym_RBRACE,
    STATE(17185), 2,
      sym_comment,
      sym_block_comment,
  [673276] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22041), 1,
      anon_sym_RBRACK,
    STATE(17186), 2,
      sym_comment,
      sym_block_comment,
  [673290] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22041), 1,
      anon_sym_RBRACE,
    STATE(17187), 2,
      sym_comment,
      sym_block_comment,
  [673304] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22043), 1,
      anon_sym_EQ_GT,
    STATE(17188), 2,
      sym_comment,
      sym_block_comment,
  [673318] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22045), 1,
      anon_sym_RBRACK,
    STATE(17189), 2,
      sym_comment,
      sym_block_comment,
  [673332] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22047), 1,
      anon_sym_EQ_GT_GT,
    STATE(17190), 2,
      sym_comment,
      sym_block_comment,
  [673346] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22049), 1,
      anon_sym_EQ_GT_GT,
    STATE(17191), 2,
      sym_comment,
      sym_block_comment,
  [673360] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22051), 1,
      anon_sym_EQ_GT_GT,
    STATE(17192), 2,
      sym_comment,
      sym_block_comment,
  [673374] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22053), 1,
      anon_sym_EQ_GT_GT,
    STATE(17193), 2,
      sym_comment,
      sym_block_comment,
  [673388] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22045), 1,
      anon_sym_RBRACE,
    STATE(17194), 2,
      sym_comment,
      sym_block_comment,
  [673402] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9210), 1,
      anon_sym_DOT,
    STATE(17195), 2,
      sym_comment,
      sym_block_comment,
  [673416] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22055), 1,
      anon_sym_COLON,
    STATE(17196), 2,
      sym_comment,
      sym_block_comment,
  [673430] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11619), 1,
      anon_sym_DOT,
    STATE(17197), 2,
      sym_comment,
      sym_block_comment,
  [673444] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22057), 1,
      anon_sym_RPAREN,
    STATE(17198), 2,
      sym_comment,
      sym_block_comment,
  [673458] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22057), 1,
      anon_sym_RBRACE,
    STATE(17199), 2,
      sym_comment,
      sym_block_comment,
  [673472] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22059), 1,
      sym__outdent,
    STATE(17200), 2,
      sym_comment,
      sym_block_comment,
  [673486] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22061), 1,
      anon_sym_COLON,
    STATE(17201), 2,
      sym_comment,
      sym_block_comment,
  [673500] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22039), 1,
      anon_sym_RPAREN,
    STATE(17202), 2,
      sym_comment,
      sym_block_comment,
  [673514] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22063), 1,
      anon_sym_RBRACE,
    STATE(17203), 2,
      sym_comment,
      sym_block_comment,
  [673528] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22065), 1,
      anon_sym_RPAREN,
    STATE(17204), 2,
      sym_comment,
      sym_block_comment,
  [673542] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22067), 1,
      sym__outdent,
    STATE(17205), 2,
      sym_comment,
      sym_block_comment,
  [673556] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22069), 1,
      anon_sym_EQ_GT_GT,
    STATE(17206), 2,
      sym_comment,
      sym_block_comment,
  [673570] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22071), 1,
      anon_sym_EQ_GT_GT,
    STATE(17207), 2,
      sym_comment,
      sym_block_comment,
  [673584] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22073), 1,
      anon_sym_do,
    STATE(17208), 2,
      sym_comment,
      sym_block_comment,
  [673598] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22075), 1,
      anon_sym_EQ_GT,
    STATE(17209), 2,
      sym_comment,
      sym_block_comment,
  [673612] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22077), 1,
      anon_sym_EQ_GT_GT,
    STATE(17210), 2,
      sym_comment,
      sym_block_comment,
  [673626] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22079), 1,
      anon_sym_EQ_GT_GT,
    STATE(17211), 2,
      sym_comment,
      sym_block_comment,
  [673640] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22081), 1,
      anon_sym_EQ_GT_GT,
    STATE(17212), 2,
      sym_comment,
      sym_block_comment,
  [673654] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22083), 1,
      anon_sym_EQ_GT_GT,
    STATE(17213), 2,
      sym_comment,
      sym_block_comment,
  [673668] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22085), 1,
      anon_sym_EQ_GT_GT,
    STATE(17214), 2,
      sym_comment,
      sym_block_comment,
  [673682] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22087), 1,
      anon_sym_RBRACE,
    STATE(17215), 2,
      sym_comment,
      sym_block_comment,
  [673696] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22089), 1,
      anon_sym_EQ_GT_GT,
    STATE(17216), 2,
      sym_comment,
      sym_block_comment,
  [673710] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22091), 1,
      anon_sym_COLON,
    STATE(17217), 2,
      sym_comment,
      sym_block_comment,
  [673724] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11147), 1,
      anon_sym_DOT,
    STATE(17218), 2,
      sym_comment,
      sym_block_comment,
  [673738] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22093), 1,
      anon_sym_else,
    STATE(17219), 2,
      sym_comment,
      sym_block_comment,
  [673752] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22095), 1,
      sym__outdent,
    STATE(17220), 2,
      sym_comment,
      sym_block_comment,
  [673766] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22097), 1,
      anon_sym_EQ_GT,
    STATE(17221), 2,
      sym_comment,
      sym_block_comment,
  [673780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22099), 1,
      anon_sym_RPAREN,
    STATE(17222), 2,
      sym_comment,
      sym_block_comment,
  [673794] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22101), 1,
      anon_sym_RPAREN,
    STATE(17223), 2,
      sym_comment,
      sym_block_comment,
  [673808] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22103), 1,
      anon_sym_else,
    STATE(17224), 2,
      sym_comment,
      sym_block_comment,
  [673822] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22105), 1,
      sym__outdent,
    STATE(17225), 2,
      sym_comment,
      sym_block_comment,
  [673836] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22107), 1,
      anon_sym_else,
    STATE(17226), 2,
      sym_comment,
      sym_block_comment,
  [673850] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22109), 1,
      sym__outdent,
    STATE(17227), 2,
      sym_comment,
      sym_block_comment,
  [673864] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22111), 1,
      anon_sym_do,
    STATE(17228), 2,
      sym_comment,
      sym_block_comment,
  [673878] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22113), 1,
      anon_sym_RBRACE,
    STATE(17229), 2,
      sym_comment,
      sym_block_comment,
  [673892] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22115), 1,
      anon_sym_EQ_GT,
    STATE(17230), 2,
      sym_comment,
      sym_block_comment,
  [673906] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22117), 1,
      anon_sym_RPAREN,
    STATE(17231), 2,
      sym_comment,
      sym_block_comment,
  [673920] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22119), 1,
      anon_sym_EQ_GT_GT,
    STATE(17232), 2,
      sym_comment,
      sym_block_comment,
  [673934] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22121), 1,
      anon_sym_EQ_GT_GT,
    STATE(17233), 2,
      sym_comment,
      sym_block_comment,
  [673948] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22123), 1,
      anon_sym_EQ_GT_GT,
    STATE(17234), 2,
      sym_comment,
      sym_block_comment,
  [673962] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22125), 1,
      anon_sym_EQ_GT_GT,
    STATE(17235), 2,
      sym_comment,
      sym_block_comment,
  [673976] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22127), 1,
      sym__outdent,
    STATE(17236), 2,
      sym_comment,
      sym_block_comment,
  [673990] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22129), 1,
      anon_sym_RBRACE,
    STATE(17237), 2,
      sym_comment,
      sym_block_comment,
  [674004] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22131), 1,
      anon_sym_COLON,
    STATE(17238), 2,
      sym_comment,
      sym_block_comment,
  [674018] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12772), 1,
      anon_sym_DOT,
    STATE(17239), 2,
      sym_comment,
      sym_block_comment,
  [674032] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22133), 1,
      anon_sym_RBRACK,
    STATE(17240), 2,
      sym_comment,
      sym_block_comment,
  [674046] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22133), 1,
      anon_sym_RBRACE,
    STATE(17241), 2,
      sym_comment,
      sym_block_comment,
  [674060] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22135), 1,
      anon_sym_RBRACK,
    STATE(17242), 2,
      sym_comment,
      sym_block_comment,
  [674074] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22135), 1,
      anon_sym_RBRACE,
    STATE(17243), 2,
      sym_comment,
      sym_block_comment,
  [674088] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22129), 1,
      anon_sym_RPAREN,
    STATE(17244), 2,
      sym_comment,
      sym_block_comment,
  [674102] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22137), 1,
      anon_sym_RPAREN,
    STATE(17245), 2,
      sym_comment,
      sym_block_comment,
  [674116] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22137), 1,
      anon_sym_RBRACE,
    STATE(17246), 2,
      sym_comment,
      sym_block_comment,
  [674130] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22139), 1,
      sym__outdent,
    STATE(17247), 2,
      sym_comment,
      sym_block_comment,
  [674144] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22141), 1,
      anon_sym_RPAREN,
    STATE(17248), 2,
      sym_comment,
      sym_block_comment,
  [674158] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11043), 1,
      anon_sym_DOT,
    STATE(17249), 2,
      sym_comment,
      sym_block_comment,
  [674172] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22143), 1,
      anon_sym_RBRACE,
    STATE(17250), 2,
      sym_comment,
      sym_block_comment,
  [674186] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22145), 1,
      anon_sym_EQ_GT,
    STATE(17251), 2,
      sym_comment,
      sym_block_comment,
  [674200] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22147), 1,
      anon_sym_COLON,
    STATE(17252), 2,
      sym_comment,
      sym_block_comment,
  [674214] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22149), 1,
      anon_sym_EQ_GT_GT,
    STATE(17253), 2,
      sym_comment,
      sym_block_comment,
  [674228] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22151), 1,
      anon_sym_EQ_GT_GT,
    STATE(17254), 2,
      sym_comment,
      sym_block_comment,
  [674242] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22153), 1,
      anon_sym_EQ_GT_GT,
    STATE(17255), 2,
      sym_comment,
      sym_block_comment,
  [674256] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22155), 1,
      anon_sym_EQ_GT_GT,
    STATE(17256), 2,
      sym_comment,
      sym_block_comment,
  [674270] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22157), 1,
      anon_sym_else,
    STATE(17257), 2,
      sym_comment,
      sym_block_comment,
  [674284] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22159), 1,
      anon_sym_do,
    STATE(17258), 2,
      sym_comment,
      sym_block_comment,
  [674298] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22161), 1,
      anon_sym_COLON,
    STATE(17259), 2,
      sym_comment,
      sym_block_comment,
  [674312] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12339), 1,
      anon_sym_DOT,
    STATE(17260), 2,
      sym_comment,
      sym_block_comment,
  [674326] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22163), 1,
      anon_sym_EQ_GT_GT,
    STATE(17261), 2,
      sym_comment,
      sym_block_comment,
  [674340] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22165), 1,
      anon_sym_do,
    STATE(17262), 2,
      sym_comment,
      sym_block_comment,
  [674354] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22167), 1,
      anon_sym_EQ_GT_GT,
    STATE(17263), 2,
      sym_comment,
      sym_block_comment,
  [674368] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22169), 1,
      anon_sym_RBRACE,
    STATE(17264), 2,
      sym_comment,
      sym_block_comment,
  [674382] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22171), 1,
      anon_sym_EQ_GT_GT,
    STATE(17265), 2,
      sym_comment,
      sym_block_comment,
  [674396] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22173), 1,
      anon_sym_else,
    STATE(17266), 2,
      sym_comment,
      sym_block_comment,
  [674410] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22175), 1,
      sym__outdent,
    STATE(17267), 2,
      sym_comment,
      sym_block_comment,
  [674424] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22177), 1,
      anon_sym_EQ_GT_GT,
    STATE(17268), 2,
      sym_comment,
      sym_block_comment,
  [674438] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22179), 1,
      anon_sym_RPAREN,
    STATE(17269), 2,
      sym_comment,
      sym_block_comment,
  [674452] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22181), 1,
      sym__outdent,
    STATE(17270), 2,
      sym_comment,
      sym_block_comment,
  [674466] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22183), 1,
      anon_sym_else,
    STATE(17271), 2,
      sym_comment,
      sym_block_comment,
  [674480] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22185), 1,
      anon_sym_EQ_GT,
    STATE(17272), 2,
      sym_comment,
      sym_block_comment,
  [674494] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22187), 1,
      anon_sym_EQ_GT,
    STATE(17273), 2,
      sym_comment,
      sym_block_comment,
  [674508] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22189), 1,
      anon_sym_EQ_GT_GT,
    STATE(17274), 2,
      sym_comment,
      sym_block_comment,
  [674522] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22191), 1,
      anon_sym_EQ_GT_GT,
    STATE(17275), 2,
      sym_comment,
      sym_block_comment,
  [674536] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22193), 1,
      anon_sym_EQ_GT_GT,
    STATE(17276), 2,
      sym_comment,
      sym_block_comment,
  [674550] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22195), 1,
      anon_sym_EQ_GT_GT,
    STATE(17277), 2,
      sym_comment,
      sym_block_comment,
  [674564] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22197), 1,
      anon_sym_else,
    STATE(17278), 2,
      sym_comment,
      sym_block_comment,
  [674578] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22199), 1,
      sym__outdent,
    STATE(17279), 2,
      sym_comment,
      sym_block_comment,
  [674592] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22201), 1,
      anon_sym_COLON,
    STATE(17280), 2,
      sym_comment,
      sym_block_comment,
  [674606] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8779), 1,
      anon_sym_DOT,
    STATE(17281), 2,
      sym_comment,
      sym_block_comment,
  [674620] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22203), 1,
      sym__outdent,
    STATE(17282), 2,
      sym_comment,
      sym_block_comment,
  [674634] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22205), 1,
      anon_sym_RBRACE,
    STATE(17283), 2,
      sym_comment,
      sym_block_comment,
  [674648] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22207), 1,
      anon_sym_RPAREN,
    STATE(17284), 2,
      sym_comment,
      sym_block_comment,
  [674662] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22209), 1,
      sym__outdent,
    STATE(17285), 2,
      sym_comment,
      sym_block_comment,
  [674676] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22211), 1,
      anon_sym_RBRACE,
    STATE(17286), 2,
      sym_comment,
      sym_block_comment,
  [674690] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22213), 1,
      anon_sym_RBRACK,
    STATE(17287), 2,
      sym_comment,
      sym_block_comment,
  [674704] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22213), 1,
      anon_sym_RBRACE,
    STATE(17288), 2,
      sym_comment,
      sym_block_comment,
  [674718] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22215), 1,
      anon_sym_RBRACK,
    STATE(17289), 2,
      sym_comment,
      sym_block_comment,
  [674732] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22215), 1,
      anon_sym_RBRACE,
    STATE(17290), 2,
      sym_comment,
      sym_block_comment,
  [674746] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22211), 1,
      anon_sym_RPAREN,
    STATE(17291), 2,
      sym_comment,
      sym_block_comment,
  [674760] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22217), 1,
      anon_sym_RPAREN,
    STATE(17292), 2,
      sym_comment,
      sym_block_comment,
  [674774] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22219), 1,
      anon_sym_EQ_GT,
    STATE(17293), 2,
      sym_comment,
      sym_block_comment,
  [674788] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22217), 1,
      anon_sym_RBRACE,
    STATE(17294), 2,
      sym_comment,
      sym_block_comment,
  [674802] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22221), 1,
      anon_sym_EQ_GT_GT,
    STATE(17295), 2,
      sym_comment,
      sym_block_comment,
  [674816] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22223), 1,
      anon_sym_EQ_GT_GT,
    STATE(17296), 2,
      sym_comment,
      sym_block_comment,
  [674830] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22225), 1,
      anon_sym_EQ_GT_GT,
    STATE(17297), 2,
      sym_comment,
      sym_block_comment,
  [674844] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22227), 1,
      anon_sym_EQ_GT_GT,
    STATE(17298), 2,
      sym_comment,
      sym_block_comment,
  [674858] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22229), 1,
      sym__outdent,
    STATE(17299), 2,
      sym_comment,
      sym_block_comment,
  [674872] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22231), 1,
      anon_sym_RPAREN,
    STATE(17300), 2,
      sym_comment,
      sym_block_comment,
  [674886] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8734), 1,
      anon_sym_DOT,
    STATE(17301), 2,
      sym_comment,
      sym_block_comment,
  [674900] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22233), 1,
      sym__outdent,
    STATE(17302), 2,
      sym_comment,
      sym_block_comment,
  [674914] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22235), 1,
      anon_sym_RBRACE,
    STATE(17303), 2,
      sym_comment,
      sym_block_comment,
  [674928] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22237), 1,
      anon_sym_else,
    STATE(17304), 2,
      sym_comment,
      sym_block_comment,
  [674942] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22239), 1,
      anon_sym_RPAREN,
    STATE(17305), 2,
      sym_comment,
      sym_block_comment,
  [674956] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15539), 1,
      anon_sym_DOT,
    STATE(17306), 2,
      sym_comment,
      sym_block_comment,
  [674970] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22241), 1,
      anon_sym_COLON,
    STATE(17307), 2,
      sym_comment,
      sym_block_comment,
  [674984] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22243), 1,
      anon_sym_do,
    STATE(17308), 2,
      sym_comment,
      sym_block_comment,
  [674998] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22245), 1,
      sym__outdent,
    STATE(17309), 2,
      sym_comment,
      sym_block_comment,
  [675012] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22247), 1,
      anon_sym_RBRACE,
    STATE(17310), 2,
      sym_comment,
      sym_block_comment,
  [675026] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22249), 1,
      anon_sym_else,
    STATE(17311), 2,
      sym_comment,
      sym_block_comment,
  [675040] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22251), 1,
      anon_sym_else,
    STATE(17312), 2,
      sym_comment,
      sym_block_comment,
  [675054] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22253), 1,
      anon_sym_EQ_GT,
    STATE(17313), 2,
      sym_comment,
      sym_block_comment,
  [675068] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22255), 1,
      sym__outdent,
    STATE(17314), 2,
      sym_comment,
      sym_block_comment,
  [675082] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22257), 1,
      anon_sym_EQ_GT_GT,
    STATE(17315), 2,
      sym_comment,
      sym_block_comment,
  [675096] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22259), 1,
      anon_sym_EQ_GT_GT,
    STATE(17316), 2,
      sym_comment,
      sym_block_comment,
  [675110] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22261), 1,
      anon_sym_EQ_GT_GT,
    STATE(17317), 2,
      sym_comment,
      sym_block_comment,
  [675124] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22263), 1,
      anon_sym_EQ_GT_GT,
    STATE(17318), 2,
      sym_comment,
      sym_block_comment,
  [675138] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22265), 1,
      sym__outdent,
    STATE(17319), 2,
      sym_comment,
      sym_block_comment,
  [675152] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22267), 1,
      anon_sym_RPAREN,
    STATE(17320), 2,
      sym_comment,
      sym_block_comment,
  [675166] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9257), 1,
      anon_sym_DOT,
    STATE(17321), 2,
      sym_comment,
      sym_block_comment,
  [675180] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22269), 1,
      anon_sym_EQ_GT_GT,
    STATE(17322), 2,
      sym_comment,
      sym_block_comment,
  [675194] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22271), 1,
      anon_sym_else,
    STATE(17323), 2,
      sym_comment,
      sym_block_comment,
  [675208] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22273), 1,
      anon_sym_EQ_GT_GT,
    STATE(17324), 2,
      sym_comment,
      sym_block_comment,
  [675222] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22275), 1,
      anon_sym_EQ_GT_GT,
    STATE(17325), 2,
      sym_comment,
      sym_block_comment,
  [675236] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22277), 1,
      sym__outdent,
    STATE(17326), 2,
      sym_comment,
      sym_block_comment,
  [675250] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22279), 1,
      anon_sym_EQ_GT_GT,
    STATE(17327), 2,
      sym_comment,
      sym_block_comment,
  [675264] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22281), 1,
      anon_sym_do,
    STATE(17328), 2,
      sym_comment,
      sym_block_comment,
  [675278] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22283), 1,
      anon_sym_RPAREN,
    STATE(17329), 2,
      sym_comment,
      sym_block_comment,
  [675292] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22285), 1,
      anon_sym_EQ_GT,
    STATE(17330), 2,
      sym_comment,
      sym_block_comment,
  [675306] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22287), 1,
      anon_sym_RBRACE,
    STATE(17331), 2,
      sym_comment,
      sym_block_comment,
  [675320] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22289), 1,
      anon_sym_RBRACK,
    STATE(17332), 2,
      sym_comment,
      sym_block_comment,
  [675334] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22291), 1,
      anon_sym_EQ_GT,
    STATE(17333), 2,
      sym_comment,
      sym_block_comment,
  [675348] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22289), 1,
      anon_sym_RBRACE,
    STATE(17334), 2,
      sym_comment,
      sym_block_comment,
  [675362] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22293), 1,
      anon_sym_EQ_GT_GT,
    STATE(17335), 2,
      sym_comment,
      sym_block_comment,
  [675376] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22295), 1,
      anon_sym_EQ_GT_GT,
    STATE(17336), 2,
      sym_comment,
      sym_block_comment,
  [675390] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22297), 1,
      anon_sym_EQ_GT_GT,
    STATE(17337), 2,
      sym_comment,
      sym_block_comment,
  [675404] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22299), 1,
      anon_sym_EQ_GT_GT,
    STATE(17338), 2,
      sym_comment,
      sym_block_comment,
  [675418] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22301), 1,
      anon_sym_RBRACK,
    STATE(17339), 2,
      sym_comment,
      sym_block_comment,
  [675432] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22301), 1,
      anon_sym_RBRACE,
    STATE(17340), 2,
      sym_comment,
      sym_block_comment,
  [675446] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8679), 1,
      anon_sym_DOT,
    STATE(17341), 2,
      sym_comment,
      sym_block_comment,
  [675460] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22303), 1,
      sym__outdent,
    STATE(17342), 2,
      sym_comment,
      sym_block_comment,
  [675474] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22305), 1,
      anon_sym_RPAREN,
    STATE(17343), 2,
      sym_comment,
      sym_block_comment,
  [675488] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22305), 1,
      anon_sym_RBRACE,
    STATE(17344), 2,
      sym_comment,
      sym_block_comment,
  [675502] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22307), 1,
      sym__outdent,
    STATE(17345), 2,
      sym_comment,
      sym_block_comment,
  [675516] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22309), 1,
      anon_sym_RBRACE,
    STATE(17346), 2,
      sym_comment,
      sym_block_comment,
  [675530] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22309), 1,
      anon_sym_RPAREN,
    STATE(17347), 2,
      sym_comment,
      sym_block_comment,
  [675544] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22311), 1,
      anon_sym_RBRACE,
    STATE(17348), 2,
      sym_comment,
      sym_block_comment,
  [675558] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22313), 1,
      anon_sym_RPAREN,
    STATE(17349), 2,
      sym_comment,
      sym_block_comment,
  [675572] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22315), 1,
      sym__outdent,
    STATE(17350), 2,
      sym_comment,
      sym_block_comment,
  [675586] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22317), 1,
      anon_sym_else,
    STATE(17351), 2,
      sym_comment,
      sym_block_comment,
  [675600] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22319), 1,
      anon_sym_RPAREN,
    STATE(17352), 2,
      sym_comment,
      sym_block_comment,
  [675614] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22321), 1,
      anon_sym_do,
    STATE(17353), 2,
      sym_comment,
      sym_block_comment,
  [675628] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22323), 1,
      anon_sym_EQ_GT_GT,
    STATE(17354), 2,
      sym_comment,
      sym_block_comment,
  [675642] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22325), 1,
      anon_sym_EQ_GT_GT,
    STATE(17355), 2,
      sym_comment,
      sym_block_comment,
  [675656] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22327), 1,
      anon_sym_EQ_GT_GT,
    STATE(17356), 2,
      sym_comment,
      sym_block_comment,
  [675670] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22329), 1,
      anon_sym_EQ_GT_GT,
    STATE(17357), 2,
      sym_comment,
      sym_block_comment,
  [675684] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22331), 1,
      sym__outdent,
    STATE(17358), 2,
      sym_comment,
      sym_block_comment,
  [675698] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22333), 1,
      anon_sym_RBRACE,
    STATE(17359), 2,
      sym_comment,
      sym_block_comment,
  [675712] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9379), 1,
      anon_sym_DOT,
    STATE(17360), 2,
      sym_comment,
      sym_block_comment,
  [675726] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22335), 1,
      anon_sym_else,
    STATE(17361), 2,
      sym_comment,
      sym_block_comment,
  [675740] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22337), 1,
      anon_sym_else,
    STATE(17362), 2,
      sym_comment,
      sym_block_comment,
  [675754] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22339), 1,
      sym__outdent,
    STATE(17363), 2,
      sym_comment,
      sym_block_comment,
  [675768] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11441), 1,
      anon_sym_DOT,
    STATE(17364), 2,
      sym_comment,
      sym_block_comment,
  [675782] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22341), 1,
      anon_sym_RPAREN,
    STATE(17365), 2,
      sym_comment,
      sym_block_comment,
  [675796] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22343), 1,
      anon_sym_COLON,
    STATE(17366), 2,
      sym_comment,
      sym_block_comment,
  [675810] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22345), 1,
      anon_sym_else,
    STATE(17367), 2,
      sym_comment,
      sym_block_comment,
  [675824] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22347), 1,
      anon_sym_do,
    STATE(17368), 2,
      sym_comment,
      sym_block_comment,
  [675838] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22349), 1,
      anon_sym_RBRACE,
    STATE(17369), 2,
      sym_comment,
      sym_block_comment,
  [675852] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22351), 1,
      sym__outdent,
    STATE(17370), 2,
      sym_comment,
      sym_block_comment,
  [675866] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22353), 1,
      anon_sym_EQ_GT_GT,
    STATE(17371), 2,
      sym_comment,
      sym_block_comment,
  [675880] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22355), 1,
      anon_sym_RPAREN,
    STATE(17372), 2,
      sym_comment,
      sym_block_comment,
  [675894] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22357), 1,
      anon_sym_EQ_GT_GT,
    STATE(17373), 2,
      sym_comment,
      sym_block_comment,
  [675908] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22359), 1,
      anon_sym_EQ_GT_GT,
    STATE(17374), 2,
      sym_comment,
      sym_block_comment,
  [675922] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22361), 1,
      anon_sym_EQ_GT_GT,
    STATE(17375), 2,
      sym_comment,
      sym_block_comment,
  [675936] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22363), 1,
      anon_sym_EQ_GT_GT,
    STATE(17376), 2,
      sym_comment,
      sym_block_comment,
  [675950] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22365), 1,
      anon_sym_RPAREN,
    STATE(17377), 2,
      sym_comment,
      sym_block_comment,
  [675964] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22367), 1,
      anon_sym_EQ_GT_GT,
    STATE(17378), 2,
      sym_comment,
      sym_block_comment,
  [675978] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9481), 1,
      anon_sym_DOT,
    STATE(17379), 2,
      sym_comment,
      sym_block_comment,
  [675992] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22369), 1,
      anon_sym_EQ_GT_GT,
    STATE(17380), 2,
      sym_comment,
      sym_block_comment,
  [676006] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22371), 1,
      anon_sym_RBRACK,
    STATE(17381), 2,
      sym_comment,
      sym_block_comment,
  [676020] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22371), 1,
      anon_sym_RBRACE,
    STATE(17382), 2,
      sym_comment,
      sym_block_comment,
  [676034] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22373), 1,
      anon_sym_RBRACK,
    STATE(17383), 2,
      sym_comment,
      sym_block_comment,
  [676048] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22373), 1,
      anon_sym_RBRACE,
    STATE(17384), 2,
      sym_comment,
      sym_block_comment,
  [676062] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22375), 1,
      anon_sym_EQ_GT_GT,
    STATE(17385), 2,
      sym_comment,
      sym_block_comment,
  [676076] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22377), 1,
      anon_sym_EQ_GT_GT,
    STATE(17386), 2,
      sym_comment,
      sym_block_comment,
  [676090] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22355), 1,
      anon_sym_RBRACE,
    STATE(17387), 2,
      sym_comment,
      sym_block_comment,
  [676104] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22379), 1,
      sym__outdent,
    STATE(17388), 2,
      sym_comment,
      sym_block_comment,
  [676118] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22381), 1,
      anon_sym_EQ_GT,
    STATE(17389), 2,
      sym_comment,
      sym_block_comment,
  [676132] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22383), 1,
      anon_sym_RBRACE,
    STATE(17390), 2,
      sym_comment,
      sym_block_comment,
  [676146] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22385), 1,
      anon_sym_RBRACE,
    STATE(17391), 2,
      sym_comment,
      sym_block_comment,
  [676160] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22387), 1,
      anon_sym_EQ_GT_GT,
    STATE(17392), 2,
      sym_comment,
      sym_block_comment,
  [676174] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22389), 1,
      anon_sym_EQ_GT_GT,
    STATE(17393), 2,
      sym_comment,
      sym_block_comment,
  [676188] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22391), 1,
      anon_sym_EQ_GT_GT,
    STATE(17394), 2,
      sym_comment,
      sym_block_comment,
  [676202] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22393), 1,
      anon_sym_EQ_GT_GT,
    STATE(17395), 2,
      sym_comment,
      sym_block_comment,
  [676216] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22383), 1,
      anon_sym_RPAREN,
    STATE(17396), 2,
      sym_comment,
      sym_block_comment,
  [676230] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22395), 1,
      anon_sym_RPAREN,
    STATE(17397), 2,
      sym_comment,
      sym_block_comment,
  [676244] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11051), 1,
      anon_sym_DOT,
    STATE(17398), 2,
      sym_comment,
      sym_block_comment,
  [676258] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22397), 1,
      sym__outdent,
    STATE(17399), 2,
      sym_comment,
      sym_block_comment,
  [676272] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22399), 1,
      anon_sym_else,
    STATE(17400), 2,
      sym_comment,
      sym_block_comment,
  [676286] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22401), 1,
      anon_sym_do,
    STATE(17401), 2,
      sym_comment,
      sym_block_comment,
  [676300] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22403), 1,
      anon_sym_RPAREN,
    STATE(17402), 2,
      sym_comment,
      sym_block_comment,
  [676314] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22405), 1,
      anon_sym_RBRACE,
    STATE(17403), 2,
      sym_comment,
      sym_block_comment,
  [676328] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22407), 1,
      sym__outdent,
    STATE(17404), 2,
      sym_comment,
      sym_block_comment,
  [676342] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22409), 1,
      anon_sym_else,
    STATE(17405), 2,
      sym_comment,
      sym_block_comment,
  [676356] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22411), 1,
      sym__outdent,
    STATE(17406), 2,
      sym_comment,
      sym_block_comment,
  [676370] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22413), 1,
      anon_sym_else,
    STATE(17407), 2,
      sym_comment,
      sym_block_comment,
  [676384] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22415), 1,
      anon_sym_RPAREN,
    STATE(17408), 2,
      sym_comment,
      sym_block_comment,
  [676398] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22417), 1,
      anon_sym_do,
    STATE(17409), 2,
      sym_comment,
      sym_block_comment,
  [676412] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22419), 1,
      anon_sym_else,
    STATE(17410), 2,
      sym_comment,
      sym_block_comment,
  [676426] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22421), 1,
      anon_sym_EQ_GT_GT,
    STATE(17411), 2,
      sym_comment,
      sym_block_comment,
  [676440] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22423), 1,
      anon_sym_EQ_GT_GT,
    STATE(17412), 2,
      sym_comment,
      sym_block_comment,
  [676454] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22425), 1,
      anon_sym_EQ_GT_GT,
    STATE(17413), 2,
      sym_comment,
      sym_block_comment,
  [676468] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22427), 1,
      anon_sym_EQ_GT_GT,
    STATE(17414), 2,
      sym_comment,
      sym_block_comment,
  [676482] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22429), 1,
      anon_sym_RBRACE,
    STATE(17415), 2,
      sym_comment,
      sym_block_comment,
  [676496] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11703), 1,
      anon_sym_DOT,
    STATE(17416), 2,
      sym_comment,
      sym_block_comment,
  [676510] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10066), 1,
      anon_sym_DOT,
    STATE(17417), 2,
      sym_comment,
      sym_block_comment,
  [676524] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22431), 1,
      sym__outdent,
    STATE(17418), 2,
      sym_comment,
      sym_block_comment,
  [676538] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22433), 1,
      anon_sym_COLON,
    STATE(17419), 2,
      sym_comment,
      sym_block_comment,
  [676552] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22435), 1,
      sym__outdent,
    STATE(17420), 2,
      sym_comment,
      sym_block_comment,
  [676566] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22437), 1,
      anon_sym_RPAREN,
    STATE(17421), 2,
      sym_comment,
      sym_block_comment,
  [676580] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22439), 1,
      anon_sym_RBRACE,
    STATE(17422), 2,
      sym_comment,
      sym_block_comment,
  [676594] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22439), 1,
      anon_sym_RPAREN,
    STATE(17423), 2,
      sym_comment,
      sym_block_comment,
  [676608] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22441), 1,
      anon_sym_RBRACK,
    STATE(17424), 2,
      sym_comment,
      sym_block_comment,
  [676622] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22441), 1,
      anon_sym_RBRACE,
    STATE(17425), 2,
      sym_comment,
      sym_block_comment,
  [676636] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22443), 1,
      anon_sym_RBRACK,
    STATE(17426), 2,
      sym_comment,
      sym_block_comment,
  [676650] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22443), 1,
      anon_sym_RBRACE,
    STATE(17427), 2,
      sym_comment,
      sym_block_comment,
  [676664] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22445), 1,
      anon_sym_EQ_GT_GT,
    STATE(17428), 2,
      sym_comment,
      sym_block_comment,
  [676678] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22447), 1,
      anon_sym_RPAREN,
    STATE(17429), 2,
      sym_comment,
      sym_block_comment,
  [676692] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22449), 1,
      anon_sym_EQ_GT_GT,
    STATE(17430), 2,
      sym_comment,
      sym_block_comment,
  [676706] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22451), 1,
      anon_sym_EQ_GT_GT,
    STATE(17431), 2,
      sym_comment,
      sym_block_comment,
  [676720] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22453), 1,
      anon_sym_EQ_GT_GT,
    STATE(17432), 2,
      sym_comment,
      sym_block_comment,
  [676734] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22455), 1,
      anon_sym_EQ_GT_GT,
    STATE(17433), 2,
      sym_comment,
      sym_block_comment,
  [676748] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22447), 1,
      anon_sym_RBRACE,
    STATE(17434), 2,
      sym_comment,
      sym_block_comment,
  [676762] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22457), 1,
      sym__outdent,
    STATE(17435), 2,
      sym_comment,
      sym_block_comment,
  [676776] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14551), 1,
      anon_sym_DOT,
    STATE(17436), 2,
      sym_comment,
      sym_block_comment,
  [676790] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22459), 1,
      anon_sym_EQ_GT_GT,
    STATE(17437), 2,
      sym_comment,
      sym_block_comment,
  [676804] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22461), 1,
      anon_sym_EQ_GT_GT,
    STATE(17438), 2,
      sym_comment,
      sym_block_comment,
  [676818] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22463), 1,
      anon_sym_RBRACE,
    STATE(17439), 2,
      sym_comment,
      sym_block_comment,
  [676832] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22465), 1,
      anon_sym_EQ_GT_GT,
    STATE(17440), 2,
      sym_comment,
      sym_block_comment,
  [676846] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22467), 1,
      anon_sym_RPAREN,
    STATE(17441), 2,
      sym_comment,
      sym_block_comment,
  [676860] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22469), 1,
      anon_sym_EQ_GT,
    STATE(17442), 2,
      sym_comment,
      sym_block_comment,
  [676874] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22471), 1,
      sym__outdent,
    STATE(17443), 2,
      sym_comment,
      sym_block_comment,
  [676888] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22473), 1,
      anon_sym_do,
    STATE(17444), 2,
      sym_comment,
      sym_block_comment,
  [676902] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22475), 1,
      anon_sym_else,
    STATE(17445), 2,
      sym_comment,
      sym_block_comment,
  [676916] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22477), 1,
      anon_sym_RBRACE,
    STATE(17446), 2,
      sym_comment,
      sym_block_comment,
  [676930] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22479), 1,
      sym__outdent,
    STATE(17447), 2,
      sym_comment,
      sym_block_comment,
  [676944] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22481), 1,
      anon_sym_else,
    STATE(17448), 2,
      sym_comment,
      sym_block_comment,
  [676958] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22483), 1,
      anon_sym_EQ_GT_GT,
    STATE(17449), 2,
      sym_comment,
      sym_block_comment,
  [676972] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22485), 1,
      anon_sym_EQ_GT_GT,
    STATE(17450), 2,
      sym_comment,
      sym_block_comment,
  [676986] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22487), 1,
      anon_sym_EQ_GT_GT,
    STATE(17451), 2,
      sym_comment,
      sym_block_comment,
  [677000] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22489), 1,
      anon_sym_EQ_GT_GT,
    STATE(17452), 2,
      sym_comment,
      sym_block_comment,
  [677014] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13236), 1,
      anon_sym_DOT,
    STATE(17453), 2,
      sym_comment,
      sym_block_comment,
  [677028] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22491), 1,
      sym__outdent,
    STATE(17454), 2,
      sym_comment,
      sym_block_comment,
  [677042] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22493), 1,
      anon_sym_RPAREN,
    STATE(17455), 2,
      sym_comment,
      sym_block_comment,
  [677056] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22495), 1,
      anon_sym_RPAREN,
    STATE(17456), 2,
      sym_comment,
      sym_block_comment,
  [677070] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22497), 1,
      sym__outdent,
    STATE(17457), 2,
      sym_comment,
      sym_block_comment,
  [677084] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22499), 1,
      anon_sym_else,
    STATE(17458), 2,
      sym_comment,
      sym_block_comment,
  [677098] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22501), 1,
      anon_sym_else,
    STATE(17459), 2,
      sym_comment,
      sym_block_comment,
  [677112] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22503), 1,
      anon_sym_do,
    STATE(17460), 2,
      sym_comment,
      sym_block_comment,
  [677126] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22505), 1,
      sym__outdent,
    STATE(17461), 2,
      sym_comment,
      sym_block_comment,
  [677140] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22507), 1,
      anon_sym_EQ_GT_GT,
    STATE(17462), 2,
      sym_comment,
      sym_block_comment,
  [677154] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22509), 1,
      anon_sym_EQ_GT_GT,
    STATE(17463), 2,
      sym_comment,
      sym_block_comment,
  [677168] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22511), 1,
      anon_sym_EQ_GT_GT,
    STATE(17464), 2,
      sym_comment,
      sym_block_comment,
  [677182] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22513), 1,
      anon_sym_EQ_GT_GT,
    STATE(17465), 2,
      sym_comment,
      sym_block_comment,
  [677196] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13208), 1,
      anon_sym_DOT,
    STATE(17466), 2,
      sym_comment,
      sym_block_comment,
  [677210] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22515), 1,
      anon_sym_RBRACE,
    STATE(17467), 2,
      sym_comment,
      sym_block_comment,
  [677224] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22517), 1,
      sym__outdent,
    STATE(17468), 2,
      sym_comment,
      sym_block_comment,
  [677238] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22519), 1,
      anon_sym_RPAREN,
    STATE(17469), 2,
      sym_comment,
      sym_block_comment,
  [677252] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22521), 1,
      anon_sym_RBRACE,
    STATE(17470), 2,
      sym_comment,
      sym_block_comment,
  [677266] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22521), 1,
      anon_sym_RPAREN,
    STATE(17471), 2,
      sym_comment,
      sym_block_comment,
  [677280] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22523), 1,
      anon_sym_RBRACK,
    STATE(17472), 2,
      sym_comment,
      sym_block_comment,
  [677294] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22523), 1,
      anon_sym_RBRACE,
    STATE(17473), 2,
      sym_comment,
      sym_block_comment,
  [677308] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22525), 1,
      anon_sym_RBRACK,
    STATE(17474), 2,
      sym_comment,
      sym_block_comment,
  [677322] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22527), 1,
      anon_sym_EQ_GT_GT,
    STATE(17475), 2,
      sym_comment,
      sym_block_comment,
  [677336] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22529), 1,
      anon_sym_EQ_GT_GT,
    STATE(17476), 2,
      sym_comment,
      sym_block_comment,
  [677350] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22531), 1,
      anon_sym_EQ_GT_GT,
    STATE(17477), 2,
      sym_comment,
      sym_block_comment,
  [677364] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22533), 1,
      anon_sym_EQ_GT_GT,
    STATE(17478), 2,
      sym_comment,
      sym_block_comment,
  [677378] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11244), 1,
      anon_sym_DOT,
    STATE(17479), 2,
      sym_comment,
      sym_block_comment,
  [677392] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22525), 1,
      anon_sym_RBRACE,
    STATE(17480), 2,
      sym_comment,
      sym_block_comment,
  [677406] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11330), 1,
      anon_sym_DOT,
    STATE(17481), 2,
      sym_comment,
      sym_block_comment,
  [677420] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22535), 1,
      anon_sym_RPAREN,
    STATE(17482), 2,
      sym_comment,
      sym_block_comment,
  [677434] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22535), 1,
      anon_sym_RBRACE,
    STATE(17483), 2,
      sym_comment,
      sym_block_comment,
  [677448] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22537), 1,
      sym__outdent,
    STATE(17484), 2,
      sym_comment,
      sym_block_comment,
  [677462] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22539), 1,
      anon_sym_COLON,
    STATE(17485), 2,
      sym_comment,
      sym_block_comment,
  [677476] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22541), 1,
      anon_sym_RPAREN,
    STATE(17486), 2,
      sym_comment,
      sym_block_comment,
  [677490] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22543), 1,
      anon_sym_RBRACE,
    STATE(17487), 2,
      sym_comment,
      sym_block_comment,
  [677504] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22545), 1,
      anon_sym_EQ_GT_GT,
    STATE(17488), 2,
      sym_comment,
      sym_block_comment,
  [677518] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22547), 1,
      anon_sym_EQ_GT_GT,
    STATE(17489), 2,
      sym_comment,
      sym_block_comment,
  [677532] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22549), 1,
      anon_sym_EQ_GT_GT,
    STATE(17490), 2,
      sym_comment,
      sym_block_comment,
  [677546] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22551), 1,
      anon_sym_EQ_GT_GT,
    STATE(17491), 2,
      sym_comment,
      sym_block_comment,
  [677560] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9317), 1,
      anon_sym_DOT,
    STATE(17492), 2,
      sym_comment,
      sym_block_comment,
  [677574] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22553), 1,
      sym__outdent,
    STATE(17493), 2,
      sym_comment,
      sym_block_comment,
  [677588] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22555), 1,
      anon_sym_EQ_GT_GT,
    STATE(17494), 2,
      sym_comment,
      sym_block_comment,
  [677602] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22557), 1,
      anon_sym_EQ_GT_GT,
    STATE(17495), 2,
      sym_comment,
      sym_block_comment,
  [677616] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22559), 1,
      anon_sym_EQ_GT_GT,
    STATE(17496), 2,
      sym_comment,
      sym_block_comment,
  [677630] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22561), 1,
      anon_sym_do,
    STATE(17497), 2,
      sym_comment,
      sym_block_comment,
  [677644] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22563), 1,
      anon_sym_do,
    STATE(17498), 2,
      sym_comment,
      sym_block_comment,
  [677658] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22565), 1,
      anon_sym_RBRACE,
    STATE(17499), 2,
      sym_comment,
      sym_block_comment,
  [677672] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22567), 1,
      anon_sym_else,
    STATE(17500), 2,
      sym_comment,
      sym_block_comment,
  [677686] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22569), 1,
      anon_sym_EQ_GT_GT,
    STATE(17501), 2,
      sym_comment,
      sym_block_comment,
  [677700] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22571), 1,
      anon_sym_EQ_GT_GT,
    STATE(17502), 2,
      sym_comment,
      sym_block_comment,
  [677714] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22573), 1,
      anon_sym_EQ_GT_GT,
    STATE(17503), 2,
      sym_comment,
      sym_block_comment,
  [677728] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22575), 1,
      anon_sym_EQ_GT_GT,
    STATE(17504), 2,
      sym_comment,
      sym_block_comment,
  [677742] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11258), 1,
      anon_sym_DOT,
    STATE(17505), 2,
      sym_comment,
      sym_block_comment,
  [677756] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22577), 1,
      anon_sym_else,
    STATE(17506), 2,
      sym_comment,
      sym_block_comment,
  [677770] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22579), 1,
      sym__outdent,
    STATE(17507), 2,
      sym_comment,
      sym_block_comment,
  [677784] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22581), 1,
      anon_sym_EQ_GT,
    STATE(17508), 2,
      sym_comment,
      sym_block_comment,
  [677798] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22583), 1,
      anon_sym_RPAREN,
    STATE(17509), 2,
      sym_comment,
      sym_block_comment,
  [677812] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22585), 1,
      anon_sym_RPAREN,
    STATE(17510), 2,
      sym_comment,
      sym_block_comment,
  [677826] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22587), 1,
      anon_sym_else,
    STATE(17511), 2,
      sym_comment,
      sym_block_comment,
  [677840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22589), 1,
      sym__outdent,
    STATE(17512), 2,
      sym_comment,
      sym_block_comment,
  [677854] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22591), 1,
      anon_sym_else,
    STATE(17513), 2,
      sym_comment,
      sym_block_comment,
  [677868] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22593), 1,
      anon_sym_EQ_GT_GT,
    STATE(17514), 2,
      sym_comment,
      sym_block_comment,
  [677882] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22595), 1,
      anon_sym_EQ_GT_GT,
    STATE(17515), 2,
      sym_comment,
      sym_block_comment,
  [677896] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22597), 1,
      anon_sym_EQ_GT_GT,
    STATE(17516), 2,
      sym_comment,
      sym_block_comment,
  [677910] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22599), 1,
      anon_sym_EQ_GT_GT,
    STATE(17517), 2,
      sym_comment,
      sym_block_comment,
  [677924] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11253), 1,
      anon_sym_DOT,
    STATE(17518), 2,
      sym_comment,
      sym_block_comment,
  [677938] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22601), 1,
      anon_sym_RBRACE,
    STATE(17519), 2,
      sym_comment,
      sym_block_comment,
  [677952] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22603), 1,
      anon_sym_RBRACE,
    STATE(17520), 2,
      sym_comment,
      sym_block_comment,
  [677966] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22605), 1,
      sym__outdent,
    STATE(17521), 2,
      sym_comment,
      sym_block_comment,
  [677980] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22607), 1,
      anon_sym_RPAREN,
    STATE(17522), 2,
      sym_comment,
      sym_block_comment,
  [677994] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22609), 1,
      anon_sym_RBRACE,
    STATE(17523), 2,
      sym_comment,
      sym_block_comment,
  [678008] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22609), 1,
      anon_sym_RPAREN,
    STATE(17524), 2,
      sym_comment,
      sym_block_comment,
  [678022] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22611), 1,
      anon_sym_RBRACK,
    STATE(17525), 2,
      sym_comment,
      sym_block_comment,
  [678036] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22611), 1,
      anon_sym_RBRACE,
    STATE(17526), 2,
      sym_comment,
      sym_block_comment,
  [678050] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22613), 1,
      anon_sym_EQ_GT_GT,
    STATE(17527), 2,
      sym_comment,
      sym_block_comment,
  [678064] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22615), 1,
      anon_sym_EQ_GT_GT,
    STATE(17528), 2,
      sym_comment,
      sym_block_comment,
  [678078] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22617), 1,
      anon_sym_EQ_GT_GT,
    STATE(17529), 2,
      sym_comment,
      sym_block_comment,
  [678092] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22619), 1,
      anon_sym_EQ_GT_GT,
    STATE(17530), 2,
      sym_comment,
      sym_block_comment,
  [678106] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10419), 1,
      anon_sym_DOT,
    STATE(17531), 2,
      sym_comment,
      sym_block_comment,
  [678120] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22621), 1,
      anon_sym_RBRACK,
    STATE(17532), 2,
      sym_comment,
      sym_block_comment,
  [678134] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22621), 1,
      anon_sym_RBRACE,
    STATE(17533), 2,
      sym_comment,
      sym_block_comment,
  [678148] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22623), 1,
      anon_sym_RPAREN,
    STATE(17534), 2,
      sym_comment,
      sym_block_comment,
  [678162] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22625), 1,
      anon_sym_RPAREN,
    STATE(17535), 2,
      sym_comment,
      sym_block_comment,
  [678176] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22625), 1,
      anon_sym_RBRACE,
    STATE(17536), 2,
      sym_comment,
      sym_block_comment,
  [678190] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22627), 1,
      sym__outdent,
    STATE(17537), 2,
      sym_comment,
      sym_block_comment,
  [678204] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22629), 1,
      sym__outdent,
    STATE(17538), 2,
      sym_comment,
      sym_block_comment,
  [678218] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10547), 1,
      anon_sym_DOT,
    STATE(17539), 2,
      sym_comment,
      sym_block_comment,
  [678232] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22631), 1,
      anon_sym_EQ_GT_GT,
    STATE(17540), 2,
      sym_comment,
      sym_block_comment,
  [678246] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22633), 1,
      anon_sym_EQ_GT_GT,
    STATE(17541), 2,
      sym_comment,
      sym_block_comment,
  [678260] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22635), 1,
      anon_sym_EQ_GT_GT,
    STATE(17542), 2,
      sym_comment,
      sym_block_comment,
  [678274] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22637), 1,
      anon_sym_EQ_GT_GT,
    STATE(17543), 2,
      sym_comment,
      sym_block_comment,
  [678288] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10347), 1,
      anon_sym_DOT,
    STATE(17544), 2,
      sym_comment,
      sym_block_comment,
  [678302] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22639), 1,
      anon_sym_RBRACE,
    STATE(17545), 2,
      sym_comment,
      sym_block_comment,
  [678316] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22641), 1,
      anon_sym_COLON,
    STATE(17546), 2,
      sym_comment,
      sym_block_comment,
  [678330] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22643), 1,
      anon_sym_else,
    STATE(17547), 2,
      sym_comment,
      sym_block_comment,
  [678344] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22645), 1,
      anon_sym_RPAREN,
    STATE(17548), 2,
      sym_comment,
      sym_block_comment,
  [678358] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22647), 1,
      sym__outdent,
    STATE(17549), 2,
      sym_comment,
      sym_block_comment,
  [678372] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22649), 1,
      anon_sym_do,
    STATE(17550), 2,
      sym_comment,
      sym_block_comment,
  [678386] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22651), 1,
      anon_sym_EQ_GT_GT,
    STATE(17551), 2,
      sym_comment,
      sym_block_comment,
  [678400] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22653), 1,
      anon_sym_RBRACE,
    STATE(17552), 2,
      sym_comment,
      sym_block_comment,
  [678414] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22655), 1,
      anon_sym_EQ_GT_GT,
    STATE(17553), 2,
      sym_comment,
      sym_block_comment,
  [678428] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22657), 1,
      anon_sym_EQ_GT_GT,
    STATE(17554), 2,
      sym_comment,
      sym_block_comment,
  [678442] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22659), 1,
      anon_sym_EQ_GT_GT,
    STATE(17555), 2,
      sym_comment,
      sym_block_comment,
  [678456] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22661), 1,
      anon_sym_EQ_GT_GT,
    STATE(17556), 2,
      sym_comment,
      sym_block_comment,
  [678470] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15511), 1,
      anon_sym_DOT,
    STATE(17557), 2,
      sym_comment,
      sym_block_comment,
  [678484] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22663), 1,
      anon_sym_EQ_GT_GT,
    STATE(17558), 2,
      sym_comment,
      sym_block_comment,
  [678498] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22665), 1,
      anon_sym_else,
    STATE(17559), 2,
      sym_comment,
      sym_block_comment,
  [678512] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22667), 1,
      sym__outdent,
    STATE(17560), 2,
      sym_comment,
      sym_block_comment,
  [678526] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22669), 1,
      anon_sym_EQ_GT_GT,
    STATE(17561), 2,
      sym_comment,
      sym_block_comment,
  [678540] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22671), 1,
      anon_sym_RPAREN,
    STATE(17562), 2,
      sym_comment,
      sym_block_comment,
  [678554] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22673), 1,
      anon_sym_EQ_GT_GT,
    STATE(17563), 2,
      sym_comment,
      sym_block_comment,
  [678568] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22675), 1,
      anon_sym_else,
    STATE(17564), 2,
      sym_comment,
      sym_block_comment,
  [678582] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22677), 1,
      anon_sym_else,
    STATE(17565), 2,
      sym_comment,
      sym_block_comment,
  [678596] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22679), 1,
      anon_sym_EQ_GT_GT,
    STATE(17566), 2,
      sym_comment,
      sym_block_comment,
  [678610] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22681), 1,
      anon_sym_EQ_GT_GT,
    STATE(17567), 2,
      sym_comment,
      sym_block_comment,
  [678624] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22683), 1,
      anon_sym_EQ_GT_GT,
    STATE(17568), 2,
      sym_comment,
      sym_block_comment,
  [678638] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22685), 1,
      anon_sym_EQ_GT_GT,
    STATE(17569), 2,
      sym_comment,
      sym_block_comment,
  [678652] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9796), 1,
      anon_sym_DOT,
    STATE(17570), 2,
      sym_comment,
      sym_block_comment,
  [678666] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22687), 1,
      anon_sym_EQ_GT,
    STATE(17571), 2,
      sym_comment,
      sym_block_comment,
  [678680] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22689), 1,
      sym__outdent,
    STATE(17572), 2,
      sym_comment,
      sym_block_comment,
  [678694] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22691), 1,
      anon_sym_do,
    STATE(17573), 2,
      sym_comment,
      sym_block_comment,
  [678708] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22693), 1,
      anon_sym_RBRACE,
    STATE(17574), 2,
      sym_comment,
      sym_block_comment,
  [678722] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22695), 1,
      anon_sym_RPAREN,
    STATE(17575), 2,
      sym_comment,
      sym_block_comment,
  [678736] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22697), 1,
      sym__outdent,
    STATE(17576), 2,
      sym_comment,
      sym_block_comment,
  [678750] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22699), 1,
      anon_sym_RBRACE,
    STATE(17577), 2,
      sym_comment,
      sym_block_comment,
  [678764] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22701), 1,
      anon_sym_EQ_GT_GT,
    STATE(17578), 2,
      sym_comment,
      sym_block_comment,
  [678778] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22703), 1,
      anon_sym_EQ_GT_GT,
    STATE(17579), 2,
      sym_comment,
      sym_block_comment,
  [678792] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22705), 1,
      anon_sym_EQ_GT_GT,
    STATE(17580), 2,
      sym_comment,
      sym_block_comment,
  [678806] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22707), 1,
      anon_sym_EQ_GT_GT,
    STATE(17581), 2,
      sym_comment,
      sym_block_comment,
  [678820] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11403), 1,
      anon_sym_DOT,
    STATE(17582), 2,
      sym_comment,
      sym_block_comment,
  [678834] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22709), 1,
      anon_sym_RBRACK,
    STATE(17583), 2,
      sym_comment,
      sym_block_comment,
  [678848] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22709), 1,
      anon_sym_RBRACE,
    STATE(17584), 2,
      sym_comment,
      sym_block_comment,
  [678862] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22711), 1,
      anon_sym_RBRACK,
    STATE(17585), 2,
      sym_comment,
      sym_block_comment,
  [678876] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22711), 1,
      anon_sym_RBRACE,
    STATE(17586), 2,
      sym_comment,
      sym_block_comment,
  [678890] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22699), 1,
      anon_sym_RPAREN,
    STATE(17587), 2,
      sym_comment,
      sym_block_comment,
  [678904] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22713), 1,
      anon_sym_RPAREN,
    STATE(17588), 2,
      sym_comment,
      sym_block_comment,
  [678918] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22713), 1,
      anon_sym_RBRACE,
    STATE(17589), 2,
      sym_comment,
      sym_block_comment,
  [678932] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22715), 1,
      anon_sym_EQ_GT_GT,
    STATE(17590), 2,
      sym_comment,
      sym_block_comment,
  [678946] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22717), 1,
      anon_sym_EQ_GT_GT,
    STATE(17591), 2,
      sym_comment,
      sym_block_comment,
  [678960] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22719), 1,
      anon_sym_EQ_GT_GT,
    STATE(17592), 2,
      sym_comment,
      sym_block_comment,
  [678974] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22721), 1,
      anon_sym_EQ_GT_GT,
    STATE(17593), 2,
      sym_comment,
      sym_block_comment,
  [678988] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12884), 1,
      anon_sym_DOT,
    STATE(17594), 2,
      sym_comment,
      sym_block_comment,
  [679002] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22723), 1,
      sym__outdent,
    STATE(17595), 2,
      sym_comment,
      sym_block_comment,
  [679016] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22725), 1,
      anon_sym_RPAREN,
    STATE(17596), 2,
      sym_comment,
      sym_block_comment,
  [679030] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22727), 1,
      sym__outdent,
    STATE(17597), 2,
      sym_comment,
      sym_block_comment,
  [679044] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22729), 1,
      anon_sym_RBRACE,
    STATE(17598), 2,
      sym_comment,
      sym_block_comment,
  [679058] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22731), 1,
      anon_sym_else,
    STATE(17599), 2,
      sym_comment,
      sym_block_comment,
  [679072] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22733), 1,
      anon_sym_RPAREN,
    STATE(17600), 2,
      sym_comment,
      sym_block_comment,
  [679086] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22735), 1,
      sym__outdent,
    STATE(17601), 2,
      sym_comment,
      sym_block_comment,
  [679100] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22737), 1,
      anon_sym_EQ_GT_GT,
    STATE(17602), 2,
      sym_comment,
      sym_block_comment,
  [679114] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22739), 1,
      anon_sym_EQ_GT_GT,
    STATE(17603), 2,
      sym_comment,
      sym_block_comment,
  [679128] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22741), 1,
      anon_sym_EQ_GT_GT,
    STATE(17604), 2,
      sym_comment,
      sym_block_comment,
  [679142] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22743), 1,
      anon_sym_EQ_GT_GT,
    STATE(17605), 2,
      sym_comment,
      sym_block_comment,
  [679156] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11157), 1,
      anon_sym_DOT,
    STATE(17606), 2,
      sym_comment,
      sym_block_comment,
  [679170] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11310), 1,
      anon_sym_DOT,
    STATE(17607), 2,
      sym_comment,
      sym_block_comment,
  [679184] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22745), 1,
      anon_sym_do,
    STATE(17608), 2,
      sym_comment,
      sym_block_comment,
  [679198] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22747), 1,
      anon_sym_else,
    STATE(17609), 2,
      sym_comment,
      sym_block_comment,
  [679212] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22749), 1,
      anon_sym_RBRACE,
    STATE(17610), 2,
      sym_comment,
      sym_block_comment,
  [679226] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22751), 1,
      anon_sym_RPAREN,
    STATE(17611), 2,
      sym_comment,
      sym_block_comment,
  [679240] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22753), 1,
      anon_sym_else,
    STATE(17612), 2,
      sym_comment,
      sym_block_comment,
  [679254] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22755), 1,
      anon_sym_do,
    STATE(17613), 2,
      sym_comment,
      sym_block_comment,
  [679268] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22757), 1,
      anon_sym_EQ_GT_GT,
    STATE(17614), 2,
      sym_comment,
      sym_block_comment,
  [679282] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22759), 1,
      anon_sym_EQ_GT_GT,
    STATE(17615), 2,
      sym_comment,
      sym_block_comment,
  [679296] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22761), 1,
      anon_sym_EQ_GT_GT,
    STATE(17616), 2,
      sym_comment,
      sym_block_comment,
  [679310] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15004), 1,
      anon_sym_DOT,
    STATE(17617), 2,
      sym_comment,
      sym_block_comment,
  [679324] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22763), 1,
      sym__outdent,
    STATE(17618), 2,
      sym_comment,
      sym_block_comment,
  [679338] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15946), 1,
      anon_sym_COLON,
    STATE(17619), 2,
      sym_comment,
      sym_block_comment,
  [679352] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22765), 1,
      anon_sym_RPAREN,
    STATE(17620), 2,
      sym_comment,
      sym_block_comment,
  [679366] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22767), 1,
      anon_sym_do,
    STATE(17621), 2,
      sym_comment,
      sym_block_comment,
  [679380] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22769), 1,
      anon_sym_else,
    STATE(17622), 2,
      sym_comment,
      sym_block_comment,
  [679394] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22771), 1,
      anon_sym_EQ_GT_GT,
    STATE(17623), 2,
      sym_comment,
      sym_block_comment,
  [679408] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22773), 1,
      anon_sym_EQ_GT_GT,
    STATE(17624), 2,
      sym_comment,
      sym_block_comment,
  [679422] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22775), 1,
      anon_sym_EQ_GT_GT,
    STATE(17625), 2,
      sym_comment,
      sym_block_comment,
  [679436] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22777), 1,
      anon_sym_EQ_GT_GT,
    STATE(17626), 2,
      sym_comment,
      sym_block_comment,
  [679450] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22779), 1,
      anon_sym_EQ_GT_GT,
    STATE(17627), 2,
      sym_comment,
      sym_block_comment,
  [679464] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8004), 1,
      anon_sym_DOT,
    STATE(17628), 2,
      sym_comment,
      sym_block_comment,
  [679478] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22781), 1,
      anon_sym_EQ_GT_GT,
    STATE(17629), 2,
      sym_comment,
      sym_block_comment,
  [679492] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22783), 1,
      sym__outdent,
    STATE(17630), 2,
      sym_comment,
      sym_block_comment,
  [679506] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22785), 1,
      anon_sym_EQ_GT_GT,
    STATE(17631), 2,
      sym_comment,
      sym_block_comment,
  [679520] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22787), 1,
      anon_sym_EQ_GT_GT,
    STATE(17632), 2,
      sym_comment,
      sym_block_comment,
  [679534] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22789), 1,
      anon_sym_RPAREN,
    STATE(17633), 2,
      sym_comment,
      sym_block_comment,
  [679548] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22791), 1,
      anon_sym_RBRACE,
    STATE(17634), 2,
      sym_comment,
      sym_block_comment,
  [679562] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9114), 1,
      anon_sym_DOT,
    STATE(17635), 2,
      sym_comment,
      sym_block_comment,
  [679576] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22793), 1,
      anon_sym_EQ_GT,
    STATE(17636), 2,
      sym_comment,
      sym_block_comment,
  [679590] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22795), 1,
      anon_sym_RBRACK,
    STATE(17637), 2,
      sym_comment,
      sym_block_comment,
  [679604] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22795), 1,
      anon_sym_RBRACE,
    STATE(17638), 2,
      sym_comment,
      sym_block_comment,
  [679618] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22797), 1,
      anon_sym_RBRACK,
    STATE(17639), 2,
      sym_comment,
      sym_block_comment,
  [679632] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22797), 1,
      anon_sym_RBRACE,
    STATE(17640), 2,
      sym_comment,
      sym_block_comment,
  [679646] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22799), 1,
      sym__outdent,
    STATE(17641), 2,
      sym_comment,
      sym_block_comment,
  [679660] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8819), 1,
      anon_sym_DOT,
    STATE(17642), 2,
      sym_comment,
      sym_block_comment,
  [679674] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22801), 1,
      anon_sym_do,
    STATE(17643), 2,
      sym_comment,
      sym_block_comment,
  [679688] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22751), 1,
      anon_sym_RBRACE,
    STATE(17644), 2,
      sym_comment,
      sym_block_comment,
  [679702] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22803), 1,
      sym__outdent,
    STATE(17645), 2,
      sym_comment,
      sym_block_comment,
  [679716] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22601), 1,
      anon_sym_RPAREN,
    STATE(17646), 2,
      sym_comment,
      sym_block_comment,
  [679730] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22805), 1,
      anon_sym_RPAREN,
    STATE(17647), 2,
      sym_comment,
      sym_block_comment,
  [679744] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8713), 1,
      anon_sym_DOT,
    STATE(17648), 2,
      sym_comment,
      sym_block_comment,
  [679758] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22807), 1,
      anon_sym_RBRACE,
    STATE(17649), 2,
      sym_comment,
      sym_block_comment,
  [679772] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22809), 1,
      sym__outdent,
    STATE(17650), 2,
      sym_comment,
      sym_block_comment,
  [679786] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22811), 1,
      anon_sym_else,
    STATE(17651), 2,
      sym_comment,
      sym_block_comment,
  [679800] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22813), 1,
      anon_sym_RPAREN,
    STATE(17652), 2,
      sym_comment,
      sym_block_comment,
  [679814] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22815), 1,
      sym__outdent,
    STATE(17653), 2,
      sym_comment,
      sym_block_comment,
  [679828] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10201), 1,
      anon_sym_DOT,
    STATE(17654), 2,
      sym_comment,
      sym_block_comment,
  [679842] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22817), 1,
      anon_sym_do,
    STATE(17655), 2,
      sym_comment,
      sym_block_comment,
  [679856] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22819), 1,
      anon_sym_else,
    STATE(17656), 2,
      sym_comment,
      sym_block_comment,
  [679870] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22821), 1,
      anon_sym_RBRACE,
    STATE(17657), 2,
      sym_comment,
      sym_block_comment,
  [679884] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22823), 1,
      anon_sym_do,
    STATE(17658), 2,
      sym_comment,
      sym_block_comment,
  [679898] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22825), 1,
      anon_sym_else,
    STATE(17659), 2,
      sym_comment,
      sym_block_comment,
  [679912] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14990), 1,
      anon_sym_DOT,
    STATE(17660), 2,
      sym_comment,
      sym_block_comment,
  [679926] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22827), 1,
      sym__outdent,
    STATE(17661), 2,
      sym_comment,
      sym_block_comment,
  [679940] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22829), 1,
      anon_sym_RBRACE,
    STATE(17662), 2,
      sym_comment,
      sym_block_comment,
  [679954] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22831), 1,
      anon_sym_RPAREN,
    STATE(17663), 2,
      sym_comment,
      sym_block_comment,
  [679968] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22833), 1,
      sym__outdent,
    STATE(17664), 2,
      sym_comment,
      sym_block_comment,
  [679982] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22835), 1,
      anon_sym_else,
    STATE(17665), 2,
      sym_comment,
      sym_block_comment,
  [679996] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10305), 1,
      anon_sym_DOT,
    STATE(17666), 2,
      sym_comment,
      sym_block_comment,
  [680010] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22837), 1,
      anon_sym_RBRACE,
    STATE(17667), 2,
      sym_comment,
      sym_block_comment,
  [680024] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10359), 1,
      anon_sym_DOT,
    STATE(17668), 2,
      sym_comment,
      sym_block_comment,
  [680038] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22837), 1,
      anon_sym_RPAREN,
    STATE(17669), 2,
      sym_comment,
      sym_block_comment,
  [680052] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22839), 1,
      sym__outdent,
    STATE(17670), 2,
      sym_comment,
      sym_block_comment,
  [680066] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22841), 1,
      anon_sym_COLON,
    STATE(17671), 2,
      sym_comment,
      sym_block_comment,
  [680080] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10104), 1,
      anon_sym_DOT,
    STATE(17672), 2,
      sym_comment,
      sym_block_comment,
  [680094] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22843), 1,
      anon_sym_RPAREN,
    STATE(17673), 2,
      sym_comment,
      sym_block_comment,
  [680108] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22845), 1,
      anon_sym_RPAREN,
    STATE(17674), 2,
      sym_comment,
      sym_block_comment,
  [680122] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22847), 1,
      sym__outdent,
    STATE(17675), 2,
      sym_comment,
      sym_block_comment,
  [680136] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22849), 1,
      anon_sym_RPAREN,
    STATE(17676), 2,
      sym_comment,
      sym_block_comment,
  [680150] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22851), 1,
      anon_sym_RBRACK,
    STATE(17677), 2,
      sym_comment,
      sym_block_comment,
  [680164] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9884), 1,
      anon_sym_DOT,
    STATE(17678), 2,
      sym_comment,
      sym_block_comment,
  [680178] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22851), 1,
      anon_sym_RBRACE,
    STATE(17679), 2,
      sym_comment,
      sym_block_comment,
  [680192] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22853), 1,
      anon_sym_RBRACK,
    STATE(17680), 2,
      sym_comment,
      sym_block_comment,
  [680206] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22853), 1,
      anon_sym_RBRACE,
    STATE(17681), 2,
      sym_comment,
      sym_block_comment,
  [680220] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22855), 1,
      anon_sym_EQ_GT_GT,
    STATE(17682), 2,
      sym_comment,
      sym_block_comment,
  [680234] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22857), 1,
      anon_sym_RPAREN,
    STATE(17683), 2,
      sym_comment,
      sym_block_comment,
  [680248] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10894), 1,
      anon_sym_DOT,
    STATE(17684), 2,
      sym_comment,
      sym_block_comment,
  [680262] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22857), 1,
      anon_sym_RBRACE,
    STATE(17685), 2,
      sym_comment,
      sym_block_comment,
  [680276] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22859), 1,
      sym__outdent,
    STATE(17686), 2,
      sym_comment,
      sym_block_comment,
  [680290] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22861), 1,
      anon_sym_EQ_GT_GT,
    STATE(17687), 2,
      sym_comment,
      sym_block_comment,
  [680304] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22863), 1,
      anon_sym_EQ_GT_GT,
    STATE(17688), 2,
      sym_comment,
      sym_block_comment,
  [680318] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22865), 1,
      anon_sym_EQ_GT_GT,
    STATE(17689), 2,
      sym_comment,
      sym_block_comment,
  [680332] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10056), 1,
      anon_sym_DOT,
    STATE(17690), 2,
      sym_comment,
      sym_block_comment,
  [680346] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22867), 1,
      anon_sym_RBRACE,
    STATE(17691), 2,
      sym_comment,
      sym_block_comment,
  [680360] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22869), 1,
      sym__outdent,
    STATE(17692), 2,
      sym_comment,
      sym_block_comment,
  [680374] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22871), 1,
      anon_sym_else,
    STATE(17693), 2,
      sym_comment,
      sym_block_comment,
  [680388] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22873), 1,
      anon_sym_LPAREN,
    STATE(17694), 2,
      sym_comment,
      sym_block_comment,
  [680402] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22875), 1,
      anon_sym_EQ_GT,
    STATE(17695), 2,
      sym_comment,
      sym_block_comment,
  [680416] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14718), 1,
      anon_sym_DOT,
    STATE(17696), 2,
      sym_comment,
      sym_block_comment,
  [680430] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22877), 1,
      anon_sym_do,
    STATE(17697), 2,
      sym_comment,
      sym_block_comment,
  [680444] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22879), 1,
      sym__outdent,
    STATE(17698), 2,
      sym_comment,
      sym_block_comment,
  [680458] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22881), 1,
      anon_sym_RBRACE,
    STATE(17699), 2,
      sym_comment,
      sym_block_comment,
  [680472] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22883), 1,
      anon_sym_RBRACE,
    STATE(17700), 2,
      sym_comment,
      sym_block_comment,
  [680486] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22885), 1,
      anon_sym_else,
    STATE(17701), 2,
      sym_comment,
      sym_block_comment,
  [680500] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11592), 1,
      anon_sym_DOT,
    STATE(17702), 2,
      sym_comment,
      sym_block_comment,
  [680514] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22887), 1,
      sym__outdent,
    STATE(17703), 2,
      sym_comment,
      sym_block_comment,
  [680528] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22889), 1,
      sym__outdent,
    STATE(17704), 2,
      sym_comment,
      sym_block_comment,
  [680542] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22891), 1,
      anon_sym_RPAREN,
    STATE(17705), 2,
      sym_comment,
      sym_block_comment,
  [680556] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22893), 1,
      anon_sym_RBRACE,
    STATE(17706), 2,
      sym_comment,
      sym_block_comment,
  [680570] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22895), 1,
      anon_sym_EQ,
    STATE(17707), 2,
      sym_comment,
      sym_block_comment,
  [680584] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10811), 1,
      anon_sym_DOT,
    STATE(17708), 2,
      sym_comment,
      sym_block_comment,
  [680598] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22897), 1,
      anon_sym_EQ,
    STATE(17709), 2,
      sym_comment,
      sym_block_comment,
  [680612] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22899), 1,
      anon_sym_else,
    STATE(17710), 2,
      sym_comment,
      sym_block_comment,
  [680626] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22893), 1,
      anon_sym_RPAREN,
    STATE(17711), 2,
      sym_comment,
      sym_block_comment,
  [680640] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22901), 1,
      anon_sym_RPAREN,
    STATE(17712), 2,
      sym_comment,
      sym_block_comment,
  [680654] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22903), 1,
      sym__outdent,
    STATE(17713), 2,
      sym_comment,
      sym_block_comment,
  [680668] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12621), 1,
      anon_sym_DOT,
    STATE(17714), 2,
      sym_comment,
      sym_block_comment,
  [680682] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22905), 1,
      sym__outdent,
    STATE(17715), 2,
      sym_comment,
      sym_block_comment,
  [680696] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22907), 1,
      anon_sym_else,
    STATE(17716), 2,
      sym_comment,
      sym_block_comment,
  [680710] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22909), 1,
      anon_sym_RPAREN,
    STATE(17717), 2,
      sym_comment,
      sym_block_comment,
  [680724] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22911), 1,
      anon_sym_RPAREN,
    STATE(17718), 2,
      sym_comment,
      sym_block_comment,
  [680738] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22913), 1,
      sym__outdent,
    STATE(17719), 2,
      sym_comment,
      sym_block_comment,
  [680752] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11553), 1,
      anon_sym_DOT,
    STATE(17720), 2,
      sym_comment,
      sym_block_comment,
  [680766] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22915), 1,
      anon_sym_LPAREN,
    STATE(17721), 2,
      sym_comment,
      sym_block_comment,
  [680780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22917), 1,
      anon_sym_RBRACK,
    STATE(17722), 2,
      sym_comment,
      sym_block_comment,
  [680794] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22917), 1,
      anon_sym_RBRACE,
    STATE(17723), 2,
      sym_comment,
      sym_block_comment,
  [680808] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22919), 1,
      anon_sym_RBRACK,
    STATE(17724), 2,
      sym_comment,
      sym_block_comment,
  [680822] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22919), 1,
      anon_sym_RBRACE,
    STATE(17725), 2,
      sym_comment,
      sym_block_comment,
  [680836] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12993), 1,
      anon_sym_DOT,
    STATE(17726), 2,
      sym_comment,
      sym_block_comment,
  [680850] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22921), 1,
      anon_sym_else,
    STATE(17727), 2,
      sym_comment,
      sym_block_comment,
  [680864] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22923), 1,
      anon_sym_RPAREN,
    STATE(17728), 2,
      sym_comment,
      sym_block_comment,
  [680878] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22923), 1,
      anon_sym_RBRACE,
    STATE(17729), 2,
      sym_comment,
      sym_block_comment,
  [680892] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22925), 1,
      sym__outdent,
    STATE(17730), 2,
      sym_comment,
      sym_block_comment,
  [680906] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22927), 1,
      anon_sym_else,
    STATE(17731), 2,
      sym_comment,
      sym_block_comment,
  [680920] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14227), 1,
      anon_sym_DOT,
    STATE(17732), 2,
      sym_comment,
      sym_block_comment,
  [680934] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22929), 1,
      anon_sym_do,
    STATE(17733), 2,
      sym_comment,
      sym_block_comment,
  [680948] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10278), 1,
      anon_sym_DOT,
    STATE(17734), 2,
      sym_comment,
      sym_block_comment,
  [680962] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22931), 1,
      anon_sym_RBRACE,
    STATE(17735), 2,
      sym_comment,
      sym_block_comment,
  [680976] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22933), 1,
      anon_sym_COLON,
    STATE(17736), 2,
      sym_comment,
      sym_block_comment,
  [680990] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22935), 1,
      anon_sym_RBRACE,
    STATE(17737), 2,
      sym_comment,
      sym_block_comment,
  [681004] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9095), 1,
      anon_sym_DOT,
    STATE(17738), 2,
      sym_comment,
      sym_block_comment,
  [681018] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22937), 1,
      sym__outdent,
    STATE(17739), 2,
      sym_comment,
      sym_block_comment,
  [681032] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22939), 1,
      anon_sym_RBRACE,
    STATE(17740), 2,
      sym_comment,
      sym_block_comment,
  [681046] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22939), 1,
      anon_sym_RPAREN,
    STATE(17741), 2,
      sym_comment,
      sym_block_comment,
  [681060] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22941), 1,
      anon_sym_RPAREN,
    STATE(17742), 2,
      sym_comment,
      sym_block_comment,
  [681074] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22943), 1,
      sym__outdent,
    STATE(17743), 2,
      sym_comment,
      sym_block_comment,
  [681088] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8642), 1,
      anon_sym_DOT,
    STATE(17744), 2,
      sym_comment,
      sym_block_comment,
  [681102] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22945), 1,
      anon_sym_do,
    STATE(17745), 2,
      sym_comment,
      sym_block_comment,
  [681116] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22947), 1,
      anon_sym_EQ_GT_GT,
    STATE(17746), 2,
      sym_comment,
      sym_block_comment,
  [681130] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22949), 1,
      anon_sym_RBRACE,
    STATE(17747), 2,
      sym_comment,
      sym_block_comment,
  [681144] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22951), 1,
      anon_sym_EQ_GT_GT,
    STATE(17748), 2,
      sym_comment,
      sym_block_comment,
  [681158] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22953), 1,
      anon_sym_else,
    STATE(17749), 2,
      sym_comment,
      sym_block_comment,
  [681172] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9122), 1,
      anon_sym_DOT,
    STATE(17750), 2,
      sym_comment,
      sym_block_comment,
  [681186] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22955), 1,
      anon_sym_EQ_GT_GT,
    STATE(17751), 2,
      sym_comment,
      sym_block_comment,
  [681200] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22957), 1,
      anon_sym_EQ_GT_GT,
    STATE(17752), 2,
      sym_comment,
      sym_block_comment,
  [681214] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22959), 1,
      anon_sym_else,
    STATE(17753), 2,
      sym_comment,
      sym_block_comment,
  [681228] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22961), 1,
      anon_sym_RPAREN,
    STATE(17754), 2,
      sym_comment,
      sym_block_comment,
  [681242] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22963), 1,
      sym__outdent,
    STATE(17755), 2,
      sym_comment,
      sym_block_comment,
  [681256] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10392), 1,
      anon_sym_DOT,
    STATE(17756), 2,
      sym_comment,
      sym_block_comment,
  [681270] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22965), 1,
      sym__outdent,
    STATE(17757), 2,
      sym_comment,
      sym_block_comment,
  [681284] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(16108), 1,
      anon_sym_DOT,
    STATE(17758), 2,
      sym_comment,
      sym_block_comment,
  [681298] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22967), 1,
      anon_sym_LPAREN,
    STATE(17759), 2,
      sym_comment,
      sym_block_comment,
  [681312] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22969), 1,
      anon_sym_RPAREN,
    STATE(17760), 2,
      sym_comment,
      sym_block_comment,
  [681326] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22971), 1,
      anon_sym_else,
    STATE(17761), 2,
      sym_comment,
      sym_block_comment,
  [681340] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9168), 1,
      anon_sym_DOT,
    STATE(17762), 2,
      sym_comment,
      sym_block_comment,
  [681354] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22973), 1,
      anon_sym_EQ,
    STATE(17763), 2,
      sym_comment,
      sym_block_comment,
  [681368] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22975), 1,
      anon_sym_EQ,
    STATE(17764), 2,
      sym_comment,
      sym_block_comment,
  [681382] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22977), 1,
      anon_sym_EQ_GT,
    STATE(17765), 2,
      sym_comment,
      sym_block_comment,
  [681396] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22979), 1,
      anon_sym_else,
    STATE(17766), 2,
      sym_comment,
      sym_block_comment,
  [681410] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22981), 1,
      anon_sym_do,
    STATE(17767), 2,
      sym_comment,
      sym_block_comment,
  [681424] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13210), 1,
      anon_sym_DOT,
    STATE(17768), 2,
      sym_comment,
      sym_block_comment,
  [681438] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22983), 1,
      anon_sym_RBRACE,
    STATE(17769), 2,
      sym_comment,
      sym_block_comment,
  [681452] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22985), 1,
      anon_sym_RPAREN,
    STATE(17770), 2,
      sym_comment,
      sym_block_comment,
  [681466] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22987), 1,
      sym__outdent,
    STATE(17771), 2,
      sym_comment,
      sym_block_comment,
  [681480] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22989), 1,
      anon_sym_RBRACE,
    STATE(17772), 2,
      sym_comment,
      sym_block_comment,
  [681494] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22989), 1,
      anon_sym_RPAREN,
    STATE(17773), 2,
      sym_comment,
      sym_block_comment,
  [681508] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10594), 1,
      anon_sym_DOT,
    STATE(17774), 2,
      sym_comment,
      sym_block_comment,
  [681522] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22991), 1,
      anon_sym_RPAREN,
    STATE(17775), 2,
      sym_comment,
      sym_block_comment,
  [681536] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22993), 1,
      anon_sym_RPAREN,
    STATE(17776), 2,
      sym_comment,
      sym_block_comment,
  [681550] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22995), 1,
      sym__outdent,
    STATE(17777), 2,
      sym_comment,
      sym_block_comment,
  [681564] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22997), 1,
      anon_sym_else,
    STATE(17778), 2,
      sym_comment,
      sym_block_comment,
  [681578] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22999), 1,
      anon_sym_RBRACK,
    STATE(17779), 2,
      sym_comment,
      sym_block_comment,
  [681592] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15408), 1,
      anon_sym_DOT,
    STATE(17780), 2,
      sym_comment,
      sym_block_comment,
  [681606] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22999), 1,
      anon_sym_RBRACE,
    STATE(17781), 2,
      sym_comment,
      sym_block_comment,
  [681620] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23001), 1,
      anon_sym_RBRACK,
    STATE(17782), 2,
      sym_comment,
      sym_block_comment,
  [681634] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23001), 1,
      anon_sym_RBRACE,
    STATE(17783), 2,
      sym_comment,
      sym_block_comment,
  [681648] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23003), 1,
      anon_sym_RPAREN,
    STATE(17784), 2,
      sym_comment,
      sym_block_comment,
  [681662] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23005), 1,
      anon_sym_RPAREN,
    STATE(17785), 2,
      sym_comment,
      sym_block_comment,
  [681676] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9036), 1,
      anon_sym_DOT,
    STATE(17786), 2,
      sym_comment,
      sym_block_comment,
  [681690] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23005), 1,
      anon_sym_RBRACE,
    STATE(17787), 2,
      sym_comment,
      sym_block_comment,
  [681704] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23007), 1,
      sym__outdent,
    STATE(17788), 2,
      sym_comment,
      sym_block_comment,
  [681718] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23009), 1,
      sym__outdent,
    STATE(17789), 2,
      sym_comment,
      sym_block_comment,
  [681732] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23011), 1,
      anon_sym_else,
    STATE(17790), 2,
      sym_comment,
      sym_block_comment,
  [681746] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23013), 1,
      anon_sym_do,
    STATE(17791), 2,
      sym_comment,
      sym_block_comment,
  [681760] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10735), 1,
      anon_sym_DOT,
    STATE(17792), 2,
      sym_comment,
      sym_block_comment,
  [681774] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23015), 1,
      anon_sym_RBRACE,
    STATE(17793), 2,
      sym_comment,
      sym_block_comment,
  [681788] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23017), 1,
      anon_sym_RBRACE,
    STATE(17794), 2,
      sym_comment,
      sym_block_comment,
  [681802] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23019), 1,
      sym__outdent,
    STATE(17795), 2,
      sym_comment,
      sym_block_comment,
  [681816] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23021), 1,
      anon_sym_RBRACE,
    STATE(17796), 2,
      sym_comment,
      sym_block_comment,
  [681830] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23021), 1,
      anon_sym_RPAREN,
    STATE(17797), 2,
      sym_comment,
      sym_block_comment,
  [681844] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15344), 1,
      anon_sym_DOT,
    STATE(17798), 2,
      sym_comment,
      sym_block_comment,
  [681858] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23023), 1,
      anon_sym_RPAREN,
    STATE(17799), 2,
      sym_comment,
      sym_block_comment,
  [681872] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23025), 1,
      sym__outdent,
    STATE(17800), 2,
      sym_comment,
      sym_block_comment,
  [681886] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23027), 1,
      anon_sym_LPAREN,
    STATE(17801), 2,
      sym_comment,
      sym_block_comment,
  [681900] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23029), 1,
      anon_sym_do,
    STATE(17802), 2,
      sym_comment,
      sym_block_comment,
  [681914] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23031), 1,
      anon_sym_else,
    STATE(17803), 2,
      sym_comment,
      sym_block_comment,
  [681928] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10156), 1,
      anon_sym_DOT,
    STATE(17804), 2,
      sym_comment,
      sym_block_comment,
  [681942] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23033), 1,
      anon_sym_RBRACE,
    STATE(17805), 2,
      sym_comment,
      sym_block_comment,
  [681956] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23035), 1,
      anon_sym_RPAREN,
    STATE(17806), 2,
      sym_comment,
      sym_block_comment,
  [681970] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23037), 1,
      sym__outdent,
    STATE(17807), 2,
      sym_comment,
      sym_block_comment,
  [681984] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23039), 1,
      anon_sym_EQ_GT_GT,
    STATE(17808), 2,
      sym_comment,
      sym_block_comment,
  [681998] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23041), 1,
      anon_sym_else,
    STATE(17809), 2,
      sym_comment,
      sym_block_comment,
  [682012] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10551), 1,
      anon_sym_DOT,
    STATE(17810), 2,
      sym_comment,
      sym_block_comment,
  [682026] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23043), 1,
      anon_sym_EQ_GT_GT,
    STATE(17811), 2,
      sym_comment,
      sym_block_comment,
  [682040] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23045), 1,
      anon_sym_EQ_GT_GT,
    STATE(17812), 2,
      sym_comment,
      sym_block_comment,
  [682054] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7764), 1,
      anon_sym_DOT,
    STATE(17813), 2,
      sym_comment,
      sym_block_comment,
  [682068] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23047), 1,
      anon_sym_else,
    STATE(17814), 2,
      sym_comment,
      sym_block_comment,
  [682082] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23049), 1,
      anon_sym_do,
    STATE(17815), 2,
      sym_comment,
      sym_block_comment,
  [682096] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8648), 1,
      anon_sym_DOT,
    STATE(17816), 2,
      sym_comment,
      sym_block_comment,
  [682110] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23051), 1,
      anon_sym_COLON,
    STATE(17817), 2,
      sym_comment,
      sym_block_comment,
  [682124] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23053), 1,
      anon_sym_RBRACE,
    STATE(17818), 2,
      sym_comment,
      sym_block_comment,
  [682138] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23055), 1,
      sym__outdent,
    STATE(17819), 2,
      sym_comment,
      sym_block_comment,
  [682152] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23057), 1,
      anon_sym_EQ_GT_GT,
    STATE(17820), 2,
      sym_comment,
      sym_block_comment,
  [682166] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23059), 1,
      sym__outdent,
    STATE(17821), 2,
      sym_comment,
      sym_block_comment,
  [682180] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12031), 1,
      anon_sym_DOT,
    STATE(17822), 2,
      sym_comment,
      sym_block_comment,
  [682194] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(22985), 1,
      anon_sym_RBRACE,
    STATE(17823), 2,
      sym_comment,
      sym_block_comment,
  [682208] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23061), 1,
      anon_sym_RBRACE,
    STATE(17824), 2,
      sym_comment,
      sym_block_comment,
  [682222] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23063), 1,
      anon_sym_RPAREN,
    STATE(17825), 2,
      sym_comment,
      sym_block_comment,
  [682236] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23065), 1,
      anon_sym_RPAREN,
    STATE(17826), 2,
      sym_comment,
      sym_block_comment,
  [682250] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23067), 1,
      sym__outdent,
    STATE(17827), 2,
      sym_comment,
      sym_block_comment,
  [682264] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9155), 1,
      anon_sym_DOT,
    STATE(17828), 2,
      sym_comment,
      sym_block_comment,
  [682278] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23069), 1,
      anon_sym_EQ,
    STATE(17829), 2,
      sym_comment,
      sym_block_comment,
  [682292] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23071), 1,
      anon_sym_EQ,
    STATE(17830), 2,
      sym_comment,
      sym_block_comment,
  [682306] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23073), 1,
      anon_sym_else,
    STATE(17831), 2,
      sym_comment,
      sym_block_comment,
  [682320] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23075), 1,
      anon_sym_else,
    STATE(17832), 2,
      sym_comment,
      sym_block_comment,
  [682334] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23077), 1,
      anon_sym_RPAREN,
    STATE(17833), 2,
      sym_comment,
      sym_block_comment,
  [682348] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10580), 1,
      anon_sym_DOT,
    STATE(17834), 2,
      sym_comment,
      sym_block_comment,
  [682362] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23079), 1,
      sym__outdent,
    STATE(17835), 2,
      sym_comment,
      sym_block_comment,
  [682376] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23081), 1,
      anon_sym_else,
    STATE(17836), 2,
      sym_comment,
      sym_block_comment,
  [682390] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23083), 1,
      anon_sym_do,
    STATE(17837), 2,
      sym_comment,
      sym_block_comment,
  [682404] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23085), 1,
      anon_sym_RBRACE,
    STATE(17838), 2,
      sym_comment,
      sym_block_comment,
  [682418] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23087), 1,
      sym__outdent,
    STATE(17839), 2,
      sym_comment,
      sym_block_comment,
  [682432] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9719), 1,
      anon_sym_DOT,
    STATE(17840), 2,
      sym_comment,
      sym_block_comment,
  [682446] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23089), 1,
      anon_sym_RBRACE,
    STATE(17841), 2,
      sym_comment,
      sym_block_comment,
  [682460] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23091), 1,
      anon_sym_EQ_GT,
    STATE(17842), 2,
      sym_comment,
      sym_block_comment,
  [682474] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23093), 1,
      sym__outdent,
    STATE(17843), 2,
      sym_comment,
      sym_block_comment,
  [682488] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23095), 1,
      anon_sym_EQ_GT,
    STATE(17844), 2,
      sym_comment,
      sym_block_comment,
  [682502] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23089), 1,
      anon_sym_RPAREN,
    STATE(17845), 2,
      sym_comment,
      sym_block_comment,
  [682516] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13379), 1,
      anon_sym_DOT,
    STATE(17846), 2,
      sym_comment,
      sym_block_comment,
  [682530] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23097), 1,
      anon_sym_RPAREN,
    STATE(17847), 2,
      sym_comment,
      sym_block_comment,
  [682544] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23099), 1,
      sym__outdent,
    STATE(17848), 2,
      sym_comment,
      sym_block_comment,
  [682558] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23101), 1,
      anon_sym_RPAREN,
    STATE(17849), 2,
      sym_comment,
      sym_block_comment,
  [682572] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23103), 1,
      anon_sym_else,
    STATE(17850), 2,
      sym_comment,
      sym_block_comment,
  [682586] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23105), 1,
      anon_sym_RPAREN,
    STATE(17851), 2,
      sym_comment,
      sym_block_comment,
  [682600] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10785), 1,
      anon_sym_DOT,
    STATE(17852), 2,
      sym_comment,
      sym_block_comment,
  [682614] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23107), 1,
      anon_sym_RBRACK,
    STATE(17853), 2,
      sym_comment,
      sym_block_comment,
  [682628] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23107), 1,
      anon_sym_RBRACE,
    STATE(17854), 2,
      sym_comment,
      sym_block_comment,
  [682642] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23109), 1,
      anon_sym_RBRACK,
    STATE(17855), 2,
      sym_comment,
      sym_block_comment,
  [682656] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23109), 1,
      anon_sym_RBRACE,
    STATE(17856), 2,
      sym_comment,
      sym_block_comment,
  [682670] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23111), 1,
      anon_sym_EQ_GT_GT,
    STATE(17857), 2,
      sym_comment,
      sym_block_comment,
  [682684] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15220), 1,
      anon_sym_DOT,
    STATE(17858), 2,
      sym_comment,
      sym_block_comment,
  [682698] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23113), 1,
      anon_sym_RBRACK,
    STATE(17859), 2,
      sym_comment,
      sym_block_comment,
  [682712] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23115), 1,
      anon_sym_RPAREN,
    STATE(17860), 2,
      sym_comment,
      sym_block_comment,
  [682726] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23115), 1,
      anon_sym_RBRACE,
    STATE(17861), 2,
      sym_comment,
      sym_block_comment,
  [682740] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23117), 1,
      sym__outdent,
    STATE(17862), 2,
      sym_comment,
      sym_block_comment,
  [682754] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23119), 1,
      anon_sym_EQ_GT_GT,
    STATE(17863), 2,
      sym_comment,
      sym_block_comment,
  [682768] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11265), 1,
      anon_sym_DOT,
    STATE(17864), 2,
      sym_comment,
      sym_block_comment,
  [682782] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23121), 1,
      sym__outdent,
    STATE(17865), 2,
      sym_comment,
      sym_block_comment,
  [682796] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23123), 1,
      anon_sym_EQ_GT_GT,
    STATE(17866), 2,
      sym_comment,
      sym_block_comment,
  [682810] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23125), 1,
      anon_sym_else,
    STATE(17867), 2,
      sym_comment,
      sym_block_comment,
  [682824] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23127), 1,
      anon_sym_RBRACE,
    STATE(17868), 2,
      sym_comment,
      sym_block_comment,
  [682838] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23129), 1,
      anon_sym_EQ_GT_GT,
    STATE(17869), 2,
      sym_comment,
      sym_block_comment,
  [682852] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12718), 1,
      anon_sym_DOT,
    STATE(17870), 2,
      sym_comment,
      sym_block_comment,
  [682866] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23131), 1,
      anon_sym_do,
    STATE(17871), 2,
      sym_comment,
      sym_block_comment,
  [682880] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23133), 1,
      anon_sym_RBRACE,
    STATE(17872), 2,
      sym_comment,
      sym_block_comment,
  [682894] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23135), 1,
      sym__outdent,
    STATE(17873), 2,
      sym_comment,
      sym_block_comment,
  [682908] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23137), 1,
      anon_sym_RBRACE,
    STATE(17874), 2,
      sym_comment,
      sym_block_comment,
  [682922] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23137), 1,
      anon_sym_RPAREN,
    STATE(17875), 2,
      sym_comment,
      sym_block_comment,
  [682936] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(8847), 1,
      anon_sym_DOT,
    STATE(17876), 2,
      sym_comment,
      sym_block_comment,
  [682950] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23139), 1,
      anon_sym_RPAREN,
    STATE(17877), 2,
      sym_comment,
      sym_block_comment,
  [682964] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23141), 1,
      anon_sym_do,
    STATE(17878), 2,
      sym_comment,
      sym_block_comment,
  [682978] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23143), 1,
      sym__outdent,
    STATE(17879), 2,
      sym_comment,
      sym_block_comment,
  [682992] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23145), 1,
      anon_sym_RBRACE,
    STATE(17880), 2,
      sym_comment,
      sym_block_comment,
  [683006] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23147), 1,
      anon_sym_else,
    STATE(17881), 2,
      sym_comment,
      sym_block_comment,
  [683020] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9632), 1,
      anon_sym_DOT,
    STATE(17882), 2,
      sym_comment,
      sym_block_comment,
  [683034] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15759), 1,
      anon_sym_DOT,
    STATE(17883), 2,
      sym_comment,
      sym_block_comment,
  [683048] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23149), 1,
      anon_sym_EQ_GT_GT,
    STATE(17884), 2,
      sym_comment,
      sym_block_comment,
  [683062] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23151), 1,
      anon_sym_LPAREN,
    STATE(17885), 2,
      sym_comment,
      sym_block_comment,
  [683076] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23153), 1,
      anon_sym_RPAREN,
    STATE(17886), 2,
      sym_comment,
      sym_block_comment,
  [683090] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23155), 1,
      sym__outdent,
    STATE(17887), 2,
      sym_comment,
      sym_block_comment,
  [683104] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13549), 1,
      anon_sym_DOT,
    STATE(17888), 2,
      sym_comment,
      sym_block_comment,
  [683118] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23157), 1,
      anon_sym_EQ_GT_GT,
    STATE(17889), 2,
      sym_comment,
      sym_block_comment,
  [683132] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23159), 1,
      anon_sym_EQ_GT_GT,
    STATE(17890), 2,
      sym_comment,
      sym_block_comment,
  [683146] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23161), 1,
      anon_sym_EQ_GT,
    STATE(17891), 2,
      sym_comment,
      sym_block_comment,
  [683160] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23163), 1,
      sym__outdent,
    STATE(17892), 2,
      sym_comment,
      sym_block_comment,
  [683174] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23165), 1,
      anon_sym_else,
    STATE(17893), 2,
      sym_comment,
      sym_block_comment,
  [683188] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9527), 1,
      anon_sym_DOT,
    STATE(17894), 2,
      sym_comment,
      sym_block_comment,
  [683202] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23167), 1,
      anon_sym_do,
    STATE(17895), 2,
      sym_comment,
      sym_block_comment,
  [683216] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23169), 1,
      sym__outdent,
    STATE(17896), 2,
      sym_comment,
      sym_block_comment,
  [683230] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23171), 1,
      anon_sym_else,
    STATE(17897), 2,
      sym_comment,
      sym_block_comment,
  [683244] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23173), 1,
      anon_sym_EQ,
    STATE(17898), 2,
      sym_comment,
      sym_block_comment,
  [683258] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23175), 1,
      sym__outdent,
    STATE(17899), 2,
      sym_comment,
      sym_block_comment,
  [683272] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10303), 1,
      anon_sym_DOT,
    STATE(17900), 2,
      sym_comment,
      sym_block_comment,
  [683286] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23177), 1,
      anon_sym_RPAREN,
    STATE(17901), 2,
      sym_comment,
      sym_block_comment,
  [683300] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23061), 1,
      anon_sym_RPAREN,
    STATE(17902), 2,
      sym_comment,
      sym_block_comment,
  [683314] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23179), 1,
      anon_sym_RPAREN,
    STATE(17903), 2,
      sym_comment,
      sym_block_comment,
  [683328] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23181), 1,
      anon_sym_EQ_GT_GT,
    STATE(17904), 2,
      sym_comment,
      sym_block_comment,
  [683342] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23183), 1,
      sym__outdent,
    STATE(17905), 2,
      sym_comment,
      sym_block_comment,
  [683356] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(14306), 1,
      anon_sym_DOT,
    STATE(17906), 2,
      sym_comment,
      sym_block_comment,
  [683370] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23185), 1,
      sym__outdent,
    STATE(17907), 2,
      sym_comment,
      sym_block_comment,
  [683384] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23187), 1,
      sym__outdent,
    STATE(17908), 2,
      sym_comment,
      sym_block_comment,
  [683398] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23189), 1,
      anon_sym_else,
    STATE(17909), 2,
      sym_comment,
      sym_block_comment,
  [683412] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23191), 1,
      anon_sym_RPAREN,
    STATE(17910), 2,
      sym_comment,
      sym_block_comment,
  [683426] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23193), 1,
      sym__outdent,
    STATE(17911), 2,
      sym_comment,
      sym_block_comment,
  [683440] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23195), 1,
      anon_sym_else,
    STATE(17912), 2,
      sym_comment,
      sym_block_comment,
  [683454] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23197), 1,
      anon_sym_do,
    STATE(17913), 2,
      sym_comment,
      sym_block_comment,
  [683468] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23199), 1,
      anon_sym_RPAREN,
    STATE(17914), 2,
      sym_comment,
      sym_block_comment,
  [683482] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23201), 1,
      anon_sym_RBRACE,
    STATE(17915), 2,
      sym_comment,
      sym_block_comment,
  [683496] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23203), 1,
      anon_sym_EQ,
    STATE(17916), 2,
      sym_comment,
      sym_block_comment,
  [683510] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23205), 1,
      sym__outdent,
    STATE(17917), 2,
      sym_comment,
      sym_block_comment,
  [683524] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23207), 1,
      anon_sym_RBRACE,
    STATE(17918), 2,
      sym_comment,
      sym_block_comment,
  [683538] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23209), 1,
      anon_sym_else,
    STATE(17919), 2,
      sym_comment,
      sym_block_comment,
  [683552] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23207), 1,
      anon_sym_RPAREN,
    STATE(17920), 2,
      sym_comment,
      sym_block_comment,
  [683566] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23211), 1,
      anon_sym_RPAREN,
    STATE(17921), 2,
      sym_comment,
      sym_block_comment,
  [683580] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23213), 1,
      sym__outdent,
    STATE(17922), 2,
      sym_comment,
      sym_block_comment,
  [683594] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23215), 1,
      anon_sym_else,
    STATE(17923), 2,
      sym_comment,
      sym_block_comment,
  [683608] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23217), 1,
      anon_sym_RPAREN,
    STATE(17924), 2,
      sym_comment,
      sym_block_comment,
  [683622] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23219), 1,
      sym__outdent,
    STATE(17925), 2,
      sym_comment,
      sym_block_comment,
  [683636] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23221), 1,
      anon_sym_else,
    STATE(17926), 2,
      sym_comment,
      sym_block_comment,
  [683650] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23223), 1,
      anon_sym_RBRACE,
    STATE(17927), 2,
      sym_comment,
      sym_block_comment,
  [683664] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23225), 1,
      anon_sym_EQ_GT,
    STATE(17928), 2,
      sym_comment,
      sym_block_comment,
  [683678] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23227), 1,
      sym__outdent,
    STATE(17929), 2,
      sym_comment,
      sym_block_comment,
  [683692] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23229), 1,
      anon_sym_EQ_GT,
    STATE(17930), 2,
      sym_comment,
      sym_block_comment,
  [683706] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23231), 1,
      sym__outdent,
    STATE(17931), 2,
      sym_comment,
      sym_block_comment,
  [683720] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23233), 1,
      anon_sym_RBRACE,
    STATE(17932), 2,
      sym_comment,
      sym_block_comment,
  [683734] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23235), 1,
      anon_sym_RPAREN,
    STATE(17933), 2,
      sym_comment,
      sym_block_comment,
  [683748] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23237), 1,
      anon_sym_type,
    STATE(17934), 2,
      sym_comment,
      sym_block_comment,
  [683762] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23239), 1,
      sym__outdent,
    STATE(17935), 2,
      sym_comment,
      sym_block_comment,
  [683776] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23241), 1,
      anon_sym_LPAREN,
    STATE(17936), 2,
      sym_comment,
      sym_block_comment,
  [683790] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23243), 1,
      anon_sym_RPAREN,
    STATE(17937), 2,
      sym_comment,
      sym_block_comment,
  [683804] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23245), 1,
      anon_sym_RPAREN,
    STATE(17938), 2,
      sym_comment,
      sym_block_comment,
  [683818] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23247), 1,
      sym__outdent,
    STATE(17939), 2,
      sym_comment,
      sym_block_comment,
  [683832] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23249), 1,
      anon_sym_RBRACE,
    STATE(17940), 2,
      sym_comment,
      sym_block_comment,
  [683846] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23251), 1,
      anon_sym_RBRACE,
    STATE(17941), 2,
      sym_comment,
      sym_block_comment,
  [683860] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11854), 1,
      anon_sym_DOT,
    STATE(17942), 2,
      sym_comment,
      sym_block_comment,
  [683874] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23253), 1,
      anon_sym_with,
    STATE(17943), 2,
      sym_comment,
      sym_block_comment,
  [683888] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23255), 1,
      anon_sym_RPAREN,
    STATE(17944), 2,
      sym_comment,
      sym_block_comment,
  [683902] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23257), 1,
      anon_sym_COLON,
    STATE(17945), 2,
      sym_comment,
      sym_block_comment,
  [683916] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23259), 1,
      anon_sym_RBRACK,
    STATE(17946), 2,
      sym_comment,
      sym_block_comment,
  [683930] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23259), 1,
      anon_sym_RBRACE,
    STATE(17947), 2,
      sym_comment,
      sym_block_comment,
  [683944] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23261), 1,
      anon_sym_RBRACK,
    STATE(17948), 2,
      sym_comment,
      sym_block_comment,
  [683958] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23261), 1,
      anon_sym_RBRACE,
    STATE(17949), 2,
      sym_comment,
      sym_block_comment,
  [683972] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23263), 1,
      sym__outdent,
    STATE(17950), 2,
      sym_comment,
      sym_block_comment,
  [683986] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23265), 1,
      anon_sym_RBRACK,
    STATE(17951), 2,
      sym_comment,
      sym_block_comment,
  [684000] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23267), 1,
      anon_sym_RBRACE,
    STATE(17952), 2,
      sym_comment,
      sym_block_comment,
  [684014] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23269), 1,
      sym__outdent,
    STATE(17953), 2,
      sym_comment,
      sym_block_comment,
  [684028] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23271), 1,
      anon_sym_RPAREN,
    STATE(17954), 2,
      sym_comment,
      sym_block_comment,
  [684042] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23271), 1,
      anon_sym_RBRACE,
    STATE(17955), 2,
      sym_comment,
      sym_block_comment,
  [684056] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23273), 1,
      sym__outdent,
    STATE(17956), 2,
      sym_comment,
      sym_block_comment,
  [684070] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23275), 1,
      anon_sym_RPAREN,
    STATE(17957), 2,
      sym_comment,
      sym_block_comment,
  [684084] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23277), 1,
      sym__outdent,
    STATE(17958), 2,
      sym_comment,
      sym_block_comment,
  [684098] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23279), 1,
      anon_sym_RBRACE,
    STATE(17959), 2,
      sym_comment,
      sym_block_comment,
  [684112] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23281), 1,
      sym__outdent,
    STATE(17960), 2,
      sym_comment,
      sym_block_comment,
  [684126] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23283), 1,
      sym__outdent,
    STATE(17961), 2,
      sym_comment,
      sym_block_comment,
  [684140] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23285), 1,
      anon_sym_RBRACE,
    STATE(17962), 2,
      sym_comment,
      sym_block_comment,
  [684154] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23287), 1,
      sym__outdent,
    STATE(17963), 2,
      sym_comment,
      sym_block_comment,
  [684168] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23289), 1,
      anon_sym_RPAREN,
    STATE(17964), 2,
      sym_comment,
      sym_block_comment,
  [684182] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23291), 1,
      sym__outdent,
    STATE(17965), 2,
      sym_comment,
      sym_block_comment,
  [684196] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23293), 1,
      anon_sym_RBRACE,
    STATE(17966), 2,
      sym_comment,
      sym_block_comment,
  [684210] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15156), 1,
      anon_sym_type,
    STATE(17967), 2,
      sym_comment,
      sym_block_comment,
  [684224] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23295), 1,
      sym__outdent,
    STATE(17968), 2,
      sym_comment,
      sym_block_comment,
  [684238] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23297), 1,
      anon_sym_RPAREN,
    STATE(17969), 2,
      sym_comment,
      sym_block_comment,
  [684252] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23299), 1,
      sym__outdent,
    STATE(17970), 2,
      sym_comment,
      sym_block_comment,
  [684266] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23301), 1,
      anon_sym_RPAREN,
    STATE(17971), 2,
      sym_comment,
      sym_block_comment,
  [684280] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23303), 1,
      sym__outdent,
    STATE(17972), 2,
      sym_comment,
      sym_block_comment,
  [684294] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7746), 1,
      anon_sym_type,
    STATE(17973), 2,
      sym_comment,
      sym_block_comment,
  [684308] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23305), 1,
      anon_sym_RBRACE,
    STATE(17974), 2,
      sym_comment,
      sym_block_comment,
  [684322] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23307), 1,
      anon_sym_do,
    STATE(17975), 2,
      sym_comment,
      sym_block_comment,
  [684336] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23309), 1,
      sym__outdent,
    STATE(17976), 2,
      sym_comment,
      sym_block_comment,
  [684350] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(12928), 1,
      anon_sym_DOT,
    STATE(17977), 2,
      sym_comment,
      sym_block_comment,
  [684364] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23311), 1,
      anon_sym_RBRACE,
    STATE(17978), 2,
      sym_comment,
      sym_block_comment,
  [684378] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23313), 1,
      anon_sym_RPAREN,
    STATE(17979), 2,
      sym_comment,
      sym_block_comment,
  [684392] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23315), 1,
      sym__indent,
    STATE(17980), 2,
      sym_comment,
      sym_block_comment,
  [684406] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7728), 1,
      anon_sym_type,
    STATE(17981), 2,
      sym_comment,
      sym_block_comment,
  [684420] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15398), 1,
      anon_sym_type,
    STATE(17982), 2,
      sym_comment,
      sym_block_comment,
  [684434] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9738), 1,
      anon_sym_EQ_GT,
    STATE(17983), 2,
      sym_comment,
      sym_block_comment,
  [684448] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23317), 1,
      sym__indent,
    STATE(17984), 2,
      sym_comment,
      sym_block_comment,
  [684462] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9515), 1,
      anon_sym_EQ_GT,
    STATE(17985), 2,
      sym_comment,
      sym_block_comment,
  [684476] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9519), 1,
      anon_sym_EQ_GT,
    STATE(17986), 2,
      sym_comment,
      sym_block_comment,
  [684490] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23319), 1,
      anon_sym_type,
    STATE(17987), 2,
      sym_comment,
      sym_block_comment,
  [684504] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23321), 1,
      sym__outdent,
    STATE(17988), 2,
      sym_comment,
      sym_block_comment,
  [684518] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9556), 1,
      anon_sym_EQ_GT,
    STATE(17989), 2,
      sym_comment,
      sym_block_comment,
  [684532] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23323), 1,
      anon_sym_RPAREN,
    STATE(17990), 2,
      sym_comment,
      sym_block_comment,
  [684546] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9626), 1,
      anon_sym_EQ_GT,
    STATE(17991), 2,
      sym_comment,
      sym_block_comment,
  [684560] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9409), 1,
      anon_sym_EQ_GT,
    STATE(17992), 2,
      sym_comment,
      sym_block_comment,
  [684574] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9417), 1,
      anon_sym_EQ_GT,
    STATE(17993), 2,
      sym_comment,
      sym_block_comment,
  [684588] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9413), 1,
      anon_sym_EQ_GT,
    STATE(17994), 2,
      sym_comment,
      sym_block_comment,
  [684602] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23325), 1,
      sym__outdent,
    STATE(17995), 2,
      sym_comment,
      sym_block_comment,
  [684616] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23327), 1,
      anon_sym_RBRACE,
    STATE(17996), 2,
      sym_comment,
      sym_block_comment,
  [684630] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23329), 1,
      sym__outdent,
    STATE(17997), 2,
      sym_comment,
      sym_block_comment,
  [684644] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11675), 1,
      anon_sym_EQ_GT,
    STATE(17998), 2,
      sym_comment,
      sym_block_comment,
  [684658] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23331), 1,
      anon_sym_RPAREN,
    STATE(17999), 2,
      sym_comment,
      sym_block_comment,
  [684672] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7880), 1,
      anon_sym_EQ_GT,
    STATE(18000), 2,
      sym_comment,
      sym_block_comment,
  [684686] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23333), 1,
      sym__indent,
    STATE(18001), 2,
      sym_comment,
      sym_block_comment,
  [684700] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11685), 1,
      anon_sym_EQ_GT,
    STATE(18002), 2,
      sym_comment,
      sym_block_comment,
  [684714] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11689), 1,
      anon_sym_EQ_GT,
    STATE(18003), 2,
      sym_comment,
      sym_block_comment,
  [684728] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23335), 1,
      anon_sym_RPAREN,
    STATE(18004), 2,
      sym_comment,
      sym_block_comment,
  [684742] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11701), 1,
      anon_sym_EQ_GT,
    STATE(18005), 2,
      sym_comment,
      sym_block_comment,
  [684756] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23337), 1,
      anon_sym_RPAREN,
    STATE(18006), 2,
      sym_comment,
      sym_block_comment,
  [684770] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11707), 1,
      anon_sym_EQ_GT,
    STATE(18007), 2,
      sym_comment,
      sym_block_comment,
  [684784] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11723), 1,
      anon_sym_EQ_GT,
    STATE(18008), 2,
      sym_comment,
      sym_block_comment,
  [684798] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11789), 1,
      anon_sym_EQ_GT,
    STATE(18009), 2,
      sym_comment,
      sym_block_comment,
  [684812] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11817), 1,
      anon_sym_EQ_GT,
    STATE(18010), 2,
      sym_comment,
      sym_block_comment,
  [684826] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13350), 1,
      sym__indent,
    STATE(18011), 2,
      sym_comment,
      sym_block_comment,
  [684840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23339), 1,
      sym__outdent,
    STATE(18012), 2,
      sym_comment,
      sym_block_comment,
  [684854] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11739), 1,
      anon_sym_EQ_GT,
    STATE(18013), 2,
      sym_comment,
      sym_block_comment,
  [684868] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23341), 1,
      anon_sym_RPAREN,
    STATE(18014), 2,
      sym_comment,
      sym_block_comment,
  [684882] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11623), 1,
      anon_sym_EQ_GT,
    STATE(18015), 2,
      sym_comment,
      sym_block_comment,
  [684896] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23343), 1,
      anon_sym_RPAREN,
    STATE(18016), 2,
      sym_comment,
      sym_block_comment,
  [684910] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23345), 1,
      anon_sym_RPAREN,
    STATE(18017), 2,
      sym_comment,
      sym_block_comment,
  [684924] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23347), 1,
      anon_sym_RPAREN,
    STATE(18018), 2,
      sym_comment,
      sym_block_comment,
  [684938] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23349), 1,
      sym__indent,
    STATE(18019), 2,
      sym_comment,
      sym_block_comment,
  [684952] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23351), 1,
      sym__outdent,
    STATE(18020), 2,
      sym_comment,
      sym_block_comment,
  [684966] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23353), 1,
      anon_sym_RPAREN,
    STATE(18021), 2,
      sym_comment,
      sym_block_comment,
  [684980] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23355), 1,
      anon_sym_RBRACE,
    STATE(18022), 2,
      sym_comment,
      sym_block_comment,
  [684994] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23357), 1,
      sym__outdent,
    STATE(18023), 2,
      sym_comment,
      sym_block_comment,
  [685008] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23359), 1,
      anon_sym_RPAREN,
    STATE(18024), 2,
      sym_comment,
      sym_block_comment,
  [685022] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23361), 1,
      sym__outdent,
    STATE(18025), 2,
      sym_comment,
      sym_block_comment,
  [685036] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23363), 1,
      sym__indent,
    STATE(18026), 2,
      sym_comment,
      sym_block_comment,
  [685050] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23365), 1,
      anon_sym_RBRACE,
    STATE(18027), 2,
      sym_comment,
      sym_block_comment,
  [685064] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23367), 1,
      anon_sym_RPAREN,
    STATE(18028), 2,
      sym_comment,
      sym_block_comment,
  [685078] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23369), 1,
      anon_sym_RBRACE,
    STATE(18029), 2,
      sym_comment,
      sym_block_comment,
  [685092] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23371), 1,
      anon_sym_RPAREN,
    STATE(18030), 2,
      sym_comment,
      sym_block_comment,
  [685106] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23373), 1,
      sym__outdent,
    STATE(18031), 2,
      sym_comment,
      sym_block_comment,
  [685120] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23375), 1,
      sym__outdent,
    STATE(18032), 2,
      sym_comment,
      sym_block_comment,
  [685134] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23377), 1,
      sym__indent,
    STATE(18033), 2,
      sym_comment,
      sym_block_comment,
  [685148] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23379), 1,
      anon_sym_RPAREN,
    STATE(18034), 2,
      sym_comment,
      sym_block_comment,
  [685162] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23381), 1,
      sym__outdent,
    STATE(18035), 2,
      sym_comment,
      sym_block_comment,
  [685176] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23383), 1,
      anon_sym_RPAREN,
    STATE(18036), 2,
      sym_comment,
      sym_block_comment,
  [685190] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23385), 1,
      anon_sym_RBRACE,
    STATE(18037), 2,
      sym_comment,
      sym_block_comment,
  [685204] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23387), 1,
      anon_sym_RPAREN,
    STATE(18038), 2,
      sym_comment,
      sym_block_comment,
  [685218] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23389), 1,
      sym__outdent,
    STATE(18039), 2,
      sym_comment,
      sym_block_comment,
  [685232] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23391), 1,
      sym__indent,
    STATE(18040), 2,
      sym_comment,
      sym_block_comment,
  [685246] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23393), 1,
      sym__outdent,
    STATE(18041), 2,
      sym_comment,
      sym_block_comment,
  [685260] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23395), 1,
      anon_sym_RPAREN,
    STATE(18042), 2,
      sym_comment,
      sym_block_comment,
  [685274] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23397), 1,
      sym__outdent,
    STATE(18043), 2,
      sym_comment,
      sym_block_comment,
  [685288] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23399), 1,
      sym__outdent,
    STATE(18044), 2,
      sym_comment,
      sym_block_comment,
  [685302] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23401), 1,
      anon_sym_RPAREN,
    STATE(18045), 2,
      sym_comment,
      sym_block_comment,
  [685316] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23403), 1,
      anon_sym_RBRACE,
    STATE(18046), 2,
      sym_comment,
      sym_block_comment,
  [685330] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23405), 1,
      sym__indent,
    STATE(18047), 2,
      sym_comment,
      sym_block_comment,
  [685344] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23407), 1,
      sym__outdent,
    STATE(18048), 2,
      sym_comment,
      sym_block_comment,
  [685358] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23409), 1,
      anon_sym_RBRACE,
    STATE(18049), 2,
      sym_comment,
      sym_block_comment,
  [685372] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23411), 1,
      sym__outdent,
    STATE(18050), 2,
      sym_comment,
      sym_block_comment,
  [685386] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23413), 1,
      anon_sym_RPAREN,
    STATE(18051), 2,
      sym_comment,
      sym_block_comment,
  [685400] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23415), 1,
      anon_sym_RPAREN,
    STATE(18052), 2,
      sym_comment,
      sym_block_comment,
  [685414] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23417), 1,
      sym__outdent,
    STATE(18053), 2,
      sym_comment,
      sym_block_comment,
  [685428] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23419), 1,
      sym__indent,
    STATE(18054), 2,
      sym_comment,
      sym_block_comment,
  [685442] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23421), 1,
      anon_sym_RPAREN,
    STATE(18055), 2,
      sym_comment,
      sym_block_comment,
  [685456] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23423), 1,
      anon_sym_RBRACE,
    STATE(18056), 2,
      sym_comment,
      sym_block_comment,
  [685470] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23425), 1,
      sym__outdent,
    STATE(18057), 2,
      sym_comment,
      sym_block_comment,
  [685484] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23427), 1,
      sym__outdent,
    STATE(18058), 2,
      sym_comment,
      sym_block_comment,
  [685498] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23429), 1,
      anon_sym_RPAREN,
    STATE(18059), 2,
      sym_comment,
      sym_block_comment,
  [685512] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23431), 1,
      anon_sym_RPAREN,
    STATE(18060), 2,
      sym_comment,
      sym_block_comment,
  [685526] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23433), 1,
      sym__indent,
    STATE(18061), 2,
      sym_comment,
      sym_block_comment,
  [685540] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23435), 1,
      sym__outdent,
    STATE(18062), 2,
      sym_comment,
      sym_block_comment,
  [685554] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23437), 1,
      anon_sym_RPAREN,
    STATE(18063), 2,
      sym_comment,
      sym_block_comment,
  [685568] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23439), 1,
      anon_sym_RPAREN,
    STATE(18064), 2,
      sym_comment,
      sym_block_comment,
  [685582] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23441), 1,
      sym__outdent,
    STATE(18065), 2,
      sym_comment,
      sym_block_comment,
  [685596] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23443), 1,
      anon_sym_RBRACE,
    STATE(18066), 2,
      sym_comment,
      sym_block_comment,
  [685610] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23445), 1,
      sym__outdent,
    STATE(18067), 2,
      sym_comment,
      sym_block_comment,
  [685624] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23447), 1,
      sym__indent,
    STATE(18068), 2,
      sym_comment,
      sym_block_comment,
  [685638] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23449), 1,
      anon_sym_RPAREN,
    STATE(18069), 2,
      sym_comment,
      sym_block_comment,
  [685652] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23451), 1,
      sym__outdent,
    STATE(18070), 2,
      sym_comment,
      sym_block_comment,
  [685666] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23453), 1,
      sym__outdent,
    STATE(18071), 2,
      sym_comment,
      sym_block_comment,
  [685680] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23455), 1,
      anon_sym_RPAREN,
    STATE(18072), 2,
      sym_comment,
      sym_block_comment,
  [685694] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23457), 1,
      anon_sym_RBRACE,
    STATE(18073), 2,
      sym_comment,
      sym_block_comment,
  [685708] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23459), 1,
      anon_sym_RPAREN,
    STATE(18074), 2,
      sym_comment,
      sym_block_comment,
  [685722] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23461), 1,
      sym__indent,
    STATE(18075), 2,
      sym_comment,
      sym_block_comment,
  [685736] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23463), 1,
      sym__outdent,
    STATE(18076), 2,
      sym_comment,
      sym_block_comment,
  [685750] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23465), 1,
      sym__outdent,
    STATE(18077), 2,
      sym_comment,
      sym_block_comment,
  [685764] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23467), 1,
      anon_sym_RPAREN,
    STATE(18078), 2,
      sym_comment,
      sym_block_comment,
  [685778] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23469), 1,
      sym__outdent,
    STATE(18079), 2,
      sym_comment,
      sym_block_comment,
  [685792] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23471), 1,
      anon_sym_RPAREN,
    STATE(18080), 2,
      sym_comment,
      sym_block_comment,
  [685806] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23473), 1,
      anon_sym_RBRACE,
    STATE(18081), 2,
      sym_comment,
      sym_block_comment,
  [685820] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23475), 1,
      sym__indent,
    STATE(18082), 2,
      sym_comment,
      sym_block_comment,
  [685834] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23477), 1,
      anon_sym_RPAREN,
    STATE(18083), 2,
      sym_comment,
      sym_block_comment,
  [685848] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23479), 1,
      sym__outdent,
    STATE(18084), 2,
      sym_comment,
      sym_block_comment,
  [685862] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23481), 1,
      sym__outdent,
    STATE(18085), 2,
      sym_comment,
      sym_block_comment,
  [685876] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23483), 1,
      anon_sym_RPAREN,
    STATE(18086), 2,
      sym_comment,
      sym_block_comment,
  [685890] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23485), 1,
      anon_sym_RBRACE,
    STATE(18087), 2,
      sym_comment,
      sym_block_comment,
  [685904] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23487), 1,
      sym__outdent,
    STATE(18088), 2,
      sym_comment,
      sym_block_comment,
  [685918] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23489), 1,
      sym__indent,
    STATE(18089), 2,
      sym_comment,
      sym_block_comment,
  [685932] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23491), 1,
      anon_sym_RPAREN,
    STATE(18090), 2,
      sym_comment,
      sym_block_comment,
  [685946] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23493), 1,
      anon_sym_RBRACE,
    STATE(18091), 2,
      sym_comment,
      sym_block_comment,
  [685960] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23495), 1,
      sym__outdent,
    STATE(18092), 2,
      sym_comment,
      sym_block_comment,
  [685974] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23497), 1,
      anon_sym_RPAREN,
    STATE(18093), 2,
      sym_comment,
      sym_block_comment,
  [685988] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23499), 1,
      anon_sym_EQ_GT_GT,
    STATE(18094), 2,
      sym_comment,
      sym_block_comment,
  [686002] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23501), 1,
      sym__outdent,
    STATE(18095), 2,
      sym_comment,
      sym_block_comment,
  [686016] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23503), 1,
      sym__indent,
    STATE(18096), 2,
      sym_comment,
      sym_block_comment,
  [686030] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23505), 1,
      anon_sym_RPAREN,
    STATE(18097), 2,
      sym_comment,
      sym_block_comment,
  [686044] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23507), 1,
      sym__outdent,
    STATE(18098), 2,
      sym_comment,
      sym_block_comment,
  [686058] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23509), 1,
      sym__outdent,
    STATE(18099), 2,
      sym_comment,
      sym_block_comment,
  [686072] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23511), 1,
      anon_sym_RPAREN,
    STATE(18100), 2,
      sym_comment,
      sym_block_comment,
  [686086] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23513), 1,
      anon_sym_RBRACE,
    STATE(18101), 2,
      sym_comment,
      sym_block_comment,
  [686100] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23515), 1,
      anon_sym_RPAREN,
    STATE(18102), 2,
      sym_comment,
      sym_block_comment,
  [686114] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23517), 1,
      sym__indent,
    STATE(18103), 2,
      sym_comment,
      sym_block_comment,
  [686128] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23519), 1,
      sym__outdent,
    STATE(18104), 2,
      sym_comment,
      sym_block_comment,
  [686142] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23521), 1,
      anon_sym_RBRACE,
    STATE(18105), 2,
      sym_comment,
      sym_block_comment,
  [686156] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23523), 1,
      sym__outdent,
    STATE(18106), 2,
      sym_comment,
      sym_block_comment,
  [686170] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23525), 1,
      anon_sym_RPAREN,
    STATE(18107), 2,
      sym_comment,
      sym_block_comment,
  [686184] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23527), 1,
      sym__outdent,
    STATE(18108), 2,
      sym_comment,
      sym_block_comment,
  [686198] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23529), 1,
      sym__outdent,
    STATE(18109), 2,
      sym_comment,
      sym_block_comment,
  [686212] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23531), 1,
      sym__indent,
    STATE(18110), 2,
      sym_comment,
      sym_block_comment,
  [686226] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23533), 1,
      sym__outdent,
    STATE(18111), 2,
      sym_comment,
      sym_block_comment,
  [686240] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23535), 1,
      anon_sym_RPAREN,
    STATE(18112), 2,
      sym_comment,
      sym_block_comment,
  [686254] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23537), 1,
      anon_sym_RPAREN,
    STATE(18113), 2,
      sym_comment,
      sym_block_comment,
  [686268] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23539), 1,
      anon_sym_RBRACE,
    STATE(18114), 2,
      sym_comment,
      sym_block_comment,
  [686282] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23541), 1,
      sym__outdent,
    STATE(18115), 2,
      sym_comment,
      sym_block_comment,
  [686296] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23543), 1,
      sym__indent,
    STATE(18116), 2,
      sym_comment,
      sym_block_comment,
  [686310] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23545), 1,
      anon_sym_RPAREN,
    STATE(18117), 2,
      sym_comment,
      sym_block_comment,
  [686324] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23547), 1,
      sym__outdent,
    STATE(18118), 2,
      sym_comment,
      sym_block_comment,
  [686338] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23549), 1,
      sym__outdent,
    STATE(18119), 2,
      sym_comment,
      sym_block_comment,
  [686352] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23551), 1,
      anon_sym_RPAREN,
    STATE(18120), 2,
      sym_comment,
      sym_block_comment,
  [686366] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23553), 1,
      anon_sym_RBRACE,
    STATE(18121), 2,
      sym_comment,
      sym_block_comment,
  [686380] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23555), 1,
      sym__indent,
    STATE(18122), 2,
      sym_comment,
      sym_block_comment,
  [686394] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23557), 1,
      sym__outdent,
    STATE(18123), 2,
      sym_comment,
      sym_block_comment,
  [686408] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23559), 1,
      anon_sym_RPAREN,
    STATE(18124), 2,
      sym_comment,
      sym_block_comment,
  [686422] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23561), 1,
      sym__outdent,
    STATE(18125), 2,
      sym_comment,
      sym_block_comment,
  [686436] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23563), 1,
      anon_sym_RBRACE,
    STATE(18126), 2,
      sym_comment,
      sym_block_comment,
  [686450] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23565), 1,
      anon_sym_EQ_GT_GT,
    STATE(18127), 2,
      sym_comment,
      sym_block_comment,
  [686464] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23567), 1,
      sym__indent,
    STATE(18128), 2,
      sym_comment,
      sym_block_comment,
  [686478] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23569), 1,
      anon_sym_RPAREN,
    STATE(18129), 2,
      sym_comment,
      sym_block_comment,
  [686492] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23571), 1,
      sym__outdent,
    STATE(18130), 2,
      sym_comment,
      sym_block_comment,
  [686506] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23573), 1,
      anon_sym_RPAREN,
    STATE(18131), 2,
      sym_comment,
      sym_block_comment,
  [686520] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23575), 1,
      anon_sym_EQ_GT_GT,
    STATE(18132), 2,
      sym_comment,
      sym_block_comment,
  [686534] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23577), 1,
      anon_sym_RBRACE,
    STATE(18133), 2,
      sym_comment,
      sym_block_comment,
  [686548] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23579), 1,
      sym__indent,
    STATE(18134), 2,
      sym_comment,
      sym_block_comment,
  [686562] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23581), 1,
      sym__outdent,
    STATE(18135), 2,
      sym_comment,
      sym_block_comment,
  [686576] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23583), 1,
      anon_sym_RPAREN,
    STATE(18136), 2,
      sym_comment,
      sym_block_comment,
  [686590] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23585), 1,
      sym__outdent,
    STATE(18137), 2,
      sym_comment,
      sym_block_comment,
  [686604] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23587), 1,
      anon_sym_RBRACE,
    STATE(18138), 2,
      sym_comment,
      sym_block_comment,
  [686618] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23589), 1,
      sym__outdent,
    STATE(18139), 2,
      sym_comment,
      sym_block_comment,
  [686632] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23591), 1,
      sym__indent,
    STATE(18140), 2,
      sym_comment,
      sym_block_comment,
  [686646] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23593), 1,
      anon_sym_RPAREN,
    STATE(18141), 2,
      sym_comment,
      sym_block_comment,
  [686660] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23595), 1,
      anon_sym_RBRACE,
    STATE(18142), 2,
      sym_comment,
      sym_block_comment,
  [686674] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23597), 1,
      anon_sym_RPAREN,
    STATE(18143), 2,
      sym_comment,
      sym_block_comment,
  [686688] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23599), 1,
      sym__outdent,
    STATE(18144), 2,
      sym_comment,
      sym_block_comment,
  [686702] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23601), 1,
      anon_sym_RPAREN,
    STATE(18145), 2,
      sym_comment,
      sym_block_comment,
  [686716] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23603), 1,
      sym__indent,
    STATE(18146), 2,
      sym_comment,
      sym_block_comment,
  [686730] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23605), 1,
      sym__outdent,
    STATE(18147), 2,
      sym_comment,
      sym_block_comment,
  [686744] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23607), 1,
      anon_sym_RPAREN,
    STATE(18148), 2,
      sym_comment,
      sym_block_comment,
  [686758] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23609), 1,
      sym__outdent,
    STATE(18149), 2,
      sym_comment,
      sym_block_comment,
  [686772] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23611), 1,
      sym__outdent,
    STATE(18150), 2,
      sym_comment,
      sym_block_comment,
  [686786] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23613), 1,
      anon_sym_RPAREN,
    STATE(18151), 2,
      sym_comment,
      sym_block_comment,
  [686800] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23615), 1,
      sym__indent,
    STATE(18152), 2,
      sym_comment,
      sym_block_comment,
  [686814] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23617), 1,
      anon_sym_RBRACE,
    STATE(18153), 2,
      sym_comment,
      sym_block_comment,
  [686828] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23619), 1,
      anon_sym_else,
    STATE(18154), 2,
      sym_comment,
      sym_block_comment,
  [686842] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23621), 1,
      sym__outdent,
    STATE(18155), 2,
      sym_comment,
      sym_block_comment,
  [686856] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23623), 1,
      sym__outdent,
    STATE(18156), 2,
      sym_comment,
      sym_block_comment,
  [686870] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23625), 1,
      anon_sym_RPAREN,
    STATE(18157), 2,
      sym_comment,
      sym_block_comment,
  [686884] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23627), 1,
      sym__indent,
    STATE(18158), 2,
      sym_comment,
      sym_block_comment,
  [686898] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23629), 1,
      sym__outdent,
    STATE(18159), 2,
      sym_comment,
      sym_block_comment,
  [686912] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23631), 1,
      anon_sym_RPAREN,
    STATE(18160), 2,
      sym_comment,
      sym_block_comment,
  [686926] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23633), 1,
      anon_sym_RBRACE,
    STATE(18161), 2,
      sym_comment,
      sym_block_comment,
  [686940] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23635), 1,
      anon_sym_RBRACE,
    STATE(18162), 2,
      sym_comment,
      sym_block_comment,
  [686954] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23637), 1,
      sym__outdent,
    STATE(18163), 2,
      sym_comment,
      sym_block_comment,
  [686968] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23639), 1,
      sym__indent,
    STATE(18164), 2,
      sym_comment,
      sym_block_comment,
  [686982] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23641), 1,
      anon_sym_RPAREN,
    STATE(18165), 2,
      sym_comment,
      sym_block_comment,
  [686996] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23643), 1,
      anon_sym_RBRACE,
    STATE(18166), 2,
      sym_comment,
      sym_block_comment,
  [687010] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23645), 1,
      anon_sym_RPAREN,
    STATE(18167), 2,
      sym_comment,
      sym_block_comment,
  [687024] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23647), 1,
      sym__outdent,
    STATE(18168), 2,
      sym_comment,
      sym_block_comment,
  [687038] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(21119), 1,
      anon_sym_EQ_GT,
    STATE(18169), 2,
      sym_comment,
      sym_block_comment,
  [687052] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23649), 1,
      sym__indent,
    STATE(18170), 2,
      sym_comment,
      sym_block_comment,
  [687066] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23651), 1,
      anon_sym_RPAREN,
    STATE(18171), 2,
      sym_comment,
      sym_block_comment,
  [687080] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23653), 1,
      sym__outdent,
    STATE(18172), 2,
      sym_comment,
      sym_block_comment,
  [687094] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23655), 1,
      anon_sym_RPAREN,
    STATE(18173), 2,
      sym_comment,
      sym_block_comment,
  [687108] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23657), 1,
      sym__outdent,
    STATE(18174), 2,
      sym_comment,
      sym_block_comment,
  [687122] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23659), 1,
      anon_sym_RBRACE,
    STATE(18175), 2,
      sym_comment,
      sym_block_comment,
  [687136] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23661), 1,
      sym__indent,
    STATE(18176), 2,
      sym_comment,
      sym_block_comment,
  [687150] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23663), 1,
      sym__outdent,
    STATE(18177), 2,
      sym_comment,
      sym_block_comment,
  [687164] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23665), 1,
      anon_sym_RPAREN,
    STATE(18178), 2,
      sym_comment,
      sym_block_comment,
  [687178] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23667), 1,
      anon_sym_RBRACE,
    STATE(18179), 2,
      sym_comment,
      sym_block_comment,
  [687192] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23669), 1,
      sym__outdent,
    STATE(18180), 2,
      sym_comment,
      sym_block_comment,
  [687206] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23671), 1,
      anon_sym_COLON,
    STATE(18181), 2,
      sym_comment,
      sym_block_comment,
  [687220] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23673), 1,
      sym__indent,
    STATE(18182), 2,
      sym_comment,
      sym_block_comment,
  [687234] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23675), 1,
      anon_sym_RPAREN,
    STATE(18183), 2,
      sym_comment,
      sym_block_comment,
  [687248] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23677), 1,
      sym__outdent,
    STATE(18184), 2,
      sym_comment,
      sym_block_comment,
  [687262] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23679), 1,
      anon_sym_RPAREN,
    STATE(18185), 2,
      sym_comment,
      sym_block_comment,
  [687276] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23681), 1,
      sym__outdent,
    STATE(18186), 2,
      sym_comment,
      sym_block_comment,
  [687290] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23683), 1,
      anon_sym_RPAREN,
    STATE(18187), 2,
      sym_comment,
      sym_block_comment,
  [687304] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23685), 1,
      sym__indent,
    STATE(18188), 2,
      sym_comment,
      sym_block_comment,
  [687318] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23687), 1,
      sym__outdent,
    STATE(18189), 2,
      sym_comment,
      sym_block_comment,
  [687332] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23689), 1,
      anon_sym_RBRACE,
    STATE(18190), 2,
      sym_comment,
      sym_block_comment,
  [687346] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23691), 1,
      sym__outdent,
    STATE(18191), 2,
      sym_comment,
      sym_block_comment,
  [687360] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23693), 1,
      anon_sym_RPAREN,
    STATE(18192), 2,
      sym_comment,
      sym_block_comment,
  [687374] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23695), 1,
      anon_sym_RBRACE,
    STATE(18193), 2,
      sym_comment,
      sym_block_comment,
  [687388] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23697), 1,
      sym__indent,
    STATE(18194), 2,
      sym_comment,
      sym_block_comment,
  [687402] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23699), 1,
      anon_sym_RPAREN,
    STATE(18195), 2,
      sym_comment,
      sym_block_comment,
  [687416] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23701), 1,
      sym__outdent,
    STATE(18196), 2,
      sym_comment,
      sym_block_comment,
  [687430] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23703), 1,
      anon_sym_RPAREN,
    STATE(18197), 2,
      sym_comment,
      sym_block_comment,
  [687444] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23705), 1,
      sym__outdent,
    STATE(18198), 2,
      sym_comment,
      sym_block_comment,
  [687458] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23707), 1,
      anon_sym_RPAREN,
    STATE(18199), 2,
      sym_comment,
      sym_block_comment,
  [687472] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23709), 1,
      sym__indent,
    STATE(18200), 2,
      sym_comment,
      sym_block_comment,
  [687486] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23711), 1,
      sym__outdent,
    STATE(18201), 2,
      sym_comment,
      sym_block_comment,
  [687500] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23713), 1,
      anon_sym_RBRACE,
    STATE(18202), 2,
      sym_comment,
      sym_block_comment,
  [687514] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23715), 1,
      sym__outdent,
    STATE(18203), 2,
      sym_comment,
      sym_block_comment,
  [687528] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23717), 1,
      anon_sym_RPAREN,
    STATE(18204), 2,
      sym_comment,
      sym_block_comment,
  [687542] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23719), 1,
      anon_sym_RBRACE,
    STATE(18205), 2,
      sym_comment,
      sym_block_comment,
  [687556] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23721), 1,
      sym__indent,
    STATE(18206), 2,
      sym_comment,
      sym_block_comment,
  [687570] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23723), 1,
      anon_sym_RBRACE,
    STATE(18207), 2,
      sym_comment,
      sym_block_comment,
  [687584] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23725), 1,
      anon_sym_RPAREN,
    STATE(18208), 2,
      sym_comment,
      sym_block_comment,
  [687598] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23727), 1,
      sym__outdent,
    STATE(18209), 2,
      sym_comment,
      sym_block_comment,
  [687612] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23729), 1,
      anon_sym_RPAREN,
    STATE(18210), 2,
      sym_comment,
      sym_block_comment,
  [687626] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23731), 1,
      anon_sym_EQ_GT_GT,
    STATE(18211), 2,
      sym_comment,
      sym_block_comment,
  [687640] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23733), 1,
      sym__indent,
    STATE(18212), 2,
      sym_comment,
      sym_block_comment,
  [687654] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23735), 1,
      sym__outdent,
    STATE(18213), 2,
      sym_comment,
      sym_block_comment,
  [687668] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23737), 1,
      anon_sym_EQ_GT,
    STATE(18214), 2,
      sym_comment,
      sym_block_comment,
  [687682] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23739), 1,
      anon_sym_RPAREN,
    STATE(18215), 2,
      sym_comment,
      sym_block_comment,
  [687696] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23741), 1,
      sym__outdent,
    STATE(18216), 2,
      sym_comment,
      sym_block_comment,
  [687710] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23743), 1,
      anon_sym_RBRACE,
    STATE(18217), 2,
      sym_comment,
      sym_block_comment,
  [687724] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23745), 1,
      sym__indent,
    STATE(18218), 2,
      sym_comment,
      sym_block_comment,
  [687738] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23747), 1,
      sym__outdent,
    STATE(18219), 2,
      sym_comment,
      sym_block_comment,
  [687752] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23749), 1,
      anon_sym_RBRACE,
    STATE(18220), 2,
      sym_comment,
      sym_block_comment,
  [687766] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23751), 1,
      sym__outdent,
    STATE(18221), 2,
      sym_comment,
      sym_block_comment,
  [687780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23753), 1,
      sym__outdent,
    STATE(18222), 2,
      sym_comment,
      sym_block_comment,
  [687794] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23755), 1,
      anon_sym_RPAREN,
    STATE(18223), 2,
      sym_comment,
      sym_block_comment,
  [687808] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23757), 1,
      sym__indent,
    STATE(18224), 2,
      sym_comment,
      sym_block_comment,
  [687822] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23759), 1,
      anon_sym_RBRACE,
    STATE(18225), 2,
      sym_comment,
      sym_block_comment,
  [687836] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23761), 1,
      anon_sym_RPAREN,
    STATE(18226), 2,
      sym_comment,
      sym_block_comment,
  [687850] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23763), 1,
      sym__outdent,
    STATE(18227), 2,
      sym_comment,
      sym_block_comment,
  [687864] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23765), 1,
      anon_sym_RPAREN,
    STATE(18228), 2,
      sym_comment,
      sym_block_comment,
  [687878] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23767), 1,
      sym__outdent,
    STATE(18229), 2,
      sym_comment,
      sym_block_comment,
  [687892] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23769), 1,
      sym__indent,
    STATE(18230), 2,
      sym_comment,
      sym_block_comment,
  [687906] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23771), 1,
      sym__outdent,
    STATE(18231), 2,
      sym_comment,
      sym_block_comment,
  [687920] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23773), 1,
      anon_sym_RPAREN,
    STATE(18232), 2,
      sym_comment,
      sym_block_comment,
  [687934] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23775), 1,
      sym__outdent,
    STATE(18233), 2,
      sym_comment,
      sym_block_comment,
  [687948] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23777), 1,
      anon_sym_RBRACE,
    STATE(18234), 2,
      sym_comment,
      sym_block_comment,
  [687962] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23779), 1,
      sym__outdent,
    STATE(18235), 2,
      sym_comment,
      sym_block_comment,
  [687976] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23781), 1,
      sym__indent,
    STATE(18236), 2,
      sym_comment,
      sym_block_comment,
  [687990] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23783), 1,
      anon_sym_RPAREN,
    STATE(18237), 2,
      sym_comment,
      sym_block_comment,
  [688004] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23785), 1,
      anon_sym_RPAREN,
    STATE(18238), 2,
      sym_comment,
      sym_block_comment,
  [688018] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23787), 1,
      anon_sym_RBRACE,
    STATE(18239), 2,
      sym_comment,
      sym_block_comment,
  [688032] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23789), 1,
      anon_sym_RPAREN,
    STATE(18240), 2,
      sym_comment,
      sym_block_comment,
  [688046] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23791), 1,
      sym__outdent,
    STATE(18241), 2,
      sym_comment,
      sym_block_comment,
  [688060] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23793), 1,
      sym__indent,
    STATE(18242), 2,
      sym_comment,
      sym_block_comment,
  [688074] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23795), 1,
      anon_sym_RPAREN,
    STATE(18243), 2,
      sym_comment,
      sym_block_comment,
  [688088] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23797), 1,
      sym__outdent,
    STATE(18244), 2,
      sym_comment,
      sym_block_comment,
  [688102] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23799), 1,
      anon_sym_RPAREN,
    STATE(18245), 2,
      sym_comment,
      sym_block_comment,
  [688116] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23801), 1,
      sym__outdent,
    STATE(18246), 2,
      sym_comment,
      sym_block_comment,
  [688130] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23803), 1,
      sym__outdent,
    STATE(18247), 2,
      sym_comment,
      sym_block_comment,
  [688144] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23805), 1,
      sym__indent,
    STATE(18248), 2,
      sym_comment,
      sym_block_comment,
  [688158] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23807), 1,
      anon_sym_RPAREN,
    STATE(18249), 2,
      sym_comment,
      sym_block_comment,
  [688172] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23809), 1,
      anon_sym_RBRACE,
    STATE(18250), 2,
      sym_comment,
      sym_block_comment,
  [688186] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23811), 1,
      anon_sym_RPAREN,
    STATE(18251), 2,
      sym_comment,
      sym_block_comment,
  [688200] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23813), 1,
      sym__outdent,
    STATE(18252), 2,
      sym_comment,
      sym_block_comment,
  [688214] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23815), 1,
      anon_sym_RPAREN,
    STATE(18253), 2,
      sym_comment,
      sym_block_comment,
  [688228] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23817), 1,
      sym__indent,
    STATE(18254), 2,
      sym_comment,
      sym_block_comment,
  [688242] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23819), 1,
      sym__outdent,
    STATE(18255), 2,
      sym_comment,
      sym_block_comment,
  [688256] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23821), 1,
      anon_sym_RPAREN,
    STATE(18256), 2,
      sym_comment,
      sym_block_comment,
  [688270] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23823), 1,
      anon_sym_RPAREN,
    STATE(18257), 2,
      sym_comment,
      sym_block_comment,
  [688284] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23825), 1,
      sym__outdent,
    STATE(18258), 2,
      sym_comment,
      sym_block_comment,
  [688298] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23827), 1,
      anon_sym_EQ,
    STATE(18259), 2,
      sym_comment,
      sym_block_comment,
  [688312] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23829), 1,
      sym__indent,
    STATE(18260), 2,
      sym_comment,
      sym_block_comment,
  [688326] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23831), 1,
      sym__outdent,
    STATE(18261), 2,
      sym_comment,
      sym_block_comment,
  [688340] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23833), 1,
      anon_sym_EQ,
    STATE(18262), 2,
      sym_comment,
      sym_block_comment,
  [688354] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23835), 1,
      sym__outdent,
    STATE(18263), 2,
      sym_comment,
      sym_block_comment,
  [688368] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23837), 1,
      anon_sym_RPAREN,
    STATE(18264), 2,
      sym_comment,
      sym_block_comment,
  [688382] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23839), 1,
      anon_sym_RBRACE,
    STATE(18265), 2,
      sym_comment,
      sym_block_comment,
  [688396] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23841), 1,
      sym__indent,
    STATE(18266), 2,
      sym_comment,
      sym_block_comment,
  [688410] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23843), 1,
      anon_sym_RPAREN,
    STATE(18267), 2,
      sym_comment,
      sym_block_comment,
  [688424] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23845), 1,
      sym__outdent,
    STATE(18268), 2,
      sym_comment,
      sym_block_comment,
  [688438] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23847), 1,
      anon_sym_RPAREN,
    STATE(18269), 2,
      sym_comment,
      sym_block_comment,
  [688452] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23849), 1,
      sym__outdent,
    STATE(18270), 2,
      sym_comment,
      sym_block_comment,
  [688466] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23851), 1,
      anon_sym_RPAREN,
    STATE(18271), 2,
      sym_comment,
      sym_block_comment,
  [688480] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23853), 1,
      sym__indent,
    STATE(18272), 2,
      sym_comment,
      sym_block_comment,
  [688494] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23855), 1,
      sym__outdent,
    STATE(18273), 2,
      sym_comment,
      sym_block_comment,
  [688508] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23857), 1,
      anon_sym_RBRACE,
    STATE(18274), 2,
      sym_comment,
      sym_block_comment,
  [688522] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23859), 1,
      sym__outdent,
    STATE(18275), 2,
      sym_comment,
      sym_block_comment,
  [688536] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23861), 1,
      anon_sym_RPAREN,
    STATE(18276), 2,
      sym_comment,
      sym_block_comment,
  [688550] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23863), 1,
      anon_sym_RBRACE,
    STATE(18277), 2,
      sym_comment,
      sym_block_comment,
  [688564] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23865), 1,
      sym__indent,
    STATE(18278), 2,
      sym_comment,
      sym_block_comment,
  [688578] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23867), 1,
      anon_sym_RPAREN,
    STATE(18279), 2,
      sym_comment,
      sym_block_comment,
  [688592] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23869), 1,
      sym__outdent,
    STATE(18280), 2,
      sym_comment,
      sym_block_comment,
  [688606] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23871), 1,
      anon_sym_RPAREN,
    STATE(18281), 2,
      sym_comment,
      sym_block_comment,
  [688620] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23873), 1,
      anon_sym_RPAREN,
    STATE(18282), 2,
      sym_comment,
      sym_block_comment,
  [688634] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23875), 1,
      anon_sym_RPAREN,
    STATE(18283), 2,
      sym_comment,
      sym_block_comment,
  [688648] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23877), 1,
      sym__indent,
    STATE(18284), 2,
      sym_comment,
      sym_block_comment,
  [688662] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23879), 1,
      sym__outdent,
    STATE(18285), 2,
      sym_comment,
      sym_block_comment,
  [688676] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23881), 1,
      anon_sym_RBRACE,
    STATE(18286), 2,
      sym_comment,
      sym_block_comment,
  [688690] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23883), 1,
      anon_sym_RBRACE,
    STATE(18287), 2,
      sym_comment,
      sym_block_comment,
  [688704] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23885), 1,
      sym__outdent,
    STATE(18288), 2,
      sym_comment,
      sym_block_comment,
  [688718] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23887), 1,
      anon_sym_else,
    STATE(18289), 2,
      sym_comment,
      sym_block_comment,
  [688732] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23889), 1,
      sym__indent,
    STATE(18290), 2,
      sym_comment,
      sym_block_comment,
  [688746] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23891), 1,
      anon_sym_RPAREN,
    STATE(18291), 2,
      sym_comment,
      sym_block_comment,
  [688760] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23893), 1,
      anon_sym_RBRACE,
    STATE(18292), 2,
      sym_comment,
      sym_block_comment,
  [688774] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23895), 1,
      anon_sym_RPAREN,
    STATE(18293), 2,
      sym_comment,
      sym_block_comment,
  [688788] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23897), 1,
      sym__outdent,
    STATE(18294), 2,
      sym_comment,
      sym_block_comment,
  [688802] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23899), 1,
      anon_sym_RPAREN,
    STATE(18295), 2,
      sym_comment,
      sym_block_comment,
  [688816] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23901), 1,
      sym__indent,
    STATE(18296), 2,
      sym_comment,
      sym_block_comment,
  [688830] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23903), 1,
      sym__outdent,
    STATE(18297), 2,
      sym_comment,
      sym_block_comment,
  [688844] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23905), 1,
      anon_sym_RPAREN,
    STATE(18298), 2,
      sym_comment,
      sym_block_comment,
  [688858] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23907), 1,
      sym__outdent,
    STATE(18299), 2,
      sym_comment,
      sym_block_comment,
  [688872] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23909), 1,
      anon_sym_RBRACE,
    STATE(18300), 2,
      sym_comment,
      sym_block_comment,
  [688886] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23911), 1,
      anon_sym_COLON,
    STATE(18301), 2,
      sym_comment,
      sym_block_comment,
  [688900] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23913), 1,
      sym__indent,
    STATE(18302), 2,
      sym_comment,
      sym_block_comment,
  [688914] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23915), 1,
      sym__outdent,
    STATE(18303), 2,
      sym_comment,
      sym_block_comment,
  [688928] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23917), 1,
      anon_sym_RPAREN,
    STATE(18304), 2,
      sym_comment,
      sym_block_comment,
  [688942] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23919), 1,
      anon_sym_RBRACE,
    STATE(18305), 2,
      sym_comment,
      sym_block_comment,
  [688956] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23921), 1,
      anon_sym_RPAREN,
    STATE(18306), 2,
      sym_comment,
      sym_block_comment,
  [688970] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23923), 1,
      sym__outdent,
    STATE(18307), 2,
      sym_comment,
      sym_block_comment,
  [688984] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23925), 1,
      sym__indent,
    STATE(18308), 2,
      sym_comment,
      sym_block_comment,
  [688998] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23927), 1,
      anon_sym_RPAREN,
    STATE(18309), 2,
      sym_comment,
      sym_block_comment,
  [689012] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23929), 1,
      sym__outdent,
    STATE(18310), 2,
      sym_comment,
      sym_block_comment,
  [689026] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23931), 1,
      anon_sym_RPAREN,
    STATE(18311), 2,
      sym_comment,
      sym_block_comment,
  [689040] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23933), 1,
      sym__outdent,
    STATE(18312), 2,
      sym_comment,
      sym_block_comment,
  [689054] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23935), 1,
      anon_sym_RBRACE,
    STATE(18313), 2,
      sym_comment,
      sym_block_comment,
  [689068] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23937), 1,
      sym__indent,
    STATE(18314), 2,
      sym_comment,
      sym_block_comment,
  [689082] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23939), 1,
      sym__outdent,
    STATE(18315), 2,
      sym_comment,
      sym_block_comment,
  [689096] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23941), 1,
      anon_sym_RPAREN,
    STATE(18316), 2,
      sym_comment,
      sym_block_comment,
  [689110] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23943), 1,
      anon_sym_RBRACE,
    STATE(18317), 2,
      sym_comment,
      sym_block_comment,
  [689124] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23945), 1,
      anon_sym_RPAREN,
    STATE(18318), 2,
      sym_comment,
      sym_block_comment,
  [689138] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23947), 1,
      sym__outdent,
    STATE(18319), 2,
      sym_comment,
      sym_block_comment,
  [689152] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23949), 1,
      sym__indent,
    STATE(18320), 2,
      sym_comment,
      sym_block_comment,
  [689166] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23951), 1,
      anon_sym_RPAREN,
    STATE(18321), 2,
      sym_comment,
      sym_block_comment,
  [689180] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23953), 1,
      sym__outdent,
    STATE(18322), 2,
      sym_comment,
      sym_block_comment,
  [689194] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23955), 1,
      anon_sym_RPAREN,
    STATE(18323), 2,
      sym_comment,
      sym_block_comment,
  [689208] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23957), 1,
      sym__outdent,
    STATE(18324), 2,
      sym_comment,
      sym_block_comment,
  [689222] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23959), 1,
      anon_sym_RBRACE,
    STATE(18325), 2,
      sym_comment,
      sym_block_comment,
  [689236] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23961), 1,
      sym__indent,
    STATE(18326), 2,
      sym_comment,
      sym_block_comment,
  [689250] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23963), 1,
      sym__outdent,
    STATE(18327), 2,
      sym_comment,
      sym_block_comment,
  [689264] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23965), 1,
      anon_sym_RBRACE,
    STATE(18328), 2,
      sym_comment,
      sym_block_comment,
  [689278] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23967), 1,
      anon_sym_RPAREN,
    STATE(18329), 2,
      sym_comment,
      sym_block_comment,
  [689292] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23969), 1,
      anon_sym_RBRACE,
    STATE(18330), 2,
      sym_comment,
      sym_block_comment,
  [689306] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23971), 1,
      anon_sym_EQ_GT,
    STATE(18331), 2,
      sym_comment,
      sym_block_comment,
  [689320] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23973), 1,
      sym__indent,
    STATE(18332), 2,
      sym_comment,
      sym_block_comment,
  [689334] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23975), 1,
      anon_sym_RPAREN,
    STATE(18333), 2,
      sym_comment,
      sym_block_comment,
  [689348] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(623), 1,
      sym__outdent,
    STATE(18334), 2,
      sym_comment,
      sym_block_comment,
  [689362] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23977), 1,
      sym__outdent,
    STATE(18335), 2,
      sym_comment,
      sym_block_comment,
  [689376] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23979), 1,
      anon_sym_RBRACE,
    STATE(18336), 2,
      sym_comment,
      sym_block_comment,
  [689390] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23981), 1,
      sym__outdent,
    STATE(18337), 2,
      sym_comment,
      sym_block_comment,
  [689404] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23983), 1,
      sym__indent,
    STATE(18338), 2,
      sym_comment,
      sym_block_comment,
  [689418] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23985), 1,
      anon_sym_RPAREN,
    STATE(18339), 2,
      sym_comment,
      sym_block_comment,
  [689432] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23987), 1,
      sym__outdent,
    STATE(18340), 2,
      sym_comment,
      sym_block_comment,
  [689446] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23989), 1,
      anon_sym_RPAREN,
    STATE(18341), 2,
      sym_comment,
      sym_block_comment,
  [689460] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23991), 1,
      anon_sym_EQ_GT,
    STATE(18342), 2,
      sym_comment,
      sym_block_comment,
  [689474] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23993), 1,
      sym__indent,
    STATE(18343), 2,
      sym_comment,
      sym_block_comment,
  [689488] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23995), 1,
      sym__outdent,
    STATE(18344), 2,
      sym_comment,
      sym_block_comment,
  [689502] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23997), 1,
      anon_sym_RBRACE,
    STATE(18345), 2,
      sym_comment,
      sym_block_comment,
  [689516] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(23999), 1,
      sym__outdent,
    STATE(18346), 2,
      sym_comment,
      sym_block_comment,
  [689530] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17600), 1,
      anon_sym_DOT,
    STATE(18347), 2,
      sym_comment,
      sym_block_comment,
  [689544] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24001), 1,
      sym__indent,
    STATE(18348), 2,
      sym_comment,
      sym_block_comment,
  [689558] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24003), 1,
      anon_sym_RPAREN,
    STATE(18349), 2,
      sym_comment,
      sym_block_comment,
  [689572] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24005), 1,
      anon_sym_RBRACE,
    STATE(18350), 2,
      sym_comment,
      sym_block_comment,
  [689586] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24007), 1,
      anon_sym_RBRACE,
    STATE(18351), 2,
      sym_comment,
      sym_block_comment,
  [689600] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24009), 1,
      anon_sym_RPAREN,
    STATE(18352), 2,
      sym_comment,
      sym_block_comment,
  [689614] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24011), 1,
      sym__indent,
    STATE(18353), 2,
      sym_comment,
      sym_block_comment,
  [689628] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24013), 1,
      sym__outdent,
    STATE(18354), 2,
      sym_comment,
      sym_block_comment,
  [689642] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24015), 1,
      anon_sym_LPAREN,
    STATE(18355), 2,
      sym_comment,
      sym_block_comment,
  [689656] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24017), 1,
      anon_sym_RPAREN,
    STATE(18356), 2,
      sym_comment,
      sym_block_comment,
  [689670] = 4,
    ACTIONS(17815), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17855), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(24019), 1,
      sym_using_directive_value,
    STATE(18357), 2,
      sym_comment,
      sym_block_comment,
  [689684] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24021), 1,
      sym__indent,
    STATE(18358), 2,
      sym_comment,
      sym_block_comment,
  [689698] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24023), 1,
      sym__outdent,
    STATE(18359), 2,
      sym_comment,
      sym_block_comment,
  [689712] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24025), 1,
      anon_sym_type,
    STATE(18360), 2,
      sym_comment,
      sym_block_comment,
  [689726] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24027), 1,
      anon_sym_RPAREN,
    STATE(18361), 2,
      sym_comment,
      sym_block_comment,
  [689740] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24029), 1,
      sym__outdent,
    STATE(18362), 2,
      sym_comment,
      sym_block_comment,
  [689754] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24031), 1,
      sym__indent,
    STATE(18363), 2,
      sym_comment,
      sym_block_comment,
  [689768] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24033), 1,
      anon_sym_RBRACE,
    STATE(18364), 2,
      sym_comment,
      sym_block_comment,
  [689782] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24035), 1,
      sym__outdent,
    STATE(18365), 2,
      sym_comment,
      sym_block_comment,
  [689796] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24037), 1,
      anon_sym_RPAREN,
    STATE(18366), 2,
      sym_comment,
      sym_block_comment,
  [689810] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24039), 1,
      anon_sym_RBRACE,
    STATE(18367), 2,
      sym_comment,
      sym_block_comment,
  [689824] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24041), 1,
      sym__indent,
    STATE(18368), 2,
      sym_comment,
      sym_block_comment,
  [689838] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24043), 1,
      anon_sym_RPAREN,
    STATE(18369), 2,
      sym_comment,
      sym_block_comment,
  [689852] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24045), 1,
      sym__outdent,
    STATE(18370), 2,
      sym_comment,
      sym_block_comment,
  [689866] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24047), 1,
      anon_sym_RPAREN,
    STATE(18371), 2,
      sym_comment,
      sym_block_comment,
  [689880] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24049), 1,
      sym__outdent,
    STATE(18372), 2,
      sym_comment,
      sym_block_comment,
  [689894] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24051), 1,
      sym__indent,
    STATE(18373), 2,
      sym_comment,
      sym_block_comment,
  [689908] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24053), 1,
      anon_sym_RPAREN,
    STATE(18374), 2,
      sym_comment,
      sym_block_comment,
  [689922] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24055), 1,
      anon_sym_EQ_GT,
    STATE(18375), 2,
      sym_comment,
      sym_block_comment,
  [689936] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24057), 1,
      sym__outdent,
    STATE(18376), 2,
      sym_comment,
      sym_block_comment,
  [689950] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24059), 1,
      anon_sym_RPAREN,
    STATE(18377), 2,
      sym_comment,
      sym_block_comment,
  [689964] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24061), 1,
      sym__indent,
    STATE(18378), 2,
      sym_comment,
      sym_block_comment,
  [689978] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24063), 1,
      anon_sym_RBRACE,
    STATE(18379), 2,
      sym_comment,
      sym_block_comment,
  [689992] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24065), 1,
      sym__outdent,
    STATE(18380), 2,
      sym_comment,
      sym_block_comment,
  [690006] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24067), 1,
      anon_sym_RPAREN,
    STATE(18381), 2,
      sym_comment,
      sym_block_comment,
  [690020] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24069), 1,
      anon_sym_RBRACE,
    STATE(18382), 2,
      sym_comment,
      sym_block_comment,
  [690034] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24071), 1,
      sym__indent,
    STATE(18383), 2,
      sym_comment,
      sym_block_comment,
  [690048] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24073), 1,
      anon_sym_RPAREN,
    STATE(18384), 2,
      sym_comment,
      sym_block_comment,
  [690062] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24075), 1,
      sym__outdent,
    STATE(18385), 2,
      sym_comment,
      sym_block_comment,
  [690076] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24077), 1,
      anon_sym_RPAREN,
    STATE(18386), 2,
      sym_comment,
      sym_block_comment,
  [690090] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24079), 1,
      sym__outdent,
    STATE(18387), 2,
      sym_comment,
      sym_block_comment,
  [690104] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24081), 1,
      sym__indent,
    STATE(18388), 2,
      sym_comment,
      sym_block_comment,
  [690118] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24083), 1,
      anon_sym_RPAREN,
    STATE(18389), 2,
      sym_comment,
      sym_block_comment,
  [690132] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24085), 1,
      sym__outdent,
    STATE(18390), 2,
      sym_comment,
      sym_block_comment,
  [690146] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24087), 1,
      anon_sym_RBRACE,
    STATE(18391), 2,
      sym_comment,
      sym_block_comment,
  [690160] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24089), 1,
      sym__outdent,
    STATE(18392), 2,
      sym_comment,
      sym_block_comment,
  [690174] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24091), 1,
      sym__indent,
    STATE(18393), 2,
      sym_comment,
      sym_block_comment,
  [690188] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24093), 1,
      anon_sym_RPAREN,
    STATE(18394), 2,
      sym_comment,
      sym_block_comment,
  [690202] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24095), 1,
      anon_sym_RBRACE,
    STATE(18395), 2,
      sym_comment,
      sym_block_comment,
  [690216] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24097), 1,
      anon_sym_RPAREN,
    STATE(18396), 2,
      sym_comment,
      sym_block_comment,
  [690230] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24099), 1,
      sym__outdent,
    STATE(18397), 2,
      sym_comment,
      sym_block_comment,
  [690244] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24101), 1,
      sym__indent,
    STATE(18398), 2,
      sym_comment,
      sym_block_comment,
  [690258] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24103), 1,
      anon_sym_RPAREN,
    STATE(18399), 2,
      sym_comment,
      sym_block_comment,
  [690272] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24105), 1,
      anon_sym_RBRACK,
    STATE(18400), 2,
      sym_comment,
      sym_block_comment,
  [690286] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24107), 1,
      sym__outdent,
    STATE(18401), 2,
      sym_comment,
      sym_block_comment,
  [690300] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24105), 1,
      anon_sym_RBRACE,
    STATE(18402), 2,
      sym_comment,
      sym_block_comment,
  [690314] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24109), 1,
      sym__indent,
    STATE(18403), 2,
      sym_comment,
      sym_block_comment,
  [690328] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24111), 1,
      anon_sym_RPAREN,
    STATE(18404), 2,
      sym_comment,
      sym_block_comment,
  [690342] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24113), 1,
      anon_sym_RBRACK,
    STATE(18405), 2,
      sym_comment,
      sym_block_comment,
  [690356] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24115), 1,
      sym__outdent,
    STATE(18406), 2,
      sym_comment,
      sym_block_comment,
  [690370] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24113), 1,
      anon_sym_RBRACE,
    STATE(18407), 2,
      sym_comment,
      sym_block_comment,
  [690384] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24117), 1,
      sym__indent,
    STATE(18408), 2,
      sym_comment,
      sym_block_comment,
  [690398] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24119), 1,
      sym__outdent,
    STATE(18409), 2,
      sym_comment,
      sym_block_comment,
  [690412] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24121), 1,
      sym__outdent,
    STATE(18410), 2,
      sym_comment,
      sym_block_comment,
  [690426] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24123), 1,
      sym__outdent,
    STATE(18411), 2,
      sym_comment,
      sym_block_comment,
  [690440] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24125), 1,
      anon_sym_RBRACE,
    STATE(18412), 2,
      sym_comment,
      sym_block_comment,
  [690454] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24127), 1,
      sym__indent,
    STATE(18413), 2,
      sym_comment,
      sym_block_comment,
  [690468] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24129), 1,
      sym__indent,
    STATE(18414), 2,
      sym_comment,
      sym_block_comment,
  [690482] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24131), 1,
      sym__indent,
    STATE(18415), 2,
      sym_comment,
      sym_block_comment,
  [690496] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24133), 1,
      sym__indent,
    STATE(18416), 2,
      sym_comment,
      sym_block_comment,
  [690510] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24135), 1,
      sym__indent,
    STATE(18417), 2,
      sym_comment,
      sym_block_comment,
  [690524] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24137), 1,
      sym__indent,
    STATE(18418), 2,
      sym_comment,
      sym_block_comment,
  [690538] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24139), 1,
      sym__indent,
    STATE(18419), 2,
      sym_comment,
      sym_block_comment,
  [690552] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24141), 1,
      sym__indent,
    STATE(18420), 2,
      sym_comment,
      sym_block_comment,
  [690566] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24143), 1,
      sym__indent,
    STATE(18421), 2,
      sym_comment,
      sym_block_comment,
  [690580] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24145), 1,
      sym__indent,
    STATE(18422), 2,
      sym_comment,
      sym_block_comment,
  [690594] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24147), 1,
      sym__indent,
    STATE(18423), 2,
      sym_comment,
      sym_block_comment,
  [690608] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24149), 1,
      sym__indent,
    STATE(18424), 2,
      sym_comment,
      sym_block_comment,
  [690622] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24151), 1,
      sym__indent,
    STATE(18425), 2,
      sym_comment,
      sym_block_comment,
  [690636] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24153), 1,
      sym__indent,
    STATE(18426), 2,
      sym_comment,
      sym_block_comment,
  [690650] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24155), 1,
      sym__indent,
    STATE(18427), 2,
      sym_comment,
      sym_block_comment,
  [690664] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24157), 1,
      sym__indent,
    STATE(18428), 2,
      sym_comment,
      sym_block_comment,
  [690678] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24159), 1,
      sym__indent,
    STATE(18429), 2,
      sym_comment,
      sym_block_comment,
  [690692] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24161), 1,
      sym__indent,
    STATE(18430), 2,
      sym_comment,
      sym_block_comment,
  [690706] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24163), 1,
      sym__indent,
    STATE(18431), 2,
      sym_comment,
      sym_block_comment,
  [690720] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24165), 1,
      sym__indent,
    STATE(18432), 2,
      sym_comment,
      sym_block_comment,
  [690734] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24167), 1,
      sym__indent,
    STATE(18433), 2,
      sym_comment,
      sym_block_comment,
  [690748] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24169), 1,
      sym__indent,
    STATE(18434), 2,
      sym_comment,
      sym_block_comment,
  [690762] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24171), 1,
      sym__indent,
    STATE(18435), 2,
      sym_comment,
      sym_block_comment,
  [690776] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24173), 1,
      sym__indent,
    STATE(18436), 2,
      sym_comment,
      sym_block_comment,
  [690790] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24175), 1,
      sym__indent,
    STATE(18437), 2,
      sym_comment,
      sym_block_comment,
  [690804] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24177), 1,
      sym__indent,
    STATE(18438), 2,
      sym_comment,
      sym_block_comment,
  [690818] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24179), 1,
      sym__indent,
    STATE(18439), 2,
      sym_comment,
      sym_block_comment,
  [690832] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24181), 1,
      sym__indent,
    STATE(18440), 2,
      sym_comment,
      sym_block_comment,
  [690846] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24183), 1,
      sym__indent,
    STATE(18441), 2,
      sym_comment,
      sym_block_comment,
  [690860] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24185), 1,
      sym__indent,
    STATE(18442), 2,
      sym_comment,
      sym_block_comment,
  [690874] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24187), 1,
      sym__indent,
    STATE(18443), 2,
      sym_comment,
      sym_block_comment,
  [690888] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24189), 1,
      sym__indent,
    STATE(18444), 2,
      sym_comment,
      sym_block_comment,
  [690902] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24191), 1,
      sym__indent,
    STATE(18445), 2,
      sym_comment,
      sym_block_comment,
  [690916] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24193), 1,
      sym__indent,
    STATE(18446), 2,
      sym_comment,
      sym_block_comment,
  [690930] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24195), 1,
      sym__indent,
    STATE(18447), 2,
      sym_comment,
      sym_block_comment,
  [690944] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24197), 1,
      sym__indent,
    STATE(18448), 2,
      sym_comment,
      sym_block_comment,
  [690958] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24199), 1,
      sym__indent,
    STATE(18449), 2,
      sym_comment,
      sym_block_comment,
  [690972] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24201), 1,
      sym__indent,
    STATE(18450), 2,
      sym_comment,
      sym_block_comment,
  [690986] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24203), 1,
      sym__indent,
    STATE(18451), 2,
      sym_comment,
      sym_block_comment,
  [691000] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24205), 1,
      sym__indent,
    STATE(18452), 2,
      sym_comment,
      sym_block_comment,
  [691014] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24207), 1,
      sym__indent,
    STATE(18453), 2,
      sym_comment,
      sym_block_comment,
  [691028] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24209), 1,
      sym__indent,
    STATE(18454), 2,
      sym_comment,
      sym_block_comment,
  [691042] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24211), 1,
      sym__indent,
    STATE(18455), 2,
      sym_comment,
      sym_block_comment,
  [691056] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24213), 1,
      sym__indent,
    STATE(18456), 2,
      sym_comment,
      sym_block_comment,
  [691070] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24215), 1,
      sym__indent,
    STATE(18457), 2,
      sym_comment,
      sym_block_comment,
  [691084] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24217), 1,
      sym__indent,
    STATE(18458), 2,
      sym_comment,
      sym_block_comment,
  [691098] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24219), 1,
      sym__indent,
    STATE(18459), 2,
      sym_comment,
      sym_block_comment,
  [691112] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24221), 1,
      sym__indent,
    STATE(18460), 2,
      sym_comment,
      sym_block_comment,
  [691126] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24223), 1,
      sym__indent,
    STATE(18461), 2,
      sym_comment,
      sym_block_comment,
  [691140] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24225), 1,
      sym__indent,
    STATE(18462), 2,
      sym_comment,
      sym_block_comment,
  [691154] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24227), 1,
      sym__indent,
    STATE(18463), 2,
      sym_comment,
      sym_block_comment,
  [691168] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24229), 1,
      sym__indent,
    STATE(18464), 2,
      sym_comment,
      sym_block_comment,
  [691182] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24231), 1,
      sym__indent,
    STATE(18465), 2,
      sym_comment,
      sym_block_comment,
  [691196] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24233), 1,
      sym__indent,
    STATE(18466), 2,
      sym_comment,
      sym_block_comment,
  [691210] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24235), 1,
      sym__indent,
    STATE(18467), 2,
      sym_comment,
      sym_block_comment,
  [691224] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24237), 1,
      sym__indent,
    STATE(18468), 2,
      sym_comment,
      sym_block_comment,
  [691238] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24239), 1,
      anon_sym_RPAREN,
    STATE(18469), 2,
      sym_comment,
      sym_block_comment,
  [691252] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24241), 1,
      anon_sym_RBRACK,
    STATE(18470), 2,
      sym_comment,
      sym_block_comment,
  [691266] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24243), 1,
      anon_sym_def,
    STATE(18471), 2,
      sym_comment,
      sym_block_comment,
  [691280] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24245), 1,
      anon_sym_COLON,
    STATE(18472), 2,
      sym_comment,
      sym_block_comment,
  [691294] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24247), 1,
      anon_sym_RBRACE,
    STATE(18473), 2,
      sym_comment,
      sym_block_comment,
  [691308] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24249), 1,
      sym__indent,
    STATE(18474), 2,
      sym_comment,
      sym_block_comment,
  [691322] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24251), 1,
      anon_sym_RPAREN,
    STATE(18475), 2,
      sym_comment,
      sym_block_comment,
  [691336] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24251), 1,
      anon_sym_RBRACE,
    STATE(18476), 2,
      sym_comment,
      sym_block_comment,
  [691350] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24253), 1,
      sym__outdent,
    STATE(18477), 2,
      sym_comment,
      sym_block_comment,
  [691364] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(10255), 1,
      anon_sym_with,
    STATE(18478), 2,
      sym_comment,
      sym_block_comment,
  [691378] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24255), 1,
      sym__outdent,
    STATE(18479), 2,
      sym_comment,
      sym_block_comment,
  [691392] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24257), 1,
      anon_sym_RPAREN,
    STATE(18480), 2,
      sym_comment,
      sym_block_comment,
  [691406] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24259), 1,
      sym__outdent,
    STATE(18481), 2,
      sym_comment,
      sym_block_comment,
  [691420] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24261), 1,
      anon_sym_RPAREN,
    STATE(18482), 2,
      sym_comment,
      sym_block_comment,
  [691434] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24263), 1,
      sym__outdent,
    STATE(18483), 2,
      sym_comment,
      sym_block_comment,
  [691448] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24265), 1,
      anon_sym_RBRACE,
    STATE(18484), 2,
      sym_comment,
      sym_block_comment,
  [691462] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24267), 1,
      sym__outdent,
    STATE(18485), 2,
      sym_comment,
      sym_block_comment,
  [691476] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24269), 1,
      anon_sym_RPAREN,
    STATE(18486), 2,
      sym_comment,
      sym_block_comment,
  [691490] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24271), 1,
      anon_sym_RPAREN,
    STATE(18487), 2,
      sym_comment,
      sym_block_comment,
  [691504] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24273), 1,
      anon_sym_RBRACE,
    STATE(18488), 2,
      sym_comment,
      sym_block_comment,
  [691518] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24275), 1,
      anon_sym_RBRACE,
    STATE(18489), 2,
      sym_comment,
      sym_block_comment,
  [691532] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24277), 1,
      anon_sym_RBRACE,
    STATE(18490), 2,
      sym_comment,
      sym_block_comment,
  [691546] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24279), 1,
      sym__outdent,
    STATE(18491), 2,
      sym_comment,
      sym_block_comment,
  [691560] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24281), 1,
      anon_sym_RPAREN,
    STATE(18492), 2,
      sym_comment,
      sym_block_comment,
  [691574] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24283), 1,
      sym__outdent,
    STATE(18493), 2,
      sym_comment,
      sym_block_comment,
  [691588] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24285), 1,
      anon_sym_do,
    STATE(18494), 2,
      sym_comment,
      sym_block_comment,
  [691602] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24287), 1,
      sym__outdent,
    STATE(18495), 2,
      sym_comment,
      sym_block_comment,
  [691616] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24289), 1,
      anon_sym_RPAREN,
    STATE(18496), 2,
      sym_comment,
      sym_block_comment,
  [691630] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24291), 1,
      sym__outdent,
    STATE(18497), 2,
      sym_comment,
      sym_block_comment,
  [691644] = 4,
    ACTIONS(17815), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(17855), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(24293), 1,
      sym_using_directive_key,
    STATE(18498), 2,
      sym_comment,
      sym_block_comment,
  [691658] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24295), 1,
      anon_sym_RBRACE,
    STATE(18499), 2,
      sym_comment,
      sym_block_comment,
  [691672] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24297), 1,
      sym__outdent,
    STATE(18500), 2,
      sym_comment,
      sym_block_comment,
  [691686] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24299), 1,
      anon_sym_RPAREN,
    STATE(18501), 2,
      sym_comment,
      sym_block_comment,
  [691700] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24301), 1,
      anon_sym_RPAREN,
    STATE(18502), 2,
      sym_comment,
      sym_block_comment,
  [691714] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(15094), 1,
      anon_sym_type,
    STATE(18503), 2,
      sym_comment,
      sym_block_comment,
  [691728] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24303), 1,
      anon_sym_type,
    STATE(18504), 2,
      sym_comment,
      sym_block_comment,
  [691742] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24305), 1,
      sym__outdent,
    STATE(18505), 2,
      sym_comment,
      sym_block_comment,
  [691756] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24307), 1,
      anon_sym_RBRACE,
    STATE(18506), 2,
      sym_comment,
      sym_block_comment,
  [691770] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24309), 1,
      anon_sym_RPAREN,
    STATE(18507), 2,
      sym_comment,
      sym_block_comment,
  [691784] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24311), 1,
      sym__outdent,
    STATE(18508), 2,
      sym_comment,
      sym_block_comment,
  [691798] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24313), 1,
      anon_sym_RBRACE,
    STATE(18509), 2,
      sym_comment,
      sym_block_comment,
  [691812] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11813), 1,
      anon_sym_def,
    STATE(18510), 2,
      sym_comment,
      sym_block_comment,
  [691826] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24315), 1,
      sym__outdent,
    STATE(18511), 2,
      sym_comment,
      sym_block_comment,
  [691840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24317), 1,
      sym__indent,
    STATE(18512), 2,
      sym_comment,
      sym_block_comment,
  [691854] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24319), 1,
      anon_sym_RPAREN,
    STATE(18513), 2,
      sym_comment,
      sym_block_comment,
  [691868] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24321), 1,
      anon_sym_LPAREN,
    STATE(18514), 2,
      sym_comment,
      sym_block_comment,
  [691882] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24323), 1,
      sym__outdent,
    STATE(18515), 2,
      sym_comment,
      sym_block_comment,
  [691896] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24325), 1,
      anon_sym_then,
    STATE(18516), 2,
      sym_comment,
      sym_block_comment,
  [691910] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24327), 1,
      anon_sym_RPAREN,
    STATE(18517), 2,
      sym_comment,
      sym_block_comment,
  [691924] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13336), 1,
      anon_sym_DOT,
    STATE(18518), 2,
      sym_comment,
      sym_block_comment,
  [691938] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7752), 1,
      anon_sym_with,
    STATE(18519), 2,
      sym_comment,
      sym_block_comment,
  [691952] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24329), 1,
      anon_sym_RBRACE,
    STATE(18520), 2,
      sym_comment,
      sym_block_comment,
  [691966] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24331), 1,
      anon_sym_with,
    STATE(18521), 2,
      sym_comment,
      sym_block_comment,
  [691980] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24333), 1,
      anon_sym_RBRACE,
    STATE(18522), 2,
      sym_comment,
      sym_block_comment,
  [691994] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(11675), 1,
      anon_sym_with,
    STATE(18523), 2,
      sym_comment,
      sym_block_comment,
  [692008] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24335), 1,
      sym__outdent,
    STATE(18524), 2,
      sym_comment,
      sym_block_comment,
  [692022] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24337), 1,
      anon_sym_RBRACE,
    STATE(18525), 2,
      sym_comment,
      sym_block_comment,
  [692036] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24339), 1,
      anon_sym_RPAREN,
    STATE(18526), 2,
      sym_comment,
      sym_block_comment,
  [692050] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24341), 1,
      ts_builtin_sym_end,
    STATE(18527), 2,
      sym_comment,
      sym_block_comment,
  [692064] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24343), 1,
      sym__outdent,
    STATE(18528), 2,
      sym_comment,
      sym_block_comment,
  [692078] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24345), 1,
      anon_sym_using,
    STATE(18529), 2,
      sym_comment,
      sym_block_comment,
  [692092] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24347), 1,
      anon_sym_RBRACE,
    STATE(18530), 2,
      sym_comment,
      sym_block_comment,
  [692106] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24349), 1,
      anon_sym_COLON,
    STATE(18531), 2,
      sym_comment,
      sym_block_comment,
  [692120] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(24351), 1,
      anon_sym_RPAREN,
    STATE(18532), 2,
      sym_comment,
      sym_block_comment,
  [692134] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(7658), 1,
      anon_sym_type,
    STATE(18533), 2,
      sym_comment,
      sym_block_comment,
  [692148] = 1,
    ACTIONS(24353), 1,
      ts_builtin_sym_end,
  [692152] = 1,
    ACTIONS(24355), 1,
      ts_builtin_sym_end,
  [692156] = 1,
    ACTIONS(24357), 1,
      ts_builtin_sym_end,
  [692160] = 1,
    ACTIONS(24359), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2415)] = 0,
  [SMALL_STATE(2416)] = 145,
  [SMALL_STATE(2417)] = 290,
  [SMALL_STATE(2418)] = 435,
  [SMALL_STATE(2419)] = 580,
  [SMALL_STATE(2420)] = 725,
  [SMALL_STATE(2421)] = 870,
  [SMALL_STATE(2422)] = 1015,
  [SMALL_STATE(2423)] = 1160,
  [SMALL_STATE(2424)] = 1305,
  [SMALL_STATE(2425)] = 1450,
  [SMALL_STATE(2426)] = 1595,
  [SMALL_STATE(2427)] = 1740,
  [SMALL_STATE(2428)] = 1885,
  [SMALL_STATE(2429)] = 2030,
  [SMALL_STATE(2430)] = 2175,
  [SMALL_STATE(2431)] = 2320,
  [SMALL_STATE(2432)] = 2465,
  [SMALL_STATE(2433)] = 2610,
  [SMALL_STATE(2434)] = 2755,
  [SMALL_STATE(2435)] = 2900,
  [SMALL_STATE(2436)] = 3045,
  [SMALL_STATE(2437)] = 3190,
  [SMALL_STATE(2438)] = 3335,
  [SMALL_STATE(2439)] = 3480,
  [SMALL_STATE(2440)] = 3625,
  [SMALL_STATE(2441)] = 3770,
  [SMALL_STATE(2442)] = 3915,
  [SMALL_STATE(2443)] = 4060,
  [SMALL_STATE(2444)] = 4205,
  [SMALL_STATE(2445)] = 4350,
  [SMALL_STATE(2446)] = 4495,
  [SMALL_STATE(2447)] = 4640,
  [SMALL_STATE(2448)] = 4785,
  [SMALL_STATE(2449)] = 4930,
  [SMALL_STATE(2450)] = 5075,
  [SMALL_STATE(2451)] = 5220,
  [SMALL_STATE(2452)] = 5365,
  [SMALL_STATE(2453)] = 5510,
  [SMALL_STATE(2454)] = 5655,
  [SMALL_STATE(2455)] = 5800,
  [SMALL_STATE(2456)] = 5945,
  [SMALL_STATE(2457)] = 6090,
  [SMALL_STATE(2458)] = 6235,
  [SMALL_STATE(2459)] = 6380,
  [SMALL_STATE(2460)] = 6525,
  [SMALL_STATE(2461)] = 6670,
  [SMALL_STATE(2462)] = 6815,
  [SMALL_STATE(2463)] = 6960,
  [SMALL_STATE(2464)] = 7034,
  [SMALL_STATE(2465)] = 7108,
  [SMALL_STATE(2466)] = 7182,
  [SMALL_STATE(2467)] = 7256,
  [SMALL_STATE(2468)] = 7330,
  [SMALL_STATE(2469)] = 7404,
  [SMALL_STATE(2470)] = 7478,
  [SMALL_STATE(2471)] = 7621,
  [SMALL_STATE(2472)] = 7764,
  [SMALL_STATE(2473)] = 7909,
  [SMALL_STATE(2474)] = 7982,
  [SMALL_STATE(2475)] = 8125,
  [SMALL_STATE(2476)] = 8259,
  [SMALL_STATE(2477)] = 8393,
  [SMALL_STATE(2478)] = 8527,
  [SMALL_STATE(2479)] = 8661,
  [SMALL_STATE(2480)] = 8795,
  [SMALL_STATE(2481)] = 8929,
  [SMALL_STATE(2482)] = 9063,
  [SMALL_STATE(2483)] = 9197,
  [SMALL_STATE(2484)] = 9331,
  [SMALL_STATE(2485)] = 9465,
  [SMALL_STATE(2486)] = 9599,
  [SMALL_STATE(2487)] = 9733,
  [SMALL_STATE(2488)] = 9867,
  [SMALL_STATE(2489)] = 10001,
  [SMALL_STATE(2490)] = 10135,
  [SMALL_STATE(2491)] = 10269,
  [SMALL_STATE(2492)] = 10403,
  [SMALL_STATE(2493)] = 10537,
  [SMALL_STATE(2494)] = 10671,
  [SMALL_STATE(2495)] = 10805,
  [SMALL_STATE(2496)] = 10939,
  [SMALL_STATE(2497)] = 11073,
  [SMALL_STATE(2498)] = 11207,
  [SMALL_STATE(2499)] = 11341,
  [SMALL_STATE(2500)] = 11470,
  [SMALL_STATE(2501)] = 11599,
  [SMALL_STATE(2502)] = 11728,
  [SMALL_STATE(2503)] = 11857,
  [SMALL_STATE(2504)] = 11986,
  [SMALL_STATE(2505)] = 12115,
  [SMALL_STATE(2506)] = 12244,
  [SMALL_STATE(2507)] = 12373,
  [SMALL_STATE(2508)] = 12502,
  [SMALL_STATE(2509)] = 12631,
  [SMALL_STATE(2510)] = 12760,
  [SMALL_STATE(2511)] = 12889,
  [SMALL_STATE(2512)] = 13018,
  [SMALL_STATE(2513)] = 13147,
  [SMALL_STATE(2514)] = 13276,
  [SMALL_STATE(2515)] = 13405,
  [SMALL_STATE(2516)] = 13534,
  [SMALL_STATE(2517)] = 13663,
  [SMALL_STATE(2518)] = 13792,
  [SMALL_STATE(2519)] = 13921,
  [SMALL_STATE(2520)] = 14050,
  [SMALL_STATE(2521)] = 14179,
  [SMALL_STATE(2522)] = 14308,
  [SMALL_STATE(2523)] = 14437,
  [SMALL_STATE(2524)] = 14566,
  [SMALL_STATE(2525)] = 14695,
  [SMALL_STATE(2526)] = 14824,
  [SMALL_STATE(2527)] = 14953,
  [SMALL_STATE(2528)] = 15082,
  [SMALL_STATE(2529)] = 15211,
  [SMALL_STATE(2530)] = 15340,
  [SMALL_STATE(2531)] = 15469,
  [SMALL_STATE(2532)] = 15598,
  [SMALL_STATE(2533)] = 15727,
  [SMALL_STATE(2534)] = 15856,
  [SMALL_STATE(2535)] = 15985,
  [SMALL_STATE(2536)] = 16114,
  [SMALL_STATE(2537)] = 16243,
  [SMALL_STATE(2538)] = 16372,
  [SMALL_STATE(2539)] = 16501,
  [SMALL_STATE(2540)] = 16630,
  [SMALL_STATE(2541)] = 16759,
  [SMALL_STATE(2542)] = 16888,
  [SMALL_STATE(2543)] = 17017,
  [SMALL_STATE(2544)] = 17146,
  [SMALL_STATE(2545)] = 17275,
  [SMALL_STATE(2546)] = 17404,
  [SMALL_STATE(2547)] = 17533,
  [SMALL_STATE(2548)] = 17662,
  [SMALL_STATE(2549)] = 17791,
  [SMALL_STATE(2550)] = 17920,
  [SMALL_STATE(2551)] = 18049,
  [SMALL_STATE(2552)] = 18178,
  [SMALL_STATE(2553)] = 18307,
  [SMALL_STATE(2554)] = 18436,
  [SMALL_STATE(2555)] = 18565,
  [SMALL_STATE(2556)] = 18694,
  [SMALL_STATE(2557)] = 18823,
  [SMALL_STATE(2558)] = 18952,
  [SMALL_STATE(2559)] = 19081,
  [SMALL_STATE(2560)] = 19210,
  [SMALL_STATE(2561)] = 19339,
  [SMALL_STATE(2562)] = 19468,
  [SMALL_STATE(2563)] = 19597,
  [SMALL_STATE(2564)] = 19726,
  [SMALL_STATE(2565)] = 19855,
  [SMALL_STATE(2566)] = 19984,
  [SMALL_STATE(2567)] = 20113,
  [SMALL_STATE(2568)] = 20242,
  [SMALL_STATE(2569)] = 20371,
  [SMALL_STATE(2570)] = 20500,
  [SMALL_STATE(2571)] = 20629,
  [SMALL_STATE(2572)] = 20758,
  [SMALL_STATE(2573)] = 20887,
  [SMALL_STATE(2574)] = 21016,
  [SMALL_STATE(2575)] = 21145,
  [SMALL_STATE(2576)] = 21274,
  [SMALL_STATE(2577)] = 21403,
  [SMALL_STATE(2578)] = 21532,
  [SMALL_STATE(2579)] = 21661,
  [SMALL_STATE(2580)] = 21790,
  [SMALL_STATE(2581)] = 21919,
  [SMALL_STATE(2582)] = 22048,
  [SMALL_STATE(2583)] = 22177,
  [SMALL_STATE(2584)] = 22306,
  [SMALL_STATE(2585)] = 22435,
  [SMALL_STATE(2586)] = 22564,
  [SMALL_STATE(2587)] = 22693,
  [SMALL_STATE(2588)] = 22822,
  [SMALL_STATE(2589)] = 22951,
  [SMALL_STATE(2590)] = 23080,
  [SMALL_STATE(2591)] = 23209,
  [SMALL_STATE(2592)] = 23338,
  [SMALL_STATE(2593)] = 23411,
  [SMALL_STATE(2594)] = 23540,
  [SMALL_STATE(2595)] = 23669,
  [SMALL_STATE(2596)] = 23798,
  [SMALL_STATE(2597)] = 23927,
  [SMALL_STATE(2598)] = 24056,
  [SMALL_STATE(2599)] = 24185,
  [SMALL_STATE(2600)] = 24314,
  [SMALL_STATE(2601)] = 24443,
  [SMALL_STATE(2602)] = 24572,
  [SMALL_STATE(2603)] = 24701,
  [SMALL_STATE(2604)] = 24830,
  [SMALL_STATE(2605)] = 24959,
  [SMALL_STATE(2606)] = 25088,
  [SMALL_STATE(2607)] = 25217,
  [SMALL_STATE(2608)] = 25346,
  [SMALL_STATE(2609)] = 25475,
  [SMALL_STATE(2610)] = 25604,
  [SMALL_STATE(2611)] = 25733,
  [SMALL_STATE(2612)] = 25862,
  [SMALL_STATE(2613)] = 25991,
  [SMALL_STATE(2614)] = 26120,
  [SMALL_STATE(2615)] = 26249,
  [SMALL_STATE(2616)] = 26378,
  [SMALL_STATE(2617)] = 26507,
  [SMALL_STATE(2618)] = 26636,
  [SMALL_STATE(2619)] = 26765,
  [SMALL_STATE(2620)] = 26894,
  [SMALL_STATE(2621)] = 27023,
  [SMALL_STATE(2622)] = 27152,
  [SMALL_STATE(2623)] = 27281,
  [SMALL_STATE(2624)] = 27410,
  [SMALL_STATE(2625)] = 27539,
  [SMALL_STATE(2626)] = 27668,
  [SMALL_STATE(2627)] = 27797,
  [SMALL_STATE(2628)] = 27926,
  [SMALL_STATE(2629)] = 28055,
  [SMALL_STATE(2630)] = 28184,
  [SMALL_STATE(2631)] = 28313,
  [SMALL_STATE(2632)] = 28442,
  [SMALL_STATE(2633)] = 28571,
  [SMALL_STATE(2634)] = 28700,
  [SMALL_STATE(2635)] = 28829,
  [SMALL_STATE(2636)] = 28958,
  [SMALL_STATE(2637)] = 29087,
  [SMALL_STATE(2638)] = 29216,
  [SMALL_STATE(2639)] = 29342,
  [SMALL_STATE(2640)] = 29468,
  [SMALL_STATE(2641)] = 29540,
  [SMALL_STATE(2642)] = 29666,
  [SMALL_STATE(2643)] = 29792,
  [SMALL_STATE(2644)] = 29918,
  [SMALL_STATE(2645)] = 30044,
  [SMALL_STATE(2646)] = 30170,
  [SMALL_STATE(2647)] = 30296,
  [SMALL_STATE(2648)] = 30368,
  [SMALL_STATE(2649)] = 30494,
  [SMALL_STATE(2650)] = 30620,
  [SMALL_STATE(2651)] = 30691,
  [SMALL_STATE(2652)] = 30814,
  [SMALL_STATE(2653)] = 30885,
  [SMALL_STATE(2654)] = 30956,
  [SMALL_STATE(2655)] = 31027,
  [SMALL_STATE(2656)] = 31149,
  [SMALL_STATE(2657)] = 31271,
  [SMALL_STATE(2658)] = 31393,
  [SMALL_STATE(2659)] = 31515,
  [SMALL_STATE(2660)] = 31637,
  [SMALL_STATE(2661)] = 31759,
  [SMALL_STATE(2662)] = 31881,
  [SMALL_STATE(2663)] = 32003,
  [SMALL_STATE(2664)] = 32125,
  [SMALL_STATE(2665)] = 32247,
  [SMALL_STATE(2666)] = 32369,
  [SMALL_STATE(2667)] = 32491,
  [SMALL_STATE(2668)] = 32613,
  [SMALL_STATE(2669)] = 32735,
  [SMALL_STATE(2670)] = 32857,
  [SMALL_STATE(2671)] = 32979,
  [SMALL_STATE(2672)] = 33101,
  [SMALL_STATE(2673)] = 33223,
  [SMALL_STATE(2674)] = 33345,
  [SMALL_STATE(2675)] = 33467,
  [SMALL_STATE(2676)] = 33589,
  [SMALL_STATE(2677)] = 33711,
  [SMALL_STATE(2678)] = 33833,
  [SMALL_STATE(2679)] = 33955,
  [SMALL_STATE(2680)] = 34077,
  [SMALL_STATE(2681)] = 34199,
  [SMALL_STATE(2682)] = 34321,
  [SMALL_STATE(2683)] = 34443,
  [SMALL_STATE(2684)] = 34565,
  [SMALL_STATE(2685)] = 34687,
  [SMALL_STATE(2686)] = 34809,
  [SMALL_STATE(2687)] = 34931,
  [SMALL_STATE(2688)] = 35053,
  [SMALL_STATE(2689)] = 35123,
  [SMALL_STATE(2690)] = 35245,
  [SMALL_STATE(2691)] = 35367,
  [SMALL_STATE(2692)] = 35489,
  [SMALL_STATE(2693)] = 35611,
  [SMALL_STATE(2694)] = 35733,
  [SMALL_STATE(2695)] = 35855,
  [SMALL_STATE(2696)] = 35977,
  [SMALL_STATE(2697)] = 36099,
  [SMALL_STATE(2698)] = 36221,
  [SMALL_STATE(2699)] = 36343,
  [SMALL_STATE(2700)] = 36465,
  [SMALL_STATE(2701)] = 36587,
  [SMALL_STATE(2702)] = 36709,
  [SMALL_STATE(2703)] = 36831,
  [SMALL_STATE(2704)] = 36953,
  [SMALL_STATE(2705)] = 37075,
  [SMALL_STATE(2706)] = 37197,
  [SMALL_STATE(2707)] = 37319,
  [SMALL_STATE(2708)] = 37441,
  [SMALL_STATE(2709)] = 37563,
  [SMALL_STATE(2710)] = 37685,
  [SMALL_STATE(2711)] = 37807,
  [SMALL_STATE(2712)] = 37929,
  [SMALL_STATE(2713)] = 38051,
  [SMALL_STATE(2714)] = 38173,
  [SMALL_STATE(2715)] = 38295,
  [SMALL_STATE(2716)] = 38417,
  [SMALL_STATE(2717)] = 38539,
  [SMALL_STATE(2718)] = 38661,
  [SMALL_STATE(2719)] = 38783,
  [SMALL_STATE(2720)] = 38905,
  [SMALL_STATE(2721)] = 39027,
  [SMALL_STATE(2722)] = 39149,
  [SMALL_STATE(2723)] = 39271,
  [SMALL_STATE(2724)] = 39393,
  [SMALL_STATE(2725)] = 39515,
  [SMALL_STATE(2726)] = 39637,
  [SMALL_STATE(2727)] = 39759,
  [SMALL_STATE(2728)] = 39881,
  [SMALL_STATE(2729)] = 40003,
  [SMALL_STATE(2730)] = 40125,
  [SMALL_STATE(2731)] = 40247,
  [SMALL_STATE(2732)] = 40369,
  [SMALL_STATE(2733)] = 40491,
  [SMALL_STATE(2734)] = 40613,
  [SMALL_STATE(2735)] = 40735,
  [SMALL_STATE(2736)] = 40857,
  [SMALL_STATE(2737)] = 40979,
  [SMALL_STATE(2738)] = 41101,
  [SMALL_STATE(2739)] = 41223,
  [SMALL_STATE(2740)] = 41345,
  [SMALL_STATE(2741)] = 41467,
  [SMALL_STATE(2742)] = 41589,
  [SMALL_STATE(2743)] = 41711,
  [SMALL_STATE(2744)] = 41833,
  [SMALL_STATE(2745)] = 41955,
  [SMALL_STATE(2746)] = 42077,
  [SMALL_STATE(2747)] = 42199,
  [SMALL_STATE(2748)] = 42321,
  [SMALL_STATE(2749)] = 42443,
  [SMALL_STATE(2750)] = 42565,
  [SMALL_STATE(2751)] = 42687,
  [SMALL_STATE(2752)] = 42809,
  [SMALL_STATE(2753)] = 42931,
  [SMALL_STATE(2754)] = 43053,
  [SMALL_STATE(2755)] = 43175,
  [SMALL_STATE(2756)] = 43297,
  [SMALL_STATE(2757)] = 43419,
  [SMALL_STATE(2758)] = 43541,
  [SMALL_STATE(2759)] = 43663,
  [SMALL_STATE(2760)] = 43785,
  [SMALL_STATE(2761)] = 43907,
  [SMALL_STATE(2762)] = 44029,
  [SMALL_STATE(2763)] = 44151,
  [SMALL_STATE(2764)] = 44273,
  [SMALL_STATE(2765)] = 44395,
  [SMALL_STATE(2766)] = 44517,
  [SMALL_STATE(2767)] = 44639,
  [SMALL_STATE(2768)] = 44761,
  [SMALL_STATE(2769)] = 44883,
  [SMALL_STATE(2770)] = 45005,
  [SMALL_STATE(2771)] = 45075,
  [SMALL_STATE(2772)] = 45197,
  [SMALL_STATE(2773)] = 45319,
  [SMALL_STATE(2774)] = 45441,
  [SMALL_STATE(2775)] = 45563,
  [SMALL_STATE(2776)] = 45685,
  [SMALL_STATE(2777)] = 45807,
  [SMALL_STATE(2778)] = 45929,
  [SMALL_STATE(2779)] = 46051,
  [SMALL_STATE(2780)] = 46173,
  [SMALL_STATE(2781)] = 46295,
  [SMALL_STATE(2782)] = 46417,
  [SMALL_STATE(2783)] = 46539,
  [SMALL_STATE(2784)] = 46661,
  [SMALL_STATE(2785)] = 46783,
  [SMALL_STATE(2786)] = 46905,
  [SMALL_STATE(2787)] = 47027,
  [SMALL_STATE(2788)] = 47149,
  [SMALL_STATE(2789)] = 47271,
  [SMALL_STATE(2790)] = 47393,
  [SMALL_STATE(2791)] = 47515,
  [SMALL_STATE(2792)] = 47637,
  [SMALL_STATE(2793)] = 47759,
  [SMALL_STATE(2794)] = 47881,
  [SMALL_STATE(2795)] = 48003,
  [SMALL_STATE(2796)] = 48125,
  [SMALL_STATE(2797)] = 48247,
  [SMALL_STATE(2798)] = 48369,
  [SMALL_STATE(2799)] = 48491,
  [SMALL_STATE(2800)] = 48613,
  [SMALL_STATE(2801)] = 48735,
  [SMALL_STATE(2802)] = 48857,
  [SMALL_STATE(2803)] = 48979,
  [SMALL_STATE(2804)] = 49101,
  [SMALL_STATE(2805)] = 49223,
  [SMALL_STATE(2806)] = 49345,
  [SMALL_STATE(2807)] = 49467,
  [SMALL_STATE(2808)] = 49589,
  [SMALL_STATE(2809)] = 49711,
  [SMALL_STATE(2810)] = 49833,
  [SMALL_STATE(2811)] = 49955,
  [SMALL_STATE(2812)] = 50077,
  [SMALL_STATE(2813)] = 50199,
  [SMALL_STATE(2814)] = 50321,
  [SMALL_STATE(2815)] = 50443,
  [SMALL_STATE(2816)] = 50565,
  [SMALL_STATE(2817)] = 50687,
  [SMALL_STATE(2818)] = 50809,
  [SMALL_STATE(2819)] = 50931,
  [SMALL_STATE(2820)] = 51053,
  [SMALL_STATE(2821)] = 51175,
  [SMALL_STATE(2822)] = 51297,
  [SMALL_STATE(2823)] = 51419,
  [SMALL_STATE(2824)] = 51541,
  [SMALL_STATE(2825)] = 51663,
  [SMALL_STATE(2826)] = 51785,
  [SMALL_STATE(2827)] = 51907,
  [SMALL_STATE(2828)] = 52029,
  [SMALL_STATE(2829)] = 52151,
  [SMALL_STATE(2830)] = 52273,
  [SMALL_STATE(2831)] = 52395,
  [SMALL_STATE(2832)] = 52517,
  [SMALL_STATE(2833)] = 52639,
  [SMALL_STATE(2834)] = 52761,
  [SMALL_STATE(2835)] = 52883,
  [SMALL_STATE(2836)] = 53005,
  [SMALL_STATE(2837)] = 53127,
  [SMALL_STATE(2838)] = 53249,
  [SMALL_STATE(2839)] = 53371,
  [SMALL_STATE(2840)] = 53493,
  [SMALL_STATE(2841)] = 53615,
  [SMALL_STATE(2842)] = 53737,
  [SMALL_STATE(2843)] = 53859,
  [SMALL_STATE(2844)] = 53981,
  [SMALL_STATE(2845)] = 54103,
  [SMALL_STATE(2846)] = 54225,
  [SMALL_STATE(2847)] = 54347,
  [SMALL_STATE(2848)] = 54469,
  [SMALL_STATE(2849)] = 54591,
  [SMALL_STATE(2850)] = 54713,
  [SMALL_STATE(2851)] = 54835,
  [SMALL_STATE(2852)] = 54957,
  [SMALL_STATE(2853)] = 55079,
  [SMALL_STATE(2854)] = 55201,
  [SMALL_STATE(2855)] = 55323,
  [SMALL_STATE(2856)] = 55445,
  [SMALL_STATE(2857)] = 55567,
  [SMALL_STATE(2858)] = 55689,
  [SMALL_STATE(2859)] = 55811,
  [SMALL_STATE(2860)] = 55933,
  [SMALL_STATE(2861)] = 56055,
  [SMALL_STATE(2862)] = 56177,
  [SMALL_STATE(2863)] = 56299,
  [SMALL_STATE(2864)] = 56421,
  [SMALL_STATE(2865)] = 56543,
  [SMALL_STATE(2866)] = 56665,
  [SMALL_STATE(2867)] = 56787,
  [SMALL_STATE(2868)] = 56909,
  [SMALL_STATE(2869)] = 57031,
  [SMALL_STATE(2870)] = 57153,
  [SMALL_STATE(2871)] = 57275,
  [SMALL_STATE(2872)] = 57397,
  [SMALL_STATE(2873)] = 57519,
  [SMALL_STATE(2874)] = 57641,
  [SMALL_STATE(2875)] = 57763,
  [SMALL_STATE(2876)] = 57833,
  [SMALL_STATE(2877)] = 57955,
  [SMALL_STATE(2878)] = 58077,
  [SMALL_STATE(2879)] = 58199,
  [SMALL_STATE(2880)] = 58321,
  [SMALL_STATE(2881)] = 58443,
  [SMALL_STATE(2882)] = 58565,
  [SMALL_STATE(2883)] = 58687,
  [SMALL_STATE(2884)] = 58809,
  [SMALL_STATE(2885)] = 58931,
  [SMALL_STATE(2886)] = 59053,
  [SMALL_STATE(2887)] = 59175,
  [SMALL_STATE(2888)] = 59297,
  [SMALL_STATE(2889)] = 59419,
  [SMALL_STATE(2890)] = 59541,
  [SMALL_STATE(2891)] = 59663,
  [SMALL_STATE(2892)] = 59785,
  [SMALL_STATE(2893)] = 59907,
  [SMALL_STATE(2894)] = 60029,
  [SMALL_STATE(2895)] = 60151,
  [SMALL_STATE(2896)] = 60273,
  [SMALL_STATE(2897)] = 60395,
  [SMALL_STATE(2898)] = 60517,
  [SMALL_STATE(2899)] = 60639,
  [SMALL_STATE(2900)] = 60761,
  [SMALL_STATE(2901)] = 60883,
  [SMALL_STATE(2902)] = 61005,
  [SMALL_STATE(2903)] = 61127,
  [SMALL_STATE(2904)] = 61249,
  [SMALL_STATE(2905)] = 61319,
  [SMALL_STATE(2906)] = 61441,
  [SMALL_STATE(2907)] = 61563,
  [SMALL_STATE(2908)] = 61685,
  [SMALL_STATE(2909)] = 61807,
  [SMALL_STATE(2910)] = 61929,
  [SMALL_STATE(2911)] = 62051,
  [SMALL_STATE(2912)] = 62173,
  [SMALL_STATE(2913)] = 62295,
  [SMALL_STATE(2914)] = 62417,
  [SMALL_STATE(2915)] = 62539,
  [SMALL_STATE(2916)] = 62661,
  [SMALL_STATE(2917)] = 62783,
  [SMALL_STATE(2918)] = 62905,
  [SMALL_STATE(2919)] = 63027,
  [SMALL_STATE(2920)] = 63149,
  [SMALL_STATE(2921)] = 63271,
  [SMALL_STATE(2922)] = 63393,
  [SMALL_STATE(2923)] = 63515,
  [SMALL_STATE(2924)] = 63637,
  [SMALL_STATE(2925)] = 63759,
  [SMALL_STATE(2926)] = 63881,
  [SMALL_STATE(2927)] = 64003,
  [SMALL_STATE(2928)] = 64125,
  [SMALL_STATE(2929)] = 64247,
  [SMALL_STATE(2930)] = 64369,
  [SMALL_STATE(2931)] = 64491,
  [SMALL_STATE(2932)] = 64613,
  [SMALL_STATE(2933)] = 64735,
  [SMALL_STATE(2934)] = 64857,
  [SMALL_STATE(2935)] = 64979,
  [SMALL_STATE(2936)] = 65101,
  [SMALL_STATE(2937)] = 65223,
  [SMALL_STATE(2938)] = 65345,
  [SMALL_STATE(2939)] = 65467,
  [SMALL_STATE(2940)] = 65589,
  [SMALL_STATE(2941)] = 65711,
  [SMALL_STATE(2942)] = 65833,
  [SMALL_STATE(2943)] = 65955,
  [SMALL_STATE(2944)] = 66077,
  [SMALL_STATE(2945)] = 66199,
  [SMALL_STATE(2946)] = 66321,
  [SMALL_STATE(2947)] = 66443,
  [SMALL_STATE(2948)] = 66565,
  [SMALL_STATE(2949)] = 66687,
  [SMALL_STATE(2950)] = 66809,
  [SMALL_STATE(2951)] = 66931,
  [SMALL_STATE(2952)] = 67053,
  [SMALL_STATE(2953)] = 67175,
  [SMALL_STATE(2954)] = 67297,
  [SMALL_STATE(2955)] = 67419,
  [SMALL_STATE(2956)] = 67541,
  [SMALL_STATE(2957)] = 67663,
  [SMALL_STATE(2958)] = 67785,
  [SMALL_STATE(2959)] = 67907,
  [SMALL_STATE(2960)] = 68029,
  [SMALL_STATE(2961)] = 68151,
  [SMALL_STATE(2962)] = 68273,
  [SMALL_STATE(2963)] = 68395,
  [SMALL_STATE(2964)] = 68517,
  [SMALL_STATE(2965)] = 68639,
  [SMALL_STATE(2966)] = 68761,
  [SMALL_STATE(2967)] = 68883,
  [SMALL_STATE(2968)] = 69005,
  [SMALL_STATE(2969)] = 69127,
  [SMALL_STATE(2970)] = 69249,
  [SMALL_STATE(2971)] = 69371,
  [SMALL_STATE(2972)] = 69493,
  [SMALL_STATE(2973)] = 69615,
  [SMALL_STATE(2974)] = 69737,
  [SMALL_STATE(2975)] = 69859,
  [SMALL_STATE(2976)] = 69981,
  [SMALL_STATE(2977)] = 70103,
  [SMALL_STATE(2978)] = 70225,
  [SMALL_STATE(2979)] = 70347,
  [SMALL_STATE(2980)] = 70469,
  [SMALL_STATE(2981)] = 70591,
  [SMALL_STATE(2982)] = 70713,
  [SMALL_STATE(2983)] = 70835,
  [SMALL_STATE(2984)] = 70957,
  [SMALL_STATE(2985)] = 71079,
  [SMALL_STATE(2986)] = 71201,
  [SMALL_STATE(2987)] = 71323,
  [SMALL_STATE(2988)] = 71445,
  [SMALL_STATE(2989)] = 71567,
  [SMALL_STATE(2990)] = 71689,
  [SMALL_STATE(2991)] = 71811,
  [SMALL_STATE(2992)] = 71933,
  [SMALL_STATE(2993)] = 72055,
  [SMALL_STATE(2994)] = 72177,
  [SMALL_STATE(2995)] = 72299,
  [SMALL_STATE(2996)] = 72421,
  [SMALL_STATE(2997)] = 72543,
  [SMALL_STATE(2998)] = 72665,
  [SMALL_STATE(2999)] = 72787,
  [SMALL_STATE(3000)] = 72909,
  [SMALL_STATE(3001)] = 73031,
  [SMALL_STATE(3002)] = 73153,
  [SMALL_STATE(3003)] = 73275,
  [SMALL_STATE(3004)] = 73397,
  [SMALL_STATE(3005)] = 73519,
  [SMALL_STATE(3006)] = 73641,
  [SMALL_STATE(3007)] = 73763,
  [SMALL_STATE(3008)] = 73885,
  [SMALL_STATE(3009)] = 74007,
  [SMALL_STATE(3010)] = 74129,
  [SMALL_STATE(3011)] = 74251,
  [SMALL_STATE(3012)] = 74373,
  [SMALL_STATE(3013)] = 74495,
  [SMALL_STATE(3014)] = 74617,
  [SMALL_STATE(3015)] = 74739,
  [SMALL_STATE(3016)] = 74861,
  [SMALL_STATE(3017)] = 74983,
  [SMALL_STATE(3018)] = 75105,
  [SMALL_STATE(3019)] = 75227,
  [SMALL_STATE(3020)] = 75349,
  [SMALL_STATE(3021)] = 75471,
  [SMALL_STATE(3022)] = 75593,
  [SMALL_STATE(3023)] = 75715,
  [SMALL_STATE(3024)] = 75837,
  [SMALL_STATE(3025)] = 75959,
  [SMALL_STATE(3026)] = 76081,
  [SMALL_STATE(3027)] = 76203,
  [SMALL_STATE(3028)] = 76325,
  [SMALL_STATE(3029)] = 76447,
  [SMALL_STATE(3030)] = 76569,
  [SMALL_STATE(3031)] = 76691,
  [SMALL_STATE(3032)] = 76813,
  [SMALL_STATE(3033)] = 76935,
  [SMALL_STATE(3034)] = 77057,
  [SMALL_STATE(3035)] = 77179,
  [SMALL_STATE(3036)] = 77301,
  [SMALL_STATE(3037)] = 77423,
  [SMALL_STATE(3038)] = 77545,
  [SMALL_STATE(3039)] = 77667,
  [SMALL_STATE(3040)] = 77789,
  [SMALL_STATE(3041)] = 77911,
  [SMALL_STATE(3042)] = 78033,
  [SMALL_STATE(3043)] = 78155,
  [SMALL_STATE(3044)] = 78277,
  [SMALL_STATE(3045)] = 78399,
  [SMALL_STATE(3046)] = 78521,
  [SMALL_STATE(3047)] = 78643,
  [SMALL_STATE(3048)] = 78765,
  [SMALL_STATE(3049)] = 78887,
  [SMALL_STATE(3050)] = 79009,
  [SMALL_STATE(3051)] = 79131,
  [SMALL_STATE(3052)] = 79253,
  [SMALL_STATE(3053)] = 79375,
  [SMALL_STATE(3054)] = 79497,
  [SMALL_STATE(3055)] = 79619,
  [SMALL_STATE(3056)] = 79741,
  [SMALL_STATE(3057)] = 79863,
  [SMALL_STATE(3058)] = 79985,
  [SMALL_STATE(3059)] = 80107,
  [SMALL_STATE(3060)] = 80229,
  [SMALL_STATE(3061)] = 80351,
  [SMALL_STATE(3062)] = 80473,
  [SMALL_STATE(3063)] = 80595,
  [SMALL_STATE(3064)] = 80717,
  [SMALL_STATE(3065)] = 80839,
  [SMALL_STATE(3066)] = 80961,
  [SMALL_STATE(3067)] = 81083,
  [SMALL_STATE(3068)] = 81205,
  [SMALL_STATE(3069)] = 81327,
  [SMALL_STATE(3070)] = 81449,
  [SMALL_STATE(3071)] = 81571,
  [SMALL_STATE(3072)] = 81693,
  [SMALL_STATE(3073)] = 81815,
  [SMALL_STATE(3074)] = 81937,
  [SMALL_STATE(3075)] = 82059,
  [SMALL_STATE(3076)] = 82181,
  [SMALL_STATE(3077)] = 82303,
  [SMALL_STATE(3078)] = 82425,
  [SMALL_STATE(3079)] = 82547,
  [SMALL_STATE(3080)] = 82669,
  [SMALL_STATE(3081)] = 82791,
  [SMALL_STATE(3082)] = 82913,
  [SMALL_STATE(3083)] = 83035,
  [SMALL_STATE(3084)] = 83157,
  [SMALL_STATE(3085)] = 83279,
  [SMALL_STATE(3086)] = 83401,
  [SMALL_STATE(3087)] = 83523,
  [SMALL_STATE(3088)] = 83645,
  [SMALL_STATE(3089)] = 83767,
  [SMALL_STATE(3090)] = 83889,
  [SMALL_STATE(3091)] = 84011,
  [SMALL_STATE(3092)] = 84133,
  [SMALL_STATE(3093)] = 84255,
  [SMALL_STATE(3094)] = 84377,
  [SMALL_STATE(3095)] = 84499,
  [SMALL_STATE(3096)] = 84621,
  [SMALL_STATE(3097)] = 84743,
  [SMALL_STATE(3098)] = 84865,
  [SMALL_STATE(3099)] = 84987,
  [SMALL_STATE(3100)] = 85109,
  [SMALL_STATE(3101)] = 85231,
  [SMALL_STATE(3102)] = 85353,
  [SMALL_STATE(3103)] = 85475,
  [SMALL_STATE(3104)] = 85597,
  [SMALL_STATE(3105)] = 85719,
  [SMALL_STATE(3106)] = 85841,
  [SMALL_STATE(3107)] = 85963,
  [SMALL_STATE(3108)] = 86085,
  [SMALL_STATE(3109)] = 86207,
  [SMALL_STATE(3110)] = 86329,
  [SMALL_STATE(3111)] = 86451,
  [SMALL_STATE(3112)] = 86573,
  [SMALL_STATE(3113)] = 86695,
  [SMALL_STATE(3114)] = 86817,
  [SMALL_STATE(3115)] = 86939,
  [SMALL_STATE(3116)] = 87061,
  [SMALL_STATE(3117)] = 87183,
  [SMALL_STATE(3118)] = 87305,
  [SMALL_STATE(3119)] = 87427,
  [SMALL_STATE(3120)] = 87549,
  [SMALL_STATE(3121)] = 87671,
  [SMALL_STATE(3122)] = 87793,
  [SMALL_STATE(3123)] = 87915,
  [SMALL_STATE(3124)] = 88037,
  [SMALL_STATE(3125)] = 88159,
  [SMALL_STATE(3126)] = 88281,
  [SMALL_STATE(3127)] = 88403,
  [SMALL_STATE(3128)] = 88525,
  [SMALL_STATE(3129)] = 88647,
  [SMALL_STATE(3130)] = 88769,
  [SMALL_STATE(3131)] = 88891,
  [SMALL_STATE(3132)] = 89013,
  [SMALL_STATE(3133)] = 89135,
  [SMALL_STATE(3134)] = 89257,
  [SMALL_STATE(3135)] = 89379,
  [SMALL_STATE(3136)] = 89501,
  [SMALL_STATE(3137)] = 89623,
  [SMALL_STATE(3138)] = 89745,
  [SMALL_STATE(3139)] = 89867,
  [SMALL_STATE(3140)] = 89989,
  [SMALL_STATE(3141)] = 90111,
  [SMALL_STATE(3142)] = 90233,
  [SMALL_STATE(3143)] = 90355,
  [SMALL_STATE(3144)] = 90477,
  [SMALL_STATE(3145)] = 90599,
  [SMALL_STATE(3146)] = 90721,
  [SMALL_STATE(3147)] = 90843,
  [SMALL_STATE(3148)] = 90965,
  [SMALL_STATE(3149)] = 91087,
  [SMALL_STATE(3150)] = 91209,
  [SMALL_STATE(3151)] = 91331,
  [SMALL_STATE(3152)] = 91453,
  [SMALL_STATE(3153)] = 91575,
  [SMALL_STATE(3154)] = 91697,
  [SMALL_STATE(3155)] = 91819,
  [SMALL_STATE(3156)] = 91941,
  [SMALL_STATE(3157)] = 92063,
  [SMALL_STATE(3158)] = 92185,
  [SMALL_STATE(3159)] = 92307,
  [SMALL_STATE(3160)] = 92429,
  [SMALL_STATE(3161)] = 92551,
  [SMALL_STATE(3162)] = 92673,
  [SMALL_STATE(3163)] = 92795,
  [SMALL_STATE(3164)] = 92917,
  [SMALL_STATE(3165)] = 93039,
  [SMALL_STATE(3166)] = 93161,
  [SMALL_STATE(3167)] = 93283,
  [SMALL_STATE(3168)] = 93405,
  [SMALL_STATE(3169)] = 93527,
  [SMALL_STATE(3170)] = 93649,
  [SMALL_STATE(3171)] = 93771,
  [SMALL_STATE(3172)] = 93893,
  [SMALL_STATE(3173)] = 94015,
  [SMALL_STATE(3174)] = 94137,
  [SMALL_STATE(3175)] = 94259,
  [SMALL_STATE(3176)] = 94381,
  [SMALL_STATE(3177)] = 94503,
  [SMALL_STATE(3178)] = 94625,
  [SMALL_STATE(3179)] = 94747,
  [SMALL_STATE(3180)] = 94869,
  [SMALL_STATE(3181)] = 94991,
  [SMALL_STATE(3182)] = 95110,
  [SMALL_STATE(3183)] = 95229,
  [SMALL_STATE(3184)] = 95348,
  [SMALL_STATE(3185)] = 95467,
  [SMALL_STATE(3186)] = 95586,
  [SMALL_STATE(3187)] = 95705,
  [SMALL_STATE(3188)] = 95824,
  [SMALL_STATE(3189)] = 95943,
  [SMALL_STATE(3190)] = 96062,
  [SMALL_STATE(3191)] = 96181,
  [SMALL_STATE(3192)] = 96300,
  [SMALL_STATE(3193)] = 96419,
  [SMALL_STATE(3194)] = 96538,
  [SMALL_STATE(3195)] = 96657,
  [SMALL_STATE(3196)] = 96776,
  [SMALL_STATE(3197)] = 96895,
  [SMALL_STATE(3198)] = 96964,
  [SMALL_STATE(3199)] = 97083,
  [SMALL_STATE(3200)] = 97202,
  [SMALL_STATE(3201)] = 97321,
  [SMALL_STATE(3202)] = 97440,
  [SMALL_STATE(3203)] = 97559,
  [SMALL_STATE(3204)] = 97678,
  [SMALL_STATE(3205)] = 97797,
  [SMALL_STATE(3206)] = 97916,
  [SMALL_STATE(3207)] = 98035,
  [SMALL_STATE(3208)] = 98154,
  [SMALL_STATE(3209)] = 98273,
  [SMALL_STATE(3210)] = 98392,
  [SMALL_STATE(3211)] = 98511,
  [SMALL_STATE(3212)] = 98630,
  [SMALL_STATE(3213)] = 98749,
  [SMALL_STATE(3214)] = 98868,
  [SMALL_STATE(3215)] = 98987,
  [SMALL_STATE(3216)] = 99106,
  [SMALL_STATE(3217)] = 99225,
  [SMALL_STATE(3218)] = 99344,
  [SMALL_STATE(3219)] = 99463,
  [SMALL_STATE(3220)] = 99582,
  [SMALL_STATE(3221)] = 99701,
  [SMALL_STATE(3222)] = 99820,
  [SMALL_STATE(3223)] = 99939,
  [SMALL_STATE(3224)] = 100058,
  [SMALL_STATE(3225)] = 100177,
  [SMALL_STATE(3226)] = 100296,
  [SMALL_STATE(3227)] = 100415,
  [SMALL_STATE(3228)] = 100534,
  [SMALL_STATE(3229)] = 100653,
  [SMALL_STATE(3230)] = 100772,
  [SMALL_STATE(3231)] = 100891,
  [SMALL_STATE(3232)] = 101010,
  [SMALL_STATE(3233)] = 101129,
  [SMALL_STATE(3234)] = 101248,
  [SMALL_STATE(3235)] = 101367,
  [SMALL_STATE(3236)] = 101486,
  [SMALL_STATE(3237)] = 101605,
  [SMALL_STATE(3238)] = 101724,
  [SMALL_STATE(3239)] = 101843,
  [SMALL_STATE(3240)] = 101962,
  [SMALL_STATE(3241)] = 102081,
  [SMALL_STATE(3242)] = 102200,
  [SMALL_STATE(3243)] = 102319,
  [SMALL_STATE(3244)] = 102438,
  [SMALL_STATE(3245)] = 102557,
  [SMALL_STATE(3246)] = 102676,
  [SMALL_STATE(3247)] = 102795,
  [SMALL_STATE(3248)] = 102914,
  [SMALL_STATE(3249)] = 103033,
  [SMALL_STATE(3250)] = 103152,
  [SMALL_STATE(3251)] = 103271,
  [SMALL_STATE(3252)] = 103390,
  [SMALL_STATE(3253)] = 103509,
  [SMALL_STATE(3254)] = 103628,
  [SMALL_STATE(3255)] = 103747,
  [SMALL_STATE(3256)] = 103866,
  [SMALL_STATE(3257)] = 103985,
  [SMALL_STATE(3258)] = 104104,
  [SMALL_STATE(3259)] = 104223,
  [SMALL_STATE(3260)] = 104342,
  [SMALL_STATE(3261)] = 104461,
  [SMALL_STATE(3262)] = 104580,
  [SMALL_STATE(3263)] = 104699,
  [SMALL_STATE(3264)] = 104818,
  [SMALL_STATE(3265)] = 104937,
  [SMALL_STATE(3266)] = 105056,
  [SMALL_STATE(3267)] = 105175,
  [SMALL_STATE(3268)] = 105294,
  [SMALL_STATE(3269)] = 105413,
  [SMALL_STATE(3270)] = 105532,
  [SMALL_STATE(3271)] = 105651,
  [SMALL_STATE(3272)] = 105770,
  [SMALL_STATE(3273)] = 105889,
  [SMALL_STATE(3274)] = 106008,
  [SMALL_STATE(3275)] = 106127,
  [SMALL_STATE(3276)] = 106246,
  [SMALL_STATE(3277)] = 106365,
  [SMALL_STATE(3278)] = 106484,
  [SMALL_STATE(3279)] = 106603,
  [SMALL_STATE(3280)] = 106722,
  [SMALL_STATE(3281)] = 106841,
  [SMALL_STATE(3282)] = 106960,
  [SMALL_STATE(3283)] = 107079,
  [SMALL_STATE(3284)] = 107198,
  [SMALL_STATE(3285)] = 107317,
  [SMALL_STATE(3286)] = 107436,
  [SMALL_STATE(3287)] = 107555,
  [SMALL_STATE(3288)] = 107674,
  [SMALL_STATE(3289)] = 107793,
  [SMALL_STATE(3290)] = 107912,
  [SMALL_STATE(3291)] = 108031,
  [SMALL_STATE(3292)] = 108150,
  [SMALL_STATE(3293)] = 108269,
  [SMALL_STATE(3294)] = 108388,
  [SMALL_STATE(3295)] = 108507,
  [SMALL_STATE(3296)] = 108626,
  [SMALL_STATE(3297)] = 108745,
  [SMALL_STATE(3298)] = 108864,
  [SMALL_STATE(3299)] = 108983,
  [SMALL_STATE(3300)] = 109102,
  [SMALL_STATE(3301)] = 109221,
  [SMALL_STATE(3302)] = 109340,
  [SMALL_STATE(3303)] = 109459,
  [SMALL_STATE(3304)] = 109578,
  [SMALL_STATE(3305)] = 109697,
  [SMALL_STATE(3306)] = 109816,
  [SMALL_STATE(3307)] = 109935,
  [SMALL_STATE(3308)] = 110054,
  [SMALL_STATE(3309)] = 110173,
  [SMALL_STATE(3310)] = 110292,
  [SMALL_STATE(3311)] = 110411,
  [SMALL_STATE(3312)] = 110530,
  [SMALL_STATE(3313)] = 110649,
  [SMALL_STATE(3314)] = 110768,
  [SMALL_STATE(3315)] = 110887,
  [SMALL_STATE(3316)] = 111006,
  [SMALL_STATE(3317)] = 111125,
  [SMALL_STATE(3318)] = 111244,
  [SMALL_STATE(3319)] = 111363,
  [SMALL_STATE(3320)] = 111482,
  [SMALL_STATE(3321)] = 111601,
  [SMALL_STATE(3322)] = 111720,
  [SMALL_STATE(3323)] = 111839,
  [SMALL_STATE(3324)] = 111958,
  [SMALL_STATE(3325)] = 112027,
  [SMALL_STATE(3326)] = 112146,
  [SMALL_STATE(3327)] = 112265,
  [SMALL_STATE(3328)] = 112384,
  [SMALL_STATE(3329)] = 112503,
  [SMALL_STATE(3330)] = 112622,
  [SMALL_STATE(3331)] = 112741,
  [SMALL_STATE(3332)] = 112860,
  [SMALL_STATE(3333)] = 112979,
  [SMALL_STATE(3334)] = 113098,
  [SMALL_STATE(3335)] = 113217,
  [SMALL_STATE(3336)] = 113336,
  [SMALL_STATE(3337)] = 113455,
  [SMALL_STATE(3338)] = 113574,
  [SMALL_STATE(3339)] = 113693,
  [SMALL_STATE(3340)] = 113812,
  [SMALL_STATE(3341)] = 113931,
  [SMALL_STATE(3342)] = 114050,
  [SMALL_STATE(3343)] = 114169,
  [SMALL_STATE(3344)] = 114288,
  [SMALL_STATE(3345)] = 114407,
  [SMALL_STATE(3346)] = 114526,
  [SMALL_STATE(3347)] = 114645,
  [SMALL_STATE(3348)] = 114764,
  [SMALL_STATE(3349)] = 114883,
  [SMALL_STATE(3350)] = 115002,
  [SMALL_STATE(3351)] = 115121,
  [SMALL_STATE(3352)] = 115240,
  [SMALL_STATE(3353)] = 115359,
  [SMALL_STATE(3354)] = 115478,
  [SMALL_STATE(3355)] = 115597,
  [SMALL_STATE(3356)] = 115716,
  [SMALL_STATE(3357)] = 115835,
  [SMALL_STATE(3358)] = 115954,
  [SMALL_STATE(3359)] = 116073,
  [SMALL_STATE(3360)] = 116192,
  [SMALL_STATE(3361)] = 116311,
  [SMALL_STATE(3362)] = 116430,
  [SMALL_STATE(3363)] = 116549,
  [SMALL_STATE(3364)] = 116668,
  [SMALL_STATE(3365)] = 116787,
  [SMALL_STATE(3366)] = 116906,
  [SMALL_STATE(3367)] = 117025,
  [SMALL_STATE(3368)] = 117144,
  [SMALL_STATE(3369)] = 117263,
  [SMALL_STATE(3370)] = 117382,
  [SMALL_STATE(3371)] = 117501,
  [SMALL_STATE(3372)] = 117620,
  [SMALL_STATE(3373)] = 117739,
  [SMALL_STATE(3374)] = 117858,
  [SMALL_STATE(3375)] = 117977,
  [SMALL_STATE(3376)] = 118096,
  [SMALL_STATE(3377)] = 118215,
  [SMALL_STATE(3378)] = 118334,
  [SMALL_STATE(3379)] = 118453,
  [SMALL_STATE(3380)] = 118572,
  [SMALL_STATE(3381)] = 118691,
  [SMALL_STATE(3382)] = 118810,
  [SMALL_STATE(3383)] = 118929,
  [SMALL_STATE(3384)] = 119048,
  [SMALL_STATE(3385)] = 119117,
  [SMALL_STATE(3386)] = 119236,
  [SMALL_STATE(3387)] = 119355,
  [SMALL_STATE(3388)] = 119474,
  [SMALL_STATE(3389)] = 119593,
  [SMALL_STATE(3390)] = 119712,
  [SMALL_STATE(3391)] = 119831,
  [SMALL_STATE(3392)] = 119950,
  [SMALL_STATE(3393)] = 120069,
  [SMALL_STATE(3394)] = 120188,
  [SMALL_STATE(3395)] = 120307,
  [SMALL_STATE(3396)] = 120426,
  [SMALL_STATE(3397)] = 120545,
  [SMALL_STATE(3398)] = 120614,
  [SMALL_STATE(3399)] = 120733,
  [SMALL_STATE(3400)] = 120852,
  [SMALL_STATE(3401)] = 120971,
  [SMALL_STATE(3402)] = 121090,
  [SMALL_STATE(3403)] = 121209,
  [SMALL_STATE(3404)] = 121328,
  [SMALL_STATE(3405)] = 121447,
  [SMALL_STATE(3406)] = 121566,
  [SMALL_STATE(3407)] = 121685,
  [SMALL_STATE(3408)] = 121804,
  [SMALL_STATE(3409)] = 121923,
  [SMALL_STATE(3410)] = 122042,
  [SMALL_STATE(3411)] = 122161,
  [SMALL_STATE(3412)] = 122280,
  [SMALL_STATE(3413)] = 122399,
  [SMALL_STATE(3414)] = 122518,
  [SMALL_STATE(3415)] = 122637,
  [SMALL_STATE(3416)] = 122756,
  [SMALL_STATE(3417)] = 122875,
  [SMALL_STATE(3418)] = 122994,
  [SMALL_STATE(3419)] = 123113,
  [SMALL_STATE(3420)] = 123232,
  [SMALL_STATE(3421)] = 123351,
  [SMALL_STATE(3422)] = 123470,
  [SMALL_STATE(3423)] = 123589,
  [SMALL_STATE(3424)] = 123708,
  [SMALL_STATE(3425)] = 123827,
  [SMALL_STATE(3426)] = 123946,
  [SMALL_STATE(3427)] = 124065,
  [SMALL_STATE(3428)] = 124184,
  [SMALL_STATE(3429)] = 124303,
  [SMALL_STATE(3430)] = 124422,
  [SMALL_STATE(3431)] = 124541,
  [SMALL_STATE(3432)] = 124660,
  [SMALL_STATE(3433)] = 124779,
  [SMALL_STATE(3434)] = 124898,
  [SMALL_STATE(3435)] = 125017,
  [SMALL_STATE(3436)] = 125136,
  [SMALL_STATE(3437)] = 125255,
  [SMALL_STATE(3438)] = 125374,
  [SMALL_STATE(3439)] = 125493,
  [SMALL_STATE(3440)] = 125612,
  [SMALL_STATE(3441)] = 125731,
  [SMALL_STATE(3442)] = 125850,
  [SMALL_STATE(3443)] = 125969,
  [SMALL_STATE(3444)] = 126088,
  [SMALL_STATE(3445)] = 126207,
  [SMALL_STATE(3446)] = 126326,
  [SMALL_STATE(3447)] = 126445,
  [SMALL_STATE(3448)] = 126564,
  [SMALL_STATE(3449)] = 126683,
  [SMALL_STATE(3450)] = 126802,
  [SMALL_STATE(3451)] = 126921,
  [SMALL_STATE(3452)] = 127040,
  [SMALL_STATE(3453)] = 127159,
  [SMALL_STATE(3454)] = 127278,
  [SMALL_STATE(3455)] = 127397,
  [SMALL_STATE(3456)] = 127516,
  [SMALL_STATE(3457)] = 127635,
  [SMALL_STATE(3458)] = 127754,
  [SMALL_STATE(3459)] = 127873,
  [SMALL_STATE(3460)] = 127992,
  [SMALL_STATE(3461)] = 128111,
  [SMALL_STATE(3462)] = 128230,
  [SMALL_STATE(3463)] = 128349,
  [SMALL_STATE(3464)] = 128468,
  [SMALL_STATE(3465)] = 128587,
  [SMALL_STATE(3466)] = 128706,
  [SMALL_STATE(3467)] = 128825,
  [SMALL_STATE(3468)] = 128944,
  [SMALL_STATE(3469)] = 129063,
  [SMALL_STATE(3470)] = 129182,
  [SMALL_STATE(3471)] = 129301,
  [SMALL_STATE(3472)] = 129420,
  [SMALL_STATE(3473)] = 129539,
  [SMALL_STATE(3474)] = 129658,
  [SMALL_STATE(3475)] = 129777,
  [SMALL_STATE(3476)] = 129896,
  [SMALL_STATE(3477)] = 130015,
  [SMALL_STATE(3478)] = 130134,
  [SMALL_STATE(3479)] = 130253,
  [SMALL_STATE(3480)] = 130372,
  [SMALL_STATE(3481)] = 130491,
  [SMALL_STATE(3482)] = 130610,
  [SMALL_STATE(3483)] = 130729,
  [SMALL_STATE(3484)] = 130848,
  [SMALL_STATE(3485)] = 130967,
  [SMALL_STATE(3486)] = 131086,
  [SMALL_STATE(3487)] = 131205,
  [SMALL_STATE(3488)] = 131324,
  [SMALL_STATE(3489)] = 131443,
  [SMALL_STATE(3490)] = 131562,
  [SMALL_STATE(3491)] = 131681,
  [SMALL_STATE(3492)] = 131800,
  [SMALL_STATE(3493)] = 131919,
  [SMALL_STATE(3494)] = 132038,
  [SMALL_STATE(3495)] = 132157,
  [SMALL_STATE(3496)] = 132276,
  [SMALL_STATE(3497)] = 132395,
  [SMALL_STATE(3498)] = 132514,
  [SMALL_STATE(3499)] = 132633,
  [SMALL_STATE(3500)] = 132752,
  [SMALL_STATE(3501)] = 132871,
  [SMALL_STATE(3502)] = 132990,
  [SMALL_STATE(3503)] = 133109,
  [SMALL_STATE(3504)] = 133228,
  [SMALL_STATE(3505)] = 133347,
  [SMALL_STATE(3506)] = 133466,
  [SMALL_STATE(3507)] = 133585,
  [SMALL_STATE(3508)] = 133704,
  [SMALL_STATE(3509)] = 133823,
  [SMALL_STATE(3510)] = 133942,
  [SMALL_STATE(3511)] = 134061,
  [SMALL_STATE(3512)] = 134180,
  [SMALL_STATE(3513)] = 134299,
  [SMALL_STATE(3514)] = 134418,
  [SMALL_STATE(3515)] = 134537,
  [SMALL_STATE(3516)] = 134656,
  [SMALL_STATE(3517)] = 134775,
  [SMALL_STATE(3518)] = 134894,
  [SMALL_STATE(3519)] = 135013,
  [SMALL_STATE(3520)] = 135132,
  [SMALL_STATE(3521)] = 135251,
  [SMALL_STATE(3522)] = 135370,
  [SMALL_STATE(3523)] = 135489,
  [SMALL_STATE(3524)] = 135608,
  [SMALL_STATE(3525)] = 135727,
  [SMALL_STATE(3526)] = 135846,
  [SMALL_STATE(3527)] = 135965,
  [SMALL_STATE(3528)] = 136084,
  [SMALL_STATE(3529)] = 136203,
  [SMALL_STATE(3530)] = 136322,
  [SMALL_STATE(3531)] = 136441,
  [SMALL_STATE(3532)] = 136560,
  [SMALL_STATE(3533)] = 136679,
  [SMALL_STATE(3534)] = 136798,
  [SMALL_STATE(3535)] = 136917,
  [SMALL_STATE(3536)] = 137036,
  [SMALL_STATE(3537)] = 137155,
  [SMALL_STATE(3538)] = 137274,
  [SMALL_STATE(3539)] = 137393,
  [SMALL_STATE(3540)] = 137512,
  [SMALL_STATE(3541)] = 137631,
  [SMALL_STATE(3542)] = 137750,
  [SMALL_STATE(3543)] = 137869,
  [SMALL_STATE(3544)] = 137988,
  [SMALL_STATE(3545)] = 138107,
  [SMALL_STATE(3546)] = 138226,
  [SMALL_STATE(3547)] = 138345,
  [SMALL_STATE(3548)] = 138464,
  [SMALL_STATE(3549)] = 138583,
  [SMALL_STATE(3550)] = 138702,
  [SMALL_STATE(3551)] = 138821,
  [SMALL_STATE(3552)] = 138940,
  [SMALL_STATE(3553)] = 139059,
  [SMALL_STATE(3554)] = 139178,
  [SMALL_STATE(3555)] = 139297,
  [SMALL_STATE(3556)] = 139416,
  [SMALL_STATE(3557)] = 139535,
  [SMALL_STATE(3558)] = 139654,
  [SMALL_STATE(3559)] = 139773,
  [SMALL_STATE(3560)] = 139892,
  [SMALL_STATE(3561)] = 140011,
  [SMALL_STATE(3562)] = 140130,
  [SMALL_STATE(3563)] = 140249,
  [SMALL_STATE(3564)] = 140368,
  [SMALL_STATE(3565)] = 140487,
  [SMALL_STATE(3566)] = 140606,
  [SMALL_STATE(3567)] = 140725,
  [SMALL_STATE(3568)] = 140844,
  [SMALL_STATE(3569)] = 140963,
  [SMALL_STATE(3570)] = 141082,
  [SMALL_STATE(3571)] = 141201,
  [SMALL_STATE(3572)] = 141320,
  [SMALL_STATE(3573)] = 141439,
  [SMALL_STATE(3574)] = 141558,
  [SMALL_STATE(3575)] = 141677,
  [SMALL_STATE(3576)] = 141796,
  [SMALL_STATE(3577)] = 141915,
  [SMALL_STATE(3578)] = 142034,
  [SMALL_STATE(3579)] = 142153,
  [SMALL_STATE(3580)] = 142272,
  [SMALL_STATE(3581)] = 142391,
  [SMALL_STATE(3582)] = 142510,
  [SMALL_STATE(3583)] = 142629,
  [SMALL_STATE(3584)] = 142748,
  [SMALL_STATE(3585)] = 142867,
  [SMALL_STATE(3586)] = 142986,
  [SMALL_STATE(3587)] = 143105,
  [SMALL_STATE(3588)] = 143224,
  [SMALL_STATE(3589)] = 143343,
  [SMALL_STATE(3590)] = 143462,
  [SMALL_STATE(3591)] = 143581,
  [SMALL_STATE(3592)] = 143700,
  [SMALL_STATE(3593)] = 143819,
  [SMALL_STATE(3594)] = 143938,
  [SMALL_STATE(3595)] = 144057,
  [SMALL_STATE(3596)] = 144126,
  [SMALL_STATE(3597)] = 144245,
  [SMALL_STATE(3598)] = 144364,
  [SMALL_STATE(3599)] = 144483,
  [SMALL_STATE(3600)] = 144602,
  [SMALL_STATE(3601)] = 144721,
  [SMALL_STATE(3602)] = 144840,
  [SMALL_STATE(3603)] = 144959,
  [SMALL_STATE(3604)] = 145078,
  [SMALL_STATE(3605)] = 145197,
  [SMALL_STATE(3606)] = 145316,
  [SMALL_STATE(3607)] = 145435,
  [SMALL_STATE(3608)] = 145554,
  [SMALL_STATE(3609)] = 145673,
  [SMALL_STATE(3610)] = 145792,
  [SMALL_STATE(3611)] = 145911,
  [SMALL_STATE(3612)] = 146030,
  [SMALL_STATE(3613)] = 146149,
  [SMALL_STATE(3614)] = 146268,
  [SMALL_STATE(3615)] = 146387,
  [SMALL_STATE(3616)] = 146506,
  [SMALL_STATE(3617)] = 146625,
  [SMALL_STATE(3618)] = 146744,
  [SMALL_STATE(3619)] = 146863,
  [SMALL_STATE(3620)] = 146982,
  [SMALL_STATE(3621)] = 147101,
  [SMALL_STATE(3622)] = 147220,
  [SMALL_STATE(3623)] = 147339,
  [SMALL_STATE(3624)] = 147458,
  [SMALL_STATE(3625)] = 147577,
  [SMALL_STATE(3626)] = 147696,
  [SMALL_STATE(3627)] = 147815,
  [SMALL_STATE(3628)] = 147934,
  [SMALL_STATE(3629)] = 148053,
  [SMALL_STATE(3630)] = 148172,
  [SMALL_STATE(3631)] = 148291,
  [SMALL_STATE(3632)] = 148410,
  [SMALL_STATE(3633)] = 148529,
  [SMALL_STATE(3634)] = 148648,
  [SMALL_STATE(3635)] = 148767,
  [SMALL_STATE(3636)] = 148886,
  [SMALL_STATE(3637)] = 149005,
  [SMALL_STATE(3638)] = 149124,
  [SMALL_STATE(3639)] = 149243,
  [SMALL_STATE(3640)] = 149362,
  [SMALL_STATE(3641)] = 149481,
  [SMALL_STATE(3642)] = 149600,
  [SMALL_STATE(3643)] = 149719,
  [SMALL_STATE(3644)] = 149838,
  [SMALL_STATE(3645)] = 149957,
  [SMALL_STATE(3646)] = 150076,
  [SMALL_STATE(3647)] = 150195,
  [SMALL_STATE(3648)] = 150314,
  [SMALL_STATE(3649)] = 150433,
  [SMALL_STATE(3650)] = 150552,
  [SMALL_STATE(3651)] = 150671,
  [SMALL_STATE(3652)] = 150790,
  [SMALL_STATE(3653)] = 150909,
  [SMALL_STATE(3654)] = 151028,
  [SMALL_STATE(3655)] = 151147,
  [SMALL_STATE(3656)] = 151266,
  [SMALL_STATE(3657)] = 151385,
  [SMALL_STATE(3658)] = 151504,
  [SMALL_STATE(3659)] = 151623,
  [SMALL_STATE(3660)] = 151742,
  [SMALL_STATE(3661)] = 151861,
  [SMALL_STATE(3662)] = 151980,
  [SMALL_STATE(3663)] = 152099,
  [SMALL_STATE(3664)] = 152218,
  [SMALL_STATE(3665)] = 152337,
  [SMALL_STATE(3666)] = 152456,
  [SMALL_STATE(3667)] = 152575,
  [SMALL_STATE(3668)] = 152694,
  [SMALL_STATE(3669)] = 152813,
  [SMALL_STATE(3670)] = 152932,
  [SMALL_STATE(3671)] = 153051,
  [SMALL_STATE(3672)] = 153170,
  [SMALL_STATE(3673)] = 153289,
  [SMALL_STATE(3674)] = 153408,
  [SMALL_STATE(3675)] = 153527,
  [SMALL_STATE(3676)] = 153646,
  [SMALL_STATE(3677)] = 153765,
  [SMALL_STATE(3678)] = 153884,
  [SMALL_STATE(3679)] = 154003,
  [SMALL_STATE(3680)] = 154122,
  [SMALL_STATE(3681)] = 154241,
  [SMALL_STATE(3682)] = 154360,
  [SMALL_STATE(3683)] = 154479,
  [SMALL_STATE(3684)] = 154598,
  [SMALL_STATE(3685)] = 154717,
  [SMALL_STATE(3686)] = 154836,
  [SMALL_STATE(3687)] = 154955,
  [SMALL_STATE(3688)] = 155074,
  [SMALL_STATE(3689)] = 155193,
  [SMALL_STATE(3690)] = 155312,
  [SMALL_STATE(3691)] = 155431,
  [SMALL_STATE(3692)] = 155550,
  [SMALL_STATE(3693)] = 155669,
  [SMALL_STATE(3694)] = 155788,
  [SMALL_STATE(3695)] = 155907,
  [SMALL_STATE(3696)] = 156026,
  [SMALL_STATE(3697)] = 156145,
  [SMALL_STATE(3698)] = 156264,
  [SMALL_STATE(3699)] = 156383,
  [SMALL_STATE(3700)] = 156502,
  [SMALL_STATE(3701)] = 156621,
  [SMALL_STATE(3702)] = 156740,
  [SMALL_STATE(3703)] = 156859,
  [SMALL_STATE(3704)] = 156978,
  [SMALL_STATE(3705)] = 157097,
  [SMALL_STATE(3706)] = 157216,
  [SMALL_STATE(3707)] = 157335,
  [SMALL_STATE(3708)] = 157454,
  [SMALL_STATE(3709)] = 157573,
  [SMALL_STATE(3710)] = 157692,
  [SMALL_STATE(3711)] = 157811,
  [SMALL_STATE(3712)] = 157930,
  [SMALL_STATE(3713)] = 158049,
  [SMALL_STATE(3714)] = 158168,
  [SMALL_STATE(3715)] = 158287,
  [SMALL_STATE(3716)] = 158406,
  [SMALL_STATE(3717)] = 158525,
  [SMALL_STATE(3718)] = 158644,
  [SMALL_STATE(3719)] = 158763,
  [SMALL_STATE(3720)] = 158882,
  [SMALL_STATE(3721)] = 159001,
  [SMALL_STATE(3722)] = 159120,
  [SMALL_STATE(3723)] = 159239,
  [SMALL_STATE(3724)] = 159358,
  [SMALL_STATE(3725)] = 159477,
  [SMALL_STATE(3726)] = 159596,
  [SMALL_STATE(3727)] = 159715,
  [SMALL_STATE(3728)] = 159834,
  [SMALL_STATE(3729)] = 159953,
  [SMALL_STATE(3730)] = 160072,
  [SMALL_STATE(3731)] = 160191,
  [SMALL_STATE(3732)] = 160310,
  [SMALL_STATE(3733)] = 160429,
  [SMALL_STATE(3734)] = 160548,
  [SMALL_STATE(3735)] = 160667,
  [SMALL_STATE(3736)] = 160786,
  [SMALL_STATE(3737)] = 160905,
  [SMALL_STATE(3738)] = 161024,
  [SMALL_STATE(3739)] = 161143,
  [SMALL_STATE(3740)] = 161262,
  [SMALL_STATE(3741)] = 161381,
  [SMALL_STATE(3742)] = 161500,
  [SMALL_STATE(3743)] = 161619,
  [SMALL_STATE(3744)] = 161738,
  [SMALL_STATE(3745)] = 161857,
  [SMALL_STATE(3746)] = 161976,
  [SMALL_STATE(3747)] = 162095,
  [SMALL_STATE(3748)] = 162214,
  [SMALL_STATE(3749)] = 162333,
  [SMALL_STATE(3750)] = 162452,
  [SMALL_STATE(3751)] = 162571,
  [SMALL_STATE(3752)] = 162690,
  [SMALL_STATE(3753)] = 162809,
  [SMALL_STATE(3754)] = 162928,
  [SMALL_STATE(3755)] = 163047,
  [SMALL_STATE(3756)] = 163166,
  [SMALL_STATE(3757)] = 163285,
  [SMALL_STATE(3758)] = 163404,
  [SMALL_STATE(3759)] = 163523,
  [SMALL_STATE(3760)] = 163642,
  [SMALL_STATE(3761)] = 163761,
  [SMALL_STATE(3762)] = 163880,
  [SMALL_STATE(3763)] = 163999,
  [SMALL_STATE(3764)] = 164118,
  [SMALL_STATE(3765)] = 164237,
  [SMALL_STATE(3766)] = 164356,
  [SMALL_STATE(3767)] = 164475,
  [SMALL_STATE(3768)] = 164594,
  [SMALL_STATE(3769)] = 164713,
  [SMALL_STATE(3770)] = 164832,
  [SMALL_STATE(3771)] = 164951,
  [SMALL_STATE(3772)] = 165070,
  [SMALL_STATE(3773)] = 165189,
  [SMALL_STATE(3774)] = 165308,
  [SMALL_STATE(3775)] = 165427,
  [SMALL_STATE(3776)] = 165546,
  [SMALL_STATE(3777)] = 165665,
  [SMALL_STATE(3778)] = 165784,
  [SMALL_STATE(3779)] = 165903,
  [SMALL_STATE(3780)] = 166022,
  [SMALL_STATE(3781)] = 166141,
  [SMALL_STATE(3782)] = 166260,
  [SMALL_STATE(3783)] = 166379,
  [SMALL_STATE(3784)] = 166498,
  [SMALL_STATE(3785)] = 166617,
  [SMALL_STATE(3786)] = 166736,
  [SMALL_STATE(3787)] = 166855,
  [SMALL_STATE(3788)] = 166974,
  [SMALL_STATE(3789)] = 167093,
  [SMALL_STATE(3790)] = 167212,
  [SMALL_STATE(3791)] = 167331,
  [SMALL_STATE(3792)] = 167450,
  [SMALL_STATE(3793)] = 167569,
  [SMALL_STATE(3794)] = 167688,
  [SMALL_STATE(3795)] = 167807,
  [SMALL_STATE(3796)] = 167926,
  [SMALL_STATE(3797)] = 168045,
  [SMALL_STATE(3798)] = 168164,
  [SMALL_STATE(3799)] = 168283,
  [SMALL_STATE(3800)] = 168402,
  [SMALL_STATE(3801)] = 168521,
  [SMALL_STATE(3802)] = 168640,
  [SMALL_STATE(3803)] = 168759,
  [SMALL_STATE(3804)] = 168878,
  [SMALL_STATE(3805)] = 168997,
  [SMALL_STATE(3806)] = 169116,
  [SMALL_STATE(3807)] = 169235,
  [SMALL_STATE(3808)] = 169354,
  [SMALL_STATE(3809)] = 169473,
  [SMALL_STATE(3810)] = 169592,
  [SMALL_STATE(3811)] = 169711,
  [SMALL_STATE(3812)] = 169830,
  [SMALL_STATE(3813)] = 169949,
  [SMALL_STATE(3814)] = 170068,
  [SMALL_STATE(3815)] = 170187,
  [SMALL_STATE(3816)] = 170306,
  [SMALL_STATE(3817)] = 170425,
  [SMALL_STATE(3818)] = 170544,
  [SMALL_STATE(3819)] = 170663,
  [SMALL_STATE(3820)] = 170782,
  [SMALL_STATE(3821)] = 170901,
  [SMALL_STATE(3822)] = 171020,
  [SMALL_STATE(3823)] = 171139,
  [SMALL_STATE(3824)] = 171258,
  [SMALL_STATE(3825)] = 171377,
  [SMALL_STATE(3826)] = 171496,
  [SMALL_STATE(3827)] = 171615,
  [SMALL_STATE(3828)] = 171734,
  [SMALL_STATE(3829)] = 171853,
  [SMALL_STATE(3830)] = 171972,
  [SMALL_STATE(3831)] = 172091,
  [SMALL_STATE(3832)] = 172210,
  [SMALL_STATE(3833)] = 172329,
  [SMALL_STATE(3834)] = 172448,
  [SMALL_STATE(3835)] = 172567,
  [SMALL_STATE(3836)] = 172686,
  [SMALL_STATE(3837)] = 172805,
  [SMALL_STATE(3838)] = 172924,
  [SMALL_STATE(3839)] = 173043,
  [SMALL_STATE(3840)] = 173162,
  [SMALL_STATE(3841)] = 173281,
  [SMALL_STATE(3842)] = 173400,
  [SMALL_STATE(3843)] = 173519,
  [SMALL_STATE(3844)] = 173638,
  [SMALL_STATE(3845)] = 173757,
  [SMALL_STATE(3846)] = 173876,
  [SMALL_STATE(3847)] = 173995,
  [SMALL_STATE(3848)] = 174114,
  [SMALL_STATE(3849)] = 174233,
  [SMALL_STATE(3850)] = 174352,
  [SMALL_STATE(3851)] = 174471,
  [SMALL_STATE(3852)] = 174590,
  [SMALL_STATE(3853)] = 174709,
  [SMALL_STATE(3854)] = 174828,
  [SMALL_STATE(3855)] = 174947,
  [SMALL_STATE(3856)] = 175066,
  [SMALL_STATE(3857)] = 175185,
  [SMALL_STATE(3858)] = 175304,
  [SMALL_STATE(3859)] = 175423,
  [SMALL_STATE(3860)] = 175542,
  [SMALL_STATE(3861)] = 175661,
  [SMALL_STATE(3862)] = 175780,
  [SMALL_STATE(3863)] = 175899,
  [SMALL_STATE(3864)] = 176018,
  [SMALL_STATE(3865)] = 176137,
  [SMALL_STATE(3866)] = 176256,
  [SMALL_STATE(3867)] = 176375,
  [SMALL_STATE(3868)] = 176494,
  [SMALL_STATE(3869)] = 176613,
  [SMALL_STATE(3870)] = 176732,
  [SMALL_STATE(3871)] = 176851,
  [SMALL_STATE(3872)] = 176970,
  [SMALL_STATE(3873)] = 177089,
  [SMALL_STATE(3874)] = 177208,
  [SMALL_STATE(3875)] = 177327,
  [SMALL_STATE(3876)] = 177446,
  [SMALL_STATE(3877)] = 177565,
  [SMALL_STATE(3878)] = 177684,
  [SMALL_STATE(3879)] = 177803,
  [SMALL_STATE(3880)] = 177922,
  [SMALL_STATE(3881)] = 178041,
  [SMALL_STATE(3882)] = 178160,
  [SMALL_STATE(3883)] = 178279,
  [SMALL_STATE(3884)] = 178398,
  [SMALL_STATE(3885)] = 178517,
  [SMALL_STATE(3886)] = 178636,
  [SMALL_STATE(3887)] = 178755,
  [SMALL_STATE(3888)] = 178874,
  [SMALL_STATE(3889)] = 178993,
  [SMALL_STATE(3890)] = 179112,
  [SMALL_STATE(3891)] = 179231,
  [SMALL_STATE(3892)] = 179350,
  [SMALL_STATE(3893)] = 179469,
  [SMALL_STATE(3894)] = 179588,
  [SMALL_STATE(3895)] = 179707,
  [SMALL_STATE(3896)] = 179826,
  [SMALL_STATE(3897)] = 179945,
  [SMALL_STATE(3898)] = 180064,
  [SMALL_STATE(3899)] = 180183,
  [SMALL_STATE(3900)] = 180302,
  [SMALL_STATE(3901)] = 180421,
  [SMALL_STATE(3902)] = 180540,
  [SMALL_STATE(3903)] = 180659,
  [SMALL_STATE(3904)] = 180778,
  [SMALL_STATE(3905)] = 180897,
  [SMALL_STATE(3906)] = 181016,
  [SMALL_STATE(3907)] = 181135,
  [SMALL_STATE(3908)] = 181254,
  [SMALL_STATE(3909)] = 181373,
  [SMALL_STATE(3910)] = 181492,
  [SMALL_STATE(3911)] = 181611,
  [SMALL_STATE(3912)] = 181730,
  [SMALL_STATE(3913)] = 181849,
  [SMALL_STATE(3914)] = 181968,
  [SMALL_STATE(3915)] = 182087,
  [SMALL_STATE(3916)] = 182206,
  [SMALL_STATE(3917)] = 182325,
  [SMALL_STATE(3918)] = 182444,
  [SMALL_STATE(3919)] = 182563,
  [SMALL_STATE(3920)] = 182682,
  [SMALL_STATE(3921)] = 182801,
  [SMALL_STATE(3922)] = 182920,
  [SMALL_STATE(3923)] = 183039,
  [SMALL_STATE(3924)] = 183158,
  [SMALL_STATE(3925)] = 183277,
  [SMALL_STATE(3926)] = 183396,
  [SMALL_STATE(3927)] = 183515,
  [SMALL_STATE(3928)] = 183634,
  [SMALL_STATE(3929)] = 183753,
  [SMALL_STATE(3930)] = 183872,
  [SMALL_STATE(3931)] = 183991,
  [SMALL_STATE(3932)] = 184110,
  [SMALL_STATE(3933)] = 184229,
  [SMALL_STATE(3934)] = 184348,
  [SMALL_STATE(3935)] = 184467,
  [SMALL_STATE(3936)] = 184586,
  [SMALL_STATE(3937)] = 184705,
  [SMALL_STATE(3938)] = 184824,
  [SMALL_STATE(3939)] = 184943,
  [SMALL_STATE(3940)] = 185062,
  [SMALL_STATE(3941)] = 185181,
  [SMALL_STATE(3942)] = 185300,
  [SMALL_STATE(3943)] = 185419,
  [SMALL_STATE(3944)] = 185538,
  [SMALL_STATE(3945)] = 185657,
  [SMALL_STATE(3946)] = 185776,
  [SMALL_STATE(3947)] = 185895,
  [SMALL_STATE(3948)] = 186014,
  [SMALL_STATE(3949)] = 186133,
  [SMALL_STATE(3950)] = 186252,
  [SMALL_STATE(3951)] = 186371,
  [SMALL_STATE(3952)] = 186490,
  [SMALL_STATE(3953)] = 186609,
  [SMALL_STATE(3954)] = 186728,
  [SMALL_STATE(3955)] = 186847,
  [SMALL_STATE(3956)] = 186966,
  [SMALL_STATE(3957)] = 187085,
  [SMALL_STATE(3958)] = 187204,
  [SMALL_STATE(3959)] = 187323,
  [SMALL_STATE(3960)] = 187442,
  [SMALL_STATE(3961)] = 187561,
  [SMALL_STATE(3962)] = 187680,
  [SMALL_STATE(3963)] = 187749,
  [SMALL_STATE(3964)] = 187868,
  [SMALL_STATE(3965)] = 187987,
  [SMALL_STATE(3966)] = 188106,
  [SMALL_STATE(3967)] = 188225,
  [SMALL_STATE(3968)] = 188344,
  [SMALL_STATE(3969)] = 188463,
  [SMALL_STATE(3970)] = 188582,
  [SMALL_STATE(3971)] = 188701,
  [SMALL_STATE(3972)] = 188820,
  [SMALL_STATE(3973)] = 188939,
  [SMALL_STATE(3974)] = 189007,
  [SMALL_STATE(3975)] = 189075,
  [SMALL_STATE(3976)] = 189143,
  [SMALL_STATE(3977)] = 189211,
  [SMALL_STATE(3978)] = 189279,
  [SMALL_STATE(3979)] = 189394,
  [SMALL_STATE(3980)] = 189509,
  [SMALL_STATE(3981)] = 189624,
  [SMALL_STATE(3982)] = 189739,
  [SMALL_STATE(3983)] = 189854,
  [SMALL_STATE(3984)] = 189921,
  [SMALL_STATE(3985)] = 190036,
  [SMALL_STATE(3986)] = 190099,
  [SMALL_STATE(3987)] = 190214,
  [SMALL_STATE(3988)] = 190277,
  [SMALL_STATE(3989)] = 190392,
  [SMALL_STATE(3990)] = 190507,
  [SMALL_STATE(3991)] = 190622,
  [SMALL_STATE(3992)] = 190737,
  [SMALL_STATE(3993)] = 190852,
  [SMALL_STATE(3994)] = 190967,
  [SMALL_STATE(3995)] = 191082,
  [SMALL_STATE(3996)] = 191197,
  [SMALL_STATE(3997)] = 191312,
  [SMALL_STATE(3998)] = 191427,
  [SMALL_STATE(3999)] = 191542,
  [SMALL_STATE(4000)] = 191657,
  [SMALL_STATE(4001)] = 191772,
  [SMALL_STATE(4002)] = 191887,
  [SMALL_STATE(4003)] = 192002,
  [SMALL_STATE(4004)] = 192117,
  [SMALL_STATE(4005)] = 192232,
  [SMALL_STATE(4006)] = 192347,
  [SMALL_STATE(4007)] = 192462,
  [SMALL_STATE(4008)] = 192577,
  [SMALL_STATE(4009)] = 192692,
  [SMALL_STATE(4010)] = 192807,
  [SMALL_STATE(4011)] = 192922,
  [SMALL_STATE(4012)] = 193037,
  [SMALL_STATE(4013)] = 193152,
  [SMALL_STATE(4014)] = 193267,
  [SMALL_STATE(4015)] = 193382,
  [SMALL_STATE(4016)] = 193497,
  [SMALL_STATE(4017)] = 193612,
  [SMALL_STATE(4018)] = 193727,
  [SMALL_STATE(4019)] = 193842,
  [SMALL_STATE(4020)] = 193957,
  [SMALL_STATE(4021)] = 194072,
  [SMALL_STATE(4022)] = 194187,
  [SMALL_STATE(4023)] = 194302,
  [SMALL_STATE(4024)] = 194417,
  [SMALL_STATE(4025)] = 194532,
  [SMALL_STATE(4026)] = 194647,
  [SMALL_STATE(4027)] = 194762,
  [SMALL_STATE(4028)] = 194877,
  [SMALL_STATE(4029)] = 194992,
  [SMALL_STATE(4030)] = 195107,
  [SMALL_STATE(4031)] = 195222,
  [SMALL_STATE(4032)] = 195337,
  [SMALL_STATE(4033)] = 195452,
  [SMALL_STATE(4034)] = 195567,
  [SMALL_STATE(4035)] = 195682,
  [SMALL_STATE(4036)] = 195797,
  [SMALL_STATE(4037)] = 195912,
  [SMALL_STATE(4038)] = 196024,
  [SMALL_STATE(4039)] = 196136,
  [SMALL_STATE(4040)] = 196248,
  [SMALL_STATE(4041)] = 196360,
  [SMALL_STATE(4042)] = 196472,
  [SMALL_STATE(4043)] = 196584,
  [SMALL_STATE(4044)] = 196696,
  [SMALL_STATE(4045)] = 196808,
  [SMALL_STATE(4046)] = 196920,
  [SMALL_STATE(4047)] = 197032,
  [SMALL_STATE(4048)] = 197144,
  [SMALL_STATE(4049)] = 197254,
  [SMALL_STATE(4050)] = 197366,
  [SMALL_STATE(4051)] = 197428,
  [SMALL_STATE(4052)] = 197540,
  [SMALL_STATE(4053)] = 197652,
  [SMALL_STATE(4054)] = 197764,
  [SMALL_STATE(4055)] = 197876,
  [SMALL_STATE(4056)] = 197988,
  [SMALL_STATE(4057)] = 198100,
  [SMALL_STATE(4058)] = 198212,
  [SMALL_STATE(4059)] = 198324,
  [SMALL_STATE(4060)] = 198436,
  [SMALL_STATE(4061)] = 198548,
  [SMALL_STATE(4062)] = 198660,
  [SMALL_STATE(4063)] = 198722,
  [SMALL_STATE(4064)] = 198834,
  [SMALL_STATE(4065)] = 198946,
  [SMALL_STATE(4066)] = 199058,
  [SMALL_STATE(4067)] = 199170,
  [SMALL_STATE(4068)] = 199282,
  [SMALL_STATE(4069)] = 199394,
  [SMALL_STATE(4070)] = 199506,
  [SMALL_STATE(4071)] = 199618,
  [SMALL_STATE(4072)] = 199730,
  [SMALL_STATE(4073)] = 199842,
  [SMALL_STATE(4074)] = 199954,
  [SMALL_STATE(4075)] = 200066,
  [SMALL_STATE(4076)] = 200178,
  [SMALL_STATE(4077)] = 200290,
  [SMALL_STATE(4078)] = 200402,
  [SMALL_STATE(4079)] = 200514,
  [SMALL_STATE(4080)] = 200626,
  [SMALL_STATE(4081)] = 200688,
  [SMALL_STATE(4082)] = 200800,
  [SMALL_STATE(4083)] = 200912,
  [SMALL_STATE(4084)] = 201024,
  [SMALL_STATE(4085)] = 201136,
  [SMALL_STATE(4086)] = 201248,
  [SMALL_STATE(4087)] = 201360,
  [SMALL_STATE(4088)] = 201472,
  [SMALL_STATE(4089)] = 201584,
  [SMALL_STATE(4090)] = 201696,
  [SMALL_STATE(4091)] = 201808,
  [SMALL_STATE(4092)] = 201920,
  [SMALL_STATE(4093)] = 202032,
  [SMALL_STATE(4094)] = 202144,
  [SMALL_STATE(4095)] = 202256,
  [SMALL_STATE(4096)] = 202368,
  [SMALL_STATE(4097)] = 202480,
  [SMALL_STATE(4098)] = 202592,
  [SMALL_STATE(4099)] = 202704,
  [SMALL_STATE(4100)] = 202816,
  [SMALL_STATE(4101)] = 202928,
  [SMALL_STATE(4102)] = 203040,
  [SMALL_STATE(4103)] = 203150,
  [SMALL_STATE(4104)] = 203262,
  [SMALL_STATE(4105)] = 203374,
  [SMALL_STATE(4106)] = 203486,
  [SMALL_STATE(4107)] = 203596,
  [SMALL_STATE(4108)] = 203708,
  [SMALL_STATE(4109)] = 203820,
  [SMALL_STATE(4110)] = 203932,
  [SMALL_STATE(4111)] = 204044,
  [SMALL_STATE(4112)] = 204156,
  [SMALL_STATE(4113)] = 204268,
  [SMALL_STATE(4114)] = 204380,
  [SMALL_STATE(4115)] = 204492,
  [SMALL_STATE(4116)] = 204604,
  [SMALL_STATE(4117)] = 204716,
  [SMALL_STATE(4118)] = 204828,
  [SMALL_STATE(4119)] = 204940,
  [SMALL_STATE(4120)] = 205052,
  [SMALL_STATE(4121)] = 205164,
  [SMALL_STATE(4122)] = 205276,
  [SMALL_STATE(4123)] = 205388,
  [SMALL_STATE(4124)] = 205500,
  [SMALL_STATE(4125)] = 205612,
  [SMALL_STATE(4126)] = 205724,
  [SMALL_STATE(4127)] = 205836,
  [SMALL_STATE(4128)] = 205948,
  [SMALL_STATE(4129)] = 206060,
  [SMALL_STATE(4130)] = 206172,
  [SMALL_STATE(4131)] = 206284,
  [SMALL_STATE(4132)] = 206396,
  [SMALL_STATE(4133)] = 206508,
  [SMALL_STATE(4134)] = 206620,
  [SMALL_STATE(4135)] = 206732,
  [SMALL_STATE(4136)] = 206844,
  [SMALL_STATE(4137)] = 206954,
  [SMALL_STATE(4138)] = 207066,
  [SMALL_STATE(4139)] = 207178,
  [SMALL_STATE(4140)] = 207290,
  [SMALL_STATE(4141)] = 207402,
  [SMALL_STATE(4142)] = 207514,
  [SMALL_STATE(4143)] = 207626,
  [SMALL_STATE(4144)] = 207738,
  [SMALL_STATE(4145)] = 207800,
  [SMALL_STATE(4146)] = 207912,
  [SMALL_STATE(4147)] = 208024,
  [SMALL_STATE(4148)] = 208136,
  [SMALL_STATE(4149)] = 208248,
  [SMALL_STATE(4150)] = 208360,
  [SMALL_STATE(4151)] = 208472,
  [SMALL_STATE(4152)] = 208584,
  [SMALL_STATE(4153)] = 208696,
  [SMALL_STATE(4154)] = 208808,
  [SMALL_STATE(4155)] = 208920,
  [SMALL_STATE(4156)] = 209032,
  [SMALL_STATE(4157)] = 209144,
  [SMALL_STATE(4158)] = 209205,
  [SMALL_STATE(4159)] = 209266,
  [SMALL_STATE(4160)] = 209327,
  [SMALL_STATE(4161)] = 209388,
  [SMALL_STATE(4162)] = 209497,
  [SMALL_STATE(4163)] = 209558,
  [SMALL_STATE(4164)] = 209619,
  [SMALL_STATE(4165)] = 209728,
  [SMALL_STATE(4166)] = 209789,
  [SMALL_STATE(4167)] = 209850,
  [SMALL_STATE(4168)] = 209910,
  [SMALL_STATE(4169)] = 209970,
  [SMALL_STATE(4170)] = 210076,
  [SMALL_STATE(4171)] = 210136,
  [SMALL_STATE(4172)] = 210242,
  [SMALL_STATE(4173)] = 210302,
  [SMALL_STATE(4174)] = 210362,
  [SMALL_STATE(4175)] = 210468,
  [SMALL_STATE(4176)] = 210574,
  [SMALL_STATE(4177)] = 210634,
  [SMALL_STATE(4178)] = 210694,
  [SMALL_STATE(4179)] = 210754,
  [SMALL_STATE(4180)] = 210814,
  [SMALL_STATE(4181)] = 210874,
  [SMALL_STATE(4182)] = 210931,
  [SMALL_STATE(4183)] = 210990,
  [SMALL_STATE(4184)] = 211047,
  [SMALL_STATE(4185)] = 211106,
  [SMALL_STATE(4186)] = 211165,
  [SMALL_STATE(4187)] = 211224,
  [SMALL_STATE(4188)] = 211283,
  [SMALL_STATE(4189)] = 211342,
  [SMALL_STATE(4190)] = 211401,
  [SMALL_STATE(4191)] = 211460,
  [SMALL_STATE(4192)] = 211519,
  [SMALL_STATE(4193)] = 211578,
  [SMALL_STATE(4194)] = 211637,
  [SMALL_STATE(4195)] = 211696,
  [SMALL_STATE(4196)] = 211796,
  [SMALL_STATE(4197)] = 211854,
  [SMALL_STATE(4198)] = 211912,
  [SMALL_STATE(4199)] = 211970,
  [SMALL_STATE(4200)] = 212028,
  [SMALL_STATE(4201)] = 212086,
  [SMALL_STATE(4202)] = 212186,
  [SMALL_STATE(4203)] = 212244,
  [SMALL_STATE(4204)] = 212310,
  [SMALL_STATE(4205)] = 212368,
  [SMALL_STATE(4206)] = 212426,
  [SMALL_STATE(4207)] = 212484,
  [SMALL_STATE(4208)] = 212541,
  [SMALL_STATE(4209)] = 212598,
  [SMALL_STATE(4210)] = 212655,
  [SMALL_STATE(4211)] = 212712,
  [SMALL_STATE(4212)] = 212806,
  [SMALL_STATE(4213)] = 212900,
  [SMALL_STATE(4214)] = 212994,
  [SMALL_STATE(4215)] = 213088,
  [SMALL_STATE(4216)] = 213182,
  [SMALL_STATE(4217)] = 213276,
  [SMALL_STATE(4218)] = 213370,
  [SMALL_STATE(4219)] = 213464,
  [SMALL_STATE(4220)] = 213558,
  [SMALL_STATE(4221)] = 213652,
  [SMALL_STATE(4222)] = 213746,
  [SMALL_STATE(4223)] = 213840,
  [SMALL_STATE(4224)] = 213934,
  [SMALL_STATE(4225)] = 213990,
  [SMALL_STATE(4226)] = 214084,
  [SMALL_STATE(4227)] = 214178,
  [SMALL_STATE(4228)] = 214272,
  [SMALL_STATE(4229)] = 214366,
  [SMALL_STATE(4230)] = 214460,
  [SMALL_STATE(4231)] = 214554,
  [SMALL_STATE(4232)] = 214648,
  [SMALL_STATE(4233)] = 214742,
  [SMALL_STATE(4234)] = 214836,
  [SMALL_STATE(4235)] = 214930,
  [SMALL_STATE(4236)] = 215024,
  [SMALL_STATE(4237)] = 215118,
  [SMALL_STATE(4238)] = 215212,
  [SMALL_STATE(4239)] = 215306,
  [SMALL_STATE(4240)] = 215400,
  [SMALL_STATE(4241)] = 215494,
  [SMALL_STATE(4242)] = 215588,
  [SMALL_STATE(4243)] = 215682,
  [SMALL_STATE(4244)] = 215776,
  [SMALL_STATE(4245)] = 215870,
  [SMALL_STATE(4246)] = 215964,
  [SMALL_STATE(4247)] = 216058,
  [SMALL_STATE(4248)] = 216152,
  [SMALL_STATE(4249)] = 216246,
  [SMALL_STATE(4250)] = 216340,
  [SMALL_STATE(4251)] = 216434,
  [SMALL_STATE(4252)] = 216528,
  [SMALL_STATE(4253)] = 216622,
  [SMALL_STATE(4254)] = 216716,
  [SMALL_STATE(4255)] = 216810,
  [SMALL_STATE(4256)] = 216904,
  [SMALL_STATE(4257)] = 216998,
  [SMALL_STATE(4258)] = 217092,
  [SMALL_STATE(4259)] = 217186,
  [SMALL_STATE(4260)] = 217280,
  [SMALL_STATE(4261)] = 217374,
  [SMALL_STATE(4262)] = 217468,
  [SMALL_STATE(4263)] = 217562,
  [SMALL_STATE(4264)] = 217656,
  [SMALL_STATE(4265)] = 217750,
  [SMALL_STATE(4266)] = 217844,
  [SMALL_STATE(4267)] = 217938,
  [SMALL_STATE(4268)] = 218032,
  [SMALL_STATE(4269)] = 218126,
  [SMALL_STATE(4270)] = 218220,
  [SMALL_STATE(4271)] = 218314,
  [SMALL_STATE(4272)] = 218408,
  [SMALL_STATE(4273)] = 218499,
  [SMALL_STATE(4274)] = 218606,
  [SMALL_STATE(4275)] = 218663,
  [SMALL_STATE(4276)] = 218770,
  [SMALL_STATE(4277)] = 218861,
  [SMALL_STATE(4278)] = 218952,
  [SMALL_STATE(4279)] = 219059,
  [SMALL_STATE(4280)] = 219150,
  [SMALL_STATE(4281)] = 219241,
  [SMALL_STATE(4282)] = 219332,
  [SMALL_STATE(4283)] = 219423,
  [SMALL_STATE(4284)] = 219530,
  [SMALL_STATE(4285)] = 219585,
  [SMALL_STATE(4286)] = 219692,
  [SMALL_STATE(4287)] = 219783,
  [SMALL_STATE(4288)] = 219874,
  [SMALL_STATE(4289)] = 219931,
  [SMALL_STATE(4290)] = 219988,
  [SMALL_STATE(4291)] = 220079,
  [SMALL_STATE(4292)] = 220136,
  [SMALL_STATE(4293)] = 220243,
  [SMALL_STATE(4294)] = 220334,
  [SMALL_STATE(4295)] = 220425,
  [SMALL_STATE(4296)] = 220532,
  [SMALL_STATE(4297)] = 220623,
  [SMALL_STATE(4298)] = 220730,
  [SMALL_STATE(4299)] = 220821,
  [SMALL_STATE(4300)] = 220912,
  [SMALL_STATE(4301)] = 221019,
  [SMALL_STATE(4302)] = 221126,
  [SMALL_STATE(4303)] = 221217,
  [SMALL_STATE(4304)] = 221308,
  [SMALL_STATE(4305)] = 221365,
  [SMALL_STATE(4306)] = 221472,
  [SMALL_STATE(4307)] = 221579,
  [SMALL_STATE(4308)] = 221636,
  [SMALL_STATE(4309)] = 221693,
  [SMALL_STATE(4310)] = 221750,
  [SMALL_STATE(4311)] = 221857,
  [SMALL_STATE(4312)] = 221964,
  [SMALL_STATE(4313)] = 222055,
  [SMALL_STATE(4314)] = 222146,
  [SMALL_STATE(4315)] = 222253,
  [SMALL_STATE(4316)] = 222310,
  [SMALL_STATE(4317)] = 222365,
  [SMALL_STATE(4318)] = 222456,
  [SMALL_STATE(4319)] = 222508,
  [SMALL_STATE(4320)] = 222560,
  [SMALL_STATE(4321)] = 222611,
  [SMALL_STATE(4322)] = 222662,
  [SMALL_STATE(4323)] = 222713,
  [SMALL_STATE(4324)] = 222777,
  [SMALL_STATE(4325)] = 222841,
  [SMALL_STATE(4326)] = 222889,
  [SMALL_STATE(4327)] = 222952,
  [SMALL_STATE(4328)] = 223043,
  [SMALL_STATE(4329)] = 223134,
  [SMALL_STATE(4330)] = 223225,
  [SMALL_STATE(4331)] = 223316,
  [SMALL_STATE(4332)] = 223407,
  [SMALL_STATE(4333)] = 223498,
  [SMALL_STATE(4334)] = 223591,
  [SMALL_STATE(4335)] = 223682,
  [SMALL_STATE(4336)] = 223773,
  [SMALL_STATE(4337)] = 223834,
  [SMALL_STATE(4338)] = 223925,
  [SMALL_STATE(4339)] = 224016,
  [SMALL_STATE(4340)] = 224107,
  [SMALL_STATE(4341)] = 224172,
  [SMALL_STATE(4342)] = 224263,
  [SMALL_STATE(4343)] = 224354,
  [SMALL_STATE(4344)] = 224447,
  [SMALL_STATE(4345)] = 224540,
  [SMALL_STATE(4346)] = 224633,
  [SMALL_STATE(4347)] = 224724,
  [SMALL_STATE(4348)] = 224817,
  [SMALL_STATE(4349)] = 224878,
  [SMALL_STATE(4350)] = 224971,
  [SMALL_STATE(4351)] = 225062,
  [SMALL_STATE(4352)] = 225111,
  [SMALL_STATE(4353)] = 225204,
  [SMALL_STATE(4354)] = 225264,
  [SMALL_STATE(4355)] = 225326,
  [SMALL_STATE(4356)] = 225388,
  [SMALL_STATE(4357)] = 225474,
  [SMALL_STATE(4358)] = 225560,
  [SMALL_STATE(4359)] = 225646,
  [SMALL_STATE(4360)] = 225732,
  [SMALL_STATE(4361)] = 225818,
  [SMALL_STATE(4362)] = 225904,
  [SMALL_STATE(4363)] = 225950,
  [SMALL_STATE(4364)] = 226036,
  [SMALL_STATE(4365)] = 226122,
  [SMALL_STATE(4366)] = 226208,
  [SMALL_STATE(4367)] = 226254,
  [SMALL_STATE(4368)] = 226340,
  [SMALL_STATE(4369)] = 226426,
  [SMALL_STATE(4370)] = 226512,
  [SMALL_STATE(4371)] = 226572,
  [SMALL_STATE(4372)] = 226658,
  [SMALL_STATE(4373)] = 226704,
  [SMALL_STATE(4374)] = 226790,
  [SMALL_STATE(4375)] = 226876,
  [SMALL_STATE(4376)] = 226962,
  [SMALL_STATE(4377)] = 227048,
  [SMALL_STATE(4378)] = 227134,
  [SMALL_STATE(4379)] = 227220,
  [SMALL_STATE(4380)] = 227306,
  [SMALL_STATE(4381)] = 227392,
  [SMALL_STATE(4382)] = 227438,
  [SMALL_STATE(4383)] = 227524,
  [SMALL_STATE(4384)] = 227610,
  [SMALL_STATE(4385)] = 227696,
  [SMALL_STATE(4386)] = 227760,
  [SMALL_STATE(4387)] = 227806,
  [SMALL_STATE(4388)] = 227852,
  [SMALL_STATE(4389)] = 227938,
  [SMALL_STATE(4390)] = 228024,
  [SMALL_STATE(4391)] = 228110,
  [SMALL_STATE(4392)] = 228196,
  [SMALL_STATE(4393)] = 228282,
  [SMALL_STATE(4394)] = 228368,
  [SMALL_STATE(4395)] = 228454,
  [SMALL_STATE(4396)] = 228500,
  [SMALL_STATE(4397)] = 228564,
  [SMALL_STATE(4398)] = 228632,
  [SMALL_STATE(4399)] = 228718,
  [SMALL_STATE(4400)] = 228804,
  [SMALL_STATE(4401)] = 228890,
  [SMALL_STATE(4402)] = 228976,
  [SMALL_STATE(4403)] = 229022,
  [SMALL_STATE(4404)] = 229108,
  [SMALL_STATE(4405)] = 229194,
  [SMALL_STATE(4406)] = 229280,
  [SMALL_STATE(4407)] = 229366,
  [SMALL_STATE(4408)] = 229452,
  [SMALL_STATE(4409)] = 229538,
  [SMALL_STATE(4410)] = 229584,
  [SMALL_STATE(4411)] = 229644,
  [SMALL_STATE(4412)] = 229730,
  [SMALL_STATE(4413)] = 229790,
  [SMALL_STATE(4414)] = 229876,
  [SMALL_STATE(4415)] = 229962,
  [SMALL_STATE(4416)] = 230048,
  [SMALL_STATE(4417)] = 230134,
  [SMALL_STATE(4418)] = 230180,
  [SMALL_STATE(4419)] = 230266,
  [SMALL_STATE(4420)] = 230352,
  [SMALL_STATE(4421)] = 230410,
  [SMALL_STATE(4422)] = 230470,
  [SMALL_STATE(4423)] = 230556,
  [SMALL_STATE(4424)] = 230616,
  [SMALL_STATE(4425)] = 230702,
  [SMALL_STATE(4426)] = 230788,
  [SMALL_STATE(4427)] = 230874,
  [SMALL_STATE(4428)] = 230960,
  [SMALL_STATE(4429)] = 231046,
  [SMALL_STATE(4430)] = 231132,
  [SMALL_STATE(4431)] = 231218,
  [SMALL_STATE(4432)] = 231304,
  [SMALL_STATE(4433)] = 231390,
  [SMALL_STATE(4434)] = 231476,
  [SMALL_STATE(4435)] = 231534,
  [SMALL_STATE(4436)] = 231620,
  [SMALL_STATE(4437)] = 231680,
  [SMALL_STATE(4438)] = 231740,
  [SMALL_STATE(4439)] = 231826,
  [SMALL_STATE(4440)] = 231872,
  [SMALL_STATE(4441)] = 231958,
  [SMALL_STATE(4442)] = 232044,
  [SMALL_STATE(4443)] = 232130,
  [SMALL_STATE(4444)] = 232215,
  [SMALL_STATE(4445)] = 232298,
  [SMALL_STATE(4446)] = 232345,
  [SMALL_STATE(4447)] = 232404,
  [SMALL_STATE(4448)] = 232463,
  [SMALL_STATE(4449)] = 232548,
  [SMALL_STATE(4450)] = 232597,
  [SMALL_STATE(4451)] = 232658,
  [SMALL_STATE(4452)] = 232717,
  [SMALL_STATE(4453)] = 232800,
  [SMALL_STATE(4454)] = 232883,
  [SMALL_STATE(4455)] = 232966,
  [SMALL_STATE(4456)] = 233049,
  [SMALL_STATE(4457)] = 233132,
  [SMALL_STATE(4458)] = 233215,
  [SMALL_STATE(4459)] = 233300,
  [SMALL_STATE(4460)] = 233347,
  [SMALL_STATE(4461)] = 233404,
  [SMALL_STATE(4462)] = 233465,
  [SMALL_STATE(4463)] = 233526,
  [SMALL_STATE(4464)] = 233609,
  [SMALL_STATE(4465)] = 233666,
  [SMALL_STATE(4466)] = 233749,
  [SMALL_STATE(4467)] = 233832,
  [SMALL_STATE(4468)] = 233891,
  [SMALL_STATE(4469)] = 233950,
  [SMALL_STATE(4470)] = 234017,
  [SMALL_STATE(4471)] = 234076,
  [SMALL_STATE(4472)] = 234135,
  [SMALL_STATE(4473)] = 234186,
  [SMALL_STATE(4474)] = 234245,
  [SMALL_STATE(4475)] = 234298,
  [SMALL_STATE(4476)] = 234359,
  [SMALL_STATE(4477)] = 234442,
  [SMALL_STATE(4478)] = 234525,
  [SMALL_STATE(4479)] = 234574,
  [SMALL_STATE(4480)] = 234631,
  [SMALL_STATE(4481)] = 234714,
  [SMALL_STATE(4482)] = 234797,
  [SMALL_STATE(4483)] = 234858,
  [SMALL_STATE(4484)] = 234943,
  [SMALL_STATE(4485)] = 235026,
  [SMALL_STATE(4486)] = 235085,
  [SMALL_STATE(4487)] = 235168,
  [SMALL_STATE(4488)] = 235251,
  [SMALL_STATE(4489)] = 235336,
  [SMALL_STATE(4490)] = 235419,
  [SMALL_STATE(4491)] = 235502,
  [SMALL_STATE(4492)] = 235587,
  [SMALL_STATE(4493)] = 235650,
  [SMALL_STATE(4494)] = 235733,
  [SMALL_STATE(4495)] = 235794,
  [SMALL_STATE(4496)] = 235877,
  [SMALL_STATE(4497)] = 235936,
  [SMALL_STATE(4498)] = 236019,
  [SMALL_STATE(4499)] = 236104,
  [SMALL_STATE(4500)] = 236165,
  [SMALL_STATE(4501)] = 236248,
  [SMALL_STATE(4502)] = 236333,
  [SMALL_STATE(4503)] = 236416,
  [SMALL_STATE(4504)] = 236501,
  [SMALL_STATE(4505)] = 236572,
  [SMALL_STATE(4506)] = 236657,
  [SMALL_STATE(4507)] = 236716,
  [SMALL_STATE(4508)] = 236775,
  [SMALL_STATE(4509)] = 236858,
  [SMALL_STATE(4510)] = 236925,
  [SMALL_STATE(4511)] = 237010,
  [SMALL_STATE(4512)] = 237093,
  [SMALL_STATE(4513)] = 237152,
  [SMALL_STATE(4514)] = 237211,
  [SMALL_STATE(4515)] = 237272,
  [SMALL_STATE(4516)] = 237355,
  [SMALL_STATE(4517)] = 237438,
  [SMALL_STATE(4518)] = 237501,
  [SMALL_STATE(4519)] = 237584,
  [SMALL_STATE(4520)] = 237669,
  [SMALL_STATE(4521)] = 237752,
  [SMALL_STATE(4522)] = 237811,
  [SMALL_STATE(4523)] = 237858,
  [SMALL_STATE(4524)] = 237941,
  [SMALL_STATE(4525)] = 238000,
  [SMALL_STATE(4526)] = 238083,
  [SMALL_STATE(4527)] = 238130,
  [SMALL_STATE(4528)] = 238213,
  [SMALL_STATE(4529)] = 238298,
  [SMALL_STATE(4530)] = 238343,
  [SMALL_STATE(4531)] = 238426,
  [SMALL_STATE(4532)] = 238509,
  [SMALL_STATE(4533)] = 238572,
  [SMALL_STATE(4534)] = 238629,
  [SMALL_STATE(4535)] = 238712,
  [SMALL_STATE(4536)] = 238797,
  [SMALL_STATE(4537)] = 238882,
  [SMALL_STATE(4538)] = 238949,
  [SMALL_STATE(4539)] = 239001,
  [SMALL_STATE(4540)] = 239067,
  [SMALL_STATE(4541)] = 239125,
  [SMALL_STATE(4542)] = 239171,
  [SMALL_STATE(4543)] = 239217,
  [SMALL_STATE(4544)] = 239277,
  [SMALL_STATE(4545)] = 239323,
  [SMALL_STATE(4546)] = 239385,
  [SMALL_STATE(4547)] = 239431,
  [SMALL_STATE(4548)] = 239477,
  [SMALL_STATE(4549)] = 239523,
  [SMALL_STATE(4550)] = 239581,
  [SMALL_STATE(4551)] = 239651,
  [SMALL_STATE(4552)] = 239707,
  [SMALL_STATE(4553)] = 239765,
  [SMALL_STATE(4554)] = 239811,
  [SMALL_STATE(4555)] = 239857,
  [SMALL_STATE(4556)] = 239903,
  [SMALL_STATE(4557)] = 239949,
  [SMALL_STATE(4558)] = 239995,
  [SMALL_STATE(4559)] = 240057,
  [SMALL_STATE(4560)] = 240103,
  [SMALL_STATE(4561)] = 240161,
  [SMALL_STATE(4562)] = 240219,
  [SMALL_STATE(4563)] = 240267,
  [SMALL_STATE(4564)] = 240327,
  [SMALL_STATE(4565)] = 240393,
  [SMALL_STATE(4566)] = 240473,
  [SMALL_STATE(4567)] = 240539,
  [SMALL_STATE(4568)] = 240585,
  [SMALL_STATE(4569)] = 240641,
  [SMALL_STATE(4570)] = 240699,
  [SMALL_STATE(4571)] = 240751,
  [SMALL_STATE(4572)] = 240799,
  [SMALL_STATE(4573)] = 240865,
  [SMALL_STATE(4574)] = 240915,
  [SMALL_STATE(4575)] = 240961,
  [SMALL_STATE(4576)] = 241011,
  [SMALL_STATE(4577)] = 241069,
  [SMALL_STATE(4578)] = 241127,
  [SMALL_STATE(4579)] = 241185,
  [SMALL_STATE(4580)] = 241233,
  [SMALL_STATE(4581)] = 241279,
  [SMALL_STATE(4582)] = 241325,
  [SMALL_STATE(4583)] = 241371,
  [SMALL_STATE(4584)] = 241427,
  [SMALL_STATE(4585)] = 241473,
  [SMALL_STATE(4586)] = 241533,
  [SMALL_STATE(4587)] = 241591,
  [SMALL_STATE(4588)] = 241649,
  [SMALL_STATE(4589)] = 241709,
  [SMALL_STATE(4590)] = 241769,
  [SMALL_STATE(4591)] = 241827,
  [SMALL_STATE(4592)] = 241877,
  [SMALL_STATE(4593)] = 241937,
  [SMALL_STATE(4594)] = 242007,
  [SMALL_STATE(4595)] = 242053,
  [SMALL_STATE(4596)] = 242103,
  [SMALL_STATE(4597)] = 242149,
  [SMALL_STATE(4598)] = 242207,
  [SMALL_STATE(4599)] = 242263,
  [SMALL_STATE(4600)] = 242321,
  [SMALL_STATE(4601)] = 242387,
  [SMALL_STATE(4602)] = 242433,
  [SMALL_STATE(4603)] = 242485,
  [SMALL_STATE(4604)] = 242535,
  [SMALL_STATE(4605)] = 242595,
  [SMALL_STATE(4606)] = 242653,
  [SMALL_STATE(4607)] = 242699,
  [SMALL_STATE(4608)] = 242755,
  [SMALL_STATE(4609)] = 242801,
  [SMALL_STATE(4610)] = 242861,
  [SMALL_STATE(4611)] = 242911,
  [SMALL_STATE(4612)] = 242969,
  [SMALL_STATE(4613)] = 243027,
  [SMALL_STATE(4614)] = 243073,
  [SMALL_STATE(4615)] = 243131,
  [SMALL_STATE(4616)] = 243191,
  [SMALL_STATE(4617)] = 243239,
  [SMALL_STATE(4618)] = 243297,
  [SMALL_STATE(4619)] = 243357,
  [SMALL_STATE(4620)] = 243417,
  [SMALL_STATE(4621)] = 243465,
  [SMALL_STATE(4622)] = 243513,
  [SMALL_STATE(4623)] = 243573,
  [SMALL_STATE(4624)] = 243631,
  [SMALL_STATE(4625)] = 243683,
  [SMALL_STATE(4626)] = 243741,
  [SMALL_STATE(4627)] = 243803,
  [SMALL_STATE(4628)] = 243849,
  [SMALL_STATE(4629)] = 243901,
  [SMALL_STATE(4630)] = 243951,
  [SMALL_STATE(4631)] = 244007,
  [SMALL_STATE(4632)] = 244059,
  [SMALL_STATE(4633)] = 244105,
  [SMALL_STATE(4634)] = 244163,
  [SMALL_STATE(4635)] = 244208,
  [SMALL_STATE(4636)] = 244253,
  [SMALL_STATE(4637)] = 244312,
  [SMALL_STATE(4638)] = 244359,
  [SMALL_STATE(4639)] = 244404,
  [SMALL_STATE(4640)] = 244451,
  [SMALL_STATE(4641)] = 244506,
  [SMALL_STATE(4642)] = 244551,
  [SMALL_STATE(4643)] = 244596,
  [SMALL_STATE(4644)] = 244647,
  [SMALL_STATE(4645)] = 244696,
  [SMALL_STATE(4646)] = 244741,
  [SMALL_STATE(4647)] = 244796,
  [SMALL_STATE(4648)] = 244841,
  [SMALL_STATE(4649)] = 244886,
  [SMALL_STATE(4650)] = 244931,
  [SMALL_STATE(4651)] = 244980,
  [SMALL_STATE(4652)] = 245025,
  [SMALL_STATE(4653)] = 245070,
  [SMALL_STATE(4654)] = 245127,
  [SMALL_STATE(4655)] = 245172,
  [SMALL_STATE(4656)] = 245223,
  [SMALL_STATE(4657)] = 245268,
  [SMALL_STATE(4658)] = 245313,
  [SMALL_STATE(4659)] = 245358,
  [SMALL_STATE(4660)] = 245403,
  [SMALL_STATE(4661)] = 245468,
  [SMALL_STATE(4662)] = 245515,
  [SMALL_STATE(4663)] = 245572,
  [SMALL_STATE(4664)] = 245623,
  [SMALL_STATE(4665)] = 245684,
  [SMALL_STATE(4666)] = 245733,
  [SMALL_STATE(4667)] = 245784,
  [SMALL_STATE(4668)] = 245841,
  [SMALL_STATE(4669)] = 245898,
  [SMALL_STATE(4670)] = 245957,
  [SMALL_STATE(4671)] = 246004,
  [SMALL_STATE(4672)] = 246049,
  [SMALL_STATE(4673)] = 246094,
  [SMALL_STATE(4674)] = 246153,
  [SMALL_STATE(4675)] = 246210,
  [SMALL_STATE(4676)] = 246259,
  [SMALL_STATE(4677)] = 246310,
  [SMALL_STATE(4678)] = 246355,
  [SMALL_STATE(4679)] = 246414,
  [SMALL_STATE(4680)] = 246471,
  [SMALL_STATE(4681)] = 246516,
  [SMALL_STATE(4682)] = 246581,
  [SMALL_STATE(4683)] = 246626,
  [SMALL_STATE(4684)] = 246685,
  [SMALL_STATE(4685)] = 246742,
  [SMALL_STATE(4686)] = 246787,
  [SMALL_STATE(4687)] = 246836,
  [SMALL_STATE(4688)] = 246881,
  [SMALL_STATE(4689)] = 246926,
  [SMALL_STATE(4690)] = 246975,
  [SMALL_STATE(4691)] = 247040,
  [SMALL_STATE(4692)] = 247091,
  [SMALL_STATE(4693)] = 247138,
  [SMALL_STATE(4694)] = 247183,
  [SMALL_STATE(4695)] = 247228,
  [SMALL_STATE(4696)] = 247277,
  [SMALL_STATE(4697)] = 247322,
  [SMALL_STATE(4698)] = 247377,
  [SMALL_STATE(4699)] = 247424,
  [SMALL_STATE(4700)] = 247473,
  [SMALL_STATE(4701)] = 247532,
  [SMALL_STATE(4702)] = 247589,
  [SMALL_STATE(4703)] = 247634,
  [SMALL_STATE(4704)] = 247679,
  [SMALL_STATE(4705)] = 247724,
  [SMALL_STATE(4706)] = 247775,
  [SMALL_STATE(4707)] = 247822,
  [SMALL_STATE(4708)] = 247871,
  [SMALL_STATE(4709)] = 247936,
  [SMALL_STATE(4710)] = 247981,
  [SMALL_STATE(4711)] = 248032,
  [SMALL_STATE(4712)] = 248083,
  [SMALL_STATE(4713)] = 248140,
  [SMALL_STATE(4714)] = 248199,
  [SMALL_STATE(4715)] = 248244,
  [SMALL_STATE(4716)] = 248295,
  [SMALL_STATE(4717)] = 248352,
  [SMALL_STATE(4718)] = 248397,
  [SMALL_STATE(4719)] = 248454,
  [SMALL_STATE(4720)] = 248499,
  [SMALL_STATE(4721)] = 248554,
  [SMALL_STATE(4722)] = 248601,
  [SMALL_STATE(4723)] = 248652,
  [SMALL_STATE(4724)] = 248697,
  [SMALL_STATE(4725)] = 248742,
  [SMALL_STATE(4726)] = 248799,
  [SMALL_STATE(4727)] = 248856,
  [SMALL_STATE(4728)] = 248901,
  [SMALL_STATE(4729)] = 248966,
  [SMALL_STATE(4730)] = 249011,
  [SMALL_STATE(4731)] = 249066,
  [SMALL_STATE(4732)] = 249111,
  [SMALL_STATE(4733)] = 249158,
  [SMALL_STATE(4734)] = 249213,
  [SMALL_STATE(4735)] = 249258,
  [SMALL_STATE(4736)] = 249315,
  [SMALL_STATE(4737)] = 249370,
  [SMALL_STATE(4738)] = 249427,
  [SMALL_STATE(4739)] = 249484,
  [SMALL_STATE(4740)] = 249529,
  [SMALL_STATE(4741)] = 249574,
  [SMALL_STATE(4742)] = 249635,
  [SMALL_STATE(4743)] = 249680,
  [SMALL_STATE(4744)] = 249727,
  [SMALL_STATE(4745)] = 249782,
  [SMALL_STATE(4746)] = 249827,
  [SMALL_STATE(4747)] = 249884,
  [SMALL_STATE(4748)] = 249929,
  [SMALL_STATE(4749)] = 249986,
  [SMALL_STATE(4750)] = 250043,
  [SMALL_STATE(4751)] = 250098,
  [SMALL_STATE(4752)] = 250143,
  [SMALL_STATE(4753)] = 250190,
  [SMALL_STATE(4754)] = 250237,
  [SMALL_STATE(4755)] = 250284,
  [SMALL_STATE(4756)] = 250329,
  [SMALL_STATE(4757)] = 250374,
  [SMALL_STATE(4758)] = 250419,
  [SMALL_STATE(4759)] = 250478,
  [SMALL_STATE(4760)] = 250535,
  [SMALL_STATE(4761)] = 250596,
  [SMALL_STATE(4762)] = 250661,
  [SMALL_STATE(4763)] = 250710,
  [SMALL_STATE(4764)] = 250769,
  [SMALL_STATE(4765)] = 250814,
  [SMALL_STATE(4766)] = 250863,
  [SMALL_STATE(4767)] = 250908,
  [SMALL_STATE(4768)] = 250967,
  [SMALL_STATE(4769)] = 251012,
  [SMALL_STATE(4770)] = 251057,
  [SMALL_STATE(4771)] = 251102,
  [SMALL_STATE(4772)] = 251147,
  [SMALL_STATE(4773)] = 251208,
  [SMALL_STATE(4774)] = 251253,
  [SMALL_STATE(4775)] = 251310,
  [SMALL_STATE(4776)] = 251355,
  [SMALL_STATE(4777)] = 251424,
  [SMALL_STATE(4778)] = 251469,
  [SMALL_STATE(4779)] = 251514,
  [SMALL_STATE(4780)] = 251583,
  [SMALL_STATE(4781)] = 251642,
  [SMALL_STATE(4782)] = 251687,
  [SMALL_STATE(4783)] = 251736,
  [SMALL_STATE(4784)] = 251781,
  [SMALL_STATE(4785)] = 251826,
  [SMALL_STATE(4786)] = 251871,
  [SMALL_STATE(4787)] = 251920,
  [SMALL_STATE(4788)] = 251979,
  [SMALL_STATE(4789)] = 252024,
  [SMALL_STATE(4790)] = 252069,
  [SMALL_STATE(4791)] = 252114,
  [SMALL_STATE(4792)] = 252171,
  [SMALL_STATE(4793)] = 252216,
  [SMALL_STATE(4794)] = 252261,
  [SMALL_STATE(4795)] = 252318,
  [SMALL_STATE(4796)] = 252377,
  [SMALL_STATE(4797)] = 252434,
  [SMALL_STATE(4798)] = 252479,
  [SMALL_STATE(4799)] = 252532,
  [SMALL_STATE(4800)] = 252577,
  [SMALL_STATE(4801)] = 252622,
  [SMALL_STATE(4802)] = 252681,
  [SMALL_STATE(4803)] = 252726,
  [SMALL_STATE(4804)] = 252771,
  [SMALL_STATE(4805)] = 252840,
  [SMALL_STATE(4806)] = 252897,
  [SMALL_STATE(4807)] = 252956,
  [SMALL_STATE(4808)] = 253001,
  [SMALL_STATE(4809)] = 253052,
  [SMALL_STATE(4810)] = 253097,
  [SMALL_STATE(4811)] = 253142,
  [SMALL_STATE(4812)] = 253191,
  [SMALL_STATE(4813)] = 253236,
  [SMALL_STATE(4814)] = 253293,
  [SMALL_STATE(4815)] = 253338,
  [SMALL_STATE(4816)] = 253382,
  [SMALL_STATE(4817)] = 253436,
  [SMALL_STATE(4818)] = 253494,
  [SMALL_STATE(4819)] = 253550,
  [SMALL_STATE(4820)] = 253606,
  [SMALL_STATE(4821)] = 253652,
  [SMALL_STATE(4822)] = 253696,
  [SMALL_STATE(4823)] = 253746,
  [SMALL_STATE(4824)] = 253790,
  [SMALL_STATE(4825)] = 253834,
  [SMALL_STATE(4826)] = 253878,
  [SMALL_STATE(4827)] = 253922,
  [SMALL_STATE(4828)] = 253968,
  [SMALL_STATE(4829)] = 254016,
  [SMALL_STATE(4830)] = 254060,
  [SMALL_STATE(4831)] = 254116,
  [SMALL_STATE(4832)] = 254174,
  [SMALL_STATE(4833)] = 254218,
  [SMALL_STATE(4834)] = 254282,
  [SMALL_STATE(4835)] = 254326,
  [SMALL_STATE(4836)] = 254386,
  [SMALL_STATE(4837)] = 254430,
  [SMALL_STATE(4838)] = 254474,
  [SMALL_STATE(4839)] = 254522,
  [SMALL_STATE(4840)] = 254580,
  [SMALL_STATE(4841)] = 254624,
  [SMALL_STATE(4842)] = 254668,
  [SMALL_STATE(4843)] = 254712,
  [SMALL_STATE(4844)] = 254758,
  [SMALL_STATE(4845)] = 254822,
  [SMALL_STATE(4846)] = 254870,
  [SMALL_STATE(4847)] = 254926,
  [SMALL_STATE(4848)] = 254984,
  [SMALL_STATE(4849)] = 255028,
  [SMALL_STATE(4850)] = 255076,
  [SMALL_STATE(4851)] = 255120,
  [SMALL_STATE(4852)] = 255164,
  [SMALL_STATE(4853)] = 255208,
  [SMALL_STATE(4854)] = 255260,
  [SMALL_STATE(4855)] = 255310,
  [SMALL_STATE(4856)] = 255358,
  [SMALL_STATE(4857)] = 255402,
  [SMALL_STATE(4858)] = 255446,
  [SMALL_STATE(4859)] = 255492,
  [SMALL_STATE(4860)] = 255536,
  [SMALL_STATE(4861)] = 255580,
  [SMALL_STATE(4862)] = 255624,
  [SMALL_STATE(4863)] = 255668,
  [SMALL_STATE(4864)] = 255712,
  [SMALL_STATE(4865)] = 255756,
  [SMALL_STATE(4866)] = 255800,
  [SMALL_STATE(4867)] = 255848,
  [SMALL_STATE(4868)] = 255904,
  [SMALL_STATE(4869)] = 255948,
  [SMALL_STATE(4870)] = 255992,
  [SMALL_STATE(4871)] = 256036,
  [SMALL_STATE(4872)] = 256092,
  [SMALL_STATE(4873)] = 256136,
  [SMALL_STATE(4874)] = 256186,
  [SMALL_STATE(4875)] = 256230,
  [SMALL_STATE(4876)] = 256274,
  [SMALL_STATE(4877)] = 256318,
  [SMALL_STATE(4878)] = 256362,
  [SMALL_STATE(4879)] = 256406,
  [SMALL_STATE(4880)] = 256452,
  [SMALL_STATE(4881)] = 256498,
  [SMALL_STATE(4882)] = 256542,
  [SMALL_STATE(4883)] = 256586,
  [SMALL_STATE(4884)] = 256644,
  [SMALL_STATE(4885)] = 256688,
  [SMALL_STATE(4886)] = 256732,
  [SMALL_STATE(4887)] = 256788,
  [SMALL_STATE(4888)] = 256832,
  [SMALL_STATE(4889)] = 256876,
  [SMALL_STATE(4890)] = 256924,
  [SMALL_STATE(4891)] = 256968,
  [SMALL_STATE(4892)] = 257012,
  [SMALL_STATE(4893)] = 257056,
  [SMALL_STATE(4894)] = 257110,
  [SMALL_STATE(4895)] = 257158,
  [SMALL_STATE(4896)] = 257202,
  [SMALL_STATE(4897)] = 257252,
  [SMALL_STATE(4898)] = 257296,
  [SMALL_STATE(4899)] = 257354,
  [SMALL_STATE(4900)] = 257398,
  [SMALL_STATE(4901)] = 257442,
  [SMALL_STATE(4902)] = 257498,
  [SMALL_STATE(4903)] = 257566,
  [SMALL_STATE(4904)] = 257610,
  [SMALL_STATE(4905)] = 257658,
  [SMALL_STATE(4906)] = 257706,
  [SMALL_STATE(4907)] = 257752,
  [SMALL_STATE(4908)] = 257806,
  [SMALL_STATE(4909)] = 257856,
  [SMALL_STATE(4910)] = 257900,
  [SMALL_STATE(4911)] = 257944,
  [SMALL_STATE(4912)] = 258008,
  [SMALL_STATE(4913)] = 258052,
  [SMALL_STATE(4914)] = 258112,
  [SMALL_STATE(4915)] = 258158,
  [SMALL_STATE(4916)] = 258212,
  [SMALL_STATE(4917)] = 258256,
  [SMALL_STATE(4918)] = 258312,
  [SMALL_STATE(4919)] = 258356,
  [SMALL_STATE(4920)] = 258410,
  [SMALL_STATE(4921)] = 258466,
  [SMALL_STATE(4922)] = 258520,
  [SMALL_STATE(4923)] = 258564,
  [SMALL_STATE(4924)] = 258616,
  [SMALL_STATE(4925)] = 258660,
  [SMALL_STATE(4926)] = 258704,
  [SMALL_STATE(4927)] = 258750,
  [SMALL_STATE(4928)] = 258818,
  [SMALL_STATE(4929)] = 258886,
  [SMALL_STATE(4930)] = 258930,
  [SMALL_STATE(4931)] = 258974,
  [SMALL_STATE(4932)] = 259018,
  [SMALL_STATE(4933)] = 259062,
  [SMALL_STATE(4934)] = 259106,
  [SMALL_STATE(4935)] = 259156,
  [SMALL_STATE(4936)] = 259204,
  [SMALL_STATE(4937)] = 259248,
  [SMALL_STATE(4938)] = 259304,
  [SMALL_STATE(4939)] = 259368,
  [SMALL_STATE(4940)] = 259412,
  [SMALL_STATE(4941)] = 259468,
  [SMALL_STATE(4942)] = 259512,
  [SMALL_STATE(4943)] = 259570,
  [SMALL_STATE(4944)] = 259616,
  [SMALL_STATE(4945)] = 259660,
  [SMALL_STATE(4946)] = 259704,
  [SMALL_STATE(4947)] = 259748,
  [SMALL_STATE(4948)] = 259792,
  [SMALL_STATE(4949)] = 259836,
  [SMALL_STATE(4950)] = 259880,
  [SMALL_STATE(4951)] = 259924,
  [SMALL_STATE(4952)] = 259978,
  [SMALL_STATE(4953)] = 260022,
  [SMALL_STATE(4954)] = 260066,
  [SMALL_STATE(4955)] = 260130,
  [SMALL_STATE(4956)] = 260188,
  [SMALL_STATE(4957)] = 260232,
  [SMALL_STATE(4958)] = 260276,
  [SMALL_STATE(4959)] = 260320,
  [SMALL_STATE(4960)] = 260370,
  [SMALL_STATE(4961)] = 260414,
  [SMALL_STATE(4962)] = 260468,
  [SMALL_STATE(4963)] = 260526,
  [SMALL_STATE(4964)] = 260574,
  [SMALL_STATE(4965)] = 260618,
  [SMALL_STATE(4966)] = 260674,
  [SMALL_STATE(4967)] = 260718,
  [SMALL_STATE(4968)] = 260776,
  [SMALL_STATE(4969)] = 260826,
  [SMALL_STATE(4970)] = 260870,
  [SMALL_STATE(4971)] = 260928,
  [SMALL_STATE(4972)] = 260982,
  [SMALL_STATE(4973)] = 261040,
  [SMALL_STATE(4974)] = 261090,
  [SMALL_STATE(4975)] = 261134,
  [SMALL_STATE(4976)] = 261190,
  [SMALL_STATE(4977)] = 261234,
  [SMALL_STATE(4978)] = 261280,
  [SMALL_STATE(4979)] = 261326,
  [SMALL_STATE(4980)] = 261374,
  [SMALL_STATE(4981)] = 261418,
  [SMALL_STATE(4982)] = 261464,
  [SMALL_STATE(4983)] = 261510,
  [SMALL_STATE(4984)] = 261554,
  [SMALL_STATE(4985)] = 261600,
  [SMALL_STATE(4986)] = 261656,
  [SMALL_STATE(4987)] = 261706,
  [SMALL_STATE(4988)] = 261766,
  [SMALL_STATE(4989)] = 261834,
  [SMALL_STATE(4990)] = 261878,
  [SMALL_STATE(4991)] = 261922,
  [SMALL_STATE(4992)] = 261978,
  [SMALL_STATE(4993)] = 262032,
  [SMALL_STATE(4994)] = 262080,
  [SMALL_STATE(4995)] = 262136,
  [SMALL_STATE(4996)] = 262180,
  [SMALL_STATE(4997)] = 262224,
  [SMALL_STATE(4998)] = 262268,
  [SMALL_STATE(4999)] = 262312,
  [SMALL_STATE(5000)] = 262366,
  [SMALL_STATE(5001)] = 262410,
  [SMALL_STATE(5002)] = 262454,
  [SMALL_STATE(5003)] = 262498,
  [SMALL_STATE(5004)] = 262544,
  [SMALL_STATE(5005)] = 262588,
  [SMALL_STATE(5006)] = 262648,
  [SMALL_STATE(5007)] = 262696,
  [SMALL_STATE(5008)] = 262740,
  [SMALL_STATE(5009)] = 262784,
  [SMALL_STATE(5010)] = 262834,
  [SMALL_STATE(5011)] = 262878,
  [SMALL_STATE(5012)] = 262924,
  [SMALL_STATE(5013)] = 262980,
  [SMALL_STATE(5014)] = 263024,
  [SMALL_STATE(5015)] = 263068,
  [SMALL_STATE(5016)] = 263112,
  [SMALL_STATE(5017)] = 263168,
  [SMALL_STATE(5018)] = 263216,
  [SMALL_STATE(5019)] = 263260,
  [SMALL_STATE(5020)] = 263304,
  [SMALL_STATE(5021)] = 263354,
  [SMALL_STATE(5022)] = 263398,
  [SMALL_STATE(5023)] = 263456,
  [SMALL_STATE(5024)] = 263520,
  [SMALL_STATE(5025)] = 263584,
  [SMALL_STATE(5026)] = 263640,
  [SMALL_STATE(5027)] = 263684,
  [SMALL_STATE(5028)] = 263730,
  [SMALL_STATE(5029)] = 263774,
  [SMALL_STATE(5030)] = 263818,
  [SMALL_STATE(5031)] = 263862,
  [SMALL_STATE(5032)] = 263906,
  [SMALL_STATE(5033)] = 263950,
  [SMALL_STATE(5034)] = 264008,
  [SMALL_STATE(5035)] = 264062,
  [SMALL_STATE(5036)] = 264120,
  [SMALL_STATE(5037)] = 264168,
  [SMALL_STATE(5038)] = 264224,
  [SMALL_STATE(5039)] = 264268,
  [SMALL_STATE(5040)] = 264312,
  [SMALL_STATE(5041)] = 264356,
  [SMALL_STATE(5042)] = 264400,
  [SMALL_STATE(5043)] = 264458,
  [SMALL_STATE(5044)] = 264512,
  [SMALL_STATE(5045)] = 264568,
  [SMALL_STATE(5046)] = 264614,
  [SMALL_STATE(5047)] = 264658,
  [SMALL_STATE(5048)] = 264712,
  [SMALL_STATE(5049)] = 264768,
  [SMALL_STATE(5050)] = 264812,
  [SMALL_STATE(5051)] = 264856,
  [SMALL_STATE(5052)] = 264912,
  [SMALL_STATE(5053)] = 264962,
  [SMALL_STATE(5054)] = 265018,
  [SMALL_STATE(5055)] = 265068,
  [SMALL_STATE(5056)] = 265112,
  [SMALL_STATE(5057)] = 265156,
  [SMALL_STATE(5058)] = 265212,
  [SMALL_STATE(5059)] = 265256,
  [SMALL_STATE(5060)] = 265300,
  [SMALL_STATE(5061)] = 265348,
  [SMALL_STATE(5062)] = 265404,
  [SMALL_STATE(5063)] = 265450,
  [SMALL_STATE(5064)] = 265494,
  [SMALL_STATE(5065)] = 265538,
  [SMALL_STATE(5066)] = 265588,
  [SMALL_STATE(5067)] = 265632,
  [SMALL_STATE(5068)] = 265678,
  [SMALL_STATE(5069)] = 265724,
  [SMALL_STATE(5070)] = 265780,
  [SMALL_STATE(5071)] = 265824,
  [SMALL_STATE(5072)] = 265880,
  [SMALL_STATE(5073)] = 265924,
  [SMALL_STATE(5074)] = 265978,
  [SMALL_STATE(5075)] = 266034,
  [SMALL_STATE(5076)] = 266078,
  [SMALL_STATE(5077)] = 266122,
  [SMALL_STATE(5078)] = 266166,
  [SMALL_STATE(5079)] = 266210,
  [SMALL_STATE(5080)] = 266254,
  [SMALL_STATE(5081)] = 266298,
  [SMALL_STATE(5082)] = 266346,
  [SMALL_STATE(5083)] = 266390,
  [SMALL_STATE(5084)] = 266438,
  [SMALL_STATE(5085)] = 266482,
  [SMALL_STATE(5086)] = 266538,
  [SMALL_STATE(5087)] = 266588,
  [SMALL_STATE(5088)] = 266632,
  [SMALL_STATE(5089)] = 266676,
  [SMALL_STATE(5090)] = 266730,
  [SMALL_STATE(5091)] = 266786,
  [SMALL_STATE(5092)] = 266836,
  [SMALL_STATE(5093)] = 266894,
  [SMALL_STATE(5094)] = 266950,
  [SMALL_STATE(5095)] = 266994,
  [SMALL_STATE(5096)] = 267051,
  [SMALL_STATE(5097)] = 267096,
  [SMALL_STATE(5098)] = 267143,
  [SMALL_STATE(5099)] = 267188,
  [SMALL_STATE(5100)] = 267243,
  [SMALL_STATE(5101)] = 267288,
  [SMALL_STATE(5102)] = 267339,
  [SMALL_STATE(5103)] = 267384,
  [SMALL_STATE(5104)] = 267451,
  [SMALL_STATE(5105)] = 267510,
  [SMALL_STATE(5106)] = 267553,
  [SMALL_STATE(5107)] = 267606,
  [SMALL_STATE(5108)] = 267649,
  [SMALL_STATE(5109)] = 267704,
  [SMALL_STATE(5110)] = 267759,
  [SMALL_STATE(5111)] = 267812,
  [SMALL_STATE(5112)] = 267859,
  [SMALL_STATE(5113)] = 267912,
  [SMALL_STATE(5114)] = 267967,
  [SMALL_STATE(5115)] = 268010,
  [SMALL_STATE(5116)] = 268053,
  [SMALL_STATE(5117)] = 268096,
  [SMALL_STATE(5118)] = 268139,
  [SMALL_STATE(5119)] = 268206,
  [SMALL_STATE(5120)] = 268249,
  [SMALL_STATE(5121)] = 268292,
  [SMALL_STATE(5122)] = 268349,
  [SMALL_STATE(5123)] = 268392,
  [SMALL_STATE(5124)] = 268435,
  [SMALL_STATE(5125)] = 268478,
  [SMALL_STATE(5126)] = 268523,
  [SMALL_STATE(5127)] = 268566,
  [SMALL_STATE(5128)] = 268619,
  [SMALL_STATE(5129)] = 268662,
  [SMALL_STATE(5130)] = 268729,
  [SMALL_STATE(5131)] = 268786,
  [SMALL_STATE(5132)] = 268829,
  [SMALL_STATE(5133)] = 268872,
  [SMALL_STATE(5134)] = 268939,
  [SMALL_STATE(5135)] = 268982,
  [SMALL_STATE(5136)] = 269035,
  [SMALL_STATE(5137)] = 269088,
  [SMALL_STATE(5138)] = 269135,
  [SMALL_STATE(5139)] = 269202,
  [SMALL_STATE(5140)] = 269245,
  [SMALL_STATE(5141)] = 269298,
  [SMALL_STATE(5142)] = 269341,
  [SMALL_STATE(5143)] = 269384,
  [SMALL_STATE(5144)] = 269429,
  [SMALL_STATE(5145)] = 269496,
  [SMALL_STATE(5146)] = 269539,
  [SMALL_STATE(5147)] = 269584,
  [SMALL_STATE(5148)] = 269627,
  [SMALL_STATE(5149)] = 269680,
  [SMALL_STATE(5150)] = 269747,
  [SMALL_STATE(5151)] = 269800,
  [SMALL_STATE(5152)] = 269843,
  [SMALL_STATE(5153)] = 269900,
  [SMALL_STATE(5154)] = 269943,
  [SMALL_STATE(5155)] = 269992,
  [SMALL_STATE(5156)] = 270035,
  [SMALL_STATE(5157)] = 270082,
  [SMALL_STATE(5158)] = 270127,
  [SMALL_STATE(5159)] = 270178,
  [SMALL_STATE(5160)] = 270221,
  [SMALL_STATE(5161)] = 270266,
  [SMALL_STATE(5162)] = 270329,
  [SMALL_STATE(5163)] = 270386,
  [SMALL_STATE(5164)] = 270429,
  [SMALL_STATE(5165)] = 270472,
  [SMALL_STATE(5166)] = 270515,
  [SMALL_STATE(5167)] = 270572,
  [SMALL_STATE(5168)] = 270615,
  [SMALL_STATE(5169)] = 270658,
  [SMALL_STATE(5170)] = 270711,
  [SMALL_STATE(5171)] = 270754,
  [SMALL_STATE(5172)] = 270809,
  [SMALL_STATE(5173)] = 270852,
  [SMALL_STATE(5174)] = 270895,
  [SMALL_STATE(5175)] = 270938,
  [SMALL_STATE(5176)] = 270981,
  [SMALL_STATE(5177)] = 271024,
  [SMALL_STATE(5178)] = 271077,
  [SMALL_STATE(5179)] = 271136,
  [SMALL_STATE(5180)] = 271189,
  [SMALL_STATE(5181)] = 271234,
  [SMALL_STATE(5182)] = 271287,
  [SMALL_STATE(5183)] = 271330,
  [SMALL_STATE(5184)] = 271373,
  [SMALL_STATE(5185)] = 271416,
  [SMALL_STATE(5186)] = 271459,
  [SMALL_STATE(5187)] = 271516,
  [SMALL_STATE(5188)] = 271559,
  [SMALL_STATE(5189)] = 271602,
  [SMALL_STATE(5190)] = 271655,
  [SMALL_STATE(5191)] = 271698,
  [SMALL_STATE(5192)] = 271753,
  [SMALL_STATE(5193)] = 271796,
  [SMALL_STATE(5194)] = 271853,
  [SMALL_STATE(5195)] = 271896,
  [SMALL_STATE(5196)] = 271939,
  [SMALL_STATE(5197)] = 271988,
  [SMALL_STATE(5198)] = 272031,
  [SMALL_STATE(5199)] = 272094,
  [SMALL_STATE(5200)] = 272143,
  [SMALL_STATE(5201)] = 272186,
  [SMALL_STATE(5202)] = 272229,
  [SMALL_STATE(5203)] = 272272,
  [SMALL_STATE(5204)] = 272321,
  [SMALL_STATE(5205)] = 272388,
  [SMALL_STATE(5206)] = 272441,
  [SMALL_STATE(5207)] = 272498,
  [SMALL_STATE(5208)] = 272551,
  [SMALL_STATE(5209)] = 272594,
  [SMALL_STATE(5210)] = 272637,
  [SMALL_STATE(5211)] = 272692,
  [SMALL_STATE(5212)] = 272735,
  [SMALL_STATE(5213)] = 272778,
  [SMALL_STATE(5214)] = 272823,
  [SMALL_STATE(5215)] = 272878,
  [SMALL_STATE(5216)] = 272921,
  [SMALL_STATE(5217)] = 272978,
  [SMALL_STATE(5218)] = 273021,
  [SMALL_STATE(5219)] = 273064,
  [SMALL_STATE(5220)] = 273107,
  [SMALL_STATE(5221)] = 273170,
  [SMALL_STATE(5222)] = 273225,
  [SMALL_STATE(5223)] = 273268,
  [SMALL_STATE(5224)] = 273323,
  [SMALL_STATE(5225)] = 273376,
  [SMALL_STATE(5226)] = 273433,
  [SMALL_STATE(5227)] = 273500,
  [SMALL_STATE(5228)] = 273543,
  [SMALL_STATE(5229)] = 273588,
  [SMALL_STATE(5230)] = 273651,
  [SMALL_STATE(5231)] = 273694,
  [SMALL_STATE(5232)] = 273739,
  [SMALL_STATE(5233)] = 273794,
  [SMALL_STATE(5234)] = 273837,
  [SMALL_STATE(5235)] = 273880,
  [SMALL_STATE(5236)] = 273923,
  [SMALL_STATE(5237)] = 273990,
  [SMALL_STATE(5238)] = 274033,
  [SMALL_STATE(5239)] = 274088,
  [SMALL_STATE(5240)] = 274131,
  [SMALL_STATE(5241)] = 274174,
  [SMALL_STATE(5242)] = 274217,
  [SMALL_STATE(5243)] = 274262,
  [SMALL_STATE(5244)] = 274309,
  [SMALL_STATE(5245)] = 274352,
  [SMALL_STATE(5246)] = 274405,
  [SMALL_STATE(5247)] = 274448,
  [SMALL_STATE(5248)] = 274491,
  [SMALL_STATE(5249)] = 274534,
  [SMALL_STATE(5250)] = 274589,
  [SMALL_STATE(5251)] = 274632,
  [SMALL_STATE(5252)] = 274675,
  [SMALL_STATE(5253)] = 274718,
  [SMALL_STATE(5254)] = 274781,
  [SMALL_STATE(5255)] = 274838,
  [SMALL_STATE(5256)] = 274885,
  [SMALL_STATE(5257)] = 274930,
  [SMALL_STATE(5258)] = 274977,
  [SMALL_STATE(5259)] = 275026,
  [SMALL_STATE(5260)] = 275069,
  [SMALL_STATE(5261)] = 275132,
  [SMALL_STATE(5262)] = 275179,
  [SMALL_STATE(5263)] = 275222,
  [SMALL_STATE(5264)] = 275265,
  [SMALL_STATE(5265)] = 275308,
  [SMALL_STATE(5266)] = 275357,
  [SMALL_STATE(5267)] = 275412,
  [SMALL_STATE(5268)] = 275455,
  [SMALL_STATE(5269)] = 275510,
  [SMALL_STATE(5270)] = 275557,
  [SMALL_STATE(5271)] = 275600,
  [SMALL_STATE(5272)] = 275643,
  [SMALL_STATE(5273)] = 275686,
  [SMALL_STATE(5274)] = 275729,
  [SMALL_STATE(5275)] = 275772,
  [SMALL_STATE(5276)] = 275815,
  [SMALL_STATE(5277)] = 275858,
  [SMALL_STATE(5278)] = 275901,
  [SMALL_STATE(5279)] = 275944,
  [SMALL_STATE(5280)] = 275987,
  [SMALL_STATE(5281)] = 276030,
  [SMALL_STATE(5282)] = 276075,
  [SMALL_STATE(5283)] = 276118,
  [SMALL_STATE(5284)] = 276161,
  [SMALL_STATE(5285)] = 276204,
  [SMALL_STATE(5286)] = 276247,
  [SMALL_STATE(5287)] = 276290,
  [SMALL_STATE(5288)] = 276333,
  [SMALL_STATE(5289)] = 276376,
  [SMALL_STATE(5290)] = 276419,
  [SMALL_STATE(5291)] = 276462,
  [SMALL_STATE(5292)] = 276505,
  [SMALL_STATE(5293)] = 276550,
  [SMALL_STATE(5294)] = 276593,
  [SMALL_STATE(5295)] = 276636,
  [SMALL_STATE(5296)] = 276679,
  [SMALL_STATE(5297)] = 276734,
  [SMALL_STATE(5298)] = 276787,
  [SMALL_STATE(5299)] = 276830,
  [SMALL_STATE(5300)] = 276873,
  [SMALL_STATE(5301)] = 276930,
  [SMALL_STATE(5302)] = 276975,
  [SMALL_STATE(5303)] = 277018,
  [SMALL_STATE(5304)] = 277061,
  [SMALL_STATE(5305)] = 277104,
  [SMALL_STATE(5306)] = 277147,
  [SMALL_STATE(5307)] = 277192,
  [SMALL_STATE(5308)] = 277237,
  [SMALL_STATE(5309)] = 277284,
  [SMALL_STATE(5310)] = 277327,
  [SMALL_STATE(5311)] = 277390,
  [SMALL_STATE(5312)] = 277445,
  [SMALL_STATE(5313)] = 277488,
  [SMALL_STATE(5314)] = 277535,
  [SMALL_STATE(5315)] = 277584,
  [SMALL_STATE(5316)] = 277627,
  [SMALL_STATE(5317)] = 277670,
  [SMALL_STATE(5318)] = 277713,
  [SMALL_STATE(5319)] = 277756,
  [SMALL_STATE(5320)] = 277811,
  [SMALL_STATE(5321)] = 277856,
  [SMALL_STATE(5322)] = 277899,
  [SMALL_STATE(5323)] = 277942,
  [SMALL_STATE(5324)] = 277987,
  [SMALL_STATE(5325)] = 278030,
  [SMALL_STATE(5326)] = 278077,
  [SMALL_STATE(5327)] = 278130,
  [SMALL_STATE(5328)] = 278173,
  [SMALL_STATE(5329)] = 278216,
  [SMALL_STATE(5330)] = 278259,
  [SMALL_STATE(5331)] = 278302,
  [SMALL_STATE(5332)] = 278351,
  [SMALL_STATE(5333)] = 278396,
  [SMALL_STATE(5334)] = 278439,
  [SMALL_STATE(5335)] = 278488,
  [SMALL_STATE(5336)] = 278535,
  [SMALL_STATE(5337)] = 278580,
  [SMALL_STATE(5338)] = 278635,
  [SMALL_STATE(5339)] = 278688,
  [SMALL_STATE(5340)] = 278731,
  [SMALL_STATE(5341)] = 278774,
  [SMALL_STATE(5342)] = 278817,
  [SMALL_STATE(5343)] = 278866,
  [SMALL_STATE(5344)] = 278923,
  [SMALL_STATE(5345)] = 278966,
  [SMALL_STATE(5346)] = 279021,
  [SMALL_STATE(5347)] = 279064,
  [SMALL_STATE(5348)] = 279107,
  [SMALL_STATE(5349)] = 279150,
  [SMALL_STATE(5350)] = 279193,
  [SMALL_STATE(5351)] = 279250,
  [SMALL_STATE(5352)] = 279293,
  [SMALL_STATE(5353)] = 279336,
  [SMALL_STATE(5354)] = 279383,
  [SMALL_STATE(5355)] = 279426,
  [SMALL_STATE(5356)] = 279473,
  [SMALL_STATE(5357)] = 279536,
  [SMALL_STATE(5358)] = 279579,
  [SMALL_STATE(5359)] = 279622,
  [SMALL_STATE(5360)] = 279665,
  [SMALL_STATE(5361)] = 279708,
  [SMALL_STATE(5362)] = 279751,
  [SMALL_STATE(5363)] = 279798,
  [SMALL_STATE(5364)] = 279841,
  [SMALL_STATE(5365)] = 279896,
  [SMALL_STATE(5366)] = 279939,
  [SMALL_STATE(5367)] = 279982,
  [SMALL_STATE(5368)] = 280025,
  [SMALL_STATE(5369)] = 280078,
  [SMALL_STATE(5370)] = 280127,
  [SMALL_STATE(5371)] = 280176,
  [SMALL_STATE(5372)] = 280223,
  [SMALL_STATE(5373)] = 280278,
  [SMALL_STATE(5374)] = 280327,
  [SMALL_STATE(5375)] = 280382,
  [SMALL_STATE(5376)] = 280425,
  [SMALL_STATE(5377)] = 280474,
  [SMALL_STATE(5378)] = 280527,
  [SMALL_STATE(5379)] = 280582,
  [SMALL_STATE(5380)] = 280637,
  [SMALL_STATE(5381)] = 280694,
  [SMALL_STATE(5382)] = 280741,
  [SMALL_STATE(5383)] = 280790,
  [SMALL_STATE(5384)] = 280833,
  [SMALL_STATE(5385)] = 280880,
  [SMALL_STATE(5386)] = 280923,
  [SMALL_STATE(5387)] = 280970,
  [SMALL_STATE(5388)] = 281015,
  [SMALL_STATE(5389)] = 281058,
  [SMALL_STATE(5390)] = 281103,
  [SMALL_STATE(5391)] = 281162,
  [SMALL_STATE(5392)] = 281205,
  [SMALL_STATE(5393)] = 281274,
  [SMALL_STATE(5394)] = 281317,
  [SMALL_STATE(5395)] = 281360,
  [SMALL_STATE(5396)] = 281405,
  [SMALL_STATE(5397)] = 281448,
  [SMALL_STATE(5398)] = 281493,
  [SMALL_STATE(5399)] = 281536,
  [SMALL_STATE(5400)] = 281579,
  [SMALL_STATE(5401)] = 281622,
  [SMALL_STATE(5402)] = 281667,
  [SMALL_STATE(5403)] = 281734,
  [SMALL_STATE(5404)] = 281789,
  [SMALL_STATE(5405)] = 281832,
  [SMALL_STATE(5406)] = 281875,
  [SMALL_STATE(5407)] = 281924,
  [SMALL_STATE(5408)] = 281967,
  [SMALL_STATE(5409)] = 282018,
  [SMALL_STATE(5410)] = 282061,
  [SMALL_STATE(5411)] = 282116,
  [SMALL_STATE(5412)] = 282159,
  [SMALL_STATE(5413)] = 282202,
  [SMALL_STATE(5414)] = 282251,
  [SMALL_STATE(5415)] = 282294,
  [SMALL_STATE(5416)] = 282361,
  [SMALL_STATE(5417)] = 282404,
  [SMALL_STATE(5418)] = 282459,
  [SMALL_STATE(5419)] = 282502,
  [SMALL_STATE(5420)] = 282545,
  [SMALL_STATE(5421)] = 282588,
  [SMALL_STATE(5422)] = 282631,
  [SMALL_STATE(5423)] = 282674,
  [SMALL_STATE(5424)] = 282741,
  [SMALL_STATE(5425)] = 282798,
  [SMALL_STATE(5426)] = 282853,
  [SMALL_STATE(5427)] = 282896,
  [SMALL_STATE(5428)] = 282945,
  [SMALL_STATE(5429)] = 282988,
  [SMALL_STATE(5430)] = 283031,
  [SMALL_STATE(5431)] = 283074,
  [SMALL_STATE(5432)] = 283117,
  [SMALL_STATE(5433)] = 283160,
  [SMALL_STATE(5434)] = 283215,
  [SMALL_STATE(5435)] = 283262,
  [SMALL_STATE(5436)] = 283305,
  [SMALL_STATE(5437)] = 283362,
  [SMALL_STATE(5438)] = 283405,
  [SMALL_STATE(5439)] = 283448,
  [SMALL_STATE(5440)] = 283491,
  [SMALL_STATE(5441)] = 283534,
  [SMALL_STATE(5442)] = 283583,
  [SMALL_STATE(5443)] = 283630,
  [SMALL_STATE(5444)] = 283689,
  [SMALL_STATE(5445)] = 283732,
  [SMALL_STATE(5446)] = 283789,
  [SMALL_STATE(5447)] = 283832,
  [SMALL_STATE(5448)] = 283887,
  [SMALL_STATE(5449)] = 283930,
  [SMALL_STATE(5450)] = 283973,
  [SMALL_STATE(5451)] = 284016,
  [SMALL_STATE(5452)] = 284059,
  [SMALL_STATE(5453)] = 284116,
  [SMALL_STATE(5454)] = 284161,
  [SMALL_STATE(5455)] = 284224,
  [SMALL_STATE(5456)] = 284267,
  [SMALL_STATE(5457)] = 284310,
  [SMALL_STATE(5458)] = 284353,
  [SMALL_STATE(5459)] = 284398,
  [SMALL_STATE(5460)] = 284453,
  [SMALL_STATE(5461)] = 284496,
  [SMALL_STATE(5462)] = 284539,
  [SMALL_STATE(5463)] = 284582,
  [SMALL_STATE(5464)] = 284625,
  [SMALL_STATE(5465)] = 284680,
  [SMALL_STATE(5466)] = 284725,
  [SMALL_STATE(5467)] = 284768,
  [SMALL_STATE(5468)] = 284811,
  [SMALL_STATE(5469)] = 284868,
  [SMALL_STATE(5470)] = 284911,
  [SMALL_STATE(5471)] = 284964,
  [SMALL_STATE(5472)] = 285019,
  [SMALL_STATE(5473)] = 285062,
  [SMALL_STATE(5474)] = 285117,
  [SMALL_STATE(5475)] = 285160,
  [SMALL_STATE(5476)] = 285203,
  [SMALL_STATE(5477)] = 285246,
  [SMALL_STATE(5478)] = 285289,
  [SMALL_STATE(5479)] = 285332,
  [SMALL_STATE(5480)] = 285375,
  [SMALL_STATE(5481)] = 285418,
  [SMALL_STATE(5482)] = 285461,
  [SMALL_STATE(5483)] = 285506,
  [SMALL_STATE(5484)] = 285563,
  [SMALL_STATE(5485)] = 285606,
  [SMALL_STATE(5486)] = 285659,
  [SMALL_STATE(5487)] = 285704,
  [SMALL_STATE(5488)] = 285747,
  [SMALL_STATE(5489)] = 285790,
  [SMALL_STATE(5490)] = 285845,
  [SMALL_STATE(5491)] = 285900,
  [SMALL_STATE(5492)] = 285943,
  [SMALL_STATE(5493)] = 285998,
  [SMALL_STATE(5494)] = 286055,
  [SMALL_STATE(5495)] = 286102,
  [SMALL_STATE(5496)] = 286157,
  [SMALL_STATE(5497)] = 286200,
  [SMALL_STATE(5498)] = 286242,
  [SMALL_STATE(5499)] = 286284,
  [SMALL_STATE(5500)] = 286352,
  [SMALL_STATE(5501)] = 286400,
  [SMALL_STATE(5502)] = 286442,
  [SMALL_STATE(5503)] = 286486,
  [SMALL_STATE(5504)] = 286554,
  [SMALL_STATE(5505)] = 286596,
  [SMALL_STATE(5506)] = 286638,
  [SMALL_STATE(5507)] = 286690,
  [SMALL_STATE(5508)] = 286734,
  [SMALL_STATE(5509)] = 286796,
  [SMALL_STATE(5510)] = 286864,
  [SMALL_STATE(5511)] = 286906,
  [SMALL_STATE(5512)] = 286952,
  [SMALL_STATE(5513)] = 287008,
  [SMALL_STATE(5514)] = 287076,
  [SMALL_STATE(5515)] = 287118,
  [SMALL_STATE(5516)] = 287164,
  [SMALL_STATE(5517)] = 287206,
  [SMALL_STATE(5518)] = 287248,
  [SMALL_STATE(5519)] = 287290,
  [SMALL_STATE(5520)] = 287332,
  [SMALL_STATE(5521)] = 287390,
  [SMALL_STATE(5522)] = 287432,
  [SMALL_STATE(5523)] = 287478,
  [SMALL_STATE(5524)] = 287532,
  [SMALL_STATE(5525)] = 287574,
  [SMALL_STATE(5526)] = 287616,
  [SMALL_STATE(5527)] = 287658,
  [SMALL_STATE(5528)] = 287700,
  [SMALL_STATE(5529)] = 287748,
  [SMALL_STATE(5530)] = 287790,
  [SMALL_STATE(5531)] = 287836,
  [SMALL_STATE(5532)] = 287878,
  [SMALL_STATE(5533)] = 287920,
  [SMALL_STATE(5534)] = 287988,
  [SMALL_STATE(5535)] = 288030,
  [SMALL_STATE(5536)] = 288072,
  [SMALL_STATE(5537)] = 288116,
  [SMALL_STATE(5538)] = 288158,
  [SMALL_STATE(5539)] = 288226,
  [SMALL_STATE(5540)] = 288268,
  [SMALL_STATE(5541)] = 288310,
  [SMALL_STATE(5542)] = 288352,
  [SMALL_STATE(5543)] = 288394,
  [SMALL_STATE(5544)] = 288446,
  [SMALL_STATE(5545)] = 288512,
  [SMALL_STATE(5546)] = 288564,
  [SMALL_STATE(5547)] = 288610,
  [SMALL_STATE(5548)] = 288662,
  [SMALL_STATE(5549)] = 288704,
  [SMALL_STATE(5550)] = 288748,
  [SMALL_STATE(5551)] = 288790,
  [SMALL_STATE(5552)] = 288832,
  [SMALL_STATE(5553)] = 288900,
  [SMALL_STATE(5554)] = 288968,
  [SMALL_STATE(5555)] = 289010,
  [SMALL_STATE(5556)] = 289052,
  [SMALL_STATE(5557)] = 289118,
  [SMALL_STATE(5558)] = 289160,
  [SMALL_STATE(5559)] = 289202,
  [SMALL_STATE(5560)] = 289270,
  [SMALL_STATE(5561)] = 289324,
  [SMALL_STATE(5562)] = 289366,
  [SMALL_STATE(5563)] = 289422,
  [SMALL_STATE(5564)] = 289490,
  [SMALL_STATE(5565)] = 289532,
  [SMALL_STATE(5566)] = 289574,
  [SMALL_STATE(5567)] = 289640,
  [SMALL_STATE(5568)] = 289682,
  [SMALL_STATE(5569)] = 289726,
  [SMALL_STATE(5570)] = 289792,
  [SMALL_STATE(5571)] = 289838,
  [SMALL_STATE(5572)] = 289882,
  [SMALL_STATE(5573)] = 289950,
  [SMALL_STATE(5574)] = 290004,
  [SMALL_STATE(5575)] = 290046,
  [SMALL_STATE(5576)] = 290090,
  [SMALL_STATE(5577)] = 290132,
  [SMALL_STATE(5578)] = 290174,
  [SMALL_STATE(5579)] = 290240,
  [SMALL_STATE(5580)] = 290282,
  [SMALL_STATE(5581)] = 290348,
  [SMALL_STATE(5582)] = 290394,
  [SMALL_STATE(5583)] = 290438,
  [SMALL_STATE(5584)] = 290480,
  [SMALL_STATE(5585)] = 290548,
  [SMALL_STATE(5586)] = 290590,
  [SMALL_STATE(5587)] = 290632,
  [SMALL_STATE(5588)] = 290674,
  [SMALL_STATE(5589)] = 290720,
  [SMALL_STATE(5590)] = 290762,
  [SMALL_STATE(5591)] = 290816,
  [SMALL_STATE(5592)] = 290858,
  [SMALL_STATE(5593)] = 290900,
  [SMALL_STATE(5594)] = 290942,
  [SMALL_STATE(5595)] = 290984,
  [SMALL_STATE(5596)] = 291032,
  [SMALL_STATE(5597)] = 291074,
  [SMALL_STATE(5598)] = 291128,
  [SMALL_STATE(5599)] = 291170,
  [SMALL_STATE(5600)] = 291212,
  [SMALL_STATE(5601)] = 291254,
  [SMALL_STATE(5602)] = 291296,
  [SMALL_STATE(5603)] = 291338,
  [SMALL_STATE(5604)] = 291382,
  [SMALL_STATE(5605)] = 291424,
  [SMALL_STATE(5606)] = 291466,
  [SMALL_STATE(5607)] = 291508,
  [SMALL_STATE(5608)] = 291550,
  [SMALL_STATE(5609)] = 291606,
  [SMALL_STATE(5610)] = 291672,
  [SMALL_STATE(5611)] = 291740,
  [SMALL_STATE(5612)] = 291782,
  [SMALL_STATE(5613)] = 291824,
  [SMALL_STATE(5614)] = 291878,
  [SMALL_STATE(5615)] = 291930,
  [SMALL_STATE(5616)] = 291998,
  [SMALL_STATE(5617)] = 292040,
  [SMALL_STATE(5618)] = 292082,
  [SMALL_STATE(5619)] = 292150,
  [SMALL_STATE(5620)] = 292198,
  [SMALL_STATE(5621)] = 292240,
  [SMALL_STATE(5622)] = 292288,
  [SMALL_STATE(5623)] = 292342,
  [SMALL_STATE(5624)] = 292386,
  [SMALL_STATE(5625)] = 292428,
  [SMALL_STATE(5626)] = 292494,
  [SMALL_STATE(5627)] = 292562,
  [SMALL_STATE(5628)] = 292614,
  [SMALL_STATE(5629)] = 292656,
  [SMALL_STATE(5630)] = 292698,
  [SMALL_STATE(5631)] = 292752,
  [SMALL_STATE(5632)] = 292794,
  [SMALL_STATE(5633)] = 292862,
  [SMALL_STATE(5634)] = 292910,
  [SMALL_STATE(5635)] = 292956,
  [SMALL_STATE(5636)] = 292998,
  [SMALL_STATE(5637)] = 293040,
  [SMALL_STATE(5638)] = 293082,
  [SMALL_STATE(5639)] = 293134,
  [SMALL_STATE(5640)] = 293202,
  [SMALL_STATE(5641)] = 293244,
  [SMALL_STATE(5642)] = 293286,
  [SMALL_STATE(5643)] = 293354,
  [SMALL_STATE(5644)] = 293398,
  [SMALL_STATE(5645)] = 293440,
  [SMALL_STATE(5646)] = 293482,
  [SMALL_STATE(5647)] = 293524,
  [SMALL_STATE(5648)] = 293566,
  [SMALL_STATE(5649)] = 293620,
  [SMALL_STATE(5650)] = 293668,
  [SMALL_STATE(5651)] = 293710,
  [SMALL_STATE(5652)] = 293764,
  [SMALL_STATE(5653)] = 293812,
  [SMALL_STATE(5654)] = 293854,
  [SMALL_STATE(5655)] = 293896,
  [SMALL_STATE(5656)] = 293948,
  [SMALL_STATE(5657)] = 293992,
  [SMALL_STATE(5658)] = 294034,
  [SMALL_STATE(5659)] = 294076,
  [SMALL_STATE(5660)] = 294144,
  [SMALL_STATE(5661)] = 294212,
  [SMALL_STATE(5662)] = 294256,
  [SMALL_STATE(5663)] = 294310,
  [SMALL_STATE(5664)] = 294356,
  [SMALL_STATE(5665)] = 294398,
  [SMALL_STATE(5666)] = 294440,
  [SMALL_STATE(5667)] = 294486,
  [SMALL_STATE(5668)] = 294528,
  [SMALL_STATE(5669)] = 294570,
  [SMALL_STATE(5670)] = 294612,
  [SMALL_STATE(5671)] = 294656,
  [SMALL_STATE(5672)] = 294722,
  [SMALL_STATE(5673)] = 294770,
  [SMALL_STATE(5674)] = 294812,
  [SMALL_STATE(5675)] = 294854,
  [SMALL_STATE(5676)] = 294896,
  [SMALL_STATE(5677)] = 294938,
  [SMALL_STATE(5678)] = 294992,
  [SMALL_STATE(5679)] = 295034,
  [SMALL_STATE(5680)] = 295076,
  [SMALL_STATE(5681)] = 295122,
  [SMALL_STATE(5682)] = 295190,
  [SMALL_STATE(5683)] = 295258,
  [SMALL_STATE(5684)] = 295306,
  [SMALL_STATE(5685)] = 295374,
  [SMALL_STATE(5686)] = 295442,
  [SMALL_STATE(5687)] = 295510,
  [SMALL_STATE(5688)] = 295562,
  [SMALL_STATE(5689)] = 295624,
  [SMALL_STATE(5690)] = 295666,
  [SMALL_STATE(5691)] = 295708,
  [SMALL_STATE(5692)] = 295776,
  [SMALL_STATE(5693)] = 295824,
  [SMALL_STATE(5694)] = 295892,
  [SMALL_STATE(5695)] = 295934,
  [SMALL_STATE(5696)] = 295978,
  [SMALL_STATE(5697)] = 296020,
  [SMALL_STATE(5698)] = 296062,
  [SMALL_STATE(5699)] = 296110,
  [SMALL_STATE(5700)] = 296152,
  [SMALL_STATE(5701)] = 296194,
  [SMALL_STATE(5702)] = 296236,
  [SMALL_STATE(5703)] = 296304,
  [SMALL_STATE(5704)] = 296346,
  [SMALL_STATE(5705)] = 296388,
  [SMALL_STATE(5706)] = 296430,
  [SMALL_STATE(5707)] = 296498,
  [SMALL_STATE(5708)] = 296540,
  [SMALL_STATE(5709)] = 296588,
  [SMALL_STATE(5710)] = 296656,
  [SMALL_STATE(5711)] = 296698,
  [SMALL_STATE(5712)] = 296752,
  [SMALL_STATE(5713)] = 296804,
  [SMALL_STATE(5714)] = 296846,
  [SMALL_STATE(5715)] = 296888,
  [SMALL_STATE(5716)] = 296930,
  [SMALL_STATE(5717)] = 296984,
  [SMALL_STATE(5718)] = 297028,
  [SMALL_STATE(5719)] = 297070,
  [SMALL_STATE(5720)] = 297136,
  [SMALL_STATE(5721)] = 297188,
  [SMALL_STATE(5722)] = 297256,
  [SMALL_STATE(5723)] = 297298,
  [SMALL_STATE(5724)] = 297350,
  [SMALL_STATE(5725)] = 297402,
  [SMALL_STATE(5726)] = 297446,
  [SMALL_STATE(5727)] = 297514,
  [SMALL_STATE(5728)] = 297556,
  [SMALL_STATE(5729)] = 297608,
  [SMALL_STATE(5730)] = 297650,
  [SMALL_STATE(5731)] = 297718,
  [SMALL_STATE(5732)] = 297760,
  [SMALL_STATE(5733)] = 297828,
  [SMALL_STATE(5734)] = 297870,
  [SMALL_STATE(5735)] = 297912,
  [SMALL_STATE(5736)] = 297954,
  [SMALL_STATE(5737)] = 297996,
  [SMALL_STATE(5738)] = 298040,
  [SMALL_STATE(5739)] = 298096,
  [SMALL_STATE(5740)] = 298138,
  [SMALL_STATE(5741)] = 298192,
  [SMALL_STATE(5742)] = 298246,
  [SMALL_STATE(5743)] = 298314,
  [SMALL_STATE(5744)] = 298356,
  [SMALL_STATE(5745)] = 298398,
  [SMALL_STATE(5746)] = 298440,
  [SMALL_STATE(5747)] = 298482,
  [SMALL_STATE(5748)] = 298524,
  [SMALL_STATE(5749)] = 298566,
  [SMALL_STATE(5750)] = 298610,
  [SMALL_STATE(5751)] = 298678,
  [SMALL_STATE(5752)] = 298720,
  [SMALL_STATE(5753)] = 298788,
  [SMALL_STATE(5754)] = 298830,
  [SMALL_STATE(5755)] = 298872,
  [SMALL_STATE(5756)] = 298916,
  [SMALL_STATE(5757)] = 298958,
  [SMALL_STATE(5758)] = 299026,
  [SMALL_STATE(5759)] = 299094,
  [SMALL_STATE(5760)] = 299136,
  [SMALL_STATE(5761)] = 299204,
  [SMALL_STATE(5762)] = 299260,
  [SMALL_STATE(5763)] = 299302,
  [SMALL_STATE(5764)] = 299358,
  [SMALL_STATE(5765)] = 299400,
  [SMALL_STATE(5766)] = 299442,
  [SMALL_STATE(5767)] = 299496,
  [SMALL_STATE(5768)] = 299540,
  [SMALL_STATE(5769)] = 299582,
  [SMALL_STATE(5770)] = 299650,
  [SMALL_STATE(5771)] = 299692,
  [SMALL_STATE(5772)] = 299758,
  [SMALL_STATE(5773)] = 299800,
  [SMALL_STATE(5774)] = 299842,
  [SMALL_STATE(5775)] = 299896,
  [SMALL_STATE(5776)] = 299938,
  [SMALL_STATE(5777)] = 299980,
  [SMALL_STATE(5778)] = 300022,
  [SMALL_STATE(5779)] = 300064,
  [SMALL_STATE(5780)] = 300116,
  [SMALL_STATE(5781)] = 300158,
  [SMALL_STATE(5782)] = 300200,
  [SMALL_STATE(5783)] = 300242,
  [SMALL_STATE(5784)] = 300284,
  [SMALL_STATE(5785)] = 300330,
  [SMALL_STATE(5786)] = 300384,
  [SMALL_STATE(5787)] = 300426,
  [SMALL_STATE(5788)] = 300468,
  [SMALL_STATE(5789)] = 300510,
  [SMALL_STATE(5790)] = 300552,
  [SMALL_STATE(5791)] = 300594,
  [SMALL_STATE(5792)] = 300642,
  [SMALL_STATE(5793)] = 300704,
  [SMALL_STATE(5794)] = 300746,
  [SMALL_STATE(5795)] = 300788,
  [SMALL_STATE(5796)] = 300832,
  [SMALL_STATE(5797)] = 300878,
  [SMALL_STATE(5798)] = 300920,
  [SMALL_STATE(5799)] = 300988,
  [SMALL_STATE(5800)] = 301030,
  [SMALL_STATE(5801)] = 301072,
  [SMALL_STATE(5802)] = 301118,
  [SMALL_STATE(5803)] = 301160,
  [SMALL_STATE(5804)] = 301214,
  [SMALL_STATE(5805)] = 301270,
  [SMALL_STATE(5806)] = 301312,
  [SMALL_STATE(5807)] = 301354,
  [SMALL_STATE(5808)] = 301396,
  [SMALL_STATE(5809)] = 301442,
  [SMALL_STATE(5810)] = 301484,
  [SMALL_STATE(5811)] = 301526,
  [SMALL_STATE(5812)] = 301574,
  [SMALL_STATE(5813)] = 301616,
  [SMALL_STATE(5814)] = 301658,
  [SMALL_STATE(5815)] = 301726,
  [SMALL_STATE(5816)] = 301772,
  [SMALL_STATE(5817)] = 301820,
  [SMALL_STATE(5818)] = 301870,
  [SMALL_STATE(5819)] = 301914,
  [SMALL_STATE(5820)] = 301958,
  [SMALL_STATE(5821)] = 302000,
  [SMALL_STATE(5822)] = 302056,
  [SMALL_STATE(5823)] = 302098,
  [SMALL_STATE(5824)] = 302140,
  [SMALL_STATE(5825)] = 302182,
  [SMALL_STATE(5826)] = 302224,
  [SMALL_STATE(5827)] = 302266,
  [SMALL_STATE(5828)] = 302308,
  [SMALL_STATE(5829)] = 302350,
  [SMALL_STATE(5830)] = 302406,
  [SMALL_STATE(5831)] = 302448,
  [SMALL_STATE(5832)] = 302490,
  [SMALL_STATE(5833)] = 302532,
  [SMALL_STATE(5834)] = 302586,
  [SMALL_STATE(5835)] = 302630,
  [SMALL_STATE(5836)] = 302686,
  [SMALL_STATE(5837)] = 302728,
  [SMALL_STATE(5838)] = 302796,
  [SMALL_STATE(5839)] = 302850,
  [SMALL_STATE(5840)] = 302892,
  [SMALL_STATE(5841)] = 302934,
  [SMALL_STATE(5842)] = 302976,
  [SMALL_STATE(5843)] = 303044,
  [SMALL_STATE(5844)] = 303086,
  [SMALL_STATE(5845)] = 303128,
  [SMALL_STATE(5846)] = 303170,
  [SMALL_STATE(5847)] = 303238,
  [SMALL_STATE(5848)] = 303304,
  [SMALL_STATE(5849)] = 303346,
  [SMALL_STATE(5850)] = 303398,
  [SMALL_STATE(5851)] = 303466,
  [SMALL_STATE(5852)] = 303520,
  [SMALL_STATE(5853)] = 303562,
  [SMALL_STATE(5854)] = 303604,
  [SMALL_STATE(5855)] = 303648,
  [SMALL_STATE(5856)] = 303700,
  [SMALL_STATE(5857)] = 303746,
  [SMALL_STATE(5858)] = 303814,
  [SMALL_STATE(5859)] = 303862,
  [SMALL_STATE(5860)] = 303906,
  [SMALL_STATE(5861)] = 303968,
  [SMALL_STATE(5862)] = 304010,
  [SMALL_STATE(5863)] = 304052,
  [SMALL_STATE(5864)] = 304094,
  [SMALL_STATE(5865)] = 304136,
  [SMALL_STATE(5866)] = 304178,
  [SMALL_STATE(5867)] = 304232,
  [SMALL_STATE(5868)] = 304274,
  [SMALL_STATE(5869)] = 304316,
  [SMALL_STATE(5870)] = 304372,
  [SMALL_STATE(5871)] = 304414,
  [SMALL_STATE(5872)] = 304456,
  [SMALL_STATE(5873)] = 304498,
  [SMALL_STATE(5874)] = 304542,
  [SMALL_STATE(5875)] = 304610,
  [SMALL_STATE(5876)] = 304652,
  [SMALL_STATE(5877)] = 304694,
  [SMALL_STATE(5878)] = 304750,
  [SMALL_STATE(5879)] = 304796,
  [SMALL_STATE(5880)] = 304838,
  [SMALL_STATE(5881)] = 304880,
  [SMALL_STATE(5882)] = 304922,
  [SMALL_STATE(5883)] = 304964,
  [SMALL_STATE(5884)] = 305018,
  [SMALL_STATE(5885)] = 305060,
  [SMALL_STATE(5886)] = 305128,
  [SMALL_STATE(5887)] = 305170,
  [SMALL_STATE(5888)] = 305212,
  [SMALL_STATE(5889)] = 305266,
  [SMALL_STATE(5890)] = 305308,
  [SMALL_STATE(5891)] = 305362,
  [SMALL_STATE(5892)] = 305404,
  [SMALL_STATE(5893)] = 305446,
  [SMALL_STATE(5894)] = 305488,
  [SMALL_STATE(5895)] = 305530,
  [SMALL_STATE(5896)] = 305572,
  [SMALL_STATE(5897)] = 305616,
  [SMALL_STATE(5898)] = 305658,
  [SMALL_STATE(5899)] = 305700,
  [SMALL_STATE(5900)] = 305742,
  [SMALL_STATE(5901)] = 305788,
  [SMALL_STATE(5902)] = 305830,
  [SMALL_STATE(5903)] = 305872,
  [SMALL_STATE(5904)] = 305940,
  [SMALL_STATE(5905)] = 305994,
  [SMALL_STATE(5906)] = 306036,
  [SMALL_STATE(5907)] = 306080,
  [SMALL_STATE(5908)] = 306122,
  [SMALL_STATE(5909)] = 306164,
  [SMALL_STATE(5910)] = 306230,
  [SMALL_STATE(5911)] = 306284,
  [SMALL_STATE(5912)] = 306340,
  [SMALL_STATE(5913)] = 306408,
  [SMALL_STATE(5914)] = 306450,
  [SMALL_STATE(5915)] = 306494,
  [SMALL_STATE(5916)] = 306536,
  [SMALL_STATE(5917)] = 306590,
  [SMALL_STATE(5918)] = 306632,
  [SMALL_STATE(5919)] = 306674,
  [SMALL_STATE(5920)] = 306716,
  [SMALL_STATE(5921)] = 306758,
  [SMALL_STATE(5922)] = 306826,
  [SMALL_STATE(5923)] = 306868,
  [SMALL_STATE(5924)] = 306910,
  [SMALL_STATE(5925)] = 306972,
  [SMALL_STATE(5926)] = 307014,
  [SMALL_STATE(5927)] = 307056,
  [SMALL_STATE(5928)] = 307098,
  [SMALL_STATE(5929)] = 307166,
  [SMALL_STATE(5930)] = 307208,
  [SMALL_STATE(5931)] = 307250,
  [SMALL_STATE(5932)] = 307306,
  [SMALL_STATE(5933)] = 307348,
  [SMALL_STATE(5934)] = 307400,
  [SMALL_STATE(5935)] = 307442,
  [SMALL_STATE(5936)] = 307488,
  [SMALL_STATE(5937)] = 307532,
  [SMALL_STATE(5938)] = 307600,
  [SMALL_STATE(5939)] = 307642,
  [SMALL_STATE(5940)] = 307684,
  [SMALL_STATE(5941)] = 307726,
  [SMALL_STATE(5942)] = 307768,
  [SMALL_STATE(5943)] = 307810,
  [SMALL_STATE(5944)] = 307852,
  [SMALL_STATE(5945)] = 307906,
  [SMALL_STATE(5946)] = 307960,
  [SMALL_STATE(5947)] = 308002,
  [SMALL_STATE(5948)] = 308044,
  [SMALL_STATE(5949)] = 308088,
  [SMALL_STATE(5950)] = 308130,
  [SMALL_STATE(5951)] = 308172,
  [SMALL_STATE(5952)] = 308214,
  [SMALL_STATE(5953)] = 308256,
  [SMALL_STATE(5954)] = 308298,
  [SMALL_STATE(5955)] = 308340,
  [SMALL_STATE(5956)] = 308384,
  [SMALL_STATE(5957)] = 308426,
  [SMALL_STATE(5958)] = 308468,
  [SMALL_STATE(5959)] = 308524,
  [SMALL_STATE(5960)] = 308566,
  [SMALL_STATE(5961)] = 308608,
  [SMALL_STATE(5962)] = 308650,
  [SMALL_STATE(5963)] = 308694,
  [SMALL_STATE(5964)] = 308750,
  [SMALL_STATE(5965)] = 308792,
  [SMALL_STATE(5966)] = 308836,
  [SMALL_STATE(5967)] = 308890,
  [SMALL_STATE(5968)] = 308932,
  [SMALL_STATE(5969)] = 308974,
  [SMALL_STATE(5970)] = 309028,
  [SMALL_STATE(5971)] = 309070,
  [SMALL_STATE(5972)] = 309114,
  [SMALL_STATE(5973)] = 309160,
  [SMALL_STATE(5974)] = 309202,
  [SMALL_STATE(5975)] = 309264,
  [SMALL_STATE(5976)] = 309306,
  [SMALL_STATE(5977)] = 309348,
  [SMALL_STATE(5978)] = 309390,
  [SMALL_STATE(5979)] = 309432,
  [SMALL_STATE(5980)] = 309474,
  [SMALL_STATE(5981)] = 309516,
  [SMALL_STATE(5982)] = 309558,
  [SMALL_STATE(5983)] = 309602,
  [SMALL_STATE(5984)] = 309644,
  [SMALL_STATE(5985)] = 309686,
  [SMALL_STATE(5986)] = 309748,
  [SMALL_STATE(5987)] = 309790,
  [SMALL_STATE(5988)] = 309834,
  [SMALL_STATE(5989)] = 309876,
  [SMALL_STATE(5990)] = 309928,
  [SMALL_STATE(5991)] = 309970,
  [SMALL_STATE(5992)] = 310012,
  [SMALL_STATE(5993)] = 310066,
  [SMALL_STATE(5994)] = 310108,
  [SMALL_STATE(5995)] = 310150,
  [SMALL_STATE(5996)] = 310192,
  [SMALL_STATE(5997)] = 310234,
  [SMALL_STATE(5998)] = 310284,
  [SMALL_STATE(5999)] = 310326,
  [SMALL_STATE(6000)] = 310394,
  [SMALL_STATE(6001)] = 310450,
  [SMALL_STATE(6002)] = 310492,
  [SMALL_STATE(6003)] = 310560,
  [SMALL_STATE(6004)] = 310628,
  [SMALL_STATE(6005)] = 310676,
  [SMALL_STATE(6006)] = 310718,
  [SMALL_STATE(6007)] = 310760,
  [SMALL_STATE(6008)] = 310802,
  [SMALL_STATE(6009)] = 310870,
  [SMALL_STATE(6010)] = 310912,
  [SMALL_STATE(6011)] = 310954,
  [SMALL_STATE(6012)] = 310996,
  [SMALL_STATE(6013)] = 311064,
  [SMALL_STATE(6014)] = 311110,
  [SMALL_STATE(6015)] = 311152,
  [SMALL_STATE(6016)] = 311200,
  [SMALL_STATE(6017)] = 311242,
  [SMALL_STATE(6018)] = 311304,
  [SMALL_STATE(6019)] = 311372,
  [SMALL_STATE(6020)] = 311414,
  [SMALL_STATE(6021)] = 311456,
  [SMALL_STATE(6022)] = 311500,
  [SMALL_STATE(6023)] = 311542,
  [SMALL_STATE(6024)] = 311584,
  [SMALL_STATE(6025)] = 311646,
  [SMALL_STATE(6026)] = 311690,
  [SMALL_STATE(6027)] = 311758,
  [SMALL_STATE(6028)] = 311800,
  [SMALL_STATE(6029)] = 311842,
  [SMALL_STATE(6030)] = 311884,
  [SMALL_STATE(6031)] = 311926,
  [SMALL_STATE(6032)] = 311992,
  [SMALL_STATE(6033)] = 312034,
  [SMALL_STATE(6034)] = 312076,
  [SMALL_STATE(6035)] = 312118,
  [SMALL_STATE(6036)] = 312162,
  [SMALL_STATE(6037)] = 312214,
  [SMALL_STATE(6038)] = 312256,
  [SMALL_STATE(6039)] = 312298,
  [SMALL_STATE(6040)] = 312354,
  [SMALL_STATE(6041)] = 312396,
  [SMALL_STATE(6042)] = 312440,
  [SMALL_STATE(6043)] = 312486,
  [SMALL_STATE(6044)] = 312530,
  [SMALL_STATE(6045)] = 312592,
  [SMALL_STATE(6046)] = 312646,
  [SMALL_STATE(6047)] = 312714,
  [SMALL_STATE(6048)] = 312766,
  [SMALL_STATE(6049)] = 312814,
  [SMALL_STATE(6050)] = 312882,
  [SMALL_STATE(6051)] = 312950,
  [SMALL_STATE(6052)] = 312992,
  [SMALL_STATE(6053)] = 313034,
  [SMALL_STATE(6054)] = 313076,
  [SMALL_STATE(6055)] = 313118,
  [SMALL_STATE(6056)] = 313160,
  [SMALL_STATE(6057)] = 313202,
  [SMALL_STATE(6058)] = 313246,
  [SMALL_STATE(6059)] = 313288,
  [SMALL_STATE(6060)] = 313344,
  [SMALL_STATE(6061)] = 313386,
  [SMALL_STATE(6062)] = 313454,
  [SMALL_STATE(6063)] = 313498,
  [SMALL_STATE(6064)] = 313540,
  [SMALL_STATE(6065)] = 313608,
  [SMALL_STATE(6066)] = 313650,
  [SMALL_STATE(6067)] = 313698,
  [SMALL_STATE(6068)] = 313750,
  [SMALL_STATE(6069)] = 313792,
  [SMALL_STATE(6070)] = 313834,
  [SMALL_STATE(6071)] = 313878,
  [SMALL_STATE(6072)] = 313922,
  [SMALL_STATE(6073)] = 313964,
  [SMALL_STATE(6074)] = 314006,
  [SMALL_STATE(6075)] = 314056,
  [SMALL_STATE(6076)] = 314122,
  [SMALL_STATE(6077)] = 314168,
  [SMALL_STATE(6078)] = 314222,
  [SMALL_STATE(6079)] = 314264,
  [SMALL_STATE(6080)] = 314306,
  [SMALL_STATE(6081)] = 314364,
  [SMALL_STATE(6082)] = 314410,
  [SMALL_STATE(6083)] = 314452,
  [SMALL_STATE(6084)] = 314518,
  [SMALL_STATE(6085)] = 314560,
  [SMALL_STATE(6086)] = 314604,
  [SMALL_STATE(6087)] = 314650,
  [SMALL_STATE(6088)] = 314696,
  [SMALL_STATE(6089)] = 314738,
  [SMALL_STATE(6090)] = 314794,
  [SMALL_STATE(6091)] = 314840,
  [SMALL_STATE(6092)] = 314908,
  [SMALL_STATE(6093)] = 314952,
  [SMALL_STATE(6094)] = 315000,
  [SMALL_STATE(6095)] = 315048,
  [SMALL_STATE(6096)] = 315116,
  [SMALL_STATE(6097)] = 315158,
  [SMALL_STATE(6098)] = 315204,
  [SMALL_STATE(6099)] = 315246,
  [SMALL_STATE(6100)] = 315288,
  [SMALL_STATE(6101)] = 315342,
  [SMALL_STATE(6102)] = 315390,
  [SMALL_STATE(6103)] = 315444,
  [SMALL_STATE(6104)] = 315512,
  [SMALL_STATE(6105)] = 315553,
  [SMALL_STATE(6106)] = 315608,
  [SMALL_STATE(6107)] = 315649,
  [SMALL_STATE(6108)] = 315690,
  [SMALL_STATE(6109)] = 315731,
  [SMALL_STATE(6110)] = 315772,
  [SMALL_STATE(6111)] = 315813,
  [SMALL_STATE(6112)] = 315854,
  [SMALL_STATE(6113)] = 315895,
  [SMALL_STATE(6114)] = 315936,
  [SMALL_STATE(6115)] = 315977,
  [SMALL_STATE(6116)] = 316018,
  [SMALL_STATE(6117)] = 316059,
  [SMALL_STATE(6118)] = 316102,
  [SMALL_STATE(6119)] = 316143,
  [SMALL_STATE(6120)] = 316184,
  [SMALL_STATE(6121)] = 316225,
  [SMALL_STATE(6122)] = 316266,
  [SMALL_STATE(6123)] = 316321,
  [SMALL_STATE(6124)] = 316362,
  [SMALL_STATE(6125)] = 316403,
  [SMALL_STATE(6126)] = 316444,
  [SMALL_STATE(6127)] = 316485,
  [SMALL_STATE(6128)] = 316526,
  [SMALL_STATE(6129)] = 316569,
  [SMALL_STATE(6130)] = 316610,
  [SMALL_STATE(6131)] = 316655,
  [SMALL_STATE(6132)] = 316708,
  [SMALL_STATE(6133)] = 316749,
  [SMALL_STATE(6134)] = 316790,
  [SMALL_STATE(6135)] = 316831,
  [SMALL_STATE(6136)] = 316872,
  [SMALL_STATE(6137)] = 316915,
  [SMALL_STATE(6138)] = 316956,
  [SMALL_STATE(6139)] = 316997,
  [SMALL_STATE(6140)] = 317038,
  [SMALL_STATE(6141)] = 317079,
  [SMALL_STATE(6142)] = 317120,
  [SMALL_STATE(6143)] = 317161,
  [SMALL_STATE(6144)] = 317202,
  [SMALL_STATE(6145)] = 317243,
  [SMALL_STATE(6146)] = 317284,
  [SMALL_STATE(6147)] = 317325,
  [SMALL_STATE(6148)] = 317366,
  [SMALL_STATE(6149)] = 317411,
  [SMALL_STATE(6150)] = 317462,
  [SMALL_STATE(6151)] = 317517,
  [SMALL_STATE(6152)] = 317560,
  [SMALL_STATE(6153)] = 317601,
  [SMALL_STATE(6154)] = 317642,
  [SMALL_STATE(6155)] = 317683,
  [SMALL_STATE(6156)] = 317726,
  [SMALL_STATE(6157)] = 317767,
  [SMALL_STATE(6158)] = 317808,
  [SMALL_STATE(6159)] = 317849,
  [SMALL_STATE(6160)] = 317890,
  [SMALL_STATE(6161)] = 317931,
  [SMALL_STATE(6162)] = 317972,
  [SMALL_STATE(6163)] = 318013,
  [SMALL_STATE(6164)] = 318054,
  [SMALL_STATE(6165)] = 318095,
  [SMALL_STATE(6166)] = 318136,
  [SMALL_STATE(6167)] = 318177,
  [SMALL_STATE(6168)] = 318218,
  [SMALL_STATE(6169)] = 318259,
  [SMALL_STATE(6170)] = 318300,
  [SMALL_STATE(6171)] = 318341,
  [SMALL_STATE(6172)] = 318382,
  [SMALL_STATE(6173)] = 318423,
  [SMALL_STATE(6174)] = 318464,
  [SMALL_STATE(6175)] = 318505,
  [SMALL_STATE(6176)] = 318546,
  [SMALL_STATE(6177)] = 318587,
  [SMALL_STATE(6178)] = 318628,
  [SMALL_STATE(6179)] = 318669,
  [SMALL_STATE(6180)] = 318710,
  [SMALL_STATE(6181)] = 318751,
  [SMALL_STATE(6182)] = 318792,
  [SMALL_STATE(6183)] = 318837,
  [SMALL_STATE(6184)] = 318878,
  [SMALL_STATE(6185)] = 318919,
  [SMALL_STATE(6186)] = 318962,
  [SMALL_STATE(6187)] = 319003,
  [SMALL_STATE(6188)] = 319048,
  [SMALL_STATE(6189)] = 319089,
  [SMALL_STATE(6190)] = 319130,
  [SMALL_STATE(6191)] = 319171,
  [SMALL_STATE(6192)] = 319216,
  [SMALL_STATE(6193)] = 319257,
  [SMALL_STATE(6194)] = 319298,
  [SMALL_STATE(6195)] = 319339,
  [SMALL_STATE(6196)] = 319380,
  [SMALL_STATE(6197)] = 319421,
  [SMALL_STATE(6198)] = 319474,
  [SMALL_STATE(6199)] = 319515,
  [SMALL_STATE(6200)] = 319558,
  [SMALL_STATE(6201)] = 319599,
  [SMALL_STATE(6202)] = 319642,
  [SMALL_STATE(6203)] = 319683,
  [SMALL_STATE(6204)] = 319724,
  [SMALL_STATE(6205)] = 319765,
  [SMALL_STATE(6206)] = 319812,
  [SMALL_STATE(6207)] = 319853,
  [SMALL_STATE(6208)] = 319894,
  [SMALL_STATE(6209)] = 319935,
  [SMALL_STATE(6210)] = 319982,
  [SMALL_STATE(6211)] = 320023,
  [SMALL_STATE(6212)] = 320064,
  [SMALL_STATE(6213)] = 320105,
  [SMALL_STATE(6214)] = 320146,
  [SMALL_STATE(6215)] = 320187,
  [SMALL_STATE(6216)] = 320228,
  [SMALL_STATE(6217)] = 320269,
  [SMALL_STATE(6218)] = 320310,
  [SMALL_STATE(6219)] = 320351,
  [SMALL_STATE(6220)] = 320392,
  [SMALL_STATE(6221)] = 320433,
  [SMALL_STATE(6222)] = 320474,
  [SMALL_STATE(6223)] = 320515,
  [SMALL_STATE(6224)] = 320558,
  [SMALL_STATE(6225)] = 320599,
  [SMALL_STATE(6226)] = 320640,
  [SMALL_STATE(6227)] = 320685,
  [SMALL_STATE(6228)] = 320726,
  [SMALL_STATE(6229)] = 320767,
  [SMALL_STATE(6230)] = 320808,
  [SMALL_STATE(6231)] = 320849,
  [SMALL_STATE(6232)] = 320902,
  [SMALL_STATE(6233)] = 320943,
  [SMALL_STATE(6234)] = 320984,
  [SMALL_STATE(6235)] = 321025,
  [SMALL_STATE(6236)] = 321066,
  [SMALL_STATE(6237)] = 321107,
  [SMALL_STATE(6238)] = 321162,
  [SMALL_STATE(6239)] = 321203,
  [SMALL_STATE(6240)] = 321264,
  [SMALL_STATE(6241)] = 321305,
  [SMALL_STATE(6242)] = 321346,
  [SMALL_STATE(6243)] = 321387,
  [SMALL_STATE(6244)] = 321428,
  [SMALL_STATE(6245)] = 321469,
  [SMALL_STATE(6246)] = 321510,
  [SMALL_STATE(6247)] = 321567,
  [SMALL_STATE(6248)] = 321608,
  [SMALL_STATE(6249)] = 321649,
  [SMALL_STATE(6250)] = 321690,
  [SMALL_STATE(6251)] = 321731,
  [SMALL_STATE(6252)] = 321772,
  [SMALL_STATE(6253)] = 321813,
  [SMALL_STATE(6254)] = 321854,
  [SMALL_STATE(6255)] = 321895,
  [SMALL_STATE(6256)] = 321938,
  [SMALL_STATE(6257)] = 321995,
  [SMALL_STATE(6258)] = 322036,
  [SMALL_STATE(6259)] = 322077,
  [SMALL_STATE(6260)] = 322118,
  [SMALL_STATE(6261)] = 322159,
  [SMALL_STATE(6262)] = 322200,
  [SMALL_STATE(6263)] = 322241,
  [SMALL_STATE(6264)] = 322284,
  [SMALL_STATE(6265)] = 322345,
  [SMALL_STATE(6266)] = 322386,
  [SMALL_STATE(6267)] = 322427,
  [SMALL_STATE(6268)] = 322470,
  [SMALL_STATE(6269)] = 322511,
  [SMALL_STATE(6270)] = 322576,
  [SMALL_STATE(6271)] = 322617,
  [SMALL_STATE(6272)] = 322658,
  [SMALL_STATE(6273)] = 322699,
  [SMALL_STATE(6274)] = 322764,
  [SMALL_STATE(6275)] = 322829,
  [SMALL_STATE(6276)] = 322884,
  [SMALL_STATE(6277)] = 322925,
  [SMALL_STATE(6278)] = 322972,
  [SMALL_STATE(6279)] = 323013,
  [SMALL_STATE(6280)] = 323054,
  [SMALL_STATE(6281)] = 323099,
  [SMALL_STATE(6282)] = 323140,
  [SMALL_STATE(6283)] = 323193,
  [SMALL_STATE(6284)] = 323248,
  [SMALL_STATE(6285)] = 323293,
  [SMALL_STATE(6286)] = 323334,
  [SMALL_STATE(6287)] = 323377,
  [SMALL_STATE(6288)] = 323418,
  [SMALL_STATE(6289)] = 323471,
  [SMALL_STATE(6290)] = 323514,
  [SMALL_STATE(6291)] = 323555,
  [SMALL_STATE(6292)] = 323596,
  [SMALL_STATE(6293)] = 323637,
  [SMALL_STATE(6294)] = 323678,
  [SMALL_STATE(6295)] = 323731,
  [SMALL_STATE(6296)] = 323792,
  [SMALL_STATE(6297)] = 323839,
  [SMALL_STATE(6298)] = 323880,
  [SMALL_STATE(6299)] = 323921,
  [SMALL_STATE(6300)] = 323962,
  [SMALL_STATE(6301)] = 324003,
  [SMALL_STATE(6302)] = 324046,
  [SMALL_STATE(6303)] = 324087,
  [SMALL_STATE(6304)] = 324128,
  [SMALL_STATE(6305)] = 324169,
  [SMALL_STATE(6306)] = 324210,
  [SMALL_STATE(6307)] = 324251,
  [SMALL_STATE(6308)] = 324292,
  [SMALL_STATE(6309)] = 324333,
  [SMALL_STATE(6310)] = 324374,
  [SMALL_STATE(6311)] = 324415,
  [SMALL_STATE(6312)] = 324480,
  [SMALL_STATE(6313)] = 324521,
  [SMALL_STATE(6314)] = 324568,
  [SMALL_STATE(6315)] = 324609,
  [SMALL_STATE(6316)] = 324650,
  [SMALL_STATE(6317)] = 324691,
  [SMALL_STATE(6318)] = 324736,
  [SMALL_STATE(6319)] = 324777,
  [SMALL_STATE(6320)] = 324820,
  [SMALL_STATE(6321)] = 324865,
  [SMALL_STATE(6322)] = 324906,
  [SMALL_STATE(6323)] = 324953,
  [SMALL_STATE(6324)] = 324994,
  [SMALL_STATE(6325)] = 325035,
  [SMALL_STATE(6326)] = 325084,
  [SMALL_STATE(6327)] = 325125,
  [SMALL_STATE(6328)] = 325166,
  [SMALL_STATE(6329)] = 325207,
  [SMALL_STATE(6330)] = 325250,
  [SMALL_STATE(6331)] = 325291,
  [SMALL_STATE(6332)] = 325334,
  [SMALL_STATE(6333)] = 325375,
  [SMALL_STATE(6334)] = 325416,
  [SMALL_STATE(6335)] = 325457,
  [SMALL_STATE(6336)] = 325500,
  [SMALL_STATE(6337)] = 325547,
  [SMALL_STATE(6338)] = 325590,
  [SMALL_STATE(6339)] = 325631,
  [SMALL_STATE(6340)] = 325672,
  [SMALL_STATE(6341)] = 325713,
  [SMALL_STATE(6342)] = 325754,
  [SMALL_STATE(6343)] = 325795,
  [SMALL_STATE(6344)] = 325838,
  [SMALL_STATE(6345)] = 325879,
  [SMALL_STATE(6346)] = 325944,
  [SMALL_STATE(6347)] = 325987,
  [SMALL_STATE(6348)] = 326028,
  [SMALL_STATE(6349)] = 326069,
  [SMALL_STATE(6350)] = 326110,
  [SMALL_STATE(6351)] = 326155,
  [SMALL_STATE(6352)] = 326196,
  [SMALL_STATE(6353)] = 326237,
  [SMALL_STATE(6354)] = 326278,
  [SMALL_STATE(6355)] = 326319,
  [SMALL_STATE(6356)] = 326360,
  [SMALL_STATE(6357)] = 326401,
  [SMALL_STATE(6358)] = 326442,
  [SMALL_STATE(6359)] = 326483,
  [SMALL_STATE(6360)] = 326524,
  [SMALL_STATE(6361)] = 326565,
  [SMALL_STATE(6362)] = 326606,
  [SMALL_STATE(6363)] = 326647,
  [SMALL_STATE(6364)] = 326688,
  [SMALL_STATE(6365)] = 326729,
  [SMALL_STATE(6366)] = 326770,
  [SMALL_STATE(6367)] = 326811,
  [SMALL_STATE(6368)] = 326852,
  [SMALL_STATE(6369)] = 326899,
  [SMALL_STATE(6370)] = 326940,
  [SMALL_STATE(6371)] = 326989,
  [SMALL_STATE(6372)] = 327034,
  [SMALL_STATE(6373)] = 327075,
  [SMALL_STATE(6374)] = 327116,
  [SMALL_STATE(6375)] = 327157,
  [SMALL_STATE(6376)] = 327198,
  [SMALL_STATE(6377)] = 327239,
  [SMALL_STATE(6378)] = 327292,
  [SMALL_STATE(6379)] = 327333,
  [SMALL_STATE(6380)] = 327374,
  [SMALL_STATE(6381)] = 327415,
  [SMALL_STATE(6382)] = 327456,
  [SMALL_STATE(6383)] = 327497,
  [SMALL_STATE(6384)] = 327538,
  [SMALL_STATE(6385)] = 327579,
  [SMALL_STATE(6386)] = 327620,
  [SMALL_STATE(6387)] = 327661,
  [SMALL_STATE(6388)] = 327702,
  [SMALL_STATE(6389)] = 327745,
  [SMALL_STATE(6390)] = 327786,
  [SMALL_STATE(6391)] = 327833,
  [SMALL_STATE(6392)] = 327894,
  [SMALL_STATE(6393)] = 327941,
  [SMALL_STATE(6394)] = 327982,
  [SMALL_STATE(6395)] = 328035,
  [SMALL_STATE(6396)] = 328090,
  [SMALL_STATE(6397)] = 328133,
  [SMALL_STATE(6398)] = 328174,
  [SMALL_STATE(6399)] = 328221,
  [SMALL_STATE(6400)] = 328262,
  [SMALL_STATE(6401)] = 328303,
  [SMALL_STATE(6402)] = 328344,
  [SMALL_STATE(6403)] = 328399,
  [SMALL_STATE(6404)] = 328440,
  [SMALL_STATE(6405)] = 328481,
  [SMALL_STATE(6406)] = 328546,
  [SMALL_STATE(6407)] = 328587,
  [SMALL_STATE(6408)] = 328630,
  [SMALL_STATE(6409)] = 328671,
  [SMALL_STATE(6410)] = 328712,
  [SMALL_STATE(6411)] = 328753,
  [SMALL_STATE(6412)] = 328806,
  [SMALL_STATE(6413)] = 328847,
  [SMALL_STATE(6414)] = 328888,
  [SMALL_STATE(6415)] = 328929,
  [SMALL_STATE(6416)] = 328984,
  [SMALL_STATE(6417)] = 329025,
  [SMALL_STATE(6418)] = 329066,
  [SMALL_STATE(6419)] = 329107,
  [SMALL_STATE(6420)] = 329148,
  [SMALL_STATE(6421)] = 329189,
  [SMALL_STATE(6422)] = 329230,
  [SMALL_STATE(6423)] = 329271,
  [SMALL_STATE(6424)] = 329312,
  [SMALL_STATE(6425)] = 329353,
  [SMALL_STATE(6426)] = 329400,
  [SMALL_STATE(6427)] = 329441,
  [SMALL_STATE(6428)] = 329482,
  [SMALL_STATE(6429)] = 329525,
  [SMALL_STATE(6430)] = 329570,
  [SMALL_STATE(6431)] = 329613,
  [SMALL_STATE(6432)] = 329654,
  [SMALL_STATE(6433)] = 329695,
  [SMALL_STATE(6434)] = 329748,
  [SMALL_STATE(6435)] = 329789,
  [SMALL_STATE(6436)] = 329830,
  [SMALL_STATE(6437)] = 329871,
  [SMALL_STATE(6438)] = 329912,
  [SMALL_STATE(6439)] = 329953,
  [SMALL_STATE(6440)] = 329994,
  [SMALL_STATE(6441)] = 330071,
  [SMALL_STATE(6442)] = 330112,
  [SMALL_STATE(6443)] = 330157,
  [SMALL_STATE(6444)] = 330198,
  [SMALL_STATE(6445)] = 330239,
  [SMALL_STATE(6446)] = 330282,
  [SMALL_STATE(6447)] = 330323,
  [SMALL_STATE(6448)] = 330364,
  [SMALL_STATE(6449)] = 330405,
  [SMALL_STATE(6450)] = 330466,
  [SMALL_STATE(6451)] = 330511,
  [SMALL_STATE(6452)] = 330552,
  [SMALL_STATE(6453)] = 330593,
  [SMALL_STATE(6454)] = 330634,
  [SMALL_STATE(6455)] = 330679,
  [SMALL_STATE(6456)] = 330720,
  [SMALL_STATE(6457)] = 330761,
  [SMALL_STATE(6458)] = 330802,
  [SMALL_STATE(6459)] = 330855,
  [SMALL_STATE(6460)] = 330896,
  [SMALL_STATE(6461)] = 330943,
  [SMALL_STATE(6462)] = 330984,
  [SMALL_STATE(6463)] = 331025,
  [SMALL_STATE(6464)] = 331066,
  [SMALL_STATE(6465)] = 331107,
  [SMALL_STATE(6466)] = 331148,
  [SMALL_STATE(6467)] = 331193,
  [SMALL_STATE(6468)] = 331236,
  [SMALL_STATE(6469)] = 331279,
  [SMALL_STATE(6470)] = 331324,
  [SMALL_STATE(6471)] = 331377,
  [SMALL_STATE(6472)] = 331424,
  [SMALL_STATE(6473)] = 331465,
  [SMALL_STATE(6474)] = 331506,
  [SMALL_STATE(6475)] = 331557,
  [SMALL_STATE(6476)] = 331598,
  [SMALL_STATE(6477)] = 331639,
  [SMALL_STATE(6478)] = 331680,
  [SMALL_STATE(6479)] = 331721,
  [SMALL_STATE(6480)] = 331762,
  [SMALL_STATE(6481)] = 331809,
  [SMALL_STATE(6482)] = 331850,
  [SMALL_STATE(6483)] = 331891,
  [SMALL_STATE(6484)] = 331938,
  [SMALL_STATE(6485)] = 331981,
  [SMALL_STATE(6486)] = 332022,
  [SMALL_STATE(6487)] = 332063,
  [SMALL_STATE(6488)] = 332116,
  [SMALL_STATE(6489)] = 332163,
  [SMALL_STATE(6490)] = 332204,
  [SMALL_STATE(6491)] = 332245,
  [SMALL_STATE(6492)] = 332286,
  [SMALL_STATE(6493)] = 332327,
  [SMALL_STATE(6494)] = 332370,
  [SMALL_STATE(6495)] = 332415,
  [SMALL_STATE(6496)] = 332460,
  [SMALL_STATE(6497)] = 332501,
  [SMALL_STATE(6498)] = 332546,
  [SMALL_STATE(6499)] = 332587,
  [SMALL_STATE(6500)] = 332630,
  [SMALL_STATE(6501)] = 332687,
  [SMALL_STATE(6502)] = 332728,
  [SMALL_STATE(6503)] = 332769,
  [SMALL_STATE(6504)] = 332810,
  [SMALL_STATE(6505)] = 332851,
  [SMALL_STATE(6506)] = 332892,
  [SMALL_STATE(6507)] = 332933,
  [SMALL_STATE(6508)] = 332974,
  [SMALL_STATE(6509)] = 333015,
  [SMALL_STATE(6510)] = 333056,
  [SMALL_STATE(6511)] = 333101,
  [SMALL_STATE(6512)] = 333142,
  [SMALL_STATE(6513)] = 333183,
  [SMALL_STATE(6514)] = 333224,
  [SMALL_STATE(6515)] = 333265,
  [SMALL_STATE(6516)] = 333312,
  [SMALL_STATE(6517)] = 333365,
  [SMALL_STATE(6518)] = 333408,
  [SMALL_STATE(6519)] = 333449,
  [SMALL_STATE(6520)] = 333492,
  [SMALL_STATE(6521)] = 333553,
  [SMALL_STATE(6522)] = 333596,
  [SMALL_STATE(6523)] = 333637,
  [SMALL_STATE(6524)] = 333688,
  [SMALL_STATE(6525)] = 333735,
  [SMALL_STATE(6526)] = 333784,
  [SMALL_STATE(6527)] = 333849,
  [SMALL_STATE(6528)] = 333890,
  [SMALL_STATE(6529)] = 333931,
  [SMALL_STATE(6530)] = 333978,
  [SMALL_STATE(6531)] = 334019,
  [SMALL_STATE(6532)] = 334060,
  [SMALL_STATE(6533)] = 334101,
  [SMALL_STATE(6534)] = 334154,
  [SMALL_STATE(6535)] = 334195,
  [SMALL_STATE(6536)] = 334236,
  [SMALL_STATE(6537)] = 334277,
  [SMALL_STATE(6538)] = 334318,
  [SMALL_STATE(6539)] = 334359,
  [SMALL_STATE(6540)] = 334402,
  [SMALL_STATE(6541)] = 334443,
  [SMALL_STATE(6542)] = 334488,
  [SMALL_STATE(6543)] = 334533,
  [SMALL_STATE(6544)] = 334588,
  [SMALL_STATE(6545)] = 334641,
  [SMALL_STATE(6546)] = 334706,
  [SMALL_STATE(6547)] = 334747,
  [SMALL_STATE(6548)] = 334788,
  [SMALL_STATE(6549)] = 334829,
  [SMALL_STATE(6550)] = 334870,
  [SMALL_STATE(6551)] = 334911,
  [SMALL_STATE(6552)] = 334952,
  [SMALL_STATE(6553)] = 334993,
  [SMALL_STATE(6554)] = 335034,
  [SMALL_STATE(6555)] = 335075,
  [SMALL_STATE(6556)] = 335116,
  [SMALL_STATE(6557)] = 335161,
  [SMALL_STATE(6558)] = 335202,
  [SMALL_STATE(6559)] = 335249,
  [SMALL_STATE(6560)] = 335302,
  [SMALL_STATE(6561)] = 335363,
  [SMALL_STATE(6562)] = 335416,
  [SMALL_STATE(6563)] = 335457,
  [SMALL_STATE(6564)] = 335498,
  [SMALL_STATE(6565)] = 335539,
  [SMALL_STATE(6566)] = 335580,
  [SMALL_STATE(6567)] = 335621,
  [SMALL_STATE(6568)] = 335662,
  [SMALL_STATE(6569)] = 335703,
  [SMALL_STATE(6570)] = 335746,
  [SMALL_STATE(6571)] = 335801,
  [SMALL_STATE(6572)] = 335842,
  [SMALL_STATE(6573)] = 335883,
  [SMALL_STATE(6574)] = 335924,
  [SMALL_STATE(6575)] = 335967,
  [SMALL_STATE(6576)] = 336008,
  [SMALL_STATE(6577)] = 336049,
  [SMALL_STATE(6578)] = 336098,
  [SMALL_STATE(6579)] = 336139,
  [SMALL_STATE(6580)] = 336180,
  [SMALL_STATE(6581)] = 336221,
  [SMALL_STATE(6582)] = 336262,
  [SMALL_STATE(6583)] = 336305,
  [SMALL_STATE(6584)] = 336346,
  [SMALL_STATE(6585)] = 336387,
  [SMALL_STATE(6586)] = 336428,
  [SMALL_STATE(6587)] = 336469,
  [SMALL_STATE(6588)] = 336510,
  [SMALL_STATE(6589)] = 336563,
  [SMALL_STATE(6590)] = 336604,
  [SMALL_STATE(6591)] = 336645,
  [SMALL_STATE(6592)] = 336686,
  [SMALL_STATE(6593)] = 336727,
  [SMALL_STATE(6594)] = 336768,
  [SMALL_STATE(6595)] = 336811,
  [SMALL_STATE(6596)] = 336852,
  [SMALL_STATE(6597)] = 336893,
  [SMALL_STATE(6598)] = 336938,
  [SMALL_STATE(6599)] = 336981,
  [SMALL_STATE(6600)] = 337022,
  [SMALL_STATE(6601)] = 337063,
  [SMALL_STATE(6602)] = 337116,
  [SMALL_STATE(6603)] = 337157,
  [SMALL_STATE(6604)] = 337198,
  [SMALL_STATE(6605)] = 337239,
  [SMALL_STATE(6606)] = 337280,
  [SMALL_STATE(6607)] = 337321,
  [SMALL_STATE(6608)] = 337362,
  [SMALL_STATE(6609)] = 337403,
  [SMALL_STATE(6610)] = 337450,
  [SMALL_STATE(6611)] = 337491,
  [SMALL_STATE(6612)] = 337532,
  [SMALL_STATE(6613)] = 337585,
  [SMALL_STATE(6614)] = 337626,
  [SMALL_STATE(6615)] = 337667,
  [SMALL_STATE(6616)] = 337708,
  [SMALL_STATE(6617)] = 337749,
  [SMALL_STATE(6618)] = 337790,
  [SMALL_STATE(6619)] = 337831,
  [SMALL_STATE(6620)] = 337874,
  [SMALL_STATE(6621)] = 337927,
  [SMALL_STATE(6622)] = 337970,
  [SMALL_STATE(6623)] = 338011,
  [SMALL_STATE(6624)] = 338056,
  [SMALL_STATE(6625)] = 338111,
  [SMALL_STATE(6626)] = 338152,
  [SMALL_STATE(6627)] = 338203,
  [SMALL_STATE(6628)] = 338244,
  [SMALL_STATE(6629)] = 338285,
  [SMALL_STATE(6630)] = 338330,
  [SMALL_STATE(6631)] = 338371,
  [SMALL_STATE(6632)] = 338412,
  [SMALL_STATE(6633)] = 338453,
  [SMALL_STATE(6634)] = 338494,
  [SMALL_STATE(6635)] = 338535,
  [SMALL_STATE(6636)] = 338576,
  [SMALL_STATE(6637)] = 338623,
  [SMALL_STATE(6638)] = 338664,
  [SMALL_STATE(6639)] = 338719,
  [SMALL_STATE(6640)] = 338760,
  [SMALL_STATE(6641)] = 338825,
  [SMALL_STATE(6642)] = 338872,
  [SMALL_STATE(6643)] = 338915,
  [SMALL_STATE(6644)] = 338958,
  [SMALL_STATE(6645)] = 339009,
  [SMALL_STATE(6646)] = 339050,
  [SMALL_STATE(6647)] = 339093,
  [SMALL_STATE(6648)] = 339150,
  [SMALL_STATE(6649)] = 339191,
  [SMALL_STATE(6650)] = 339232,
  [SMALL_STATE(6651)] = 339273,
  [SMALL_STATE(6652)] = 339314,
  [SMALL_STATE(6653)] = 339355,
  [SMALL_STATE(6654)] = 339398,
  [SMALL_STATE(6655)] = 339443,
  [SMALL_STATE(6656)] = 339484,
  [SMALL_STATE(6657)] = 339545,
  [SMALL_STATE(6658)] = 339586,
  [SMALL_STATE(6659)] = 339627,
  [SMALL_STATE(6660)] = 339668,
  [SMALL_STATE(6661)] = 339721,
  [SMALL_STATE(6662)] = 339766,
  [SMALL_STATE(6663)] = 339809,
  [SMALL_STATE(6664)] = 339850,
  [SMALL_STATE(6665)] = 339891,
  [SMALL_STATE(6666)] = 339932,
  [SMALL_STATE(6667)] = 339973,
  [SMALL_STATE(6668)] = 340026,
  [SMALL_STATE(6669)] = 340067,
  [SMALL_STATE(6670)] = 340110,
  [SMALL_STATE(6671)] = 340151,
  [SMALL_STATE(6672)] = 340192,
  [SMALL_STATE(6673)] = 340233,
  [SMALL_STATE(6674)] = 340274,
  [SMALL_STATE(6675)] = 340315,
  [SMALL_STATE(6676)] = 340380,
  [SMALL_STATE(6677)] = 340435,
  [SMALL_STATE(6678)] = 340476,
  [SMALL_STATE(6679)] = 340517,
  [SMALL_STATE(6680)] = 340558,
  [SMALL_STATE(6681)] = 340609,
  [SMALL_STATE(6682)] = 340650,
  [SMALL_STATE(6683)] = 340693,
  [SMALL_STATE(6684)] = 340734,
  [SMALL_STATE(6685)] = 340775,
  [SMALL_STATE(6686)] = 340826,
  [SMALL_STATE(6687)] = 340867,
  [SMALL_STATE(6688)] = 340918,
  [SMALL_STATE(6689)] = 340971,
  [SMALL_STATE(6690)] = 341012,
  [SMALL_STATE(6691)] = 341067,
  [SMALL_STATE(6692)] = 341108,
  [SMALL_STATE(6693)] = 341149,
  [SMALL_STATE(6694)] = 341190,
  [SMALL_STATE(6695)] = 341231,
  [SMALL_STATE(6696)] = 341272,
  [SMALL_STATE(6697)] = 341315,
  [SMALL_STATE(6698)] = 341362,
  [SMALL_STATE(6699)] = 341403,
  [SMALL_STATE(6700)] = 341444,
  [SMALL_STATE(6701)] = 341495,
  [SMALL_STATE(6702)] = 341536,
  [SMALL_STATE(6703)] = 341581,
  [SMALL_STATE(6704)] = 341646,
  [SMALL_STATE(6705)] = 341689,
  [SMALL_STATE(6706)] = 341730,
  [SMALL_STATE(6707)] = 341795,
  [SMALL_STATE(6708)] = 341836,
  [SMALL_STATE(6709)] = 341881,
  [SMALL_STATE(6710)] = 341922,
  [SMALL_STATE(6711)] = 341987,
  [SMALL_STATE(6712)] = 342038,
  [SMALL_STATE(6713)] = 342085,
  [SMALL_STATE(6714)] = 342140,
  [SMALL_STATE(6715)] = 342181,
  [SMALL_STATE(6716)] = 342224,
  [SMALL_STATE(6717)] = 342267,
  [SMALL_STATE(6718)] = 342308,
  [SMALL_STATE(6719)] = 342373,
  [SMALL_STATE(6720)] = 342418,
  [SMALL_STATE(6721)] = 342459,
  [SMALL_STATE(6722)] = 342502,
  [SMALL_STATE(6723)] = 342567,
  [SMALL_STATE(6724)] = 342608,
  [SMALL_STATE(6725)] = 342649,
  [SMALL_STATE(6726)] = 342694,
  [SMALL_STATE(6727)] = 342745,
  [SMALL_STATE(6728)] = 342786,
  [SMALL_STATE(6729)] = 342841,
  [SMALL_STATE(6730)] = 342882,
  [SMALL_STATE(6731)] = 342923,
  [SMALL_STATE(6732)] = 342964,
  [SMALL_STATE(6733)] = 343005,
  [SMALL_STATE(6734)] = 343058,
  [SMALL_STATE(6735)] = 343101,
  [SMALL_STATE(6736)] = 343142,
  [SMALL_STATE(6737)] = 343189,
  [SMALL_STATE(6738)] = 343230,
  [SMALL_STATE(6739)] = 343287,
  [SMALL_STATE(6740)] = 343328,
  [SMALL_STATE(6741)] = 343369,
  [SMALL_STATE(6742)] = 343410,
  [SMALL_STATE(6743)] = 343451,
  [SMALL_STATE(6744)] = 343492,
  [SMALL_STATE(6745)] = 343533,
  [SMALL_STATE(6746)] = 343574,
  [SMALL_STATE(6747)] = 343617,
  [SMALL_STATE(6748)] = 343658,
  [SMALL_STATE(6749)] = 343699,
  [SMALL_STATE(6750)] = 343742,
  [SMALL_STATE(6751)] = 343783,
  [SMALL_STATE(6752)] = 343834,
  [SMALL_STATE(6753)] = 343875,
  [SMALL_STATE(6754)] = 343928,
  [SMALL_STATE(6755)] = 343969,
  [SMALL_STATE(6756)] = 344010,
  [SMALL_STATE(6757)] = 344051,
  [SMALL_STATE(6758)] = 344092,
  [SMALL_STATE(6759)] = 344133,
  [SMALL_STATE(6760)] = 344174,
  [SMALL_STATE(6761)] = 344217,
  [SMALL_STATE(6762)] = 344258,
  [SMALL_STATE(6763)] = 344299,
  [SMALL_STATE(6764)] = 344340,
  [SMALL_STATE(6765)] = 344393,
  [SMALL_STATE(6766)] = 344458,
  [SMALL_STATE(6767)] = 344499,
  [SMALL_STATE(6768)] = 344564,
  [SMALL_STATE(6769)] = 344605,
  [SMALL_STATE(6770)] = 344646,
  [SMALL_STATE(6771)] = 344693,
  [SMALL_STATE(6772)] = 344754,
  [SMALL_STATE(6773)] = 344795,
  [SMALL_STATE(6774)] = 344836,
  [SMALL_STATE(6775)] = 344877,
  [SMALL_STATE(6776)] = 344918,
  [SMALL_STATE(6777)] = 344973,
  [SMALL_STATE(6778)] = 345026,
  [SMALL_STATE(6779)] = 345067,
  [SMALL_STATE(6780)] = 345107,
  [SMALL_STATE(6781)] = 345147,
  [SMALL_STATE(6782)] = 345189,
  [SMALL_STATE(6783)] = 345253,
  [SMALL_STATE(6784)] = 345305,
  [SMALL_STATE(6785)] = 345345,
  [SMALL_STATE(6786)] = 345385,
  [SMALL_STATE(6787)] = 345425,
  [SMALL_STATE(6788)] = 345465,
  [SMALL_STATE(6789)] = 345511,
  [SMALL_STATE(6790)] = 345555,
  [SMALL_STATE(6791)] = 345601,
  [SMALL_STATE(6792)] = 345641,
  [SMALL_STATE(6793)] = 345681,
  [SMALL_STATE(6794)] = 345721,
  [SMALL_STATE(6795)] = 345767,
  [SMALL_STATE(6796)] = 345809,
  [SMALL_STATE(6797)] = 345849,
  [SMALL_STATE(6798)] = 345899,
  [SMALL_STATE(6799)] = 345947,
  [SMALL_STATE(6800)] = 345987,
  [SMALL_STATE(6801)] = 346027,
  [SMALL_STATE(6802)] = 346077,
  [SMALL_STATE(6803)] = 346117,
  [SMALL_STATE(6804)] = 346171,
  [SMALL_STATE(6805)] = 346217,
  [SMALL_STATE(6806)] = 346257,
  [SMALL_STATE(6807)] = 346307,
  [SMALL_STATE(6808)] = 346353,
  [SMALL_STATE(6809)] = 346393,
  [SMALL_STATE(6810)] = 346435,
  [SMALL_STATE(6811)] = 346479,
  [SMALL_STATE(6812)] = 346519,
  [SMALL_STATE(6813)] = 346559,
  [SMALL_STATE(6814)] = 346601,
  [SMALL_STATE(6815)] = 346665,
  [SMALL_STATE(6816)] = 346705,
  [SMALL_STATE(6817)] = 346745,
  [SMALL_STATE(6818)] = 346785,
  [SMALL_STATE(6819)] = 346825,
  [SMALL_STATE(6820)] = 346865,
  [SMALL_STATE(6821)] = 346905,
  [SMALL_STATE(6822)] = 346955,
  [SMALL_STATE(6823)] = 346999,
  [SMALL_STATE(6824)] = 347039,
  [SMALL_STATE(6825)] = 347081,
  [SMALL_STATE(6826)] = 347123,
  [SMALL_STATE(6827)] = 347165,
  [SMALL_STATE(6828)] = 347229,
  [SMALL_STATE(6829)] = 347269,
  [SMALL_STATE(6830)] = 347309,
  [SMALL_STATE(6831)] = 347349,
  [SMALL_STATE(6832)] = 347389,
  [SMALL_STATE(6833)] = 347429,
  [SMALL_STATE(6834)] = 347481,
  [SMALL_STATE(6835)] = 347551,
  [SMALL_STATE(6836)] = 347591,
  [SMALL_STATE(6837)] = 347631,
  [SMALL_STATE(6838)] = 347671,
  [SMALL_STATE(6839)] = 347711,
  [SMALL_STATE(6840)] = 347751,
  [SMALL_STATE(6841)] = 347791,
  [SMALL_STATE(6842)] = 347831,
  [SMALL_STATE(6843)] = 347901,
  [SMALL_STATE(6844)] = 347941,
  [SMALL_STATE(6845)] = 348011,
  [SMALL_STATE(6846)] = 348051,
  [SMALL_STATE(6847)] = 348091,
  [SMALL_STATE(6848)] = 348131,
  [SMALL_STATE(6849)] = 348171,
  [SMALL_STATE(6850)] = 348211,
  [SMALL_STATE(6851)] = 348251,
  [SMALL_STATE(6852)] = 348291,
  [SMALL_STATE(6853)] = 348331,
  [SMALL_STATE(6854)] = 348375,
  [SMALL_STATE(6855)] = 348417,
  [SMALL_STATE(6856)] = 348457,
  [SMALL_STATE(6857)] = 348497,
  [SMALL_STATE(6858)] = 348539,
  [SMALL_STATE(6859)] = 348579,
  [SMALL_STATE(6860)] = 348619,
  [SMALL_STATE(6861)] = 348659,
  [SMALL_STATE(6862)] = 348699,
  [SMALL_STATE(6863)] = 348739,
  [SMALL_STATE(6864)] = 348779,
  [SMALL_STATE(6865)] = 348849,
  [SMALL_STATE(6866)] = 348889,
  [SMALL_STATE(6867)] = 348929,
  [SMALL_STATE(6868)] = 348969,
  [SMALL_STATE(6869)] = 349009,
  [SMALL_STATE(6870)] = 349049,
  [SMALL_STATE(6871)] = 349089,
  [SMALL_STATE(6872)] = 349129,
  [SMALL_STATE(6873)] = 349171,
  [SMALL_STATE(6874)] = 349215,
  [SMALL_STATE(6875)] = 349255,
  [SMALL_STATE(6876)] = 349295,
  [SMALL_STATE(6877)] = 349341,
  [SMALL_STATE(6878)] = 349381,
  [SMALL_STATE(6879)] = 349421,
  [SMALL_STATE(6880)] = 349475,
  [SMALL_STATE(6881)] = 349519,
  [SMALL_STATE(6882)] = 349559,
  [SMALL_STATE(6883)] = 349611,
  [SMALL_STATE(6884)] = 349651,
  [SMALL_STATE(6885)] = 349691,
  [SMALL_STATE(6886)] = 349731,
  [SMALL_STATE(6887)] = 349771,
  [SMALL_STATE(6888)] = 349841,
  [SMALL_STATE(6889)] = 349885,
  [SMALL_STATE(6890)] = 349925,
  [SMALL_STATE(6891)] = 349965,
  [SMALL_STATE(6892)] = 350005,
  [SMALL_STATE(6893)] = 350045,
  [SMALL_STATE(6894)] = 350085,
  [SMALL_STATE(6895)] = 350125,
  [SMALL_STATE(6896)] = 350167,
  [SMALL_STATE(6897)] = 350209,
  [SMALL_STATE(6898)] = 350275,
  [SMALL_STATE(6899)] = 350315,
  [SMALL_STATE(6900)] = 350355,
  [SMALL_STATE(6901)] = 350395,
  [SMALL_STATE(6902)] = 350437,
  [SMALL_STATE(6903)] = 350477,
  [SMALL_STATE(6904)] = 350517,
  [SMALL_STATE(6905)] = 350577,
  [SMALL_STATE(6906)] = 350647,
  [SMALL_STATE(6907)] = 350687,
  [SMALL_STATE(6908)] = 350727,
  [SMALL_STATE(6909)] = 350781,
  [SMALL_STATE(6910)] = 350821,
  [SMALL_STATE(6911)] = 350861,
  [SMALL_STATE(6912)] = 350901,
  [SMALL_STATE(6913)] = 350941,
  [SMALL_STATE(6914)] = 350981,
  [SMALL_STATE(6915)] = 351021,
  [SMALL_STATE(6916)] = 351061,
  [SMALL_STATE(6917)] = 351101,
  [SMALL_STATE(6918)] = 351141,
  [SMALL_STATE(6919)] = 351181,
  [SMALL_STATE(6920)] = 351221,
  [SMALL_STATE(6921)] = 351261,
  [SMALL_STATE(6922)] = 351301,
  [SMALL_STATE(6923)] = 351351,
  [SMALL_STATE(6924)] = 351391,
  [SMALL_STATE(6925)] = 351431,
  [SMALL_STATE(6926)] = 351471,
  [SMALL_STATE(6927)] = 351511,
  [SMALL_STATE(6928)] = 351553,
  [SMALL_STATE(6929)] = 351593,
  [SMALL_STATE(6930)] = 351635,
  [SMALL_STATE(6931)] = 351675,
  [SMALL_STATE(6932)] = 351715,
  [SMALL_STATE(6933)] = 351755,
  [SMALL_STATE(6934)] = 351795,
  [SMALL_STATE(6935)] = 351835,
  [SMALL_STATE(6936)] = 351875,
  [SMALL_STATE(6937)] = 351919,
  [SMALL_STATE(6938)] = 351961,
  [SMALL_STATE(6939)] = 352001,
  [SMALL_STATE(6940)] = 352043,
  [SMALL_STATE(6941)] = 352085,
  [SMALL_STATE(6942)] = 352155,
  [SMALL_STATE(6943)] = 352197,
  [SMALL_STATE(6944)] = 352237,
  [SMALL_STATE(6945)] = 352277,
  [SMALL_STATE(6946)] = 352317,
  [SMALL_STATE(6947)] = 352381,
  [SMALL_STATE(6948)] = 352421,
  [SMALL_STATE(6949)] = 352461,
  [SMALL_STATE(6950)] = 352501,
  [SMALL_STATE(6951)] = 352541,
  [SMALL_STATE(6952)] = 352581,
  [SMALL_STATE(6953)] = 352621,
  [SMALL_STATE(6954)] = 352661,
  [SMALL_STATE(6955)] = 352701,
  [SMALL_STATE(6956)] = 352741,
  [SMALL_STATE(6957)] = 352781,
  [SMALL_STATE(6958)] = 352821,
  [SMALL_STATE(6959)] = 352861,
  [SMALL_STATE(6960)] = 352901,
  [SMALL_STATE(6961)] = 352941,
  [SMALL_STATE(6962)] = 352981,
  [SMALL_STATE(6963)] = 353051,
  [SMALL_STATE(6964)] = 353091,
  [SMALL_STATE(6965)] = 353145,
  [SMALL_STATE(6966)] = 353185,
  [SMALL_STATE(6967)] = 353225,
  [SMALL_STATE(6968)] = 353265,
  [SMALL_STATE(6969)] = 353305,
  [SMALL_STATE(6970)] = 353345,
  [SMALL_STATE(6971)] = 353385,
  [SMALL_STATE(6972)] = 353425,
  [SMALL_STATE(6973)] = 353465,
  [SMALL_STATE(6974)] = 353505,
  [SMALL_STATE(6975)] = 353545,
  [SMALL_STATE(6976)] = 353585,
  [SMALL_STATE(6977)] = 353625,
  [SMALL_STATE(6978)] = 353665,
  [SMALL_STATE(6979)] = 353719,
  [SMALL_STATE(6980)] = 353759,
  [SMALL_STATE(6981)] = 353799,
  [SMALL_STATE(6982)] = 353849,
  [SMALL_STATE(6983)] = 353895,
  [SMALL_STATE(6984)] = 353935,
  [SMALL_STATE(6985)] = 353975,
  [SMALL_STATE(6986)] = 354039,
  [SMALL_STATE(6987)] = 354091,
  [SMALL_STATE(6988)] = 354131,
  [SMALL_STATE(6989)] = 354171,
  [SMALL_STATE(6990)] = 354211,
  [SMALL_STATE(6991)] = 354251,
  [SMALL_STATE(6992)] = 354291,
  [SMALL_STATE(6993)] = 354331,
  [SMALL_STATE(6994)] = 354373,
  [SMALL_STATE(6995)] = 354437,
  [SMALL_STATE(6996)] = 354477,
  [SMALL_STATE(6997)] = 354541,
  [SMALL_STATE(6998)] = 354581,
  [SMALL_STATE(6999)] = 354633,
  [SMALL_STATE(7000)] = 354673,
  [SMALL_STATE(7001)] = 354713,
  [SMALL_STATE(7002)] = 354753,
  [SMALL_STATE(7003)] = 354793,
  [SMALL_STATE(7004)] = 354833,
  [SMALL_STATE(7005)] = 354873,
  [SMALL_STATE(7006)] = 354923,
  [SMALL_STATE(7007)] = 354963,
  [SMALL_STATE(7008)] = 355003,
  [SMALL_STATE(7009)] = 355047,
  [SMALL_STATE(7010)] = 355087,
  [SMALL_STATE(7011)] = 355127,
  [SMALL_STATE(7012)] = 355169,
  [SMALL_STATE(7013)] = 355211,
  [SMALL_STATE(7014)] = 355251,
  [SMALL_STATE(7015)] = 355291,
  [SMALL_STATE(7016)] = 355331,
  [SMALL_STATE(7017)] = 355373,
  [SMALL_STATE(7018)] = 355415,
  [SMALL_STATE(7019)] = 355455,
  [SMALL_STATE(7020)] = 355509,
  [SMALL_STATE(7021)] = 355549,
  [SMALL_STATE(7022)] = 355589,
  [SMALL_STATE(7023)] = 355633,
  [SMALL_STATE(7024)] = 355679,
  [SMALL_STATE(7025)] = 355719,
  [SMALL_STATE(7026)] = 355759,
  [SMALL_STATE(7027)] = 355799,
  [SMALL_STATE(7028)] = 355839,
  [SMALL_STATE(7029)] = 355879,
  [SMALL_STATE(7030)] = 355931,
  [SMALL_STATE(7031)] = 355985,
  [SMALL_STATE(7032)] = 356025,
  [SMALL_STATE(7033)] = 356089,
  [SMALL_STATE(7034)] = 356133,
  [SMALL_STATE(7035)] = 356173,
  [SMALL_STATE(7036)] = 356237,
  [SMALL_STATE(7037)] = 356285,
  [SMALL_STATE(7038)] = 356325,
  [SMALL_STATE(7039)] = 356367,
  [SMALL_STATE(7040)] = 356413,
  [SMALL_STATE(7041)] = 356453,
  [SMALL_STATE(7042)] = 356493,
  [SMALL_STATE(7043)] = 356533,
  [SMALL_STATE(7044)] = 356573,
  [SMALL_STATE(7045)] = 356613,
  [SMALL_STATE(7046)] = 356653,
  [SMALL_STATE(7047)] = 356693,
  [SMALL_STATE(7048)] = 356737,
  [SMALL_STATE(7049)] = 356777,
  [SMALL_STATE(7050)] = 356823,
  [SMALL_STATE(7051)] = 356877,
  [SMALL_STATE(7052)] = 356917,
  [SMALL_STATE(7053)] = 356957,
  [SMALL_STATE(7054)] = 356997,
  [SMALL_STATE(7055)] = 357037,
  [SMALL_STATE(7056)] = 357077,
  [SMALL_STATE(7057)] = 357129,
  [SMALL_STATE(7058)] = 357169,
  [SMALL_STATE(7059)] = 357209,
  [SMALL_STATE(7060)] = 357251,
  [SMALL_STATE(7061)] = 357321,
  [SMALL_STATE(7062)] = 357363,
  [SMALL_STATE(7063)] = 357403,
  [SMALL_STATE(7064)] = 357445,
  [SMALL_STATE(7065)] = 357497,
  [SMALL_STATE(7066)] = 357541,
  [SMALL_STATE(7067)] = 357583,
  [SMALL_STATE(7068)] = 357623,
  [SMALL_STATE(7069)] = 357663,
  [SMALL_STATE(7070)] = 357703,
  [SMALL_STATE(7071)] = 357743,
  [SMALL_STATE(7072)] = 357783,
  [SMALL_STATE(7073)] = 357823,
  [SMALL_STATE(7074)] = 357867,
  [SMALL_STATE(7075)] = 357907,
  [SMALL_STATE(7076)] = 357961,
  [SMALL_STATE(7077)] = 358001,
  [SMALL_STATE(7078)] = 358047,
  [SMALL_STATE(7079)] = 358087,
  [SMALL_STATE(7080)] = 358127,
  [SMALL_STATE(7081)] = 358167,
  [SMALL_STATE(7082)] = 358207,
  [SMALL_STATE(7083)] = 358247,
  [SMALL_STATE(7084)] = 358317,
  [SMALL_STATE(7085)] = 358357,
  [SMALL_STATE(7086)] = 358409,
  [SMALL_STATE(7087)] = 358449,
  [SMALL_STATE(7088)] = 358489,
  [SMALL_STATE(7089)] = 358549,
  [SMALL_STATE(7090)] = 358589,
  [SMALL_STATE(7091)] = 358631,
  [SMALL_STATE(7092)] = 358673,
  [SMALL_STATE(7093)] = 358713,
  [SMALL_STATE(7094)] = 358757,
  [SMALL_STATE(7095)] = 358805,
  [SMALL_STATE(7096)] = 358847,
  [SMALL_STATE(7097)] = 358887,
  [SMALL_STATE(7098)] = 358931,
  [SMALL_STATE(7099)] = 358971,
  [SMALL_STATE(7100)] = 359031,
  [SMALL_STATE(7101)] = 359077,
  [SMALL_STATE(7102)] = 359117,
  [SMALL_STATE(7103)] = 359163,
  [SMALL_STATE(7104)] = 359205,
  [SMALL_STATE(7105)] = 359245,
  [SMALL_STATE(7106)] = 359285,
  [SMALL_STATE(7107)] = 359329,
  [SMALL_STATE(7108)] = 359381,
  [SMALL_STATE(7109)] = 359421,
  [SMALL_STATE(7110)] = 359461,
  [SMALL_STATE(7111)] = 359507,
  [SMALL_STATE(7112)] = 359547,
  [SMALL_STATE(7113)] = 359587,
  [SMALL_STATE(7114)] = 359629,
  [SMALL_STATE(7115)] = 359669,
  [SMALL_STATE(7116)] = 359709,
  [SMALL_STATE(7117)] = 359761,
  [SMALL_STATE(7118)] = 359801,
  [SMALL_STATE(7119)] = 359841,
  [SMALL_STATE(7120)] = 359881,
  [SMALL_STATE(7121)] = 359925,
  [SMALL_STATE(7122)] = 359965,
  [SMALL_STATE(7123)] = 360007,
  [SMALL_STATE(7124)] = 360057,
  [SMALL_STATE(7125)] = 360101,
  [SMALL_STATE(7126)] = 360143,
  [SMALL_STATE(7127)] = 360187,
  [SMALL_STATE(7128)] = 360227,
  [SMALL_STATE(7129)] = 360267,
  [SMALL_STATE(7130)] = 360307,
  [SMALL_STATE(7131)] = 360347,
  [SMALL_STATE(7132)] = 360393,
  [SMALL_STATE(7133)] = 360433,
  [SMALL_STATE(7134)] = 360503,
  [SMALL_STATE(7135)] = 360543,
  [SMALL_STATE(7136)] = 360583,
  [SMALL_STATE(7137)] = 360623,
  [SMALL_STATE(7138)] = 360663,
  [SMALL_STATE(7139)] = 360703,
  [SMALL_STATE(7140)] = 360743,
  [SMALL_STATE(7141)] = 360783,
  [SMALL_STATE(7142)] = 360823,
  [SMALL_STATE(7143)] = 360863,
  [SMALL_STATE(7144)] = 360903,
  [SMALL_STATE(7145)] = 360957,
  [SMALL_STATE(7146)] = 360997,
  [SMALL_STATE(7147)] = 361037,
  [SMALL_STATE(7148)] = 361077,
  [SMALL_STATE(7149)] = 361117,
  [SMALL_STATE(7150)] = 361157,
  [SMALL_STATE(7151)] = 361197,
  [SMALL_STATE(7152)] = 361237,
  [SMALL_STATE(7153)] = 361277,
  [SMALL_STATE(7154)] = 361317,
  [SMALL_STATE(7155)] = 361363,
  [SMALL_STATE(7156)] = 361403,
  [SMALL_STATE(7157)] = 361443,
  [SMALL_STATE(7158)] = 361483,
  [SMALL_STATE(7159)] = 361523,
  [SMALL_STATE(7160)] = 361577,
  [SMALL_STATE(7161)] = 361623,
  [SMALL_STATE(7162)] = 361667,
  [SMALL_STATE(7163)] = 361707,
  [SMALL_STATE(7164)] = 361747,
  [SMALL_STATE(7165)] = 361791,
  [SMALL_STATE(7166)] = 361831,
  [SMALL_STATE(7167)] = 361871,
  [SMALL_STATE(7168)] = 361911,
  [SMALL_STATE(7169)] = 361951,
  [SMALL_STATE(7170)] = 361991,
  [SMALL_STATE(7171)] = 362031,
  [SMALL_STATE(7172)] = 362071,
  [SMALL_STATE(7173)] = 362111,
  [SMALL_STATE(7174)] = 362151,
  [SMALL_STATE(7175)] = 362191,
  [SMALL_STATE(7176)] = 362251,
  [SMALL_STATE(7177)] = 362291,
  [SMALL_STATE(7178)] = 362331,
  [SMALL_STATE(7179)] = 362379,
  [SMALL_STATE(7180)] = 362423,
  [SMALL_STATE(7181)] = 362463,
  [SMALL_STATE(7182)] = 362503,
  [SMALL_STATE(7183)] = 362543,
  [SMALL_STATE(7184)] = 362583,
  [SMALL_STATE(7185)] = 362623,
  [SMALL_STATE(7186)] = 362663,
  [SMALL_STATE(7187)] = 362703,
  [SMALL_STATE(7188)] = 362745,
  [SMALL_STATE(7189)] = 362785,
  [SMALL_STATE(7190)] = 362825,
  [SMALL_STATE(7191)] = 362869,
  [SMALL_STATE(7192)] = 362909,
  [SMALL_STATE(7193)] = 362949,
  [SMALL_STATE(7194)] = 362989,
  [SMALL_STATE(7195)] = 363029,
  [SMALL_STATE(7196)] = 363069,
  [SMALL_STATE(7197)] = 363115,
  [SMALL_STATE(7198)] = 363157,
  [SMALL_STATE(7199)] = 363197,
  [SMALL_STATE(7200)] = 363237,
  [SMALL_STATE(7201)] = 363277,
  [SMALL_STATE(7202)] = 363317,
  [SMALL_STATE(7203)] = 363357,
  [SMALL_STATE(7204)] = 363397,
  [SMALL_STATE(7205)] = 363437,
  [SMALL_STATE(7206)] = 363477,
  [SMALL_STATE(7207)] = 363517,
  [SMALL_STATE(7208)] = 363559,
  [SMALL_STATE(7209)] = 363599,
  [SMALL_STATE(7210)] = 363639,
  [SMALL_STATE(7211)] = 363683,
  [SMALL_STATE(7212)] = 363723,
  [SMALL_STATE(7213)] = 363769,
  [SMALL_STATE(7214)] = 363815,
  [SMALL_STATE(7215)] = 363855,
  [SMALL_STATE(7216)] = 363895,
  [SMALL_STATE(7217)] = 363935,
  [SMALL_STATE(7218)] = 363977,
  [SMALL_STATE(7219)] = 364017,
  [SMALL_STATE(7220)] = 364057,
  [SMALL_STATE(7221)] = 364097,
  [SMALL_STATE(7222)] = 364137,
  [SMALL_STATE(7223)] = 364177,
  [SMALL_STATE(7224)] = 364217,
  [SMALL_STATE(7225)] = 364263,
  [SMALL_STATE(7226)] = 364307,
  [SMALL_STATE(7227)] = 364347,
  [SMALL_STATE(7228)] = 364387,
  [SMALL_STATE(7229)] = 364427,
  [SMALL_STATE(7230)] = 364467,
  [SMALL_STATE(7231)] = 364525,
  [SMALL_STATE(7232)] = 364565,
  [SMALL_STATE(7233)] = 364605,
  [SMALL_STATE(7234)] = 364645,
  [SMALL_STATE(7235)] = 364685,
  [SMALL_STATE(7236)] = 364725,
  [SMALL_STATE(7237)] = 364765,
  [SMALL_STATE(7238)] = 364805,
  [SMALL_STATE(7239)] = 364847,
  [SMALL_STATE(7240)] = 364889,
  [SMALL_STATE(7241)] = 364929,
  [SMALL_STATE(7242)] = 364969,
  [SMALL_STATE(7243)] = 365009,
  [SMALL_STATE(7244)] = 365049,
  [SMALL_STATE(7245)] = 365101,
  [SMALL_STATE(7246)] = 365141,
  [SMALL_STATE(7247)] = 365181,
  [SMALL_STATE(7248)] = 365221,
  [SMALL_STATE(7249)] = 365281,
  [SMALL_STATE(7250)] = 365321,
  [SMALL_STATE(7251)] = 365361,
  [SMALL_STATE(7252)] = 365401,
  [SMALL_STATE(7253)] = 365441,
  [SMALL_STATE(7254)] = 365481,
  [SMALL_STATE(7255)] = 365521,
  [SMALL_STATE(7256)] = 365573,
  [SMALL_STATE(7257)] = 365613,
  [SMALL_STATE(7258)] = 365653,
  [SMALL_STATE(7259)] = 365693,
  [SMALL_STATE(7260)] = 365735,
  [SMALL_STATE(7261)] = 365799,
  [SMALL_STATE(7262)] = 365839,
  [SMALL_STATE(7263)] = 365879,
  [SMALL_STATE(7264)] = 365919,
  [SMALL_STATE(7265)] = 365959,
  [SMALL_STATE(7266)] = 365999,
  [SMALL_STATE(7267)] = 366039,
  [SMALL_STATE(7268)] = 366083,
  [SMALL_STATE(7269)] = 366135,
  [SMALL_STATE(7270)] = 366175,
  [SMALL_STATE(7271)] = 366215,
  [SMALL_STATE(7272)] = 366255,
  [SMALL_STATE(7273)] = 366295,
  [SMALL_STATE(7274)] = 366353,
  [SMALL_STATE(7275)] = 366395,
  [SMALL_STATE(7276)] = 366435,
  [SMALL_STATE(7277)] = 366475,
  [SMALL_STATE(7278)] = 366515,
  [SMALL_STATE(7279)] = 366569,
  [SMALL_STATE(7280)] = 366609,
  [SMALL_STATE(7281)] = 366649,
  [SMALL_STATE(7282)] = 366701,
  [SMALL_STATE(7283)] = 366741,
  [SMALL_STATE(7284)] = 366785,
  [SMALL_STATE(7285)] = 366825,
  [SMALL_STATE(7286)] = 366865,
  [SMALL_STATE(7287)] = 366905,
  [SMALL_STATE(7288)] = 366947,
  [SMALL_STATE(7289)] = 366987,
  [SMALL_STATE(7290)] = 367029,
  [SMALL_STATE(7291)] = 367069,
  [SMALL_STATE(7292)] = 367113,
  [SMALL_STATE(7293)] = 367153,
  [SMALL_STATE(7294)] = 367223,
  [SMALL_STATE(7295)] = 367287,
  [SMALL_STATE(7296)] = 367339,
  [SMALL_STATE(7297)] = 367379,
  [SMALL_STATE(7298)] = 367419,
  [SMALL_STATE(7299)] = 367459,
  [SMALL_STATE(7300)] = 367499,
  [SMALL_STATE(7301)] = 367545,
  [SMALL_STATE(7302)] = 367585,
  [SMALL_STATE(7303)] = 367625,
  [SMALL_STATE(7304)] = 367665,
  [SMALL_STATE(7305)] = 367717,
  [SMALL_STATE(7306)] = 367757,
  [SMALL_STATE(7307)] = 367797,
  [SMALL_STATE(7308)] = 367837,
  [SMALL_STATE(7309)] = 367877,
  [SMALL_STATE(7310)] = 367917,
  [SMALL_STATE(7311)] = 367957,
  [SMALL_STATE(7312)] = 367997,
  [SMALL_STATE(7313)] = 368037,
  [SMALL_STATE(7314)] = 368077,
  [SMALL_STATE(7315)] = 368117,
  [SMALL_STATE(7316)] = 368157,
  [SMALL_STATE(7317)] = 368197,
  [SMALL_STATE(7318)] = 368237,
  [SMALL_STATE(7319)] = 368277,
  [SMALL_STATE(7320)] = 368317,
  [SMALL_STATE(7321)] = 368357,
  [SMALL_STATE(7322)] = 368397,
  [SMALL_STATE(7323)] = 368437,
  [SMALL_STATE(7324)] = 368479,
  [SMALL_STATE(7325)] = 368519,
  [SMALL_STATE(7326)] = 368579,
  [SMALL_STATE(7327)] = 368619,
  [SMALL_STATE(7328)] = 368659,
  [SMALL_STATE(7329)] = 368703,
  [SMALL_STATE(7330)] = 368767,
  [SMALL_STATE(7331)] = 368807,
  [SMALL_STATE(7332)] = 368847,
  [SMALL_STATE(7333)] = 368907,
  [SMALL_STATE(7334)] = 368947,
  [SMALL_STATE(7335)] = 368987,
  [SMALL_STATE(7336)] = 369027,
  [SMALL_STATE(7337)] = 369067,
  [SMALL_STATE(7338)] = 369107,
  [SMALL_STATE(7339)] = 369147,
  [SMALL_STATE(7340)] = 369187,
  [SMALL_STATE(7341)] = 369227,
  [SMALL_STATE(7342)] = 369267,
  [SMALL_STATE(7343)] = 369307,
  [SMALL_STATE(7344)] = 369347,
  [SMALL_STATE(7345)] = 369387,
  [SMALL_STATE(7346)] = 369427,
  [SMALL_STATE(7347)] = 369467,
  [SMALL_STATE(7348)] = 369507,
  [SMALL_STATE(7349)] = 369549,
  [SMALL_STATE(7350)] = 369589,
  [SMALL_STATE(7351)] = 369629,
  [SMALL_STATE(7352)] = 369683,
  [SMALL_STATE(7353)] = 369725,
  [SMALL_STATE(7354)] = 369765,
  [SMALL_STATE(7355)] = 369805,
  [SMALL_STATE(7356)] = 369847,
  [SMALL_STATE(7357)] = 369887,
  [SMALL_STATE(7358)] = 369929,
  [SMALL_STATE(7359)] = 369969,
  [SMALL_STATE(7360)] = 370009,
  [SMALL_STATE(7361)] = 370049,
  [SMALL_STATE(7362)] = 370089,
  [SMALL_STATE(7363)] = 370159,
  [SMALL_STATE(7364)] = 370199,
  [SMALL_STATE(7365)] = 370239,
  [SMALL_STATE(7366)] = 370279,
  [SMALL_STATE(7367)] = 370319,
  [SMALL_STATE(7368)] = 370363,
  [SMALL_STATE(7369)] = 370409,
  [SMALL_STATE(7370)] = 370449,
  [SMALL_STATE(7371)] = 370495,
  [SMALL_STATE(7372)] = 370537,
  [SMALL_STATE(7373)] = 370583,
  [SMALL_STATE(7374)] = 370625,
  [SMALL_STATE(7375)] = 370689,
  [SMALL_STATE(7376)] = 370729,
  [SMALL_STATE(7377)] = 370769,
  [SMALL_STATE(7378)] = 370809,
  [SMALL_STATE(7379)] = 370849,
  [SMALL_STATE(7380)] = 370889,
  [SMALL_STATE(7381)] = 370929,
  [SMALL_STATE(7382)] = 370969,
  [SMALL_STATE(7383)] = 371009,
  [SMALL_STATE(7384)] = 371053,
  [SMALL_STATE(7385)] = 371093,
  [SMALL_STATE(7386)] = 371133,
  [SMALL_STATE(7387)] = 371179,
  [SMALL_STATE(7388)] = 371223,
  [SMALL_STATE(7389)] = 371271,
  [SMALL_STATE(7390)] = 371311,
  [SMALL_STATE(7391)] = 371363,
  [SMALL_STATE(7392)] = 371403,
  [SMALL_STATE(7393)] = 371445,
  [SMALL_STATE(7394)] = 371499,
  [SMALL_STATE(7395)] = 371539,
  [SMALL_STATE(7396)] = 371589,
  [SMALL_STATE(7397)] = 371629,
  [SMALL_STATE(7398)] = 371669,
  [SMALL_STATE(7399)] = 371709,
  [SMALL_STATE(7400)] = 371749,
  [SMALL_STATE(7401)] = 371789,
  [SMALL_STATE(7402)] = 371829,
  [SMALL_STATE(7403)] = 371871,
  [SMALL_STATE(7404)] = 371911,
  [SMALL_STATE(7405)] = 371957,
  [SMALL_STATE(7406)] = 371997,
  [SMALL_STATE(7407)] = 372037,
  [SMALL_STATE(7408)] = 372077,
  [SMALL_STATE(7409)] = 372119,
  [SMALL_STATE(7410)] = 372157,
  [SMALL_STATE(7411)] = 372199,
  [SMALL_STATE(7412)] = 372239,
  [SMALL_STATE(7413)] = 372295,
  [SMALL_STATE(7414)] = 372335,
  [SMALL_STATE(7415)] = 372379,
  [SMALL_STATE(7416)] = 372419,
  [SMALL_STATE(7417)] = 372461,
  [SMALL_STATE(7418)] = 372499,
  [SMALL_STATE(7419)] = 372541,
  [SMALL_STATE(7420)] = 372581,
  [SMALL_STATE(7421)] = 372625,
  [SMALL_STATE(7422)] = 372671,
  [SMALL_STATE(7423)] = 372711,
  [SMALL_STATE(7424)] = 372751,
  [SMALL_STATE(7425)] = 372791,
  [SMALL_STATE(7426)] = 372837,
  [SMALL_STATE(7427)] = 372877,
  [SMALL_STATE(7428)] = 372917,
  [SMALL_STATE(7429)] = 372957,
  [SMALL_STATE(7430)] = 372997,
  [SMALL_STATE(7431)] = 373037,
  [SMALL_STATE(7432)] = 373077,
  [SMALL_STATE(7433)] = 373117,
  [SMALL_STATE(7434)] = 373157,
  [SMALL_STATE(7435)] = 373197,
  [SMALL_STATE(7436)] = 373237,
  [SMALL_STATE(7437)] = 373283,
  [SMALL_STATE(7438)] = 373323,
  [SMALL_STATE(7439)] = 373363,
  [SMALL_STATE(7440)] = 373403,
  [SMALL_STATE(7441)] = 373443,
  [SMALL_STATE(7442)] = 373483,
  [SMALL_STATE(7443)] = 373523,
  [SMALL_STATE(7444)] = 373563,
  [SMALL_STATE(7445)] = 373603,
  [SMALL_STATE(7446)] = 373643,
  [SMALL_STATE(7447)] = 373685,
  [SMALL_STATE(7448)] = 373725,
  [SMALL_STATE(7449)] = 373765,
  [SMALL_STATE(7450)] = 373805,
  [SMALL_STATE(7451)] = 373845,
  [SMALL_STATE(7452)] = 373885,
  [SMALL_STATE(7453)] = 373923,
  [SMALL_STATE(7454)] = 373963,
  [SMALL_STATE(7455)] = 374003,
  [SMALL_STATE(7456)] = 374043,
  [SMALL_STATE(7457)] = 374083,
  [SMALL_STATE(7458)] = 374123,
  [SMALL_STATE(7459)] = 374163,
  [SMALL_STATE(7460)] = 374205,
  [SMALL_STATE(7461)] = 374245,
  [SMALL_STATE(7462)] = 374299,
  [SMALL_STATE(7463)] = 374339,
  [SMALL_STATE(7464)] = 374379,
  [SMALL_STATE(7465)] = 374419,
  [SMALL_STATE(7466)] = 374459,
  [SMALL_STATE(7467)] = 374511,
  [SMALL_STATE(7468)] = 374551,
  [SMALL_STATE(7469)] = 374591,
  [SMALL_STATE(7470)] = 374631,
  [SMALL_STATE(7471)] = 374671,
  [SMALL_STATE(7472)] = 374725,
  [SMALL_STATE(7473)] = 374765,
  [SMALL_STATE(7474)] = 374805,
  [SMALL_STATE(7475)] = 374845,
  [SMALL_STATE(7476)] = 374885,
  [SMALL_STATE(7477)] = 374925,
  [SMALL_STATE(7478)] = 374965,
  [SMALL_STATE(7479)] = 375005,
  [SMALL_STATE(7480)] = 375047,
  [SMALL_STATE(7481)] = 375089,
  [SMALL_STATE(7482)] = 375129,
  [SMALL_STATE(7483)] = 375169,
  [SMALL_STATE(7484)] = 375209,
  [SMALL_STATE(7485)] = 375249,
  [SMALL_STATE(7486)] = 375289,
  [SMALL_STATE(7487)] = 375331,
  [SMALL_STATE(7488)] = 375391,
  [SMALL_STATE(7489)] = 375435,
  [SMALL_STATE(7490)] = 375487,
  [SMALL_STATE(7491)] = 375527,
  [SMALL_STATE(7492)] = 375567,
  [SMALL_STATE(7493)] = 375607,
  [SMALL_STATE(7494)] = 375647,
  [SMALL_STATE(7495)] = 375703,
  [SMALL_STATE(7496)] = 375745,
  [SMALL_STATE(7497)] = 375785,
  [SMALL_STATE(7498)] = 375825,
  [SMALL_STATE(7499)] = 375865,
  [SMALL_STATE(7500)] = 375905,
  [SMALL_STATE(7501)] = 375945,
  [SMALL_STATE(7502)] = 375985,
  [SMALL_STATE(7503)] = 376024,
  [SMALL_STATE(7504)] = 376063,
  [SMALL_STATE(7505)] = 376102,
  [SMALL_STATE(7506)] = 376141,
  [SMALL_STATE(7507)] = 376180,
  [SMALL_STATE(7508)] = 376219,
  [SMALL_STATE(7509)] = 376272,
  [SMALL_STATE(7510)] = 376311,
  [SMALL_STATE(7511)] = 376372,
  [SMALL_STATE(7512)] = 376411,
  [SMALL_STATE(7513)] = 376464,
  [SMALL_STATE(7514)] = 376505,
  [SMALL_STATE(7515)] = 376544,
  [SMALL_STATE(7516)] = 376591,
  [SMALL_STATE(7517)] = 376644,
  [SMALL_STATE(7518)] = 376695,
  [SMALL_STATE(7519)] = 376734,
  [SMALL_STATE(7520)] = 376779,
  [SMALL_STATE(7521)] = 376818,
  [SMALL_STATE(7522)] = 376857,
  [SMALL_STATE(7523)] = 376896,
  [SMALL_STATE(7524)] = 376935,
  [SMALL_STATE(7525)] = 376974,
  [SMALL_STATE(7526)] = 377013,
  [SMALL_STATE(7527)] = 377074,
  [SMALL_STATE(7528)] = 377113,
  [SMALL_STATE(7529)] = 377152,
  [SMALL_STATE(7530)] = 377191,
  [SMALL_STATE(7531)] = 377230,
  [SMALL_STATE(7532)] = 377269,
  [SMALL_STATE(7533)] = 377308,
  [SMALL_STATE(7534)] = 377359,
  [SMALL_STATE(7535)] = 377400,
  [SMALL_STATE(7536)] = 377439,
  [SMALL_STATE(7537)] = 377512,
  [SMALL_STATE(7538)] = 377551,
  [SMALL_STATE(7539)] = 377590,
  [SMALL_STATE(7540)] = 377629,
  [SMALL_STATE(7541)] = 377668,
  [SMALL_STATE(7542)] = 377707,
  [SMALL_STATE(7543)] = 377746,
  [SMALL_STATE(7544)] = 377785,
  [SMALL_STATE(7545)] = 377846,
  [SMALL_STATE(7546)] = 377885,
  [SMALL_STATE(7547)] = 377928,
  [SMALL_STATE(7548)] = 377967,
  [SMALL_STATE(7549)] = 378012,
  [SMALL_STATE(7550)] = 378051,
  [SMALL_STATE(7551)] = 378090,
  [SMALL_STATE(7552)] = 378129,
  [SMALL_STATE(7553)] = 378168,
  [SMALL_STATE(7554)] = 378229,
  [SMALL_STATE(7555)] = 378268,
  [SMALL_STATE(7556)] = 378307,
  [SMALL_STATE(7557)] = 378350,
  [SMALL_STATE(7558)] = 378389,
  [SMALL_STATE(7559)] = 378428,
  [SMALL_STATE(7560)] = 378467,
  [SMALL_STATE(7561)] = 378506,
  [SMALL_STATE(7562)] = 378545,
  [SMALL_STATE(7563)] = 378584,
  [SMALL_STATE(7564)] = 378623,
  [SMALL_STATE(7565)] = 378662,
  [SMALL_STATE(7566)] = 378701,
  [SMALL_STATE(7567)] = 378740,
  [SMALL_STATE(7568)] = 378785,
  [SMALL_STATE(7569)] = 378824,
  [SMALL_STATE(7570)] = 378863,
  [SMALL_STATE(7571)] = 378902,
  [SMALL_STATE(7572)] = 378941,
  [SMALL_STATE(7573)] = 379002,
  [SMALL_STATE(7574)] = 379041,
  [SMALL_STATE(7575)] = 379080,
  [SMALL_STATE(7576)] = 379119,
  [SMALL_STATE(7577)] = 379180,
  [SMALL_STATE(7578)] = 379219,
  [SMALL_STATE(7579)] = 379258,
  [SMALL_STATE(7580)] = 379319,
  [SMALL_STATE(7581)] = 379362,
  [SMALL_STATE(7582)] = 379401,
  [SMALL_STATE(7583)] = 379440,
  [SMALL_STATE(7584)] = 379479,
  [SMALL_STATE(7585)] = 379518,
  [SMALL_STATE(7586)] = 379557,
  [SMALL_STATE(7587)] = 379610,
  [SMALL_STATE(7588)] = 379651,
  [SMALL_STATE(7589)] = 379690,
  [SMALL_STATE(7590)] = 379729,
  [SMALL_STATE(7591)] = 379768,
  [SMALL_STATE(7592)] = 379807,
  [SMALL_STATE(7593)] = 379846,
  [SMALL_STATE(7594)] = 379899,
  [SMALL_STATE(7595)] = 379938,
  [SMALL_STATE(7596)] = 379977,
  [SMALL_STATE(7597)] = 380016,
  [SMALL_STATE(7598)] = 380055,
  [SMALL_STATE(7599)] = 380094,
  [SMALL_STATE(7600)] = 380133,
  [SMALL_STATE(7601)] = 380172,
  [SMALL_STATE(7602)] = 380211,
  [SMALL_STATE(7603)] = 380274,
  [SMALL_STATE(7604)] = 380313,
  [SMALL_STATE(7605)] = 380366,
  [SMALL_STATE(7606)] = 380405,
  [SMALL_STATE(7607)] = 380448,
  [SMALL_STATE(7608)] = 380509,
  [SMALL_STATE(7609)] = 380560,
  [SMALL_STATE(7610)] = 380601,
  [SMALL_STATE(7611)] = 380640,
  [SMALL_STATE(7612)] = 380679,
  [SMALL_STATE(7613)] = 380718,
  [SMALL_STATE(7614)] = 380779,
  [SMALL_STATE(7615)] = 380818,
  [SMALL_STATE(7616)] = 380859,
  [SMALL_STATE(7617)] = 380898,
  [SMALL_STATE(7618)] = 380937,
  [SMALL_STATE(7619)] = 380988,
  [SMALL_STATE(7620)] = 381029,
  [SMALL_STATE(7621)] = 381068,
  [SMALL_STATE(7622)] = 381107,
  [SMALL_STATE(7623)] = 381152,
  [SMALL_STATE(7624)] = 381213,
  [SMALL_STATE(7625)] = 381258,
  [SMALL_STATE(7626)] = 381299,
  [SMALL_STATE(7627)] = 381360,
  [SMALL_STATE(7628)] = 381407,
  [SMALL_STATE(7629)] = 381446,
  [SMALL_STATE(7630)] = 381485,
  [SMALL_STATE(7631)] = 381524,
  [SMALL_STATE(7632)] = 381585,
  [SMALL_STATE(7633)] = 381626,
  [SMALL_STATE(7634)] = 381665,
  [SMALL_STATE(7635)] = 381726,
  [SMALL_STATE(7636)] = 381765,
  [SMALL_STATE(7637)] = 381804,
  [SMALL_STATE(7638)] = 381845,
  [SMALL_STATE(7639)] = 381884,
  [SMALL_STATE(7640)] = 381945,
  [SMALL_STATE(7641)] = 381986,
  [SMALL_STATE(7642)] = 382025,
  [SMALL_STATE(7643)] = 382064,
  [SMALL_STATE(7644)] = 382125,
  [SMALL_STATE(7645)] = 382164,
  [SMALL_STATE(7646)] = 382203,
  [SMALL_STATE(7647)] = 382264,
  [SMALL_STATE(7648)] = 382305,
  [SMALL_STATE(7649)] = 382356,
  [SMALL_STATE(7650)] = 382395,
  [SMALL_STATE(7651)] = 382434,
  [SMALL_STATE(7652)] = 382473,
  [SMALL_STATE(7653)] = 382512,
  [SMALL_STATE(7654)] = 382551,
  [SMALL_STATE(7655)] = 382612,
  [SMALL_STATE(7656)] = 382673,
  [SMALL_STATE(7657)] = 382712,
  [SMALL_STATE(7658)] = 382765,
  [SMALL_STATE(7659)] = 382804,
  [SMALL_STATE(7660)] = 382865,
  [SMALL_STATE(7661)] = 382904,
  [SMALL_STATE(7662)] = 382943,
  [SMALL_STATE(7663)] = 382982,
  [SMALL_STATE(7664)] = 383043,
  [SMALL_STATE(7665)] = 383082,
  [SMALL_STATE(7666)] = 383121,
  [SMALL_STATE(7667)] = 383164,
  [SMALL_STATE(7668)] = 383203,
  [SMALL_STATE(7669)] = 383242,
  [SMALL_STATE(7670)] = 383281,
  [SMALL_STATE(7671)] = 383320,
  [SMALL_STATE(7672)] = 383361,
  [SMALL_STATE(7673)] = 383404,
  [SMALL_STATE(7674)] = 383465,
  [SMALL_STATE(7675)] = 383504,
  [SMALL_STATE(7676)] = 383545,
  [SMALL_STATE(7677)] = 383584,
  [SMALL_STATE(7678)] = 383629,
  [SMALL_STATE(7679)] = 383690,
  [SMALL_STATE(7680)] = 383729,
  [SMALL_STATE(7681)] = 383768,
  [SMALL_STATE(7682)] = 383807,
  [SMALL_STATE(7683)] = 383846,
  [SMALL_STATE(7684)] = 383885,
  [SMALL_STATE(7685)] = 383924,
  [SMALL_STATE(7686)] = 383963,
  [SMALL_STATE(7687)] = 384002,
  [SMALL_STATE(7688)] = 384043,
  [SMALL_STATE(7689)] = 384104,
  [SMALL_STATE(7690)] = 384143,
  [SMALL_STATE(7691)] = 384188,
  [SMALL_STATE(7692)] = 384227,
  [SMALL_STATE(7693)] = 384266,
  [SMALL_STATE(7694)] = 384305,
  [SMALL_STATE(7695)] = 384344,
  [SMALL_STATE(7696)] = 384387,
  [SMALL_STATE(7697)] = 384448,
  [SMALL_STATE(7698)] = 384487,
  [SMALL_STATE(7699)] = 384528,
  [SMALL_STATE(7700)] = 384571,
  [SMALL_STATE(7701)] = 384610,
  [SMALL_STATE(7702)] = 384671,
  [SMALL_STATE(7703)] = 384710,
  [SMALL_STATE(7704)] = 384749,
  [SMALL_STATE(7705)] = 384788,
  [SMALL_STATE(7706)] = 384827,
  [SMALL_STATE(7707)] = 384888,
  [SMALL_STATE(7708)] = 384927,
  [SMALL_STATE(7709)] = 384966,
  [SMALL_STATE(7710)] = 385005,
  [SMALL_STATE(7711)] = 385044,
  [SMALL_STATE(7712)] = 385083,
  [SMALL_STATE(7713)] = 385122,
  [SMALL_STATE(7714)] = 385165,
  [SMALL_STATE(7715)] = 385208,
  [SMALL_STATE(7716)] = 385247,
  [SMALL_STATE(7717)] = 385286,
  [SMALL_STATE(7718)] = 385325,
  [SMALL_STATE(7719)] = 385386,
  [SMALL_STATE(7720)] = 385425,
  [SMALL_STATE(7721)] = 385464,
  [SMALL_STATE(7722)] = 385509,
  [SMALL_STATE(7723)] = 385548,
  [SMALL_STATE(7724)] = 385587,
  [SMALL_STATE(7725)] = 385648,
  [SMALL_STATE(7726)] = 385687,
  [SMALL_STATE(7727)] = 385726,
  [SMALL_STATE(7728)] = 385765,
  [SMALL_STATE(7729)] = 385808,
  [SMALL_STATE(7730)] = 385847,
  [SMALL_STATE(7731)] = 385888,
  [SMALL_STATE(7732)] = 385929,
  [SMALL_STATE(7733)] = 385968,
  [SMALL_STATE(7734)] = 386007,
  [SMALL_STATE(7735)] = 386046,
  [SMALL_STATE(7736)] = 386119,
  [SMALL_STATE(7737)] = 386192,
  [SMALL_STATE(7738)] = 386253,
  [SMALL_STATE(7739)] = 386292,
  [SMALL_STATE(7740)] = 386331,
  [SMALL_STATE(7741)] = 386372,
  [SMALL_STATE(7742)] = 386411,
  [SMALL_STATE(7743)] = 386450,
  [SMALL_STATE(7744)] = 386489,
  [SMALL_STATE(7745)] = 386550,
  [SMALL_STATE(7746)] = 386589,
  [SMALL_STATE(7747)] = 386628,
  [SMALL_STATE(7748)] = 386667,
  [SMALL_STATE(7749)] = 386706,
  [SMALL_STATE(7750)] = 386745,
  [SMALL_STATE(7751)] = 386812,
  [SMALL_STATE(7752)] = 386873,
  [SMALL_STATE(7753)] = 386912,
  [SMALL_STATE(7754)] = 386953,
  [SMALL_STATE(7755)] = 386992,
  [SMALL_STATE(7756)] = 387039,
  [SMALL_STATE(7757)] = 387078,
  [SMALL_STATE(7758)] = 387119,
  [SMALL_STATE(7759)] = 387158,
  [SMALL_STATE(7760)] = 387197,
  [SMALL_STATE(7761)] = 387242,
  [SMALL_STATE(7762)] = 387281,
  [SMALL_STATE(7763)] = 387320,
  [SMALL_STATE(7764)] = 387359,
  [SMALL_STATE(7765)] = 387398,
  [SMALL_STATE(7766)] = 387439,
  [SMALL_STATE(7767)] = 387478,
  [SMALL_STATE(7768)] = 387517,
  [SMALL_STATE(7769)] = 387560,
  [SMALL_STATE(7770)] = 387599,
  [SMALL_STATE(7771)] = 387638,
  [SMALL_STATE(7772)] = 387677,
  [SMALL_STATE(7773)] = 387722,
  [SMALL_STATE(7774)] = 387775,
  [SMALL_STATE(7775)] = 387814,
  [SMALL_STATE(7776)] = 387853,
  [SMALL_STATE(7777)] = 387898,
  [SMALL_STATE(7778)] = 387939,
  [SMALL_STATE(7779)] = 388000,
  [SMALL_STATE(7780)] = 388039,
  [SMALL_STATE(7781)] = 388078,
  [SMALL_STATE(7782)] = 388117,
  [SMALL_STATE(7783)] = 388156,
  [SMALL_STATE(7784)] = 388217,
  [SMALL_STATE(7785)] = 388256,
  [SMALL_STATE(7786)] = 388295,
  [SMALL_STATE(7787)] = 388356,
  [SMALL_STATE(7788)] = 388397,
  [SMALL_STATE(7789)] = 388438,
  [SMALL_STATE(7790)] = 388499,
  [SMALL_STATE(7791)] = 388538,
  [SMALL_STATE(7792)] = 388577,
  [SMALL_STATE(7793)] = 388616,
  [SMALL_STATE(7794)] = 388655,
  [SMALL_STATE(7795)] = 388694,
  [SMALL_STATE(7796)] = 388733,
  [SMALL_STATE(7797)] = 388786,
  [SMALL_STATE(7798)] = 388827,
  [SMALL_STATE(7799)] = 388866,
  [SMALL_STATE(7800)] = 388909,
  [SMALL_STATE(7801)] = 388948,
  [SMALL_STATE(7802)] = 389003,
  [SMALL_STATE(7803)] = 389042,
  [SMALL_STATE(7804)] = 389081,
  [SMALL_STATE(7805)] = 389120,
  [SMALL_STATE(7806)] = 389159,
  [SMALL_STATE(7807)] = 389198,
  [SMALL_STATE(7808)] = 389259,
  [SMALL_STATE(7809)] = 389298,
  [SMALL_STATE(7810)] = 389337,
  [SMALL_STATE(7811)] = 389376,
  [SMALL_STATE(7812)] = 389415,
  [SMALL_STATE(7813)] = 389454,
  [SMALL_STATE(7814)] = 389515,
  [SMALL_STATE(7815)] = 389554,
  [SMALL_STATE(7816)] = 389615,
  [SMALL_STATE(7817)] = 389654,
  [SMALL_STATE(7818)] = 389693,
  [SMALL_STATE(7819)] = 389732,
  [SMALL_STATE(7820)] = 389771,
  [SMALL_STATE(7821)] = 389814,
  [SMALL_STATE(7822)] = 389853,
  [SMALL_STATE(7823)] = 389892,
  [SMALL_STATE(7824)] = 389931,
  [SMALL_STATE(7825)] = 389970,
  [SMALL_STATE(7826)] = 390015,
  [SMALL_STATE(7827)] = 390054,
  [SMALL_STATE(7828)] = 390093,
  [SMALL_STATE(7829)] = 390132,
  [SMALL_STATE(7830)] = 390171,
  [SMALL_STATE(7831)] = 390212,
  [SMALL_STATE(7832)] = 390251,
  [SMALL_STATE(7833)] = 390290,
  [SMALL_STATE(7834)] = 390351,
  [SMALL_STATE(7835)] = 390390,
  [SMALL_STATE(7836)] = 390429,
  [SMALL_STATE(7837)] = 390488,
  [SMALL_STATE(7838)] = 390549,
  [SMALL_STATE(7839)] = 390588,
  [SMALL_STATE(7840)] = 390627,
  [SMALL_STATE(7841)] = 390666,
  [SMALL_STATE(7842)] = 390705,
  [SMALL_STATE(7843)] = 390744,
  [SMALL_STATE(7844)] = 390783,
  [SMALL_STATE(7845)] = 390824,
  [SMALL_STATE(7846)] = 390863,
  [SMALL_STATE(7847)] = 390902,
  [SMALL_STATE(7848)] = 390941,
  [SMALL_STATE(7849)] = 390982,
  [SMALL_STATE(7850)] = 391021,
  [SMALL_STATE(7851)] = 391060,
  [SMALL_STATE(7852)] = 391099,
  [SMALL_STATE(7853)] = 391138,
  [SMALL_STATE(7854)] = 391183,
  [SMALL_STATE(7855)] = 391240,
  [SMALL_STATE(7856)] = 391281,
  [SMALL_STATE(7857)] = 391320,
  [SMALL_STATE(7858)] = 391359,
  [SMALL_STATE(7859)] = 391420,
  [SMALL_STATE(7860)] = 391459,
  [SMALL_STATE(7861)] = 391498,
  [SMALL_STATE(7862)] = 391571,
  [SMALL_STATE(7863)] = 391610,
  [SMALL_STATE(7864)] = 391649,
  [SMALL_STATE(7865)] = 391688,
  [SMALL_STATE(7866)] = 391727,
  [SMALL_STATE(7867)] = 391766,
  [SMALL_STATE(7868)] = 391805,
  [SMALL_STATE(7869)] = 391844,
  [SMALL_STATE(7870)] = 391905,
  [SMALL_STATE(7871)] = 391950,
  [SMALL_STATE(7872)] = 392011,
  [SMALL_STATE(7873)] = 392084,
  [SMALL_STATE(7874)] = 392127,
  [SMALL_STATE(7875)] = 392188,
  [SMALL_STATE(7876)] = 392241,
  [SMALL_STATE(7877)] = 392280,
  [SMALL_STATE(7878)] = 392319,
  [SMALL_STATE(7879)] = 392360,
  [SMALL_STATE(7880)] = 392421,
  [SMALL_STATE(7881)] = 392460,
  [SMALL_STATE(7882)] = 392499,
  [SMALL_STATE(7883)] = 392538,
  [SMALL_STATE(7884)] = 392577,
  [SMALL_STATE(7885)] = 392616,
  [SMALL_STATE(7886)] = 392677,
  [SMALL_STATE(7887)] = 392716,
  [SMALL_STATE(7888)] = 392755,
  [SMALL_STATE(7889)] = 392794,
  [SMALL_STATE(7890)] = 392833,
  [SMALL_STATE(7891)] = 392872,
  [SMALL_STATE(7892)] = 392933,
  [SMALL_STATE(7893)] = 392994,
  [SMALL_STATE(7894)] = 393033,
  [SMALL_STATE(7895)] = 393072,
  [SMALL_STATE(7896)] = 393111,
  [SMALL_STATE(7897)] = 393150,
  [SMALL_STATE(7898)] = 393189,
  [SMALL_STATE(7899)] = 393228,
  [SMALL_STATE(7900)] = 393289,
  [SMALL_STATE(7901)] = 393348,
  [SMALL_STATE(7902)] = 393389,
  [SMALL_STATE(7903)] = 393428,
  [SMALL_STATE(7904)] = 393489,
  [SMALL_STATE(7905)] = 393530,
  [SMALL_STATE(7906)] = 393603,
  [SMALL_STATE(7907)] = 393654,
  [SMALL_STATE(7908)] = 393727,
  [SMALL_STATE(7909)] = 393766,
  [SMALL_STATE(7910)] = 393819,
  [SMALL_STATE(7911)] = 393864,
  [SMALL_STATE(7912)] = 393903,
  [SMALL_STATE(7913)] = 393976,
  [SMALL_STATE(7914)] = 394037,
  [SMALL_STATE(7915)] = 394098,
  [SMALL_STATE(7916)] = 394139,
  [SMALL_STATE(7917)] = 394178,
  [SMALL_STATE(7918)] = 394223,
  [SMALL_STATE(7919)] = 394296,
  [SMALL_STATE(7920)] = 394347,
  [SMALL_STATE(7921)] = 394386,
  [SMALL_STATE(7922)] = 394427,
  [SMALL_STATE(7923)] = 394466,
  [SMALL_STATE(7924)] = 394505,
  [SMALL_STATE(7925)] = 394544,
  [SMALL_STATE(7926)] = 394583,
  [SMALL_STATE(7927)] = 394622,
  [SMALL_STATE(7928)] = 394661,
  [SMALL_STATE(7929)] = 394722,
  [SMALL_STATE(7930)] = 394761,
  [SMALL_STATE(7931)] = 394800,
  [SMALL_STATE(7932)] = 394839,
  [SMALL_STATE(7933)] = 394878,
  [SMALL_STATE(7934)] = 394917,
  [SMALL_STATE(7935)] = 394956,
  [SMALL_STATE(7936)] = 394997,
  [SMALL_STATE(7937)] = 395060,
  [SMALL_STATE(7938)] = 395099,
  [SMALL_STATE(7939)] = 395138,
  [SMALL_STATE(7940)] = 395177,
  [SMALL_STATE(7941)] = 395216,
  [SMALL_STATE(7942)] = 395255,
  [SMALL_STATE(7943)] = 395308,
  [SMALL_STATE(7944)] = 395347,
  [SMALL_STATE(7945)] = 395386,
  [SMALL_STATE(7946)] = 395447,
  [SMALL_STATE(7947)] = 395494,
  [SMALL_STATE(7948)] = 395555,
  [SMALL_STATE(7949)] = 395594,
  [SMALL_STATE(7950)] = 395633,
  [SMALL_STATE(7951)] = 395672,
  [SMALL_STATE(7952)] = 395711,
  [SMALL_STATE(7953)] = 395750,
  [SMALL_STATE(7954)] = 395791,
  [SMALL_STATE(7955)] = 395830,
  [SMALL_STATE(7956)] = 395903,
  [SMALL_STATE(7957)] = 395942,
  [SMALL_STATE(7958)] = 395981,
  [SMALL_STATE(7959)] = 396020,
  [SMALL_STATE(7960)] = 396059,
  [SMALL_STATE(7961)] = 396102,
  [SMALL_STATE(7962)] = 396141,
  [SMALL_STATE(7963)] = 396182,
  [SMALL_STATE(7964)] = 396225,
  [SMALL_STATE(7965)] = 396264,
  [SMALL_STATE(7966)] = 396307,
  [SMALL_STATE(7967)] = 396368,
  [SMALL_STATE(7968)] = 396407,
  [SMALL_STATE(7969)] = 396446,
  [SMALL_STATE(7970)] = 396485,
  [SMALL_STATE(7971)] = 396524,
  [SMALL_STATE(7972)] = 396565,
  [SMALL_STATE(7973)] = 396626,
  [SMALL_STATE(7974)] = 396665,
  [SMALL_STATE(7975)] = 396704,
  [SMALL_STATE(7976)] = 396743,
  [SMALL_STATE(7977)] = 396788,
  [SMALL_STATE(7978)] = 396827,
  [SMALL_STATE(7979)] = 396872,
  [SMALL_STATE(7980)] = 396923,
  [SMALL_STATE(7981)] = 396982,
  [SMALL_STATE(7982)] = 397021,
  [SMALL_STATE(7983)] = 397060,
  [SMALL_STATE(7984)] = 397121,
  [SMALL_STATE(7985)] = 397160,
  [SMALL_STATE(7986)] = 397223,
  [SMALL_STATE(7987)] = 397262,
  [SMALL_STATE(7988)] = 397301,
  [SMALL_STATE(7989)] = 397340,
  [SMALL_STATE(7990)] = 397379,
  [SMALL_STATE(7991)] = 397418,
  [SMALL_STATE(7992)] = 397479,
  [SMALL_STATE(7993)] = 397518,
  [SMALL_STATE(7994)] = 397559,
  [SMALL_STATE(7995)] = 397598,
  [SMALL_STATE(7996)] = 397653,
  [SMALL_STATE(7997)] = 397692,
  [SMALL_STATE(7998)] = 397731,
  [SMALL_STATE(7999)] = 397792,
  [SMALL_STATE(8000)] = 397831,
  [SMALL_STATE(8001)] = 397870,
  [SMALL_STATE(8002)] = 397911,
  [SMALL_STATE(8003)] = 397950,
  [SMALL_STATE(8004)] = 398011,
  [SMALL_STATE(8005)] = 398052,
  [SMALL_STATE(8006)] = 398091,
  [SMALL_STATE(8007)] = 398130,
  [SMALL_STATE(8008)] = 398169,
  [SMALL_STATE(8009)] = 398208,
  [SMALL_STATE(8010)] = 398247,
  [SMALL_STATE(8011)] = 398288,
  [SMALL_STATE(8012)] = 398347,
  [SMALL_STATE(8013)] = 398386,
  [SMALL_STATE(8014)] = 398425,
  [SMALL_STATE(8015)] = 398488,
  [SMALL_STATE(8016)] = 398527,
  [SMALL_STATE(8017)] = 398570,
  [SMALL_STATE(8018)] = 398609,
  [SMALL_STATE(8019)] = 398648,
  [SMALL_STATE(8020)] = 398709,
  [SMALL_STATE(8021)] = 398770,
  [SMALL_STATE(8022)] = 398809,
  [SMALL_STATE(8023)] = 398848,
  [SMALL_STATE(8024)] = 398887,
  [SMALL_STATE(8025)] = 398926,
  [SMALL_STATE(8026)] = 398977,
  [SMALL_STATE(8027)] = 399016,
  [SMALL_STATE(8028)] = 399083,
  [SMALL_STATE(8029)] = 399126,
  [SMALL_STATE(8030)] = 399165,
  [SMALL_STATE(8031)] = 399204,
  [SMALL_STATE(8032)] = 399255,
  [SMALL_STATE(8033)] = 399294,
  [SMALL_STATE(8034)] = 399333,
  [SMALL_STATE(8035)] = 399372,
  [SMALL_STATE(8036)] = 399413,
  [SMALL_STATE(8037)] = 399454,
  [SMALL_STATE(8038)] = 399517,
  [SMALL_STATE(8039)] = 399578,
  [SMALL_STATE(8040)] = 399619,
  [SMALL_STATE(8041)] = 399680,
  [SMALL_STATE(8042)] = 399721,
  [SMALL_STATE(8043)] = 399782,
  [SMALL_STATE(8044)] = 399821,
  [SMALL_STATE(8045)] = 399860,
  [SMALL_STATE(8046)] = 399899,
  [SMALL_STATE(8047)] = 399940,
  [SMALL_STATE(8048)] = 399979,
  [SMALL_STATE(8049)] = 400018,
  [SMALL_STATE(8050)] = 400057,
  [SMALL_STATE(8051)] = 400118,
  [SMALL_STATE(8052)] = 400177,
  [SMALL_STATE(8053)] = 400216,
  [SMALL_STATE(8054)] = 400255,
  [SMALL_STATE(8055)] = 400298,
  [SMALL_STATE(8056)] = 400337,
  [SMALL_STATE(8057)] = 400382,
  [SMALL_STATE(8058)] = 400421,
  [SMALL_STATE(8059)] = 400460,
  [SMALL_STATE(8060)] = 400527,
  [SMALL_STATE(8061)] = 400566,
  [SMALL_STATE(8062)] = 400607,
  [SMALL_STATE(8063)] = 400646,
  [SMALL_STATE(8064)] = 400707,
  [SMALL_STATE(8065)] = 400746,
  [SMALL_STATE(8066)] = 400785,
  [SMALL_STATE(8067)] = 400824,
  [SMALL_STATE(8068)] = 400885,
  [SMALL_STATE(8069)] = 400924,
  [SMALL_STATE(8070)] = 400963,
  [SMALL_STATE(8071)] = 401002,
  [SMALL_STATE(8072)] = 401041,
  [SMALL_STATE(8073)] = 401090,
  [SMALL_STATE(8074)] = 401133,
  [SMALL_STATE(8075)] = 401172,
  [SMALL_STATE(8076)] = 401233,
  [SMALL_STATE(8077)] = 401272,
  [SMALL_STATE(8078)] = 401311,
  [SMALL_STATE(8079)] = 401350,
  [SMALL_STATE(8080)] = 401389,
  [SMALL_STATE(8081)] = 401428,
  [SMALL_STATE(8082)] = 401467,
  [SMALL_STATE(8083)] = 401508,
  [SMALL_STATE(8084)] = 401547,
  [SMALL_STATE(8085)] = 401586,
  [SMALL_STATE(8086)] = 401625,
  [SMALL_STATE(8087)] = 401664,
  [SMALL_STATE(8088)] = 401725,
  [SMALL_STATE(8089)] = 401764,
  [SMALL_STATE(8090)] = 401803,
  [SMALL_STATE(8091)] = 401842,
  [SMALL_STATE(8092)] = 401903,
  [SMALL_STATE(8093)] = 401942,
  [SMALL_STATE(8094)] = 401981,
  [SMALL_STATE(8095)] = 402020,
  [SMALL_STATE(8096)] = 402059,
  [SMALL_STATE(8097)] = 402098,
  [SMALL_STATE(8098)] = 402137,
  [SMALL_STATE(8099)] = 402176,
  [SMALL_STATE(8100)] = 402215,
  [SMALL_STATE(8101)] = 402254,
  [SMALL_STATE(8102)] = 402315,
  [SMALL_STATE(8103)] = 402354,
  [SMALL_STATE(8104)] = 402393,
  [SMALL_STATE(8105)] = 402460,
  [SMALL_STATE(8106)] = 402499,
  [SMALL_STATE(8107)] = 402538,
  [SMALL_STATE(8108)] = 402611,
  [SMALL_STATE(8109)] = 402650,
  [SMALL_STATE(8110)] = 402695,
  [SMALL_STATE(8111)] = 402734,
  [SMALL_STATE(8112)] = 402795,
  [SMALL_STATE(8113)] = 402834,
  [SMALL_STATE(8114)] = 402873,
  [SMALL_STATE(8115)] = 402916,
  [SMALL_STATE(8116)] = 402977,
  [SMALL_STATE(8117)] = 403038,
  [SMALL_STATE(8118)] = 403077,
  [SMALL_STATE(8119)] = 403116,
  [SMALL_STATE(8120)] = 403155,
  [SMALL_STATE(8121)] = 403228,
  [SMALL_STATE(8122)] = 403291,
  [SMALL_STATE(8123)] = 403328,
  [SMALL_STATE(8124)] = 403367,
  [SMALL_STATE(8125)] = 403408,
  [SMALL_STATE(8126)] = 403447,
  [SMALL_STATE(8127)] = 403490,
  [SMALL_STATE(8128)] = 403529,
  [SMALL_STATE(8129)] = 403590,
  [SMALL_STATE(8130)] = 403651,
  [SMALL_STATE(8131)] = 403690,
  [SMALL_STATE(8132)] = 403757,
  [SMALL_STATE(8133)] = 403796,
  [SMALL_STATE(8134)] = 403869,
  [SMALL_STATE(8135)] = 403908,
  [SMALL_STATE(8136)] = 403947,
  [SMALL_STATE(8137)] = 403988,
  [SMALL_STATE(8138)] = 404049,
  [SMALL_STATE(8139)] = 404110,
  [SMALL_STATE(8140)] = 404149,
  [SMALL_STATE(8141)] = 404188,
  [SMALL_STATE(8142)] = 404227,
  [SMALL_STATE(8143)] = 404288,
  [SMALL_STATE(8144)] = 404333,
  [SMALL_STATE(8145)] = 404372,
  [SMALL_STATE(8146)] = 404433,
  [SMALL_STATE(8147)] = 404472,
  [SMALL_STATE(8148)] = 404513,
  [SMALL_STATE(8149)] = 404574,
  [SMALL_STATE(8150)] = 404613,
  [SMALL_STATE(8151)] = 404654,
  [SMALL_STATE(8152)] = 404693,
  [SMALL_STATE(8153)] = 404754,
  [SMALL_STATE(8154)] = 404797,
  [SMALL_STATE(8155)] = 404842,
  [SMALL_STATE(8156)] = 404903,
  [SMALL_STATE(8157)] = 404942,
  [SMALL_STATE(8158)] = 405015,
  [SMALL_STATE(8159)] = 405054,
  [SMALL_STATE(8160)] = 405093,
  [SMALL_STATE(8161)] = 405154,
  [SMALL_STATE(8162)] = 405227,
  [SMALL_STATE(8163)] = 405266,
  [SMALL_STATE(8164)] = 405305,
  [SMALL_STATE(8165)] = 405344,
  [SMALL_STATE(8166)] = 405383,
  [SMALL_STATE(8167)] = 405456,
  [SMALL_STATE(8168)] = 405495,
  [SMALL_STATE(8169)] = 405550,
  [SMALL_STATE(8170)] = 405589,
  [SMALL_STATE(8171)] = 405630,
  [SMALL_STATE(8172)] = 405669,
  [SMALL_STATE(8173)] = 405710,
  [SMALL_STATE(8174)] = 405751,
  [SMALL_STATE(8175)] = 405792,
  [SMALL_STATE(8176)] = 405831,
  [SMALL_STATE(8177)] = 405904,
  [SMALL_STATE(8178)] = 405943,
  [SMALL_STATE(8179)] = 405982,
  [SMALL_STATE(8180)] = 406023,
  [SMALL_STATE(8181)] = 406062,
  [SMALL_STATE(8182)] = 406101,
  [SMALL_STATE(8183)] = 406140,
  [SMALL_STATE(8184)] = 406179,
  [SMALL_STATE(8185)] = 406218,
  [SMALL_STATE(8186)] = 406257,
  [SMALL_STATE(8187)] = 406324,
  [SMALL_STATE(8188)] = 406363,
  [SMALL_STATE(8189)] = 406436,
  [SMALL_STATE(8190)] = 406475,
  [SMALL_STATE(8191)] = 406514,
  [SMALL_STATE(8192)] = 406575,
  [SMALL_STATE(8193)] = 406614,
  [SMALL_STATE(8194)] = 406655,
  [SMALL_STATE(8195)] = 406694,
  [SMALL_STATE(8196)] = 406767,
  [SMALL_STATE(8197)] = 406808,
  [SMALL_STATE(8198)] = 406847,
  [SMALL_STATE(8199)] = 406888,
  [SMALL_STATE(8200)] = 406927,
  [SMALL_STATE(8201)] = 406966,
  [SMALL_STATE(8202)] = 407005,
  [SMALL_STATE(8203)] = 407044,
  [SMALL_STATE(8204)] = 407107,
  [SMALL_STATE(8205)] = 407146,
  [SMALL_STATE(8206)] = 407185,
  [SMALL_STATE(8207)] = 407224,
  [SMALL_STATE(8208)] = 407279,
  [SMALL_STATE(8209)] = 407318,
  [SMALL_STATE(8210)] = 407379,
  [SMALL_STATE(8211)] = 407418,
  [SMALL_STATE(8212)] = 407457,
  [SMALL_STATE(8213)] = 407508,
  [SMALL_STATE(8214)] = 407549,
  [SMALL_STATE(8215)] = 407612,
  [SMALL_STATE(8216)] = 407673,
  [SMALL_STATE(8217)] = 407712,
  [SMALL_STATE(8218)] = 407751,
  [SMALL_STATE(8219)] = 407812,
  [SMALL_STATE(8220)] = 407855,
  [SMALL_STATE(8221)] = 407894,
  [SMALL_STATE(8222)] = 407939,
  [SMALL_STATE(8223)] = 408002,
  [SMALL_STATE(8224)] = 408047,
  [SMALL_STATE(8225)] = 408086,
  [SMALL_STATE(8226)] = 408127,
  [SMALL_STATE(8227)] = 408166,
  [SMALL_STATE(8228)] = 408205,
  [SMALL_STATE(8229)] = 408244,
  [SMALL_STATE(8230)] = 408283,
  [SMALL_STATE(8231)] = 408322,
  [SMALL_STATE(8232)] = 408367,
  [SMALL_STATE(8233)] = 408440,
  [SMALL_STATE(8234)] = 408479,
  [SMALL_STATE(8235)] = 408552,
  [SMALL_STATE(8236)] = 408591,
  [SMALL_STATE(8237)] = 408630,
  [SMALL_STATE(8238)] = 408673,
  [SMALL_STATE(8239)] = 408716,
  [SMALL_STATE(8240)] = 408757,
  [SMALL_STATE(8241)] = 408818,
  [SMALL_STATE(8242)] = 408859,
  [SMALL_STATE(8243)] = 408904,
  [SMALL_STATE(8244)] = 408943,
  [SMALL_STATE(8245)] = 409004,
  [SMALL_STATE(8246)] = 409065,
  [SMALL_STATE(8247)] = 409104,
  [SMALL_STATE(8248)] = 409143,
  [SMALL_STATE(8249)] = 409182,
  [SMALL_STATE(8250)] = 409221,
  [SMALL_STATE(8251)] = 409262,
  [SMALL_STATE(8252)] = 409301,
  [SMALL_STATE(8253)] = 409340,
  [SMALL_STATE(8254)] = 409379,
  [SMALL_STATE(8255)] = 409418,
  [SMALL_STATE(8256)] = 409457,
  [SMALL_STATE(8257)] = 409518,
  [SMALL_STATE(8258)] = 409559,
  [SMALL_STATE(8259)] = 409598,
  [SMALL_STATE(8260)] = 409637,
  [SMALL_STATE(8261)] = 409676,
  [SMALL_STATE(8262)] = 409715,
  [SMALL_STATE(8263)] = 409754,
  [SMALL_STATE(8264)] = 409815,
  [SMALL_STATE(8265)] = 409882,
  [SMALL_STATE(8266)] = 409923,
  [SMALL_STATE(8267)] = 409962,
  [SMALL_STATE(8268)] = 410001,
  [SMALL_STATE(8269)] = 410040,
  [SMALL_STATE(8270)] = 410079,
  [SMALL_STATE(8271)] = 410128,
  [SMALL_STATE(8272)] = 410169,
  [SMALL_STATE(8273)] = 410208,
  [SMALL_STATE(8274)] = 410247,
  [SMALL_STATE(8275)] = 410286,
  [SMALL_STATE(8276)] = 410325,
  [SMALL_STATE(8277)] = 410364,
  [SMALL_STATE(8278)] = 410403,
  [SMALL_STATE(8279)] = 410464,
  [SMALL_STATE(8280)] = 410503,
  [SMALL_STATE(8281)] = 410542,
  [SMALL_STATE(8282)] = 410581,
  [SMALL_STATE(8283)] = 410619,
  [SMALL_STATE(8284)] = 410657,
  [SMALL_STATE(8285)] = 410695,
  [SMALL_STATE(8286)] = 410735,
  [SMALL_STATE(8287)] = 410773,
  [SMALL_STATE(8288)] = 410811,
  [SMALL_STATE(8289)] = 410851,
  [SMALL_STATE(8290)] = 410889,
  [SMALL_STATE(8291)] = 410927,
  [SMALL_STATE(8292)] = 410967,
  [SMALL_STATE(8293)] = 411005,
  [SMALL_STATE(8294)] = 411043,
  [SMALL_STATE(8295)] = 411081,
  [SMALL_STATE(8296)] = 411143,
  [SMALL_STATE(8297)] = 411181,
  [SMALL_STATE(8298)] = 411219,
  [SMALL_STATE(8299)] = 411273,
  [SMALL_STATE(8300)] = 411317,
  [SMALL_STATE(8301)] = 411355,
  [SMALL_STATE(8302)] = 411393,
  [SMALL_STATE(8303)] = 411431,
  [SMALL_STATE(8304)] = 411475,
  [SMALL_STATE(8305)] = 411513,
  [SMALL_STATE(8306)] = 411551,
  [SMALL_STATE(8307)] = 411589,
  [SMALL_STATE(8308)] = 411627,
  [SMALL_STATE(8309)] = 411665,
  [SMALL_STATE(8310)] = 411703,
  [SMALL_STATE(8311)] = 411741,
  [SMALL_STATE(8312)] = 411781,
  [SMALL_STATE(8313)] = 411819,
  [SMALL_STATE(8314)] = 411857,
  [SMALL_STATE(8315)] = 411895,
  [SMALL_STATE(8316)] = 411933,
  [SMALL_STATE(8317)] = 411997,
  [SMALL_STATE(8318)] = 412035,
  [SMALL_STATE(8319)] = 412073,
  [SMALL_STATE(8320)] = 412111,
  [SMALL_STATE(8321)] = 412149,
  [SMALL_STATE(8322)] = 412217,
  [SMALL_STATE(8323)] = 412275,
  [SMALL_STATE(8324)] = 412313,
  [SMALL_STATE(8325)] = 412351,
  [SMALL_STATE(8326)] = 412391,
  [SMALL_STATE(8327)] = 412431,
  [SMALL_STATE(8328)] = 412469,
  [SMALL_STATE(8329)] = 412515,
  [SMALL_STATE(8330)] = 412553,
  [SMALL_STATE(8331)] = 412591,
  [SMALL_STATE(8332)] = 412629,
  [SMALL_STATE(8333)] = 412667,
  [SMALL_STATE(8334)] = 412705,
  [SMALL_STATE(8335)] = 412743,
  [SMALL_STATE(8336)] = 412781,
  [SMALL_STATE(8337)] = 412833,
  [SMALL_STATE(8338)] = 412871,
  [SMALL_STATE(8339)] = 412909,
  [SMALL_STATE(8340)] = 412947,
  [SMALL_STATE(8341)] = 412985,
  [SMALL_STATE(8342)] = 413023,
  [SMALL_STATE(8343)] = 413061,
  [SMALL_STATE(8344)] = 413099,
  [SMALL_STATE(8345)] = 413141,
  [SMALL_STATE(8346)] = 413183,
  [SMALL_STATE(8347)] = 413223,
  [SMALL_STATE(8348)] = 413261,
  [SMALL_STATE(8349)] = 413299,
  [SMALL_STATE(8350)] = 413337,
  [SMALL_STATE(8351)] = 413375,
  [SMALL_STATE(8352)] = 413425,
  [SMALL_STATE(8353)] = 413463,
  [SMALL_STATE(8354)] = 413501,
  [SMALL_STATE(8355)] = 413539,
  [SMALL_STATE(8356)] = 413577,
  [SMALL_STATE(8357)] = 413615,
  [SMALL_STATE(8358)] = 413653,
  [SMALL_STATE(8359)] = 413693,
  [SMALL_STATE(8360)] = 413733,
  [SMALL_STATE(8361)] = 413771,
  [SMALL_STATE(8362)] = 413811,
  [SMALL_STATE(8363)] = 413849,
  [SMALL_STATE(8364)] = 413887,
  [SMALL_STATE(8365)] = 413925,
  [SMALL_STATE(8366)] = 413963,
  [SMALL_STATE(8367)] = 414011,
  [SMALL_STATE(8368)] = 414049,
  [SMALL_STATE(8369)] = 414087,
  [SMALL_STATE(8370)] = 414125,
  [SMALL_STATE(8371)] = 414163,
  [SMALL_STATE(8372)] = 414201,
  [SMALL_STATE(8373)] = 414239,
  [SMALL_STATE(8374)] = 414277,
  [SMALL_STATE(8375)] = 414315,
  [SMALL_STATE(8376)] = 414353,
  [SMALL_STATE(8377)] = 414393,
  [SMALL_STATE(8378)] = 414431,
  [SMALL_STATE(8379)] = 414469,
  [SMALL_STATE(8380)] = 414509,
  [SMALL_STATE(8381)] = 414547,
  [SMALL_STATE(8382)] = 414585,
  [SMALL_STATE(8383)] = 414625,
  [SMALL_STATE(8384)] = 414663,
  [SMALL_STATE(8385)] = 414701,
  [SMALL_STATE(8386)] = 414739,
  [SMALL_STATE(8387)] = 414777,
  [SMALL_STATE(8388)] = 414815,
  [SMALL_STATE(8389)] = 414853,
  [SMALL_STATE(8390)] = 414891,
  [SMALL_STATE(8391)] = 414929,
  [SMALL_STATE(8392)] = 414967,
  [SMALL_STATE(8393)] = 415005,
  [SMALL_STATE(8394)] = 415047,
  [SMALL_STATE(8395)] = 415085,
  [SMALL_STATE(8396)] = 415123,
  [SMALL_STATE(8397)] = 415161,
  [SMALL_STATE(8398)] = 415199,
  [SMALL_STATE(8399)] = 415237,
  [SMALL_STATE(8400)] = 415275,
  [SMALL_STATE(8401)] = 415313,
  [SMALL_STATE(8402)] = 415351,
  [SMALL_STATE(8403)] = 415393,
  [SMALL_STATE(8404)] = 415431,
  [SMALL_STATE(8405)] = 415469,
  [SMALL_STATE(8406)] = 415513,
  [SMALL_STATE(8407)] = 415557,
  [SMALL_STATE(8408)] = 415595,
  [SMALL_STATE(8409)] = 415633,
  [SMALL_STATE(8410)] = 415673,
  [SMALL_STATE(8411)] = 415711,
  [SMALL_STATE(8412)] = 415749,
  [SMALL_STATE(8413)] = 415787,
  [SMALL_STATE(8414)] = 415825,
  [SMALL_STATE(8415)] = 415863,
  [SMALL_STATE(8416)] = 415901,
  [SMALL_STATE(8417)] = 415939,
  [SMALL_STATE(8418)] = 415977,
  [SMALL_STATE(8419)] = 416029,
  [SMALL_STATE(8420)] = 416067,
  [SMALL_STATE(8421)] = 416105,
  [SMALL_STATE(8422)] = 416143,
  [SMALL_STATE(8423)] = 416183,
  [SMALL_STATE(8424)] = 416221,
  [SMALL_STATE(8425)] = 416259,
  [SMALL_STATE(8426)] = 416303,
  [SMALL_STATE(8427)] = 416341,
  [SMALL_STATE(8428)] = 416379,
  [SMALL_STATE(8429)] = 416417,
  [SMALL_STATE(8430)] = 416455,
  [SMALL_STATE(8431)] = 416493,
  [SMALL_STATE(8432)] = 416531,
  [SMALL_STATE(8433)] = 416569,
  [SMALL_STATE(8434)] = 416607,
  [SMALL_STATE(8435)] = 416645,
  [SMALL_STATE(8436)] = 416683,
  [SMALL_STATE(8437)] = 416721,
  [SMALL_STATE(8438)] = 416759,
  [SMALL_STATE(8439)] = 416797,
  [SMALL_STATE(8440)] = 416835,
  [SMALL_STATE(8441)] = 416873,
  [SMALL_STATE(8442)] = 416911,
  [SMALL_STATE(8443)] = 416949,
  [SMALL_STATE(8444)] = 416987,
  [SMALL_STATE(8445)] = 417025,
  [SMALL_STATE(8446)] = 417063,
  [SMALL_STATE(8447)] = 417101,
  [SMALL_STATE(8448)] = 417139,
  [SMALL_STATE(8449)] = 417177,
  [SMALL_STATE(8450)] = 417215,
  [SMALL_STATE(8451)] = 417253,
  [SMALL_STATE(8452)] = 417297,
  [SMALL_STATE(8453)] = 417341,
  [SMALL_STATE(8454)] = 417379,
  [SMALL_STATE(8455)] = 417417,
  [SMALL_STATE(8456)] = 417455,
  [SMALL_STATE(8457)] = 417493,
  [SMALL_STATE(8458)] = 417531,
  [SMALL_STATE(8459)] = 417569,
  [SMALL_STATE(8460)] = 417607,
  [SMALL_STATE(8461)] = 417645,
  [SMALL_STATE(8462)] = 417685,
  [SMALL_STATE(8463)] = 417723,
  [SMALL_STATE(8464)] = 417761,
  [SMALL_STATE(8465)] = 417799,
  [SMALL_STATE(8466)] = 417837,
  [SMALL_STATE(8467)] = 417875,
  [SMALL_STATE(8468)] = 417913,
  [SMALL_STATE(8469)] = 417951,
  [SMALL_STATE(8470)] = 417989,
  [SMALL_STATE(8471)] = 418027,
  [SMALL_STATE(8472)] = 418065,
  [SMALL_STATE(8473)] = 418109,
  [SMALL_STATE(8474)] = 418147,
  [SMALL_STATE(8475)] = 418185,
  [SMALL_STATE(8476)] = 418223,
  [SMALL_STATE(8477)] = 418261,
  [SMALL_STATE(8478)] = 418299,
  [SMALL_STATE(8479)] = 418337,
  [SMALL_STATE(8480)] = 418375,
  [SMALL_STATE(8481)] = 418413,
  [SMALL_STATE(8482)] = 418453,
  [SMALL_STATE(8483)] = 418491,
  [SMALL_STATE(8484)] = 418529,
  [SMALL_STATE(8485)] = 418567,
  [SMALL_STATE(8486)] = 418605,
  [SMALL_STATE(8487)] = 418645,
  [SMALL_STATE(8488)] = 418683,
  [SMALL_STATE(8489)] = 418721,
  [SMALL_STATE(8490)] = 418759,
  [SMALL_STATE(8491)] = 418797,
  [SMALL_STATE(8492)] = 418835,
  [SMALL_STATE(8493)] = 418873,
  [SMALL_STATE(8494)] = 418911,
  [SMALL_STATE(8495)] = 418953,
  [SMALL_STATE(8496)] = 418991,
  [SMALL_STATE(8497)] = 419033,
  [SMALL_STATE(8498)] = 419073,
  [SMALL_STATE(8499)] = 419117,
  [SMALL_STATE(8500)] = 419155,
  [SMALL_STATE(8501)] = 419207,
  [SMALL_STATE(8502)] = 419245,
  [SMALL_STATE(8503)] = 419285,
  [SMALL_STATE(8504)] = 419325,
  [SMALL_STATE(8505)] = 419363,
  [SMALL_STATE(8506)] = 419401,
  [SMALL_STATE(8507)] = 419439,
  [SMALL_STATE(8508)] = 419477,
  [SMALL_STATE(8509)] = 419515,
  [SMALL_STATE(8510)] = 419559,
  [SMALL_STATE(8511)] = 419597,
  [SMALL_STATE(8512)] = 419635,
  [SMALL_STATE(8513)] = 419673,
  [SMALL_STATE(8514)] = 419711,
  [SMALL_STATE(8515)] = 419749,
  [SMALL_STATE(8516)] = 419787,
  [SMALL_STATE(8517)] = 419825,
  [SMALL_STATE(8518)] = 419865,
  [SMALL_STATE(8519)] = 419903,
  [SMALL_STATE(8520)] = 419941,
  [SMALL_STATE(8521)] = 419979,
  [SMALL_STATE(8522)] = 420017,
  [SMALL_STATE(8523)] = 420055,
  [SMALL_STATE(8524)] = 420093,
  [SMALL_STATE(8525)] = 420131,
  [SMALL_STATE(8526)] = 420169,
  [SMALL_STATE(8527)] = 420207,
  [SMALL_STATE(8528)] = 420245,
  [SMALL_STATE(8529)] = 420283,
  [SMALL_STATE(8530)] = 420321,
  [SMALL_STATE(8531)] = 420373,
  [SMALL_STATE(8532)] = 420411,
  [SMALL_STATE(8533)] = 420449,
  [SMALL_STATE(8534)] = 420487,
  [SMALL_STATE(8535)] = 420525,
  [SMALL_STATE(8536)] = 420563,
  [SMALL_STATE(8537)] = 420601,
  [SMALL_STATE(8538)] = 420641,
  [SMALL_STATE(8539)] = 420679,
  [SMALL_STATE(8540)] = 420717,
  [SMALL_STATE(8541)] = 420757,
  [SMALL_STATE(8542)] = 420799,
  [SMALL_STATE(8543)] = 420837,
  [SMALL_STATE(8544)] = 420875,
  [SMALL_STATE(8545)] = 420913,
  [SMALL_STATE(8546)] = 420951,
  [SMALL_STATE(8547)] = 420989,
  [SMALL_STATE(8548)] = 421027,
  [SMALL_STATE(8549)] = 421065,
  [SMALL_STATE(8550)] = 421103,
  [SMALL_STATE(8551)] = 421141,
  [SMALL_STATE(8552)] = 421179,
  [SMALL_STATE(8553)] = 421217,
  [SMALL_STATE(8554)] = 421255,
  [SMALL_STATE(8555)] = 421297,
  [SMALL_STATE(8556)] = 421335,
  [SMALL_STATE(8557)] = 421389,
  [SMALL_STATE(8558)] = 421427,
  [SMALL_STATE(8559)] = 421465,
  [SMALL_STATE(8560)] = 421503,
  [SMALL_STATE(8561)] = 421543,
  [SMALL_STATE(8562)] = 421581,
  [SMALL_STATE(8563)] = 421625,
  [SMALL_STATE(8564)] = 421663,
  [SMALL_STATE(8565)] = 421705,
  [SMALL_STATE(8566)] = 421747,
  [SMALL_STATE(8567)] = 421791,
  [SMALL_STATE(8568)] = 421829,
  [SMALL_STATE(8569)] = 421869,
  [SMALL_STATE(8570)] = 421907,
  [SMALL_STATE(8571)] = 421945,
  [SMALL_STATE(8572)] = 422001,
  [SMALL_STATE(8573)] = 422039,
  [SMALL_STATE(8574)] = 422077,
  [SMALL_STATE(8575)] = 422115,
  [SMALL_STATE(8576)] = 422153,
  [SMALL_STATE(8577)] = 422191,
  [SMALL_STATE(8578)] = 422229,
  [SMALL_STATE(8579)] = 422267,
  [SMALL_STATE(8580)] = 422305,
  [SMALL_STATE(8581)] = 422343,
  [SMALL_STATE(8582)] = 422381,
  [SMALL_STATE(8583)] = 422419,
  [SMALL_STATE(8584)] = 422457,
  [SMALL_STATE(8585)] = 422495,
  [SMALL_STATE(8586)] = 422533,
  [SMALL_STATE(8587)] = 422577,
  [SMALL_STATE(8588)] = 422627,
  [SMALL_STATE(8589)] = 422667,
  [SMALL_STATE(8590)] = 422719,
  [SMALL_STATE(8591)] = 422757,
  [SMALL_STATE(8592)] = 422795,
  [SMALL_STATE(8593)] = 422833,
  [SMALL_STATE(8594)] = 422877,
  [SMALL_STATE(8595)] = 422915,
  [SMALL_STATE(8596)] = 422953,
  [SMALL_STATE(8597)] = 422997,
  [SMALL_STATE(8598)] = 423035,
  [SMALL_STATE(8599)] = 423073,
  [SMALL_STATE(8600)] = 423115,
  [SMALL_STATE(8601)] = 423153,
  [SMALL_STATE(8602)] = 423191,
  [SMALL_STATE(8603)] = 423231,
  [SMALL_STATE(8604)] = 423269,
  [SMALL_STATE(8605)] = 423311,
  [SMALL_STATE(8606)] = 423349,
  [SMALL_STATE(8607)] = 423389,
  [SMALL_STATE(8608)] = 423429,
  [SMALL_STATE(8609)] = 423467,
  [SMALL_STATE(8610)] = 423505,
  [SMALL_STATE(8611)] = 423543,
  [SMALL_STATE(8612)] = 423581,
  [SMALL_STATE(8613)] = 423619,
  [SMALL_STATE(8614)] = 423657,
  [SMALL_STATE(8615)] = 423695,
  [SMALL_STATE(8616)] = 423733,
  [SMALL_STATE(8617)] = 423771,
  [SMALL_STATE(8618)] = 423811,
  [SMALL_STATE(8619)] = 423849,
  [SMALL_STATE(8620)] = 423887,
  [SMALL_STATE(8621)] = 423925,
  [SMALL_STATE(8622)] = 423965,
  [SMALL_STATE(8623)] = 424003,
  [SMALL_STATE(8624)] = 424043,
  [SMALL_STATE(8625)] = 424081,
  [SMALL_STATE(8626)] = 424119,
  [SMALL_STATE(8627)] = 424157,
  [SMALL_STATE(8628)] = 424195,
  [SMALL_STATE(8629)] = 424233,
  [SMALL_STATE(8630)] = 424287,
  [SMALL_STATE(8631)] = 424325,
  [SMALL_STATE(8632)] = 424363,
  [SMALL_STATE(8633)] = 424403,
  [SMALL_STATE(8634)] = 424453,
  [SMALL_STATE(8635)] = 424491,
  [SMALL_STATE(8636)] = 424529,
  [SMALL_STATE(8637)] = 424567,
  [SMALL_STATE(8638)] = 424605,
  [SMALL_STATE(8639)] = 424643,
  [SMALL_STATE(8640)] = 424681,
  [SMALL_STATE(8641)] = 424719,
  [SMALL_STATE(8642)] = 424757,
  [SMALL_STATE(8643)] = 424795,
  [SMALL_STATE(8644)] = 424833,
  [SMALL_STATE(8645)] = 424871,
  [SMALL_STATE(8646)] = 424909,
  [SMALL_STATE(8647)] = 424947,
  [SMALL_STATE(8648)] = 424985,
  [SMALL_STATE(8649)] = 425023,
  [SMALL_STATE(8650)] = 425061,
  [SMALL_STATE(8651)] = 425099,
  [SMALL_STATE(8652)] = 425137,
  [SMALL_STATE(8653)] = 425175,
  [SMALL_STATE(8654)] = 425213,
  [SMALL_STATE(8655)] = 425251,
  [SMALL_STATE(8656)] = 425289,
  [SMALL_STATE(8657)] = 425327,
  [SMALL_STATE(8658)] = 425369,
  [SMALL_STATE(8659)] = 425407,
  [SMALL_STATE(8660)] = 425445,
  [SMALL_STATE(8661)] = 425483,
  [SMALL_STATE(8662)] = 425521,
  [SMALL_STATE(8663)] = 425559,
  [SMALL_STATE(8664)] = 425597,
  [SMALL_STATE(8665)] = 425635,
  [SMALL_STATE(8666)] = 425673,
  [SMALL_STATE(8667)] = 425711,
  [SMALL_STATE(8668)] = 425751,
  [SMALL_STATE(8669)] = 425793,
  [SMALL_STATE(8670)] = 425831,
  [SMALL_STATE(8671)] = 425869,
  [SMALL_STATE(8672)] = 425907,
  [SMALL_STATE(8673)] = 425975,
  [SMALL_STATE(8674)] = 426013,
  [SMALL_STATE(8675)] = 426051,
  [SMALL_STATE(8676)] = 426089,
  [SMALL_STATE(8677)] = 426131,
  [SMALL_STATE(8678)] = 426187,
  [SMALL_STATE(8679)] = 426225,
  [SMALL_STATE(8680)] = 426263,
  [SMALL_STATE(8681)] = 426301,
  [SMALL_STATE(8682)] = 426339,
  [SMALL_STATE(8683)] = 426379,
  [SMALL_STATE(8684)] = 426417,
  [SMALL_STATE(8685)] = 426455,
  [SMALL_STATE(8686)] = 426507,
  [SMALL_STATE(8687)] = 426545,
  [SMALL_STATE(8688)] = 426585,
  [SMALL_STATE(8689)] = 426623,
  [SMALL_STATE(8690)] = 426661,
  [SMALL_STATE(8691)] = 426699,
  [SMALL_STATE(8692)] = 426739,
  [SMALL_STATE(8693)] = 426779,
  [SMALL_STATE(8694)] = 426817,
  [SMALL_STATE(8695)] = 426855,
  [SMALL_STATE(8696)] = 426895,
  [SMALL_STATE(8697)] = 426935,
  [SMALL_STATE(8698)] = 427003,
  [SMALL_STATE(8699)] = 427041,
  [SMALL_STATE(8700)] = 427083,
  [SMALL_STATE(8701)] = 427121,
  [SMALL_STATE(8702)] = 427161,
  [SMALL_STATE(8703)] = 427229,
  [SMALL_STATE(8704)] = 427285,
  [SMALL_STATE(8705)] = 427329,
  [SMALL_STATE(8706)] = 427373,
  [SMALL_STATE(8707)] = 427411,
  [SMALL_STATE(8708)] = 427449,
  [SMALL_STATE(8709)] = 427487,
  [SMALL_STATE(8710)] = 427525,
  [SMALL_STATE(8711)] = 427563,
  [SMALL_STATE(8712)] = 427603,
  [SMALL_STATE(8713)] = 427665,
  [SMALL_STATE(8714)] = 427705,
  [SMALL_STATE(8715)] = 427743,
  [SMALL_STATE(8716)] = 427781,
  [SMALL_STATE(8717)] = 427835,
  [SMALL_STATE(8718)] = 427873,
  [SMALL_STATE(8719)] = 427911,
  [SMALL_STATE(8720)] = 427949,
  [SMALL_STATE(8721)] = 427987,
  [SMALL_STATE(8722)] = 428025,
  [SMALL_STATE(8723)] = 428063,
  [SMALL_STATE(8724)] = 428101,
  [SMALL_STATE(8725)] = 428139,
  [SMALL_STATE(8726)] = 428177,
  [SMALL_STATE(8727)] = 428227,
  [SMALL_STATE(8728)] = 428265,
  [SMALL_STATE(8729)] = 428303,
  [SMALL_STATE(8730)] = 428341,
  [SMALL_STATE(8731)] = 428379,
  [SMALL_STATE(8732)] = 428417,
  [SMALL_STATE(8733)] = 428455,
  [SMALL_STATE(8734)] = 428493,
  [SMALL_STATE(8735)] = 428531,
  [SMALL_STATE(8736)] = 428569,
  [SMALL_STATE(8737)] = 428611,
  [SMALL_STATE(8738)] = 428649,
  [SMALL_STATE(8739)] = 428687,
  [SMALL_STATE(8740)] = 428725,
  [SMALL_STATE(8741)] = 428763,
  [SMALL_STATE(8742)] = 428805,
  [SMALL_STATE(8743)] = 428845,
  [SMALL_STATE(8744)] = 428883,
  [SMALL_STATE(8745)] = 428921,
  [SMALL_STATE(8746)] = 428959,
  [SMALL_STATE(8747)] = 428997,
  [SMALL_STATE(8748)] = 429035,
  [SMALL_STATE(8749)] = 429073,
  [SMALL_STATE(8750)] = 429111,
  [SMALL_STATE(8751)] = 429169,
  [SMALL_STATE(8752)] = 429207,
  [SMALL_STATE(8753)] = 429251,
  [SMALL_STATE(8754)] = 429289,
  [SMALL_STATE(8755)] = 429327,
  [SMALL_STATE(8756)] = 429365,
  [SMALL_STATE(8757)] = 429403,
  [SMALL_STATE(8758)] = 429441,
  [SMALL_STATE(8759)] = 429485,
  [SMALL_STATE(8760)] = 429523,
  [SMALL_STATE(8761)] = 429561,
  [SMALL_STATE(8762)] = 429611,
  [SMALL_STATE(8763)] = 429649,
  [SMALL_STATE(8764)] = 429687,
  [SMALL_STATE(8765)] = 429725,
  [SMALL_STATE(8766)] = 429771,
  [SMALL_STATE(8767)] = 429809,
  [SMALL_STATE(8768)] = 429847,
  [SMALL_STATE(8769)] = 429885,
  [SMALL_STATE(8770)] = 429923,
  [SMALL_STATE(8771)] = 429961,
  [SMALL_STATE(8772)] = 430011,
  [SMALL_STATE(8773)] = 430049,
  [SMALL_STATE(8774)] = 430087,
  [SMALL_STATE(8775)] = 430125,
  [SMALL_STATE(8776)] = 430163,
  [SMALL_STATE(8777)] = 430201,
  [SMALL_STATE(8778)] = 430245,
  [SMALL_STATE(8779)] = 430283,
  [SMALL_STATE(8780)] = 430321,
  [SMALL_STATE(8781)] = 430361,
  [SMALL_STATE(8782)] = 430399,
  [SMALL_STATE(8783)] = 430437,
  [SMALL_STATE(8784)] = 430475,
  [SMALL_STATE(8785)] = 430515,
  [SMALL_STATE(8786)] = 430555,
  [SMALL_STATE(8787)] = 430593,
  [SMALL_STATE(8788)] = 430631,
  [SMALL_STATE(8789)] = 430669,
  [SMALL_STATE(8790)] = 430707,
  [SMALL_STATE(8791)] = 430745,
  [SMALL_STATE(8792)] = 430783,
  [SMALL_STATE(8793)] = 430821,
  [SMALL_STATE(8794)] = 430859,
  [SMALL_STATE(8795)] = 430897,
  [SMALL_STATE(8796)] = 430935,
  [SMALL_STATE(8797)] = 430973,
  [SMALL_STATE(8798)] = 431011,
  [SMALL_STATE(8799)] = 431049,
  [SMALL_STATE(8800)] = 431087,
  [SMALL_STATE(8801)] = 431125,
  [SMALL_STATE(8802)] = 431163,
  [SMALL_STATE(8803)] = 431201,
  [SMALL_STATE(8804)] = 431249,
  [SMALL_STATE(8805)] = 431287,
  [SMALL_STATE(8806)] = 431329,
  [SMALL_STATE(8807)] = 431367,
  [SMALL_STATE(8808)] = 431405,
  [SMALL_STATE(8809)] = 431443,
  [SMALL_STATE(8810)] = 431481,
  [SMALL_STATE(8811)] = 431549,
  [SMALL_STATE(8812)] = 431587,
  [SMALL_STATE(8813)] = 431627,
  [SMALL_STATE(8814)] = 431665,
  [SMALL_STATE(8815)] = 431707,
  [SMALL_STATE(8816)] = 431751,
  [SMALL_STATE(8817)] = 431789,
  [SMALL_STATE(8818)] = 431857,
  [SMALL_STATE(8819)] = 431897,
  [SMALL_STATE(8820)] = 431939,
  [SMALL_STATE(8821)] = 431981,
  [SMALL_STATE(8822)] = 432019,
  [SMALL_STATE(8823)] = 432059,
  [SMALL_STATE(8824)] = 432097,
  [SMALL_STATE(8825)] = 432135,
  [SMALL_STATE(8826)] = 432175,
  [SMALL_STATE(8827)] = 432213,
  [SMALL_STATE(8828)] = 432251,
  [SMALL_STATE(8829)] = 432289,
  [SMALL_STATE(8830)] = 432327,
  [SMALL_STATE(8831)] = 432365,
  [SMALL_STATE(8832)] = 432403,
  [SMALL_STATE(8833)] = 432441,
  [SMALL_STATE(8834)] = 432479,
  [SMALL_STATE(8835)] = 432517,
  [SMALL_STATE(8836)] = 432555,
  [SMALL_STATE(8837)] = 432593,
  [SMALL_STATE(8838)] = 432631,
  [SMALL_STATE(8839)] = 432683,
  [SMALL_STATE(8840)] = 432721,
  [SMALL_STATE(8841)] = 432759,
  [SMALL_STATE(8842)] = 432797,
  [SMALL_STATE(8843)] = 432837,
  [SMALL_STATE(8844)] = 432875,
  [SMALL_STATE(8845)] = 432913,
  [SMALL_STATE(8846)] = 432951,
  [SMALL_STATE(8847)] = 432991,
  [SMALL_STATE(8848)] = 433029,
  [SMALL_STATE(8849)] = 433079,
  [SMALL_STATE(8850)] = 433117,
  [SMALL_STATE(8851)] = 433155,
  [SMALL_STATE(8852)] = 433193,
  [SMALL_STATE(8853)] = 433261,
  [SMALL_STATE(8854)] = 433299,
  [SMALL_STATE(8855)] = 433337,
  [SMALL_STATE(8856)] = 433375,
  [SMALL_STATE(8857)] = 433413,
  [SMALL_STATE(8858)] = 433451,
  [SMALL_STATE(8859)] = 433489,
  [SMALL_STATE(8860)] = 433527,
  [SMALL_STATE(8861)] = 433565,
  [SMALL_STATE(8862)] = 433603,
  [SMALL_STATE(8863)] = 433641,
  [SMALL_STATE(8864)] = 433679,
  [SMALL_STATE(8865)] = 433717,
  [SMALL_STATE(8866)] = 433755,
  [SMALL_STATE(8867)] = 433795,
  [SMALL_STATE(8868)] = 433833,
  [SMALL_STATE(8869)] = 433901,
  [SMALL_STATE(8870)] = 433939,
  [SMALL_STATE(8871)] = 433983,
  [SMALL_STATE(8872)] = 434025,
  [SMALL_STATE(8873)] = 434063,
  [SMALL_STATE(8874)] = 434101,
  [SMALL_STATE(8875)] = 434139,
  [SMALL_STATE(8876)] = 434177,
  [SMALL_STATE(8877)] = 434215,
  [SMALL_STATE(8878)] = 434253,
  [SMALL_STATE(8879)] = 434301,
  [SMALL_STATE(8880)] = 434339,
  [SMALL_STATE(8881)] = 434395,
  [SMALL_STATE(8882)] = 434433,
  [SMALL_STATE(8883)] = 434475,
  [SMALL_STATE(8884)] = 434513,
  [SMALL_STATE(8885)] = 434553,
  [SMALL_STATE(8886)] = 434619,
  [SMALL_STATE(8887)] = 434661,
  [SMALL_STATE(8888)] = 434713,
  [SMALL_STATE(8889)] = 434751,
  [SMALL_STATE(8890)] = 434789,
  [SMALL_STATE(8891)] = 434827,
  [SMALL_STATE(8892)] = 434865,
  [SMALL_STATE(8893)] = 434903,
  [SMALL_STATE(8894)] = 434941,
  [SMALL_STATE(8895)] = 434979,
  [SMALL_STATE(8896)] = 435035,
  [SMALL_STATE(8897)] = 435077,
  [SMALL_STATE(8898)] = 435117,
  [SMALL_STATE(8899)] = 435155,
  [SMALL_STATE(8900)] = 435193,
  [SMALL_STATE(8901)] = 435231,
  [SMALL_STATE(8902)] = 435287,
  [SMALL_STATE(8903)] = 435327,
  [SMALL_STATE(8904)] = 435367,
  [SMALL_STATE(8905)] = 435405,
  [SMALL_STATE(8906)] = 435443,
  [SMALL_STATE(8907)] = 435481,
  [SMALL_STATE(8908)] = 435519,
  [SMALL_STATE(8909)] = 435557,
  [SMALL_STATE(8910)] = 435595,
  [SMALL_STATE(8911)] = 435633,
  [SMALL_STATE(8912)] = 435671,
  [SMALL_STATE(8913)] = 435709,
  [SMALL_STATE(8914)] = 435747,
  [SMALL_STATE(8915)] = 435785,
  [SMALL_STATE(8916)] = 435823,
  [SMALL_STATE(8917)] = 435861,
  [SMALL_STATE(8918)] = 435899,
  [SMALL_STATE(8919)] = 435937,
  [SMALL_STATE(8920)] = 435975,
  [SMALL_STATE(8921)] = 436013,
  [SMALL_STATE(8922)] = 436051,
  [SMALL_STATE(8923)] = 436111,
  [SMALL_STATE(8924)] = 436151,
  [SMALL_STATE(8925)] = 436189,
  [SMALL_STATE(8926)] = 436227,
  [SMALL_STATE(8927)] = 436265,
  [SMALL_STATE(8928)] = 436303,
  [SMALL_STATE(8929)] = 436341,
  [SMALL_STATE(8930)] = 436379,
  [SMALL_STATE(8931)] = 436417,
  [SMALL_STATE(8932)] = 436455,
  [SMALL_STATE(8933)] = 436493,
  [SMALL_STATE(8934)] = 436531,
  [SMALL_STATE(8935)] = 436571,
  [SMALL_STATE(8936)] = 436609,
  [SMALL_STATE(8937)] = 436647,
  [SMALL_STATE(8938)] = 436685,
  [SMALL_STATE(8939)] = 436723,
  [SMALL_STATE(8940)] = 436764,
  [SMALL_STATE(8941)] = 436801,
  [SMALL_STATE(8942)] = 436838,
  [SMALL_STATE(8943)] = 436875,
  [SMALL_STATE(8944)] = 436928,
  [SMALL_STATE(8945)] = 436965,
  [SMALL_STATE(8946)] = 437002,
  [SMALL_STATE(8947)] = 437057,
  [SMALL_STATE(8948)] = 437112,
  [SMALL_STATE(8949)] = 437149,
  [SMALL_STATE(8950)] = 437192,
  [SMALL_STATE(8951)] = 437229,
  [SMALL_STATE(8952)] = 437268,
  [SMALL_STATE(8953)] = 437305,
  [SMALL_STATE(8954)] = 437344,
  [SMALL_STATE(8955)] = 437381,
  [SMALL_STATE(8956)] = 437418,
  [SMALL_STATE(8957)] = 437473,
  [SMALL_STATE(8958)] = 437510,
  [SMALL_STATE(8959)] = 437547,
  [SMALL_STATE(8960)] = 437584,
  [SMALL_STATE(8961)] = 437621,
  [SMALL_STATE(8962)] = 437658,
  [SMALL_STATE(8963)] = 437695,
  [SMALL_STATE(8964)] = 437732,
  [SMALL_STATE(8965)] = 437777,
  [SMALL_STATE(8966)] = 437832,
  [SMALL_STATE(8967)] = 437887,
  [SMALL_STATE(8968)] = 437942,
  [SMALL_STATE(8969)] = 437979,
  [SMALL_STATE(8970)] = 438034,
  [SMALL_STATE(8971)] = 438071,
  [SMALL_STATE(8972)] = 438108,
  [SMALL_STATE(8973)] = 438145,
  [SMALL_STATE(8974)] = 438200,
  [SMALL_STATE(8975)] = 438237,
  [SMALL_STATE(8976)] = 438274,
  [SMALL_STATE(8977)] = 438311,
  [SMALL_STATE(8978)] = 438360,
  [SMALL_STATE(8979)] = 438397,
  [SMALL_STATE(8980)] = 438440,
  [SMALL_STATE(8981)] = 438495,
  [SMALL_STATE(8982)] = 438532,
  [SMALL_STATE(8983)] = 438569,
  [SMALL_STATE(8984)] = 438606,
  [SMALL_STATE(8985)] = 438643,
  [SMALL_STATE(8986)] = 438698,
  [SMALL_STATE(8987)] = 438735,
  [SMALL_STATE(8988)] = 438790,
  [SMALL_STATE(8989)] = 438845,
  [SMALL_STATE(8990)] = 438886,
  [SMALL_STATE(8991)] = 438929,
  [SMALL_STATE(8992)] = 438966,
  [SMALL_STATE(8993)] = 439003,
  [SMALL_STATE(8994)] = 439040,
  [SMALL_STATE(8995)] = 439085,
  [SMALL_STATE(8996)] = 439124,
  [SMALL_STATE(8997)] = 439161,
  [SMALL_STATE(8998)] = 439204,
  [SMALL_STATE(8999)] = 439241,
  [SMALL_STATE(9000)] = 439282,
  [SMALL_STATE(9001)] = 439319,
  [SMALL_STATE(9002)] = 439356,
  [SMALL_STATE(9003)] = 439393,
  [SMALL_STATE(9004)] = 439448,
  [SMALL_STATE(9005)] = 439485,
  [SMALL_STATE(9006)] = 439522,
  [SMALL_STATE(9007)] = 439577,
  [SMALL_STATE(9008)] = 439614,
  [SMALL_STATE(9009)] = 439651,
  [SMALL_STATE(9010)] = 439688,
  [SMALL_STATE(9011)] = 439725,
  [SMALL_STATE(9012)] = 439764,
  [SMALL_STATE(9013)] = 439801,
  [SMALL_STATE(9014)] = 439856,
  [SMALL_STATE(9015)] = 439911,
  [SMALL_STATE(9016)] = 439950,
  [SMALL_STATE(9017)] = 439991,
  [SMALL_STATE(9018)] = 440046,
  [SMALL_STATE(9019)] = 440083,
  [SMALL_STATE(9020)] = 440120,
  [SMALL_STATE(9021)] = 440157,
  [SMALL_STATE(9022)] = 440194,
  [SMALL_STATE(9023)] = 440235,
  [SMALL_STATE(9024)] = 440272,
  [SMALL_STATE(9025)] = 440309,
  [SMALL_STATE(9026)] = 440362,
  [SMALL_STATE(9027)] = 440399,
  [SMALL_STATE(9028)] = 440436,
  [SMALL_STATE(9029)] = 440473,
  [SMALL_STATE(9030)] = 440510,
  [SMALL_STATE(9031)] = 440547,
  [SMALL_STATE(9032)] = 440584,
  [SMALL_STATE(9033)] = 440639,
  [SMALL_STATE(9034)] = 440694,
  [SMALL_STATE(9035)] = 440731,
  [SMALL_STATE(9036)] = 440774,
  [SMALL_STATE(9037)] = 440829,
  [SMALL_STATE(9038)] = 440890,
  [SMALL_STATE(9039)] = 440929,
  [SMALL_STATE(9040)] = 440966,
  [SMALL_STATE(9041)] = 441003,
  [SMALL_STATE(9042)] = 441040,
  [SMALL_STATE(9043)] = 441083,
  [SMALL_STATE(9044)] = 441120,
  [SMALL_STATE(9045)] = 441171,
  [SMALL_STATE(9046)] = 441208,
  [SMALL_STATE(9047)] = 441263,
  [SMALL_STATE(9048)] = 441300,
  [SMALL_STATE(9049)] = 441343,
  [SMALL_STATE(9050)] = 441380,
  [SMALL_STATE(9051)] = 441435,
  [SMALL_STATE(9052)] = 441490,
  [SMALL_STATE(9053)] = 441545,
  [SMALL_STATE(9054)] = 441582,
  [SMALL_STATE(9055)] = 441621,
  [SMALL_STATE(9056)] = 441658,
  [SMALL_STATE(9057)] = 441695,
  [SMALL_STATE(9058)] = 441732,
  [SMALL_STATE(9059)] = 441769,
  [SMALL_STATE(9060)] = 441824,
  [SMALL_STATE(9061)] = 441879,
  [SMALL_STATE(9062)] = 441934,
  [SMALL_STATE(9063)] = 441971,
  [SMALL_STATE(9064)] = 442010,
  [SMALL_STATE(9065)] = 442065,
  [SMALL_STATE(9066)] = 442102,
  [SMALL_STATE(9067)] = 442139,
  [SMALL_STATE(9068)] = 442194,
  [SMALL_STATE(9069)] = 442231,
  [SMALL_STATE(9070)] = 442268,
  [SMALL_STATE(9071)] = 442321,
  [SMALL_STATE(9072)] = 442376,
  [SMALL_STATE(9073)] = 442413,
  [SMALL_STATE(9074)] = 442450,
  [SMALL_STATE(9075)] = 442501,
  [SMALL_STATE(9076)] = 442556,
  [SMALL_STATE(9077)] = 442595,
  [SMALL_STATE(9078)] = 442632,
  [SMALL_STATE(9079)] = 442669,
  [SMALL_STATE(9080)] = 442706,
  [SMALL_STATE(9081)] = 442743,
  [SMALL_STATE(9082)] = 442780,
  [SMALL_STATE(9083)] = 442817,
  [SMALL_STATE(9084)] = 442872,
  [SMALL_STATE(9085)] = 442909,
  [SMALL_STATE(9086)] = 442946,
  [SMALL_STATE(9087)] = 442983,
  [SMALL_STATE(9088)] = 443022,
  [SMALL_STATE(9089)] = 443059,
  [SMALL_STATE(9090)] = 443096,
  [SMALL_STATE(9091)] = 443133,
  [SMALL_STATE(9092)] = 443170,
  [SMALL_STATE(9093)] = 443207,
  [SMALL_STATE(9094)] = 443244,
  [SMALL_STATE(9095)] = 443299,
  [SMALL_STATE(9096)] = 443336,
  [SMALL_STATE(9097)] = 443373,
  [SMALL_STATE(9098)] = 443412,
  [SMALL_STATE(9099)] = 443449,
  [SMALL_STATE(9100)] = 443486,
  [SMALL_STATE(9101)] = 443529,
  [SMALL_STATE(9102)] = 443566,
  [SMALL_STATE(9103)] = 443619,
  [SMALL_STATE(9104)] = 443656,
  [SMALL_STATE(9105)] = 443693,
  [SMALL_STATE(9106)] = 443730,
  [SMALL_STATE(9107)] = 443769,
  [SMALL_STATE(9108)] = 443806,
  [SMALL_STATE(9109)] = 443843,
  [SMALL_STATE(9110)] = 443880,
  [SMALL_STATE(9111)] = 443917,
  [SMALL_STATE(9112)] = 443954,
  [SMALL_STATE(9113)] = 443991,
  [SMALL_STATE(9114)] = 444028,
  [SMALL_STATE(9115)] = 444065,
  [SMALL_STATE(9116)] = 444102,
  [SMALL_STATE(9117)] = 444157,
  [SMALL_STATE(9118)] = 444194,
  [SMALL_STATE(9119)] = 444231,
  [SMALL_STATE(9120)] = 444268,
  [SMALL_STATE(9121)] = 444333,
  [SMALL_STATE(9122)] = 444370,
  [SMALL_STATE(9123)] = 444407,
  [SMALL_STATE(9124)] = 444444,
  [SMALL_STATE(9125)] = 444481,
  [SMALL_STATE(9126)] = 444518,
  [SMALL_STATE(9127)] = 444557,
  [SMALL_STATE(9128)] = 444612,
  [SMALL_STATE(9129)] = 444667,
  [SMALL_STATE(9130)] = 444704,
  [SMALL_STATE(9131)] = 444741,
  [SMALL_STATE(9132)] = 444796,
  [SMALL_STATE(9133)] = 444833,
  [SMALL_STATE(9134)] = 444870,
  [SMALL_STATE(9135)] = 444907,
  [SMALL_STATE(9136)] = 444944,
  [SMALL_STATE(9137)] = 444981,
  [SMALL_STATE(9138)] = 445036,
  [SMALL_STATE(9139)] = 445073,
  [SMALL_STATE(9140)] = 445110,
  [SMALL_STATE(9141)] = 445147,
  [SMALL_STATE(9142)] = 445184,
  [SMALL_STATE(9143)] = 445221,
  [SMALL_STATE(9144)] = 445266,
  [SMALL_STATE(9145)] = 445303,
  [SMALL_STATE(9146)] = 445340,
  [SMALL_STATE(9147)] = 445377,
  [SMALL_STATE(9148)] = 445432,
  [SMALL_STATE(9149)] = 445485,
  [SMALL_STATE(9150)] = 445538,
  [SMALL_STATE(9151)] = 445575,
  [SMALL_STATE(9152)] = 445612,
  [SMALL_STATE(9153)] = 445649,
  [SMALL_STATE(9154)] = 445694,
  [SMALL_STATE(9155)] = 445731,
  [SMALL_STATE(9156)] = 445768,
  [SMALL_STATE(9157)] = 445805,
  [SMALL_STATE(9158)] = 445842,
  [SMALL_STATE(9159)] = 445879,
  [SMALL_STATE(9160)] = 445934,
  [SMALL_STATE(9161)] = 445971,
  [SMALL_STATE(9162)] = 446008,
  [SMALL_STATE(9163)] = 446045,
  [SMALL_STATE(9164)] = 446082,
  [SMALL_STATE(9165)] = 446137,
  [SMALL_STATE(9166)] = 446176,
  [SMALL_STATE(9167)] = 446213,
  [SMALL_STATE(9168)] = 446250,
  [SMALL_STATE(9169)] = 446287,
  [SMALL_STATE(9170)] = 446324,
  [SMALL_STATE(9171)] = 446361,
  [SMALL_STATE(9172)] = 446398,
  [SMALL_STATE(9173)] = 446453,
  [SMALL_STATE(9174)] = 446492,
  [SMALL_STATE(9175)] = 446529,
  [SMALL_STATE(9176)] = 446566,
  [SMALL_STATE(9177)] = 446603,
  [SMALL_STATE(9178)] = 446640,
  [SMALL_STATE(9179)] = 446677,
  [SMALL_STATE(9180)] = 446718,
  [SMALL_STATE(9181)] = 446755,
  [SMALL_STATE(9182)] = 446792,
  [SMALL_STATE(9183)] = 446831,
  [SMALL_STATE(9184)] = 446892,
  [SMALL_STATE(9185)] = 446929,
  [SMALL_STATE(9186)] = 446966,
  [SMALL_STATE(9187)] = 447021,
  [SMALL_STATE(9188)] = 447058,
  [SMALL_STATE(9189)] = 447095,
  [SMALL_STATE(9190)] = 447132,
  [SMALL_STATE(9191)] = 447187,
  [SMALL_STATE(9192)] = 447224,
  [SMALL_STATE(9193)] = 447261,
  [SMALL_STATE(9194)] = 447298,
  [SMALL_STATE(9195)] = 447335,
  [SMALL_STATE(9196)] = 447372,
  [SMALL_STATE(9197)] = 447411,
  [SMALL_STATE(9198)] = 447450,
  [SMALL_STATE(9199)] = 447487,
  [SMALL_STATE(9200)] = 447524,
  [SMALL_STATE(9201)] = 447561,
  [SMALL_STATE(9202)] = 447598,
  [SMALL_STATE(9203)] = 447639,
  [SMALL_STATE(9204)] = 447676,
  [SMALL_STATE(9205)] = 447731,
  [SMALL_STATE(9206)] = 447768,
  [SMALL_STATE(9207)] = 447823,
  [SMALL_STATE(9208)] = 447860,
  [SMALL_STATE(9209)] = 447901,
  [SMALL_STATE(9210)] = 447956,
  [SMALL_STATE(9211)] = 447993,
  [SMALL_STATE(9212)] = 448048,
  [SMALL_STATE(9213)] = 448085,
  [SMALL_STATE(9214)] = 448140,
  [SMALL_STATE(9215)] = 448177,
  [SMALL_STATE(9216)] = 448214,
  [SMALL_STATE(9217)] = 448251,
  [SMALL_STATE(9218)] = 448288,
  [SMALL_STATE(9219)] = 448343,
  [SMALL_STATE(9220)] = 448380,
  [SMALL_STATE(9221)] = 448437,
  [SMALL_STATE(9222)] = 448474,
  [SMALL_STATE(9223)] = 448511,
  [SMALL_STATE(9224)] = 448566,
  [SMALL_STATE(9225)] = 448603,
  [SMALL_STATE(9226)] = 448640,
  [SMALL_STATE(9227)] = 448677,
  [SMALL_STATE(9228)] = 448714,
  [SMALL_STATE(9229)] = 448751,
  [SMALL_STATE(9230)] = 448788,
  [SMALL_STATE(9231)] = 448843,
  [SMALL_STATE(9232)] = 448880,
  [SMALL_STATE(9233)] = 448919,
  [SMALL_STATE(9234)] = 448974,
  [SMALL_STATE(9235)] = 449029,
  [SMALL_STATE(9236)] = 449066,
  [SMALL_STATE(9237)] = 449103,
  [SMALL_STATE(9238)] = 449158,
  [SMALL_STATE(9239)] = 449213,
  [SMALL_STATE(9240)] = 449256,
  [SMALL_STATE(9241)] = 449293,
  [SMALL_STATE(9242)] = 449336,
  [SMALL_STATE(9243)] = 449373,
  [SMALL_STATE(9244)] = 449410,
  [SMALL_STATE(9245)] = 449447,
  [SMALL_STATE(9246)] = 449502,
  [SMALL_STATE(9247)] = 449539,
  [SMALL_STATE(9248)] = 449576,
  [SMALL_STATE(9249)] = 449613,
  [SMALL_STATE(9250)] = 449650,
  [SMALL_STATE(9251)] = 449693,
  [SMALL_STATE(9252)] = 449730,
  [SMALL_STATE(9253)] = 449767,
  [SMALL_STATE(9254)] = 449804,
  [SMALL_STATE(9255)] = 449841,
  [SMALL_STATE(9256)] = 449878,
  [SMALL_STATE(9257)] = 449915,
  [SMALL_STATE(9258)] = 449952,
  [SMALL_STATE(9259)] = 449989,
  [SMALL_STATE(9260)] = 450044,
  [SMALL_STATE(9261)] = 450099,
  [SMALL_STATE(9262)] = 450136,
  [SMALL_STATE(9263)] = 450173,
  [SMALL_STATE(9264)] = 450210,
  [SMALL_STATE(9265)] = 450247,
  [SMALL_STATE(9266)] = 450288,
  [SMALL_STATE(9267)] = 450343,
  [SMALL_STATE(9268)] = 450380,
  [SMALL_STATE(9269)] = 450435,
  [SMALL_STATE(9270)] = 450472,
  [SMALL_STATE(9271)] = 450509,
  [SMALL_STATE(9272)] = 450546,
  [SMALL_STATE(9273)] = 450583,
  [SMALL_STATE(9274)] = 450620,
  [SMALL_STATE(9275)] = 450657,
  [SMALL_STATE(9276)] = 450694,
  [SMALL_STATE(9277)] = 450731,
  [SMALL_STATE(9278)] = 450768,
  [SMALL_STATE(9279)] = 450805,
  [SMALL_STATE(9280)] = 450848,
  [SMALL_STATE(9281)] = 450885,
  [SMALL_STATE(9282)] = 450938,
  [SMALL_STATE(9283)] = 450975,
  [SMALL_STATE(9284)] = 451012,
  [SMALL_STATE(9285)] = 451049,
  [SMALL_STATE(9286)] = 451086,
  [SMALL_STATE(9287)] = 451141,
  [SMALL_STATE(9288)] = 451196,
  [SMALL_STATE(9289)] = 451235,
  [SMALL_STATE(9290)] = 451272,
  [SMALL_STATE(9291)] = 451311,
  [SMALL_STATE(9292)] = 451348,
  [SMALL_STATE(9293)] = 451403,
  [SMALL_STATE(9294)] = 451440,
  [SMALL_STATE(9295)] = 451477,
  [SMALL_STATE(9296)] = 451532,
  [SMALL_STATE(9297)] = 451571,
  [SMALL_STATE(9298)] = 451608,
  [SMALL_STATE(9299)] = 451645,
  [SMALL_STATE(9300)] = 451700,
  [SMALL_STATE(9301)] = 451737,
  [SMALL_STATE(9302)] = 451774,
  [SMALL_STATE(9303)] = 451811,
  [SMALL_STATE(9304)] = 451848,
  [SMALL_STATE(9305)] = 451903,
  [SMALL_STATE(9306)] = 451940,
  [SMALL_STATE(9307)] = 451995,
  [SMALL_STATE(9308)] = 452032,
  [SMALL_STATE(9309)] = 452069,
  [SMALL_STATE(9310)] = 452106,
  [SMALL_STATE(9311)] = 452143,
  [SMALL_STATE(9312)] = 452180,
  [SMALL_STATE(9313)] = 452233,
  [SMALL_STATE(9314)] = 452270,
  [SMALL_STATE(9315)] = 452325,
  [SMALL_STATE(9316)] = 452362,
  [SMALL_STATE(9317)] = 452415,
  [SMALL_STATE(9318)] = 452452,
  [SMALL_STATE(9319)] = 452489,
  [SMALL_STATE(9320)] = 452544,
  [SMALL_STATE(9321)] = 452599,
  [SMALL_STATE(9322)] = 452654,
  [SMALL_STATE(9323)] = 452691,
  [SMALL_STATE(9324)] = 452732,
  [SMALL_STATE(9325)] = 452787,
  [SMALL_STATE(9326)] = 452824,
  [SMALL_STATE(9327)] = 452861,
  [SMALL_STATE(9328)] = 452914,
  [SMALL_STATE(9329)] = 452951,
  [SMALL_STATE(9330)] = 453002,
  [SMALL_STATE(9331)] = 453039,
  [SMALL_STATE(9332)] = 453078,
  [SMALL_STATE(9333)] = 453115,
  [SMALL_STATE(9334)] = 453152,
  [SMALL_STATE(9335)] = 453189,
  [SMALL_STATE(9336)] = 453226,
  [SMALL_STATE(9337)] = 453281,
  [SMALL_STATE(9338)] = 453318,
  [SMALL_STATE(9339)] = 453355,
  [SMALL_STATE(9340)] = 453410,
  [SMALL_STATE(9341)] = 453453,
  [SMALL_STATE(9342)] = 453508,
  [SMALL_STATE(9343)] = 453563,
  [SMALL_STATE(9344)] = 453600,
  [SMALL_STATE(9345)] = 453637,
  [SMALL_STATE(9346)] = 453692,
  [SMALL_STATE(9347)] = 453729,
  [SMALL_STATE(9348)] = 453766,
  [SMALL_STATE(9349)] = 453803,
  [SMALL_STATE(9350)] = 453840,
  [SMALL_STATE(9351)] = 453877,
  [SMALL_STATE(9352)] = 453914,
  [SMALL_STATE(9353)] = 453955,
  [SMALL_STATE(9354)] = 453992,
  [SMALL_STATE(9355)] = 454031,
  [SMALL_STATE(9356)] = 454068,
  [SMALL_STATE(9357)] = 454105,
  [SMALL_STATE(9358)] = 454142,
  [SMALL_STATE(9359)] = 454179,
  [SMALL_STATE(9360)] = 454218,
  [SMALL_STATE(9361)] = 454257,
  [SMALL_STATE(9362)] = 454294,
  [SMALL_STATE(9363)] = 454337,
  [SMALL_STATE(9364)] = 454376,
  [SMALL_STATE(9365)] = 454417,
  [SMALL_STATE(9366)] = 454454,
  [SMALL_STATE(9367)] = 454493,
  [SMALL_STATE(9368)] = 454532,
  [SMALL_STATE(9369)] = 454575,
  [SMALL_STATE(9370)] = 454612,
  [SMALL_STATE(9371)] = 454649,
  [SMALL_STATE(9372)] = 454686,
  [SMALL_STATE(9373)] = 454723,
  [SMALL_STATE(9374)] = 454778,
  [SMALL_STATE(9375)] = 454833,
  [SMALL_STATE(9376)] = 454870,
  [SMALL_STATE(9377)] = 454923,
  [SMALL_STATE(9378)] = 454960,
  [SMALL_STATE(9379)] = 454997,
  [SMALL_STATE(9380)] = 455034,
  [SMALL_STATE(9381)] = 455071,
  [SMALL_STATE(9382)] = 455132,
  [SMALL_STATE(9383)] = 455169,
  [SMALL_STATE(9384)] = 455206,
  [SMALL_STATE(9385)] = 455243,
  [SMALL_STATE(9386)] = 455298,
  [SMALL_STATE(9387)] = 455339,
  [SMALL_STATE(9388)] = 455376,
  [SMALL_STATE(9389)] = 455431,
  [SMALL_STATE(9390)] = 455486,
  [SMALL_STATE(9391)] = 455523,
  [SMALL_STATE(9392)] = 455578,
  [SMALL_STATE(9393)] = 455615,
  [SMALL_STATE(9394)] = 455652,
  [SMALL_STATE(9395)] = 455689,
  [SMALL_STATE(9396)] = 455726,
  [SMALL_STATE(9397)] = 455763,
  [SMALL_STATE(9398)] = 455800,
  [SMALL_STATE(9399)] = 455855,
  [SMALL_STATE(9400)] = 455892,
  [SMALL_STATE(9401)] = 455929,
  [SMALL_STATE(9402)] = 455966,
  [SMALL_STATE(9403)] = 456003,
  [SMALL_STATE(9404)] = 456040,
  [SMALL_STATE(9405)] = 456077,
  [SMALL_STATE(9406)] = 456114,
  [SMALL_STATE(9407)] = 456169,
  [SMALL_STATE(9408)] = 456206,
  [SMALL_STATE(9409)] = 456261,
  [SMALL_STATE(9410)] = 456298,
  [SMALL_STATE(9411)] = 456337,
  [SMALL_STATE(9412)] = 456374,
  [SMALL_STATE(9413)] = 456423,
  [SMALL_STATE(9414)] = 456460,
  [SMALL_STATE(9415)] = 456499,
  [SMALL_STATE(9416)] = 456536,
  [SMALL_STATE(9417)] = 456591,
  [SMALL_STATE(9418)] = 456628,
  [SMALL_STATE(9419)] = 456683,
  [SMALL_STATE(9420)] = 456738,
  [SMALL_STATE(9421)] = 456775,
  [SMALL_STATE(9422)] = 456812,
  [SMALL_STATE(9423)] = 456851,
  [SMALL_STATE(9424)] = 456906,
  [SMALL_STATE(9425)] = 456943,
  [SMALL_STATE(9426)] = 456982,
  [SMALL_STATE(9427)] = 457019,
  [SMALL_STATE(9428)] = 457074,
  [SMALL_STATE(9429)] = 457111,
  [SMALL_STATE(9430)] = 457148,
  [SMALL_STATE(9431)] = 457185,
  [SMALL_STATE(9432)] = 457222,
  [SMALL_STATE(9433)] = 457277,
  [SMALL_STATE(9434)] = 457314,
  [SMALL_STATE(9435)] = 457351,
  [SMALL_STATE(9436)] = 457388,
  [SMALL_STATE(9437)] = 457425,
  [SMALL_STATE(9438)] = 457480,
  [SMALL_STATE(9439)] = 457517,
  [SMALL_STATE(9440)] = 457554,
  [SMALL_STATE(9441)] = 457591,
  [SMALL_STATE(9442)] = 457628,
  [SMALL_STATE(9443)] = 457665,
  [SMALL_STATE(9444)] = 457702,
  [SMALL_STATE(9445)] = 457757,
  [SMALL_STATE(9446)] = 457794,
  [SMALL_STATE(9447)] = 457831,
  [SMALL_STATE(9448)] = 457868,
  [SMALL_STATE(9449)] = 457923,
  [SMALL_STATE(9450)] = 457964,
  [SMALL_STATE(9451)] = 458003,
  [SMALL_STATE(9452)] = 458040,
  [SMALL_STATE(9453)] = 458077,
  [SMALL_STATE(9454)] = 458114,
  [SMALL_STATE(9455)] = 458151,
  [SMALL_STATE(9456)] = 458188,
  [SMALL_STATE(9457)] = 458229,
  [SMALL_STATE(9458)] = 458266,
  [SMALL_STATE(9459)] = 458303,
  [SMALL_STATE(9460)] = 458340,
  [SMALL_STATE(9461)] = 458377,
  [SMALL_STATE(9462)] = 458414,
  [SMALL_STATE(9463)] = 458469,
  [SMALL_STATE(9464)] = 458506,
  [SMALL_STATE(9465)] = 458543,
  [SMALL_STATE(9466)] = 458594,
  [SMALL_STATE(9467)] = 458649,
  [SMALL_STATE(9468)] = 458686,
  [SMALL_STATE(9469)] = 458723,
  [SMALL_STATE(9470)] = 458760,
  [SMALL_STATE(9471)] = 458815,
  [SMALL_STATE(9472)] = 458870,
  [SMALL_STATE(9473)] = 458925,
  [SMALL_STATE(9474)] = 458962,
  [SMALL_STATE(9475)] = 459017,
  [SMALL_STATE(9476)] = 459054,
  [SMALL_STATE(9477)] = 459091,
  [SMALL_STATE(9478)] = 459146,
  [SMALL_STATE(9479)] = 459187,
  [SMALL_STATE(9480)] = 459224,
  [SMALL_STATE(9481)] = 459261,
  [SMALL_STATE(9482)] = 459312,
  [SMALL_STATE(9483)] = 459349,
  [SMALL_STATE(9484)] = 459386,
  [SMALL_STATE(9485)] = 459423,
  [SMALL_STATE(9486)] = 459478,
  [SMALL_STATE(9487)] = 459517,
  [SMALL_STATE(9488)] = 459554,
  [SMALL_STATE(9489)] = 459605,
  [SMALL_STATE(9490)] = 459658,
  [SMALL_STATE(9491)] = 459713,
  [SMALL_STATE(9492)] = 459756,
  [SMALL_STATE(9493)] = 459795,
  [SMALL_STATE(9494)] = 459832,
  [SMALL_STATE(9495)] = 459869,
  [SMALL_STATE(9496)] = 459906,
  [SMALL_STATE(9497)] = 459943,
  [SMALL_STATE(9498)] = 459980,
  [SMALL_STATE(9499)] = 460017,
  [SMALL_STATE(9500)] = 460054,
  [SMALL_STATE(9501)] = 460091,
  [SMALL_STATE(9502)] = 460128,
  [SMALL_STATE(9503)] = 460165,
  [SMALL_STATE(9504)] = 460202,
  [SMALL_STATE(9505)] = 460245,
  [SMALL_STATE(9506)] = 460282,
  [SMALL_STATE(9507)] = 460319,
  [SMALL_STATE(9508)] = 460356,
  [SMALL_STATE(9509)] = 460393,
  [SMALL_STATE(9510)] = 460434,
  [SMALL_STATE(9511)] = 460471,
  [SMALL_STATE(9512)] = 460508,
  [SMALL_STATE(9513)] = 460549,
  [SMALL_STATE(9514)] = 460604,
  [SMALL_STATE(9515)] = 460641,
  [SMALL_STATE(9516)] = 460678,
  [SMALL_STATE(9517)] = 460715,
  [SMALL_STATE(9518)] = 460770,
  [SMALL_STATE(9519)] = 460809,
  [SMALL_STATE(9520)] = 460846,
  [SMALL_STATE(9521)] = 460901,
  [SMALL_STATE(9522)] = 460938,
  [SMALL_STATE(9523)] = 460975,
  [SMALL_STATE(9524)] = 461030,
  [SMALL_STATE(9525)] = 461067,
  [SMALL_STATE(9526)] = 461122,
  [SMALL_STATE(9527)] = 461159,
  [SMALL_STATE(9528)] = 461198,
  [SMALL_STATE(9529)] = 461253,
  [SMALL_STATE(9530)] = 461290,
  [SMALL_STATE(9531)] = 461327,
  [SMALL_STATE(9532)] = 461364,
  [SMALL_STATE(9533)] = 461405,
  [SMALL_STATE(9534)] = 461444,
  [SMALL_STATE(9535)] = 461499,
  [SMALL_STATE(9536)] = 461554,
  [SMALL_STATE(9537)] = 461609,
  [SMALL_STATE(9538)] = 461646,
  [SMALL_STATE(9539)] = 461683,
  [SMALL_STATE(9540)] = 461720,
  [SMALL_STATE(9541)] = 461757,
  [SMALL_STATE(9542)] = 461812,
  [SMALL_STATE(9543)] = 461867,
  [SMALL_STATE(9544)] = 461904,
  [SMALL_STATE(9545)] = 461941,
  [SMALL_STATE(9546)] = 461978,
  [SMALL_STATE(9547)] = 462015,
  [SMALL_STATE(9548)] = 462052,
  [SMALL_STATE(9549)] = 462089,
  [SMALL_STATE(9550)] = 462144,
  [SMALL_STATE(9551)] = 462185,
  [SMALL_STATE(9552)] = 462222,
  [SMALL_STATE(9553)] = 462259,
  [SMALL_STATE(9554)] = 462296,
  [SMALL_STATE(9555)] = 462351,
  [SMALL_STATE(9556)] = 462388,
  [SMALL_STATE(9557)] = 462425,
  [SMALL_STATE(9558)] = 462480,
  [SMALL_STATE(9559)] = 462517,
  [SMALL_STATE(9560)] = 462570,
  [SMALL_STATE(9561)] = 462607,
  [SMALL_STATE(9562)] = 462644,
  [SMALL_STATE(9563)] = 462681,
  [SMALL_STATE(9564)] = 462718,
  [SMALL_STATE(9565)] = 462769,
  [SMALL_STATE(9566)] = 462806,
  [SMALL_STATE(9567)] = 462843,
  [SMALL_STATE(9568)] = 462880,
  [SMALL_STATE(9569)] = 462945,
  [SMALL_STATE(9570)] = 462982,
  [SMALL_STATE(9571)] = 463031,
  [SMALL_STATE(9572)] = 463068,
  [SMALL_STATE(9573)] = 463111,
  [SMALL_STATE(9574)] = 463148,
  [SMALL_STATE(9575)] = 463197,
  [SMALL_STATE(9576)] = 463234,
  [SMALL_STATE(9577)] = 463289,
  [SMALL_STATE(9578)] = 463326,
  [SMALL_STATE(9579)] = 463363,
  [SMALL_STATE(9580)] = 463404,
  [SMALL_STATE(9581)] = 463441,
  [SMALL_STATE(9582)] = 463478,
  [SMALL_STATE(9583)] = 463515,
  [SMALL_STATE(9584)] = 463570,
  [SMALL_STATE(9585)] = 463625,
  [SMALL_STATE(9586)] = 463680,
  [SMALL_STATE(9587)] = 463717,
  [SMALL_STATE(9588)] = 463754,
  [SMALL_STATE(9589)] = 463794,
  [SMALL_STATE(9590)] = 463830,
  [SMALL_STATE(9591)] = 463880,
  [SMALL_STATE(9592)] = 463916,
  [SMALL_STATE(9593)] = 463952,
  [SMALL_STATE(9594)] = 463988,
  [SMALL_STATE(9595)] = 464024,
  [SMALL_STATE(9596)] = 464060,
  [SMALL_STATE(9597)] = 464106,
  [SMALL_STATE(9598)] = 464142,
  [SMALL_STATE(9599)] = 464178,
  [SMALL_STATE(9600)] = 464214,
  [SMALL_STATE(9601)] = 464260,
  [SMALL_STATE(9602)] = 464296,
  [SMALL_STATE(9603)] = 464332,
  [SMALL_STATE(9604)] = 464368,
  [SMALL_STATE(9605)] = 464404,
  [SMALL_STATE(9606)] = 464440,
  [SMALL_STATE(9607)] = 464476,
  [SMALL_STATE(9608)] = 464514,
  [SMALL_STATE(9609)] = 464550,
  [SMALL_STATE(9610)] = 464588,
  [SMALL_STATE(9611)] = 464624,
  [SMALL_STATE(9612)] = 464660,
  [SMALL_STATE(9613)] = 464696,
  [SMALL_STATE(9614)] = 464732,
  [SMALL_STATE(9615)] = 464768,
  [SMALL_STATE(9616)] = 464804,
  [SMALL_STATE(9617)] = 464840,
  [SMALL_STATE(9618)] = 464876,
  [SMALL_STATE(9619)] = 464912,
  [SMALL_STATE(9620)] = 464948,
  [SMALL_STATE(9621)] = 464984,
  [SMALL_STATE(9622)] = 465020,
  [SMALL_STATE(9623)] = 465056,
  [SMALL_STATE(9624)] = 465092,
  [SMALL_STATE(9625)] = 465128,
  [SMALL_STATE(9626)] = 465164,
  [SMALL_STATE(9627)] = 465200,
  [SMALL_STATE(9628)] = 465236,
  [SMALL_STATE(9629)] = 465272,
  [SMALL_STATE(9630)] = 465308,
  [SMALL_STATE(9631)] = 465344,
  [SMALL_STATE(9632)] = 465380,
  [SMALL_STATE(9633)] = 465416,
  [SMALL_STATE(9634)] = 465458,
  [SMALL_STATE(9635)] = 465496,
  [SMALL_STATE(9636)] = 465532,
  [SMALL_STATE(9637)] = 465568,
  [SMALL_STATE(9638)] = 465608,
  [SMALL_STATE(9639)] = 465644,
  [SMALL_STATE(9640)] = 465682,
  [SMALL_STATE(9641)] = 465718,
  [SMALL_STATE(9642)] = 465754,
  [SMALL_STATE(9643)] = 465790,
  [SMALL_STATE(9644)] = 465826,
  [SMALL_STATE(9645)] = 465862,
  [SMALL_STATE(9646)] = 465898,
  [SMALL_STATE(9647)] = 465934,
  [SMALL_STATE(9648)] = 465976,
  [SMALL_STATE(9649)] = 466012,
  [SMALL_STATE(9650)] = 466048,
  [SMALL_STATE(9651)] = 466084,
  [SMALL_STATE(9652)] = 466120,
  [SMALL_STATE(9653)] = 466156,
  [SMALL_STATE(9654)] = 466192,
  [SMALL_STATE(9655)] = 466230,
  [SMALL_STATE(9656)] = 466266,
  [SMALL_STATE(9657)] = 466302,
  [SMALL_STATE(9658)] = 466338,
  [SMALL_STATE(9659)] = 466374,
  [SMALL_STATE(9660)] = 466410,
  [SMALL_STATE(9661)] = 466452,
  [SMALL_STATE(9662)] = 466488,
  [SMALL_STATE(9663)] = 466524,
  [SMALL_STATE(9664)] = 466560,
  [SMALL_STATE(9665)] = 466596,
  [SMALL_STATE(9666)] = 466632,
  [SMALL_STATE(9667)] = 466668,
  [SMALL_STATE(9668)] = 466704,
  [SMALL_STATE(9669)] = 466740,
  [SMALL_STATE(9670)] = 466776,
  [SMALL_STATE(9671)] = 466828,
  [SMALL_STATE(9672)] = 466864,
  [SMALL_STATE(9673)] = 466900,
  [SMALL_STATE(9674)] = 466936,
  [SMALL_STATE(9675)] = 466972,
  [SMALL_STATE(9676)] = 467008,
  [SMALL_STATE(9677)] = 467044,
  [SMALL_STATE(9678)] = 467080,
  [SMALL_STATE(9679)] = 467118,
  [SMALL_STATE(9680)] = 467156,
  [SMALL_STATE(9681)] = 467192,
  [SMALL_STATE(9682)] = 467228,
  [SMALL_STATE(9683)] = 467264,
  [SMALL_STATE(9684)] = 467300,
  [SMALL_STATE(9685)] = 467336,
  [SMALL_STATE(9686)] = 467372,
  [SMALL_STATE(9687)] = 467408,
  [SMALL_STATE(9688)] = 467444,
  [SMALL_STATE(9689)] = 467480,
  [SMALL_STATE(9690)] = 467516,
  [SMALL_STATE(9691)] = 467552,
  [SMALL_STATE(9692)] = 467588,
  [SMALL_STATE(9693)] = 467628,
  [SMALL_STATE(9694)] = 467664,
  [SMALL_STATE(9695)] = 467700,
  [SMALL_STATE(9696)] = 467736,
  [SMALL_STATE(9697)] = 467772,
  [SMALL_STATE(9698)] = 467808,
  [SMALL_STATE(9699)] = 467844,
  [SMALL_STATE(9700)] = 467880,
  [SMALL_STATE(9701)] = 467922,
  [SMALL_STATE(9702)] = 467958,
  [SMALL_STATE(9703)] = 467994,
  [SMALL_STATE(9704)] = 468032,
  [SMALL_STATE(9705)] = 468068,
  [SMALL_STATE(9706)] = 468104,
  [SMALL_STATE(9707)] = 468146,
  [SMALL_STATE(9708)] = 468182,
  [SMALL_STATE(9709)] = 468232,
  [SMALL_STATE(9710)] = 468268,
  [SMALL_STATE(9711)] = 468304,
  [SMALL_STATE(9712)] = 468340,
  [SMALL_STATE(9713)] = 468382,
  [SMALL_STATE(9714)] = 468418,
  [SMALL_STATE(9715)] = 468454,
  [SMALL_STATE(9716)] = 468490,
  [SMALL_STATE(9717)] = 468526,
  [SMALL_STATE(9718)] = 468562,
  [SMALL_STATE(9719)] = 468598,
  [SMALL_STATE(9720)] = 468634,
  [SMALL_STATE(9721)] = 468674,
  [SMALL_STATE(9722)] = 468710,
  [SMALL_STATE(9723)] = 468762,
  [SMALL_STATE(9724)] = 468798,
  [SMALL_STATE(9725)] = 468834,
  [SMALL_STATE(9726)] = 468870,
  [SMALL_STATE(9727)] = 468906,
  [SMALL_STATE(9728)] = 468942,
  [SMALL_STATE(9729)] = 468978,
  [SMALL_STATE(9730)] = 469018,
  [SMALL_STATE(9731)] = 469056,
  [SMALL_STATE(9732)] = 469092,
  [SMALL_STATE(9733)] = 469128,
  [SMALL_STATE(9734)] = 469164,
  [SMALL_STATE(9735)] = 469212,
  [SMALL_STATE(9736)] = 469248,
  [SMALL_STATE(9737)] = 469284,
  [SMALL_STATE(9738)] = 469320,
  [SMALL_STATE(9739)] = 469356,
  [SMALL_STATE(9740)] = 469392,
  [SMALL_STATE(9741)] = 469428,
  [SMALL_STATE(9742)] = 469464,
  [SMALL_STATE(9743)] = 469506,
  [SMALL_STATE(9744)] = 469548,
  [SMALL_STATE(9745)] = 469584,
  [SMALL_STATE(9746)] = 469620,
  [SMALL_STATE(9747)] = 469656,
  [SMALL_STATE(9748)] = 469710,
  [SMALL_STATE(9749)] = 469746,
  [SMALL_STATE(9750)] = 469784,
  [SMALL_STATE(9751)] = 469824,
  [SMALL_STATE(9752)] = 469860,
  [SMALL_STATE(9753)] = 469896,
  [SMALL_STATE(9754)] = 469934,
  [SMALL_STATE(9755)] = 469980,
  [SMALL_STATE(9756)] = 470016,
  [SMALL_STATE(9757)] = 470052,
  [SMALL_STATE(9758)] = 470088,
  [SMALL_STATE(9759)] = 470128,
  [SMALL_STATE(9760)] = 470178,
  [SMALL_STATE(9761)] = 470214,
  [SMALL_STATE(9762)] = 470250,
  [SMALL_STATE(9763)] = 470296,
  [SMALL_STATE(9764)] = 470332,
  [SMALL_STATE(9765)] = 470372,
  [SMALL_STATE(9766)] = 470408,
  [SMALL_STATE(9767)] = 470444,
  [SMALL_STATE(9768)] = 470480,
  [SMALL_STATE(9769)] = 470520,
  [SMALL_STATE(9770)] = 470556,
  [SMALL_STATE(9771)] = 470592,
  [SMALL_STATE(9772)] = 470628,
  [SMALL_STATE(9773)] = 470664,
  [SMALL_STATE(9774)] = 470700,
  [SMALL_STATE(9775)] = 470736,
  [SMALL_STATE(9776)] = 470772,
  [SMALL_STATE(9777)] = 470808,
  [SMALL_STATE(9778)] = 470854,
  [SMALL_STATE(9779)] = 470890,
  [SMALL_STATE(9780)] = 470926,
  [SMALL_STATE(9781)] = 470976,
  [SMALL_STATE(9782)] = 471012,
  [SMALL_STATE(9783)] = 471048,
  [SMALL_STATE(9784)] = 471084,
  [SMALL_STATE(9785)] = 471130,
  [SMALL_STATE(9786)] = 471166,
  [SMALL_STATE(9787)] = 471202,
  [SMALL_STATE(9788)] = 471238,
  [SMALL_STATE(9789)] = 471274,
  [SMALL_STATE(9790)] = 471326,
  [SMALL_STATE(9791)] = 471362,
  [SMALL_STATE(9792)] = 471412,
  [SMALL_STATE(9793)] = 471458,
  [SMALL_STATE(9794)] = 471494,
  [SMALL_STATE(9795)] = 471546,
  [SMALL_STATE(9796)] = 471582,
  [SMALL_STATE(9797)] = 471640,
  [SMALL_STATE(9798)] = 471676,
  [SMALL_STATE(9799)] = 471712,
  [SMALL_STATE(9800)] = 471748,
  [SMALL_STATE(9801)] = 471784,
  [SMALL_STATE(9802)] = 471820,
  [SMALL_STATE(9803)] = 471856,
  [SMALL_STATE(9804)] = 471892,
  [SMALL_STATE(9805)] = 471928,
  [SMALL_STATE(9806)] = 471966,
  [SMALL_STATE(9807)] = 472002,
  [SMALL_STATE(9808)] = 472054,
  [SMALL_STATE(9809)] = 472090,
  [SMALL_STATE(9810)] = 472126,
  [SMALL_STATE(9811)] = 472172,
  [SMALL_STATE(9812)] = 472208,
  [SMALL_STATE(9813)] = 472244,
  [SMALL_STATE(9814)] = 472294,
  [SMALL_STATE(9815)] = 472340,
  [SMALL_STATE(9816)] = 472376,
  [SMALL_STATE(9817)] = 472412,
  [SMALL_STATE(9818)] = 472448,
  [SMALL_STATE(9819)] = 472484,
  [SMALL_STATE(9820)] = 472520,
  [SMALL_STATE(9821)] = 472556,
  [SMALL_STATE(9822)] = 472592,
  [SMALL_STATE(9823)] = 472628,
  [SMALL_STATE(9824)] = 472664,
  [SMALL_STATE(9825)] = 472700,
  [SMALL_STATE(9826)] = 472736,
  [SMALL_STATE(9827)] = 472772,
  [SMALL_STATE(9828)] = 472814,
  [SMALL_STATE(9829)] = 472850,
  [SMALL_STATE(9830)] = 472886,
  [SMALL_STATE(9831)] = 472922,
  [SMALL_STATE(9832)] = 472958,
  [SMALL_STATE(9833)] = 472994,
  [SMALL_STATE(9834)] = 473032,
  [SMALL_STATE(9835)] = 473068,
  [SMALL_STATE(9836)] = 473104,
  [SMALL_STATE(9837)] = 473140,
  [SMALL_STATE(9838)] = 473176,
  [SMALL_STATE(9839)] = 473228,
  [SMALL_STATE(9840)] = 473264,
  [SMALL_STATE(9841)] = 473300,
  [SMALL_STATE(9842)] = 473336,
  [SMALL_STATE(9843)] = 473372,
  [SMALL_STATE(9844)] = 473410,
  [SMALL_STATE(9845)] = 473452,
  [SMALL_STATE(9846)] = 473486,
  [SMALL_STATE(9847)] = 473522,
  [SMALL_STATE(9848)] = 473574,
  [SMALL_STATE(9849)] = 473610,
  [SMALL_STATE(9850)] = 473646,
  [SMALL_STATE(9851)] = 473692,
  [SMALL_STATE(9852)] = 473728,
  [SMALL_STATE(9853)] = 473770,
  [SMALL_STATE(9854)] = 473806,
  [SMALL_STATE(9855)] = 473842,
  [SMALL_STATE(9856)] = 473880,
  [SMALL_STATE(9857)] = 473922,
  [SMALL_STATE(9858)] = 473958,
  [SMALL_STATE(9859)] = 473994,
  [SMALL_STATE(9860)] = 474030,
  [SMALL_STATE(9861)] = 474066,
  [SMALL_STATE(9862)] = 474102,
  [SMALL_STATE(9863)] = 474154,
  [SMALL_STATE(9864)] = 474190,
  [SMALL_STATE(9865)] = 474236,
  [SMALL_STATE(9866)] = 474272,
  [SMALL_STATE(9867)] = 474308,
  [SMALL_STATE(9868)] = 474344,
  [SMALL_STATE(9869)] = 474380,
  [SMALL_STATE(9870)] = 474416,
  [SMALL_STATE(9871)] = 474452,
  [SMALL_STATE(9872)] = 474492,
  [SMALL_STATE(9873)] = 474528,
  [SMALL_STATE(9874)] = 474564,
  [SMALL_STATE(9875)] = 474600,
  [SMALL_STATE(9876)] = 474636,
  [SMALL_STATE(9877)] = 474672,
  [SMALL_STATE(9878)] = 474708,
  [SMALL_STATE(9879)] = 474744,
  [SMALL_STATE(9880)] = 474780,
  [SMALL_STATE(9881)] = 474816,
  [SMALL_STATE(9882)] = 474852,
  [SMALL_STATE(9883)] = 474888,
  [SMALL_STATE(9884)] = 474930,
  [SMALL_STATE(9885)] = 474970,
  [SMALL_STATE(9886)] = 475008,
  [SMALL_STATE(9887)] = 475044,
  [SMALL_STATE(9888)] = 475080,
  [SMALL_STATE(9889)] = 475116,
  [SMALL_STATE(9890)] = 475152,
  [SMALL_STATE(9891)] = 475192,
  [SMALL_STATE(9892)] = 475228,
  [SMALL_STATE(9893)] = 475266,
  [SMALL_STATE(9894)] = 475302,
  [SMALL_STATE(9895)] = 475338,
  [SMALL_STATE(9896)] = 475376,
  [SMALL_STATE(9897)] = 475426,
  [SMALL_STATE(9898)] = 475462,
  [SMALL_STATE(9899)] = 475498,
  [SMALL_STATE(9900)] = 475534,
  [SMALL_STATE(9901)] = 475580,
  [SMALL_STATE(9902)] = 475632,
  [SMALL_STATE(9903)] = 475672,
  [SMALL_STATE(9904)] = 475708,
  [SMALL_STATE(9905)] = 475744,
  [SMALL_STATE(9906)] = 475782,
  [SMALL_STATE(9907)] = 475828,
  [SMALL_STATE(9908)] = 475876,
  [SMALL_STATE(9909)] = 475912,
  [SMALL_STATE(9910)] = 475948,
  [SMALL_STATE(9911)] = 475984,
  [SMALL_STATE(9912)] = 476020,
  [SMALL_STATE(9913)] = 476056,
  [SMALL_STATE(9914)] = 476102,
  [SMALL_STATE(9915)] = 476138,
  [SMALL_STATE(9916)] = 476174,
  [SMALL_STATE(9917)] = 476210,
  [SMALL_STATE(9918)] = 476246,
  [SMALL_STATE(9919)] = 476282,
  [SMALL_STATE(9920)] = 476318,
  [SMALL_STATE(9921)] = 476354,
  [SMALL_STATE(9922)] = 476392,
  [SMALL_STATE(9923)] = 476442,
  [SMALL_STATE(9924)] = 476478,
  [SMALL_STATE(9925)] = 476514,
  [SMALL_STATE(9926)] = 476550,
  [SMALL_STATE(9927)] = 476586,
  [SMALL_STATE(9928)] = 476622,
  [SMALL_STATE(9929)] = 476674,
  [SMALL_STATE(9930)] = 476710,
  [SMALL_STATE(9931)] = 476746,
  [SMALL_STATE(9932)] = 476782,
  [SMALL_STATE(9933)] = 476818,
  [SMALL_STATE(9934)] = 476864,
  [SMALL_STATE(9935)] = 476900,
  [SMALL_STATE(9936)] = 476936,
  [SMALL_STATE(9937)] = 476976,
  [SMALL_STATE(9938)] = 477014,
  [SMALL_STATE(9939)] = 477050,
  [SMALL_STATE(9940)] = 477092,
  [SMALL_STATE(9941)] = 477132,
  [SMALL_STATE(9942)] = 477178,
  [SMALL_STATE(9943)] = 477214,
  [SMALL_STATE(9944)] = 477250,
  [SMALL_STATE(9945)] = 477286,
  [SMALL_STATE(9946)] = 477322,
  [SMALL_STATE(9947)] = 477358,
  [SMALL_STATE(9948)] = 477394,
  [SMALL_STATE(9949)] = 477430,
  [SMALL_STATE(9950)] = 477466,
  [SMALL_STATE(9951)] = 477502,
  [SMALL_STATE(9952)] = 477538,
  [SMALL_STATE(9953)] = 477574,
  [SMALL_STATE(9954)] = 477610,
  [SMALL_STATE(9955)] = 477646,
  [SMALL_STATE(9956)] = 477682,
  [SMALL_STATE(9957)] = 477734,
  [SMALL_STATE(9958)] = 477770,
  [SMALL_STATE(9959)] = 477806,
  [SMALL_STATE(9960)] = 477842,
  [SMALL_STATE(9961)] = 477878,
  [SMALL_STATE(9962)] = 477920,
  [SMALL_STATE(9963)] = 477956,
  [SMALL_STATE(9964)] = 477992,
  [SMALL_STATE(9965)] = 478028,
  [SMALL_STATE(9966)] = 478064,
  [SMALL_STATE(9967)] = 478116,
  [SMALL_STATE(9968)] = 478152,
  [SMALL_STATE(9969)] = 478188,
  [SMALL_STATE(9970)] = 478224,
  [SMALL_STATE(9971)] = 478262,
  [SMALL_STATE(9972)] = 478300,
  [SMALL_STATE(9973)] = 478346,
  [SMALL_STATE(9974)] = 478382,
  [SMALL_STATE(9975)] = 478418,
  [SMALL_STATE(9976)] = 478468,
  [SMALL_STATE(9977)] = 478504,
  [SMALL_STATE(9978)] = 478540,
  [SMALL_STATE(9979)] = 478578,
  [SMALL_STATE(9980)] = 478614,
  [SMALL_STATE(9981)] = 478656,
  [SMALL_STATE(9982)] = 478692,
  [SMALL_STATE(9983)] = 478734,
  [SMALL_STATE(9984)] = 478786,
  [SMALL_STATE(9985)] = 478822,
  [SMALL_STATE(9986)] = 478862,
  [SMALL_STATE(9987)] = 478898,
  [SMALL_STATE(9988)] = 478944,
  [SMALL_STATE(9989)] = 478984,
  [SMALL_STATE(9990)] = 479024,
  [SMALL_STATE(9991)] = 479060,
  [SMALL_STATE(9992)] = 479096,
  [SMALL_STATE(9993)] = 479136,
  [SMALL_STATE(9994)] = 479188,
  [SMALL_STATE(9995)] = 479240,
  [SMALL_STATE(9996)] = 479276,
  [SMALL_STATE(9997)] = 479312,
  [SMALL_STATE(9998)] = 479348,
  [SMALL_STATE(9999)] = 479394,
  [SMALL_STATE(10000)] = 479430,
  [SMALL_STATE(10001)] = 479466,
  [SMALL_STATE(10002)] = 479502,
  [SMALL_STATE(10003)] = 479538,
  [SMALL_STATE(10004)] = 479584,
  [SMALL_STATE(10005)] = 479636,
  [SMALL_STATE(10006)] = 479672,
  [SMALL_STATE(10007)] = 479708,
  [SMALL_STATE(10008)] = 479758,
  [SMALL_STATE(10009)] = 479810,
  [SMALL_STATE(10010)] = 479846,
  [SMALL_STATE(10011)] = 479882,
  [SMALL_STATE(10012)] = 479917,
  [SMALL_STATE(10013)] = 479952,
  [SMALL_STATE(10014)] = 479987,
  [SMALL_STATE(10015)] = 480022,
  [SMALL_STATE(10016)] = 480083,
  [SMALL_STATE(10017)] = 480118,
  [SMALL_STATE(10018)] = 480159,
  [SMALL_STATE(10019)] = 480194,
  [SMALL_STATE(10020)] = 480255,
  [SMALL_STATE(10021)] = 480292,
  [SMALL_STATE(10022)] = 480327,
  [SMALL_STATE(10023)] = 480362,
  [SMALL_STATE(10024)] = 480397,
  [SMALL_STATE(10025)] = 480448,
  [SMALL_STATE(10026)] = 480489,
  [SMALL_STATE(10027)] = 480526,
  [SMALL_STATE(10028)] = 480561,
  [SMALL_STATE(10029)] = 480596,
  [SMALL_STATE(10030)] = 480631,
  [SMALL_STATE(10031)] = 480666,
  [SMALL_STATE(10032)] = 480701,
  [SMALL_STATE(10033)] = 480736,
  [SMALL_STATE(10034)] = 480771,
  [SMALL_STATE(10035)] = 480806,
  [SMALL_STATE(10036)] = 480841,
  [SMALL_STATE(10037)] = 480890,
  [SMALL_STATE(10038)] = 480925,
  [SMALL_STATE(10039)] = 480960,
  [SMALL_STATE(10040)] = 480999,
  [SMALL_STATE(10041)] = 481038,
  [SMALL_STATE(10042)] = 481073,
  [SMALL_STATE(10043)] = 481108,
  [SMALL_STATE(10044)] = 481145,
  [SMALL_STATE(10045)] = 481184,
  [SMALL_STATE(10046)] = 481219,
  [SMALL_STATE(10047)] = 481280,
  [SMALL_STATE(10048)] = 481315,
  [SMALL_STATE(10049)] = 481350,
  [SMALL_STATE(10050)] = 481385,
  [SMALL_STATE(10051)] = 481436,
  [SMALL_STATE(10052)] = 481471,
  [SMALL_STATE(10053)] = 481506,
  [SMALL_STATE(10054)] = 481541,
  [SMALL_STATE(10055)] = 481576,
  [SMALL_STATE(10056)] = 481611,
  [SMALL_STATE(10057)] = 481646,
  [SMALL_STATE(10058)] = 481683,
  [SMALL_STATE(10059)] = 481718,
  [SMALL_STATE(10060)] = 481779,
  [SMALL_STATE(10061)] = 481818,
  [SMALL_STATE(10062)] = 481853,
  [SMALL_STATE(10063)] = 481888,
  [SMALL_STATE(10064)] = 481925,
  [SMALL_STATE(10065)] = 481960,
  [SMALL_STATE(10066)] = 481995,
  [SMALL_STATE(10067)] = 482030,
  [SMALL_STATE(10068)] = 482065,
  [SMALL_STATE(10069)] = 482100,
  [SMALL_STATE(10070)] = 482141,
  [SMALL_STATE(10071)] = 482176,
  [SMALL_STATE(10072)] = 482217,
  [SMALL_STATE(10073)] = 482252,
  [SMALL_STATE(10074)] = 482287,
  [SMALL_STATE(10075)] = 482322,
  [SMALL_STATE(10076)] = 482357,
  [SMALL_STATE(10077)] = 482392,
  [SMALL_STATE(10078)] = 482427,
  [SMALL_STATE(10079)] = 482462,
  [SMALL_STATE(10080)] = 482503,
  [SMALL_STATE(10081)] = 482538,
  [SMALL_STATE(10082)] = 482573,
  [SMALL_STATE(10083)] = 482608,
  [SMALL_STATE(10084)] = 482643,
  [SMALL_STATE(10085)] = 482678,
  [SMALL_STATE(10086)] = 482713,
  [SMALL_STATE(10087)] = 482748,
  [SMALL_STATE(10088)] = 482783,
  [SMALL_STATE(10089)] = 482818,
  [SMALL_STATE(10090)] = 482853,
  [SMALL_STATE(10091)] = 482914,
  [SMALL_STATE(10092)] = 482965,
  [SMALL_STATE(10093)] = 483000,
  [SMALL_STATE(10094)] = 483039,
  [SMALL_STATE(10095)] = 483088,
  [SMALL_STATE(10096)] = 483139,
  [SMALL_STATE(10097)] = 483178,
  [SMALL_STATE(10098)] = 483213,
  [SMALL_STATE(10099)] = 483274,
  [SMALL_STATE(10100)] = 483309,
  [SMALL_STATE(10101)] = 483344,
  [SMALL_STATE(10102)] = 483381,
  [SMALL_STATE(10103)] = 483416,
  [SMALL_STATE(10104)] = 483477,
  [SMALL_STATE(10105)] = 483512,
  [SMALL_STATE(10106)] = 483573,
  [SMALL_STATE(10107)] = 483608,
  [SMALL_STATE(10108)] = 483643,
  [SMALL_STATE(10109)] = 483678,
  [SMALL_STATE(10110)] = 483713,
  [SMALL_STATE(10111)] = 483748,
  [SMALL_STATE(10112)] = 483783,
  [SMALL_STATE(10113)] = 483818,
  [SMALL_STATE(10114)] = 483853,
  [SMALL_STATE(10115)] = 483892,
  [SMALL_STATE(10116)] = 483927,
  [SMALL_STATE(10117)] = 483962,
  [SMALL_STATE(10118)] = 484005,
  [SMALL_STATE(10119)] = 484040,
  [SMALL_STATE(10120)] = 484075,
  [SMALL_STATE(10121)] = 484114,
  [SMALL_STATE(10122)] = 484165,
  [SMALL_STATE(10123)] = 484226,
  [SMALL_STATE(10124)] = 484261,
  [SMALL_STATE(10125)] = 484296,
  [SMALL_STATE(10126)] = 484335,
  [SMALL_STATE(10127)] = 484370,
  [SMALL_STATE(10128)] = 484405,
  [SMALL_STATE(10129)] = 484440,
  [SMALL_STATE(10130)] = 484479,
  [SMALL_STATE(10131)] = 484514,
  [SMALL_STATE(10132)] = 484549,
  [SMALL_STATE(10133)] = 484610,
  [SMALL_STATE(10134)] = 484645,
  [SMALL_STATE(10135)] = 484680,
  [SMALL_STATE(10136)] = 484729,
  [SMALL_STATE(10137)] = 484768,
  [SMALL_STATE(10138)] = 484829,
  [SMALL_STATE(10139)] = 484864,
  [SMALL_STATE(10140)] = 484899,
  [SMALL_STATE(10141)] = 484934,
  [SMALL_STATE(10142)] = 484969,
  [SMALL_STATE(10143)] = 485010,
  [SMALL_STATE(10144)] = 485045,
  [SMALL_STATE(10145)] = 485080,
  [SMALL_STATE(10146)] = 485115,
  [SMALL_STATE(10147)] = 485174,
  [SMALL_STATE(10148)] = 485233,
  [SMALL_STATE(10149)] = 485268,
  [SMALL_STATE(10150)] = 485303,
  [SMALL_STATE(10151)] = 485338,
  [SMALL_STATE(10152)] = 485379,
  [SMALL_STATE(10153)] = 485414,
  [SMALL_STATE(10154)] = 485449,
  [SMALL_STATE(10155)] = 485484,
  [SMALL_STATE(10156)] = 485521,
  [SMALL_STATE(10157)] = 485560,
  [SMALL_STATE(10158)] = 485595,
  [SMALL_STATE(10159)] = 485636,
  [SMALL_STATE(10160)] = 485671,
  [SMALL_STATE(10161)] = 485706,
  [SMALL_STATE(10162)] = 485743,
  [SMALL_STATE(10163)] = 485794,
  [SMALL_STATE(10164)] = 485829,
  [SMALL_STATE(10165)] = 485864,
  [SMALL_STATE(10166)] = 485899,
  [SMALL_STATE(10167)] = 485938,
  [SMALL_STATE(10168)] = 485973,
  [SMALL_STATE(10169)] = 486024,
  [SMALL_STATE(10170)] = 486059,
  [SMALL_STATE(10171)] = 486094,
  [SMALL_STATE(10172)] = 486145,
  [SMALL_STATE(10173)] = 486180,
  [SMALL_STATE(10174)] = 486215,
  [SMALL_STATE(10175)] = 486250,
  [SMALL_STATE(10176)] = 486285,
  [SMALL_STATE(10177)] = 486320,
  [SMALL_STATE(10178)] = 486355,
  [SMALL_STATE(10179)] = 486394,
  [SMALL_STATE(10180)] = 486433,
  [SMALL_STATE(10181)] = 486470,
  [SMALL_STATE(10182)] = 486507,
  [SMALL_STATE(10183)] = 486568,
  [SMALL_STATE(10184)] = 486603,
  [SMALL_STATE(10185)] = 486638,
  [SMALL_STATE(10186)] = 486673,
  [SMALL_STATE(10187)] = 486708,
  [SMALL_STATE(10188)] = 486743,
  [SMALL_STATE(10189)] = 486782,
  [SMALL_STATE(10190)] = 486817,
  [SMALL_STATE(10191)] = 486852,
  [SMALL_STATE(10192)] = 486887,
  [SMALL_STATE(10193)] = 486926,
  [SMALL_STATE(10194)] = 486961,
  [SMALL_STATE(10195)] = 487010,
  [SMALL_STATE(10196)] = 487045,
  [SMALL_STATE(10197)] = 487080,
  [SMALL_STATE(10198)] = 487119,
  [SMALL_STATE(10199)] = 487154,
  [SMALL_STATE(10200)] = 487189,
  [SMALL_STATE(10201)] = 487224,
  [SMALL_STATE(10202)] = 487259,
  [SMALL_STATE(10203)] = 487294,
  [SMALL_STATE(10204)] = 487355,
  [SMALL_STATE(10205)] = 487396,
  [SMALL_STATE(10206)] = 487433,
  [SMALL_STATE(10207)] = 487468,
  [SMALL_STATE(10208)] = 487503,
  [SMALL_STATE(10209)] = 487538,
  [SMALL_STATE(10210)] = 487573,
  [SMALL_STATE(10211)] = 487608,
  [SMALL_STATE(10212)] = 487643,
  [SMALL_STATE(10213)] = 487678,
  [SMALL_STATE(10214)] = 487717,
  [SMALL_STATE(10215)] = 487754,
  [SMALL_STATE(10216)] = 487805,
  [SMALL_STATE(10217)] = 487856,
  [SMALL_STATE(10218)] = 487891,
  [SMALL_STATE(10219)] = 487928,
  [SMALL_STATE(10220)] = 487963,
  [SMALL_STATE(10221)] = 488002,
  [SMALL_STATE(10222)] = 488041,
  [SMALL_STATE(10223)] = 488076,
  [SMALL_STATE(10224)] = 488111,
  [SMALL_STATE(10225)] = 488146,
  [SMALL_STATE(10226)] = 488185,
  [SMALL_STATE(10227)] = 488220,
  [SMALL_STATE(10228)] = 488255,
  [SMALL_STATE(10229)] = 488290,
  [SMALL_STATE(10230)] = 488339,
  [SMALL_STATE(10231)] = 488374,
  [SMALL_STATE(10232)] = 488409,
  [SMALL_STATE(10233)] = 488458,
  [SMALL_STATE(10234)] = 488497,
  [SMALL_STATE(10235)] = 488536,
  [SMALL_STATE(10236)] = 488571,
  [SMALL_STATE(10237)] = 488606,
  [SMALL_STATE(10238)] = 488641,
  [SMALL_STATE(10239)] = 488680,
  [SMALL_STATE(10240)] = 488715,
  [SMALL_STATE(10241)] = 488750,
  [SMALL_STATE(10242)] = 488791,
  [SMALL_STATE(10243)] = 488826,
  [SMALL_STATE(10244)] = 488861,
  [SMALL_STATE(10245)] = 488896,
  [SMALL_STATE(10246)] = 488937,
  [SMALL_STATE(10247)] = 488972,
  [SMALL_STATE(10248)] = 489007,
  [SMALL_STATE(10249)] = 489042,
  [SMALL_STATE(10250)] = 489077,
  [SMALL_STATE(10251)] = 489112,
  [SMALL_STATE(10252)] = 489147,
  [SMALL_STATE(10253)] = 489182,
  [SMALL_STATE(10254)] = 489217,
  [SMALL_STATE(10255)] = 489252,
  [SMALL_STATE(10256)] = 489287,
  [SMALL_STATE(10257)] = 489328,
  [SMALL_STATE(10258)] = 489379,
  [SMALL_STATE(10259)] = 489414,
  [SMALL_STATE(10260)] = 489455,
  [SMALL_STATE(10261)] = 489490,
  [SMALL_STATE(10262)] = 489543,
  [SMALL_STATE(10263)] = 489604,
  [SMALL_STATE(10264)] = 489639,
  [SMALL_STATE(10265)] = 489674,
  [SMALL_STATE(10266)] = 489713,
  [SMALL_STATE(10267)] = 489752,
  [SMALL_STATE(10268)] = 489787,
  [SMALL_STATE(10269)] = 489826,
  [SMALL_STATE(10270)] = 489861,
  [SMALL_STATE(10271)] = 489896,
  [SMALL_STATE(10272)] = 489937,
  [SMALL_STATE(10273)] = 489978,
  [SMALL_STATE(10274)] = 490013,
  [SMALL_STATE(10275)] = 490048,
  [SMALL_STATE(10276)] = 490083,
  [SMALL_STATE(10277)] = 490118,
  [SMALL_STATE(10278)] = 490153,
  [SMALL_STATE(10279)] = 490192,
  [SMALL_STATE(10280)] = 490227,
  [SMALL_STATE(10281)] = 490262,
  [SMALL_STATE(10282)] = 490297,
  [SMALL_STATE(10283)] = 490336,
  [SMALL_STATE(10284)] = 490371,
  [SMALL_STATE(10285)] = 490406,
  [SMALL_STATE(10286)] = 490441,
  [SMALL_STATE(10287)] = 490492,
  [SMALL_STATE(10288)] = 490533,
  [SMALL_STATE(10289)] = 490568,
  [SMALL_STATE(10290)] = 490607,
  [SMALL_STATE(10291)] = 490642,
  [SMALL_STATE(10292)] = 490703,
  [SMALL_STATE(10293)] = 490738,
  [SMALL_STATE(10294)] = 490773,
  [SMALL_STATE(10295)] = 490808,
  [SMALL_STATE(10296)] = 490843,
  [SMALL_STATE(10297)] = 490878,
  [SMALL_STATE(10298)] = 490913,
  [SMALL_STATE(10299)] = 490946,
  [SMALL_STATE(10300)] = 490981,
  [SMALL_STATE(10301)] = 491030,
  [SMALL_STATE(10302)] = 491081,
  [SMALL_STATE(10303)] = 491116,
  [SMALL_STATE(10304)] = 491151,
  [SMALL_STATE(10305)] = 491186,
  [SMALL_STATE(10306)] = 491221,
  [SMALL_STATE(10307)] = 491256,
  [SMALL_STATE(10308)] = 491291,
  [SMALL_STATE(10309)] = 491326,
  [SMALL_STATE(10310)] = 491387,
  [SMALL_STATE(10311)] = 491426,
  [SMALL_STATE(10312)] = 491461,
  [SMALL_STATE(10313)] = 491496,
  [SMALL_STATE(10314)] = 491531,
  [SMALL_STATE(10315)] = 491592,
  [SMALL_STATE(10316)] = 491627,
  [SMALL_STATE(10317)] = 491662,
  [SMALL_STATE(10318)] = 491697,
  [SMALL_STATE(10319)] = 491748,
  [SMALL_STATE(10320)] = 491783,
  [SMALL_STATE(10321)] = 491818,
  [SMALL_STATE(10322)] = 491853,
  [SMALL_STATE(10323)] = 491888,
  [SMALL_STATE(10324)] = 491923,
  [SMALL_STATE(10325)] = 491984,
  [SMALL_STATE(10326)] = 492033,
  [SMALL_STATE(10327)] = 492094,
  [SMALL_STATE(10328)] = 492145,
  [SMALL_STATE(10329)] = 492180,
  [SMALL_STATE(10330)] = 492219,
  [SMALL_STATE(10331)] = 492254,
  [SMALL_STATE(10332)] = 492289,
  [SMALL_STATE(10333)] = 492350,
  [SMALL_STATE(10334)] = 492385,
  [SMALL_STATE(10335)] = 492420,
  [SMALL_STATE(10336)] = 492461,
  [SMALL_STATE(10337)] = 492496,
  [SMALL_STATE(10338)] = 492531,
  [SMALL_STATE(10339)] = 492566,
  [SMALL_STATE(10340)] = 492601,
  [SMALL_STATE(10341)] = 492636,
  [SMALL_STATE(10342)] = 492671,
  [SMALL_STATE(10343)] = 492706,
  [SMALL_STATE(10344)] = 492757,
  [SMALL_STATE(10345)] = 492792,
  [SMALL_STATE(10346)] = 492827,
  [SMALL_STATE(10347)] = 492862,
  [SMALL_STATE(10348)] = 492913,
  [SMALL_STATE(10349)] = 492954,
  [SMALL_STATE(10350)] = 492989,
  [SMALL_STATE(10351)] = 493028,
  [SMALL_STATE(10352)] = 493063,
  [SMALL_STATE(10353)] = 493098,
  [SMALL_STATE(10354)] = 493133,
  [SMALL_STATE(10355)] = 493168,
  [SMALL_STATE(10356)] = 493207,
  [SMALL_STATE(10357)] = 493242,
  [SMALL_STATE(10358)] = 493277,
  [SMALL_STATE(10359)] = 493338,
  [SMALL_STATE(10360)] = 493373,
  [SMALL_STATE(10361)] = 493408,
  [SMALL_STATE(10362)] = 493447,
  [SMALL_STATE(10363)] = 493482,
  [SMALL_STATE(10364)] = 493517,
  [SMALL_STATE(10365)] = 493552,
  [SMALL_STATE(10366)] = 493602,
  [SMALL_STATE(10367)] = 493636,
  [SMALL_STATE(10368)] = 493670,
  [SMALL_STATE(10369)] = 493720,
  [SMALL_STATE(10370)] = 493770,
  [SMALL_STATE(10371)] = 493804,
  [SMALL_STATE(10372)] = 493842,
  [SMALL_STATE(10373)] = 493876,
  [SMALL_STATE(10374)] = 493910,
  [SMALL_STATE(10375)] = 493944,
  [SMALL_STATE(10376)] = 493978,
  [SMALL_STATE(10377)] = 494012,
  [SMALL_STATE(10378)] = 494046,
  [SMALL_STATE(10379)] = 494080,
  [SMALL_STATE(10380)] = 494132,
  [SMALL_STATE(10381)] = 494166,
  [SMALL_STATE(10382)] = 494200,
  [SMALL_STATE(10383)] = 494234,
  [SMALL_STATE(10384)] = 494268,
  [SMALL_STATE(10385)] = 494302,
  [SMALL_STATE(10386)] = 494340,
  [SMALL_STATE(10387)] = 494376,
  [SMALL_STATE(10388)] = 494410,
  [SMALL_STATE(10389)] = 494444,
  [SMALL_STATE(10390)] = 494496,
  [SMALL_STATE(10391)] = 494530,
  [SMALL_STATE(10392)] = 494564,
  [SMALL_STATE(10393)] = 494598,
  [SMALL_STATE(10394)] = 494632,
  [SMALL_STATE(10395)] = 494666,
  [SMALL_STATE(10396)] = 494700,
  [SMALL_STATE(10397)] = 494734,
  [SMALL_STATE(10398)] = 494768,
  [SMALL_STATE(10399)] = 494802,
  [SMALL_STATE(10400)] = 494838,
  [SMALL_STATE(10401)] = 494872,
  [SMALL_STATE(10402)] = 494906,
  [SMALL_STATE(10403)] = 494940,
  [SMALL_STATE(10404)] = 494990,
  [SMALL_STATE(10405)] = 495026,
  [SMALL_STATE(10406)] = 495070,
  [SMALL_STATE(10407)] = 495104,
  [SMALL_STATE(10408)] = 495140,
  [SMALL_STATE(10409)] = 495196,
  [SMALL_STATE(10410)] = 495236,
  [SMALL_STATE(10411)] = 495270,
  [SMALL_STATE(10412)] = 495314,
  [SMALL_STATE(10413)] = 495364,
  [SMALL_STATE(10414)] = 495400,
  [SMALL_STATE(10415)] = 495434,
  [SMALL_STATE(10416)] = 495468,
  [SMALL_STATE(10417)] = 495502,
  [SMALL_STATE(10418)] = 495542,
  [SMALL_STATE(10419)] = 495578,
  [SMALL_STATE(10420)] = 495612,
  [SMALL_STATE(10421)] = 495646,
  [SMALL_STATE(10422)] = 495680,
  [SMALL_STATE(10423)] = 495714,
  [SMALL_STATE(10424)] = 495766,
  [SMALL_STATE(10425)] = 495818,
  [SMALL_STATE(10426)] = 495852,
  [SMALL_STATE(10427)] = 495886,
  [SMALL_STATE(10428)] = 495920,
  [SMALL_STATE(10429)] = 495954,
  [SMALL_STATE(10430)] = 496002,
  [SMALL_STATE(10431)] = 496054,
  [SMALL_STATE(10432)] = 496094,
  [SMALL_STATE(10433)] = 496130,
  [SMALL_STATE(10434)] = 496166,
  [SMALL_STATE(10435)] = 496200,
  [SMALL_STATE(10436)] = 496234,
  [SMALL_STATE(10437)] = 496268,
  [SMALL_STATE(10438)] = 496308,
  [SMALL_STATE(10439)] = 496364,
  [SMALL_STATE(10440)] = 496398,
  [SMALL_STATE(10441)] = 496432,
  [SMALL_STATE(10442)] = 496466,
  [SMALL_STATE(10443)] = 496516,
  [SMALL_STATE(10444)] = 496568,
  [SMALL_STATE(10445)] = 496602,
  [SMALL_STATE(10446)] = 496636,
  [SMALL_STATE(10447)] = 496670,
  [SMALL_STATE(10448)] = 496704,
  [SMALL_STATE(10449)] = 496756,
  [SMALL_STATE(10450)] = 496792,
  [SMALL_STATE(10451)] = 496826,
  [SMALL_STATE(10452)] = 496860,
  [SMALL_STATE(10453)] = 496894,
  [SMALL_STATE(10454)] = 496934,
  [SMALL_STATE(10455)] = 496968,
  [SMALL_STATE(10456)] = 497002,
  [SMALL_STATE(10457)] = 497042,
  [SMALL_STATE(10458)] = 497078,
  [SMALL_STATE(10459)] = 497130,
  [SMALL_STATE(10460)] = 497182,
  [SMALL_STATE(10461)] = 497216,
  [SMALL_STATE(10462)] = 497250,
  [SMALL_STATE(10463)] = 497286,
  [SMALL_STATE(10464)] = 497320,
  [SMALL_STATE(10465)] = 497360,
  [SMALL_STATE(10466)] = 497394,
  [SMALL_STATE(10467)] = 497430,
  [SMALL_STATE(10468)] = 497490,
  [SMALL_STATE(10469)] = 497524,
  [SMALL_STATE(10470)] = 497558,
  [SMALL_STATE(10471)] = 497592,
  [SMALL_STATE(10472)] = 497644,
  [SMALL_STATE(10473)] = 497680,
  [SMALL_STATE(10474)] = 497714,
  [SMALL_STATE(10475)] = 497754,
  [SMALL_STATE(10476)] = 497788,
  [SMALL_STATE(10477)] = 497832,
  [SMALL_STATE(10478)] = 497866,
  [SMALL_STATE(10479)] = 497900,
  [SMALL_STATE(10480)] = 497934,
  [SMALL_STATE(10481)] = 497986,
  [SMALL_STATE(10482)] = 498020,
  [SMALL_STATE(10483)] = 498054,
  [SMALL_STATE(10484)] = 498090,
  [SMALL_STATE(10485)] = 498130,
  [SMALL_STATE(10486)] = 498168,
  [SMALL_STATE(10487)] = 498220,
  [SMALL_STATE(10488)] = 498268,
  [SMALL_STATE(10489)] = 498302,
  [SMALL_STATE(10490)] = 498352,
  [SMALL_STATE(10491)] = 498386,
  [SMALL_STATE(10492)] = 498420,
  [SMALL_STATE(10493)] = 498472,
  [SMALL_STATE(10494)] = 498508,
  [SMALL_STATE(10495)] = 498542,
  [SMALL_STATE(10496)] = 498582,
  [SMALL_STATE(10497)] = 498634,
  [SMALL_STATE(10498)] = 498682,
  [SMALL_STATE(10499)] = 498732,
  [SMALL_STATE(10500)] = 498766,
  [SMALL_STATE(10501)] = 498802,
  [SMALL_STATE(10502)] = 498854,
  [SMALL_STATE(10503)] = 498888,
  [SMALL_STATE(10504)] = 498922,
  [SMALL_STATE(10505)] = 498958,
  [SMALL_STATE(10506)] = 498994,
  [SMALL_STATE(10507)] = 499028,
  [SMALL_STATE(10508)] = 499062,
  [SMALL_STATE(10509)] = 499118,
  [SMALL_STATE(10510)] = 499154,
  [SMALL_STATE(10511)] = 499188,
  [SMALL_STATE(10512)] = 499238,
  [SMALL_STATE(10513)] = 499272,
  [SMALL_STATE(10514)] = 499322,
  [SMALL_STATE(10515)] = 499382,
  [SMALL_STATE(10516)] = 499438,
  [SMALL_STATE(10517)] = 499490,
  [SMALL_STATE(10518)] = 499524,
  [SMALL_STATE(10519)] = 499558,
  [SMALL_STATE(10520)] = 499592,
  [SMALL_STATE(10521)] = 499628,
  [SMALL_STATE(10522)] = 499662,
  [SMALL_STATE(10523)] = 499696,
  [SMALL_STATE(10524)] = 499748,
  [SMALL_STATE(10525)] = 499782,
  [SMALL_STATE(10526)] = 499834,
  [SMALL_STATE(10527)] = 499868,
  [SMALL_STATE(10528)] = 499902,
  [SMALL_STATE(10529)] = 499936,
  [SMALL_STATE(10530)] = 499970,
  [SMALL_STATE(10531)] = 500008,
  [SMALL_STATE(10532)] = 500042,
  [SMALL_STATE(10533)] = 500076,
  [SMALL_STATE(10534)] = 500110,
  [SMALL_STATE(10535)] = 500144,
  [SMALL_STATE(10536)] = 500200,
  [SMALL_STATE(10537)] = 500250,
  [SMALL_STATE(10538)] = 500302,
  [SMALL_STATE(10539)] = 500336,
  [SMALL_STATE(10540)] = 500370,
  [SMALL_STATE(10541)] = 500406,
  [SMALL_STATE(10542)] = 500454,
  [SMALL_STATE(10543)] = 500488,
  [SMALL_STATE(10544)] = 500522,
  [SMALL_STATE(10545)] = 500556,
  [SMALL_STATE(10546)] = 500590,
  [SMALL_STATE(10547)] = 500624,
  [SMALL_STATE(10548)] = 500658,
  [SMALL_STATE(10549)] = 500714,
  [SMALL_STATE(10550)] = 500748,
  [SMALL_STATE(10551)] = 500782,
  [SMALL_STATE(10552)] = 500816,
  [SMALL_STATE(10553)] = 500850,
  [SMALL_STATE(10554)] = 500884,
  [SMALL_STATE(10555)] = 500918,
  [SMALL_STATE(10556)] = 500958,
  [SMALL_STATE(10557)] = 500992,
  [SMALL_STATE(10558)] = 501026,
  [SMALL_STATE(10559)] = 501062,
  [SMALL_STATE(10560)] = 501098,
  [SMALL_STATE(10561)] = 501138,
  [SMALL_STATE(10562)] = 501172,
  [SMALL_STATE(10563)] = 501206,
  [SMALL_STATE(10564)] = 501240,
  [SMALL_STATE(10565)] = 501292,
  [SMALL_STATE(10566)] = 501328,
  [SMALL_STATE(10567)] = 501368,
  [SMALL_STATE(10568)] = 501402,
  [SMALL_STATE(10569)] = 501454,
  [SMALL_STATE(10570)] = 501488,
  [SMALL_STATE(10571)] = 501522,
  [SMALL_STATE(10572)] = 501556,
  [SMALL_STATE(10573)] = 501590,
  [SMALL_STATE(10574)] = 501624,
  [SMALL_STATE(10575)] = 501658,
  [SMALL_STATE(10576)] = 501692,
  [SMALL_STATE(10577)] = 501744,
  [SMALL_STATE(10578)] = 501778,
  [SMALL_STATE(10579)] = 501814,
  [SMALL_STATE(10580)] = 501850,
  [SMALL_STATE(10581)] = 501902,
  [SMALL_STATE(10582)] = 501936,
  [SMALL_STATE(10583)] = 501970,
  [SMALL_STATE(10584)] = 502004,
  [SMALL_STATE(10585)] = 502056,
  [SMALL_STATE(10586)] = 502090,
  [SMALL_STATE(10587)] = 502124,
  [SMALL_STATE(10588)] = 502158,
  [SMALL_STATE(10589)] = 502192,
  [SMALL_STATE(10590)] = 502228,
  [SMALL_STATE(10591)] = 502278,
  [SMALL_STATE(10592)] = 502328,
  [SMALL_STATE(10593)] = 502376,
  [SMALL_STATE(10594)] = 502410,
  [SMALL_STATE(10595)] = 502444,
  [SMALL_STATE(10596)] = 502478,
  [SMALL_STATE(10597)] = 502518,
  [SMALL_STATE(10598)] = 502552,
  [SMALL_STATE(10599)] = 502608,
  [SMALL_STATE(10600)] = 502664,
  [SMALL_STATE(10601)] = 502704,
  [SMALL_STATE(10602)] = 502740,
  [SMALL_STATE(10603)] = 502784,
  [SMALL_STATE(10604)] = 502818,
  [SMALL_STATE(10605)] = 502852,
  [SMALL_STATE(10606)] = 502904,
  [SMALL_STATE(10607)] = 502942,
  [SMALL_STATE(10608)] = 502976,
  [SMALL_STATE(10609)] = 503010,
  [SMALL_STATE(10610)] = 503048,
  [SMALL_STATE(10611)] = 503082,
  [SMALL_STATE(10612)] = 503118,
  [SMALL_STATE(10613)] = 503158,
  [SMALL_STATE(10614)] = 503192,
  [SMALL_STATE(10615)] = 503226,
  [SMALL_STATE(10616)] = 503282,
  [SMALL_STATE(10617)] = 503316,
  [SMALL_STATE(10618)] = 503362,
  [SMALL_STATE(10619)] = 503396,
  [SMALL_STATE(10620)] = 503448,
  [SMALL_STATE(10621)] = 503482,
  [SMALL_STATE(10622)] = 503516,
  [SMALL_STATE(10623)] = 503564,
  [SMALL_STATE(10624)] = 503598,
  [SMALL_STATE(10625)] = 503632,
  [SMALL_STATE(10626)] = 503684,
  [SMALL_STATE(10627)] = 503718,
  [SMALL_STATE(10628)] = 503754,
  [SMALL_STATE(10629)] = 503798,
  [SMALL_STATE(10630)] = 503832,
  [SMALL_STATE(10631)] = 503868,
  [SMALL_STATE(10632)] = 503902,
  [SMALL_STATE(10633)] = 503936,
  [SMALL_STATE(10634)] = 503974,
  [SMALL_STATE(10635)] = 504026,
  [SMALL_STATE(10636)] = 504076,
  [SMALL_STATE(10637)] = 504110,
  [SMALL_STATE(10638)] = 504144,
  [SMALL_STATE(10639)] = 504178,
  [SMALL_STATE(10640)] = 504212,
  [SMALL_STATE(10641)] = 504262,
  [SMALL_STATE(10642)] = 504296,
  [SMALL_STATE(10643)] = 504350,
  [SMALL_STATE(10644)] = 504384,
  [SMALL_STATE(10645)] = 504418,
  [SMALL_STATE(10646)] = 504452,
  [SMALL_STATE(10647)] = 504504,
  [SMALL_STATE(10648)] = 504538,
  [SMALL_STATE(10649)] = 504588,
  [SMALL_STATE(10650)] = 504622,
  [SMALL_STATE(10651)] = 504656,
  [SMALL_STATE(10652)] = 504690,
  [SMALL_STATE(10653)] = 504726,
  [SMALL_STATE(10654)] = 504760,
  [SMALL_STATE(10655)] = 504796,
  [SMALL_STATE(10656)] = 504830,
  [SMALL_STATE(10657)] = 504864,
  [SMALL_STATE(10658)] = 504898,
  [SMALL_STATE(10659)] = 504936,
  [SMALL_STATE(10660)] = 504986,
  [SMALL_STATE(10661)] = 505020,
  [SMALL_STATE(10662)] = 505054,
  [SMALL_STATE(10663)] = 505088,
  [SMALL_STATE(10664)] = 505148,
  [SMALL_STATE(10665)] = 505182,
  [SMALL_STATE(10666)] = 505216,
  [SMALL_STATE(10667)] = 505250,
  [SMALL_STATE(10668)] = 505286,
  [SMALL_STATE(10669)] = 505320,
  [SMALL_STATE(10670)] = 505354,
  [SMALL_STATE(10671)] = 505387,
  [SMALL_STATE(10672)] = 505424,
  [SMALL_STATE(10673)] = 505471,
  [SMALL_STATE(10674)] = 505504,
  [SMALL_STATE(10675)] = 505537,
  [SMALL_STATE(10676)] = 505572,
  [SMALL_STATE(10677)] = 505605,
  [SMALL_STATE(10678)] = 505638,
  [SMALL_STATE(10679)] = 505675,
  [SMALL_STATE(10680)] = 505708,
  [SMALL_STATE(10681)] = 505741,
  [SMALL_STATE(10682)] = 505774,
  [SMALL_STATE(10683)] = 505807,
  [SMALL_STATE(10684)] = 505840,
  [SMALL_STATE(10685)] = 505873,
  [SMALL_STATE(10686)] = 505920,
  [SMALL_STATE(10687)] = 505969,
  [SMALL_STATE(10688)] = 506002,
  [SMALL_STATE(10689)] = 506035,
  [SMALL_STATE(10690)] = 506068,
  [SMALL_STATE(10691)] = 506103,
  [SMALL_STATE(10692)] = 506136,
  [SMALL_STATE(10693)] = 506169,
  [SMALL_STATE(10694)] = 506202,
  [SMALL_STATE(10695)] = 506235,
  [SMALL_STATE(10696)] = 506274,
  [SMALL_STATE(10697)] = 506311,
  [SMALL_STATE(10698)] = 506358,
  [SMALL_STATE(10699)] = 506391,
  [SMALL_STATE(10700)] = 506424,
  [SMALL_STATE(10701)] = 506457,
  [SMALL_STATE(10702)] = 506490,
  [SMALL_STATE(10703)] = 506539,
  [SMALL_STATE(10704)] = 506578,
  [SMALL_STATE(10705)] = 506611,
  [SMALL_STATE(10706)] = 506644,
  [SMALL_STATE(10707)] = 506691,
  [SMALL_STATE(10708)] = 506724,
  [SMALL_STATE(10709)] = 506757,
  [SMALL_STATE(10710)] = 506804,
  [SMALL_STATE(10711)] = 506837,
  [SMALL_STATE(10712)] = 506870,
  [SMALL_STATE(10713)] = 506917,
  [SMALL_STATE(10714)] = 506950,
  [SMALL_STATE(10715)] = 506999,
  [SMALL_STATE(10716)] = 507032,
  [SMALL_STATE(10717)] = 507065,
  [SMALL_STATE(10718)] = 507112,
  [SMALL_STATE(10719)] = 507145,
  [SMALL_STATE(10720)] = 507192,
  [SMALL_STATE(10721)] = 507225,
  [SMALL_STATE(10722)] = 507280,
  [SMALL_STATE(10723)] = 507335,
  [SMALL_STATE(10724)] = 507370,
  [SMALL_STATE(10725)] = 507403,
  [SMALL_STATE(10726)] = 507436,
  [SMALL_STATE(10727)] = 507469,
  [SMALL_STATE(10728)] = 507516,
  [SMALL_STATE(10729)] = 507549,
  [SMALL_STATE(10730)] = 507582,
  [SMALL_STATE(10731)] = 507615,
  [SMALL_STATE(10732)] = 507650,
  [SMALL_STATE(10733)] = 507683,
  [SMALL_STATE(10734)] = 507716,
  [SMALL_STATE(10735)] = 507749,
  [SMALL_STATE(10736)] = 507796,
  [SMALL_STATE(10737)] = 507829,
  [SMALL_STATE(10738)] = 507884,
  [SMALL_STATE(10739)] = 507939,
  [SMALL_STATE(10740)] = 507972,
  [SMALL_STATE(10741)] = 508005,
  [SMALL_STATE(10742)] = 508054,
  [SMALL_STATE(10743)] = 508087,
  [SMALL_STATE(10744)] = 508120,
  [SMALL_STATE(10745)] = 508153,
  [SMALL_STATE(10746)] = 508190,
  [SMALL_STATE(10747)] = 508223,
  [SMALL_STATE(10748)] = 508270,
  [SMALL_STATE(10749)] = 508303,
  [SMALL_STATE(10750)] = 508336,
  [SMALL_STATE(10751)] = 508385,
  [SMALL_STATE(10752)] = 508418,
  [SMALL_STATE(10753)] = 508451,
  [SMALL_STATE(10754)] = 508484,
  [SMALL_STATE(10755)] = 508517,
  [SMALL_STATE(10756)] = 508550,
  [SMALL_STATE(10757)] = 508589,
  [SMALL_STATE(10758)] = 508622,
  [SMALL_STATE(10759)] = 508655,
  [SMALL_STATE(10760)] = 508688,
  [SMALL_STATE(10761)] = 508721,
  [SMALL_STATE(10762)] = 508776,
  [SMALL_STATE(10763)] = 508811,
  [SMALL_STATE(10764)] = 508844,
  [SMALL_STATE(10765)] = 508899,
  [SMALL_STATE(10766)] = 508954,
  [SMALL_STATE(10767)] = 509009,
  [SMALL_STATE(10768)] = 509042,
  [SMALL_STATE(10769)] = 509075,
  [SMALL_STATE(10770)] = 509108,
  [SMALL_STATE(10771)] = 509145,
  [SMALL_STATE(10772)] = 509178,
  [SMALL_STATE(10773)] = 509211,
  [SMALL_STATE(10774)] = 509244,
  [SMALL_STATE(10775)] = 509277,
  [SMALL_STATE(10776)] = 509310,
  [SMALL_STATE(10777)] = 509343,
  [SMALL_STATE(10778)] = 509390,
  [SMALL_STATE(10779)] = 509423,
  [SMALL_STATE(10780)] = 509456,
  [SMALL_STATE(10781)] = 509489,
  [SMALL_STATE(10782)] = 509522,
  [SMALL_STATE(10783)] = 509555,
  [SMALL_STATE(10784)] = 509588,
  [SMALL_STATE(10785)] = 509621,
  [SMALL_STATE(10786)] = 509660,
  [SMALL_STATE(10787)] = 509693,
  [SMALL_STATE(10788)] = 509742,
  [SMALL_STATE(10789)] = 509775,
  [SMALL_STATE(10790)] = 509808,
  [SMALL_STATE(10791)] = 509847,
  [SMALL_STATE(10792)] = 509898,
  [SMALL_STATE(10793)] = 509931,
  [SMALL_STATE(10794)] = 509978,
  [SMALL_STATE(10795)] = 510011,
  [SMALL_STATE(10796)] = 510066,
  [SMALL_STATE(10797)] = 510105,
  [SMALL_STATE(10798)] = 510160,
  [SMALL_STATE(10799)] = 510195,
  [SMALL_STATE(10800)] = 510228,
  [SMALL_STATE(10801)] = 510277,
  [SMALL_STATE(10802)] = 510324,
  [SMALL_STATE(10803)] = 510357,
  [SMALL_STATE(10804)] = 510390,
  [SMALL_STATE(10805)] = 510423,
  [SMALL_STATE(10806)] = 510470,
  [SMALL_STATE(10807)] = 510503,
  [SMALL_STATE(10808)] = 510558,
  [SMALL_STATE(10809)] = 510591,
  [SMALL_STATE(10810)] = 510638,
  [SMALL_STATE(10811)] = 510671,
  [SMALL_STATE(10812)] = 510704,
  [SMALL_STATE(10813)] = 510739,
  [SMALL_STATE(10814)] = 510794,
  [SMALL_STATE(10815)] = 510827,
  [SMALL_STATE(10816)] = 510874,
  [SMALL_STATE(10817)] = 510917,
  [SMALL_STATE(10818)] = 510950,
  [SMALL_STATE(10819)] = 510983,
  [SMALL_STATE(10820)] = 511016,
  [SMALL_STATE(10821)] = 511055,
  [SMALL_STATE(10822)] = 511108,
  [SMALL_STATE(10823)] = 511141,
  [SMALL_STATE(10824)] = 511174,
  [SMALL_STATE(10825)] = 511207,
  [SMALL_STATE(10826)] = 511240,
  [SMALL_STATE(10827)] = 511273,
  [SMALL_STATE(10828)] = 511316,
  [SMALL_STATE(10829)] = 511371,
  [SMALL_STATE(10830)] = 511404,
  [SMALL_STATE(10831)] = 511447,
  [SMALL_STATE(10832)] = 511502,
  [SMALL_STATE(10833)] = 511535,
  [SMALL_STATE(10834)] = 511568,
  [SMALL_STATE(10835)] = 511617,
  [SMALL_STATE(10836)] = 511664,
  [SMALL_STATE(10837)] = 511701,
  [SMALL_STATE(10838)] = 511756,
  [SMALL_STATE(10839)] = 511789,
  [SMALL_STATE(10840)] = 511824,
  [SMALL_STATE(10841)] = 511879,
  [SMALL_STATE(10842)] = 511912,
  [SMALL_STATE(10843)] = 511945,
  [SMALL_STATE(10844)] = 511994,
  [SMALL_STATE(10845)] = 512049,
  [SMALL_STATE(10846)] = 512082,
  [SMALL_STATE(10847)] = 512115,
  [SMALL_STATE(10848)] = 512148,
  [SMALL_STATE(10849)] = 512181,
  [SMALL_STATE(10850)] = 512214,
  [SMALL_STATE(10851)] = 512247,
  [SMALL_STATE(10852)] = 512296,
  [SMALL_STATE(10853)] = 512329,
  [SMALL_STATE(10854)] = 512384,
  [SMALL_STATE(10855)] = 512421,
  [SMALL_STATE(10856)] = 512454,
  [SMALL_STATE(10857)] = 512487,
  [SMALL_STATE(10858)] = 512520,
  [SMALL_STATE(10859)] = 512559,
  [SMALL_STATE(10860)] = 512614,
  [SMALL_STATE(10861)] = 512663,
  [SMALL_STATE(10862)] = 512696,
  [SMALL_STATE(10863)] = 512751,
  [SMALL_STATE(10864)] = 512806,
  [SMALL_STATE(10865)] = 512839,
  [SMALL_STATE(10866)] = 512874,
  [SMALL_STATE(10867)] = 512907,
  [SMALL_STATE(10868)] = 512954,
  [SMALL_STATE(10869)] = 513009,
  [SMALL_STATE(10870)] = 513042,
  [SMALL_STATE(10871)] = 513075,
  [SMALL_STATE(10872)] = 513108,
  [SMALL_STATE(10873)] = 513151,
  [SMALL_STATE(10874)] = 513184,
  [SMALL_STATE(10875)] = 513223,
  [SMALL_STATE(10876)] = 513256,
  [SMALL_STATE(10877)] = 513289,
  [SMALL_STATE(10878)] = 513322,
  [SMALL_STATE(10879)] = 513355,
  [SMALL_STATE(10880)] = 513388,
  [SMALL_STATE(10881)] = 513421,
  [SMALL_STATE(10882)] = 513454,
  [SMALL_STATE(10883)] = 513491,
  [SMALL_STATE(10884)] = 513524,
  [SMALL_STATE(10885)] = 513557,
  [SMALL_STATE(10886)] = 513596,
  [SMALL_STATE(10887)] = 513629,
  [SMALL_STATE(10888)] = 513662,
  [SMALL_STATE(10889)] = 513695,
  [SMALL_STATE(10890)] = 513728,
  [SMALL_STATE(10891)] = 513761,
  [SMALL_STATE(10892)] = 513794,
  [SMALL_STATE(10893)] = 513826,
  [SMALL_STATE(10894)] = 513864,
  [SMALL_STATE(10895)] = 513896,
  [SMALL_STATE(10896)] = 513928,
  [SMALL_STATE(10897)] = 513960,
  [SMALL_STATE(10898)] = 513992,
  [SMALL_STATE(10899)] = 514042,
  [SMALL_STATE(10900)] = 514088,
  [SMALL_STATE(10901)] = 514138,
  [SMALL_STATE(10902)] = 514170,
  [SMALL_STATE(10903)] = 514220,
  [SMALL_STATE(10904)] = 514254,
  [SMALL_STATE(10905)] = 514286,
  [SMALL_STATE(10906)] = 514318,
  [SMALL_STATE(10907)] = 514350,
  [SMALL_STATE(10908)] = 514382,
  [SMALL_STATE(10909)] = 514414,
  [SMALL_STATE(10910)] = 514446,
  [SMALL_STATE(10911)] = 514496,
  [SMALL_STATE(10912)] = 514528,
  [SMALL_STATE(10913)] = 514578,
  [SMALL_STATE(10914)] = 514610,
  [SMALL_STATE(10915)] = 514642,
  [SMALL_STATE(10916)] = 514672,
  [SMALL_STATE(10917)] = 514704,
  [SMALL_STATE(10918)] = 514736,
  [SMALL_STATE(10919)] = 514768,
  [SMALL_STATE(10920)] = 514800,
  [SMALL_STATE(10921)] = 514850,
  [SMALL_STATE(10922)] = 514896,
  [SMALL_STATE(10923)] = 514950,
  [SMALL_STATE(10924)] = 514986,
  [SMALL_STATE(10925)] = 515018,
  [SMALL_STATE(10926)] = 515050,
  [SMALL_STATE(10927)] = 515080,
  [SMALL_STATE(10928)] = 515112,
  [SMALL_STATE(10929)] = 515166,
  [SMALL_STATE(10930)] = 515198,
  [SMALL_STATE(10931)] = 515228,
  [SMALL_STATE(10932)] = 515282,
  [SMALL_STATE(10933)] = 515312,
  [SMALL_STATE(10934)] = 515342,
  [SMALL_STATE(10935)] = 515374,
  [SMALL_STATE(10936)] = 515406,
  [SMALL_STATE(10937)] = 515438,
  [SMALL_STATE(10938)] = 515468,
  [SMALL_STATE(10939)] = 515520,
  [SMALL_STATE(10940)] = 515572,
  [SMALL_STATE(10941)] = 515602,
  [SMALL_STATE(10942)] = 515632,
  [SMALL_STATE(10943)] = 515664,
  [SMALL_STATE(10944)] = 515696,
  [SMALL_STATE(10945)] = 515728,
  [SMALL_STATE(10946)] = 515774,
  [SMALL_STATE(10947)] = 515806,
  [SMALL_STATE(10948)] = 515838,
  [SMALL_STATE(10949)] = 515870,
  [SMALL_STATE(10950)] = 515902,
  [SMALL_STATE(10951)] = 515934,
  [SMALL_STATE(10952)] = 515966,
  [SMALL_STATE(10953)] = 515996,
  [SMALL_STATE(10954)] = 516028,
  [SMALL_STATE(10955)] = 516058,
  [SMALL_STATE(10956)] = 516090,
  [SMALL_STATE(10957)] = 516142,
  [SMALL_STATE(10958)] = 516174,
  [SMALL_STATE(10959)] = 516206,
  [SMALL_STATE(10960)] = 516238,
  [SMALL_STATE(10961)] = 516268,
  [SMALL_STATE(10962)] = 516304,
  [SMALL_STATE(10963)] = 516358,
  [SMALL_STATE(10964)] = 516390,
  [SMALL_STATE(10965)] = 516422,
  [SMALL_STATE(10966)] = 516454,
  [SMALL_STATE(10967)] = 516506,
  [SMALL_STATE(10968)] = 516538,
  [SMALL_STATE(10969)] = 516570,
  [SMALL_STATE(10970)] = 516602,
  [SMALL_STATE(10971)] = 516636,
  [SMALL_STATE(10972)] = 516668,
  [SMALL_STATE(10973)] = 516720,
  [SMALL_STATE(10974)] = 516752,
  [SMALL_STATE(10975)] = 516784,
  [SMALL_STATE(10976)] = 516816,
  [SMALL_STATE(10977)] = 516854,
  [SMALL_STATE(10978)] = 516892,
  [SMALL_STATE(10979)] = 516924,
  [SMALL_STATE(10980)] = 516956,
  [SMALL_STATE(10981)] = 516992,
  [SMALL_STATE(10982)] = 517024,
  [SMALL_STATE(10983)] = 517056,
  [SMALL_STATE(10984)] = 517088,
  [SMALL_STATE(10985)] = 517120,
  [SMALL_STATE(10986)] = 517170,
  [SMALL_STATE(10987)] = 517202,
  [SMALL_STATE(10988)] = 517234,
  [SMALL_STATE(10989)] = 517266,
  [SMALL_STATE(10990)] = 517298,
  [SMALL_STATE(10991)] = 517330,
  [SMALL_STATE(10992)] = 517360,
  [SMALL_STATE(10993)] = 517390,
  [SMALL_STATE(10994)] = 517422,
  [SMALL_STATE(10995)] = 517454,
  [SMALL_STATE(10996)] = 517506,
  [SMALL_STATE(10997)] = 517538,
  [SMALL_STATE(10998)] = 517570,
  [SMALL_STATE(10999)] = 517622,
  [SMALL_STATE(11000)] = 517654,
  [SMALL_STATE(11001)] = 517686,
  [SMALL_STATE(11002)] = 517724,
  [SMALL_STATE(11003)] = 517756,
  [SMALL_STATE(11004)] = 517788,
  [SMALL_STATE(11005)] = 517820,
  [SMALL_STATE(11006)] = 517852,
  [SMALL_STATE(11007)] = 517884,
  [SMALL_STATE(11008)] = 517916,
  [SMALL_STATE(11009)] = 517948,
  [SMALL_STATE(11010)] = 517980,
  [SMALL_STATE(11011)] = 518012,
  [SMALL_STATE(11012)] = 518054,
  [SMALL_STATE(11013)] = 518096,
  [SMALL_STATE(11014)] = 518128,
  [SMALL_STATE(11015)] = 518160,
  [SMALL_STATE(11016)] = 518192,
  [SMALL_STATE(11017)] = 518224,
  [SMALL_STATE(11018)] = 518274,
  [SMALL_STATE(11019)] = 518328,
  [SMALL_STATE(11020)] = 518358,
  [SMALL_STATE(11021)] = 518390,
  [SMALL_STATE(11022)] = 518440,
  [SMALL_STATE(11023)] = 518472,
  [SMALL_STATE(11024)] = 518526,
  [SMALL_STATE(11025)] = 518558,
  [SMALL_STATE(11026)] = 518590,
  [SMALL_STATE(11027)] = 518622,
  [SMALL_STATE(11028)] = 518660,
  [SMALL_STATE(11029)] = 518692,
  [SMALL_STATE(11030)] = 518724,
  [SMALL_STATE(11031)] = 518756,
  [SMALL_STATE(11032)] = 518788,
  [SMALL_STATE(11033)] = 518826,
  [SMALL_STATE(11034)] = 518868,
  [SMALL_STATE(11035)] = 518920,
  [SMALL_STATE(11036)] = 518972,
  [SMALL_STATE(11037)] = 519004,
  [SMALL_STATE(11038)] = 519052,
  [SMALL_STATE(11039)] = 519092,
  [SMALL_STATE(11040)] = 519142,
  [SMALL_STATE(11041)] = 519174,
  [SMALL_STATE(11042)] = 519206,
  [SMALL_STATE(11043)] = 519238,
  [SMALL_STATE(11044)] = 519276,
  [SMALL_STATE(11045)] = 519314,
  [SMALL_STATE(11046)] = 519364,
  [SMALL_STATE(11047)] = 519396,
  [SMALL_STATE(11048)] = 519428,
  [SMALL_STATE(11049)] = 519460,
  [SMALL_STATE(11050)] = 519498,
  [SMALL_STATE(11051)] = 519536,
  [SMALL_STATE(11052)] = 519568,
  [SMALL_STATE(11053)] = 519600,
  [SMALL_STATE(11054)] = 519632,
  [SMALL_STATE(11055)] = 519664,
  [SMALL_STATE(11056)] = 519714,
  [SMALL_STATE(11057)] = 519746,
  [SMALL_STATE(11058)] = 519778,
  [SMALL_STATE(11059)] = 519816,
  [SMALL_STATE(11060)] = 519848,
  [SMALL_STATE(11061)] = 519880,
  [SMALL_STATE(11062)] = 519934,
  [SMALL_STATE(11063)] = 519966,
  [SMALL_STATE(11064)] = 519998,
  [SMALL_STATE(11065)] = 520052,
  [SMALL_STATE(11066)] = 520102,
  [SMALL_STATE(11067)] = 520134,
  [SMALL_STATE(11068)] = 520166,
  [SMALL_STATE(11069)] = 520198,
  [SMALL_STATE(11070)] = 520230,
  [SMALL_STATE(11071)] = 520262,
  [SMALL_STATE(11072)] = 520294,
  [SMALL_STATE(11073)] = 520326,
  [SMALL_STATE(11074)] = 520358,
  [SMALL_STATE(11075)] = 520390,
  [SMALL_STATE(11076)] = 520440,
  [SMALL_STATE(11077)] = 520472,
  [SMALL_STATE(11078)] = 520524,
  [SMALL_STATE(11079)] = 520556,
  [SMALL_STATE(11080)] = 520588,
  [SMALL_STATE(11081)] = 520620,
  [SMALL_STATE(11082)] = 520652,
  [SMALL_STATE(11083)] = 520684,
  [SMALL_STATE(11084)] = 520722,
  [SMALL_STATE(11085)] = 520776,
  [SMALL_STATE(11086)] = 520830,
  [SMALL_STATE(11087)] = 520868,
  [SMALL_STATE(11088)] = 520900,
  [SMALL_STATE(11089)] = 520932,
  [SMALL_STATE(11090)] = 520980,
  [SMALL_STATE(11091)] = 521012,
  [SMALL_STATE(11092)] = 521044,
  [SMALL_STATE(11093)] = 521076,
  [SMALL_STATE(11094)] = 521108,
  [SMALL_STATE(11095)] = 521158,
  [SMALL_STATE(11096)] = 521190,
  [SMALL_STATE(11097)] = 521222,
  [SMALL_STATE(11098)] = 521272,
  [SMALL_STATE(11099)] = 521304,
  [SMALL_STATE(11100)] = 521346,
  [SMALL_STATE(11101)] = 521388,
  [SMALL_STATE(11102)] = 521420,
  [SMALL_STATE(11103)] = 521452,
  [SMALL_STATE(11104)] = 521484,
  [SMALL_STATE(11105)] = 521516,
  [SMALL_STATE(11106)] = 521548,
  [SMALL_STATE(11107)] = 521586,
  [SMALL_STATE(11108)] = 521634,
  [SMALL_STATE(11109)] = 521686,
  [SMALL_STATE(11110)] = 521718,
  [SMALL_STATE(11111)] = 521756,
  [SMALL_STATE(11112)] = 521788,
  [SMALL_STATE(11113)] = 521824,
  [SMALL_STATE(11114)] = 521856,
  [SMALL_STATE(11115)] = 521888,
  [SMALL_STATE(11116)] = 521920,
  [SMALL_STATE(11117)] = 521952,
  [SMALL_STATE(11118)] = 521984,
  [SMALL_STATE(11119)] = 522016,
  [SMALL_STATE(11120)] = 522048,
  [SMALL_STATE(11121)] = 522080,
  [SMALL_STATE(11122)] = 522110,
  [SMALL_STATE(11123)] = 522140,
  [SMALL_STATE(11124)] = 522172,
  [SMALL_STATE(11125)] = 522206,
  [SMALL_STATE(11126)] = 522238,
  [SMALL_STATE(11127)] = 522292,
  [SMALL_STATE(11128)] = 522330,
  [SMALL_STATE(11129)] = 522362,
  [SMALL_STATE(11130)] = 522394,
  [SMALL_STATE(11131)] = 522426,
  [SMALL_STATE(11132)] = 522464,
  [SMALL_STATE(11133)] = 522496,
  [SMALL_STATE(11134)] = 522534,
  [SMALL_STATE(11135)] = 522566,
  [SMALL_STATE(11136)] = 522598,
  [SMALL_STATE(11137)] = 522652,
  [SMALL_STATE(11138)] = 522684,
  [SMALL_STATE(11139)] = 522738,
  [SMALL_STATE(11140)] = 522770,
  [SMALL_STATE(11141)] = 522802,
  [SMALL_STATE(11142)] = 522848,
  [SMALL_STATE(11143)] = 522880,
  [SMALL_STATE(11144)] = 522934,
  [SMALL_STATE(11145)] = 522966,
  [SMALL_STATE(11146)] = 523020,
  [SMALL_STATE(11147)] = 523052,
  [SMALL_STATE(11148)] = 523084,
  [SMALL_STATE(11149)] = 523116,
  [SMALL_STATE(11150)] = 523148,
  [SMALL_STATE(11151)] = 523180,
  [SMALL_STATE(11152)] = 523212,
  [SMALL_STATE(11153)] = 523250,
  [SMALL_STATE(11154)] = 523282,
  [SMALL_STATE(11155)] = 523324,
  [SMALL_STATE(11156)] = 523356,
  [SMALL_STATE(11157)] = 523388,
  [SMALL_STATE(11158)] = 523426,
  [SMALL_STATE(11159)] = 523458,
  [SMALL_STATE(11160)] = 523490,
  [SMALL_STATE(11161)] = 523522,
  [SMALL_STATE(11162)] = 523554,
  [SMALL_STATE(11163)] = 523608,
  [SMALL_STATE(11164)] = 523640,
  [SMALL_STATE(11165)] = 523672,
  [SMALL_STATE(11166)] = 523704,
  [SMALL_STATE(11167)] = 523736,
  [SMALL_STATE(11168)] = 523784,
  [SMALL_STATE(11169)] = 523816,
  [SMALL_STATE(11170)] = 523848,
  [SMALL_STATE(11171)] = 523880,
  [SMALL_STATE(11172)] = 523912,
  [SMALL_STATE(11173)] = 523944,
  [SMALL_STATE(11174)] = 523978,
  [SMALL_STATE(11175)] = 524008,
  [SMALL_STATE(11176)] = 524040,
  [SMALL_STATE(11177)] = 524072,
  [SMALL_STATE(11178)] = 524126,
  [SMALL_STATE(11179)] = 524172,
  [SMALL_STATE(11180)] = 524226,
  [SMALL_STATE(11181)] = 524258,
  [SMALL_STATE(11182)] = 524292,
  [SMALL_STATE(11183)] = 524327,
  [SMALL_STATE(11184)] = 524362,
  [SMALL_STATE(11185)] = 524397,
  [SMALL_STATE(11186)] = 524428,
  [SMALL_STATE(11187)] = 524459,
  [SMALL_STATE(11188)] = 524490,
  [SMALL_STATE(11189)] = 524529,
  [SMALL_STATE(11190)] = 524560,
  [SMALL_STATE(11191)] = 524591,
  [SMALL_STATE(11192)] = 524622,
  [SMALL_STATE(11193)] = 524653,
  [SMALL_STATE(11194)] = 524684,
  [SMALL_STATE(11195)] = 524715,
  [SMALL_STATE(11196)] = 524746,
  [SMALL_STATE(11197)] = 524777,
  [SMALL_STATE(11198)] = 524808,
  [SMALL_STATE(11199)] = 524839,
  [SMALL_STATE(11200)] = 524870,
  [SMALL_STATE(11201)] = 524903,
  [SMALL_STATE(11202)] = 524934,
  [SMALL_STATE(11203)] = 524965,
  [SMALL_STATE(11204)] = 525016,
  [SMALL_STATE(11205)] = 525047,
  [SMALL_STATE(11206)] = 525078,
  [SMALL_STATE(11207)] = 525109,
  [SMALL_STATE(11208)] = 525140,
  [SMALL_STATE(11209)] = 525171,
  [SMALL_STATE(11210)] = 525202,
  [SMALL_STATE(11211)] = 525233,
  [SMALL_STATE(11212)] = 525262,
  [SMALL_STATE(11213)] = 525293,
  [SMALL_STATE(11214)] = 525324,
  [SMALL_STATE(11215)] = 525355,
  [SMALL_STATE(11216)] = 525404,
  [SMALL_STATE(11217)] = 525453,
  [SMALL_STATE(11218)] = 525484,
  [SMALL_STATE(11219)] = 525533,
  [SMALL_STATE(11220)] = 525582,
  [SMALL_STATE(11221)] = 525613,
  [SMALL_STATE(11222)] = 525648,
  [SMALL_STATE(11223)] = 525697,
  [SMALL_STATE(11224)] = 525728,
  [SMALL_STATE(11225)] = 525775,
  [SMALL_STATE(11226)] = 525806,
  [SMALL_STATE(11227)] = 525855,
  [SMALL_STATE(11228)] = 525902,
  [SMALL_STATE(11229)] = 525933,
  [SMALL_STATE(11230)] = 525964,
  [SMALL_STATE(11231)] = 525995,
  [SMALL_STATE(11232)] = 526026,
  [SMALL_STATE(11233)] = 526055,
  [SMALL_STATE(11234)] = 526086,
  [SMALL_STATE(11235)] = 526117,
  [SMALL_STATE(11236)] = 526158,
  [SMALL_STATE(11237)] = 526199,
  [SMALL_STATE(11238)] = 526230,
  [SMALL_STATE(11239)] = 526259,
  [SMALL_STATE(11240)] = 526290,
  [SMALL_STATE(11241)] = 526321,
  [SMALL_STATE(11242)] = 526350,
  [SMALL_STATE(11243)] = 526387,
  [SMALL_STATE(11244)] = 526418,
  [SMALL_STATE(11245)] = 526463,
  [SMALL_STATE(11246)] = 526494,
  [SMALL_STATE(11247)] = 526525,
  [SMALL_STATE(11248)] = 526562,
  [SMALL_STATE(11249)] = 526611,
  [SMALL_STATE(11250)] = 526640,
  [SMALL_STATE(11251)] = 526671,
  [SMALL_STATE(11252)] = 526702,
  [SMALL_STATE(11253)] = 526751,
  [SMALL_STATE(11254)] = 526798,
  [SMALL_STATE(11255)] = 526829,
  [SMALL_STATE(11256)] = 526868,
  [SMALL_STATE(11257)] = 526899,
  [SMALL_STATE(11258)] = 526934,
  [SMALL_STATE(11259)] = 526965,
  [SMALL_STATE(11260)] = 526996,
  [SMALL_STATE(11261)] = 527043,
  [SMALL_STATE(11262)] = 527074,
  [SMALL_STATE(11263)] = 527105,
  [SMALL_STATE(11264)] = 527152,
  [SMALL_STATE(11265)] = 527183,
  [SMALL_STATE(11266)] = 527214,
  [SMALL_STATE(11267)] = 527249,
  [SMALL_STATE(11268)] = 527284,
  [SMALL_STATE(11269)] = 527313,
  [SMALL_STATE(11270)] = 527344,
  [SMALL_STATE(11271)] = 527375,
  [SMALL_STATE(11272)] = 527422,
  [SMALL_STATE(11273)] = 527457,
  [SMALL_STATE(11274)] = 527488,
  [SMALL_STATE(11275)] = 527519,
  [SMALL_STATE(11276)] = 527556,
  [SMALL_STATE(11277)] = 527589,
  [SMALL_STATE(11278)] = 527620,
  [SMALL_STATE(11279)] = 527655,
  [SMALL_STATE(11280)] = 527684,
  [SMALL_STATE(11281)] = 527721,
  [SMALL_STATE(11282)] = 527762,
  [SMALL_STATE(11283)] = 527809,
  [SMALL_STATE(11284)] = 527840,
  [SMALL_STATE(11285)] = 527871,
  [SMALL_STATE(11286)] = 527902,
  [SMALL_STATE(11287)] = 527933,
  [SMALL_STATE(11288)] = 527964,
  [SMALL_STATE(11289)] = 527995,
  [SMALL_STATE(11290)] = 528026,
  [SMALL_STATE(11291)] = 528057,
  [SMALL_STATE(11292)] = 528088,
  [SMALL_STATE(11293)] = 528135,
  [SMALL_STATE(11294)] = 528164,
  [SMALL_STATE(11295)] = 528197,
  [SMALL_STATE(11296)] = 528228,
  [SMALL_STATE(11297)] = 528259,
  [SMALL_STATE(11298)] = 528290,
  [SMALL_STATE(11299)] = 528319,
  [SMALL_STATE(11300)] = 528350,
  [SMALL_STATE(11301)] = 528381,
  [SMALL_STATE(11302)] = 528412,
  [SMALL_STATE(11303)] = 528443,
  [SMALL_STATE(11304)] = 528474,
  [SMALL_STATE(11305)] = 528505,
  [SMALL_STATE(11306)] = 528534,
  [SMALL_STATE(11307)] = 528565,
  [SMALL_STATE(11308)] = 528596,
  [SMALL_STATE(11309)] = 528625,
  [SMALL_STATE(11310)] = 528656,
  [SMALL_STATE(11311)] = 528703,
  [SMALL_STATE(11312)] = 528734,
  [SMALL_STATE(11313)] = 528765,
  [SMALL_STATE(11314)] = 528798,
  [SMALL_STATE(11315)] = 528829,
  [SMALL_STATE(11316)] = 528860,
  [SMALL_STATE(11317)] = 528907,
  [SMALL_STATE(11318)] = 528938,
  [SMALL_STATE(11319)] = 528975,
  [SMALL_STATE(11320)] = 529006,
  [SMALL_STATE(11321)] = 529035,
  [SMALL_STATE(11322)] = 529064,
  [SMALL_STATE(11323)] = 529111,
  [SMALL_STATE(11324)] = 529140,
  [SMALL_STATE(11325)] = 529171,
  [SMALL_STATE(11326)] = 529208,
  [SMALL_STATE(11327)] = 529239,
  [SMALL_STATE(11328)] = 529270,
  [SMALL_STATE(11329)] = 529301,
  [SMALL_STATE(11330)] = 529334,
  [SMALL_STATE(11331)] = 529365,
  [SMALL_STATE(11332)] = 529394,
  [SMALL_STATE(11333)] = 529425,
  [SMALL_STATE(11334)] = 529456,
  [SMALL_STATE(11335)] = 529485,
  [SMALL_STATE(11336)] = 529516,
  [SMALL_STATE(11337)] = 529551,
  [SMALL_STATE(11338)] = 529582,
  [SMALL_STATE(11339)] = 529623,
  [SMALL_STATE(11340)] = 529652,
  [SMALL_STATE(11341)] = 529683,
  [SMALL_STATE(11342)] = 529714,
  [SMALL_STATE(11343)] = 529745,
  [SMALL_STATE(11344)] = 529776,
  [SMALL_STATE(11345)] = 529807,
  [SMALL_STATE(11346)] = 529838,
  [SMALL_STATE(11347)] = 529867,
  [SMALL_STATE(11348)] = 529898,
  [SMALL_STATE(11349)] = 529927,
  [SMALL_STATE(11350)] = 529958,
  [SMALL_STATE(11351)] = 529989,
  [SMALL_STATE(11352)] = 530020,
  [SMALL_STATE(11353)] = 530057,
  [SMALL_STATE(11354)] = 530092,
  [SMALL_STATE(11355)] = 530123,
  [SMALL_STATE(11356)] = 530156,
  [SMALL_STATE(11357)] = 530185,
  [SMALL_STATE(11358)] = 530220,
  [SMALL_STATE(11359)] = 530251,
  [SMALL_STATE(11360)] = 530282,
  [SMALL_STATE(11361)] = 530317,
  [SMALL_STATE(11362)] = 530366,
  [SMALL_STATE(11363)] = 530401,
  [SMALL_STATE(11364)] = 530446,
  [SMALL_STATE(11365)] = 530495,
  [SMALL_STATE(11366)] = 530544,
  [SMALL_STATE(11367)] = 530575,
  [SMALL_STATE(11368)] = 530610,
  [SMALL_STATE(11369)] = 530645,
  [SMALL_STATE(11370)] = 530676,
  [SMALL_STATE(11371)] = 530707,
  [SMALL_STATE(11372)] = 530756,
  [SMALL_STATE(11373)] = 530805,
  [SMALL_STATE(11374)] = 530852,
  [SMALL_STATE(11375)] = 530901,
  [SMALL_STATE(11376)] = 530932,
  [SMALL_STATE(11377)] = 530981,
  [SMALL_STATE(11378)] = 531022,
  [SMALL_STATE(11379)] = 531053,
  [SMALL_STATE(11380)] = 531084,
  [SMALL_STATE(11381)] = 531115,
  [SMALL_STATE(11382)] = 531146,
  [SMALL_STATE(11383)] = 531183,
  [SMALL_STATE(11384)] = 531224,
  [SMALL_STATE(11385)] = 531273,
  [SMALL_STATE(11386)] = 531304,
  [SMALL_STATE(11387)] = 531353,
  [SMALL_STATE(11388)] = 531384,
  [SMALL_STATE(11389)] = 531415,
  [SMALL_STATE(11390)] = 531464,
  [SMALL_STATE(11391)] = 531495,
  [SMALL_STATE(11392)] = 531530,
  [SMALL_STATE(11393)] = 531579,
  [SMALL_STATE(11394)] = 531610,
  [SMALL_STATE(11395)] = 531639,
  [SMALL_STATE(11396)] = 531688,
  [SMALL_STATE(11397)] = 531723,
  [SMALL_STATE(11398)] = 531754,
  [SMALL_STATE(11399)] = 531801,
  [SMALL_STATE(11400)] = 531832,
  [SMALL_STATE(11401)] = 531861,
  [SMALL_STATE(11402)] = 531898,
  [SMALL_STATE(11403)] = 531929,
  [SMALL_STATE(11404)] = 531960,
  [SMALL_STATE(11405)] = 531989,
  [SMALL_STATE(11406)] = 532020,
  [SMALL_STATE(11407)] = 532051,
  [SMALL_STATE(11408)] = 532095,
  [SMALL_STATE(11409)] = 532139,
  [SMALL_STATE(11410)] = 532185,
  [SMALL_STATE(11411)] = 532229,
  [SMALL_STATE(11412)] = 532273,
  [SMALL_STATE(11413)] = 532301,
  [SMALL_STATE(11414)] = 532345,
  [SMALL_STATE(11415)] = 532389,
  [SMALL_STATE(11416)] = 532433,
  [SMALL_STATE(11417)] = 532477,
  [SMALL_STATE(11418)] = 532523,
  [SMALL_STATE(11419)] = 532567,
  [SMALL_STATE(11420)] = 532597,
  [SMALL_STATE(11421)] = 532637,
  [SMALL_STATE(11422)] = 532665,
  [SMALL_STATE(11423)] = 532709,
  [SMALL_STATE(11424)] = 532753,
  [SMALL_STATE(11425)] = 532781,
  [SMALL_STATE(11426)] = 532811,
  [SMALL_STATE(11427)] = 532839,
  [SMALL_STATE(11428)] = 532883,
  [SMALL_STATE(11429)] = 532927,
  [SMALL_STATE(11430)] = 532955,
  [SMALL_STATE(11431)] = 532985,
  [SMALL_STATE(11432)] = 533013,
  [SMALL_STATE(11433)] = 533057,
  [SMALL_STATE(11434)] = 533101,
  [SMALL_STATE(11435)] = 533145,
  [SMALL_STATE(11436)] = 533189,
  [SMALL_STATE(11437)] = 533233,
  [SMALL_STATE(11438)] = 533263,
  [SMALL_STATE(11439)] = 533293,
  [SMALL_STATE(11440)] = 533331,
  [SMALL_STATE(11441)] = 533377,
  [SMALL_STATE(11442)] = 533405,
  [SMALL_STATE(11443)] = 533449,
  [SMALL_STATE(11444)] = 533493,
  [SMALL_STATE(11445)] = 533523,
  [SMALL_STATE(11446)] = 533567,
  [SMALL_STATE(11447)] = 533613,
  [SMALL_STATE(11448)] = 533643,
  [SMALL_STATE(11449)] = 533673,
  [SMALL_STATE(11450)] = 533701,
  [SMALL_STATE(11451)] = 533731,
  [SMALL_STATE(11452)] = 533775,
  [SMALL_STATE(11453)] = 533807,
  [SMALL_STATE(11454)] = 533835,
  [SMALL_STATE(11455)] = 533871,
  [SMALL_STATE(11456)] = 533901,
  [SMALL_STATE(11457)] = 533931,
  [SMALL_STATE(11458)] = 533959,
  [SMALL_STATE(11459)] = 534003,
  [SMALL_STATE(11460)] = 534031,
  [SMALL_STATE(11461)] = 534075,
  [SMALL_STATE(11462)] = 534121,
  [SMALL_STATE(11463)] = 534167,
  [SMALL_STATE(11464)] = 534211,
  [SMALL_STATE(11465)] = 534255,
  [SMALL_STATE(11466)] = 534283,
  [SMALL_STATE(11467)] = 534317,
  [SMALL_STATE(11468)] = 534345,
  [SMALL_STATE(11469)] = 534375,
  [SMALL_STATE(11470)] = 534419,
  [SMALL_STATE(11471)] = 534459,
  [SMALL_STATE(11472)] = 534505,
  [SMALL_STATE(11473)] = 534535,
  [SMALL_STATE(11474)] = 534563,
  [SMALL_STATE(11475)] = 534607,
  [SMALL_STATE(11476)] = 534651,
  [SMALL_STATE(11477)] = 534695,
  [SMALL_STATE(11478)] = 534723,
  [SMALL_STATE(11479)] = 534751,
  [SMALL_STATE(11480)] = 534781,
  [SMALL_STATE(11481)] = 534827,
  [SMALL_STATE(11482)] = 534855,
  [SMALL_STATE(11483)] = 534883,
  [SMALL_STATE(11484)] = 534929,
  [SMALL_STATE(11485)] = 534973,
  [SMALL_STATE(11486)] = 535017,
  [SMALL_STATE(11487)] = 535061,
  [SMALL_STATE(11488)] = 535089,
  [SMALL_STATE(11489)] = 535133,
  [SMALL_STATE(11490)] = 535179,
  [SMALL_STATE(11491)] = 535223,
  [SMALL_STATE(11492)] = 535251,
  [SMALL_STATE(11493)] = 535295,
  [SMALL_STATE(11494)] = 535323,
  [SMALL_STATE(11495)] = 535367,
  [SMALL_STATE(11496)] = 535411,
  [SMALL_STATE(11497)] = 535451,
  [SMALL_STATE(11498)] = 535495,
  [SMALL_STATE(11499)] = 535539,
  [SMALL_STATE(11500)] = 535567,
  [SMALL_STATE(11501)] = 535611,
  [SMALL_STATE(11502)] = 535655,
  [SMALL_STATE(11503)] = 535699,
  [SMALL_STATE(11504)] = 535727,
  [SMALL_STATE(11505)] = 535771,
  [SMALL_STATE(11506)] = 535815,
  [SMALL_STATE(11507)] = 535847,
  [SMALL_STATE(11508)] = 535875,
  [SMALL_STATE(11509)] = 535919,
  [SMALL_STATE(11510)] = 535963,
  [SMALL_STATE(11511)] = 535993,
  [SMALL_STATE(11512)] = 536023,
  [SMALL_STATE(11513)] = 536067,
  [SMALL_STATE(11514)] = 536095,
  [SMALL_STATE(11515)] = 536139,
  [SMALL_STATE(11516)] = 536167,
  [SMALL_STATE(11517)] = 536195,
  [SMALL_STATE(11518)] = 536229,
  [SMALL_STATE(11519)] = 536259,
  [SMALL_STATE(11520)] = 536289,
  [SMALL_STATE(11521)] = 536333,
  [SMALL_STATE(11522)] = 536377,
  [SMALL_STATE(11523)] = 536407,
  [SMALL_STATE(11524)] = 536435,
  [SMALL_STATE(11525)] = 536465,
  [SMALL_STATE(11526)] = 536493,
  [SMALL_STATE(11527)] = 536521,
  [SMALL_STATE(11528)] = 536549,
  [SMALL_STATE(11529)] = 536581,
  [SMALL_STATE(11530)] = 536625,
  [SMALL_STATE(11531)] = 536673,
  [SMALL_STATE(11532)] = 536717,
  [SMALL_STATE(11533)] = 536761,
  [SMALL_STATE(11534)] = 536797,
  [SMALL_STATE(11535)] = 536825,
  [SMALL_STATE(11536)] = 536869,
  [SMALL_STATE(11537)] = 536897,
  [SMALL_STATE(11538)] = 536927,
  [SMALL_STATE(11539)] = 536971,
  [SMALL_STATE(11540)] = 537015,
  [SMALL_STATE(11541)] = 537059,
  [SMALL_STATE(11542)] = 537103,
  [SMALL_STATE(11543)] = 537147,
  [SMALL_STATE(11544)] = 537191,
  [SMALL_STATE(11545)] = 537219,
  [SMALL_STATE(11546)] = 537263,
  [SMALL_STATE(11547)] = 537307,
  [SMALL_STATE(11548)] = 537335,
  [SMALL_STATE(11549)] = 537383,
  [SMALL_STATE(11550)] = 537411,
  [SMALL_STATE(11551)] = 537441,
  [SMALL_STATE(11552)] = 537485,
  [SMALL_STATE(11553)] = 537513,
  [SMALL_STATE(11554)] = 537557,
  [SMALL_STATE(11555)] = 537585,
  [SMALL_STATE(11556)] = 537613,
  [SMALL_STATE(11557)] = 537647,
  [SMALL_STATE(11558)] = 537675,
  [SMALL_STATE(11559)] = 537719,
  [SMALL_STATE(11560)] = 537763,
  [SMALL_STATE(11561)] = 537793,
  [SMALL_STATE(11562)] = 537821,
  [SMALL_STATE(11563)] = 537865,
  [SMALL_STATE(11564)] = 537895,
  [SMALL_STATE(11565)] = 537923,
  [SMALL_STATE(11566)] = 537967,
  [SMALL_STATE(11567)] = 538011,
  [SMALL_STATE(11568)] = 538041,
  [SMALL_STATE(11569)] = 538071,
  [SMALL_STATE(11570)] = 538115,
  [SMALL_STATE(11571)] = 538159,
  [SMALL_STATE(11572)] = 538187,
  [SMALL_STATE(11573)] = 538215,
  [SMALL_STATE(11574)] = 538259,
  [SMALL_STATE(11575)] = 538303,
  [SMALL_STATE(11576)] = 538331,
  [SMALL_STATE(11577)] = 538359,
  [SMALL_STATE(11578)] = 538403,
  [SMALL_STATE(11579)] = 538431,
  [SMALL_STATE(11580)] = 538475,
  [SMALL_STATE(11581)] = 538519,
  [SMALL_STATE(11582)] = 538563,
  [SMALL_STATE(11583)] = 538607,
  [SMALL_STATE(11584)] = 538651,
  [SMALL_STATE(11585)] = 538697,
  [SMALL_STATE(11586)] = 538741,
  [SMALL_STATE(11587)] = 538785,
  [SMALL_STATE(11588)] = 538829,
  [SMALL_STATE(11589)] = 538859,
  [SMALL_STATE(11590)] = 538903,
  [SMALL_STATE(11591)] = 538949,
  [SMALL_STATE(11592)] = 538993,
  [SMALL_STATE(11593)] = 539037,
  [SMALL_STATE(11594)] = 539067,
  [SMALL_STATE(11595)] = 539111,
  [SMALL_STATE(11596)] = 539155,
  [SMALL_STATE(11597)] = 539183,
  [SMALL_STATE(11598)] = 539227,
  [SMALL_STATE(11599)] = 539257,
  [SMALL_STATE(11600)] = 539305,
  [SMALL_STATE(11601)] = 539349,
  [SMALL_STATE(11602)] = 539393,
  [SMALL_STATE(11603)] = 539437,
  [SMALL_STATE(11604)] = 539481,
  [SMALL_STATE(11605)] = 539525,
  [SMALL_STATE(11606)] = 539571,
  [SMALL_STATE(11607)] = 539615,
  [SMALL_STATE(11608)] = 539659,
  [SMALL_STATE(11609)] = 539703,
  [SMALL_STATE(11610)] = 539747,
  [SMALL_STATE(11611)] = 539791,
  [SMALL_STATE(11612)] = 539819,
  [SMALL_STATE(11613)] = 539847,
  [SMALL_STATE(11614)] = 539875,
  [SMALL_STATE(11615)] = 539919,
  [SMALL_STATE(11616)] = 539963,
  [SMALL_STATE(11617)] = 539991,
  [SMALL_STATE(11618)] = 540035,
  [SMALL_STATE(11619)] = 540079,
  [SMALL_STATE(11620)] = 540125,
  [SMALL_STATE(11621)] = 540169,
  [SMALL_STATE(11622)] = 540213,
  [SMALL_STATE(11623)] = 540257,
  [SMALL_STATE(11624)] = 540285,
  [SMALL_STATE(11625)] = 540329,
  [SMALL_STATE(11626)] = 540357,
  [SMALL_STATE(11627)] = 540401,
  [SMALL_STATE(11628)] = 540447,
  [SMALL_STATE(11629)] = 540491,
  [SMALL_STATE(11630)] = 540537,
  [SMALL_STATE(11631)] = 540581,
  [SMALL_STATE(11632)] = 540609,
  [SMALL_STATE(11633)] = 540653,
  [SMALL_STATE(11634)] = 540697,
  [SMALL_STATE(11635)] = 540725,
  [SMALL_STATE(11636)] = 540769,
  [SMALL_STATE(11637)] = 540813,
  [SMALL_STATE(11638)] = 540841,
  [SMALL_STATE(11639)] = 540885,
  [SMALL_STATE(11640)] = 540929,
  [SMALL_STATE(11641)] = 540975,
  [SMALL_STATE(11642)] = 541021,
  [SMALL_STATE(11643)] = 541049,
  [SMALL_STATE(11644)] = 541077,
  [SMALL_STATE(11645)] = 541105,
  [SMALL_STATE(11646)] = 541135,
  [SMALL_STATE(11647)] = 541165,
  [SMALL_STATE(11648)] = 541193,
  [SMALL_STATE(11649)] = 541237,
  [SMALL_STATE(11650)] = 541265,
  [SMALL_STATE(11651)] = 541293,
  [SMALL_STATE(11652)] = 541321,
  [SMALL_STATE(11653)] = 541365,
  [SMALL_STATE(11654)] = 541409,
  [SMALL_STATE(11655)] = 541453,
  [SMALL_STATE(11656)] = 541497,
  [SMALL_STATE(11657)] = 541525,
  [SMALL_STATE(11658)] = 541569,
  [SMALL_STATE(11659)] = 541597,
  [SMALL_STATE(11660)] = 541625,
  [SMALL_STATE(11661)] = 541669,
  [SMALL_STATE(11662)] = 541701,
  [SMALL_STATE(11663)] = 541731,
  [SMALL_STATE(11664)] = 541775,
  [SMALL_STATE(11665)] = 541819,
  [SMALL_STATE(11666)] = 541863,
  [SMALL_STATE(11667)] = 541893,
  [SMALL_STATE(11668)] = 541923,
  [SMALL_STATE(11669)] = 541967,
  [SMALL_STATE(11670)] = 541995,
  [SMALL_STATE(11671)] = 542039,
  [SMALL_STATE(11672)] = 542083,
  [SMALL_STATE(11673)] = 542123,
  [SMALL_STATE(11674)] = 542153,
  [SMALL_STATE(11675)] = 542183,
  [SMALL_STATE(11676)] = 542211,
  [SMALL_STATE(11677)] = 542255,
  [SMALL_STATE(11678)] = 542299,
  [SMALL_STATE(11679)] = 542343,
  [SMALL_STATE(11680)] = 542387,
  [SMALL_STATE(11681)] = 542431,
  [SMALL_STATE(11682)] = 542459,
  [SMALL_STATE(11683)] = 542503,
  [SMALL_STATE(11684)] = 542547,
  [SMALL_STATE(11685)] = 542581,
  [SMALL_STATE(11686)] = 542625,
  [SMALL_STATE(11687)] = 542669,
  [SMALL_STATE(11688)] = 542697,
  [SMALL_STATE(11689)] = 542741,
  [SMALL_STATE(11690)] = 542773,
  [SMALL_STATE(11691)] = 542817,
  [SMALL_STATE(11692)] = 542861,
  [SMALL_STATE(11693)] = 542905,
  [SMALL_STATE(11694)] = 542949,
  [SMALL_STATE(11695)] = 542993,
  [SMALL_STATE(11696)] = 543037,
  [SMALL_STATE(11697)] = 543081,
  [SMALL_STATE(11698)] = 543125,
  [SMALL_STATE(11699)] = 543169,
  [SMALL_STATE(11700)] = 543197,
  [SMALL_STATE(11701)] = 543241,
  [SMALL_STATE(11702)] = 543285,
  [SMALL_STATE(11703)] = 543314,
  [SMALL_STATE(11704)] = 543343,
  [SMALL_STATE(11705)] = 543372,
  [SMALL_STATE(11706)] = 543401,
  [SMALL_STATE(11707)] = 543430,
  [SMALL_STATE(11708)] = 543459,
  [SMALL_STATE(11709)] = 543488,
  [SMALL_STATE(11710)] = 543517,
  [SMALL_STATE(11711)] = 543546,
  [SMALL_STATE(11712)] = 543573,
  [SMALL_STATE(11713)] = 543602,
  [SMALL_STATE(11714)] = 543631,
  [SMALL_STATE(11715)] = 543664,
  [SMALL_STATE(11716)] = 543695,
  [SMALL_STATE(11717)] = 543736,
  [SMALL_STATE(11718)] = 543767,
  [SMALL_STATE(11719)] = 543810,
  [SMALL_STATE(11720)] = 543843,
  [SMALL_STATE(11721)] = 543874,
  [SMALL_STATE(11722)] = 543901,
  [SMALL_STATE(11723)] = 543928,
  [SMALL_STATE(11724)] = 543959,
  [SMALL_STATE(11725)] = 543990,
  [SMALL_STATE(11726)] = 544021,
  [SMALL_STATE(11727)] = 544062,
  [SMALL_STATE(11728)] = 544089,
  [SMALL_STATE(11729)] = 544130,
  [SMALL_STATE(11730)] = 544171,
  [SMALL_STATE(11731)] = 544212,
  [SMALL_STATE(11732)] = 544239,
  [SMALL_STATE(11733)] = 544278,
  [SMALL_STATE(11734)] = 544307,
  [SMALL_STATE(11735)] = 544336,
  [SMALL_STATE(11736)] = 544377,
  [SMALL_STATE(11737)] = 544406,
  [SMALL_STATE(11738)] = 544433,
  [SMALL_STATE(11739)] = 544462,
  [SMALL_STATE(11740)] = 544489,
  [SMALL_STATE(11741)] = 544518,
  [SMALL_STATE(11742)] = 544547,
  [SMALL_STATE(11743)] = 544574,
  [SMALL_STATE(11744)] = 544601,
  [SMALL_STATE(11745)] = 544630,
  [SMALL_STATE(11746)] = 544671,
  [SMALL_STATE(11747)] = 544698,
  [SMALL_STATE(11748)] = 544739,
  [SMALL_STATE(11749)] = 544768,
  [SMALL_STATE(11750)] = 544795,
  [SMALL_STATE(11751)] = 544822,
  [SMALL_STATE(11752)] = 544861,
  [SMALL_STATE(11753)] = 544888,
  [SMALL_STATE(11754)] = 544915,
  [SMALL_STATE(11755)] = 544942,
  [SMALL_STATE(11756)] = 544969,
  [SMALL_STATE(11757)] = 544996,
  [SMALL_STATE(11758)] = 545023,
  [SMALL_STATE(11759)] = 545050,
  [SMALL_STATE(11760)] = 545077,
  [SMALL_STATE(11761)] = 545104,
  [SMALL_STATE(11762)] = 545131,
  [SMALL_STATE(11763)] = 545158,
  [SMALL_STATE(11764)] = 545185,
  [SMALL_STATE(11765)] = 545212,
  [SMALL_STATE(11766)] = 545253,
  [SMALL_STATE(11767)] = 545294,
  [SMALL_STATE(11768)] = 545321,
  [SMALL_STATE(11769)] = 545348,
  [SMALL_STATE(11770)] = 545375,
  [SMALL_STATE(11771)] = 545404,
  [SMALL_STATE(11772)] = 545443,
  [SMALL_STATE(11773)] = 545472,
  [SMALL_STATE(11774)] = 545503,
  [SMALL_STATE(11775)] = 545532,
  [SMALL_STATE(11776)] = 545561,
  [SMALL_STATE(11777)] = 545588,
  [SMALL_STATE(11778)] = 545617,
  [SMALL_STATE(11779)] = 545646,
  [SMALL_STATE(11780)] = 545675,
  [SMALL_STATE(11781)] = 545704,
  [SMALL_STATE(11782)] = 545745,
  [SMALL_STATE(11783)] = 545772,
  [SMALL_STATE(11784)] = 545813,
  [SMALL_STATE(11785)] = 545854,
  [SMALL_STATE(11786)] = 545883,
  [SMALL_STATE(11787)] = 545924,
  [SMALL_STATE(11788)] = 545953,
  [SMALL_STATE(11789)] = 545994,
  [SMALL_STATE(11790)] = 546027,
  [SMALL_STATE(11791)] = 546054,
  [SMALL_STATE(11792)] = 546081,
  [SMALL_STATE(11793)] = 546108,
  [SMALL_STATE(11794)] = 546139,
  [SMALL_STATE(11795)] = 546166,
  [SMALL_STATE(11796)] = 546193,
  [SMALL_STATE(11797)] = 546224,
  [SMALL_STATE(11798)] = 546253,
  [SMALL_STATE(11799)] = 546280,
  [SMALL_STATE(11800)] = 546307,
  [SMALL_STATE(11801)] = 546334,
  [SMALL_STATE(11802)] = 546361,
  [SMALL_STATE(11803)] = 546402,
  [SMALL_STATE(11804)] = 546431,
  [SMALL_STATE(11805)] = 546460,
  [SMALL_STATE(11806)] = 546501,
  [SMALL_STATE(11807)] = 546532,
  [SMALL_STATE(11808)] = 546573,
  [SMALL_STATE(11809)] = 546612,
  [SMALL_STATE(11810)] = 546643,
  [SMALL_STATE(11811)] = 546670,
  [SMALL_STATE(11812)] = 546699,
  [SMALL_STATE(11813)] = 546728,
  [SMALL_STATE(11814)] = 546757,
  [SMALL_STATE(11815)] = 546784,
  [SMALL_STATE(11816)] = 546825,
  [SMALL_STATE(11817)] = 546854,
  [SMALL_STATE(11818)] = 546883,
  [SMALL_STATE(11819)] = 546910,
  [SMALL_STATE(11820)] = 546937,
  [SMALL_STATE(11821)] = 546964,
  [SMALL_STATE(11822)] = 546991,
  [SMALL_STATE(11823)] = 547032,
  [SMALL_STATE(11824)] = 547073,
  [SMALL_STATE(11825)] = 547100,
  [SMALL_STATE(11826)] = 547127,
  [SMALL_STATE(11827)] = 547168,
  [SMALL_STATE(11828)] = 547195,
  [SMALL_STATE(11829)] = 547246,
  [SMALL_STATE(11830)] = 547287,
  [SMALL_STATE(11831)] = 547328,
  [SMALL_STATE(11832)] = 547369,
  [SMALL_STATE(11833)] = 547402,
  [SMALL_STATE(11834)] = 547429,
  [SMALL_STATE(11835)] = 547456,
  [SMALL_STATE(11836)] = 547485,
  [SMALL_STATE(11837)] = 547514,
  [SMALL_STATE(11838)] = 547541,
  [SMALL_STATE(11839)] = 547568,
  [SMALL_STATE(11840)] = 547609,
  [SMALL_STATE(11841)] = 547638,
  [SMALL_STATE(11842)] = 547665,
  [SMALL_STATE(11843)] = 547706,
  [SMALL_STATE(11844)] = 547747,
  [SMALL_STATE(11845)] = 547774,
  [SMALL_STATE(11846)] = 547801,
  [SMALL_STATE(11847)] = 547834,
  [SMALL_STATE(11848)] = 547863,
  [SMALL_STATE(11849)] = 547890,
  [SMALL_STATE(11850)] = 547917,
  [SMALL_STATE(11851)] = 547944,
  [SMALL_STATE(11852)] = 547971,
  [SMALL_STATE(11853)] = 548000,
  [SMALL_STATE(11854)] = 548027,
  [SMALL_STATE(11855)] = 548068,
  [SMALL_STATE(11856)] = 548095,
  [SMALL_STATE(11857)] = 548122,
  [SMALL_STATE(11858)] = 548151,
  [SMALL_STATE(11859)] = 548178,
  [SMALL_STATE(11860)] = 548205,
  [SMALL_STATE(11861)] = 548232,
  [SMALL_STATE(11862)] = 548259,
  [SMALL_STATE(11863)] = 548286,
  [SMALL_STATE(11864)] = 548313,
  [SMALL_STATE(11865)] = 548340,
  [SMALL_STATE(11866)] = 548381,
  [SMALL_STATE(11867)] = 548410,
  [SMALL_STATE(11868)] = 548437,
  [SMALL_STATE(11869)] = 548464,
  [SMALL_STATE(11870)] = 548491,
  [SMALL_STATE(11871)] = 548518,
  [SMALL_STATE(11872)] = 548559,
  [SMALL_STATE(11873)] = 548600,
  [SMALL_STATE(11874)] = 548639,
  [SMALL_STATE(11875)] = 548666,
  [SMALL_STATE(11876)] = 548693,
  [SMALL_STATE(11877)] = 548720,
  [SMALL_STATE(11878)] = 548761,
  [SMALL_STATE(11879)] = 548788,
  [SMALL_STATE(11880)] = 548829,
  [SMALL_STATE(11881)] = 548856,
  [SMALL_STATE(11882)] = 548883,
  [SMALL_STATE(11883)] = 548910,
  [SMALL_STATE(11884)] = 548937,
  [SMALL_STATE(11885)] = 548966,
  [SMALL_STATE(11886)] = 548993,
  [SMALL_STATE(11887)] = 549022,
  [SMALL_STATE(11888)] = 549049,
  [SMALL_STATE(11889)] = 549078,
  [SMALL_STATE(11890)] = 549105,
  [SMALL_STATE(11891)] = 549132,
  [SMALL_STATE(11892)] = 549173,
  [SMALL_STATE(11893)] = 549214,
  [SMALL_STATE(11894)] = 549241,
  [SMALL_STATE(11895)] = 549276,
  [SMALL_STATE(11896)] = 549303,
  [SMALL_STATE(11897)] = 549332,
  [SMALL_STATE(11898)] = 549359,
  [SMALL_STATE(11899)] = 549386,
  [SMALL_STATE(11900)] = 549427,
  [SMALL_STATE(11901)] = 549454,
  [SMALL_STATE(11902)] = 549481,
  [SMALL_STATE(11903)] = 549508,
  [SMALL_STATE(11904)] = 549549,
  [SMALL_STATE(11905)] = 549576,
  [SMALL_STATE(11906)] = 549605,
  [SMALL_STATE(11907)] = 549632,
  [SMALL_STATE(11908)] = 549673,
  [SMALL_STATE(11909)] = 549700,
  [SMALL_STATE(11910)] = 549729,
  [SMALL_STATE(11911)] = 549770,
  [SMALL_STATE(11912)] = 549797,
  [SMALL_STATE(11913)] = 549824,
  [SMALL_STATE(11914)] = 549851,
  [SMALL_STATE(11915)] = 549892,
  [SMALL_STATE(11916)] = 549921,
  [SMALL_STATE(11917)] = 549950,
  [SMALL_STATE(11918)] = 549991,
  [SMALL_STATE(11919)] = 550018,
  [SMALL_STATE(11920)] = 550059,
  [SMALL_STATE(11921)] = 550086,
  [SMALL_STATE(11922)] = 550127,
  [SMALL_STATE(11923)] = 550154,
  [SMALL_STATE(11924)] = 550195,
  [SMALL_STATE(11925)] = 550224,
  [SMALL_STATE(11926)] = 550265,
  [SMALL_STATE(11927)] = 550306,
  [SMALL_STATE(11928)] = 550335,
  [SMALL_STATE(11929)] = 550364,
  [SMALL_STATE(11930)] = 550405,
  [SMALL_STATE(11931)] = 550434,
  [SMALL_STATE(11932)] = 550463,
  [SMALL_STATE(11933)] = 550490,
  [SMALL_STATE(11934)] = 550519,
  [SMALL_STATE(11935)] = 550552,
  [SMALL_STATE(11936)] = 550581,
  [SMALL_STATE(11937)] = 550628,
  [SMALL_STATE(11938)] = 550669,
  [SMALL_STATE(11939)] = 550710,
  [SMALL_STATE(11940)] = 550739,
  [SMALL_STATE(11941)] = 550766,
  [SMALL_STATE(11942)] = 550793,
  [SMALL_STATE(11943)] = 550820,
  [SMALL_STATE(11944)] = 550849,
  [SMALL_STATE(11945)] = 550878,
  [SMALL_STATE(11946)] = 550905,
  [SMALL_STATE(11947)] = 550932,
  [SMALL_STATE(11948)] = 550961,
  [SMALL_STATE(11949)] = 551002,
  [SMALL_STATE(11950)] = 551031,
  [SMALL_STATE(11951)] = 551058,
  [SMALL_STATE(11952)] = 551087,
  [SMALL_STATE(11953)] = 551126,
  [SMALL_STATE(11954)] = 551167,
  [SMALL_STATE(11955)] = 551208,
  [SMALL_STATE(11956)] = 551237,
  [SMALL_STATE(11957)] = 551266,
  [SMALL_STATE(11958)] = 551293,
  [SMALL_STATE(11959)] = 551320,
  [SMALL_STATE(11960)] = 551347,
  [SMALL_STATE(11961)] = 551388,
  [SMALL_STATE(11962)] = 551431,
  [SMALL_STATE(11963)] = 551458,
  [SMALL_STATE(11964)] = 551503,
  [SMALL_STATE(11965)] = 551542,
  [SMALL_STATE(11966)] = 551575,
  [SMALL_STATE(11967)] = 551604,
  [SMALL_STATE(11968)] = 551631,
  [SMALL_STATE(11969)] = 551658,
  [SMALL_STATE(11970)] = 551687,
  [SMALL_STATE(11971)] = 551716,
  [SMALL_STATE(11972)] = 551747,
  [SMALL_STATE(11973)] = 551788,
  [SMALL_STATE(11974)] = 551829,
  [SMALL_STATE(11975)] = 551856,
  [SMALL_STATE(11976)] = 551885,
  [SMALL_STATE(11977)] = 551912,
  [SMALL_STATE(11978)] = 551939,
  [SMALL_STATE(11979)] = 551966,
  [SMALL_STATE(11980)] = 551993,
  [SMALL_STATE(11981)] = 552020,
  [SMALL_STATE(11982)] = 552049,
  [SMALL_STATE(11983)] = 552076,
  [SMALL_STATE(11984)] = 552117,
  [SMALL_STATE(11985)] = 552144,
  [SMALL_STATE(11986)] = 552171,
  [SMALL_STATE(11987)] = 552200,
  [SMALL_STATE(11988)] = 552227,
  [SMALL_STATE(11989)] = 552256,
  [SMALL_STATE(11990)] = 552297,
  [SMALL_STATE(11991)] = 552326,
  [SMALL_STATE(11992)] = 552353,
  [SMALL_STATE(11993)] = 552380,
  [SMALL_STATE(11994)] = 552409,
  [SMALL_STATE(11995)] = 552436,
  [SMALL_STATE(11996)] = 552477,
  [SMALL_STATE(11997)] = 552518,
  [SMALL_STATE(11998)] = 552561,
  [SMALL_STATE(11999)] = 552602,
  [SMALL_STATE(12000)] = 552631,
  [SMALL_STATE(12001)] = 552660,
  [SMALL_STATE(12002)] = 552701,
  [SMALL_STATE(12003)] = 552742,
  [SMALL_STATE(12004)] = 552769,
  [SMALL_STATE(12005)] = 552798,
  [SMALL_STATE(12006)] = 552839,
  [SMALL_STATE(12007)] = 552880,
  [SMALL_STATE(12008)] = 552921,
  [SMALL_STATE(12009)] = 552962,
  [SMALL_STATE(12010)] = 552989,
  [SMALL_STATE(12011)] = 553030,
  [SMALL_STATE(12012)] = 553057,
  [SMALL_STATE(12013)] = 553086,
  [SMALL_STATE(12014)] = 553127,
  [SMALL_STATE(12015)] = 553154,
  [SMALL_STATE(12016)] = 553195,
  [SMALL_STATE(12017)] = 553240,
  [SMALL_STATE(12018)] = 553271,
  [SMALL_STATE(12019)] = 553298,
  [SMALL_STATE(12020)] = 553325,
  [SMALL_STATE(12021)] = 553352,
  [SMALL_STATE(12022)] = 553381,
  [SMALL_STATE(12023)] = 553410,
  [SMALL_STATE(12024)] = 553451,
  [SMALL_STATE(12025)] = 553492,
  [SMALL_STATE(12026)] = 553521,
  [SMALL_STATE(12027)] = 553550,
  [SMALL_STATE(12028)] = 553589,
  [SMALL_STATE(12029)] = 553616,
  [SMALL_STATE(12030)] = 553657,
  [SMALL_STATE(12031)] = 553698,
  [SMALL_STATE(12032)] = 553739,
  [SMALL_STATE(12033)] = 553780,
  [SMALL_STATE(12034)] = 553821,
  [SMALL_STATE(12035)] = 553862,
  [SMALL_STATE(12036)] = 553903,
  [SMALL_STATE(12037)] = 553934,
  [SMALL_STATE(12038)] = 553963,
  [SMALL_STATE(12039)] = 554004,
  [SMALL_STATE(12040)] = 554045,
  [SMALL_STATE(12041)] = 554086,
  [SMALL_STATE(12042)] = 554127,
  [SMALL_STATE(12043)] = 554156,
  [SMALL_STATE(12044)] = 554195,
  [SMALL_STATE(12045)] = 554224,
  [SMALL_STATE(12046)] = 554253,
  [SMALL_STATE(12047)] = 554282,
  [SMALL_STATE(12048)] = 554311,
  [SMALL_STATE(12049)] = 554340,
  [SMALL_STATE(12050)] = 554381,
  [SMALL_STATE(12051)] = 554422,
  [SMALL_STATE(12052)] = 554461,
  [SMALL_STATE(12053)] = 554489,
  [SMALL_STATE(12054)] = 554515,
  [SMALL_STATE(12055)] = 554555,
  [SMALL_STATE(12056)] = 554595,
  [SMALL_STATE(12057)] = 554625,
  [SMALL_STATE(12058)] = 554653,
  [SMALL_STATE(12059)] = 554693,
  [SMALL_STATE(12060)] = 554725,
  [SMALL_STATE(12061)] = 554751,
  [SMALL_STATE(12062)] = 554791,
  [SMALL_STATE(12063)] = 554831,
  [SMALL_STATE(12064)] = 554871,
  [SMALL_STATE(12065)] = 554911,
  [SMALL_STATE(12066)] = 554951,
  [SMALL_STATE(12067)] = 554991,
  [SMALL_STATE(12068)] = 555019,
  [SMALL_STATE(12069)] = 555059,
  [SMALL_STATE(12070)] = 555087,
  [SMALL_STATE(12071)] = 555115,
  [SMALL_STATE(12072)] = 555155,
  [SMALL_STATE(12073)] = 555183,
  [SMALL_STATE(12074)] = 555211,
  [SMALL_STATE(12075)] = 555249,
  [SMALL_STATE(12076)] = 555279,
  [SMALL_STATE(12077)] = 555319,
  [SMALL_STATE(12078)] = 555359,
  [SMALL_STATE(12079)] = 555387,
  [SMALL_STATE(12080)] = 555415,
  [SMALL_STATE(12081)] = 555455,
  [SMALL_STATE(12082)] = 555495,
  [SMALL_STATE(12083)] = 555535,
  [SMALL_STATE(12084)] = 555563,
  [SMALL_STATE(12085)] = 555603,
  [SMALL_STATE(12086)] = 555631,
  [SMALL_STATE(12087)] = 555659,
  [SMALL_STATE(12088)] = 555699,
  [SMALL_STATE(12089)] = 555727,
  [SMALL_STATE(12090)] = 555753,
  [SMALL_STATE(12091)] = 555781,
  [SMALL_STATE(12092)] = 555821,
  [SMALL_STATE(12093)] = 555861,
  [SMALL_STATE(12094)] = 555887,
  [SMALL_STATE(12095)] = 555927,
  [SMALL_STATE(12096)] = 555967,
  [SMALL_STATE(12097)] = 555993,
  [SMALL_STATE(12098)] = 556021,
  [SMALL_STATE(12099)] = 556047,
  [SMALL_STATE(12100)] = 556073,
  [SMALL_STATE(12101)] = 556111,
  [SMALL_STATE(12102)] = 556151,
  [SMALL_STATE(12103)] = 556191,
  [SMALL_STATE(12104)] = 556217,
  [SMALL_STATE(12105)] = 556257,
  [SMALL_STATE(12106)] = 556297,
  [SMALL_STATE(12107)] = 556323,
  [SMALL_STATE(12108)] = 556349,
  [SMALL_STATE(12109)] = 556375,
  [SMALL_STATE(12110)] = 556401,
  [SMALL_STATE(12111)] = 556441,
  [SMALL_STATE(12112)] = 556469,
  [SMALL_STATE(12113)] = 556501,
  [SMALL_STATE(12114)] = 556527,
  [SMALL_STATE(12115)] = 556557,
  [SMALL_STATE(12116)] = 556597,
  [SMALL_STATE(12117)] = 556637,
  [SMALL_STATE(12118)] = 556677,
  [SMALL_STATE(12119)] = 556703,
  [SMALL_STATE(12120)] = 556743,
  [SMALL_STATE(12121)] = 556769,
  [SMALL_STATE(12122)] = 556807,
  [SMALL_STATE(12123)] = 556847,
  [SMALL_STATE(12124)] = 556875,
  [SMALL_STATE(12125)] = 556903,
  [SMALL_STATE(12126)] = 556929,
  [SMALL_STATE(12127)] = 556955,
  [SMALL_STATE(12128)] = 556981,
  [SMALL_STATE(12129)] = 557009,
  [SMALL_STATE(12130)] = 557037,
  [SMALL_STATE(12131)] = 557063,
  [SMALL_STATE(12132)] = 557103,
  [SMALL_STATE(12133)] = 557143,
  [SMALL_STATE(12134)] = 557183,
  [SMALL_STATE(12135)] = 557215,
  [SMALL_STATE(12136)] = 557255,
  [SMALL_STATE(12137)] = 557293,
  [SMALL_STATE(12138)] = 557319,
  [SMALL_STATE(12139)] = 557347,
  [SMALL_STATE(12140)] = 557373,
  [SMALL_STATE(12141)] = 557401,
  [SMALL_STATE(12142)] = 557441,
  [SMALL_STATE(12143)] = 557469,
  [SMALL_STATE(12144)] = 557509,
  [SMALL_STATE(12145)] = 557549,
  [SMALL_STATE(12146)] = 557589,
  [SMALL_STATE(12147)] = 557617,
  [SMALL_STATE(12148)] = 557657,
  [SMALL_STATE(12149)] = 557683,
  [SMALL_STATE(12150)] = 557725,
  [SMALL_STATE(12151)] = 557755,
  [SMALL_STATE(12152)] = 557781,
  [SMALL_STATE(12153)] = 557821,
  [SMALL_STATE(12154)] = 557849,
  [SMALL_STATE(12155)] = 557877,
  [SMALL_STATE(12156)] = 557917,
  [SMALL_STATE(12157)] = 557957,
  [SMALL_STATE(12158)] = 557995,
  [SMALL_STATE(12159)] = 558025,
  [SMALL_STATE(12160)] = 558055,
  [SMALL_STATE(12161)] = 558095,
  [SMALL_STATE(12162)] = 558123,
  [SMALL_STATE(12163)] = 558163,
  [SMALL_STATE(12164)] = 558203,
  [SMALL_STATE(12165)] = 558231,
  [SMALL_STATE(12166)] = 558271,
  [SMALL_STATE(12167)] = 558299,
  [SMALL_STATE(12168)] = 558327,
  [SMALL_STATE(12169)] = 558355,
  [SMALL_STATE(12170)] = 558381,
  [SMALL_STATE(12171)] = 558421,
  [SMALL_STATE(12172)] = 558461,
  [SMALL_STATE(12173)] = 558501,
  [SMALL_STATE(12174)] = 558541,
  [SMALL_STATE(12175)] = 558567,
  [SMALL_STATE(12176)] = 558607,
  [SMALL_STATE(12177)] = 558647,
  [SMALL_STATE(12178)] = 558687,
  [SMALL_STATE(12179)] = 558727,
  [SMALL_STATE(12180)] = 558755,
  [SMALL_STATE(12181)] = 558795,
  [SMALL_STATE(12182)] = 558825,
  [SMALL_STATE(12183)] = 558865,
  [SMALL_STATE(12184)] = 558905,
  [SMALL_STATE(12185)] = 558945,
  [SMALL_STATE(12186)] = 558975,
  [SMALL_STATE(12187)] = 559003,
  [SMALL_STATE(12188)] = 559043,
  [SMALL_STATE(12189)] = 559069,
  [SMALL_STATE(12190)] = 559109,
  [SMALL_STATE(12191)] = 559149,
  [SMALL_STATE(12192)] = 559189,
  [SMALL_STATE(12193)] = 559217,
  [SMALL_STATE(12194)] = 559243,
  [SMALL_STATE(12195)] = 559269,
  [SMALL_STATE(12196)] = 559297,
  [SMALL_STATE(12197)] = 559325,
  [SMALL_STATE(12198)] = 559353,
  [SMALL_STATE(12199)] = 559379,
  [SMALL_STATE(12200)] = 559407,
  [SMALL_STATE(12201)] = 559433,
  [SMALL_STATE(12202)] = 559461,
  [SMALL_STATE(12203)] = 559501,
  [SMALL_STATE(12204)] = 559527,
  [SMALL_STATE(12205)] = 559555,
  [SMALL_STATE(12206)] = 559585,
  [SMALL_STATE(12207)] = 559623,
  [SMALL_STATE(12208)] = 559649,
  [SMALL_STATE(12209)] = 559689,
  [SMALL_STATE(12210)] = 559719,
  [SMALL_STATE(12211)] = 559745,
  [SMALL_STATE(12212)] = 559773,
  [SMALL_STATE(12213)] = 559799,
  [SMALL_STATE(12214)] = 559827,
  [SMALL_STATE(12215)] = 559867,
  [SMALL_STATE(12216)] = 559907,
  [SMALL_STATE(12217)] = 559933,
  [SMALL_STATE(12218)] = 559961,
  [SMALL_STATE(12219)] = 560001,
  [SMALL_STATE(12220)] = 560027,
  [SMALL_STATE(12221)] = 560067,
  [SMALL_STATE(12222)] = 560093,
  [SMALL_STATE(12223)] = 560133,
  [SMALL_STATE(12224)] = 560173,
  [SMALL_STATE(12225)] = 560199,
  [SMALL_STATE(12226)] = 560225,
  [SMALL_STATE(12227)] = 560265,
  [SMALL_STATE(12228)] = 560291,
  [SMALL_STATE(12229)] = 560317,
  [SMALL_STATE(12230)] = 560357,
  [SMALL_STATE(12231)] = 560385,
  [SMALL_STATE(12232)] = 560411,
  [SMALL_STATE(12233)] = 560437,
  [SMALL_STATE(12234)] = 560463,
  [SMALL_STATE(12235)] = 560503,
  [SMALL_STATE(12236)] = 560531,
  [SMALL_STATE(12237)] = 560557,
  [SMALL_STATE(12238)] = 560597,
  [SMALL_STATE(12239)] = 560623,
  [SMALL_STATE(12240)] = 560663,
  [SMALL_STATE(12241)] = 560703,
  [SMALL_STATE(12242)] = 560731,
  [SMALL_STATE(12243)] = 560759,
  [SMALL_STATE(12244)] = 560799,
  [SMALL_STATE(12245)] = 560825,
  [SMALL_STATE(12246)] = 560865,
  [SMALL_STATE(12247)] = 560893,
  [SMALL_STATE(12248)] = 560919,
  [SMALL_STATE(12249)] = 560959,
  [SMALL_STATE(12250)] = 560985,
  [SMALL_STATE(12251)] = 561025,
  [SMALL_STATE(12252)] = 561065,
  [SMALL_STATE(12253)] = 561105,
  [SMALL_STATE(12254)] = 561135,
  [SMALL_STATE(12255)] = 561161,
  [SMALL_STATE(12256)] = 561201,
  [SMALL_STATE(12257)] = 561227,
  [SMALL_STATE(12258)] = 561253,
  [SMALL_STATE(12259)] = 561293,
  [SMALL_STATE(12260)] = 561333,
  [SMALL_STATE(12261)] = 561359,
  [SMALL_STATE(12262)] = 561385,
  [SMALL_STATE(12263)] = 561411,
  [SMALL_STATE(12264)] = 561441,
  [SMALL_STATE(12265)] = 561481,
  [SMALL_STATE(12266)] = 561521,
  [SMALL_STATE(12267)] = 561563,
  [SMALL_STATE(12268)] = 561589,
  [SMALL_STATE(12269)] = 561629,
  [SMALL_STATE(12270)] = 561655,
  [SMALL_STATE(12271)] = 561681,
  [SMALL_STATE(12272)] = 561707,
  [SMALL_STATE(12273)] = 561733,
  [SMALL_STATE(12274)] = 561759,
  [SMALL_STATE(12275)] = 561785,
  [SMALL_STATE(12276)] = 561825,
  [SMALL_STATE(12277)] = 561865,
  [SMALL_STATE(12278)] = 561893,
  [SMALL_STATE(12279)] = 561923,
  [SMALL_STATE(12280)] = 561963,
  [SMALL_STATE(12281)] = 561989,
  [SMALL_STATE(12282)] = 562029,
  [SMALL_STATE(12283)] = 562063,
  [SMALL_STATE(12284)] = 562089,
  [SMALL_STATE(12285)] = 562115,
  [SMALL_STATE(12286)] = 562155,
  [SMALL_STATE(12287)] = 562185,
  [SMALL_STATE(12288)] = 562211,
  [SMALL_STATE(12289)] = 562237,
  [SMALL_STATE(12290)] = 562267,
  [SMALL_STATE(12291)] = 562293,
  [SMALL_STATE(12292)] = 562333,
  [SMALL_STATE(12293)] = 562359,
  [SMALL_STATE(12294)] = 562397,
  [SMALL_STATE(12295)] = 562423,
  [SMALL_STATE(12296)] = 562449,
  [SMALL_STATE(12297)] = 562475,
  [SMALL_STATE(12298)] = 562515,
  [SMALL_STATE(12299)] = 562541,
  [SMALL_STATE(12300)] = 562581,
  [SMALL_STATE(12301)] = 562607,
  [SMALL_STATE(12302)] = 562633,
  [SMALL_STATE(12303)] = 562659,
  [SMALL_STATE(12304)] = 562699,
  [SMALL_STATE(12305)] = 562727,
  [SMALL_STATE(12306)] = 562753,
  [SMALL_STATE(12307)] = 562779,
  [SMALL_STATE(12308)] = 562819,
  [SMALL_STATE(12309)] = 562845,
  [SMALL_STATE(12310)] = 562871,
  [SMALL_STATE(12311)] = 562897,
  [SMALL_STATE(12312)] = 562923,
  [SMALL_STATE(12313)] = 562949,
  [SMALL_STATE(12314)] = 562975,
  [SMALL_STATE(12315)] = 563001,
  [SMALL_STATE(12316)] = 563027,
  [SMALL_STATE(12317)] = 563053,
  [SMALL_STATE(12318)] = 563093,
  [SMALL_STATE(12319)] = 563119,
  [SMALL_STATE(12320)] = 563145,
  [SMALL_STATE(12321)] = 563171,
  [SMALL_STATE(12322)] = 563199,
  [SMALL_STATE(12323)] = 563225,
  [SMALL_STATE(12324)] = 563251,
  [SMALL_STATE(12325)] = 563291,
  [SMALL_STATE(12326)] = 563317,
  [SMALL_STATE(12327)] = 563357,
  [SMALL_STATE(12328)] = 563397,
  [SMALL_STATE(12329)] = 563429,
  [SMALL_STATE(12330)] = 563469,
  [SMALL_STATE(12331)] = 563497,
  [SMALL_STATE(12332)] = 563523,
  [SMALL_STATE(12333)] = 563563,
  [SMALL_STATE(12334)] = 563589,
  [SMALL_STATE(12335)] = 563615,
  [SMALL_STATE(12336)] = 563643,
  [SMALL_STATE(12337)] = 563683,
  [SMALL_STATE(12338)] = 563709,
  [SMALL_STATE(12339)] = 563737,
  [SMALL_STATE(12340)] = 563765,
  [SMALL_STATE(12341)] = 563791,
  [SMALL_STATE(12342)] = 563819,
  [SMALL_STATE(12343)] = 563857,
  [SMALL_STATE(12344)] = 563883,
  [SMALL_STATE(12345)] = 563911,
  [SMALL_STATE(12346)] = 563937,
  [SMALL_STATE(12347)] = 563965,
  [SMALL_STATE(12348)] = 563991,
  [SMALL_STATE(12349)] = 564031,
  [SMALL_STATE(12350)] = 564057,
  [SMALL_STATE(12351)] = 564083,
  [SMALL_STATE(12352)] = 564109,
  [SMALL_STATE(12353)] = 564135,
  [SMALL_STATE(12354)] = 564175,
  [SMALL_STATE(12355)] = 564203,
  [SMALL_STATE(12356)] = 564231,
  [SMALL_STATE(12357)] = 564257,
  [SMALL_STATE(12358)] = 564287,
  [SMALL_STATE(12359)] = 564327,
  [SMALL_STATE(12360)] = 564353,
  [SMALL_STATE(12361)] = 564393,
  [SMALL_STATE(12362)] = 564419,
  [SMALL_STATE(12363)] = 564445,
  [SMALL_STATE(12364)] = 564475,
  [SMALL_STATE(12365)] = 564515,
  [SMALL_STATE(12366)] = 564555,
  [SMALL_STATE(12367)] = 564595,
  [SMALL_STATE(12368)] = 564621,
  [SMALL_STATE(12369)] = 564653,
  [SMALL_STATE(12370)] = 564679,
  [SMALL_STATE(12371)] = 564705,
  [SMALL_STATE(12372)] = 564731,
  [SMALL_STATE(12373)] = 564761,
  [SMALL_STATE(12374)] = 564801,
  [SMALL_STATE(12375)] = 564827,
  [SMALL_STATE(12376)] = 564867,
  [SMALL_STATE(12377)] = 564897,
  [SMALL_STATE(12378)] = 564925,
  [SMALL_STATE(12379)] = 564951,
  [SMALL_STATE(12380)] = 564977,
  [SMALL_STATE(12381)] = 565017,
  [SMALL_STATE(12382)] = 565057,
  [SMALL_STATE(12383)] = 565083,
  [SMALL_STATE(12384)] = 565123,
  [SMALL_STATE(12385)] = 565155,
  [SMALL_STATE(12386)] = 565195,
  [SMALL_STATE(12387)] = 565225,
  [SMALL_STATE(12388)] = 565251,
  [SMALL_STATE(12389)] = 565291,
  [SMALL_STATE(12390)] = 565317,
  [SMALL_STATE(12391)] = 565343,
  [SMALL_STATE(12392)] = 565369,
  [SMALL_STATE(12393)] = 565395,
  [SMALL_STATE(12394)] = 565427,
  [SMALL_STATE(12395)] = 565467,
  [SMALL_STATE(12396)] = 565505,
  [SMALL_STATE(12397)] = 565531,
  [SMALL_STATE(12398)] = 565571,
  [SMALL_STATE(12399)] = 565597,
  [SMALL_STATE(12400)] = 565623,
  [SMALL_STATE(12401)] = 565651,
  [SMALL_STATE(12402)] = 565679,
  [SMALL_STATE(12403)] = 565719,
  [SMALL_STATE(12404)] = 565747,
  [SMALL_STATE(12405)] = 565777,
  [SMALL_STATE(12406)] = 565817,
  [SMALL_STATE(12407)] = 565855,
  [SMALL_STATE(12408)] = 565881,
  [SMALL_STATE(12409)] = 565921,
  [SMALL_STATE(12410)] = 565961,
  [SMALL_STATE(12411)] = 566001,
  [SMALL_STATE(12412)] = 566041,
  [SMALL_STATE(12413)] = 566067,
  [SMALL_STATE(12414)] = 566107,
  [SMALL_STATE(12415)] = 566133,
  [SMALL_STATE(12416)] = 566161,
  [SMALL_STATE(12417)] = 566203,
  [SMALL_STATE(12418)] = 566235,
  [SMALL_STATE(12419)] = 566263,
  [SMALL_STATE(12420)] = 566293,
  [SMALL_STATE(12421)] = 566323,
  [SMALL_STATE(12422)] = 566351,
  [SMALL_STATE(12423)] = 566391,
  [SMALL_STATE(12424)] = 566423,
  [SMALL_STATE(12425)] = 566449,
  [SMALL_STATE(12426)] = 566491,
  [SMALL_STATE(12427)] = 566517,
  [SMALL_STATE(12428)] = 566557,
  [SMALL_STATE(12429)] = 566597,
  [SMALL_STATE(12430)] = 566623,
  [SMALL_STATE(12431)] = 566651,
  [SMALL_STATE(12432)] = 566691,
  [SMALL_STATE(12433)] = 566731,
  [SMALL_STATE(12434)] = 566757,
  [SMALL_STATE(12435)] = 566797,
  [SMALL_STATE(12436)] = 566837,
  [SMALL_STATE(12437)] = 566867,
  [SMALL_STATE(12438)] = 566907,
  [SMALL_STATE(12439)] = 566933,
  [SMALL_STATE(12440)] = 566973,
  [SMALL_STATE(12441)] = 566999,
  [SMALL_STATE(12442)] = 567039,
  [SMALL_STATE(12443)] = 567069,
  [SMALL_STATE(12444)] = 567095,
  [SMALL_STATE(12445)] = 567133,
  [SMALL_STATE(12446)] = 567161,
  [SMALL_STATE(12447)] = 567187,
  [SMALL_STATE(12448)] = 567227,
  [SMALL_STATE(12449)] = 567253,
  [SMALL_STATE(12450)] = 567293,
  [SMALL_STATE(12451)] = 567319,
  [SMALL_STATE(12452)] = 567345,
  [SMALL_STATE(12453)] = 567375,
  [SMALL_STATE(12454)] = 567415,
  [SMALL_STATE(12455)] = 567455,
  [SMALL_STATE(12456)] = 567481,
  [SMALL_STATE(12457)] = 567521,
  [SMALL_STATE(12458)] = 567561,
  [SMALL_STATE(12459)] = 567589,
  [SMALL_STATE(12460)] = 567629,
  [SMALL_STATE(12461)] = 567657,
  [SMALL_STATE(12462)] = 567685,
  [SMALL_STATE(12463)] = 567725,
  [SMALL_STATE(12464)] = 567765,
  [SMALL_STATE(12465)] = 567795,
  [SMALL_STATE(12466)] = 567821,
  [SMALL_STATE(12467)] = 567858,
  [SMALL_STATE(12468)] = 567895,
  [SMALL_STATE(12469)] = 567932,
  [SMALL_STATE(12470)] = 567969,
  [SMALL_STATE(12471)] = 568000,
  [SMALL_STATE(12472)] = 568037,
  [SMALL_STATE(12473)] = 568064,
  [SMALL_STATE(12474)] = 568091,
  [SMALL_STATE(12475)] = 568128,
  [SMALL_STATE(12476)] = 568165,
  [SMALL_STATE(12477)] = 568202,
  [SMALL_STATE(12478)] = 568239,
  [SMALL_STATE(12479)] = 568268,
  [SMALL_STATE(12480)] = 568297,
  [SMALL_STATE(12481)] = 568334,
  [SMALL_STATE(12482)] = 568371,
  [SMALL_STATE(12483)] = 568408,
  [SMALL_STATE(12484)] = 568435,
  [SMALL_STATE(12485)] = 568470,
  [SMALL_STATE(12486)] = 568505,
  [SMALL_STATE(12487)] = 568532,
  [SMALL_STATE(12488)] = 568563,
  [SMALL_STATE(12489)] = 568600,
  [SMALL_STATE(12490)] = 568637,
  [SMALL_STATE(12491)] = 568674,
  [SMALL_STATE(12492)] = 568711,
  [SMALL_STATE(12493)] = 568740,
  [SMALL_STATE(12494)] = 568777,
  [SMALL_STATE(12495)] = 568806,
  [SMALL_STATE(12496)] = 568843,
  [SMALL_STATE(12497)] = 568880,
  [SMALL_STATE(12498)] = 568909,
  [SMALL_STATE(12499)] = 568946,
  [SMALL_STATE(12500)] = 568983,
  [SMALL_STATE(12501)] = 569008,
  [SMALL_STATE(12502)] = 569045,
  [SMALL_STATE(12503)] = 569074,
  [SMALL_STATE(12504)] = 569105,
  [SMALL_STATE(12505)] = 569142,
  [SMALL_STATE(12506)] = 569179,
  [SMALL_STATE(12507)] = 569216,
  [SMALL_STATE(12508)] = 569249,
  [SMALL_STATE(12509)] = 569286,
  [SMALL_STATE(12510)] = 569323,
  [SMALL_STATE(12511)] = 569348,
  [SMALL_STATE(12512)] = 569385,
  [SMALL_STATE(12513)] = 569422,
  [SMALL_STATE(12514)] = 569459,
  [SMALL_STATE(12515)] = 569496,
  [SMALL_STATE(12516)] = 569533,
  [SMALL_STATE(12517)] = 569570,
  [SMALL_STATE(12518)] = 569607,
  [SMALL_STATE(12519)] = 569636,
  [SMALL_STATE(12520)] = 569665,
  [SMALL_STATE(12521)] = 569696,
  [SMALL_STATE(12522)] = 569733,
  [SMALL_STATE(12523)] = 569760,
  [SMALL_STATE(12524)] = 569797,
  [SMALL_STATE(12525)] = 569834,
  [SMALL_STATE(12526)] = 569859,
  [SMALL_STATE(12527)] = 569896,
  [SMALL_STATE(12528)] = 569933,
  [SMALL_STATE(12529)] = 569958,
  [SMALL_STATE(12530)] = 569995,
  [SMALL_STATE(12531)] = 570032,
  [SMALL_STATE(12532)] = 570065,
  [SMALL_STATE(12533)] = 570090,
  [SMALL_STATE(12534)] = 570127,
  [SMALL_STATE(12535)] = 570160,
  [SMALL_STATE(12536)] = 570197,
  [SMALL_STATE(12537)] = 570234,
  [SMALL_STATE(12538)] = 570271,
  [SMALL_STATE(12539)] = 570296,
  [SMALL_STATE(12540)] = 570333,
  [SMALL_STATE(12541)] = 570370,
  [SMALL_STATE(12542)] = 570407,
  [SMALL_STATE(12543)] = 570444,
  [SMALL_STATE(12544)] = 570481,
  [SMALL_STATE(12545)] = 570518,
  [SMALL_STATE(12546)] = 570549,
  [SMALL_STATE(12547)] = 570586,
  [SMALL_STATE(12548)] = 570623,
  [SMALL_STATE(12549)] = 570660,
  [SMALL_STATE(12550)] = 570691,
  [SMALL_STATE(12551)] = 570718,
  [SMALL_STATE(12552)] = 570755,
  [SMALL_STATE(12553)] = 570780,
  [SMALL_STATE(12554)] = 570817,
  [SMALL_STATE(12555)] = 570842,
  [SMALL_STATE(12556)] = 570875,
  [SMALL_STATE(12557)] = 570912,
  [SMALL_STATE(12558)] = 570953,
  [SMALL_STATE(12559)] = 570990,
  [SMALL_STATE(12560)] = 571027,
  [SMALL_STATE(12561)] = 571064,
  [SMALL_STATE(12562)] = 571097,
  [SMALL_STATE(12563)] = 571130,
  [SMALL_STATE(12564)] = 571167,
  [SMALL_STATE(12565)] = 571204,
  [SMALL_STATE(12566)] = 571237,
  [SMALL_STATE(12567)] = 571274,
  [SMALL_STATE(12568)] = 571319,
  [SMALL_STATE(12569)] = 571356,
  [SMALL_STATE(12570)] = 571393,
  [SMALL_STATE(12571)] = 571430,
  [SMALL_STATE(12572)] = 571457,
  [SMALL_STATE(12573)] = 571494,
  [SMALL_STATE(12574)] = 571531,
  [SMALL_STATE(12575)] = 571568,
  [SMALL_STATE(12576)] = 571605,
  [SMALL_STATE(12577)] = 571642,
  [SMALL_STATE(12578)] = 571679,
  [SMALL_STATE(12579)] = 571716,
  [SMALL_STATE(12580)] = 571753,
  [SMALL_STATE(12581)] = 571790,
  [SMALL_STATE(12582)] = 571827,
  [SMALL_STATE(12583)] = 571864,
  [SMALL_STATE(12584)] = 571897,
  [SMALL_STATE(12585)] = 571934,
  [SMALL_STATE(12586)] = 571971,
  [SMALL_STATE(12587)] = 572008,
  [SMALL_STATE(12588)] = 572045,
  [SMALL_STATE(12589)] = 572070,
  [SMALL_STATE(12590)] = 572095,
  [SMALL_STATE(12591)] = 572120,
  [SMALL_STATE(12592)] = 572145,
  [SMALL_STATE(12593)] = 572182,
  [SMALL_STATE(12594)] = 572219,
  [SMALL_STATE(12595)] = 572256,
  [SMALL_STATE(12596)] = 572281,
  [SMALL_STATE(12597)] = 572318,
  [SMALL_STATE(12598)] = 572343,
  [SMALL_STATE(12599)] = 572370,
  [SMALL_STATE(12600)] = 572407,
  [SMALL_STATE(12601)] = 572432,
  [SMALL_STATE(12602)] = 572469,
  [SMALL_STATE(12603)] = 572506,
  [SMALL_STATE(12604)] = 572543,
  [SMALL_STATE(12605)] = 572580,
  [SMALL_STATE(12606)] = 572617,
  [SMALL_STATE(12607)] = 572642,
  [SMALL_STATE(12608)] = 572679,
  [SMALL_STATE(12609)] = 572704,
  [SMALL_STATE(12610)] = 572741,
  [SMALL_STATE(12611)] = 572778,
  [SMALL_STATE(12612)] = 572815,
  [SMALL_STATE(12613)] = 572840,
  [SMALL_STATE(12614)] = 572865,
  [SMALL_STATE(12615)] = 572902,
  [SMALL_STATE(12616)] = 572939,
  [SMALL_STATE(12617)] = 572976,
  [SMALL_STATE(12618)] = 573013,
  [SMALL_STATE(12619)] = 573050,
  [SMALL_STATE(12620)] = 573079,
  [SMALL_STATE(12621)] = 573104,
  [SMALL_STATE(12622)] = 573129,
  [SMALL_STATE(12623)] = 573166,
  [SMALL_STATE(12624)] = 573203,
  [SMALL_STATE(12625)] = 573228,
  [SMALL_STATE(12626)] = 573253,
  [SMALL_STATE(12627)] = 573278,
  [SMALL_STATE(12628)] = 573315,
  [SMALL_STATE(12629)] = 573352,
  [SMALL_STATE(12630)] = 573377,
  [SMALL_STATE(12631)] = 573402,
  [SMALL_STATE(12632)] = 573439,
  [SMALL_STATE(12633)] = 573464,
  [SMALL_STATE(12634)] = 573489,
  [SMALL_STATE(12635)] = 573526,
  [SMALL_STATE(12636)] = 573563,
  [SMALL_STATE(12637)] = 573588,
  [SMALL_STATE(12638)] = 573625,
  [SMALL_STATE(12639)] = 573650,
  [SMALL_STATE(12640)] = 573683,
  [SMALL_STATE(12641)] = 573708,
  [SMALL_STATE(12642)] = 573745,
  [SMALL_STATE(12643)] = 573780,
  [SMALL_STATE(12644)] = 573817,
  [SMALL_STATE(12645)] = 573854,
  [SMALL_STATE(12646)] = 573879,
  [SMALL_STATE(12647)] = 573916,
  [SMALL_STATE(12648)] = 573953,
  [SMALL_STATE(12649)] = 573990,
  [SMALL_STATE(12650)] = 574027,
  [SMALL_STATE(12651)] = 574052,
  [SMALL_STATE(12652)] = 574089,
  [SMALL_STATE(12653)] = 574114,
  [SMALL_STATE(12654)] = 574151,
  [SMALL_STATE(12655)] = 574176,
  [SMALL_STATE(12656)] = 574201,
  [SMALL_STATE(12657)] = 574238,
  [SMALL_STATE(12658)] = 574275,
  [SMALL_STATE(12659)] = 574300,
  [SMALL_STATE(12660)] = 574325,
  [SMALL_STATE(12661)] = 574350,
  [SMALL_STATE(12662)] = 574379,
  [SMALL_STATE(12663)] = 574416,
  [SMALL_STATE(12664)] = 574453,
  [SMALL_STATE(12665)] = 574478,
  [SMALL_STATE(12666)] = 574511,
  [SMALL_STATE(12667)] = 574544,
  [SMALL_STATE(12668)] = 574581,
  [SMALL_STATE(12669)] = 574618,
  [SMALL_STATE(12670)] = 574655,
  [SMALL_STATE(12671)] = 574688,
  [SMALL_STATE(12672)] = 574725,
  [SMALL_STATE(12673)] = 574762,
  [SMALL_STATE(12674)] = 574789,
  [SMALL_STATE(12675)] = 574826,
  [SMALL_STATE(12676)] = 574859,
  [SMALL_STATE(12677)] = 574896,
  [SMALL_STATE(12678)] = 574933,
  [SMALL_STATE(12679)] = 574960,
  [SMALL_STATE(12680)] = 574997,
  [SMALL_STATE(12681)] = 575022,
  [SMALL_STATE(12682)] = 575047,
  [SMALL_STATE(12683)] = 575084,
  [SMALL_STATE(12684)] = 575121,
  [SMALL_STATE(12685)] = 575148,
  [SMALL_STATE(12686)] = 575173,
  [SMALL_STATE(12687)] = 575200,
  [SMALL_STATE(12688)] = 575227,
  [SMALL_STATE(12689)] = 575264,
  [SMALL_STATE(12690)] = 575301,
  [SMALL_STATE(12691)] = 575338,
  [SMALL_STATE(12692)] = 575375,
  [SMALL_STATE(12693)] = 575400,
  [SMALL_STATE(12694)] = 575425,
  [SMALL_STATE(12695)] = 575462,
  [SMALL_STATE(12696)] = 575499,
  [SMALL_STATE(12697)] = 575536,
  [SMALL_STATE(12698)] = 575573,
  [SMALL_STATE(12699)] = 575610,
  [SMALL_STATE(12700)] = 575647,
  [SMALL_STATE(12701)] = 575672,
  [SMALL_STATE(12702)] = 575697,
  [SMALL_STATE(12703)] = 575734,
  [SMALL_STATE(12704)] = 575759,
  [SMALL_STATE(12705)] = 575784,
  [SMALL_STATE(12706)] = 575821,
  [SMALL_STATE(12707)] = 575858,
  [SMALL_STATE(12708)] = 575895,
  [SMALL_STATE(12709)] = 575932,
  [SMALL_STATE(12710)] = 575957,
  [SMALL_STATE(12711)] = 575994,
  [SMALL_STATE(12712)] = 576019,
  [SMALL_STATE(12713)] = 576056,
  [SMALL_STATE(12714)] = 576081,
  [SMALL_STATE(12715)] = 576118,
  [SMALL_STATE(12716)] = 576155,
  [SMALL_STATE(12717)] = 576196,
  [SMALL_STATE(12718)] = 576221,
  [SMALL_STATE(12719)] = 576258,
  [SMALL_STATE(12720)] = 576285,
  [SMALL_STATE(12721)] = 576322,
  [SMALL_STATE(12722)] = 576347,
  [SMALL_STATE(12723)] = 576384,
  [SMALL_STATE(12724)] = 576421,
  [SMALL_STATE(12725)] = 576458,
  [SMALL_STATE(12726)] = 576495,
  [SMALL_STATE(12727)] = 576520,
  [SMALL_STATE(12728)] = 576545,
  [SMALL_STATE(12729)] = 576582,
  [SMALL_STATE(12730)] = 576619,
  [SMALL_STATE(12731)] = 576644,
  [SMALL_STATE(12732)] = 576669,
  [SMALL_STATE(12733)] = 576706,
  [SMALL_STATE(12734)] = 576743,
  [SMALL_STATE(12735)] = 576768,
  [SMALL_STATE(12736)] = 576793,
  [SMALL_STATE(12737)] = 576830,
  [SMALL_STATE(12738)] = 576867,
  [SMALL_STATE(12739)] = 576904,
  [SMALL_STATE(12740)] = 576941,
  [SMALL_STATE(12741)] = 576978,
  [SMALL_STATE(12742)] = 577015,
  [SMALL_STATE(12743)] = 577044,
  [SMALL_STATE(12744)] = 577077,
  [SMALL_STATE(12745)] = 577114,
  [SMALL_STATE(12746)] = 577153,
  [SMALL_STATE(12747)] = 577190,
  [SMALL_STATE(12748)] = 577227,
  [SMALL_STATE(12749)] = 577258,
  [SMALL_STATE(12750)] = 577295,
  [SMALL_STATE(12751)] = 577332,
  [SMALL_STATE(12752)] = 577369,
  [SMALL_STATE(12753)] = 577402,
  [SMALL_STATE(12754)] = 577439,
  [SMALL_STATE(12755)] = 577472,
  [SMALL_STATE(12756)] = 577497,
  [SMALL_STATE(12757)] = 577534,
  [SMALL_STATE(12758)] = 577563,
  [SMALL_STATE(12759)] = 577604,
  [SMALL_STATE(12760)] = 577641,
  [SMALL_STATE(12761)] = 577678,
  [SMALL_STATE(12762)] = 577715,
  [SMALL_STATE(12763)] = 577740,
  [SMALL_STATE(12764)] = 577771,
  [SMALL_STATE(12765)] = 577796,
  [SMALL_STATE(12766)] = 577821,
  [SMALL_STATE(12767)] = 577858,
  [SMALL_STATE(12768)] = 577883,
  [SMALL_STATE(12769)] = 577908,
  [SMALL_STATE(12770)] = 577937,
  [SMALL_STATE(12771)] = 577974,
  [SMALL_STATE(12772)] = 578011,
  [SMALL_STATE(12773)] = 578048,
  [SMALL_STATE(12774)] = 578073,
  [SMALL_STATE(12775)] = 578098,
  [SMALL_STATE(12776)] = 578129,
  [SMALL_STATE(12777)] = 578154,
  [SMALL_STATE(12778)] = 578181,
  [SMALL_STATE(12779)] = 578218,
  [SMALL_STATE(12780)] = 578255,
  [SMALL_STATE(12781)] = 578282,
  [SMALL_STATE(12782)] = 578319,
  [SMALL_STATE(12783)] = 578356,
  [SMALL_STATE(12784)] = 578393,
  [SMALL_STATE(12785)] = 578430,
  [SMALL_STATE(12786)] = 578467,
  [SMALL_STATE(12787)] = 578504,
  [SMALL_STATE(12788)] = 578529,
  [SMALL_STATE(12789)] = 578554,
  [SMALL_STATE(12790)] = 578579,
  [SMALL_STATE(12791)] = 578616,
  [SMALL_STATE(12792)] = 578653,
  [SMALL_STATE(12793)] = 578690,
  [SMALL_STATE(12794)] = 578727,
  [SMALL_STATE(12795)] = 578756,
  [SMALL_STATE(12796)] = 578781,
  [SMALL_STATE(12797)] = 578818,
  [SMALL_STATE(12798)] = 578855,
  [SMALL_STATE(12799)] = 578880,
  [SMALL_STATE(12800)] = 578917,
  [SMALL_STATE(12801)] = 578942,
  [SMALL_STATE(12802)] = 578979,
  [SMALL_STATE(12803)] = 579016,
  [SMALL_STATE(12804)] = 579053,
  [SMALL_STATE(12805)] = 579090,
  [SMALL_STATE(12806)] = 579127,
  [SMALL_STATE(12807)] = 579164,
  [SMALL_STATE(12808)] = 579189,
  [SMALL_STATE(12809)] = 579230,
  [SMALL_STATE(12810)] = 579267,
  [SMALL_STATE(12811)] = 579292,
  [SMALL_STATE(12812)] = 579317,
  [SMALL_STATE(12813)] = 579342,
  [SMALL_STATE(12814)] = 579379,
  [SMALL_STATE(12815)] = 579416,
  [SMALL_STATE(12816)] = 579453,
  [SMALL_STATE(12817)] = 579490,
  [SMALL_STATE(12818)] = 579515,
  [SMALL_STATE(12819)] = 579552,
  [SMALL_STATE(12820)] = 579577,
  [SMALL_STATE(12821)] = 579602,
  [SMALL_STATE(12822)] = 579639,
  [SMALL_STATE(12823)] = 579664,
  [SMALL_STATE(12824)] = 579693,
  [SMALL_STATE(12825)] = 579718,
  [SMALL_STATE(12826)] = 579747,
  [SMALL_STATE(12827)] = 579772,
  [SMALL_STATE(12828)] = 579809,
  [SMALL_STATE(12829)] = 579834,
  [SMALL_STATE(12830)] = 579865,
  [SMALL_STATE(12831)] = 579902,
  [SMALL_STATE(12832)] = 579939,
  [SMALL_STATE(12833)] = 579964,
  [SMALL_STATE(12834)] = 579989,
  [SMALL_STATE(12835)] = 580026,
  [SMALL_STATE(12836)] = 580063,
  [SMALL_STATE(12837)] = 580100,
  [SMALL_STATE(12838)] = 580127,
  [SMALL_STATE(12839)] = 580164,
  [SMALL_STATE(12840)] = 580189,
  [SMALL_STATE(12841)] = 580226,
  [SMALL_STATE(12842)] = 580263,
  [SMALL_STATE(12843)] = 580292,
  [SMALL_STATE(12844)] = 580329,
  [SMALL_STATE(12845)] = 580366,
  [SMALL_STATE(12846)] = 580403,
  [SMALL_STATE(12847)] = 580440,
  [SMALL_STATE(12848)] = 580477,
  [SMALL_STATE(12849)] = 580514,
  [SMALL_STATE(12850)] = 580541,
  [SMALL_STATE(12851)] = 580570,
  [SMALL_STATE(12852)] = 580607,
  [SMALL_STATE(12853)] = 580644,
  [SMALL_STATE(12854)] = 580681,
  [SMALL_STATE(12855)] = 580718,
  [SMALL_STATE(12856)] = 580755,
  [SMALL_STATE(12857)] = 580780,
  [SMALL_STATE(12858)] = 580805,
  [SMALL_STATE(12859)] = 580842,
  [SMALL_STATE(12860)] = 580879,
  [SMALL_STATE(12861)] = 580912,
  [SMALL_STATE(12862)] = 580937,
  [SMALL_STATE(12863)] = 580974,
  [SMALL_STATE(12864)] = 581011,
  [SMALL_STATE(12865)] = 581048,
  [SMALL_STATE(12866)] = 581085,
  [SMALL_STATE(12867)] = 581122,
  [SMALL_STATE(12868)] = 581159,
  [SMALL_STATE(12869)] = 581196,
  [SMALL_STATE(12870)] = 581233,
  [SMALL_STATE(12871)] = 581270,
  [SMALL_STATE(12872)] = 581307,
  [SMALL_STATE(12873)] = 581344,
  [SMALL_STATE(12874)] = 581381,
  [SMALL_STATE(12875)] = 581418,
  [SMALL_STATE(12876)] = 581443,
  [SMALL_STATE(12877)] = 581468,
  [SMALL_STATE(12878)] = 581493,
  [SMALL_STATE(12879)] = 581530,
  [SMALL_STATE(12880)] = 581557,
  [SMALL_STATE(12881)] = 581594,
  [SMALL_STATE(12882)] = 581631,
  [SMALL_STATE(12883)] = 581668,
  [SMALL_STATE(12884)] = 581695,
  [SMALL_STATE(12885)] = 581732,
  [SMALL_STATE(12886)] = 581769,
  [SMALL_STATE(12887)] = 581796,
  [SMALL_STATE(12888)] = 581825,
  [SMALL_STATE(12889)] = 581862,
  [SMALL_STATE(12890)] = 581887,
  [SMALL_STATE(12891)] = 581912,
  [SMALL_STATE(12892)] = 581949,
  [SMALL_STATE(12893)] = 581974,
  [SMALL_STATE(12894)] = 582011,
  [SMALL_STATE(12895)] = 582048,
  [SMALL_STATE(12896)] = 582073,
  [SMALL_STATE(12897)] = 582098,
  [SMALL_STATE(12898)] = 582135,
  [SMALL_STATE(12899)] = 582172,
  [SMALL_STATE(12900)] = 582209,
  [SMALL_STATE(12901)] = 582246,
  [SMALL_STATE(12902)] = 582283,
  [SMALL_STATE(12903)] = 582320,
  [SMALL_STATE(12904)] = 582357,
  [SMALL_STATE(12905)] = 582394,
  [SMALL_STATE(12906)] = 582419,
  [SMALL_STATE(12907)] = 582456,
  [SMALL_STATE(12908)] = 582493,
  [SMALL_STATE(12909)] = 582530,
  [SMALL_STATE(12910)] = 582559,
  [SMALL_STATE(12911)] = 582590,
  [SMALL_STATE(12912)] = 582619,
  [SMALL_STATE(12913)] = 582656,
  [SMALL_STATE(12914)] = 582693,
  [SMALL_STATE(12915)] = 582730,
  [SMALL_STATE(12916)] = 582755,
  [SMALL_STATE(12917)] = 582792,
  [SMALL_STATE(12918)] = 582829,
  [SMALL_STATE(12919)] = 582860,
  [SMALL_STATE(12920)] = 582897,
  [SMALL_STATE(12921)] = 582922,
  [SMALL_STATE(12922)] = 582947,
  [SMALL_STATE(12923)] = 582984,
  [SMALL_STATE(12924)] = 583021,
  [SMALL_STATE(12925)] = 583058,
  [SMALL_STATE(12926)] = 583095,
  [SMALL_STATE(12927)] = 583132,
  [SMALL_STATE(12928)] = 583169,
  [SMALL_STATE(12929)] = 583196,
  [SMALL_STATE(12930)] = 583233,
  [SMALL_STATE(12931)] = 583270,
  [SMALL_STATE(12932)] = 583303,
  [SMALL_STATE(12933)] = 583340,
  [SMALL_STATE(12934)] = 583377,
  [SMALL_STATE(12935)] = 583404,
  [SMALL_STATE(12936)] = 583441,
  [SMALL_STATE(12937)] = 583478,
  [SMALL_STATE(12938)] = 583515,
  [SMALL_STATE(12939)] = 583540,
  [SMALL_STATE(12940)] = 583565,
  [SMALL_STATE(12941)] = 583590,
  [SMALL_STATE(12942)] = 583615,
  [SMALL_STATE(12943)] = 583652,
  [SMALL_STATE(12944)] = 583689,
  [SMALL_STATE(12945)] = 583716,
  [SMALL_STATE(12946)] = 583741,
  [SMALL_STATE(12947)] = 583778,
  [SMALL_STATE(12948)] = 583815,
  [SMALL_STATE(12949)] = 583840,
  [SMALL_STATE(12950)] = 583875,
  [SMALL_STATE(12951)] = 583899,
  [SMALL_STATE(12952)] = 583923,
  [SMALL_STATE(12953)] = 583957,
  [SMALL_STATE(12954)] = 583999,
  [SMALL_STATE(12955)] = 584033,
  [SMALL_STATE(12956)] = 584057,
  [SMALL_STATE(12957)] = 584081,
  [SMALL_STATE(12958)] = 584125,
  [SMALL_STATE(12959)] = 584149,
  [SMALL_STATE(12960)] = 584173,
  [SMALL_STATE(12961)] = 584197,
  [SMALL_STATE(12962)] = 584221,
  [SMALL_STATE(12963)] = 584263,
  [SMALL_STATE(12964)] = 584287,
  [SMALL_STATE(12965)] = 584323,
  [SMALL_STATE(12966)] = 584355,
  [SMALL_STATE(12967)] = 584381,
  [SMALL_STATE(12968)] = 584413,
  [SMALL_STATE(12969)] = 584447,
  [SMALL_STATE(12970)] = 584471,
  [SMALL_STATE(12971)] = 584499,
  [SMALL_STATE(12972)] = 584541,
  [SMALL_STATE(12973)] = 584583,
  [SMALL_STATE(12974)] = 584607,
  [SMALL_STATE(12975)] = 584649,
  [SMALL_STATE(12976)] = 584677,
  [SMALL_STATE(12977)] = 584711,
  [SMALL_STATE(12978)] = 584753,
  [SMALL_STATE(12979)] = 584777,
  [SMALL_STATE(12980)] = 584801,
  [SMALL_STATE(12981)] = 584843,
  [SMALL_STATE(12982)] = 584877,
  [SMALL_STATE(12983)] = 584903,
  [SMALL_STATE(12984)] = 584945,
  [SMALL_STATE(12985)] = 584987,
  [SMALL_STATE(12986)] = 585011,
  [SMALL_STATE(12987)] = 585035,
  [SMALL_STATE(12988)] = 585061,
  [SMALL_STATE(12989)] = 585103,
  [SMALL_STATE(12990)] = 585129,
  [SMALL_STATE(12991)] = 585161,
  [SMALL_STATE(12992)] = 585195,
  [SMALL_STATE(12993)] = 585229,
  [SMALL_STATE(12994)] = 585261,
  [SMALL_STATE(12995)] = 585293,
  [SMALL_STATE(12996)] = 585319,
  [SMALL_STATE(12997)] = 585363,
  [SMALL_STATE(12998)] = 585391,
  [SMALL_STATE(12999)] = 585433,
  [SMALL_STATE(13000)] = 585463,
  [SMALL_STATE(13001)] = 585505,
  [SMALL_STATE(13002)] = 585529,
  [SMALL_STATE(13003)] = 585563,
  [SMALL_STATE(13004)] = 585587,
  [SMALL_STATE(13005)] = 585611,
  [SMALL_STATE(13006)] = 585645,
  [SMALL_STATE(13007)] = 585687,
  [SMALL_STATE(13008)] = 585711,
  [SMALL_STATE(13009)] = 585735,
  [SMALL_STATE(13010)] = 585763,
  [SMALL_STATE(13011)] = 585791,
  [SMALL_STATE(13012)] = 585835,
  [SMALL_STATE(13013)] = 585877,
  [SMALL_STATE(13014)] = 585907,
  [SMALL_STATE(13015)] = 585943,
  [SMALL_STATE(13016)] = 585985,
  [SMALL_STATE(13017)] = 586027,
  [SMALL_STATE(13018)] = 586051,
  [SMALL_STATE(13019)] = 586085,
  [SMALL_STATE(13020)] = 586127,
  [SMALL_STATE(13021)] = 586169,
  [SMALL_STATE(13022)] = 586203,
  [SMALL_STATE(13023)] = 586237,
  [SMALL_STATE(13024)] = 586261,
  [SMALL_STATE(13025)] = 586295,
  [SMALL_STATE(13026)] = 586329,
  [SMALL_STATE(13027)] = 586353,
  [SMALL_STATE(13028)] = 586385,
  [SMALL_STATE(13029)] = 586417,
  [SMALL_STATE(13030)] = 586451,
  [SMALL_STATE(13031)] = 586493,
  [SMALL_STATE(13032)] = 586527,
  [SMALL_STATE(13033)] = 586551,
  [SMALL_STATE(13034)] = 586585,
  [SMALL_STATE(13035)] = 586611,
  [SMALL_STATE(13036)] = 586635,
  [SMALL_STATE(13037)] = 586677,
  [SMALL_STATE(13038)] = 586721,
  [SMALL_STATE(13039)] = 586753,
  [SMALL_STATE(13040)] = 586789,
  [SMALL_STATE(13041)] = 586813,
  [SMALL_STATE(13042)] = 586847,
  [SMALL_STATE(13043)] = 586875,
  [SMALL_STATE(13044)] = 586899,
  [SMALL_STATE(13045)] = 586923,
  [SMALL_STATE(13046)] = 586947,
  [SMALL_STATE(13047)] = 586991,
  [SMALL_STATE(13048)] = 587021,
  [SMALL_STATE(13049)] = 587045,
  [SMALL_STATE(13050)] = 587077,
  [SMALL_STATE(13051)] = 587109,
  [SMALL_STATE(13052)] = 587137,
  [SMALL_STATE(13053)] = 587161,
  [SMALL_STATE(13054)] = 587195,
  [SMALL_STATE(13055)] = 587229,
  [SMALL_STATE(13056)] = 587271,
  [SMALL_STATE(13057)] = 587305,
  [SMALL_STATE(13058)] = 587329,
  [SMALL_STATE(13059)] = 587353,
  [SMALL_STATE(13060)] = 587377,
  [SMALL_STATE(13061)] = 587409,
  [SMALL_STATE(13062)] = 587433,
  [SMALL_STATE(13063)] = 587461,
  [SMALL_STATE(13064)] = 587485,
  [SMALL_STATE(13065)] = 587519,
  [SMALL_STATE(13066)] = 587555,
  [SMALL_STATE(13067)] = 587585,
  [SMALL_STATE(13068)] = 587617,
  [SMALL_STATE(13069)] = 587651,
  [SMALL_STATE(13070)] = 587675,
  [SMALL_STATE(13071)] = 587709,
  [SMALL_STATE(13072)] = 587733,
  [SMALL_STATE(13073)] = 587765,
  [SMALL_STATE(13074)] = 587799,
  [SMALL_STATE(13075)] = 587835,
  [SMALL_STATE(13076)] = 587859,
  [SMALL_STATE(13077)] = 587889,
  [SMALL_STATE(13078)] = 587913,
  [SMALL_STATE(13079)] = 587947,
  [SMALL_STATE(13080)] = 587971,
  [SMALL_STATE(13081)] = 588005,
  [SMALL_STATE(13082)] = 588029,
  [SMALL_STATE(13083)] = 588053,
  [SMALL_STATE(13084)] = 588077,
  [SMALL_STATE(13085)] = 588101,
  [SMALL_STATE(13086)] = 588125,
  [SMALL_STATE(13087)] = 588151,
  [SMALL_STATE(13088)] = 588175,
  [SMALL_STATE(13089)] = 588203,
  [SMALL_STATE(13090)] = 588227,
  [SMALL_STATE(13091)] = 588251,
  [SMALL_STATE(13092)] = 588275,
  [SMALL_STATE(13093)] = 588299,
  [SMALL_STATE(13094)] = 588323,
  [SMALL_STATE(13095)] = 588347,
  [SMALL_STATE(13096)] = 588371,
  [SMALL_STATE(13097)] = 588399,
  [SMALL_STATE(13098)] = 588423,
  [SMALL_STATE(13099)] = 588453,
  [SMALL_STATE(13100)] = 588483,
  [SMALL_STATE(13101)] = 588513,
  [SMALL_STATE(13102)] = 588539,
  [SMALL_STATE(13103)] = 588563,
  [SMALL_STATE(13104)] = 588589,
  [SMALL_STATE(13105)] = 588613,
  [SMALL_STATE(13106)] = 588637,
  [SMALL_STATE(13107)] = 588679,
  [SMALL_STATE(13108)] = 588705,
  [SMALL_STATE(13109)] = 588737,
  [SMALL_STATE(13110)] = 588767,
  [SMALL_STATE(13111)] = 588791,
  [SMALL_STATE(13112)] = 588825,
  [SMALL_STATE(13113)] = 588859,
  [SMALL_STATE(13114)] = 588887,
  [SMALL_STATE(13115)] = 588915,
  [SMALL_STATE(13116)] = 588949,
  [SMALL_STATE(13117)] = 588973,
  [SMALL_STATE(13118)] = 588997,
  [SMALL_STATE(13119)] = 589023,
  [SMALL_STATE(13120)] = 589057,
  [SMALL_STATE(13121)] = 589083,
  [SMALL_STATE(13122)] = 589107,
  [SMALL_STATE(13123)] = 589149,
  [SMALL_STATE(13124)] = 589175,
  [SMALL_STATE(13125)] = 589199,
  [SMALL_STATE(13126)] = 589223,
  [SMALL_STATE(13127)] = 589247,
  [SMALL_STATE(13128)] = 589273,
  [SMALL_STATE(13129)] = 589297,
  [SMALL_STATE(13130)] = 589321,
  [SMALL_STATE(13131)] = 589363,
  [SMALL_STATE(13132)] = 589387,
  [SMALL_STATE(13133)] = 589411,
  [SMALL_STATE(13134)] = 589435,
  [SMALL_STATE(13135)] = 589471,
  [SMALL_STATE(13136)] = 589495,
  [SMALL_STATE(13137)] = 589519,
  [SMALL_STATE(13138)] = 589553,
  [SMALL_STATE(13139)] = 589577,
  [SMALL_STATE(13140)] = 589601,
  [SMALL_STATE(13141)] = 589625,
  [SMALL_STATE(13142)] = 589667,
  [SMALL_STATE(13143)] = 589709,
  [SMALL_STATE(13144)] = 589733,
  [SMALL_STATE(13145)] = 589767,
  [SMALL_STATE(13146)] = 589801,
  [SMALL_STATE(13147)] = 589831,
  [SMALL_STATE(13148)] = 589855,
  [SMALL_STATE(13149)] = 589879,
  [SMALL_STATE(13150)] = 589903,
  [SMALL_STATE(13151)] = 589927,
  [SMALL_STATE(13152)] = 589951,
  [SMALL_STATE(13153)] = 589975,
  [SMALL_STATE(13154)] = 590009,
  [SMALL_STATE(13155)] = 590033,
  [SMALL_STATE(13156)] = 590057,
  [SMALL_STATE(13157)] = 590081,
  [SMALL_STATE(13158)] = 590113,
  [SMALL_STATE(13159)] = 590137,
  [SMALL_STATE(13160)] = 590171,
  [SMALL_STATE(13161)] = 590195,
  [SMALL_STATE(13162)] = 590219,
  [SMALL_STATE(13163)] = 590243,
  [SMALL_STATE(13164)] = 590267,
  [SMALL_STATE(13165)] = 590291,
  [SMALL_STATE(13166)] = 590325,
  [SMALL_STATE(13167)] = 590359,
  [SMALL_STATE(13168)] = 590389,
  [SMALL_STATE(13169)] = 590413,
  [SMALL_STATE(13170)] = 590437,
  [SMALL_STATE(13171)] = 590461,
  [SMALL_STATE(13172)] = 590485,
  [SMALL_STATE(13173)] = 590513,
  [SMALL_STATE(13174)] = 590537,
  [SMALL_STATE(13175)] = 590561,
  [SMALL_STATE(13176)] = 590585,
  [SMALL_STATE(13177)] = 590619,
  [SMALL_STATE(13178)] = 590643,
  [SMALL_STATE(13179)] = 590667,
  [SMALL_STATE(13180)] = 590691,
  [SMALL_STATE(13181)] = 590715,
  [SMALL_STATE(13182)] = 590743,
  [SMALL_STATE(13183)] = 590775,
  [SMALL_STATE(13184)] = 590803,
  [SMALL_STATE(13185)] = 590845,
  [SMALL_STATE(13186)] = 590869,
  [SMALL_STATE(13187)] = 590893,
  [SMALL_STATE(13188)] = 590917,
  [SMALL_STATE(13189)] = 590951,
  [SMALL_STATE(13190)] = 590975,
  [SMALL_STATE(13191)] = 591003,
  [SMALL_STATE(13192)] = 591027,
  [SMALL_STATE(13193)] = 591057,
  [SMALL_STATE(13194)] = 591091,
  [SMALL_STATE(13195)] = 591123,
  [SMALL_STATE(13196)] = 591157,
  [SMALL_STATE(13197)] = 591199,
  [SMALL_STATE(13198)] = 591233,
  [SMALL_STATE(13199)] = 591267,
  [SMALL_STATE(13200)] = 591309,
  [SMALL_STATE(13201)] = 591339,
  [SMALL_STATE(13202)] = 591373,
  [SMALL_STATE(13203)] = 591407,
  [SMALL_STATE(13204)] = 591441,
  [SMALL_STATE(13205)] = 591475,
  [SMALL_STATE(13206)] = 591499,
  [SMALL_STATE(13207)] = 591527,
  [SMALL_STATE(13208)] = 591571,
  [SMALL_STATE(13209)] = 591605,
  [SMALL_STATE(13210)] = 591639,
  [SMALL_STATE(13211)] = 591663,
  [SMALL_STATE(13212)] = 591687,
  [SMALL_STATE(13213)] = 591711,
  [SMALL_STATE(13214)] = 591745,
  [SMALL_STATE(13215)] = 591769,
  [SMALL_STATE(13216)] = 591803,
  [SMALL_STATE(13217)] = 591827,
  [SMALL_STATE(13218)] = 591861,
  [SMALL_STATE(13219)] = 591893,
  [SMALL_STATE(13220)] = 591927,
  [SMALL_STATE(13221)] = 591961,
  [SMALL_STATE(13222)] = 591987,
  [SMALL_STATE(13223)] = 592015,
  [SMALL_STATE(13224)] = 592049,
  [SMALL_STATE(13225)] = 592081,
  [SMALL_STATE(13226)] = 592109,
  [SMALL_STATE(13227)] = 592135,
  [SMALL_STATE(13228)] = 592179,
  [SMALL_STATE(13229)] = 592203,
  [SMALL_STATE(13230)] = 592237,
  [SMALL_STATE(13231)] = 592261,
  [SMALL_STATE(13232)] = 592303,
  [SMALL_STATE(13233)] = 592327,
  [SMALL_STATE(13234)] = 592361,
  [SMALL_STATE(13235)] = 592405,
  [SMALL_STATE(13236)] = 592429,
  [SMALL_STATE(13237)] = 592463,
  [SMALL_STATE(13238)] = 592493,
  [SMALL_STATE(13239)] = 592517,
  [SMALL_STATE(13240)] = 592545,
  [SMALL_STATE(13241)] = 592579,
  [SMALL_STATE(13242)] = 592613,
  [SMALL_STATE(13243)] = 592647,
  [SMALL_STATE(13244)] = 592683,
  [SMALL_STATE(13245)] = 592715,
  [SMALL_STATE(13246)] = 592739,
  [SMALL_STATE(13247)] = 592765,
  [SMALL_STATE(13248)] = 592789,
  [SMALL_STATE(13249)] = 592813,
  [SMALL_STATE(13250)] = 592837,
  [SMALL_STATE(13251)] = 592861,
  [SMALL_STATE(13252)] = 592895,
  [SMALL_STATE(13253)] = 592919,
  [SMALL_STATE(13254)] = 592943,
  [SMALL_STATE(13255)] = 592967,
  [SMALL_STATE(13256)] = 592991,
  [SMALL_STATE(13257)] = 593025,
  [SMALL_STATE(13258)] = 593049,
  [SMALL_STATE(13259)] = 593073,
  [SMALL_STATE(13260)] = 593107,
  [SMALL_STATE(13261)] = 593141,
  [SMALL_STATE(13262)] = 593175,
  [SMALL_STATE(13263)] = 593199,
  [SMALL_STATE(13264)] = 593227,
  [SMALL_STATE(13265)] = 593251,
  [SMALL_STATE(13266)] = 593285,
  [SMALL_STATE(13267)] = 593309,
  [SMALL_STATE(13268)] = 593333,
  [SMALL_STATE(13269)] = 593357,
  [SMALL_STATE(13270)] = 593385,
  [SMALL_STATE(13271)] = 593409,
  [SMALL_STATE(13272)] = 593443,
  [SMALL_STATE(13273)] = 593467,
  [SMALL_STATE(13274)] = 593499,
  [SMALL_STATE(13275)] = 593533,
  [SMALL_STATE(13276)] = 593557,
  [SMALL_STATE(13277)] = 593581,
  [SMALL_STATE(13278)] = 593605,
  [SMALL_STATE(13279)] = 593639,
  [SMALL_STATE(13280)] = 593663,
  [SMALL_STATE(13281)] = 593697,
  [SMALL_STATE(13282)] = 593731,
  [SMALL_STATE(13283)] = 593755,
  [SMALL_STATE(13284)] = 593789,
  [SMALL_STATE(13285)] = 593821,
  [SMALL_STATE(13286)] = 593853,
  [SMALL_STATE(13287)] = 593885,
  [SMALL_STATE(13288)] = 593915,
  [SMALL_STATE(13289)] = 593939,
  [SMALL_STATE(13290)] = 593965,
  [SMALL_STATE(13291)] = 593989,
  [SMALL_STATE(13292)] = 594019,
  [SMALL_STATE(13293)] = 594053,
  [SMALL_STATE(13294)] = 594083,
  [SMALL_STATE(13295)] = 594107,
  [SMALL_STATE(13296)] = 594131,
  [SMALL_STATE(13297)] = 594165,
  [SMALL_STATE(13298)] = 594189,
  [SMALL_STATE(13299)] = 594213,
  [SMALL_STATE(13300)] = 594237,
  [SMALL_STATE(13301)] = 594261,
  [SMALL_STATE(13302)] = 594285,
  [SMALL_STATE(13303)] = 594309,
  [SMALL_STATE(13304)] = 594333,
  [SMALL_STATE(13305)] = 594357,
  [SMALL_STATE(13306)] = 594391,
  [SMALL_STATE(13307)] = 594415,
  [SMALL_STATE(13308)] = 594439,
  [SMALL_STATE(13309)] = 594483,
  [SMALL_STATE(13310)] = 594507,
  [SMALL_STATE(13311)] = 594531,
  [SMALL_STATE(13312)] = 594565,
  [SMALL_STATE(13313)] = 594589,
  [SMALL_STATE(13314)] = 594613,
  [SMALL_STATE(13315)] = 594637,
  [SMALL_STATE(13316)] = 594661,
  [SMALL_STATE(13317)] = 594685,
  [SMALL_STATE(13318)] = 594719,
  [SMALL_STATE(13319)] = 594743,
  [SMALL_STATE(13320)] = 594769,
  [SMALL_STATE(13321)] = 594803,
  [SMALL_STATE(13322)] = 594829,
  [SMALL_STATE(13323)] = 594853,
  [SMALL_STATE(13324)] = 594879,
  [SMALL_STATE(13325)] = 594903,
  [SMALL_STATE(13326)] = 594927,
  [SMALL_STATE(13327)] = 594961,
  [SMALL_STATE(13328)] = 594985,
  [SMALL_STATE(13329)] = 595009,
  [SMALL_STATE(13330)] = 595043,
  [SMALL_STATE(13331)] = 595077,
  [SMALL_STATE(13332)] = 595111,
  [SMALL_STATE(13333)] = 595145,
  [SMALL_STATE(13334)] = 595173,
  [SMALL_STATE(13335)] = 595207,
  [SMALL_STATE(13336)] = 595237,
  [SMALL_STATE(13337)] = 595261,
  [SMALL_STATE(13338)] = 595289,
  [SMALL_STATE(13339)] = 595313,
  [SMALL_STATE(13340)] = 595341,
  [SMALL_STATE(13341)] = 595365,
  [SMALL_STATE(13342)] = 595389,
  [SMALL_STATE(13343)] = 595417,
  [SMALL_STATE(13344)] = 595451,
  [SMALL_STATE(13345)] = 595475,
  [SMALL_STATE(13346)] = 595509,
  [SMALL_STATE(13347)] = 595537,
  [SMALL_STATE(13348)] = 595581,
  [SMALL_STATE(13349)] = 595615,
  [SMALL_STATE(13350)] = 595649,
  [SMALL_STATE(13351)] = 595677,
  [SMALL_STATE(13352)] = 595701,
  [SMALL_STATE(13353)] = 595735,
  [SMALL_STATE(13354)] = 595761,
  [SMALL_STATE(13355)] = 595787,
  [SMALL_STATE(13356)] = 595811,
  [SMALL_STATE(13357)] = 595835,
  [SMALL_STATE(13358)] = 595869,
  [SMALL_STATE(13359)] = 595903,
  [SMALL_STATE(13360)] = 595937,
  [SMALL_STATE(13361)] = 595961,
  [SMALL_STATE(13362)] = 595995,
  [SMALL_STATE(13363)] = 596019,
  [SMALL_STATE(13364)] = 596043,
  [SMALL_STATE(13365)] = 596067,
  [SMALL_STATE(13366)] = 596101,
  [SMALL_STATE(13367)] = 596135,
  [SMALL_STATE(13368)] = 596159,
  [SMALL_STATE(13369)] = 596183,
  [SMALL_STATE(13370)] = 596207,
  [SMALL_STATE(13371)] = 596235,
  [SMALL_STATE(13372)] = 596259,
  [SMALL_STATE(13373)] = 596291,
  [SMALL_STATE(13374)] = 596323,
  [SMALL_STATE(13375)] = 596347,
  [SMALL_STATE(13376)] = 596379,
  [SMALL_STATE(13377)] = 596411,
  [SMALL_STATE(13378)] = 596435,
  [SMALL_STATE(13379)] = 596459,
  [SMALL_STATE(13380)] = 596483,
  [SMALL_STATE(13381)] = 596507,
  [SMALL_STATE(13382)] = 596531,
  [SMALL_STATE(13383)] = 596555,
  [SMALL_STATE(13384)] = 596589,
  [SMALL_STATE(13385)] = 596623,
  [SMALL_STATE(13386)] = 596647,
  [SMALL_STATE(13387)] = 596671,
  [SMALL_STATE(13388)] = 596695,
  [SMALL_STATE(13389)] = 596719,
  [SMALL_STATE(13390)] = 596753,
  [SMALL_STATE(13391)] = 596777,
  [SMALL_STATE(13392)] = 596801,
  [SMALL_STATE(13393)] = 596825,
  [SMALL_STATE(13394)] = 596859,
  [SMALL_STATE(13395)] = 596883,
  [SMALL_STATE(13396)] = 596915,
  [SMALL_STATE(13397)] = 596947,
  [SMALL_STATE(13398)] = 596971,
  [SMALL_STATE(13399)] = 596995,
  [SMALL_STATE(13400)] = 597019,
  [SMALL_STATE(13401)] = 597043,
  [SMALL_STATE(13402)] = 597067,
  [SMALL_STATE(13403)] = 597091,
  [SMALL_STATE(13404)] = 597119,
  [SMALL_STATE(13405)] = 597153,
  [SMALL_STATE(13406)] = 597177,
  [SMALL_STATE(13407)] = 597200,
  [SMALL_STATE(13408)] = 597229,
  [SMALL_STATE(13409)] = 597252,
  [SMALL_STATE(13410)] = 597277,
  [SMALL_STATE(13411)] = 597300,
  [SMALL_STATE(13412)] = 597327,
  [SMALL_STATE(13413)] = 597350,
  [SMALL_STATE(13414)] = 597379,
  [SMALL_STATE(13415)] = 597402,
  [SMALL_STATE(13416)] = 597425,
  [SMALL_STATE(13417)] = 597448,
  [SMALL_STATE(13418)] = 597471,
  [SMALL_STATE(13419)] = 597494,
  [SMALL_STATE(13420)] = 597517,
  [SMALL_STATE(13421)] = 597540,
  [SMALL_STATE(13422)] = 597567,
  [SMALL_STATE(13423)] = 597590,
  [SMALL_STATE(13424)] = 597613,
  [SMALL_STATE(13425)] = 597636,
  [SMALL_STATE(13426)] = 597659,
  [SMALL_STATE(13427)] = 597682,
  [SMALL_STATE(13428)] = 597705,
  [SMALL_STATE(13429)] = 597728,
  [SMALL_STATE(13430)] = 597757,
  [SMALL_STATE(13431)] = 597780,
  [SMALL_STATE(13432)] = 597803,
  [SMALL_STATE(13433)] = 597828,
  [SMALL_STATE(13434)] = 597855,
  [SMALL_STATE(13435)] = 597878,
  [SMALL_STATE(13436)] = 597901,
  [SMALL_STATE(13437)] = 597924,
  [SMALL_STATE(13438)] = 597949,
  [SMALL_STATE(13439)] = 597972,
  [SMALL_STATE(13440)] = 597995,
  [SMALL_STATE(13441)] = 598018,
  [SMALL_STATE(13442)] = 598041,
  [SMALL_STATE(13443)] = 598068,
  [SMALL_STATE(13444)] = 598091,
  [SMALL_STATE(13445)] = 598118,
  [SMALL_STATE(13446)] = 598145,
  [SMALL_STATE(13447)] = 598168,
  [SMALL_STATE(13448)] = 598191,
  [SMALL_STATE(13449)] = 598220,
  [SMALL_STATE(13450)] = 598243,
  [SMALL_STATE(13451)] = 598266,
  [SMALL_STATE(13452)] = 598289,
  [SMALL_STATE(13453)] = 598312,
  [SMALL_STATE(13454)] = 598335,
  [SMALL_STATE(13455)] = 598366,
  [SMALL_STATE(13456)] = 598389,
  [SMALL_STATE(13457)] = 598428,
  [SMALL_STATE(13458)] = 598451,
  [SMALL_STATE(13459)] = 598480,
  [SMALL_STATE(13460)] = 598511,
  [SMALL_STATE(13461)] = 598534,
  [SMALL_STATE(13462)] = 598557,
  [SMALL_STATE(13463)] = 598584,
  [SMALL_STATE(13464)] = 598609,
  [SMALL_STATE(13465)] = 598648,
  [SMALL_STATE(13466)] = 598673,
  [SMALL_STATE(13467)] = 598702,
  [SMALL_STATE(13468)] = 598725,
  [SMALL_STATE(13469)] = 598748,
  [SMALL_STATE(13470)] = 598771,
  [SMALL_STATE(13471)] = 598798,
  [SMALL_STATE(13472)] = 598823,
  [SMALL_STATE(13473)] = 598852,
  [SMALL_STATE(13474)] = 598875,
  [SMALL_STATE(13475)] = 598898,
  [SMALL_STATE(13476)] = 598923,
  [SMALL_STATE(13477)] = 598950,
  [SMALL_STATE(13478)] = 598973,
  [SMALL_STATE(13479)] = 598998,
  [SMALL_STATE(13480)] = 599025,
  [SMALL_STATE(13481)] = 599052,
  [SMALL_STATE(13482)] = 599075,
  [SMALL_STATE(13483)] = 599104,
  [SMALL_STATE(13484)] = 599127,
  [SMALL_STATE(13485)] = 599152,
  [SMALL_STATE(13486)] = 599175,
  [SMALL_STATE(13487)] = 599198,
  [SMALL_STATE(13488)] = 599221,
  [SMALL_STATE(13489)] = 599244,
  [SMALL_STATE(13490)] = 599271,
  [SMALL_STATE(13491)] = 599294,
  [SMALL_STATE(13492)] = 599317,
  [SMALL_STATE(13493)] = 599340,
  [SMALL_STATE(13494)] = 599365,
  [SMALL_STATE(13495)] = 599392,
  [SMALL_STATE(13496)] = 599415,
  [SMALL_STATE(13497)] = 599438,
  [SMALL_STATE(13498)] = 599469,
  [SMALL_STATE(13499)] = 599492,
  [SMALL_STATE(13500)] = 599519,
  [SMALL_STATE(13501)] = 599546,
  [SMALL_STATE(13502)] = 599569,
  [SMALL_STATE(13503)] = 599592,
  [SMALL_STATE(13504)] = 599615,
  [SMALL_STATE(13505)] = 599638,
  [SMALL_STATE(13506)] = 599665,
  [SMALL_STATE(13507)] = 599688,
  [SMALL_STATE(13508)] = 599711,
  [SMALL_STATE(13509)] = 599734,
  [SMALL_STATE(13510)] = 599757,
  [SMALL_STATE(13511)] = 599780,
  [SMALL_STATE(13512)] = 599803,
  [SMALL_STATE(13513)] = 599826,
  [SMALL_STATE(13514)] = 599849,
  [SMALL_STATE(13515)] = 599878,
  [SMALL_STATE(13516)] = 599901,
  [SMALL_STATE(13517)] = 599928,
  [SMALL_STATE(13518)] = 599955,
  [SMALL_STATE(13519)] = 599978,
  [SMALL_STATE(13520)] = 600009,
  [SMALL_STATE(13521)] = 600040,
  [SMALL_STATE(13522)] = 600063,
  [SMALL_STATE(13523)] = 600094,
  [SMALL_STATE(13524)] = 600117,
  [SMALL_STATE(13525)] = 600140,
  [SMALL_STATE(13526)] = 600169,
  [SMALL_STATE(13527)] = 600192,
  [SMALL_STATE(13528)] = 600215,
  [SMALL_STATE(13529)] = 600238,
  [SMALL_STATE(13530)] = 600261,
  [SMALL_STATE(13531)] = 600284,
  [SMALL_STATE(13532)] = 600307,
  [SMALL_STATE(13533)] = 600330,
  [SMALL_STATE(13534)] = 600353,
  [SMALL_STATE(13535)] = 600376,
  [SMALL_STATE(13536)] = 600399,
  [SMALL_STATE(13537)] = 600422,
  [SMALL_STATE(13538)] = 600449,
  [SMALL_STATE(13539)] = 600476,
  [SMALL_STATE(13540)] = 600503,
  [SMALL_STATE(13541)] = 600526,
  [SMALL_STATE(13542)] = 600557,
  [SMALL_STATE(13543)] = 600584,
  [SMALL_STATE(13544)] = 600607,
  [SMALL_STATE(13545)] = 600630,
  [SMALL_STATE(13546)] = 600653,
  [SMALL_STATE(13547)] = 600676,
  [SMALL_STATE(13548)] = 600711,
  [SMALL_STATE(13549)] = 600734,
  [SMALL_STATE(13550)] = 600757,
  [SMALL_STATE(13551)] = 600780,
  [SMALL_STATE(13552)] = 600803,
  [SMALL_STATE(13553)] = 600840,
  [SMALL_STATE(13554)] = 600867,
  [SMALL_STATE(13555)] = 600892,
  [SMALL_STATE(13556)] = 600915,
  [SMALL_STATE(13557)] = 600938,
  [SMALL_STATE(13558)] = 600961,
  [SMALL_STATE(13559)] = 600984,
  [SMALL_STATE(13560)] = 601007,
  [SMALL_STATE(13561)] = 601030,
  [SMALL_STATE(13562)] = 601053,
  [SMALL_STATE(13563)] = 601076,
  [SMALL_STATE(13564)] = 601099,
  [SMALL_STATE(13565)] = 601122,
  [SMALL_STATE(13566)] = 601145,
  [SMALL_STATE(13567)] = 601168,
  [SMALL_STATE(13568)] = 601191,
  [SMALL_STATE(13569)] = 601218,
  [SMALL_STATE(13570)] = 601241,
  [SMALL_STATE(13571)] = 601264,
  [SMALL_STATE(13572)] = 601287,
  [SMALL_STATE(13573)] = 601316,
  [SMALL_STATE(13574)] = 601339,
  [SMALL_STATE(13575)] = 601362,
  [SMALL_STATE(13576)] = 601385,
  [SMALL_STATE(13577)] = 601408,
  [SMALL_STATE(13578)] = 601439,
  [SMALL_STATE(13579)] = 601462,
  [SMALL_STATE(13580)] = 601487,
  [SMALL_STATE(13581)] = 601512,
  [SMALL_STATE(13582)] = 601543,
  [SMALL_STATE(13583)] = 601566,
  [SMALL_STATE(13584)] = 601593,
  [SMALL_STATE(13585)] = 601616,
  [SMALL_STATE(13586)] = 601639,
  [SMALL_STATE(13587)] = 601670,
  [SMALL_STATE(13588)] = 601693,
  [SMALL_STATE(13589)] = 601720,
  [SMALL_STATE(13590)] = 601743,
  [SMALL_STATE(13591)] = 601766,
  [SMALL_STATE(13592)] = 601789,
  [SMALL_STATE(13593)] = 601812,
  [SMALL_STATE(13594)] = 601841,
  [SMALL_STATE(13595)] = 601868,
  [SMALL_STATE(13596)] = 601899,
  [SMALL_STATE(13597)] = 601922,
  [SMALL_STATE(13598)] = 601945,
  [SMALL_STATE(13599)] = 601968,
  [SMALL_STATE(13600)] = 601995,
  [SMALL_STATE(13601)] = 602018,
  [SMALL_STATE(13602)] = 602041,
  [SMALL_STATE(13603)] = 602064,
  [SMALL_STATE(13604)] = 602087,
  [SMALL_STATE(13605)] = 602110,
  [SMALL_STATE(13606)] = 602133,
  [SMALL_STATE(13607)] = 602162,
  [SMALL_STATE(13608)] = 602185,
  [SMALL_STATE(13609)] = 602208,
  [SMALL_STATE(13610)] = 602231,
  [SMALL_STATE(13611)] = 602254,
  [SMALL_STATE(13612)] = 602277,
  [SMALL_STATE(13613)] = 602302,
  [SMALL_STATE(13614)] = 602327,
  [SMALL_STATE(13615)] = 602350,
  [SMALL_STATE(13616)] = 602373,
  [SMALL_STATE(13617)] = 602396,
  [SMALL_STATE(13618)] = 602421,
  [SMALL_STATE(13619)] = 602444,
  [SMALL_STATE(13620)] = 602467,
  [SMALL_STATE(13621)] = 602496,
  [SMALL_STATE(13622)] = 602521,
  [SMALL_STATE(13623)] = 602544,
  [SMALL_STATE(13624)] = 602567,
  [SMALL_STATE(13625)] = 602592,
  [SMALL_STATE(13626)] = 602625,
  [SMALL_STATE(13627)] = 602648,
  [SMALL_STATE(13628)] = 602675,
  [SMALL_STATE(13629)] = 602698,
  [SMALL_STATE(13630)] = 602721,
  [SMALL_STATE(13631)] = 602744,
  [SMALL_STATE(13632)] = 602767,
  [SMALL_STATE(13633)] = 602790,
  [SMALL_STATE(13634)] = 602813,
  [SMALL_STATE(13635)] = 602836,
  [SMALL_STATE(13636)] = 602859,
  [SMALL_STATE(13637)] = 602882,
  [SMALL_STATE(13638)] = 602909,
  [SMALL_STATE(13639)] = 602932,
  [SMALL_STATE(13640)] = 602955,
  [SMALL_STATE(13641)] = 602990,
  [SMALL_STATE(13642)] = 603013,
  [SMALL_STATE(13643)] = 603036,
  [SMALL_STATE(13644)] = 603059,
  [SMALL_STATE(13645)] = 603082,
  [SMALL_STATE(13646)] = 603109,
  [SMALL_STATE(13647)] = 603132,
  [SMALL_STATE(13648)] = 603155,
  [SMALL_STATE(13649)] = 603182,
  [SMALL_STATE(13650)] = 603209,
  [SMALL_STATE(13651)] = 603240,
  [SMALL_STATE(13652)] = 603263,
  [SMALL_STATE(13653)] = 603290,
  [SMALL_STATE(13654)] = 603313,
  [SMALL_STATE(13655)] = 603336,
  [SMALL_STATE(13656)] = 603359,
  [SMALL_STATE(13657)] = 603382,
  [SMALL_STATE(13658)] = 603405,
  [SMALL_STATE(13659)] = 603428,
  [SMALL_STATE(13660)] = 603451,
  [SMALL_STATE(13661)] = 603474,
  [SMALL_STATE(13662)] = 603497,
  [SMALL_STATE(13663)] = 603520,
  [SMALL_STATE(13664)] = 603543,
  [SMALL_STATE(13665)] = 603566,
  [SMALL_STATE(13666)] = 603589,
  [SMALL_STATE(13667)] = 603612,
  [SMALL_STATE(13668)] = 603635,
  [SMALL_STATE(13669)] = 603658,
  [SMALL_STATE(13670)] = 603681,
  [SMALL_STATE(13671)] = 603704,
  [SMALL_STATE(13672)] = 603727,
  [SMALL_STATE(13673)] = 603750,
  [SMALL_STATE(13674)] = 603773,
  [SMALL_STATE(13675)] = 603796,
  [SMALL_STATE(13676)] = 603819,
  [SMALL_STATE(13677)] = 603848,
  [SMALL_STATE(13678)] = 603871,
  [SMALL_STATE(13679)] = 603894,
  [SMALL_STATE(13680)] = 603919,
  [SMALL_STATE(13681)] = 603942,
  [SMALL_STATE(13682)] = 603965,
  [SMALL_STATE(13683)] = 603988,
  [SMALL_STATE(13684)] = 604011,
  [SMALL_STATE(13685)] = 604034,
  [SMALL_STATE(13686)] = 604057,
  [SMALL_STATE(13687)] = 604084,
  [SMALL_STATE(13688)] = 604107,
  [SMALL_STATE(13689)] = 604130,
  [SMALL_STATE(13690)] = 604153,
  [SMALL_STATE(13691)] = 604176,
  [SMALL_STATE(13692)] = 604199,
  [SMALL_STATE(13693)] = 604222,
  [SMALL_STATE(13694)] = 604245,
  [SMALL_STATE(13695)] = 604272,
  [SMALL_STATE(13696)] = 604295,
  [SMALL_STATE(13697)] = 604320,
  [SMALL_STATE(13698)] = 604343,
  [SMALL_STATE(13699)] = 604370,
  [SMALL_STATE(13700)] = 604393,
  [SMALL_STATE(13701)] = 604428,
  [SMALL_STATE(13702)] = 604451,
  [SMALL_STATE(13703)] = 604474,
  [SMALL_STATE(13704)] = 604501,
  [SMALL_STATE(13705)] = 604536,
  [SMALL_STATE(13706)] = 604567,
  [SMALL_STATE(13707)] = 604594,
  [SMALL_STATE(13708)] = 604619,
  [SMALL_STATE(13709)] = 604652,
  [SMALL_STATE(13710)] = 604681,
  [SMALL_STATE(13711)] = 604708,
  [SMALL_STATE(13712)] = 604737,
  [SMALL_STATE(13713)] = 604764,
  [SMALL_STATE(13714)] = 604793,
  [SMALL_STATE(13715)] = 604820,
  [SMALL_STATE(13716)] = 604843,
  [SMALL_STATE(13717)] = 604866,
  [SMALL_STATE(13718)] = 604889,
  [SMALL_STATE(13719)] = 604915,
  [SMALL_STATE(13720)] = 604937,
  [SMALL_STATE(13721)] = 604959,
  [SMALL_STATE(13722)] = 604981,
  [SMALL_STATE(13723)] = 605003,
  [SMALL_STATE(13724)] = 605025,
  [SMALL_STATE(13725)] = 605047,
  [SMALL_STATE(13726)] = 605069,
  [SMALL_STATE(13727)] = 605091,
  [SMALL_STATE(13728)] = 605113,
  [SMALL_STATE(13729)] = 605141,
  [SMALL_STATE(13730)] = 605167,
  [SMALL_STATE(13731)] = 605193,
  [SMALL_STATE(13732)] = 605215,
  [SMALL_STATE(13733)] = 605237,
  [SMALL_STATE(13734)] = 605259,
  [SMALL_STATE(13735)] = 605281,
  [SMALL_STATE(13736)] = 605303,
  [SMALL_STATE(13737)] = 605325,
  [SMALL_STATE(13738)] = 605347,
  [SMALL_STATE(13739)] = 605369,
  [SMALL_STATE(13740)] = 605391,
  [SMALL_STATE(13741)] = 605413,
  [SMALL_STATE(13742)] = 605435,
  [SMALL_STATE(13743)] = 605457,
  [SMALL_STATE(13744)] = 605485,
  [SMALL_STATE(13745)] = 605507,
  [SMALL_STATE(13746)] = 605529,
  [SMALL_STATE(13747)] = 605551,
  [SMALL_STATE(13748)] = 605573,
  [SMALL_STATE(13749)] = 605601,
  [SMALL_STATE(13750)] = 605625,
  [SMALL_STATE(13751)] = 605647,
  [SMALL_STATE(13752)] = 605677,
  [SMALL_STATE(13753)] = 605701,
  [SMALL_STATE(13754)] = 605725,
  [SMALL_STATE(13755)] = 605755,
  [SMALL_STATE(13756)] = 605779,
  [SMALL_STATE(13757)] = 605801,
  [SMALL_STATE(13758)] = 605823,
  [SMALL_STATE(13759)] = 605845,
  [SMALL_STATE(13760)] = 605867,
  [SMALL_STATE(13761)] = 605889,
  [SMALL_STATE(13762)] = 605911,
  [SMALL_STATE(13763)] = 605933,
  [SMALL_STATE(13764)] = 605955,
  [SMALL_STATE(13765)] = 605977,
  [SMALL_STATE(13766)] = 606003,
  [SMALL_STATE(13767)] = 606033,
  [SMALL_STATE(13768)] = 606059,
  [SMALL_STATE(13769)] = 606081,
  [SMALL_STATE(13770)] = 606103,
  [SMALL_STATE(13771)] = 606127,
  [SMALL_STATE(13772)] = 606155,
  [SMALL_STATE(13773)] = 606181,
  [SMALL_STATE(13774)] = 606207,
  [SMALL_STATE(13775)] = 606229,
  [SMALL_STATE(13776)] = 606251,
  [SMALL_STATE(13777)] = 606273,
  [SMALL_STATE(13778)] = 606299,
  [SMALL_STATE(13779)] = 606329,
  [SMALL_STATE(13780)] = 606351,
  [SMALL_STATE(13781)] = 606377,
  [SMALL_STATE(13782)] = 606403,
  [SMALL_STATE(13783)] = 606429,
  [SMALL_STATE(13784)] = 606451,
  [SMALL_STATE(13785)] = 606477,
  [SMALL_STATE(13786)] = 606505,
  [SMALL_STATE(13787)] = 606533,
  [SMALL_STATE(13788)] = 606559,
  [SMALL_STATE(13789)] = 606585,
  [SMALL_STATE(13790)] = 606609,
  [SMALL_STATE(13791)] = 606631,
  [SMALL_STATE(13792)] = 606659,
  [SMALL_STATE(13793)] = 606687,
  [SMALL_STATE(13794)] = 606709,
  [SMALL_STATE(13795)] = 606731,
  [SMALL_STATE(13796)] = 606753,
  [SMALL_STATE(13797)] = 606775,
  [SMALL_STATE(13798)] = 606797,
  [SMALL_STATE(13799)] = 606819,
  [SMALL_STATE(13800)] = 606841,
  [SMALL_STATE(13801)] = 606863,
  [SMALL_STATE(13802)] = 606885,
  [SMALL_STATE(13803)] = 606907,
  [SMALL_STATE(13804)] = 606933,
  [SMALL_STATE(13805)] = 606961,
  [SMALL_STATE(13806)] = 606985,
  [SMALL_STATE(13807)] = 607007,
  [SMALL_STATE(13808)] = 607029,
  [SMALL_STATE(13809)] = 607051,
  [SMALL_STATE(13810)] = 607073,
  [SMALL_STATE(13811)] = 607095,
  [SMALL_STATE(13812)] = 607119,
  [SMALL_STATE(13813)] = 607145,
  [SMALL_STATE(13814)] = 607167,
  [SMALL_STATE(13815)] = 607193,
  [SMALL_STATE(13816)] = 607217,
  [SMALL_STATE(13817)] = 607239,
  [SMALL_STATE(13818)] = 607265,
  [SMALL_STATE(13819)] = 607287,
  [SMALL_STATE(13820)] = 607317,
  [SMALL_STATE(13821)] = 607343,
  [SMALL_STATE(13822)] = 607365,
  [SMALL_STATE(13823)] = 607387,
  [SMALL_STATE(13824)] = 607409,
  [SMALL_STATE(13825)] = 607439,
  [SMALL_STATE(13826)] = 607461,
  [SMALL_STATE(13827)] = 607489,
  [SMALL_STATE(13828)] = 607511,
  [SMALL_STATE(13829)] = 607537,
  [SMALL_STATE(13830)] = 607561,
  [SMALL_STATE(13831)] = 607587,
  [SMALL_STATE(13832)] = 607615,
  [SMALL_STATE(13833)] = 607639,
  [SMALL_STATE(13834)] = 607661,
  [SMALL_STATE(13835)] = 607687,
  [SMALL_STATE(13836)] = 607709,
  [SMALL_STATE(13837)] = 607731,
  [SMALL_STATE(13838)] = 607753,
  [SMALL_STATE(13839)] = 607779,
  [SMALL_STATE(13840)] = 607801,
  [SMALL_STATE(13841)] = 607823,
  [SMALL_STATE(13842)] = 607853,
  [SMALL_STATE(13843)] = 607875,
  [SMALL_STATE(13844)] = 607897,
  [SMALL_STATE(13845)] = 607919,
  [SMALL_STATE(13846)] = 607941,
  [SMALL_STATE(13847)] = 607963,
  [SMALL_STATE(13848)] = 607985,
  [SMALL_STATE(13849)] = 608007,
  [SMALL_STATE(13850)] = 608029,
  [SMALL_STATE(13851)] = 608055,
  [SMALL_STATE(13852)] = 608077,
  [SMALL_STATE(13853)] = 608099,
  [SMALL_STATE(13854)] = 608121,
  [SMALL_STATE(13855)] = 608147,
  [SMALL_STATE(13856)] = 608169,
  [SMALL_STATE(13857)] = 608191,
  [SMALL_STATE(13858)] = 608213,
  [SMALL_STATE(13859)] = 608235,
  [SMALL_STATE(13860)] = 608257,
  [SMALL_STATE(13861)] = 608279,
  [SMALL_STATE(13862)] = 608301,
  [SMALL_STATE(13863)] = 608323,
  [SMALL_STATE(13864)] = 608345,
  [SMALL_STATE(13865)] = 608367,
  [SMALL_STATE(13866)] = 608389,
  [SMALL_STATE(13867)] = 608411,
  [SMALL_STATE(13868)] = 608433,
  [SMALL_STATE(13869)] = 608455,
  [SMALL_STATE(13870)] = 608477,
  [SMALL_STATE(13871)] = 608499,
  [SMALL_STATE(13872)] = 608521,
  [SMALL_STATE(13873)] = 608543,
  [SMALL_STATE(13874)] = 608571,
  [SMALL_STATE(13875)] = 608593,
  [SMALL_STATE(13876)] = 608615,
  [SMALL_STATE(13877)] = 608637,
  [SMALL_STATE(13878)] = 608659,
  [SMALL_STATE(13879)] = 608681,
  [SMALL_STATE(13880)] = 608709,
  [SMALL_STATE(13881)] = 608731,
  [SMALL_STATE(13882)] = 608753,
  [SMALL_STATE(13883)] = 608775,
  [SMALL_STATE(13884)] = 608797,
  [SMALL_STATE(13885)] = 608819,
  [SMALL_STATE(13886)] = 608843,
  [SMALL_STATE(13887)] = 608869,
  [SMALL_STATE(13888)] = 608891,
  [SMALL_STATE(13889)] = 608913,
  [SMALL_STATE(13890)] = 608935,
  [SMALL_STATE(13891)] = 608957,
  [SMALL_STATE(13892)] = 608979,
  [SMALL_STATE(13893)] = 609001,
  [SMALL_STATE(13894)] = 609023,
  [SMALL_STATE(13895)] = 609049,
  [SMALL_STATE(13896)] = 609071,
  [SMALL_STATE(13897)] = 609093,
  [SMALL_STATE(13898)] = 609115,
  [SMALL_STATE(13899)] = 609137,
  [SMALL_STATE(13900)] = 609159,
  [SMALL_STATE(13901)] = 609181,
  [SMALL_STATE(13902)] = 609203,
  [SMALL_STATE(13903)] = 609225,
  [SMALL_STATE(13904)] = 609251,
  [SMALL_STATE(13905)] = 609273,
  [SMALL_STATE(13906)] = 609295,
  [SMALL_STATE(13907)] = 609319,
  [SMALL_STATE(13908)] = 609341,
  [SMALL_STATE(13909)] = 609363,
  [SMALL_STATE(13910)] = 609385,
  [SMALL_STATE(13911)] = 609407,
  [SMALL_STATE(13912)] = 609429,
  [SMALL_STATE(13913)] = 609451,
  [SMALL_STATE(13914)] = 609473,
  [SMALL_STATE(13915)] = 609495,
  [SMALL_STATE(13916)] = 609517,
  [SMALL_STATE(13917)] = 609543,
  [SMALL_STATE(13918)] = 609567,
  [SMALL_STATE(13919)] = 609595,
  [SMALL_STATE(13920)] = 609617,
  [SMALL_STATE(13921)] = 609639,
  [SMALL_STATE(13922)] = 609665,
  [SMALL_STATE(13923)] = 609687,
  [SMALL_STATE(13924)] = 609709,
  [SMALL_STATE(13925)] = 609731,
  [SMALL_STATE(13926)] = 609753,
  [SMALL_STATE(13927)] = 609775,
  [SMALL_STATE(13928)] = 609799,
  [SMALL_STATE(13929)] = 609825,
  [SMALL_STATE(13930)] = 609847,
  [SMALL_STATE(13931)] = 609869,
  [SMALL_STATE(13932)] = 609891,
  [SMALL_STATE(13933)] = 609913,
  [SMALL_STATE(13934)] = 609939,
  [SMALL_STATE(13935)] = 609965,
  [SMALL_STATE(13936)] = 609987,
  [SMALL_STATE(13937)] = 610009,
  [SMALL_STATE(13938)] = 610031,
  [SMALL_STATE(13939)] = 610053,
  [SMALL_STATE(13940)] = 610079,
  [SMALL_STATE(13941)] = 610101,
  [SMALL_STATE(13942)] = 610123,
  [SMALL_STATE(13943)] = 610149,
  [SMALL_STATE(13944)] = 610175,
  [SMALL_STATE(13945)] = 610197,
  [SMALL_STATE(13946)] = 610219,
  [SMALL_STATE(13947)] = 610241,
  [SMALL_STATE(13948)] = 610267,
  [SMALL_STATE(13949)] = 610289,
  [SMALL_STATE(13950)] = 610311,
  [SMALL_STATE(13951)] = 610335,
  [SMALL_STATE(13952)] = 610365,
  [SMALL_STATE(13953)] = 610389,
  [SMALL_STATE(13954)] = 610411,
  [SMALL_STATE(13955)] = 610439,
  [SMALL_STATE(13956)] = 610461,
  [SMALL_STATE(13957)] = 610483,
  [SMALL_STATE(13958)] = 610505,
  [SMALL_STATE(13959)] = 610527,
  [SMALL_STATE(13960)] = 610549,
  [SMALL_STATE(13961)] = 610571,
  [SMALL_STATE(13962)] = 610593,
  [SMALL_STATE(13963)] = 610615,
  [SMALL_STATE(13964)] = 610637,
  [SMALL_STATE(13965)] = 610659,
  [SMALL_STATE(13966)] = 610681,
  [SMALL_STATE(13967)] = 610711,
  [SMALL_STATE(13968)] = 610739,
  [SMALL_STATE(13969)] = 610761,
  [SMALL_STATE(13970)] = 610783,
  [SMALL_STATE(13971)] = 610813,
  [SMALL_STATE(13972)] = 610843,
  [SMALL_STATE(13973)] = 610865,
  [SMALL_STATE(13974)] = 610891,
  [SMALL_STATE(13975)] = 610913,
  [SMALL_STATE(13976)] = 610939,
  [SMALL_STATE(13977)] = 610967,
  [SMALL_STATE(13978)] = 610993,
  [SMALL_STATE(13979)] = 611015,
  [SMALL_STATE(13980)] = 611039,
  [SMALL_STATE(13981)] = 611063,
  [SMALL_STATE(13982)] = 611085,
  [SMALL_STATE(13983)] = 611107,
  [SMALL_STATE(13984)] = 611129,
  [SMALL_STATE(13985)] = 611157,
  [SMALL_STATE(13986)] = 611179,
  [SMALL_STATE(13987)] = 611201,
  [SMALL_STATE(13988)] = 611223,
  [SMALL_STATE(13989)] = 611245,
  [SMALL_STATE(13990)] = 611267,
  [SMALL_STATE(13991)] = 611289,
  [SMALL_STATE(13992)] = 611311,
  [SMALL_STATE(13993)] = 611333,
  [SMALL_STATE(13994)] = 611355,
  [SMALL_STATE(13995)] = 611377,
  [SMALL_STATE(13996)] = 611401,
  [SMALL_STATE(13997)] = 611423,
  [SMALL_STATE(13998)] = 611445,
  [SMALL_STATE(13999)] = 611473,
  [SMALL_STATE(14000)] = 611495,
  [SMALL_STATE(14001)] = 611517,
  [SMALL_STATE(14002)] = 611543,
  [SMALL_STATE(14003)] = 611569,
  [SMALL_STATE(14004)] = 611591,
  [SMALL_STATE(14005)] = 611613,
  [SMALL_STATE(14006)] = 611639,
  [SMALL_STATE(14007)] = 611661,
  [SMALL_STATE(14008)] = 611683,
  [SMALL_STATE(14009)] = 611709,
  [SMALL_STATE(14010)] = 611731,
  [SMALL_STATE(14011)] = 611761,
  [SMALL_STATE(14012)] = 611789,
  [SMALL_STATE(14013)] = 611813,
  [SMALL_STATE(14014)] = 611835,
  [SMALL_STATE(14015)] = 611857,
  [SMALL_STATE(14016)] = 611879,
  [SMALL_STATE(14017)] = 611901,
  [SMALL_STATE(14018)] = 611927,
  [SMALL_STATE(14019)] = 611949,
  [SMALL_STATE(14020)] = 611975,
  [SMALL_STATE(14021)] = 612001,
  [SMALL_STATE(14022)] = 612027,
  [SMALL_STATE(14023)] = 612049,
  [SMALL_STATE(14024)] = 612075,
  [SMALL_STATE(14025)] = 612105,
  [SMALL_STATE(14026)] = 612139,
  [SMALL_STATE(14027)] = 612165,
  [SMALL_STATE(14028)] = 612189,
  [SMALL_STATE(14029)] = 612211,
  [SMALL_STATE(14030)] = 612241,
  [SMALL_STATE(14031)] = 612263,
  [SMALL_STATE(14032)] = 612293,
  [SMALL_STATE(14033)] = 612315,
  [SMALL_STATE(14034)] = 612343,
  [SMALL_STATE(14035)] = 612365,
  [SMALL_STATE(14036)] = 612387,
  [SMALL_STATE(14037)] = 612411,
  [SMALL_STATE(14038)] = 612439,
  [SMALL_STATE(14039)] = 612461,
  [SMALL_STATE(14040)] = 612485,
  [SMALL_STATE(14041)] = 612509,
  [SMALL_STATE(14042)] = 612531,
  [SMALL_STATE(14043)] = 612553,
  [SMALL_STATE(14044)] = 612583,
  [SMALL_STATE(14045)] = 612605,
  [SMALL_STATE(14046)] = 612631,
  [SMALL_STATE(14047)] = 612659,
  [SMALL_STATE(14048)] = 612681,
  [SMALL_STATE(14049)] = 612707,
  [SMALL_STATE(14050)] = 612733,
  [SMALL_STATE(14051)] = 612759,
  [SMALL_STATE(14052)] = 612781,
  [SMALL_STATE(14053)] = 612807,
  [SMALL_STATE(14054)] = 612829,
  [SMALL_STATE(14055)] = 612851,
  [SMALL_STATE(14056)] = 612874,
  [SMALL_STATE(14057)] = 612899,
  [SMALL_STATE(14058)] = 612920,
  [SMALL_STATE(14059)] = 612941,
  [SMALL_STATE(14060)] = 612966,
  [SMALL_STATE(14061)] = 612999,
  [SMALL_STATE(14062)] = 613024,
  [SMALL_STATE(14063)] = 613045,
  [SMALL_STATE(14064)] = 613070,
  [SMALL_STATE(14065)] = 613091,
  [SMALL_STATE(14066)] = 613118,
  [SMALL_STATE(14067)] = 613139,
  [SMALL_STATE(14068)] = 613164,
  [SMALL_STATE(14069)] = 613193,
  [SMALL_STATE(14070)] = 613214,
  [SMALL_STATE(14071)] = 613239,
  [SMALL_STATE(14072)] = 613266,
  [SMALL_STATE(14073)] = 613289,
  [SMALL_STATE(14074)] = 613310,
  [SMALL_STATE(14075)] = 613335,
  [SMALL_STATE(14076)] = 613360,
  [SMALL_STATE(14077)] = 613381,
  [SMALL_STATE(14078)] = 613414,
  [SMALL_STATE(14079)] = 613447,
  [SMALL_STATE(14080)] = 613476,
  [SMALL_STATE(14081)] = 613497,
  [SMALL_STATE(14082)] = 613518,
  [SMALL_STATE(14083)] = 613545,
  [SMALL_STATE(14084)] = 613566,
  [SMALL_STATE(14085)] = 613587,
  [SMALL_STATE(14086)] = 613614,
  [SMALL_STATE(14087)] = 613635,
  [SMALL_STATE(14088)] = 613656,
  [SMALL_STATE(14089)] = 613683,
  [SMALL_STATE(14090)] = 613704,
  [SMALL_STATE(14091)] = 613725,
  [SMALL_STATE(14092)] = 613746,
  [SMALL_STATE(14093)] = 613779,
  [SMALL_STATE(14094)] = 613806,
  [SMALL_STATE(14095)] = 613827,
  [SMALL_STATE(14096)] = 613854,
  [SMALL_STATE(14097)] = 613887,
  [SMALL_STATE(14098)] = 613908,
  [SMALL_STATE(14099)] = 613937,
  [SMALL_STATE(14100)] = 613958,
  [SMALL_STATE(14101)] = 613989,
  [SMALL_STATE(14102)] = 614014,
  [SMALL_STATE(14103)] = 614035,
  [SMALL_STATE(14104)] = 614056,
  [SMALL_STATE(14105)] = 614077,
  [SMALL_STATE(14106)] = 614098,
  [SMALL_STATE(14107)] = 614129,
  [SMALL_STATE(14108)] = 614150,
  [SMALL_STATE(14109)] = 614171,
  [SMALL_STATE(14110)] = 614192,
  [SMALL_STATE(14111)] = 614213,
  [SMALL_STATE(14112)] = 614246,
  [SMALL_STATE(14113)] = 614267,
  [SMALL_STATE(14114)] = 614298,
  [SMALL_STATE(14115)] = 614319,
  [SMALL_STATE(14116)] = 614344,
  [SMALL_STATE(14117)] = 614367,
  [SMALL_STATE(14118)] = 614388,
  [SMALL_STATE(14119)] = 614421,
  [SMALL_STATE(14120)] = 614442,
  [SMALL_STATE(14121)] = 614467,
  [SMALL_STATE(14122)] = 614492,
  [SMALL_STATE(14123)] = 614513,
  [SMALL_STATE(14124)] = 614536,
  [SMALL_STATE(14125)] = 614557,
  [SMALL_STATE(14126)] = 614580,
  [SMALL_STATE(14127)] = 614605,
  [SMALL_STATE(14128)] = 614630,
  [SMALL_STATE(14129)] = 614655,
  [SMALL_STATE(14130)] = 614680,
  [SMALL_STATE(14131)] = 614701,
  [SMALL_STATE(14132)] = 614730,
  [SMALL_STATE(14133)] = 614763,
  [SMALL_STATE(14134)] = 614788,
  [SMALL_STATE(14135)] = 614821,
  [SMALL_STATE(14136)] = 614844,
  [SMALL_STATE(14137)] = 614877,
  [SMALL_STATE(14138)] = 614898,
  [SMALL_STATE(14139)] = 614923,
  [SMALL_STATE(14140)] = 614950,
  [SMALL_STATE(14141)] = 614971,
  [SMALL_STATE(14142)] = 614992,
  [SMALL_STATE(14143)] = 615021,
  [SMALL_STATE(14144)] = 615042,
  [SMALL_STATE(14145)] = 615067,
  [SMALL_STATE(14146)] = 615096,
  [SMALL_STATE(14147)] = 615121,
  [SMALL_STATE(14148)] = 615142,
  [SMALL_STATE(14149)] = 615169,
  [SMALL_STATE(14150)] = 615190,
  [SMALL_STATE(14151)] = 615219,
  [SMALL_STATE(14152)] = 615240,
  [SMALL_STATE(14153)] = 615265,
  [SMALL_STATE(14154)] = 615290,
  [SMALL_STATE(14155)] = 615313,
  [SMALL_STATE(14156)] = 615334,
  [SMALL_STATE(14157)] = 615355,
  [SMALL_STATE(14158)] = 615380,
  [SMALL_STATE(14159)] = 615405,
  [SMALL_STATE(14160)] = 615428,
  [SMALL_STATE(14161)] = 615461,
  [SMALL_STATE(14162)] = 615486,
  [SMALL_STATE(14163)] = 615507,
  [SMALL_STATE(14164)] = 615534,
  [SMALL_STATE(14165)] = 615561,
  [SMALL_STATE(14166)] = 615588,
  [SMALL_STATE(14167)] = 615613,
  [SMALL_STATE(14168)] = 615638,
  [SMALL_STATE(14169)] = 615659,
  [SMALL_STATE(14170)] = 615686,
  [SMALL_STATE(14171)] = 615711,
  [SMALL_STATE(14172)] = 615744,
  [SMALL_STATE(14173)] = 615769,
  [SMALL_STATE(14174)] = 615790,
  [SMALL_STATE(14175)] = 615815,
  [SMALL_STATE(14176)] = 615840,
  [SMALL_STATE(14177)] = 615861,
  [SMALL_STATE(14178)] = 615882,
  [SMALL_STATE(14179)] = 615911,
  [SMALL_STATE(14180)] = 615932,
  [SMALL_STATE(14181)] = 615959,
  [SMALL_STATE(14182)] = 615980,
  [SMALL_STATE(14183)] = 616001,
  [SMALL_STATE(14184)] = 616022,
  [SMALL_STATE(14185)] = 616051,
  [SMALL_STATE(14186)] = 616072,
  [SMALL_STATE(14187)] = 616099,
  [SMALL_STATE(14188)] = 616120,
  [SMALL_STATE(14189)] = 616141,
  [SMALL_STATE(14190)] = 616170,
  [SMALL_STATE(14191)] = 616191,
  [SMALL_STATE(14192)] = 616216,
  [SMALL_STATE(14193)] = 616237,
  [SMALL_STATE(14194)] = 616260,
  [SMALL_STATE(14195)] = 616283,
  [SMALL_STATE(14196)] = 616304,
  [SMALL_STATE(14197)] = 616329,
  [SMALL_STATE(14198)] = 616362,
  [SMALL_STATE(14199)] = 616389,
  [SMALL_STATE(14200)] = 616410,
  [SMALL_STATE(14201)] = 616431,
  [SMALL_STATE(14202)] = 616458,
  [SMALL_STATE(14203)] = 616483,
  [SMALL_STATE(14204)] = 616504,
  [SMALL_STATE(14205)] = 616529,
  [SMALL_STATE(14206)] = 616550,
  [SMALL_STATE(14207)] = 616575,
  [SMALL_STATE(14208)] = 616596,
  [SMALL_STATE(14209)] = 616617,
  [SMALL_STATE(14210)] = 616638,
  [SMALL_STATE(14211)] = 616663,
  [SMALL_STATE(14212)] = 616684,
  [SMALL_STATE(14213)] = 616705,
  [SMALL_STATE(14214)] = 616726,
  [SMALL_STATE(14215)] = 616747,
  [SMALL_STATE(14216)] = 616780,
  [SMALL_STATE(14217)] = 616801,
  [SMALL_STATE(14218)] = 616824,
  [SMALL_STATE(14219)] = 616845,
  [SMALL_STATE(14220)] = 616870,
  [SMALL_STATE(14221)] = 616895,
  [SMALL_STATE(14222)] = 616916,
  [SMALL_STATE(14223)] = 616941,
  [SMALL_STATE(14224)] = 616962,
  [SMALL_STATE(14225)] = 616985,
  [SMALL_STATE(14226)] = 617014,
  [SMALL_STATE(14227)] = 617043,
  [SMALL_STATE(14228)] = 617072,
  [SMALL_STATE(14229)] = 617093,
  [SMALL_STATE(14230)] = 617114,
  [SMALL_STATE(14231)] = 617137,
  [SMALL_STATE(14232)] = 617162,
  [SMALL_STATE(14233)] = 617191,
  [SMALL_STATE(14234)] = 617216,
  [SMALL_STATE(14235)] = 617241,
  [SMALL_STATE(14236)] = 617266,
  [SMALL_STATE(14237)] = 617287,
  [SMALL_STATE(14238)] = 617308,
  [SMALL_STATE(14239)] = 617329,
  [SMALL_STATE(14240)] = 617350,
  [SMALL_STATE(14241)] = 617375,
  [SMALL_STATE(14242)] = 617406,
  [SMALL_STATE(14243)] = 617427,
  [SMALL_STATE(14244)] = 617454,
  [SMALL_STATE(14245)] = 617479,
  [SMALL_STATE(14246)] = 617508,
  [SMALL_STATE(14247)] = 617535,
  [SMALL_STATE(14248)] = 617560,
  [SMALL_STATE(14249)] = 617591,
  [SMALL_STATE(14250)] = 617622,
  [SMALL_STATE(14251)] = 617643,
  [SMALL_STATE(14252)] = 617666,
  [SMALL_STATE(14253)] = 617687,
  [SMALL_STATE(14254)] = 617714,
  [SMALL_STATE(14255)] = 617735,
  [SMALL_STATE(14256)] = 617762,
  [SMALL_STATE(14257)] = 617789,
  [SMALL_STATE(14258)] = 617814,
  [SMALL_STATE(14259)] = 617845,
  [SMALL_STATE(14260)] = 617872,
  [SMALL_STATE(14261)] = 617899,
  [SMALL_STATE(14262)] = 617920,
  [SMALL_STATE(14263)] = 617941,
  [SMALL_STATE(14264)] = 617962,
  [SMALL_STATE(14265)] = 617985,
  [SMALL_STATE(14266)] = 618006,
  [SMALL_STATE(14267)] = 618027,
  [SMALL_STATE(14268)] = 618050,
  [SMALL_STATE(14269)] = 618077,
  [SMALL_STATE(14270)] = 618104,
  [SMALL_STATE(14271)] = 618125,
  [SMALL_STATE(14272)] = 618150,
  [SMALL_STATE(14273)] = 618175,
  [SMALL_STATE(14274)] = 618198,
  [SMALL_STATE(14275)] = 618219,
  [SMALL_STATE(14276)] = 618243,
  [SMALL_STATE(14277)] = 618263,
  [SMALL_STATE(14278)] = 618285,
  [SMALL_STATE(14279)] = 618311,
  [SMALL_STATE(14280)] = 618333,
  [SMALL_STATE(14281)] = 618357,
  [SMALL_STATE(14282)] = 618383,
  [SMALL_STATE(14283)] = 618405,
  [SMALL_STATE(14284)] = 618435,
  [SMALL_STATE(14285)] = 618461,
  [SMALL_STATE(14286)] = 618485,
  [SMALL_STATE(14287)] = 618517,
  [SMALL_STATE(14288)] = 618545,
  [SMALL_STATE(14289)] = 618567,
  [SMALL_STATE(14290)] = 618591,
  [SMALL_STATE(14291)] = 618615,
  [SMALL_STATE(14292)] = 618635,
  [SMALL_STATE(14293)] = 618657,
  [SMALL_STATE(14294)] = 618681,
  [SMALL_STATE(14295)] = 618707,
  [SMALL_STATE(14296)] = 618731,
  [SMALL_STATE(14297)] = 618753,
  [SMALL_STATE(14298)] = 618779,
  [SMALL_STATE(14299)] = 618811,
  [SMALL_STATE(14300)] = 618833,
  [SMALL_STATE(14301)] = 618855,
  [SMALL_STATE(14302)] = 618879,
  [SMALL_STATE(14303)] = 618903,
  [SMALL_STATE(14304)] = 618929,
  [SMALL_STATE(14305)] = 618955,
  [SMALL_STATE(14306)] = 618979,
  [SMALL_STATE(14307)] = 618999,
  [SMALL_STATE(14308)] = 619023,
  [SMALL_STATE(14309)] = 619045,
  [SMALL_STATE(14310)] = 619071,
  [SMALL_STATE(14311)] = 619097,
  [SMALL_STATE(14312)] = 619117,
  [SMALL_STATE(14313)] = 619137,
  [SMALL_STATE(14314)] = 619157,
  [SMALL_STATE(14315)] = 619177,
  [SMALL_STATE(14316)] = 619199,
  [SMALL_STATE(14317)] = 619225,
  [SMALL_STATE(14318)] = 619251,
  [SMALL_STATE(14319)] = 619275,
  [SMALL_STATE(14320)] = 619295,
  [SMALL_STATE(14321)] = 619319,
  [SMALL_STATE(14322)] = 619343,
  [SMALL_STATE(14323)] = 619367,
  [SMALL_STATE(14324)] = 619391,
  [SMALL_STATE(14325)] = 619411,
  [SMALL_STATE(14326)] = 619435,
  [SMALL_STATE(14327)] = 619461,
  [SMALL_STATE(14328)] = 619487,
  [SMALL_STATE(14329)] = 619513,
  [SMALL_STATE(14330)] = 619537,
  [SMALL_STATE(14331)] = 619561,
  [SMALL_STATE(14332)] = 619583,
  [SMALL_STATE(14333)] = 619603,
  [SMALL_STATE(14334)] = 619623,
  [SMALL_STATE(14335)] = 619647,
  [SMALL_STATE(14336)] = 619679,
  [SMALL_STATE(14337)] = 619707,
  [SMALL_STATE(14338)] = 619727,
  [SMALL_STATE(14339)] = 619751,
  [SMALL_STATE(14340)] = 619777,
  [SMALL_STATE(14341)] = 619803,
  [SMALL_STATE(14342)] = 619827,
  [SMALL_STATE(14343)] = 619855,
  [SMALL_STATE(14344)] = 619877,
  [SMALL_STATE(14345)] = 619909,
  [SMALL_STATE(14346)] = 619935,
  [SMALL_STATE(14347)] = 619961,
  [SMALL_STATE(14348)] = 619981,
  [SMALL_STATE(14349)] = 620001,
  [SMALL_STATE(14350)] = 620025,
  [SMALL_STATE(14351)] = 620049,
  [SMALL_STATE(14352)] = 620079,
  [SMALL_STATE(14353)] = 620099,
  [SMALL_STATE(14354)] = 620121,
  [SMALL_STATE(14355)] = 620151,
  [SMALL_STATE(14356)] = 620175,
  [SMALL_STATE(14357)] = 620195,
  [SMALL_STATE(14358)] = 620219,
  [SMALL_STATE(14359)] = 620243,
  [SMALL_STATE(14360)] = 620263,
  [SMALL_STATE(14361)] = 620283,
  [SMALL_STATE(14362)] = 620307,
  [SMALL_STATE(14363)] = 620327,
  [SMALL_STATE(14364)] = 620351,
  [SMALL_STATE(14365)] = 620375,
  [SMALL_STATE(14366)] = 620397,
  [SMALL_STATE(14367)] = 620425,
  [SMALL_STATE(14368)] = 620449,
  [SMALL_STATE(14369)] = 620473,
  [SMALL_STATE(14370)] = 620495,
  [SMALL_STATE(14371)] = 620519,
  [SMALL_STATE(14372)] = 620547,
  [SMALL_STATE(14373)] = 620571,
  [SMALL_STATE(14374)] = 620591,
  [SMALL_STATE(14375)] = 620611,
  [SMALL_STATE(14376)] = 620631,
  [SMALL_STATE(14377)] = 620655,
  [SMALL_STATE(14378)] = 620675,
  [SMALL_STATE(14379)] = 620699,
  [SMALL_STATE(14380)] = 620723,
  [SMALL_STATE(14381)] = 620743,
  [SMALL_STATE(14382)] = 620763,
  [SMALL_STATE(14383)] = 620783,
  [SMALL_STATE(14384)] = 620803,
  [SMALL_STATE(14385)] = 620827,
  [SMALL_STATE(14386)] = 620849,
  [SMALL_STATE(14387)] = 620869,
  [SMALL_STATE(14388)] = 620889,
  [SMALL_STATE(14389)] = 620917,
  [SMALL_STATE(14390)] = 620937,
  [SMALL_STATE(14391)] = 620961,
  [SMALL_STATE(14392)] = 620983,
  [SMALL_STATE(14393)] = 621003,
  [SMALL_STATE(14394)] = 621023,
  [SMALL_STATE(14395)] = 621045,
  [SMALL_STATE(14396)] = 621065,
  [SMALL_STATE(14397)] = 621089,
  [SMALL_STATE(14398)] = 621109,
  [SMALL_STATE(14399)] = 621131,
  [SMALL_STATE(14400)] = 621151,
  [SMALL_STATE(14401)] = 621171,
  [SMALL_STATE(14402)] = 621195,
  [SMALL_STATE(14403)] = 621219,
  [SMALL_STATE(14404)] = 621243,
  [SMALL_STATE(14405)] = 621263,
  [SMALL_STATE(14406)] = 621285,
  [SMALL_STATE(14407)] = 621305,
  [SMALL_STATE(14408)] = 621335,
  [SMALL_STATE(14409)] = 621355,
  [SMALL_STATE(14410)] = 621381,
  [SMALL_STATE(14411)] = 621401,
  [SMALL_STATE(14412)] = 621421,
  [SMALL_STATE(14413)] = 621443,
  [SMALL_STATE(14414)] = 621467,
  [SMALL_STATE(14415)] = 621491,
  [SMALL_STATE(14416)] = 621511,
  [SMALL_STATE(14417)] = 621537,
  [SMALL_STATE(14418)] = 621557,
  [SMALL_STATE(14419)] = 621583,
  [SMALL_STATE(14420)] = 621603,
  [SMALL_STATE(14421)] = 621623,
  [SMALL_STATE(14422)] = 621649,
  [SMALL_STATE(14423)] = 621673,
  [SMALL_STATE(14424)] = 621693,
  [SMALL_STATE(14425)] = 621713,
  [SMALL_STATE(14426)] = 621739,
  [SMALL_STATE(14427)] = 621759,
  [SMALL_STATE(14428)] = 621783,
  [SMALL_STATE(14429)] = 621805,
  [SMALL_STATE(14430)] = 621825,
  [SMALL_STATE(14431)] = 621845,
  [SMALL_STATE(14432)] = 621871,
  [SMALL_STATE(14433)] = 621893,
  [SMALL_STATE(14434)] = 621912,
  [SMALL_STATE(14435)] = 621931,
  [SMALL_STATE(14436)] = 621954,
  [SMALL_STATE(14437)] = 621983,
  [SMALL_STATE(14438)] = 622002,
  [SMALL_STATE(14439)] = 622021,
  [SMALL_STATE(14440)] = 622044,
  [SMALL_STATE(14441)] = 622069,
  [SMALL_STATE(14442)] = 622098,
  [SMALL_STATE(14443)] = 622117,
  [SMALL_STATE(14444)] = 622136,
  [SMALL_STATE(14445)] = 622161,
  [SMALL_STATE(14446)] = 622190,
  [SMALL_STATE(14447)] = 622219,
  [SMALL_STATE(14448)] = 622242,
  [SMALL_STATE(14449)] = 622265,
  [SMALL_STATE(14450)] = 622288,
  [SMALL_STATE(14451)] = 622307,
  [SMALL_STATE(14452)] = 622326,
  [SMALL_STATE(14453)] = 622349,
  [SMALL_STATE(14454)] = 622378,
  [SMALL_STATE(14455)] = 622397,
  [SMALL_STATE(14456)] = 622416,
  [SMALL_STATE(14457)] = 622445,
  [SMALL_STATE(14458)] = 622468,
  [SMALL_STATE(14459)] = 622487,
  [SMALL_STATE(14460)] = 622506,
  [SMALL_STATE(14461)] = 622535,
  [SMALL_STATE(14462)] = 622556,
  [SMALL_STATE(14463)] = 622575,
  [SMALL_STATE(14464)] = 622598,
  [SMALL_STATE(14465)] = 622617,
  [SMALL_STATE(14466)] = 622642,
  [SMALL_STATE(14467)] = 622667,
  [SMALL_STATE(14468)] = 622692,
  [SMALL_STATE(14469)] = 622711,
  [SMALL_STATE(14470)] = 622730,
  [SMALL_STATE(14471)] = 622749,
  [SMALL_STATE(14472)] = 622772,
  [SMALL_STATE(14473)] = 622801,
  [SMALL_STATE(14474)] = 622830,
  [SMALL_STATE(14475)] = 622853,
  [SMALL_STATE(14476)] = 622882,
  [SMALL_STATE(14477)] = 622901,
  [SMALL_STATE(14478)] = 622926,
  [SMALL_STATE(14479)] = 622945,
  [SMALL_STATE(14480)] = 622974,
  [SMALL_STATE(14481)] = 622999,
  [SMALL_STATE(14482)] = 623018,
  [SMALL_STATE(14483)] = 623039,
  [SMALL_STATE(14484)] = 623062,
  [SMALL_STATE(14485)] = 623081,
  [SMALL_STATE(14486)] = 623100,
  [SMALL_STATE(14487)] = 623123,
  [SMALL_STATE(14488)] = 623146,
  [SMALL_STATE(14489)] = 623165,
  [SMALL_STATE(14490)] = 623184,
  [SMALL_STATE(14491)] = 623209,
  [SMALL_STATE(14492)] = 623234,
  [SMALL_STATE(14493)] = 623253,
  [SMALL_STATE(14494)] = 623272,
  [SMALL_STATE(14495)] = 623297,
  [SMALL_STATE(14496)] = 623316,
  [SMALL_STATE(14497)] = 623335,
  [SMALL_STATE(14498)] = 623356,
  [SMALL_STATE(14499)] = 623379,
  [SMALL_STATE(14500)] = 623404,
  [SMALL_STATE(14501)] = 623425,
  [SMALL_STATE(14502)] = 623444,
  [SMALL_STATE(14503)] = 623463,
  [SMALL_STATE(14504)] = 623488,
  [SMALL_STATE(14505)] = 623517,
  [SMALL_STATE(14506)] = 623536,
  [SMALL_STATE(14507)] = 623561,
  [SMALL_STATE(14508)] = 623580,
  [SMALL_STATE(14509)] = 623609,
  [SMALL_STATE(14510)] = 623638,
  [SMALL_STATE(14511)] = 623667,
  [SMALL_STATE(14512)] = 623696,
  [SMALL_STATE(14513)] = 623719,
  [SMALL_STATE(14514)] = 623742,
  [SMALL_STATE(14515)] = 623765,
  [SMALL_STATE(14516)] = 623794,
  [SMALL_STATE(14517)] = 623813,
  [SMALL_STATE(14518)] = 623836,
  [SMALL_STATE(14519)] = 623865,
  [SMALL_STATE(14520)] = 623894,
  [SMALL_STATE(14521)] = 623913,
  [SMALL_STATE(14522)] = 623938,
  [SMALL_STATE(14523)] = 623961,
  [SMALL_STATE(14524)] = 623990,
  [SMALL_STATE(14525)] = 624015,
  [SMALL_STATE(14526)] = 624040,
  [SMALL_STATE(14527)] = 624059,
  [SMALL_STATE(14528)] = 624084,
  [SMALL_STATE(14529)] = 624113,
  [SMALL_STATE(14530)] = 624132,
  [SMALL_STATE(14531)] = 624155,
  [SMALL_STATE(14532)] = 624174,
  [SMALL_STATE(14533)] = 624193,
  [SMALL_STATE(14534)] = 624222,
  [SMALL_STATE(14535)] = 624241,
  [SMALL_STATE(14536)] = 624260,
  [SMALL_STATE(14537)] = 624279,
  [SMALL_STATE(14538)] = 624298,
  [SMALL_STATE(14539)] = 624321,
  [SMALL_STATE(14540)] = 624350,
  [SMALL_STATE(14541)] = 624371,
  [SMALL_STATE(14542)] = 624394,
  [SMALL_STATE(14543)] = 624417,
  [SMALL_STATE(14544)] = 624436,
  [SMALL_STATE(14545)] = 624455,
  [SMALL_STATE(14546)] = 624474,
  [SMALL_STATE(14547)] = 624493,
  [SMALL_STATE(14548)] = 624516,
  [SMALL_STATE(14549)] = 624541,
  [SMALL_STATE(14550)] = 624562,
  [SMALL_STATE(14551)] = 624581,
  [SMALL_STATE(14552)] = 624600,
  [SMALL_STATE(14553)] = 624629,
  [SMALL_STATE(14554)] = 624648,
  [SMALL_STATE(14555)] = 624667,
  [SMALL_STATE(14556)] = 624686,
  [SMALL_STATE(14557)] = 624709,
  [SMALL_STATE(14558)] = 624730,
  [SMALL_STATE(14559)] = 624749,
  [SMALL_STATE(14560)] = 624774,
  [SMALL_STATE(14561)] = 624803,
  [SMALL_STATE(14562)] = 624824,
  [SMALL_STATE(14563)] = 624847,
  [SMALL_STATE(14564)] = 624868,
  [SMALL_STATE(14565)] = 624887,
  [SMALL_STATE(14566)] = 624908,
  [SMALL_STATE(14567)] = 624937,
  [SMALL_STATE(14568)] = 624966,
  [SMALL_STATE(14569)] = 624985,
  [SMALL_STATE(14570)] = 625010,
  [SMALL_STATE(14571)] = 625033,
  [SMALL_STATE(14572)] = 625062,
  [SMALL_STATE(14573)] = 625091,
  [SMALL_STATE(14574)] = 625110,
  [SMALL_STATE(14575)] = 625133,
  [SMALL_STATE(14576)] = 625152,
  [SMALL_STATE(14577)] = 625173,
  [SMALL_STATE(14578)] = 625198,
  [SMALL_STATE(14579)] = 625223,
  [SMALL_STATE(14580)] = 625252,
  [SMALL_STATE(14581)] = 625271,
  [SMALL_STATE(14582)] = 625290,
  [SMALL_STATE(14583)] = 625315,
  [SMALL_STATE(14584)] = 625344,
  [SMALL_STATE(14585)] = 625363,
  [SMALL_STATE(14586)] = 625382,
  [SMALL_STATE(14587)] = 625401,
  [SMALL_STATE(14588)] = 625420,
  [SMALL_STATE(14589)] = 625449,
  [SMALL_STATE(14590)] = 625468,
  [SMALL_STATE(14591)] = 625487,
  [SMALL_STATE(14592)] = 625506,
  [SMALL_STATE(14593)] = 625529,
  [SMALL_STATE(14594)] = 625548,
  [SMALL_STATE(14595)] = 625567,
  [SMALL_STATE(14596)] = 625590,
  [SMALL_STATE(14597)] = 625619,
  [SMALL_STATE(14598)] = 625648,
  [SMALL_STATE(14599)] = 625666,
  [SMALL_STATE(14600)] = 625692,
  [SMALL_STATE(14601)] = 625710,
  [SMALL_STATE(14602)] = 625728,
  [SMALL_STATE(14603)] = 625754,
  [SMALL_STATE(14604)] = 625776,
  [SMALL_STATE(14605)] = 625794,
  [SMALL_STATE(14606)] = 625812,
  [SMALL_STATE(14607)] = 625830,
  [SMALL_STATE(14608)] = 625856,
  [SMALL_STATE(14609)] = 625874,
  [SMALL_STATE(14610)] = 625892,
  [SMALL_STATE(14611)] = 625910,
  [SMALL_STATE(14612)] = 625936,
  [SMALL_STATE(14613)] = 625954,
  [SMALL_STATE(14614)] = 625980,
  [SMALL_STATE(14615)] = 626002,
  [SMALL_STATE(14616)] = 626020,
  [SMALL_STATE(14617)] = 626042,
  [SMALL_STATE(14618)] = 626068,
  [SMALL_STATE(14619)] = 626088,
  [SMALL_STATE(14620)] = 626114,
  [SMALL_STATE(14621)] = 626132,
  [SMALL_STATE(14622)] = 626158,
  [SMALL_STATE(14623)] = 626176,
  [SMALL_STATE(14624)] = 626200,
  [SMALL_STATE(14625)] = 626226,
  [SMALL_STATE(14626)] = 626244,
  [SMALL_STATE(14627)] = 626262,
  [SMALL_STATE(14628)] = 626288,
  [SMALL_STATE(14629)] = 626314,
  [SMALL_STATE(14630)] = 626332,
  [SMALL_STATE(14631)] = 626350,
  [SMALL_STATE(14632)] = 626376,
  [SMALL_STATE(14633)] = 626394,
  [SMALL_STATE(14634)] = 626412,
  [SMALL_STATE(14635)] = 626430,
  [SMALL_STATE(14636)] = 626448,
  [SMALL_STATE(14637)] = 626468,
  [SMALL_STATE(14638)] = 626486,
  [SMALL_STATE(14639)] = 626512,
  [SMALL_STATE(14640)] = 626530,
  [SMALL_STATE(14641)] = 626556,
  [SMALL_STATE(14642)] = 626582,
  [SMALL_STATE(14643)] = 626600,
  [SMALL_STATE(14644)] = 626618,
  [SMALL_STATE(14645)] = 626636,
  [SMALL_STATE(14646)] = 626654,
  [SMALL_STATE(14647)] = 626680,
  [SMALL_STATE(14648)] = 626698,
  [SMALL_STATE(14649)] = 626716,
  [SMALL_STATE(14650)] = 626734,
  [SMALL_STATE(14651)] = 626758,
  [SMALL_STATE(14652)] = 626784,
  [SMALL_STATE(14653)] = 626810,
  [SMALL_STATE(14654)] = 626830,
  [SMALL_STATE(14655)] = 626854,
  [SMALL_STATE(14656)] = 626872,
  [SMALL_STATE(14657)] = 626890,
  [SMALL_STATE(14658)] = 626914,
  [SMALL_STATE(14659)] = 626936,
  [SMALL_STATE(14660)] = 626954,
  [SMALL_STATE(14661)] = 626972,
  [SMALL_STATE(14662)] = 626990,
  [SMALL_STATE(14663)] = 627014,
  [SMALL_STATE(14664)] = 627040,
  [SMALL_STATE(14665)] = 627062,
  [SMALL_STATE(14666)] = 627080,
  [SMALL_STATE(14667)] = 627106,
  [SMALL_STATE(14668)] = 627128,
  [SMALL_STATE(14669)] = 627154,
  [SMALL_STATE(14670)] = 627180,
  [SMALL_STATE(14671)] = 627198,
  [SMALL_STATE(14672)] = 627218,
  [SMALL_STATE(14673)] = 627238,
  [SMALL_STATE(14674)] = 627262,
  [SMALL_STATE(14675)] = 627280,
  [SMALL_STATE(14676)] = 627302,
  [SMALL_STATE(14677)] = 627320,
  [SMALL_STATE(14678)] = 627338,
  [SMALL_STATE(14679)] = 627364,
  [SMALL_STATE(14680)] = 627382,
  [SMALL_STATE(14681)] = 627404,
  [SMALL_STATE(14682)] = 627422,
  [SMALL_STATE(14683)] = 627444,
  [SMALL_STATE(14684)] = 627466,
  [SMALL_STATE(14685)] = 627492,
  [SMALL_STATE(14686)] = 627514,
  [SMALL_STATE(14687)] = 627532,
  [SMALL_STATE(14688)] = 627550,
  [SMALL_STATE(14689)] = 627568,
  [SMALL_STATE(14690)] = 627594,
  [SMALL_STATE(14691)] = 627620,
  [SMALL_STATE(14692)] = 627642,
  [SMALL_STATE(14693)] = 627664,
  [SMALL_STATE(14694)] = 627684,
  [SMALL_STATE(14695)] = 627710,
  [SMALL_STATE(14696)] = 627736,
  [SMALL_STATE(14697)] = 627754,
  [SMALL_STATE(14698)] = 627778,
  [SMALL_STATE(14699)] = 627802,
  [SMALL_STATE(14700)] = 627828,
  [SMALL_STATE(14701)] = 627848,
  [SMALL_STATE(14702)] = 627866,
  [SMALL_STATE(14703)] = 627888,
  [SMALL_STATE(14704)] = 627912,
  [SMALL_STATE(14705)] = 627930,
  [SMALL_STATE(14706)] = 627954,
  [SMALL_STATE(14707)] = 627972,
  [SMALL_STATE(14708)] = 627990,
  [SMALL_STATE(14709)] = 628016,
  [SMALL_STATE(14710)] = 628038,
  [SMALL_STATE(14711)] = 628064,
  [SMALL_STATE(14712)] = 628084,
  [SMALL_STATE(14713)] = 628108,
  [SMALL_STATE(14714)] = 628132,
  [SMALL_STATE(14715)] = 628150,
  [SMALL_STATE(14716)] = 628170,
  [SMALL_STATE(14717)] = 628188,
  [SMALL_STATE(14718)] = 628206,
  [SMALL_STATE(14719)] = 628232,
  [SMALL_STATE(14720)] = 628258,
  [SMALL_STATE(14721)] = 628276,
  [SMALL_STATE(14722)] = 628294,
  [SMALL_STATE(14723)] = 628320,
  [SMALL_STATE(14724)] = 628338,
  [SMALL_STATE(14725)] = 628364,
  [SMALL_STATE(14726)] = 628382,
  [SMALL_STATE(14727)] = 628408,
  [SMALL_STATE(14728)] = 628426,
  [SMALL_STATE(14729)] = 628444,
  [SMALL_STATE(14730)] = 628462,
  [SMALL_STATE(14731)] = 628488,
  [SMALL_STATE(14732)] = 628508,
  [SMALL_STATE(14733)] = 628526,
  [SMALL_STATE(14734)] = 628546,
  [SMALL_STATE(14735)] = 628564,
  [SMALL_STATE(14736)] = 628582,
  [SMALL_STATE(14737)] = 628600,
  [SMALL_STATE(14738)] = 628618,
  [SMALL_STATE(14739)] = 628636,
  [SMALL_STATE(14740)] = 628654,
  [SMALL_STATE(14741)] = 628672,
  [SMALL_STATE(14742)] = 628690,
  [SMALL_STATE(14743)] = 628712,
  [SMALL_STATE(14744)] = 628730,
  [SMALL_STATE(14745)] = 628752,
  [SMALL_STATE(14746)] = 628770,
  [SMALL_STATE(14747)] = 628788,
  [SMALL_STATE(14748)] = 628806,
  [SMALL_STATE(14749)] = 628824,
  [SMALL_STATE(14750)] = 628842,
  [SMALL_STATE(14751)] = 628866,
  [SMALL_STATE(14752)] = 628884,
  [SMALL_STATE(14753)] = 628910,
  [SMALL_STATE(14754)] = 628934,
  [SMALL_STATE(14755)] = 628960,
  [SMALL_STATE(14756)] = 628986,
  [SMALL_STATE(14757)] = 629010,
  [SMALL_STATE(14758)] = 629036,
  [SMALL_STATE(14759)] = 629056,
  [SMALL_STATE(14760)] = 629078,
  [SMALL_STATE(14761)] = 629098,
  [SMALL_STATE(14762)] = 629116,
  [SMALL_STATE(14763)] = 629134,
  [SMALL_STATE(14764)] = 629156,
  [SMALL_STATE(14765)] = 629174,
  [SMALL_STATE(14766)] = 629200,
  [SMALL_STATE(14767)] = 629222,
  [SMALL_STATE(14768)] = 629248,
  [SMALL_STATE(14769)] = 629274,
  [SMALL_STATE(14770)] = 629296,
  [SMALL_STATE(14771)] = 629314,
  [SMALL_STATE(14772)] = 629338,
  [SMALL_STATE(14773)] = 629356,
  [SMALL_STATE(14774)] = 629382,
  [SMALL_STATE(14775)] = 629400,
  [SMALL_STATE(14776)] = 629426,
  [SMALL_STATE(14777)] = 629452,
  [SMALL_STATE(14778)] = 629476,
  [SMALL_STATE(14779)] = 629500,
  [SMALL_STATE(14780)] = 629524,
  [SMALL_STATE(14781)] = 629542,
  [SMALL_STATE(14782)] = 629560,
  [SMALL_STATE(14783)] = 629578,
  [SMALL_STATE(14784)] = 629596,
  [SMALL_STATE(14785)] = 629614,
  [SMALL_STATE(14786)] = 629632,
  [SMALL_STATE(14787)] = 629650,
  [SMALL_STATE(14788)] = 629668,
  [SMALL_STATE(14789)] = 629686,
  [SMALL_STATE(14790)] = 629710,
  [SMALL_STATE(14791)] = 629728,
  [SMALL_STATE(14792)] = 629754,
  [SMALL_STATE(14793)] = 629780,
  [SMALL_STATE(14794)] = 629798,
  [SMALL_STATE(14795)] = 629824,
  [SMALL_STATE(14796)] = 629850,
  [SMALL_STATE(14797)] = 629876,
  [SMALL_STATE(14798)] = 629894,
  [SMALL_STATE(14799)] = 629912,
  [SMALL_STATE(14800)] = 629932,
  [SMALL_STATE(14801)] = 629958,
  [SMALL_STATE(14802)] = 629976,
  [SMALL_STATE(14803)] = 629996,
  [SMALL_STATE(14804)] = 630020,
  [SMALL_STATE(14805)] = 630044,
  [SMALL_STATE(14806)] = 630062,
  [SMALL_STATE(14807)] = 630088,
  [SMALL_STATE(14808)] = 630114,
  [SMALL_STATE(14809)] = 630132,
  [SMALL_STATE(14810)] = 630158,
  [SMALL_STATE(14811)] = 630182,
  [SMALL_STATE(14812)] = 630208,
  [SMALL_STATE(14813)] = 630226,
  [SMALL_STATE(14814)] = 630252,
  [SMALL_STATE(14815)] = 630278,
  [SMALL_STATE(14816)] = 630296,
  [SMALL_STATE(14817)] = 630314,
  [SMALL_STATE(14818)] = 630340,
  [SMALL_STATE(14819)] = 630364,
  [SMALL_STATE(14820)] = 630382,
  [SMALL_STATE(14821)] = 630406,
  [SMALL_STATE(14822)] = 630430,
  [SMALL_STATE(14823)] = 630448,
  [SMALL_STATE(14824)] = 630470,
  [SMALL_STATE(14825)] = 630488,
  [SMALL_STATE(14826)] = 630514,
  [SMALL_STATE(14827)] = 630532,
  [SMALL_STATE(14828)] = 630556,
  [SMALL_STATE(14829)] = 630582,
  [SMALL_STATE(14830)] = 630608,
  [SMALL_STATE(14831)] = 630634,
  [SMALL_STATE(14832)] = 630658,
  [SMALL_STATE(14833)] = 630676,
  [SMALL_STATE(14834)] = 630694,
  [SMALL_STATE(14835)] = 630720,
  [SMALL_STATE(14836)] = 630744,
  [SMALL_STATE(14837)] = 630770,
  [SMALL_STATE(14838)] = 630796,
  [SMALL_STATE(14839)] = 630822,
  [SMALL_STATE(14840)] = 630840,
  [SMALL_STATE(14841)] = 630858,
  [SMALL_STATE(14842)] = 630884,
  [SMALL_STATE(14843)] = 630910,
  [SMALL_STATE(14844)] = 630928,
  [SMALL_STATE(14845)] = 630948,
  [SMALL_STATE(14846)] = 630966,
  [SMALL_STATE(14847)] = 630992,
  [SMALL_STATE(14848)] = 631010,
  [SMALL_STATE(14849)] = 631028,
  [SMALL_STATE(14850)] = 631046,
  [SMALL_STATE(14851)] = 631070,
  [SMALL_STATE(14852)] = 631088,
  [SMALL_STATE(14853)] = 631106,
  [SMALL_STATE(14854)] = 631129,
  [SMALL_STATE(14855)] = 631146,
  [SMALL_STATE(14856)] = 631167,
  [SMALL_STATE(14857)] = 631188,
  [SMALL_STATE(14858)] = 631205,
  [SMALL_STATE(14859)] = 631222,
  [SMALL_STATE(14860)] = 631239,
  [SMALL_STATE(14861)] = 631260,
  [SMALL_STATE(14862)] = 631283,
  [SMALL_STATE(14863)] = 631306,
  [SMALL_STATE(14864)] = 631323,
  [SMALL_STATE(14865)] = 631346,
  [SMALL_STATE(14866)] = 631363,
  [SMALL_STATE(14867)] = 631386,
  [SMALL_STATE(14868)] = 631409,
  [SMALL_STATE(14869)] = 631432,
  [SMALL_STATE(14870)] = 631455,
  [SMALL_STATE(14871)] = 631478,
  [SMALL_STATE(14872)] = 631501,
  [SMALL_STATE(14873)] = 631524,
  [SMALL_STATE(14874)] = 631541,
  [SMALL_STATE(14875)] = 631564,
  [SMALL_STATE(14876)] = 631587,
  [SMALL_STATE(14877)] = 631610,
  [SMALL_STATE(14878)] = 631627,
  [SMALL_STATE(14879)] = 631650,
  [SMALL_STATE(14880)] = 631667,
  [SMALL_STATE(14881)] = 631684,
  [SMALL_STATE(14882)] = 631705,
  [SMALL_STATE(14883)] = 631726,
  [SMALL_STATE(14884)] = 631747,
  [SMALL_STATE(14885)] = 631770,
  [SMALL_STATE(14886)] = 631793,
  [SMALL_STATE(14887)] = 631810,
  [SMALL_STATE(14888)] = 631831,
  [SMALL_STATE(14889)] = 631854,
  [SMALL_STATE(14890)] = 631875,
  [SMALL_STATE(14891)] = 631892,
  [SMALL_STATE(14892)] = 631913,
  [SMALL_STATE(14893)] = 631934,
  [SMALL_STATE(14894)] = 631951,
  [SMALL_STATE(14895)] = 631974,
  [SMALL_STATE(14896)] = 631991,
  [SMALL_STATE(14897)] = 632008,
  [SMALL_STATE(14898)] = 632031,
  [SMALL_STATE(14899)] = 632052,
  [SMALL_STATE(14900)] = 632075,
  [SMALL_STATE(14901)] = 632098,
  [SMALL_STATE(14902)] = 632115,
  [SMALL_STATE(14903)] = 632138,
  [SMALL_STATE(14904)] = 632161,
  [SMALL_STATE(14905)] = 632184,
  [SMALL_STATE(14906)] = 632207,
  [SMALL_STATE(14907)] = 632230,
  [SMALL_STATE(14908)] = 632251,
  [SMALL_STATE(14909)] = 632274,
  [SMALL_STATE(14910)] = 632297,
  [SMALL_STATE(14911)] = 632318,
  [SMALL_STATE(14912)] = 632341,
  [SMALL_STATE(14913)] = 632364,
  [SMALL_STATE(14914)] = 632387,
  [SMALL_STATE(14915)] = 632410,
  [SMALL_STATE(14916)] = 632431,
  [SMALL_STATE(14917)] = 632452,
  [SMALL_STATE(14918)] = 632475,
  [SMALL_STATE(14919)] = 632492,
  [SMALL_STATE(14920)] = 632515,
  [SMALL_STATE(14921)] = 632536,
  [SMALL_STATE(14922)] = 632559,
  [SMALL_STATE(14923)] = 632582,
  [SMALL_STATE(14924)] = 632605,
  [SMALL_STATE(14925)] = 632628,
  [SMALL_STATE(14926)] = 632645,
  [SMALL_STATE(14927)] = 632668,
  [SMALL_STATE(14928)] = 632691,
  [SMALL_STATE(14929)] = 632714,
  [SMALL_STATE(14930)] = 632735,
  [SMALL_STATE(14931)] = 632756,
  [SMALL_STATE(14932)] = 632777,
  [SMALL_STATE(14933)] = 632800,
  [SMALL_STATE(14934)] = 632823,
  [SMALL_STATE(14935)] = 632844,
  [SMALL_STATE(14936)] = 632867,
  [SMALL_STATE(14937)] = 632888,
  [SMALL_STATE(14938)] = 632911,
  [SMALL_STATE(14939)] = 632928,
  [SMALL_STATE(14940)] = 632945,
  [SMALL_STATE(14941)] = 632966,
  [SMALL_STATE(14942)] = 632987,
  [SMALL_STATE(14943)] = 633010,
  [SMALL_STATE(14944)] = 633027,
  [SMALL_STATE(14945)] = 633048,
  [SMALL_STATE(14946)] = 633071,
  [SMALL_STATE(14947)] = 633094,
  [SMALL_STATE(14948)] = 633115,
  [SMALL_STATE(14949)] = 633138,
  [SMALL_STATE(14950)] = 633161,
  [SMALL_STATE(14951)] = 633178,
  [SMALL_STATE(14952)] = 633197,
  [SMALL_STATE(14953)] = 633214,
  [SMALL_STATE(14954)] = 633235,
  [SMALL_STATE(14955)] = 633252,
  [SMALL_STATE(14956)] = 633269,
  [SMALL_STATE(14957)] = 633292,
  [SMALL_STATE(14958)] = 633313,
  [SMALL_STATE(14959)] = 633336,
  [SMALL_STATE(14960)] = 633359,
  [SMALL_STATE(14961)] = 633382,
  [SMALL_STATE(14962)] = 633403,
  [SMALL_STATE(14963)] = 633426,
  [SMALL_STATE(14964)] = 633449,
  [SMALL_STATE(14965)] = 633472,
  [SMALL_STATE(14966)] = 633495,
  [SMALL_STATE(14967)] = 633518,
  [SMALL_STATE(14968)] = 633541,
  [SMALL_STATE(14969)] = 633558,
  [SMALL_STATE(14970)] = 633575,
  [SMALL_STATE(14971)] = 633598,
  [SMALL_STATE(14972)] = 633619,
  [SMALL_STATE(14973)] = 633642,
  [SMALL_STATE(14974)] = 633665,
  [SMALL_STATE(14975)] = 633686,
  [SMALL_STATE(14976)] = 633703,
  [SMALL_STATE(14977)] = 633720,
  [SMALL_STATE(14978)] = 633737,
  [SMALL_STATE(14979)] = 633756,
  [SMALL_STATE(14980)] = 633779,
  [SMALL_STATE(14981)] = 633796,
  [SMALL_STATE(14982)] = 633813,
  [SMALL_STATE(14983)] = 633830,
  [SMALL_STATE(14984)] = 633853,
  [SMALL_STATE(14985)] = 633876,
  [SMALL_STATE(14986)] = 633899,
  [SMALL_STATE(14987)] = 633922,
  [SMALL_STATE(14988)] = 633941,
  [SMALL_STATE(14989)] = 633962,
  [SMALL_STATE(14990)] = 633985,
  [SMALL_STATE(14991)] = 634008,
  [SMALL_STATE(14992)] = 634031,
  [SMALL_STATE(14993)] = 634054,
  [SMALL_STATE(14994)] = 634077,
  [SMALL_STATE(14995)] = 634100,
  [SMALL_STATE(14996)] = 634117,
  [SMALL_STATE(14997)] = 634134,
  [SMALL_STATE(14998)] = 634151,
  [SMALL_STATE(14999)] = 634170,
  [SMALL_STATE(15000)] = 634189,
  [SMALL_STATE(15001)] = 634212,
  [SMALL_STATE(15002)] = 634229,
  [SMALL_STATE(15003)] = 634252,
  [SMALL_STATE(15004)] = 634269,
  [SMALL_STATE(15005)] = 634290,
  [SMALL_STATE(15006)] = 634309,
  [SMALL_STATE(15007)] = 634332,
  [SMALL_STATE(15008)] = 634355,
  [SMALL_STATE(15009)] = 634376,
  [SMALL_STATE(15010)] = 634397,
  [SMALL_STATE(15011)] = 634416,
  [SMALL_STATE(15012)] = 634439,
  [SMALL_STATE(15013)] = 634462,
  [SMALL_STATE(15014)] = 634485,
  [SMALL_STATE(15015)] = 634508,
  [SMALL_STATE(15016)] = 634531,
  [SMALL_STATE(15017)] = 634552,
  [SMALL_STATE(15018)] = 634575,
  [SMALL_STATE(15019)] = 634596,
  [SMALL_STATE(15020)] = 634619,
  [SMALL_STATE(15021)] = 634642,
  [SMALL_STATE(15022)] = 634665,
  [SMALL_STATE(15023)] = 634688,
  [SMALL_STATE(15024)] = 634705,
  [SMALL_STATE(15025)] = 634724,
  [SMALL_STATE(15026)] = 634745,
  [SMALL_STATE(15027)] = 634766,
  [SMALL_STATE(15028)] = 634783,
  [SMALL_STATE(15029)] = 634800,
  [SMALL_STATE(15030)] = 634817,
  [SMALL_STATE(15031)] = 634834,
  [SMALL_STATE(15032)] = 634855,
  [SMALL_STATE(15033)] = 634878,
  [SMALL_STATE(15034)] = 634901,
  [SMALL_STATE(15035)] = 634922,
  [SMALL_STATE(15036)] = 634941,
  [SMALL_STATE(15037)] = 634964,
  [SMALL_STATE(15038)] = 634985,
  [SMALL_STATE(15039)] = 635002,
  [SMALL_STATE(15040)] = 635025,
  [SMALL_STATE(15041)] = 635046,
  [SMALL_STATE(15042)] = 635067,
  [SMALL_STATE(15043)] = 635084,
  [SMALL_STATE(15044)] = 635101,
  [SMALL_STATE(15045)] = 635122,
  [SMALL_STATE(15046)] = 635139,
  [SMALL_STATE(15047)] = 635156,
  [SMALL_STATE(15048)] = 635179,
  [SMALL_STATE(15049)] = 635202,
  [SMALL_STATE(15050)] = 635223,
  [SMALL_STATE(15051)] = 635246,
  [SMALL_STATE(15052)] = 635265,
  [SMALL_STATE(15053)] = 635286,
  [SMALL_STATE(15054)] = 635303,
  [SMALL_STATE(15055)] = 635326,
  [SMALL_STATE(15056)] = 635343,
  [SMALL_STATE(15057)] = 635360,
  [SMALL_STATE(15058)] = 635377,
  [SMALL_STATE(15059)] = 635400,
  [SMALL_STATE(15060)] = 635423,
  [SMALL_STATE(15061)] = 635446,
  [SMALL_STATE(15062)] = 635467,
  [SMALL_STATE(15063)] = 635490,
  [SMALL_STATE(15064)] = 635507,
  [SMALL_STATE(15065)] = 635530,
  [SMALL_STATE(15066)] = 635553,
  [SMALL_STATE(15067)] = 635570,
  [SMALL_STATE(15068)] = 635587,
  [SMALL_STATE(15069)] = 635610,
  [SMALL_STATE(15070)] = 635627,
  [SMALL_STATE(15071)] = 635650,
  [SMALL_STATE(15072)] = 635673,
  [SMALL_STATE(15073)] = 635692,
  [SMALL_STATE(15074)] = 635715,
  [SMALL_STATE(15075)] = 635736,
  [SMALL_STATE(15076)] = 635759,
  [SMALL_STATE(15077)] = 635782,
  [SMALL_STATE(15078)] = 635805,
  [SMALL_STATE(15079)] = 635828,
  [SMALL_STATE(15080)] = 635845,
  [SMALL_STATE(15081)] = 635862,
  [SMALL_STATE(15082)] = 635885,
  [SMALL_STATE(15083)] = 635906,
  [SMALL_STATE(15084)] = 635927,
  [SMALL_STATE(15085)] = 635948,
  [SMALL_STATE(15086)] = 635971,
  [SMALL_STATE(15087)] = 635994,
  [SMALL_STATE(15088)] = 636017,
  [SMALL_STATE(15089)] = 636040,
  [SMALL_STATE(15090)] = 636057,
  [SMALL_STATE(15091)] = 636074,
  [SMALL_STATE(15092)] = 636093,
  [SMALL_STATE(15093)] = 636114,
  [SMALL_STATE(15094)] = 636137,
  [SMALL_STATE(15095)] = 636160,
  [SMALL_STATE(15096)] = 636177,
  [SMALL_STATE(15097)] = 636194,
  [SMALL_STATE(15098)] = 636215,
  [SMALL_STATE(15099)] = 636232,
  [SMALL_STATE(15100)] = 636255,
  [SMALL_STATE(15101)] = 636272,
  [SMALL_STATE(15102)] = 636295,
  [SMALL_STATE(15103)] = 636316,
  [SMALL_STATE(15104)] = 636333,
  [SMALL_STATE(15105)] = 636356,
  [SMALL_STATE(15106)] = 636373,
  [SMALL_STATE(15107)] = 636390,
  [SMALL_STATE(15108)] = 636407,
  [SMALL_STATE(15109)] = 636424,
  [SMALL_STATE(15110)] = 636445,
  [SMALL_STATE(15111)] = 636462,
  [SMALL_STATE(15112)] = 636479,
  [SMALL_STATE(15113)] = 636502,
  [SMALL_STATE(15114)] = 636525,
  [SMALL_STATE(15115)] = 636548,
  [SMALL_STATE(15116)] = 636567,
  [SMALL_STATE(15117)] = 636588,
  [SMALL_STATE(15118)] = 636611,
  [SMALL_STATE(15119)] = 636634,
  [SMALL_STATE(15120)] = 636651,
  [SMALL_STATE(15121)] = 636674,
  [SMALL_STATE(15122)] = 636697,
  [SMALL_STATE(15123)] = 636714,
  [SMALL_STATE(15124)] = 636737,
  [SMALL_STATE(15125)] = 636760,
  [SMALL_STATE(15126)] = 636783,
  [SMALL_STATE(15127)] = 636806,
  [SMALL_STATE(15128)] = 636823,
  [SMALL_STATE(15129)] = 636840,
  [SMALL_STATE(15130)] = 636863,
  [SMALL_STATE(15131)] = 636886,
  [SMALL_STATE(15132)] = 636903,
  [SMALL_STATE(15133)] = 636920,
  [SMALL_STATE(15134)] = 636937,
  [SMALL_STATE(15135)] = 636954,
  [SMALL_STATE(15136)] = 636977,
  [SMALL_STATE(15137)] = 636994,
  [SMALL_STATE(15138)] = 637017,
  [SMALL_STATE(15139)] = 637034,
  [SMALL_STATE(15140)] = 637057,
  [SMALL_STATE(15141)] = 637080,
  [SMALL_STATE(15142)] = 637097,
  [SMALL_STATE(15143)] = 637118,
  [SMALL_STATE(15144)] = 637141,
  [SMALL_STATE(15145)] = 637162,
  [SMALL_STATE(15146)] = 637179,
  [SMALL_STATE(15147)] = 637202,
  [SMALL_STATE(15148)] = 637225,
  [SMALL_STATE(15149)] = 637246,
  [SMALL_STATE(15150)] = 637269,
  [SMALL_STATE(15151)] = 637290,
  [SMALL_STATE(15152)] = 637307,
  [SMALL_STATE(15153)] = 637324,
  [SMALL_STATE(15154)] = 637345,
  [SMALL_STATE(15155)] = 637362,
  [SMALL_STATE(15156)] = 637385,
  [SMALL_STATE(15157)] = 637406,
  [SMALL_STATE(15158)] = 637427,
  [SMALL_STATE(15159)] = 637450,
  [SMALL_STATE(15160)] = 637473,
  [SMALL_STATE(15161)] = 637496,
  [SMALL_STATE(15162)] = 637519,
  [SMALL_STATE(15163)] = 637542,
  [SMALL_STATE(15164)] = 637565,
  [SMALL_STATE(15165)] = 637588,
  [SMALL_STATE(15166)] = 637611,
  [SMALL_STATE(15167)] = 637634,
  [SMALL_STATE(15168)] = 637657,
  [SMALL_STATE(15169)] = 637678,
  [SMALL_STATE(15170)] = 637701,
  [SMALL_STATE(15171)] = 637724,
  [SMALL_STATE(15172)] = 637747,
  [SMALL_STATE(15173)] = 637770,
  [SMALL_STATE(15174)] = 637793,
  [SMALL_STATE(15175)] = 637816,
  [SMALL_STATE(15176)] = 637839,
  [SMALL_STATE(15177)] = 637862,
  [SMALL_STATE(15178)] = 637885,
  [SMALL_STATE(15179)] = 637908,
  [SMALL_STATE(15180)] = 637925,
  [SMALL_STATE(15181)] = 637948,
  [SMALL_STATE(15182)] = 637971,
  [SMALL_STATE(15183)] = 637992,
  [SMALL_STATE(15184)] = 638015,
  [SMALL_STATE(15185)] = 638038,
  [SMALL_STATE(15186)] = 638061,
  [SMALL_STATE(15187)] = 638080,
  [SMALL_STATE(15188)] = 638101,
  [SMALL_STATE(15189)] = 638124,
  [SMALL_STATE(15190)] = 638147,
  [SMALL_STATE(15191)] = 638170,
  [SMALL_STATE(15192)] = 638193,
  [SMALL_STATE(15193)] = 638213,
  [SMALL_STATE(15194)] = 638233,
  [SMALL_STATE(15195)] = 638251,
  [SMALL_STATE(15196)] = 638271,
  [SMALL_STATE(15197)] = 638291,
  [SMALL_STATE(15198)] = 638311,
  [SMALL_STATE(15199)] = 638327,
  [SMALL_STATE(15200)] = 638345,
  [SMALL_STATE(15201)] = 638365,
  [SMALL_STATE(15202)] = 638385,
  [SMALL_STATE(15203)] = 638405,
  [SMALL_STATE(15204)] = 638423,
  [SMALL_STATE(15205)] = 638443,
  [SMALL_STATE(15206)] = 638463,
  [SMALL_STATE(15207)] = 638483,
  [SMALL_STATE(15208)] = 638503,
  [SMALL_STATE(15209)] = 638523,
  [SMALL_STATE(15210)] = 638543,
  [SMALL_STATE(15211)] = 638563,
  [SMALL_STATE(15212)] = 638583,
  [SMALL_STATE(15213)] = 638603,
  [SMALL_STATE(15214)] = 638623,
  [SMALL_STATE(15215)] = 638643,
  [SMALL_STATE(15216)] = 638663,
  [SMALL_STATE(15217)] = 638683,
  [SMALL_STATE(15218)] = 638703,
  [SMALL_STATE(15219)] = 638723,
  [SMALL_STATE(15220)] = 638743,
  [SMALL_STATE(15221)] = 638763,
  [SMALL_STATE(15222)] = 638783,
  [SMALL_STATE(15223)] = 638803,
  [SMALL_STATE(15224)] = 638823,
  [SMALL_STATE(15225)] = 638843,
  [SMALL_STATE(15226)] = 638861,
  [SMALL_STATE(15227)] = 638881,
  [SMALL_STATE(15228)] = 638901,
  [SMALL_STATE(15229)] = 638921,
  [SMALL_STATE(15230)] = 638941,
  [SMALL_STATE(15231)] = 638961,
  [SMALL_STATE(15232)] = 638981,
  [SMALL_STATE(15233)] = 639001,
  [SMALL_STATE(15234)] = 639021,
  [SMALL_STATE(15235)] = 639041,
  [SMALL_STATE(15236)] = 639057,
  [SMALL_STATE(15237)] = 639077,
  [SMALL_STATE(15238)] = 639097,
  [SMALL_STATE(15239)] = 639117,
  [SMALL_STATE(15240)] = 639133,
  [SMALL_STATE(15241)] = 639149,
  [SMALL_STATE(15242)] = 639169,
  [SMALL_STATE(15243)] = 639189,
  [SMALL_STATE(15244)] = 639209,
  [SMALL_STATE(15245)] = 639229,
  [SMALL_STATE(15246)] = 639249,
  [SMALL_STATE(15247)] = 639269,
  [SMALL_STATE(15248)] = 639289,
  [SMALL_STATE(15249)] = 639309,
  [SMALL_STATE(15250)] = 639329,
  [SMALL_STATE(15251)] = 639349,
  [SMALL_STATE(15252)] = 639369,
  [SMALL_STATE(15253)] = 639389,
  [SMALL_STATE(15254)] = 639409,
  [SMALL_STATE(15255)] = 639427,
  [SMALL_STATE(15256)] = 639447,
  [SMALL_STATE(15257)] = 639467,
  [SMALL_STATE(15258)] = 639487,
  [SMALL_STATE(15259)] = 639505,
  [SMALL_STATE(15260)] = 639525,
  [SMALL_STATE(15261)] = 639545,
  [SMALL_STATE(15262)] = 639565,
  [SMALL_STATE(15263)] = 639583,
  [SMALL_STATE(15264)] = 639603,
  [SMALL_STATE(15265)] = 639623,
  [SMALL_STATE(15266)] = 639643,
  [SMALL_STATE(15267)] = 639663,
  [SMALL_STATE(15268)] = 639683,
  [SMALL_STATE(15269)] = 639703,
  [SMALL_STATE(15270)] = 639723,
  [SMALL_STATE(15271)] = 639743,
  [SMALL_STATE(15272)] = 639763,
  [SMALL_STATE(15273)] = 639783,
  [SMALL_STATE(15274)] = 639803,
  [SMALL_STATE(15275)] = 639823,
  [SMALL_STATE(15276)] = 639843,
  [SMALL_STATE(15277)] = 639863,
  [SMALL_STATE(15278)] = 639883,
  [SMALL_STATE(15279)] = 639903,
  [SMALL_STATE(15280)] = 639923,
  [SMALL_STATE(15281)] = 639939,
  [SMALL_STATE(15282)] = 639959,
  [SMALL_STATE(15283)] = 639979,
  [SMALL_STATE(15284)] = 639999,
  [SMALL_STATE(15285)] = 640019,
  [SMALL_STATE(15286)] = 640039,
  [SMALL_STATE(15287)] = 640059,
  [SMALL_STATE(15288)] = 640079,
  [SMALL_STATE(15289)] = 640099,
  [SMALL_STATE(15290)] = 640119,
  [SMALL_STATE(15291)] = 640139,
  [SMALL_STATE(15292)] = 640159,
  [SMALL_STATE(15293)] = 640179,
  [SMALL_STATE(15294)] = 640199,
  [SMALL_STATE(15295)] = 640219,
  [SMALL_STATE(15296)] = 640239,
  [SMALL_STATE(15297)] = 640259,
  [SMALL_STATE(15298)] = 640279,
  [SMALL_STATE(15299)] = 640299,
  [SMALL_STATE(15300)] = 640319,
  [SMALL_STATE(15301)] = 640339,
  [SMALL_STATE(15302)] = 640359,
  [SMALL_STATE(15303)] = 640379,
  [SMALL_STATE(15304)] = 640399,
  [SMALL_STATE(15305)] = 640419,
  [SMALL_STATE(15306)] = 640439,
  [SMALL_STATE(15307)] = 640459,
  [SMALL_STATE(15308)] = 640479,
  [SMALL_STATE(15309)] = 640499,
  [SMALL_STATE(15310)] = 640519,
  [SMALL_STATE(15311)] = 640537,
  [SMALL_STATE(15312)] = 640557,
  [SMALL_STATE(15313)] = 640577,
  [SMALL_STATE(15314)] = 640597,
  [SMALL_STATE(15315)] = 640617,
  [SMALL_STATE(15316)] = 640637,
  [SMALL_STATE(15317)] = 640655,
  [SMALL_STATE(15318)] = 640675,
  [SMALL_STATE(15319)] = 640695,
  [SMALL_STATE(15320)] = 640715,
  [SMALL_STATE(15321)] = 640735,
  [SMALL_STATE(15322)] = 640755,
  [SMALL_STATE(15323)] = 640775,
  [SMALL_STATE(15324)] = 640795,
  [SMALL_STATE(15325)] = 640815,
  [SMALL_STATE(15326)] = 640835,
  [SMALL_STATE(15327)] = 640855,
  [SMALL_STATE(15328)] = 640875,
  [SMALL_STATE(15329)] = 640895,
  [SMALL_STATE(15330)] = 640915,
  [SMALL_STATE(15331)] = 640935,
  [SMALL_STATE(15332)] = 640955,
  [SMALL_STATE(15333)] = 640975,
  [SMALL_STATE(15334)] = 640995,
  [SMALL_STATE(15335)] = 641015,
  [SMALL_STATE(15336)] = 641035,
  [SMALL_STATE(15337)] = 641055,
  [SMALL_STATE(15338)] = 641075,
  [SMALL_STATE(15339)] = 641095,
  [SMALL_STATE(15340)] = 641115,
  [SMALL_STATE(15341)] = 641135,
  [SMALL_STATE(15342)] = 641155,
  [SMALL_STATE(15343)] = 641175,
  [SMALL_STATE(15344)] = 641195,
  [SMALL_STATE(15345)] = 641215,
  [SMALL_STATE(15346)] = 641235,
  [SMALL_STATE(15347)] = 641255,
  [SMALL_STATE(15348)] = 641275,
  [SMALL_STATE(15349)] = 641295,
  [SMALL_STATE(15350)] = 641315,
  [SMALL_STATE(15351)] = 641335,
  [SMALL_STATE(15352)] = 641355,
  [SMALL_STATE(15353)] = 641375,
  [SMALL_STATE(15354)] = 641395,
  [SMALL_STATE(15355)] = 641415,
  [SMALL_STATE(15356)] = 641435,
  [SMALL_STATE(15357)] = 641455,
  [SMALL_STATE(15358)] = 641475,
  [SMALL_STATE(15359)] = 641495,
  [SMALL_STATE(15360)] = 641515,
  [SMALL_STATE(15361)] = 641535,
  [SMALL_STATE(15362)] = 641555,
  [SMALL_STATE(15363)] = 641575,
  [SMALL_STATE(15364)] = 641595,
  [SMALL_STATE(15365)] = 641613,
  [SMALL_STATE(15366)] = 641633,
  [SMALL_STATE(15367)] = 641649,
  [SMALL_STATE(15368)] = 641669,
  [SMALL_STATE(15369)] = 641689,
  [SMALL_STATE(15370)] = 641709,
  [SMALL_STATE(15371)] = 641729,
  [SMALL_STATE(15372)] = 641749,
  [SMALL_STATE(15373)] = 641769,
  [SMALL_STATE(15374)] = 641789,
  [SMALL_STATE(15375)] = 641809,
  [SMALL_STATE(15376)] = 641829,
  [SMALL_STATE(15377)] = 641849,
  [SMALL_STATE(15378)] = 641869,
  [SMALL_STATE(15379)] = 641889,
  [SMALL_STATE(15380)] = 641909,
  [SMALL_STATE(15381)] = 641929,
  [SMALL_STATE(15382)] = 641949,
  [SMALL_STATE(15383)] = 641967,
  [SMALL_STATE(15384)] = 641987,
  [SMALL_STATE(15385)] = 642007,
  [SMALL_STATE(15386)] = 642027,
  [SMALL_STATE(15387)] = 642047,
  [SMALL_STATE(15388)] = 642067,
  [SMALL_STATE(15389)] = 642087,
  [SMALL_STATE(15390)] = 642107,
  [SMALL_STATE(15391)] = 642127,
  [SMALL_STATE(15392)] = 642147,
  [SMALL_STATE(15393)] = 642167,
  [SMALL_STATE(15394)] = 642187,
  [SMALL_STATE(15395)] = 642207,
  [SMALL_STATE(15396)] = 642227,
  [SMALL_STATE(15397)] = 642247,
  [SMALL_STATE(15398)] = 642267,
  [SMALL_STATE(15399)] = 642287,
  [SMALL_STATE(15400)] = 642307,
  [SMALL_STATE(15401)] = 642327,
  [SMALL_STATE(15402)] = 642347,
  [SMALL_STATE(15403)] = 642367,
  [SMALL_STATE(15404)] = 642387,
  [SMALL_STATE(15405)] = 642407,
  [SMALL_STATE(15406)] = 642427,
  [SMALL_STATE(15407)] = 642447,
  [SMALL_STATE(15408)] = 642467,
  [SMALL_STATE(15409)] = 642487,
  [SMALL_STATE(15410)] = 642507,
  [SMALL_STATE(15411)] = 642527,
  [SMALL_STATE(15412)] = 642547,
  [SMALL_STATE(15413)] = 642567,
  [SMALL_STATE(15414)] = 642587,
  [SMALL_STATE(15415)] = 642607,
  [SMALL_STATE(15416)] = 642627,
  [SMALL_STATE(15417)] = 642647,
  [SMALL_STATE(15418)] = 642667,
  [SMALL_STATE(15419)] = 642685,
  [SMALL_STATE(15420)] = 642705,
  [SMALL_STATE(15421)] = 642725,
  [SMALL_STATE(15422)] = 642745,
  [SMALL_STATE(15423)] = 642765,
  [SMALL_STATE(15424)] = 642785,
  [SMALL_STATE(15425)] = 642803,
  [SMALL_STATE(15426)] = 642823,
  [SMALL_STATE(15427)] = 642843,
  [SMALL_STATE(15428)] = 642863,
  [SMALL_STATE(15429)] = 642883,
  [SMALL_STATE(15430)] = 642903,
  [SMALL_STATE(15431)] = 642923,
  [SMALL_STATE(15432)] = 642941,
  [SMALL_STATE(15433)] = 642961,
  [SMALL_STATE(15434)] = 642981,
  [SMALL_STATE(15435)] = 642999,
  [SMALL_STATE(15436)] = 643019,
  [SMALL_STATE(15437)] = 643037,
  [SMALL_STATE(15438)] = 643057,
  [SMALL_STATE(15439)] = 643077,
  [SMALL_STATE(15440)] = 643097,
  [SMALL_STATE(15441)] = 643117,
  [SMALL_STATE(15442)] = 643137,
  [SMALL_STATE(15443)] = 643157,
  [SMALL_STATE(15444)] = 643175,
  [SMALL_STATE(15445)] = 643195,
  [SMALL_STATE(15446)] = 643215,
  [SMALL_STATE(15447)] = 643235,
  [SMALL_STATE(15448)] = 643255,
  [SMALL_STATE(15449)] = 643275,
  [SMALL_STATE(15450)] = 643295,
  [SMALL_STATE(15451)] = 643315,
  [SMALL_STATE(15452)] = 643335,
  [SMALL_STATE(15453)] = 643355,
  [SMALL_STATE(15454)] = 643375,
  [SMALL_STATE(15455)] = 643395,
  [SMALL_STATE(15456)] = 643415,
  [SMALL_STATE(15457)] = 643435,
  [SMALL_STATE(15458)] = 643455,
  [SMALL_STATE(15459)] = 643475,
  [SMALL_STATE(15460)] = 643495,
  [SMALL_STATE(15461)] = 643513,
  [SMALL_STATE(15462)] = 643533,
  [SMALL_STATE(15463)] = 643553,
  [SMALL_STATE(15464)] = 643573,
  [SMALL_STATE(15465)] = 643593,
  [SMALL_STATE(15466)] = 643613,
  [SMALL_STATE(15467)] = 643633,
  [SMALL_STATE(15468)] = 643651,
  [SMALL_STATE(15469)] = 643671,
  [SMALL_STATE(15470)] = 643691,
  [SMALL_STATE(15471)] = 643711,
  [SMALL_STATE(15472)] = 643731,
  [SMALL_STATE(15473)] = 643751,
  [SMALL_STATE(15474)] = 643771,
  [SMALL_STATE(15475)] = 643789,
  [SMALL_STATE(15476)] = 643809,
  [SMALL_STATE(15477)] = 643829,
  [SMALL_STATE(15478)] = 643849,
  [SMALL_STATE(15479)] = 643869,
  [SMALL_STATE(15480)] = 643889,
  [SMALL_STATE(15481)] = 643909,
  [SMALL_STATE(15482)] = 643929,
  [SMALL_STATE(15483)] = 643949,
  [SMALL_STATE(15484)] = 643969,
  [SMALL_STATE(15485)] = 643989,
  [SMALL_STATE(15486)] = 644007,
  [SMALL_STATE(15487)] = 644027,
  [SMALL_STATE(15488)] = 644047,
  [SMALL_STATE(15489)] = 644067,
  [SMALL_STATE(15490)] = 644087,
  [SMALL_STATE(15491)] = 644107,
  [SMALL_STATE(15492)] = 644123,
  [SMALL_STATE(15493)] = 644143,
  [SMALL_STATE(15494)] = 644163,
  [SMALL_STATE(15495)] = 644183,
  [SMALL_STATE(15496)] = 644199,
  [SMALL_STATE(15497)] = 644219,
  [SMALL_STATE(15498)] = 644239,
  [SMALL_STATE(15499)] = 644259,
  [SMALL_STATE(15500)] = 644279,
  [SMALL_STATE(15501)] = 644299,
  [SMALL_STATE(15502)] = 644319,
  [SMALL_STATE(15503)] = 644339,
  [SMALL_STATE(15504)] = 644359,
  [SMALL_STATE(15505)] = 644379,
  [SMALL_STATE(15506)] = 644399,
  [SMALL_STATE(15507)] = 644419,
  [SMALL_STATE(15508)] = 644439,
  [SMALL_STATE(15509)] = 644459,
  [SMALL_STATE(15510)] = 644479,
  [SMALL_STATE(15511)] = 644499,
  [SMALL_STATE(15512)] = 644519,
  [SMALL_STATE(15513)] = 644539,
  [SMALL_STATE(15514)] = 644555,
  [SMALL_STATE(15515)] = 644575,
  [SMALL_STATE(15516)] = 644595,
  [SMALL_STATE(15517)] = 644615,
  [SMALL_STATE(15518)] = 644633,
  [SMALL_STATE(15519)] = 644653,
  [SMALL_STATE(15520)] = 644673,
  [SMALL_STATE(15521)] = 644693,
  [SMALL_STATE(15522)] = 644713,
  [SMALL_STATE(15523)] = 644733,
  [SMALL_STATE(15524)] = 644753,
  [SMALL_STATE(15525)] = 644773,
  [SMALL_STATE(15526)] = 644793,
  [SMALL_STATE(15527)] = 644811,
  [SMALL_STATE(15528)] = 644831,
  [SMALL_STATE(15529)] = 644851,
  [SMALL_STATE(15530)] = 644871,
  [SMALL_STATE(15531)] = 644891,
  [SMALL_STATE(15532)] = 644911,
  [SMALL_STATE(15533)] = 644931,
  [SMALL_STATE(15534)] = 644949,
  [SMALL_STATE(15535)] = 644969,
  [SMALL_STATE(15536)] = 644989,
  [SMALL_STATE(15537)] = 645009,
  [SMALL_STATE(15538)] = 645029,
  [SMALL_STATE(15539)] = 645049,
  [SMALL_STATE(15540)] = 645069,
  [SMALL_STATE(15541)] = 645089,
  [SMALL_STATE(15542)] = 645109,
  [SMALL_STATE(15543)] = 645127,
  [SMALL_STATE(15544)] = 645147,
  [SMALL_STATE(15545)] = 645163,
  [SMALL_STATE(15546)] = 645183,
  [SMALL_STATE(15547)] = 645203,
  [SMALL_STATE(15548)] = 645223,
  [SMALL_STATE(15549)] = 645243,
  [SMALL_STATE(15550)] = 645263,
  [SMALL_STATE(15551)] = 645283,
  [SMALL_STATE(15552)] = 645301,
  [SMALL_STATE(15553)] = 645321,
  [SMALL_STATE(15554)] = 645341,
  [SMALL_STATE(15555)] = 645361,
  [SMALL_STATE(15556)] = 645381,
  [SMALL_STATE(15557)] = 645401,
  [SMALL_STATE(15558)] = 645421,
  [SMALL_STATE(15559)] = 645441,
  [SMALL_STATE(15560)] = 645461,
  [SMALL_STATE(15561)] = 645481,
  [SMALL_STATE(15562)] = 645501,
  [SMALL_STATE(15563)] = 645521,
  [SMALL_STATE(15564)] = 645541,
  [SMALL_STATE(15565)] = 645559,
  [SMALL_STATE(15566)] = 645579,
  [SMALL_STATE(15567)] = 645599,
  [SMALL_STATE(15568)] = 645619,
  [SMALL_STATE(15569)] = 645639,
  [SMALL_STATE(15570)] = 645659,
  [SMALL_STATE(15571)] = 645679,
  [SMALL_STATE(15572)] = 645699,
  [SMALL_STATE(15573)] = 645719,
  [SMALL_STATE(15574)] = 645739,
  [SMALL_STATE(15575)] = 645759,
  [SMALL_STATE(15576)] = 645779,
  [SMALL_STATE(15577)] = 645799,
  [SMALL_STATE(15578)] = 645819,
  [SMALL_STATE(15579)] = 645839,
  [SMALL_STATE(15580)] = 645859,
  [SMALL_STATE(15581)] = 645879,
  [SMALL_STATE(15582)] = 645899,
  [SMALL_STATE(15583)] = 645919,
  [SMALL_STATE(15584)] = 645939,
  [SMALL_STATE(15585)] = 645959,
  [SMALL_STATE(15586)] = 645979,
  [SMALL_STATE(15587)] = 645999,
  [SMALL_STATE(15588)] = 646019,
  [SMALL_STATE(15589)] = 646039,
  [SMALL_STATE(15590)] = 646059,
  [SMALL_STATE(15591)] = 646079,
  [SMALL_STATE(15592)] = 646099,
  [SMALL_STATE(15593)] = 646117,
  [SMALL_STATE(15594)] = 646137,
  [SMALL_STATE(15595)] = 646157,
  [SMALL_STATE(15596)] = 646177,
  [SMALL_STATE(15597)] = 646193,
  [SMALL_STATE(15598)] = 646213,
  [SMALL_STATE(15599)] = 646233,
  [SMALL_STATE(15600)] = 646249,
  [SMALL_STATE(15601)] = 646265,
  [SMALL_STATE(15602)] = 646285,
  [SMALL_STATE(15603)] = 646305,
  [SMALL_STATE(15604)] = 646325,
  [SMALL_STATE(15605)] = 646341,
  [SMALL_STATE(15606)] = 646361,
  [SMALL_STATE(15607)] = 646381,
  [SMALL_STATE(15608)] = 646401,
  [SMALL_STATE(15609)] = 646421,
  [SMALL_STATE(15610)] = 646441,
  [SMALL_STATE(15611)] = 646461,
  [SMALL_STATE(15612)] = 646481,
  [SMALL_STATE(15613)] = 646501,
  [SMALL_STATE(15614)] = 646521,
  [SMALL_STATE(15615)] = 646539,
  [SMALL_STATE(15616)] = 646559,
  [SMALL_STATE(15617)] = 646579,
  [SMALL_STATE(15618)] = 646599,
  [SMALL_STATE(15619)] = 646619,
  [SMALL_STATE(15620)] = 646639,
  [SMALL_STATE(15621)] = 646659,
  [SMALL_STATE(15622)] = 646679,
  [SMALL_STATE(15623)] = 646697,
  [SMALL_STATE(15624)] = 646717,
  [SMALL_STATE(15625)] = 646737,
  [SMALL_STATE(15626)] = 646757,
  [SMALL_STATE(15627)] = 646775,
  [SMALL_STATE(15628)] = 646795,
  [SMALL_STATE(15629)] = 646815,
  [SMALL_STATE(15630)] = 646833,
  [SMALL_STATE(15631)] = 646853,
  [SMALL_STATE(15632)] = 646873,
  [SMALL_STATE(15633)] = 646893,
  [SMALL_STATE(15634)] = 646913,
  [SMALL_STATE(15635)] = 646933,
  [SMALL_STATE(15636)] = 646951,
  [SMALL_STATE(15637)] = 646971,
  [SMALL_STATE(15638)] = 646989,
  [SMALL_STATE(15639)] = 647009,
  [SMALL_STATE(15640)] = 647029,
  [SMALL_STATE(15641)] = 647047,
  [SMALL_STATE(15642)] = 647067,
  [SMALL_STATE(15643)] = 647087,
  [SMALL_STATE(15644)] = 647107,
  [SMALL_STATE(15645)] = 647127,
  [SMALL_STATE(15646)] = 647147,
  [SMALL_STATE(15647)] = 647163,
  [SMALL_STATE(15648)] = 647183,
  [SMALL_STATE(15649)] = 647203,
  [SMALL_STATE(15650)] = 647221,
  [SMALL_STATE(15651)] = 647241,
  [SMALL_STATE(15652)] = 647261,
  [SMALL_STATE(15653)] = 647281,
  [SMALL_STATE(15654)] = 647301,
  [SMALL_STATE(15655)] = 647321,
  [SMALL_STATE(15656)] = 647339,
  [SMALL_STATE(15657)] = 647355,
  [SMALL_STATE(15658)] = 647375,
  [SMALL_STATE(15659)] = 647395,
  [SMALL_STATE(15660)] = 647415,
  [SMALL_STATE(15661)] = 647435,
  [SMALL_STATE(15662)] = 647455,
  [SMALL_STATE(15663)] = 647475,
  [SMALL_STATE(15664)] = 647495,
  [SMALL_STATE(15665)] = 647515,
  [SMALL_STATE(15666)] = 647535,
  [SMALL_STATE(15667)] = 647555,
  [SMALL_STATE(15668)] = 647573,
  [SMALL_STATE(15669)] = 647593,
  [SMALL_STATE(15670)] = 647613,
  [SMALL_STATE(15671)] = 647633,
  [SMALL_STATE(15672)] = 647651,
  [SMALL_STATE(15673)] = 647671,
  [SMALL_STATE(15674)] = 647691,
  [SMALL_STATE(15675)] = 647711,
  [SMALL_STATE(15676)] = 647731,
  [SMALL_STATE(15677)] = 647749,
  [SMALL_STATE(15678)] = 647765,
  [SMALL_STATE(15679)] = 647785,
  [SMALL_STATE(15680)] = 647805,
  [SMALL_STATE(15681)] = 647825,
  [SMALL_STATE(15682)] = 647845,
  [SMALL_STATE(15683)] = 647863,
  [SMALL_STATE(15684)] = 647883,
  [SMALL_STATE(15685)] = 647903,
  [SMALL_STATE(15686)] = 647923,
  [SMALL_STATE(15687)] = 647941,
  [SMALL_STATE(15688)] = 647961,
  [SMALL_STATE(15689)] = 647981,
  [SMALL_STATE(15690)] = 648001,
  [SMALL_STATE(15691)] = 648021,
  [SMALL_STATE(15692)] = 648041,
  [SMALL_STATE(15693)] = 648061,
  [SMALL_STATE(15694)] = 648081,
  [SMALL_STATE(15695)] = 648101,
  [SMALL_STATE(15696)] = 648117,
  [SMALL_STATE(15697)] = 648137,
  [SMALL_STATE(15698)] = 648157,
  [SMALL_STATE(15699)] = 648175,
  [SMALL_STATE(15700)] = 648195,
  [SMALL_STATE(15701)] = 648215,
  [SMALL_STATE(15702)] = 648233,
  [SMALL_STATE(15703)] = 648249,
  [SMALL_STATE(15704)] = 648269,
  [SMALL_STATE(15705)] = 648285,
  [SMALL_STATE(15706)] = 648305,
  [SMALL_STATE(15707)] = 648325,
  [SMALL_STATE(15708)] = 648345,
  [SMALL_STATE(15709)] = 648365,
  [SMALL_STATE(15710)] = 648385,
  [SMALL_STATE(15711)] = 648405,
  [SMALL_STATE(15712)] = 648425,
  [SMALL_STATE(15713)] = 648445,
  [SMALL_STATE(15714)] = 648465,
  [SMALL_STATE(15715)] = 648485,
  [SMALL_STATE(15716)] = 648505,
  [SMALL_STATE(15717)] = 648523,
  [SMALL_STATE(15718)] = 648543,
  [SMALL_STATE(15719)] = 648563,
  [SMALL_STATE(15720)] = 648579,
  [SMALL_STATE(15721)] = 648595,
  [SMALL_STATE(15722)] = 648615,
  [SMALL_STATE(15723)] = 648635,
  [SMALL_STATE(15724)] = 648655,
  [SMALL_STATE(15725)] = 648671,
  [SMALL_STATE(15726)] = 648691,
  [SMALL_STATE(15727)] = 648711,
  [SMALL_STATE(15728)] = 648731,
  [SMALL_STATE(15729)] = 648747,
  [SMALL_STATE(15730)] = 648767,
  [SMALL_STATE(15731)] = 648783,
  [SMALL_STATE(15732)] = 648803,
  [SMALL_STATE(15733)] = 648819,
  [SMALL_STATE(15734)] = 648839,
  [SMALL_STATE(15735)] = 648859,
  [SMALL_STATE(15736)] = 648879,
  [SMALL_STATE(15737)] = 648899,
  [SMALL_STATE(15738)] = 648917,
  [SMALL_STATE(15739)] = 648937,
  [SMALL_STATE(15740)] = 648957,
  [SMALL_STATE(15741)] = 648977,
  [SMALL_STATE(15742)] = 648997,
  [SMALL_STATE(15743)] = 649017,
  [SMALL_STATE(15744)] = 649037,
  [SMALL_STATE(15745)] = 649057,
  [SMALL_STATE(15746)] = 649077,
  [SMALL_STATE(15747)] = 649095,
  [SMALL_STATE(15748)] = 649115,
  [SMALL_STATE(15749)] = 649135,
  [SMALL_STATE(15750)] = 649155,
  [SMALL_STATE(15751)] = 649175,
  [SMALL_STATE(15752)] = 649195,
  [SMALL_STATE(15753)] = 649215,
  [SMALL_STATE(15754)] = 649235,
  [SMALL_STATE(15755)] = 649255,
  [SMALL_STATE(15756)] = 649275,
  [SMALL_STATE(15757)] = 649295,
  [SMALL_STATE(15758)] = 649315,
  [SMALL_STATE(15759)] = 649335,
  [SMALL_STATE(15760)] = 649355,
  [SMALL_STATE(15761)] = 649375,
  [SMALL_STATE(15762)] = 649395,
  [SMALL_STATE(15763)] = 649415,
  [SMALL_STATE(15764)] = 649435,
  [SMALL_STATE(15765)] = 649455,
  [SMALL_STATE(15766)] = 649475,
  [SMALL_STATE(15767)] = 649495,
  [SMALL_STATE(15768)] = 649515,
  [SMALL_STATE(15769)] = 649535,
  [SMALL_STATE(15770)] = 649555,
  [SMALL_STATE(15771)] = 649575,
  [SMALL_STATE(15772)] = 649595,
  [SMALL_STATE(15773)] = 649615,
  [SMALL_STATE(15774)] = 649635,
  [SMALL_STATE(15775)] = 649655,
  [SMALL_STATE(15776)] = 649675,
  [SMALL_STATE(15777)] = 649695,
  [SMALL_STATE(15778)] = 649715,
  [SMALL_STATE(15779)] = 649733,
  [SMALL_STATE(15780)] = 649753,
  [SMALL_STATE(15781)] = 649773,
  [SMALL_STATE(15782)] = 649793,
  [SMALL_STATE(15783)] = 649813,
  [SMALL_STATE(15784)] = 649833,
  [SMALL_STATE(15785)] = 649853,
  [SMALL_STATE(15786)] = 649873,
  [SMALL_STATE(15787)] = 649893,
  [SMALL_STATE(15788)] = 649913,
  [SMALL_STATE(15789)] = 649933,
  [SMALL_STATE(15790)] = 649953,
  [SMALL_STATE(15791)] = 649973,
  [SMALL_STATE(15792)] = 649993,
  [SMALL_STATE(15793)] = 650013,
  [SMALL_STATE(15794)] = 650033,
  [SMALL_STATE(15795)] = 650053,
  [SMALL_STATE(15796)] = 650073,
  [SMALL_STATE(15797)] = 650093,
  [SMALL_STATE(15798)] = 650113,
  [SMALL_STATE(15799)] = 650133,
  [SMALL_STATE(15800)] = 650153,
  [SMALL_STATE(15801)] = 650173,
  [SMALL_STATE(15802)] = 650193,
  [SMALL_STATE(15803)] = 650213,
  [SMALL_STATE(15804)] = 650233,
  [SMALL_STATE(15805)] = 650253,
  [SMALL_STATE(15806)] = 650273,
  [SMALL_STATE(15807)] = 650293,
  [SMALL_STATE(15808)] = 650313,
  [SMALL_STATE(15809)] = 650333,
  [SMALL_STATE(15810)] = 650353,
  [SMALL_STATE(15811)] = 650373,
  [SMALL_STATE(15812)] = 650393,
  [SMALL_STATE(15813)] = 650413,
  [SMALL_STATE(15814)] = 650431,
  [SMALL_STATE(15815)] = 650451,
  [SMALL_STATE(15816)] = 650471,
  [SMALL_STATE(15817)] = 650491,
  [SMALL_STATE(15818)] = 650511,
  [SMALL_STATE(15819)] = 650531,
  [SMALL_STATE(15820)] = 650551,
  [SMALL_STATE(15821)] = 650571,
  [SMALL_STATE(15822)] = 650591,
  [SMALL_STATE(15823)] = 650611,
  [SMALL_STATE(15824)] = 650631,
  [SMALL_STATE(15825)] = 650651,
  [SMALL_STATE(15826)] = 650671,
  [SMALL_STATE(15827)] = 650691,
  [SMALL_STATE(15828)] = 650711,
  [SMALL_STATE(15829)] = 650731,
  [SMALL_STATE(15830)] = 650751,
  [SMALL_STATE(15831)] = 650771,
  [SMALL_STATE(15832)] = 650791,
  [SMALL_STATE(15833)] = 650811,
  [SMALL_STATE(15834)] = 650831,
  [SMALL_STATE(15835)] = 650851,
  [SMALL_STATE(15836)] = 650871,
  [SMALL_STATE(15837)] = 650891,
  [SMALL_STATE(15838)] = 650911,
  [SMALL_STATE(15839)] = 650931,
  [SMALL_STATE(15840)] = 650949,
  [SMALL_STATE(15841)] = 650967,
  [SMALL_STATE(15842)] = 650987,
  [SMALL_STATE(15843)] = 651007,
  [SMALL_STATE(15844)] = 651027,
  [SMALL_STATE(15845)] = 651047,
  [SMALL_STATE(15846)] = 651067,
  [SMALL_STATE(15847)] = 651087,
  [SMALL_STATE(15848)] = 651107,
  [SMALL_STATE(15849)] = 651127,
  [SMALL_STATE(15850)] = 651147,
  [SMALL_STATE(15851)] = 651167,
  [SMALL_STATE(15852)] = 651187,
  [SMALL_STATE(15853)] = 651207,
  [SMALL_STATE(15854)] = 651227,
  [SMALL_STATE(15855)] = 651247,
  [SMALL_STATE(15856)] = 651267,
  [SMALL_STATE(15857)] = 651287,
  [SMALL_STATE(15858)] = 651307,
  [SMALL_STATE(15859)] = 651327,
  [SMALL_STATE(15860)] = 651347,
  [SMALL_STATE(15861)] = 651367,
  [SMALL_STATE(15862)] = 651387,
  [SMALL_STATE(15863)] = 651407,
  [SMALL_STATE(15864)] = 651427,
  [SMALL_STATE(15865)] = 651447,
  [SMALL_STATE(15866)] = 651467,
  [SMALL_STATE(15867)] = 651487,
  [SMALL_STATE(15868)] = 651507,
  [SMALL_STATE(15869)] = 651527,
  [SMALL_STATE(15870)] = 651547,
  [SMALL_STATE(15871)] = 651567,
  [SMALL_STATE(15872)] = 651587,
  [SMALL_STATE(15873)] = 651607,
  [SMALL_STATE(15874)] = 651627,
  [SMALL_STATE(15875)] = 651647,
  [SMALL_STATE(15876)] = 651667,
  [SMALL_STATE(15877)] = 651687,
  [SMALL_STATE(15878)] = 651707,
  [SMALL_STATE(15879)] = 651725,
  [SMALL_STATE(15880)] = 651745,
  [SMALL_STATE(15881)] = 651765,
  [SMALL_STATE(15882)] = 651785,
  [SMALL_STATE(15883)] = 651805,
  [SMALL_STATE(15884)] = 651825,
  [SMALL_STATE(15885)] = 651843,
  [SMALL_STATE(15886)] = 651863,
  [SMALL_STATE(15887)] = 651883,
  [SMALL_STATE(15888)] = 651903,
  [SMALL_STATE(15889)] = 651923,
  [SMALL_STATE(15890)] = 651943,
  [SMALL_STATE(15891)] = 651963,
  [SMALL_STATE(15892)] = 651983,
  [SMALL_STATE(15893)] = 652003,
  [SMALL_STATE(15894)] = 652023,
  [SMALL_STATE(15895)] = 652043,
  [SMALL_STATE(15896)] = 652063,
  [SMALL_STATE(15897)] = 652083,
  [SMALL_STATE(15898)] = 652103,
  [SMALL_STATE(15899)] = 652123,
  [SMALL_STATE(15900)] = 652143,
  [SMALL_STATE(15901)] = 652163,
  [SMALL_STATE(15902)] = 652183,
  [SMALL_STATE(15903)] = 652203,
  [SMALL_STATE(15904)] = 652221,
  [SMALL_STATE(15905)] = 652241,
  [SMALL_STATE(15906)] = 652261,
  [SMALL_STATE(15907)] = 652281,
  [SMALL_STATE(15908)] = 652301,
  [SMALL_STATE(15909)] = 652321,
  [SMALL_STATE(15910)] = 652341,
  [SMALL_STATE(15911)] = 652361,
  [SMALL_STATE(15912)] = 652381,
  [SMALL_STATE(15913)] = 652401,
  [SMALL_STATE(15914)] = 652421,
  [SMALL_STATE(15915)] = 652441,
  [SMALL_STATE(15916)] = 652461,
  [SMALL_STATE(15917)] = 652481,
  [SMALL_STATE(15918)] = 652501,
  [SMALL_STATE(15919)] = 652521,
  [SMALL_STATE(15920)] = 652541,
  [SMALL_STATE(15921)] = 652561,
  [SMALL_STATE(15922)] = 652581,
  [SMALL_STATE(15923)] = 652601,
  [SMALL_STATE(15924)] = 652621,
  [SMALL_STATE(15925)] = 652641,
  [SMALL_STATE(15926)] = 652661,
  [SMALL_STATE(15927)] = 652681,
  [SMALL_STATE(15928)] = 652701,
  [SMALL_STATE(15929)] = 652721,
  [SMALL_STATE(15930)] = 652741,
  [SMALL_STATE(15931)] = 652761,
  [SMALL_STATE(15932)] = 652779,
  [SMALL_STATE(15933)] = 652799,
  [SMALL_STATE(15934)] = 652819,
  [SMALL_STATE(15935)] = 652837,
  [SMALL_STATE(15936)] = 652857,
  [SMALL_STATE(15937)] = 652877,
  [SMALL_STATE(15938)] = 652897,
  [SMALL_STATE(15939)] = 652917,
  [SMALL_STATE(15940)] = 652937,
  [SMALL_STATE(15941)] = 652957,
  [SMALL_STATE(15942)] = 652977,
  [SMALL_STATE(15943)] = 652997,
  [SMALL_STATE(15944)] = 653017,
  [SMALL_STATE(15945)] = 653037,
  [SMALL_STATE(15946)] = 653057,
  [SMALL_STATE(15947)] = 653077,
  [SMALL_STATE(15948)] = 653097,
  [SMALL_STATE(15949)] = 653117,
  [SMALL_STATE(15950)] = 653135,
  [SMALL_STATE(15951)] = 653155,
  [SMALL_STATE(15952)] = 653175,
  [SMALL_STATE(15953)] = 653195,
  [SMALL_STATE(15954)] = 653215,
  [SMALL_STATE(15955)] = 653235,
  [SMALL_STATE(15956)] = 653255,
  [SMALL_STATE(15957)] = 653275,
  [SMALL_STATE(15958)] = 653295,
  [SMALL_STATE(15959)] = 653315,
  [SMALL_STATE(15960)] = 653333,
  [SMALL_STATE(15961)] = 653351,
  [SMALL_STATE(15962)] = 653371,
  [SMALL_STATE(15963)] = 653389,
  [SMALL_STATE(15964)] = 653407,
  [SMALL_STATE(15965)] = 653425,
  [SMALL_STATE(15966)] = 653443,
  [SMALL_STATE(15967)] = 653461,
  [SMALL_STATE(15968)] = 653479,
  [SMALL_STATE(15969)] = 653497,
  [SMALL_STATE(15970)] = 653515,
  [SMALL_STATE(15971)] = 653533,
  [SMALL_STATE(15972)] = 653551,
  [SMALL_STATE(15973)] = 653569,
  [SMALL_STATE(15974)] = 653587,
  [SMALL_STATE(15975)] = 653605,
  [SMALL_STATE(15976)] = 653623,
  [SMALL_STATE(15977)] = 653641,
  [SMALL_STATE(15978)] = 653659,
  [SMALL_STATE(15979)] = 653677,
  [SMALL_STATE(15980)] = 653697,
  [SMALL_STATE(15981)] = 653717,
  [SMALL_STATE(15982)] = 653737,
  [SMALL_STATE(15983)] = 653757,
  [SMALL_STATE(15984)] = 653777,
  [SMALL_STATE(15985)] = 653797,
  [SMALL_STATE(15986)] = 653817,
  [SMALL_STATE(15987)] = 653837,
  [SMALL_STATE(15988)] = 653857,
  [SMALL_STATE(15989)] = 653877,
  [SMALL_STATE(15990)] = 653897,
  [SMALL_STATE(15991)] = 653917,
  [SMALL_STATE(15992)] = 653937,
  [SMALL_STATE(15993)] = 653957,
  [SMALL_STATE(15994)] = 653977,
  [SMALL_STATE(15995)] = 653997,
  [SMALL_STATE(15996)] = 654017,
  [SMALL_STATE(15997)] = 654037,
  [SMALL_STATE(15998)] = 654057,
  [SMALL_STATE(15999)] = 654075,
  [SMALL_STATE(16000)] = 654095,
  [SMALL_STATE(16001)] = 654115,
  [SMALL_STATE(16002)] = 654135,
  [SMALL_STATE(16003)] = 654155,
  [SMALL_STATE(16004)] = 654175,
  [SMALL_STATE(16005)] = 654195,
  [SMALL_STATE(16006)] = 654215,
  [SMALL_STATE(16007)] = 654235,
  [SMALL_STATE(16008)] = 654255,
  [SMALL_STATE(16009)] = 654275,
  [SMALL_STATE(16010)] = 654295,
  [SMALL_STATE(16011)] = 654313,
  [SMALL_STATE(16012)] = 654333,
  [SMALL_STATE(16013)] = 654353,
  [SMALL_STATE(16014)] = 654371,
  [SMALL_STATE(16015)] = 654391,
  [SMALL_STATE(16016)] = 654411,
  [SMALL_STATE(16017)] = 654431,
  [SMALL_STATE(16018)] = 654451,
  [SMALL_STATE(16019)] = 654471,
  [SMALL_STATE(16020)] = 654491,
  [SMALL_STATE(16021)] = 654511,
  [SMALL_STATE(16022)] = 654531,
  [SMALL_STATE(16023)] = 654551,
  [SMALL_STATE(16024)] = 654571,
  [SMALL_STATE(16025)] = 654591,
  [SMALL_STATE(16026)] = 654609,
  [SMALL_STATE(16027)] = 654627,
  [SMALL_STATE(16028)] = 654647,
  [SMALL_STATE(16029)] = 654667,
  [SMALL_STATE(16030)] = 654687,
  [SMALL_STATE(16031)] = 654707,
  [SMALL_STATE(16032)] = 654727,
  [SMALL_STATE(16033)] = 654745,
  [SMALL_STATE(16034)] = 654765,
  [SMALL_STATE(16035)] = 654785,
  [SMALL_STATE(16036)] = 654805,
  [SMALL_STATE(16037)] = 654825,
  [SMALL_STATE(16038)] = 654843,
  [SMALL_STATE(16039)] = 654863,
  [SMALL_STATE(16040)] = 654883,
  [SMALL_STATE(16041)] = 654903,
  [SMALL_STATE(16042)] = 654923,
  [SMALL_STATE(16043)] = 654943,
  [SMALL_STATE(16044)] = 654963,
  [SMALL_STATE(16045)] = 654983,
  [SMALL_STATE(16046)] = 655003,
  [SMALL_STATE(16047)] = 655023,
  [SMALL_STATE(16048)] = 655043,
  [SMALL_STATE(16049)] = 655063,
  [SMALL_STATE(16050)] = 655083,
  [SMALL_STATE(16051)] = 655103,
  [SMALL_STATE(16052)] = 655121,
  [SMALL_STATE(16053)] = 655139,
  [SMALL_STATE(16054)] = 655157,
  [SMALL_STATE(16055)] = 655175,
  [SMALL_STATE(16056)] = 655193,
  [SMALL_STATE(16057)] = 655211,
  [SMALL_STATE(16058)] = 655229,
  [SMALL_STATE(16059)] = 655247,
  [SMALL_STATE(16060)] = 655267,
  [SMALL_STATE(16061)] = 655287,
  [SMALL_STATE(16062)] = 655307,
  [SMALL_STATE(16063)] = 655327,
  [SMALL_STATE(16064)] = 655347,
  [SMALL_STATE(16065)] = 655367,
  [SMALL_STATE(16066)] = 655387,
  [SMALL_STATE(16067)] = 655407,
  [SMALL_STATE(16068)] = 655427,
  [SMALL_STATE(16069)] = 655445,
  [SMALL_STATE(16070)] = 655465,
  [SMALL_STATE(16071)] = 655485,
  [SMALL_STATE(16072)] = 655505,
  [SMALL_STATE(16073)] = 655525,
  [SMALL_STATE(16074)] = 655543,
  [SMALL_STATE(16075)] = 655563,
  [SMALL_STATE(16076)] = 655583,
  [SMALL_STATE(16077)] = 655603,
  [SMALL_STATE(16078)] = 655623,
  [SMALL_STATE(16079)] = 655643,
  [SMALL_STATE(16080)] = 655663,
  [SMALL_STATE(16081)] = 655683,
  [SMALL_STATE(16082)] = 655703,
  [SMALL_STATE(16083)] = 655723,
  [SMALL_STATE(16084)] = 655741,
  [SMALL_STATE(16085)] = 655761,
  [SMALL_STATE(16086)] = 655781,
  [SMALL_STATE(16087)] = 655801,
  [SMALL_STATE(16088)] = 655819,
  [SMALL_STATE(16089)] = 655839,
  [SMALL_STATE(16090)] = 655859,
  [SMALL_STATE(16091)] = 655879,
  [SMALL_STATE(16092)] = 655899,
  [SMALL_STATE(16093)] = 655919,
  [SMALL_STATE(16094)] = 655939,
  [SMALL_STATE(16095)] = 655959,
  [SMALL_STATE(16096)] = 655979,
  [SMALL_STATE(16097)] = 655999,
  [SMALL_STATE(16098)] = 656019,
  [SMALL_STATE(16099)] = 656037,
  [SMALL_STATE(16100)] = 656057,
  [SMALL_STATE(16101)] = 656075,
  [SMALL_STATE(16102)] = 656093,
  [SMALL_STATE(16103)] = 656113,
  [SMALL_STATE(16104)] = 656133,
  [SMALL_STATE(16105)] = 656151,
  [SMALL_STATE(16106)] = 656169,
  [SMALL_STATE(16107)] = 656187,
  [SMALL_STATE(16108)] = 656205,
  [SMALL_STATE(16109)] = 656223,
  [SMALL_STATE(16110)] = 656241,
  [SMALL_STATE(16111)] = 656259,
  [SMALL_STATE(16112)] = 656277,
  [SMALL_STATE(16113)] = 656297,
  [SMALL_STATE(16114)] = 656317,
  [SMALL_STATE(16115)] = 656337,
  [SMALL_STATE(16116)] = 656357,
  [SMALL_STATE(16117)] = 656377,
  [SMALL_STATE(16118)] = 656397,
  [SMALL_STATE(16119)] = 656417,
  [SMALL_STATE(16120)] = 656435,
  [SMALL_STATE(16121)] = 656455,
  [SMALL_STATE(16122)] = 656473,
  [SMALL_STATE(16123)] = 656493,
  [SMALL_STATE(16124)] = 656513,
  [SMALL_STATE(16125)] = 656533,
  [SMALL_STATE(16126)] = 656553,
  [SMALL_STATE(16127)] = 656573,
  [SMALL_STATE(16128)] = 656593,
  [SMALL_STATE(16129)] = 656613,
  [SMALL_STATE(16130)] = 656633,
  [SMALL_STATE(16131)] = 656651,
  [SMALL_STATE(16132)] = 656671,
  [SMALL_STATE(16133)] = 656691,
  [SMALL_STATE(16134)] = 656711,
  [SMALL_STATE(16135)] = 656731,
  [SMALL_STATE(16136)] = 656751,
  [SMALL_STATE(16137)] = 656771,
  [SMALL_STATE(16138)] = 656789,
  [SMALL_STATE(16139)] = 656809,
  [SMALL_STATE(16140)] = 656829,
  [SMALL_STATE(16141)] = 656849,
  [SMALL_STATE(16142)] = 656869,
  [SMALL_STATE(16143)] = 656889,
  [SMALL_STATE(16144)] = 656909,
  [SMALL_STATE(16145)] = 656929,
  [SMALL_STATE(16146)] = 656949,
  [SMALL_STATE(16147)] = 656969,
  [SMALL_STATE(16148)] = 656989,
  [SMALL_STATE(16149)] = 657009,
  [SMALL_STATE(16150)] = 657029,
  [SMALL_STATE(16151)] = 657049,
  [SMALL_STATE(16152)] = 657069,
  [SMALL_STATE(16153)] = 657087,
  [SMALL_STATE(16154)] = 657105,
  [SMALL_STATE(16155)] = 657123,
  [SMALL_STATE(16156)] = 657141,
  [SMALL_STATE(16157)] = 657159,
  [SMALL_STATE(16158)] = 657179,
  [SMALL_STATE(16159)] = 657199,
  [SMALL_STATE(16160)] = 657219,
  [SMALL_STATE(16161)] = 657239,
  [SMALL_STATE(16162)] = 657259,
  [SMALL_STATE(16163)] = 657277,
  [SMALL_STATE(16164)] = 657297,
  [SMALL_STATE(16165)] = 657317,
  [SMALL_STATE(16166)] = 657337,
  [SMALL_STATE(16167)] = 657357,
  [SMALL_STATE(16168)] = 657375,
  [SMALL_STATE(16169)] = 657395,
  [SMALL_STATE(16170)] = 657415,
  [SMALL_STATE(16171)] = 657435,
  [SMALL_STATE(16172)] = 657455,
  [SMALL_STATE(16173)] = 657475,
  [SMALL_STATE(16174)] = 657495,
  [SMALL_STATE(16175)] = 657515,
  [SMALL_STATE(16176)] = 657535,
  [SMALL_STATE(16177)] = 657555,
  [SMALL_STATE(16178)] = 657575,
  [SMALL_STATE(16179)] = 657595,
  [SMALL_STATE(16180)] = 657615,
  [SMALL_STATE(16181)] = 657635,
  [SMALL_STATE(16182)] = 657655,
  [SMALL_STATE(16183)] = 657675,
  [SMALL_STATE(16184)] = 657693,
  [SMALL_STATE(16185)] = 657713,
  [SMALL_STATE(16186)] = 657731,
  [SMALL_STATE(16187)] = 657751,
  [SMALL_STATE(16188)] = 657769,
  [SMALL_STATE(16189)] = 657789,
  [SMALL_STATE(16190)] = 657807,
  [SMALL_STATE(16191)] = 657825,
  [SMALL_STATE(16192)] = 657843,
  [SMALL_STATE(16193)] = 657863,
  [SMALL_STATE(16194)] = 657883,
  [SMALL_STATE(16195)] = 657903,
  [SMALL_STATE(16196)] = 657921,
  [SMALL_STATE(16197)] = 657941,
  [SMALL_STATE(16198)] = 657961,
  [SMALL_STATE(16199)] = 657981,
  [SMALL_STATE(16200)] = 658001,
  [SMALL_STATE(16201)] = 658021,
  [SMALL_STATE(16202)] = 658041,
  [SMALL_STATE(16203)] = 658061,
  [SMALL_STATE(16204)] = 658081,
  [SMALL_STATE(16205)] = 658101,
  [SMALL_STATE(16206)] = 658121,
  [SMALL_STATE(16207)] = 658141,
  [SMALL_STATE(16208)] = 658161,
  [SMALL_STATE(16209)] = 658181,
  [SMALL_STATE(16210)] = 658201,
  [SMALL_STATE(16211)] = 658221,
  [SMALL_STATE(16212)] = 658241,
  [SMALL_STATE(16213)] = 658261,
  [SMALL_STATE(16214)] = 658279,
  [SMALL_STATE(16215)] = 658297,
  [SMALL_STATE(16216)] = 658317,
  [SMALL_STATE(16217)] = 658337,
  [SMALL_STATE(16218)] = 658357,
  [SMALL_STATE(16219)] = 658375,
  [SMALL_STATE(16220)] = 658395,
  [SMALL_STATE(16221)] = 658415,
  [SMALL_STATE(16222)] = 658435,
  [SMALL_STATE(16223)] = 658455,
  [SMALL_STATE(16224)] = 658475,
  [SMALL_STATE(16225)] = 658495,
  [SMALL_STATE(16226)] = 658513,
  [SMALL_STATE(16227)] = 658531,
  [SMALL_STATE(16228)] = 658549,
  [SMALL_STATE(16229)] = 658569,
  [SMALL_STATE(16230)] = 658589,
  [SMALL_STATE(16231)] = 658609,
  [SMALL_STATE(16232)] = 658629,
  [SMALL_STATE(16233)] = 658649,
  [SMALL_STATE(16234)] = 658669,
  [SMALL_STATE(16235)] = 658689,
  [SMALL_STATE(16236)] = 658709,
  [SMALL_STATE(16237)] = 658729,
  [SMALL_STATE(16238)] = 658749,
  [SMALL_STATE(16239)] = 658769,
  [SMALL_STATE(16240)] = 658789,
  [SMALL_STATE(16241)] = 658809,
  [SMALL_STATE(16242)] = 658827,
  [SMALL_STATE(16243)] = 658847,
  [SMALL_STATE(16244)] = 658865,
  [SMALL_STATE(16245)] = 658885,
  [SMALL_STATE(16246)] = 658905,
  [SMALL_STATE(16247)] = 658925,
  [SMALL_STATE(16248)] = 658945,
  [SMALL_STATE(16249)] = 658965,
  [SMALL_STATE(16250)] = 658985,
  [SMALL_STATE(16251)] = 659005,
  [SMALL_STATE(16252)] = 659025,
  [SMALL_STATE(16253)] = 659045,
  [SMALL_STATE(16254)] = 659065,
  [SMALL_STATE(16255)] = 659085,
  [SMALL_STATE(16256)] = 659103,
  [SMALL_STATE(16257)] = 659123,
  [SMALL_STATE(16258)] = 659141,
  [SMALL_STATE(16259)] = 659161,
  [SMALL_STATE(16260)] = 659181,
  [SMALL_STATE(16261)] = 659199,
  [SMALL_STATE(16262)] = 659219,
  [SMALL_STATE(16263)] = 659239,
  [SMALL_STATE(16264)] = 659259,
  [SMALL_STATE(16265)] = 659277,
  [SMALL_STATE(16266)] = 659297,
  [SMALL_STATE(16267)] = 659317,
  [SMALL_STATE(16268)] = 659337,
  [SMALL_STATE(16269)] = 659355,
  [SMALL_STATE(16270)] = 659375,
  [SMALL_STATE(16271)] = 659395,
  [SMALL_STATE(16272)] = 659415,
  [SMALL_STATE(16273)] = 659433,
  [SMALL_STATE(16274)] = 659453,
  [SMALL_STATE(16275)] = 659473,
  [SMALL_STATE(16276)] = 659493,
  [SMALL_STATE(16277)] = 659513,
  [SMALL_STATE(16278)] = 659533,
  [SMALL_STATE(16279)] = 659553,
  [SMALL_STATE(16280)] = 659573,
  [SMALL_STATE(16281)] = 659593,
  [SMALL_STATE(16282)] = 659613,
  [SMALL_STATE(16283)] = 659633,
  [SMALL_STATE(16284)] = 659651,
  [SMALL_STATE(16285)] = 659671,
  [SMALL_STATE(16286)] = 659691,
  [SMALL_STATE(16287)] = 659711,
  [SMALL_STATE(16288)] = 659729,
  [SMALL_STATE(16289)] = 659749,
  [SMALL_STATE(16290)] = 659769,
  [SMALL_STATE(16291)] = 659789,
  [SMALL_STATE(16292)] = 659809,
  [SMALL_STATE(16293)] = 659829,
  [SMALL_STATE(16294)] = 659849,
  [SMALL_STATE(16295)] = 659869,
  [SMALL_STATE(16296)] = 659889,
  [SMALL_STATE(16297)] = 659907,
  [SMALL_STATE(16298)] = 659927,
  [SMALL_STATE(16299)] = 659947,
  [SMALL_STATE(16300)] = 659967,
  [SMALL_STATE(16301)] = 659987,
  [SMALL_STATE(16302)] = 660005,
  [SMALL_STATE(16303)] = 660025,
  [SMALL_STATE(16304)] = 660045,
  [SMALL_STATE(16305)] = 660065,
  [SMALL_STATE(16306)] = 660085,
  [SMALL_STATE(16307)] = 660105,
  [SMALL_STATE(16308)] = 660125,
  [SMALL_STATE(16309)] = 660145,
  [SMALL_STATE(16310)] = 660165,
  [SMALL_STATE(16311)] = 660183,
  [SMALL_STATE(16312)] = 660203,
  [SMALL_STATE(16313)] = 660223,
  [SMALL_STATE(16314)] = 660243,
  [SMALL_STATE(16315)] = 660263,
  [SMALL_STATE(16316)] = 660283,
  [SMALL_STATE(16317)] = 660303,
  [SMALL_STATE(16318)] = 660323,
  [SMALL_STATE(16319)] = 660341,
  [SMALL_STATE(16320)] = 660361,
  [SMALL_STATE(16321)] = 660381,
  [SMALL_STATE(16322)] = 660401,
  [SMALL_STATE(16323)] = 660421,
  [SMALL_STATE(16324)] = 660441,
  [SMALL_STATE(16325)] = 660459,
  [SMALL_STATE(16326)] = 660477,
  [SMALL_STATE(16327)] = 660497,
  [SMALL_STATE(16328)] = 660517,
  [SMALL_STATE(16329)] = 660535,
  [SMALL_STATE(16330)] = 660555,
  [SMALL_STATE(16331)] = 660575,
  [SMALL_STATE(16332)] = 660595,
  [SMALL_STATE(16333)] = 660615,
  [SMALL_STATE(16334)] = 660635,
  [SMALL_STATE(16335)] = 660655,
  [SMALL_STATE(16336)] = 660673,
  [SMALL_STATE(16337)] = 660693,
  [SMALL_STATE(16338)] = 660713,
  [SMALL_STATE(16339)] = 660733,
  [SMALL_STATE(16340)] = 660753,
  [SMALL_STATE(16341)] = 660773,
  [SMALL_STATE(16342)] = 660793,
  [SMALL_STATE(16343)] = 660813,
  [SMALL_STATE(16344)] = 660833,
  [SMALL_STATE(16345)] = 660853,
  [SMALL_STATE(16346)] = 660873,
  [SMALL_STATE(16347)] = 660893,
  [SMALL_STATE(16348)] = 660913,
  [SMALL_STATE(16349)] = 660933,
  [SMALL_STATE(16350)] = 660953,
  [SMALL_STATE(16351)] = 660973,
  [SMALL_STATE(16352)] = 660991,
  [SMALL_STATE(16353)] = 661009,
  [SMALL_STATE(16354)] = 661027,
  [SMALL_STATE(16355)] = 661047,
  [SMALL_STATE(16356)] = 661067,
  [SMALL_STATE(16357)] = 661087,
  [SMALL_STATE(16358)] = 661107,
  [SMALL_STATE(16359)] = 661127,
  [SMALL_STATE(16360)] = 661147,
  [SMALL_STATE(16361)] = 661167,
  [SMALL_STATE(16362)] = 661187,
  [SMALL_STATE(16363)] = 661207,
  [SMALL_STATE(16364)] = 661225,
  [SMALL_STATE(16365)] = 661245,
  [SMALL_STATE(16366)] = 661265,
  [SMALL_STATE(16367)] = 661285,
  [SMALL_STATE(16368)] = 661305,
  [SMALL_STATE(16369)] = 661325,
  [SMALL_STATE(16370)] = 661345,
  [SMALL_STATE(16371)] = 661365,
  [SMALL_STATE(16372)] = 661385,
  [SMALL_STATE(16373)] = 661405,
  [SMALL_STATE(16374)] = 661425,
  [SMALL_STATE(16375)] = 661445,
  [SMALL_STATE(16376)] = 661465,
  [SMALL_STATE(16377)] = 661485,
  [SMALL_STATE(16378)] = 661505,
  [SMALL_STATE(16379)] = 661525,
  [SMALL_STATE(16380)] = 661543,
  [SMALL_STATE(16381)] = 661563,
  [SMALL_STATE(16382)] = 661581,
  [SMALL_STATE(16383)] = 661601,
  [SMALL_STATE(16384)] = 661616,
  [SMALL_STATE(16385)] = 661631,
  [SMALL_STATE(16386)] = 661648,
  [SMALL_STATE(16387)] = 661663,
  [SMALL_STATE(16388)] = 661678,
  [SMALL_STATE(16389)] = 661693,
  [SMALL_STATE(16390)] = 661708,
  [SMALL_STATE(16391)] = 661723,
  [SMALL_STATE(16392)] = 661740,
  [SMALL_STATE(16393)] = 661755,
  [SMALL_STATE(16394)] = 661770,
  [SMALL_STATE(16395)] = 661785,
  [SMALL_STATE(16396)] = 661802,
  [SMALL_STATE(16397)] = 661819,
  [SMALL_STATE(16398)] = 661834,
  [SMALL_STATE(16399)] = 661849,
  [SMALL_STATE(16400)] = 661864,
  [SMALL_STATE(16401)] = 661881,
  [SMALL_STATE(16402)] = 661896,
  [SMALL_STATE(16403)] = 661911,
  [SMALL_STATE(16404)] = 661926,
  [SMALL_STATE(16405)] = 661941,
  [SMALL_STATE(16406)] = 661958,
  [SMALL_STATE(16407)] = 661973,
  [SMALL_STATE(16408)] = 661988,
  [SMALL_STATE(16409)] = 662005,
  [SMALL_STATE(16410)] = 662020,
  [SMALL_STATE(16411)] = 662035,
  [SMALL_STATE(16412)] = 662050,
  [SMALL_STATE(16413)] = 662067,
  [SMALL_STATE(16414)] = 662082,
  [SMALL_STATE(16415)] = 662097,
  [SMALL_STATE(16416)] = 662112,
  [SMALL_STATE(16417)] = 662127,
  [SMALL_STATE(16418)] = 662142,
  [SMALL_STATE(16419)] = 662157,
  [SMALL_STATE(16420)] = 662172,
  [SMALL_STATE(16421)] = 662187,
  [SMALL_STATE(16422)] = 662204,
  [SMALL_STATE(16423)] = 662221,
  [SMALL_STATE(16424)] = 662236,
  [SMALL_STATE(16425)] = 662253,
  [SMALL_STATE(16426)] = 662268,
  [SMALL_STATE(16427)] = 662283,
  [SMALL_STATE(16428)] = 662298,
  [SMALL_STATE(16429)] = 662313,
  [SMALL_STATE(16430)] = 662328,
  [SMALL_STATE(16431)] = 662343,
  [SMALL_STATE(16432)] = 662358,
  [SMALL_STATE(16433)] = 662375,
  [SMALL_STATE(16434)] = 662390,
  [SMALL_STATE(16435)] = 662405,
  [SMALL_STATE(16436)] = 662422,
  [SMALL_STATE(16437)] = 662439,
  [SMALL_STATE(16438)] = 662454,
  [SMALL_STATE(16439)] = 662469,
  [SMALL_STATE(16440)] = 662484,
  [SMALL_STATE(16441)] = 662499,
  [SMALL_STATE(16442)] = 662516,
  [SMALL_STATE(16443)] = 662531,
  [SMALL_STATE(16444)] = 662546,
  [SMALL_STATE(16445)] = 662561,
  [SMALL_STATE(16446)] = 662576,
  [SMALL_STATE(16447)] = 662591,
  [SMALL_STATE(16448)] = 662608,
  [SMALL_STATE(16449)] = 662623,
  [SMALL_STATE(16450)] = 662638,
  [SMALL_STATE(16451)] = 662653,
  [SMALL_STATE(16452)] = 662670,
  [SMALL_STATE(16453)] = 662687,
  [SMALL_STATE(16454)] = 662702,
  [SMALL_STATE(16455)] = 662717,
  [SMALL_STATE(16456)] = 662732,
  [SMALL_STATE(16457)] = 662749,
  [SMALL_STATE(16458)] = 662764,
  [SMALL_STATE(16459)] = 662779,
  [SMALL_STATE(16460)] = 662794,
  [SMALL_STATE(16461)] = 662809,
  [SMALL_STATE(16462)] = 662826,
  [SMALL_STATE(16463)] = 662841,
  [SMALL_STATE(16464)] = 662856,
  [SMALL_STATE(16465)] = 662871,
  [SMALL_STATE(16466)] = 662886,
  [SMALL_STATE(16467)] = 662901,
  [SMALL_STATE(16468)] = 662916,
  [SMALL_STATE(16469)] = 662931,
  [SMALL_STATE(16470)] = 662948,
  [SMALL_STATE(16471)] = 662963,
  [SMALL_STATE(16472)] = 662978,
  [SMALL_STATE(16473)] = 662995,
  [SMALL_STATE(16474)] = 663010,
  [SMALL_STATE(16475)] = 663025,
  [SMALL_STATE(16476)] = 663040,
  [SMALL_STATE(16477)] = 663055,
  [SMALL_STATE(16478)] = 663072,
  [SMALL_STATE(16479)] = 663089,
  [SMALL_STATE(16480)] = 663104,
  [SMALL_STATE(16481)] = 663119,
  [SMALL_STATE(16482)] = 663134,
  [SMALL_STATE(16483)] = 663149,
  [SMALL_STATE(16484)] = 663164,
  [SMALL_STATE(16485)] = 663179,
  [SMALL_STATE(16486)] = 663196,
  [SMALL_STATE(16487)] = 663211,
  [SMALL_STATE(16488)] = 663226,
  [SMALL_STATE(16489)] = 663243,
  [SMALL_STATE(16490)] = 663258,
  [SMALL_STATE(16491)] = 663273,
  [SMALL_STATE(16492)] = 663288,
  [SMALL_STATE(16493)] = 663305,
  [SMALL_STATE(16494)] = 663320,
  [SMALL_STATE(16495)] = 663337,
  [SMALL_STATE(16496)] = 663352,
  [SMALL_STATE(16497)] = 663367,
  [SMALL_STATE(16498)] = 663382,
  [SMALL_STATE(16499)] = 663397,
  [SMALL_STATE(16500)] = 663412,
  [SMALL_STATE(16501)] = 663427,
  [SMALL_STATE(16502)] = 663444,
  [SMALL_STATE(16503)] = 663461,
  [SMALL_STATE(16504)] = 663476,
  [SMALL_STATE(16505)] = 663491,
  [SMALL_STATE(16506)] = 663508,
  [SMALL_STATE(16507)] = 663523,
  [SMALL_STATE(16508)] = 663538,
  [SMALL_STATE(16509)] = 663553,
  [SMALL_STATE(16510)] = 663568,
  [SMALL_STATE(16511)] = 663583,
  [SMALL_STATE(16512)] = 663598,
  [SMALL_STATE(16513)] = 663613,
  [SMALL_STATE(16514)] = 663630,
  [SMALL_STATE(16515)] = 663645,
  [SMALL_STATE(16516)] = 663660,
  [SMALL_STATE(16517)] = 663677,
  [SMALL_STATE(16518)] = 663692,
  [SMALL_STATE(16519)] = 663707,
  [SMALL_STATE(16520)] = 663724,
  [SMALL_STATE(16521)] = 663739,
  [SMALL_STATE(16522)] = 663754,
  [SMALL_STATE(16523)] = 663769,
  [SMALL_STATE(16524)] = 663784,
  [SMALL_STATE(16525)] = 663801,
  [SMALL_STATE(16526)] = 663818,
  [SMALL_STATE(16527)] = 663833,
  [SMALL_STATE(16528)] = 663848,
  [SMALL_STATE(16529)] = 663863,
  [SMALL_STATE(16530)] = 663878,
  [SMALL_STATE(16531)] = 663893,
  [SMALL_STATE(16532)] = 663908,
  [SMALL_STATE(16533)] = 663925,
  [SMALL_STATE(16534)] = 663942,
  [SMALL_STATE(16535)] = 663957,
  [SMALL_STATE(16536)] = 663972,
  [SMALL_STATE(16537)] = 663987,
  [SMALL_STATE(16538)] = 664002,
  [SMALL_STATE(16539)] = 664017,
  [SMALL_STATE(16540)] = 664032,
  [SMALL_STATE(16541)] = 664047,
  [SMALL_STATE(16542)] = 664062,
  [SMALL_STATE(16543)] = 664079,
  [SMALL_STATE(16544)] = 664094,
  [SMALL_STATE(16545)] = 664109,
  [SMALL_STATE(16546)] = 664124,
  [SMALL_STATE(16547)] = 664139,
  [SMALL_STATE(16548)] = 664154,
  [SMALL_STATE(16549)] = 664171,
  [SMALL_STATE(16550)] = 664188,
  [SMALL_STATE(16551)] = 664203,
  [SMALL_STATE(16552)] = 664218,
  [SMALL_STATE(16553)] = 664233,
  [SMALL_STATE(16554)] = 664248,
  [SMALL_STATE(16555)] = 664263,
  [SMALL_STATE(16556)] = 664278,
  [SMALL_STATE(16557)] = 664293,
  [SMALL_STATE(16558)] = 664308,
  [SMALL_STATE(16559)] = 664325,
  [SMALL_STATE(16560)] = 664342,
  [SMALL_STATE(16561)] = 664357,
  [SMALL_STATE(16562)] = 664374,
  [SMALL_STATE(16563)] = 664391,
  [SMALL_STATE(16564)] = 664408,
  [SMALL_STATE(16565)] = 664423,
  [SMALL_STATE(16566)] = 664438,
  [SMALL_STATE(16567)] = 664453,
  [SMALL_STATE(16568)] = 664470,
  [SMALL_STATE(16569)] = 664485,
  [SMALL_STATE(16570)] = 664500,
  [SMALL_STATE(16571)] = 664517,
  [SMALL_STATE(16572)] = 664534,
  [SMALL_STATE(16573)] = 664551,
  [SMALL_STATE(16574)] = 664566,
  [SMALL_STATE(16575)] = 664581,
  [SMALL_STATE(16576)] = 664596,
  [SMALL_STATE(16577)] = 664611,
  [SMALL_STATE(16578)] = 664626,
  [SMALL_STATE(16579)] = 664641,
  [SMALL_STATE(16580)] = 664656,
  [SMALL_STATE(16581)] = 664671,
  [SMALL_STATE(16582)] = 664686,
  [SMALL_STATE(16583)] = 664701,
  [SMALL_STATE(16584)] = 664716,
  [SMALL_STATE(16585)] = 664731,
  [SMALL_STATE(16586)] = 664746,
  [SMALL_STATE(16587)] = 664763,
  [SMALL_STATE(16588)] = 664778,
  [SMALL_STATE(16589)] = 664793,
  [SMALL_STATE(16590)] = 664808,
  [SMALL_STATE(16591)] = 664823,
  [SMALL_STATE(16592)] = 664838,
  [SMALL_STATE(16593)] = 664853,
  [SMALL_STATE(16594)] = 664868,
  [SMALL_STATE(16595)] = 664883,
  [SMALL_STATE(16596)] = 664898,
  [SMALL_STATE(16597)] = 664913,
  [SMALL_STATE(16598)] = 664928,
  [SMALL_STATE(16599)] = 664943,
  [SMALL_STATE(16600)] = 664958,
  [SMALL_STATE(16601)] = 664975,
  [SMALL_STATE(16602)] = 664990,
  [SMALL_STATE(16603)] = 665005,
  [SMALL_STATE(16604)] = 665020,
  [SMALL_STATE(16605)] = 665035,
  [SMALL_STATE(16606)] = 665050,
  [SMALL_STATE(16607)] = 665065,
  [SMALL_STATE(16608)] = 665080,
  [SMALL_STATE(16609)] = 665095,
  [SMALL_STATE(16610)] = 665110,
  [SMALL_STATE(16611)] = 665125,
  [SMALL_STATE(16612)] = 665140,
  [SMALL_STATE(16613)] = 665155,
  [SMALL_STATE(16614)] = 665170,
  [SMALL_STATE(16615)] = 665185,
  [SMALL_STATE(16616)] = 665200,
  [SMALL_STATE(16617)] = 665217,
  [SMALL_STATE(16618)] = 665232,
  [SMALL_STATE(16619)] = 665247,
  [SMALL_STATE(16620)] = 665262,
  [SMALL_STATE(16621)] = 665277,
  [SMALL_STATE(16622)] = 665292,
  [SMALL_STATE(16623)] = 665307,
  [SMALL_STATE(16624)] = 665322,
  [SMALL_STATE(16625)] = 665337,
  [SMALL_STATE(16626)] = 665352,
  [SMALL_STATE(16627)] = 665367,
  [SMALL_STATE(16628)] = 665382,
  [SMALL_STATE(16629)] = 665397,
  [SMALL_STATE(16630)] = 665412,
  [SMALL_STATE(16631)] = 665427,
  [SMALL_STATE(16632)] = 665442,
  [SMALL_STATE(16633)] = 665457,
  [SMALL_STATE(16634)] = 665472,
  [SMALL_STATE(16635)] = 665487,
  [SMALL_STATE(16636)] = 665502,
  [SMALL_STATE(16637)] = 665517,
  [SMALL_STATE(16638)] = 665532,
  [SMALL_STATE(16639)] = 665547,
  [SMALL_STATE(16640)] = 665562,
  [SMALL_STATE(16641)] = 665577,
  [SMALL_STATE(16642)] = 665594,
  [SMALL_STATE(16643)] = 665609,
  [SMALL_STATE(16644)] = 665624,
  [SMALL_STATE(16645)] = 665639,
  [SMALL_STATE(16646)] = 665654,
  [SMALL_STATE(16647)] = 665669,
  [SMALL_STATE(16648)] = 665686,
  [SMALL_STATE(16649)] = 665701,
  [SMALL_STATE(16650)] = 665718,
  [SMALL_STATE(16651)] = 665733,
  [SMALL_STATE(16652)] = 665748,
  [SMALL_STATE(16653)] = 665763,
  [SMALL_STATE(16654)] = 665778,
  [SMALL_STATE(16655)] = 665793,
  [SMALL_STATE(16656)] = 665808,
  [SMALL_STATE(16657)] = 665823,
  [SMALL_STATE(16658)] = 665838,
  [SMALL_STATE(16659)] = 665853,
  [SMALL_STATE(16660)] = 665868,
  [SMALL_STATE(16661)] = 665885,
  [SMALL_STATE(16662)] = 665900,
  [SMALL_STATE(16663)] = 665915,
  [SMALL_STATE(16664)] = 665932,
  [SMALL_STATE(16665)] = 665947,
  [SMALL_STATE(16666)] = 665964,
  [SMALL_STATE(16667)] = 665979,
  [SMALL_STATE(16668)] = 665994,
  [SMALL_STATE(16669)] = 666009,
  [SMALL_STATE(16670)] = 666026,
  [SMALL_STATE(16671)] = 666041,
  [SMALL_STATE(16672)] = 666056,
  [SMALL_STATE(16673)] = 666073,
  [SMALL_STATE(16674)] = 666088,
  [SMALL_STATE(16675)] = 666103,
  [SMALL_STATE(16676)] = 666118,
  [SMALL_STATE(16677)] = 666133,
  [SMALL_STATE(16678)] = 666150,
  [SMALL_STATE(16679)] = 666167,
  [SMALL_STATE(16680)] = 666184,
  [SMALL_STATE(16681)] = 666199,
  [SMALL_STATE(16682)] = 666214,
  [SMALL_STATE(16683)] = 666229,
  [SMALL_STATE(16684)] = 666244,
  [SMALL_STATE(16685)] = 666259,
  [SMALL_STATE(16686)] = 666272,
  [SMALL_STATE(16687)] = 666287,
  [SMALL_STATE(16688)] = 666304,
  [SMALL_STATE(16689)] = 666318,
  [SMALL_STATE(16690)] = 666332,
  [SMALL_STATE(16691)] = 666346,
  [SMALL_STATE(16692)] = 666360,
  [SMALL_STATE(16693)] = 666374,
  [SMALL_STATE(16694)] = 666388,
  [SMALL_STATE(16695)] = 666402,
  [SMALL_STATE(16696)] = 666416,
  [SMALL_STATE(16697)] = 666430,
  [SMALL_STATE(16698)] = 666444,
  [SMALL_STATE(16699)] = 666458,
  [SMALL_STATE(16700)] = 666472,
  [SMALL_STATE(16701)] = 666486,
  [SMALL_STATE(16702)] = 666500,
  [SMALL_STATE(16703)] = 666514,
  [SMALL_STATE(16704)] = 666528,
  [SMALL_STATE(16705)] = 666542,
  [SMALL_STATE(16706)] = 666556,
  [SMALL_STATE(16707)] = 666570,
  [SMALL_STATE(16708)] = 666584,
  [SMALL_STATE(16709)] = 666598,
  [SMALL_STATE(16710)] = 666612,
  [SMALL_STATE(16711)] = 666626,
  [SMALL_STATE(16712)] = 666640,
  [SMALL_STATE(16713)] = 666654,
  [SMALL_STATE(16714)] = 666668,
  [SMALL_STATE(16715)] = 666682,
  [SMALL_STATE(16716)] = 666696,
  [SMALL_STATE(16717)] = 666710,
  [SMALL_STATE(16718)] = 666724,
  [SMALL_STATE(16719)] = 666738,
  [SMALL_STATE(16720)] = 666752,
  [SMALL_STATE(16721)] = 666766,
  [SMALL_STATE(16722)] = 666780,
  [SMALL_STATE(16723)] = 666794,
  [SMALL_STATE(16724)] = 666808,
  [SMALL_STATE(16725)] = 666822,
  [SMALL_STATE(16726)] = 666836,
  [SMALL_STATE(16727)] = 666850,
  [SMALL_STATE(16728)] = 666864,
  [SMALL_STATE(16729)] = 666878,
  [SMALL_STATE(16730)] = 666892,
  [SMALL_STATE(16731)] = 666906,
  [SMALL_STATE(16732)] = 666920,
  [SMALL_STATE(16733)] = 666934,
  [SMALL_STATE(16734)] = 666948,
  [SMALL_STATE(16735)] = 666962,
  [SMALL_STATE(16736)] = 666976,
  [SMALL_STATE(16737)] = 666990,
  [SMALL_STATE(16738)] = 667004,
  [SMALL_STATE(16739)] = 667018,
  [SMALL_STATE(16740)] = 667032,
  [SMALL_STATE(16741)] = 667046,
  [SMALL_STATE(16742)] = 667060,
  [SMALL_STATE(16743)] = 667074,
  [SMALL_STATE(16744)] = 667088,
  [SMALL_STATE(16745)] = 667102,
  [SMALL_STATE(16746)] = 667116,
  [SMALL_STATE(16747)] = 667130,
  [SMALL_STATE(16748)] = 667144,
  [SMALL_STATE(16749)] = 667158,
  [SMALL_STATE(16750)] = 667172,
  [SMALL_STATE(16751)] = 667186,
  [SMALL_STATE(16752)] = 667200,
  [SMALL_STATE(16753)] = 667214,
  [SMALL_STATE(16754)] = 667228,
  [SMALL_STATE(16755)] = 667242,
  [SMALL_STATE(16756)] = 667256,
  [SMALL_STATE(16757)] = 667270,
  [SMALL_STATE(16758)] = 667284,
  [SMALL_STATE(16759)] = 667298,
  [SMALL_STATE(16760)] = 667312,
  [SMALL_STATE(16761)] = 667326,
  [SMALL_STATE(16762)] = 667340,
  [SMALL_STATE(16763)] = 667354,
  [SMALL_STATE(16764)] = 667368,
  [SMALL_STATE(16765)] = 667382,
  [SMALL_STATE(16766)] = 667396,
  [SMALL_STATE(16767)] = 667410,
  [SMALL_STATE(16768)] = 667424,
  [SMALL_STATE(16769)] = 667438,
  [SMALL_STATE(16770)] = 667452,
  [SMALL_STATE(16771)] = 667466,
  [SMALL_STATE(16772)] = 667480,
  [SMALL_STATE(16773)] = 667494,
  [SMALL_STATE(16774)] = 667508,
  [SMALL_STATE(16775)] = 667522,
  [SMALL_STATE(16776)] = 667536,
  [SMALL_STATE(16777)] = 667550,
  [SMALL_STATE(16778)] = 667564,
  [SMALL_STATE(16779)] = 667578,
  [SMALL_STATE(16780)] = 667592,
  [SMALL_STATE(16781)] = 667606,
  [SMALL_STATE(16782)] = 667620,
  [SMALL_STATE(16783)] = 667634,
  [SMALL_STATE(16784)] = 667648,
  [SMALL_STATE(16785)] = 667662,
  [SMALL_STATE(16786)] = 667676,
  [SMALL_STATE(16787)] = 667690,
  [SMALL_STATE(16788)] = 667704,
  [SMALL_STATE(16789)] = 667718,
  [SMALL_STATE(16790)] = 667732,
  [SMALL_STATE(16791)] = 667746,
  [SMALL_STATE(16792)] = 667760,
  [SMALL_STATE(16793)] = 667774,
  [SMALL_STATE(16794)] = 667788,
  [SMALL_STATE(16795)] = 667802,
  [SMALL_STATE(16796)] = 667816,
  [SMALL_STATE(16797)] = 667830,
  [SMALL_STATE(16798)] = 667844,
  [SMALL_STATE(16799)] = 667858,
  [SMALL_STATE(16800)] = 667872,
  [SMALL_STATE(16801)] = 667886,
  [SMALL_STATE(16802)] = 667900,
  [SMALL_STATE(16803)] = 667914,
  [SMALL_STATE(16804)] = 667928,
  [SMALL_STATE(16805)] = 667942,
  [SMALL_STATE(16806)] = 667956,
  [SMALL_STATE(16807)] = 667970,
  [SMALL_STATE(16808)] = 667984,
  [SMALL_STATE(16809)] = 667998,
  [SMALL_STATE(16810)] = 668012,
  [SMALL_STATE(16811)] = 668026,
  [SMALL_STATE(16812)] = 668040,
  [SMALL_STATE(16813)] = 668054,
  [SMALL_STATE(16814)] = 668068,
  [SMALL_STATE(16815)] = 668082,
  [SMALL_STATE(16816)] = 668096,
  [SMALL_STATE(16817)] = 668110,
  [SMALL_STATE(16818)] = 668124,
  [SMALL_STATE(16819)] = 668138,
  [SMALL_STATE(16820)] = 668152,
  [SMALL_STATE(16821)] = 668166,
  [SMALL_STATE(16822)] = 668180,
  [SMALL_STATE(16823)] = 668194,
  [SMALL_STATE(16824)] = 668208,
  [SMALL_STATE(16825)] = 668222,
  [SMALL_STATE(16826)] = 668236,
  [SMALL_STATE(16827)] = 668250,
  [SMALL_STATE(16828)] = 668264,
  [SMALL_STATE(16829)] = 668278,
  [SMALL_STATE(16830)] = 668292,
  [SMALL_STATE(16831)] = 668306,
  [SMALL_STATE(16832)] = 668320,
  [SMALL_STATE(16833)] = 668334,
  [SMALL_STATE(16834)] = 668348,
  [SMALL_STATE(16835)] = 668362,
  [SMALL_STATE(16836)] = 668376,
  [SMALL_STATE(16837)] = 668390,
  [SMALL_STATE(16838)] = 668404,
  [SMALL_STATE(16839)] = 668418,
  [SMALL_STATE(16840)] = 668432,
  [SMALL_STATE(16841)] = 668446,
  [SMALL_STATE(16842)] = 668460,
  [SMALL_STATE(16843)] = 668474,
  [SMALL_STATE(16844)] = 668488,
  [SMALL_STATE(16845)] = 668502,
  [SMALL_STATE(16846)] = 668516,
  [SMALL_STATE(16847)] = 668530,
  [SMALL_STATE(16848)] = 668544,
  [SMALL_STATE(16849)] = 668558,
  [SMALL_STATE(16850)] = 668572,
  [SMALL_STATE(16851)] = 668586,
  [SMALL_STATE(16852)] = 668600,
  [SMALL_STATE(16853)] = 668614,
  [SMALL_STATE(16854)] = 668628,
  [SMALL_STATE(16855)] = 668642,
  [SMALL_STATE(16856)] = 668656,
  [SMALL_STATE(16857)] = 668670,
  [SMALL_STATE(16858)] = 668684,
  [SMALL_STATE(16859)] = 668698,
  [SMALL_STATE(16860)] = 668712,
  [SMALL_STATE(16861)] = 668726,
  [SMALL_STATE(16862)] = 668740,
  [SMALL_STATE(16863)] = 668754,
  [SMALL_STATE(16864)] = 668768,
  [SMALL_STATE(16865)] = 668782,
  [SMALL_STATE(16866)] = 668796,
  [SMALL_STATE(16867)] = 668810,
  [SMALL_STATE(16868)] = 668824,
  [SMALL_STATE(16869)] = 668838,
  [SMALL_STATE(16870)] = 668852,
  [SMALL_STATE(16871)] = 668866,
  [SMALL_STATE(16872)] = 668880,
  [SMALL_STATE(16873)] = 668894,
  [SMALL_STATE(16874)] = 668908,
  [SMALL_STATE(16875)] = 668922,
  [SMALL_STATE(16876)] = 668936,
  [SMALL_STATE(16877)] = 668950,
  [SMALL_STATE(16878)] = 668964,
  [SMALL_STATE(16879)] = 668978,
  [SMALL_STATE(16880)] = 668992,
  [SMALL_STATE(16881)] = 669006,
  [SMALL_STATE(16882)] = 669020,
  [SMALL_STATE(16883)] = 669034,
  [SMALL_STATE(16884)] = 669048,
  [SMALL_STATE(16885)] = 669062,
  [SMALL_STATE(16886)] = 669076,
  [SMALL_STATE(16887)] = 669090,
  [SMALL_STATE(16888)] = 669104,
  [SMALL_STATE(16889)] = 669118,
  [SMALL_STATE(16890)] = 669132,
  [SMALL_STATE(16891)] = 669146,
  [SMALL_STATE(16892)] = 669160,
  [SMALL_STATE(16893)] = 669174,
  [SMALL_STATE(16894)] = 669188,
  [SMALL_STATE(16895)] = 669202,
  [SMALL_STATE(16896)] = 669216,
  [SMALL_STATE(16897)] = 669230,
  [SMALL_STATE(16898)] = 669244,
  [SMALL_STATE(16899)] = 669258,
  [SMALL_STATE(16900)] = 669272,
  [SMALL_STATE(16901)] = 669286,
  [SMALL_STATE(16902)] = 669300,
  [SMALL_STATE(16903)] = 669314,
  [SMALL_STATE(16904)] = 669328,
  [SMALL_STATE(16905)] = 669342,
  [SMALL_STATE(16906)] = 669356,
  [SMALL_STATE(16907)] = 669370,
  [SMALL_STATE(16908)] = 669384,
  [SMALL_STATE(16909)] = 669398,
  [SMALL_STATE(16910)] = 669412,
  [SMALL_STATE(16911)] = 669426,
  [SMALL_STATE(16912)] = 669440,
  [SMALL_STATE(16913)] = 669454,
  [SMALL_STATE(16914)] = 669468,
  [SMALL_STATE(16915)] = 669482,
  [SMALL_STATE(16916)] = 669496,
  [SMALL_STATE(16917)] = 669510,
  [SMALL_STATE(16918)] = 669524,
  [SMALL_STATE(16919)] = 669538,
  [SMALL_STATE(16920)] = 669552,
  [SMALL_STATE(16921)] = 669566,
  [SMALL_STATE(16922)] = 669580,
  [SMALL_STATE(16923)] = 669594,
  [SMALL_STATE(16924)] = 669608,
  [SMALL_STATE(16925)] = 669622,
  [SMALL_STATE(16926)] = 669636,
  [SMALL_STATE(16927)] = 669650,
  [SMALL_STATE(16928)] = 669664,
  [SMALL_STATE(16929)] = 669678,
  [SMALL_STATE(16930)] = 669692,
  [SMALL_STATE(16931)] = 669706,
  [SMALL_STATE(16932)] = 669720,
  [SMALL_STATE(16933)] = 669734,
  [SMALL_STATE(16934)] = 669748,
  [SMALL_STATE(16935)] = 669762,
  [SMALL_STATE(16936)] = 669776,
  [SMALL_STATE(16937)] = 669790,
  [SMALL_STATE(16938)] = 669804,
  [SMALL_STATE(16939)] = 669818,
  [SMALL_STATE(16940)] = 669832,
  [SMALL_STATE(16941)] = 669846,
  [SMALL_STATE(16942)] = 669860,
  [SMALL_STATE(16943)] = 669874,
  [SMALL_STATE(16944)] = 669888,
  [SMALL_STATE(16945)] = 669902,
  [SMALL_STATE(16946)] = 669916,
  [SMALL_STATE(16947)] = 669930,
  [SMALL_STATE(16948)] = 669944,
  [SMALL_STATE(16949)] = 669958,
  [SMALL_STATE(16950)] = 669972,
  [SMALL_STATE(16951)] = 669986,
  [SMALL_STATE(16952)] = 670000,
  [SMALL_STATE(16953)] = 670014,
  [SMALL_STATE(16954)] = 670028,
  [SMALL_STATE(16955)] = 670042,
  [SMALL_STATE(16956)] = 670056,
  [SMALL_STATE(16957)] = 670070,
  [SMALL_STATE(16958)] = 670084,
  [SMALL_STATE(16959)] = 670098,
  [SMALL_STATE(16960)] = 670112,
  [SMALL_STATE(16961)] = 670126,
  [SMALL_STATE(16962)] = 670140,
  [SMALL_STATE(16963)] = 670154,
  [SMALL_STATE(16964)] = 670168,
  [SMALL_STATE(16965)] = 670182,
  [SMALL_STATE(16966)] = 670196,
  [SMALL_STATE(16967)] = 670210,
  [SMALL_STATE(16968)] = 670224,
  [SMALL_STATE(16969)] = 670238,
  [SMALL_STATE(16970)] = 670252,
  [SMALL_STATE(16971)] = 670266,
  [SMALL_STATE(16972)] = 670280,
  [SMALL_STATE(16973)] = 670294,
  [SMALL_STATE(16974)] = 670308,
  [SMALL_STATE(16975)] = 670322,
  [SMALL_STATE(16976)] = 670336,
  [SMALL_STATE(16977)] = 670350,
  [SMALL_STATE(16978)] = 670364,
  [SMALL_STATE(16979)] = 670378,
  [SMALL_STATE(16980)] = 670392,
  [SMALL_STATE(16981)] = 670406,
  [SMALL_STATE(16982)] = 670420,
  [SMALL_STATE(16983)] = 670434,
  [SMALL_STATE(16984)] = 670448,
  [SMALL_STATE(16985)] = 670462,
  [SMALL_STATE(16986)] = 670476,
  [SMALL_STATE(16987)] = 670490,
  [SMALL_STATE(16988)] = 670504,
  [SMALL_STATE(16989)] = 670518,
  [SMALL_STATE(16990)] = 670532,
  [SMALL_STATE(16991)] = 670546,
  [SMALL_STATE(16992)] = 670560,
  [SMALL_STATE(16993)] = 670574,
  [SMALL_STATE(16994)] = 670588,
  [SMALL_STATE(16995)] = 670602,
  [SMALL_STATE(16996)] = 670616,
  [SMALL_STATE(16997)] = 670630,
  [SMALL_STATE(16998)] = 670644,
  [SMALL_STATE(16999)] = 670658,
  [SMALL_STATE(17000)] = 670672,
  [SMALL_STATE(17001)] = 670686,
  [SMALL_STATE(17002)] = 670700,
  [SMALL_STATE(17003)] = 670714,
  [SMALL_STATE(17004)] = 670728,
  [SMALL_STATE(17005)] = 670742,
  [SMALL_STATE(17006)] = 670756,
  [SMALL_STATE(17007)] = 670770,
  [SMALL_STATE(17008)] = 670784,
  [SMALL_STATE(17009)] = 670798,
  [SMALL_STATE(17010)] = 670812,
  [SMALL_STATE(17011)] = 670826,
  [SMALL_STATE(17012)] = 670840,
  [SMALL_STATE(17013)] = 670854,
  [SMALL_STATE(17014)] = 670868,
  [SMALL_STATE(17015)] = 670882,
  [SMALL_STATE(17016)] = 670896,
  [SMALL_STATE(17017)] = 670910,
  [SMALL_STATE(17018)] = 670924,
  [SMALL_STATE(17019)] = 670938,
  [SMALL_STATE(17020)] = 670952,
  [SMALL_STATE(17021)] = 670966,
  [SMALL_STATE(17022)] = 670980,
  [SMALL_STATE(17023)] = 670994,
  [SMALL_STATE(17024)] = 671008,
  [SMALL_STATE(17025)] = 671022,
  [SMALL_STATE(17026)] = 671036,
  [SMALL_STATE(17027)] = 671050,
  [SMALL_STATE(17028)] = 671064,
  [SMALL_STATE(17029)] = 671078,
  [SMALL_STATE(17030)] = 671092,
  [SMALL_STATE(17031)] = 671106,
  [SMALL_STATE(17032)] = 671120,
  [SMALL_STATE(17033)] = 671134,
  [SMALL_STATE(17034)] = 671148,
  [SMALL_STATE(17035)] = 671162,
  [SMALL_STATE(17036)] = 671176,
  [SMALL_STATE(17037)] = 671190,
  [SMALL_STATE(17038)] = 671204,
  [SMALL_STATE(17039)] = 671218,
  [SMALL_STATE(17040)] = 671232,
  [SMALL_STATE(17041)] = 671246,
  [SMALL_STATE(17042)] = 671260,
  [SMALL_STATE(17043)] = 671274,
  [SMALL_STATE(17044)] = 671288,
  [SMALL_STATE(17045)] = 671302,
  [SMALL_STATE(17046)] = 671316,
  [SMALL_STATE(17047)] = 671330,
  [SMALL_STATE(17048)] = 671344,
  [SMALL_STATE(17049)] = 671358,
  [SMALL_STATE(17050)] = 671372,
  [SMALL_STATE(17051)] = 671386,
  [SMALL_STATE(17052)] = 671400,
  [SMALL_STATE(17053)] = 671414,
  [SMALL_STATE(17054)] = 671428,
  [SMALL_STATE(17055)] = 671442,
  [SMALL_STATE(17056)] = 671456,
  [SMALL_STATE(17057)] = 671470,
  [SMALL_STATE(17058)] = 671484,
  [SMALL_STATE(17059)] = 671498,
  [SMALL_STATE(17060)] = 671512,
  [SMALL_STATE(17061)] = 671526,
  [SMALL_STATE(17062)] = 671540,
  [SMALL_STATE(17063)] = 671554,
  [SMALL_STATE(17064)] = 671568,
  [SMALL_STATE(17065)] = 671582,
  [SMALL_STATE(17066)] = 671596,
  [SMALL_STATE(17067)] = 671610,
  [SMALL_STATE(17068)] = 671624,
  [SMALL_STATE(17069)] = 671638,
  [SMALL_STATE(17070)] = 671652,
  [SMALL_STATE(17071)] = 671666,
  [SMALL_STATE(17072)] = 671680,
  [SMALL_STATE(17073)] = 671694,
  [SMALL_STATE(17074)] = 671708,
  [SMALL_STATE(17075)] = 671722,
  [SMALL_STATE(17076)] = 671736,
  [SMALL_STATE(17077)] = 671750,
  [SMALL_STATE(17078)] = 671764,
  [SMALL_STATE(17079)] = 671778,
  [SMALL_STATE(17080)] = 671792,
  [SMALL_STATE(17081)] = 671806,
  [SMALL_STATE(17082)] = 671820,
  [SMALL_STATE(17083)] = 671834,
  [SMALL_STATE(17084)] = 671848,
  [SMALL_STATE(17085)] = 671862,
  [SMALL_STATE(17086)] = 671876,
  [SMALL_STATE(17087)] = 671890,
  [SMALL_STATE(17088)] = 671904,
  [SMALL_STATE(17089)] = 671918,
  [SMALL_STATE(17090)] = 671932,
  [SMALL_STATE(17091)] = 671946,
  [SMALL_STATE(17092)] = 671960,
  [SMALL_STATE(17093)] = 671974,
  [SMALL_STATE(17094)] = 671988,
  [SMALL_STATE(17095)] = 672002,
  [SMALL_STATE(17096)] = 672016,
  [SMALL_STATE(17097)] = 672030,
  [SMALL_STATE(17098)] = 672044,
  [SMALL_STATE(17099)] = 672058,
  [SMALL_STATE(17100)] = 672072,
  [SMALL_STATE(17101)] = 672086,
  [SMALL_STATE(17102)] = 672100,
  [SMALL_STATE(17103)] = 672114,
  [SMALL_STATE(17104)] = 672128,
  [SMALL_STATE(17105)] = 672142,
  [SMALL_STATE(17106)] = 672156,
  [SMALL_STATE(17107)] = 672170,
  [SMALL_STATE(17108)] = 672184,
  [SMALL_STATE(17109)] = 672198,
  [SMALL_STATE(17110)] = 672212,
  [SMALL_STATE(17111)] = 672226,
  [SMALL_STATE(17112)] = 672240,
  [SMALL_STATE(17113)] = 672254,
  [SMALL_STATE(17114)] = 672268,
  [SMALL_STATE(17115)] = 672282,
  [SMALL_STATE(17116)] = 672296,
  [SMALL_STATE(17117)] = 672310,
  [SMALL_STATE(17118)] = 672324,
  [SMALL_STATE(17119)] = 672338,
  [SMALL_STATE(17120)] = 672352,
  [SMALL_STATE(17121)] = 672366,
  [SMALL_STATE(17122)] = 672380,
  [SMALL_STATE(17123)] = 672394,
  [SMALL_STATE(17124)] = 672408,
  [SMALL_STATE(17125)] = 672422,
  [SMALL_STATE(17126)] = 672436,
  [SMALL_STATE(17127)] = 672450,
  [SMALL_STATE(17128)] = 672464,
  [SMALL_STATE(17129)] = 672478,
  [SMALL_STATE(17130)] = 672492,
  [SMALL_STATE(17131)] = 672506,
  [SMALL_STATE(17132)] = 672520,
  [SMALL_STATE(17133)] = 672534,
  [SMALL_STATE(17134)] = 672548,
  [SMALL_STATE(17135)] = 672562,
  [SMALL_STATE(17136)] = 672576,
  [SMALL_STATE(17137)] = 672590,
  [SMALL_STATE(17138)] = 672604,
  [SMALL_STATE(17139)] = 672618,
  [SMALL_STATE(17140)] = 672632,
  [SMALL_STATE(17141)] = 672646,
  [SMALL_STATE(17142)] = 672660,
  [SMALL_STATE(17143)] = 672674,
  [SMALL_STATE(17144)] = 672688,
  [SMALL_STATE(17145)] = 672702,
  [SMALL_STATE(17146)] = 672716,
  [SMALL_STATE(17147)] = 672730,
  [SMALL_STATE(17148)] = 672744,
  [SMALL_STATE(17149)] = 672758,
  [SMALL_STATE(17150)] = 672772,
  [SMALL_STATE(17151)] = 672786,
  [SMALL_STATE(17152)] = 672800,
  [SMALL_STATE(17153)] = 672814,
  [SMALL_STATE(17154)] = 672828,
  [SMALL_STATE(17155)] = 672842,
  [SMALL_STATE(17156)] = 672856,
  [SMALL_STATE(17157)] = 672870,
  [SMALL_STATE(17158)] = 672884,
  [SMALL_STATE(17159)] = 672898,
  [SMALL_STATE(17160)] = 672912,
  [SMALL_STATE(17161)] = 672926,
  [SMALL_STATE(17162)] = 672940,
  [SMALL_STATE(17163)] = 672954,
  [SMALL_STATE(17164)] = 672968,
  [SMALL_STATE(17165)] = 672982,
  [SMALL_STATE(17166)] = 672996,
  [SMALL_STATE(17167)] = 673010,
  [SMALL_STATE(17168)] = 673024,
  [SMALL_STATE(17169)] = 673038,
  [SMALL_STATE(17170)] = 673052,
  [SMALL_STATE(17171)] = 673066,
  [SMALL_STATE(17172)] = 673080,
  [SMALL_STATE(17173)] = 673094,
  [SMALL_STATE(17174)] = 673108,
  [SMALL_STATE(17175)] = 673122,
  [SMALL_STATE(17176)] = 673136,
  [SMALL_STATE(17177)] = 673150,
  [SMALL_STATE(17178)] = 673164,
  [SMALL_STATE(17179)] = 673178,
  [SMALL_STATE(17180)] = 673192,
  [SMALL_STATE(17181)] = 673206,
  [SMALL_STATE(17182)] = 673220,
  [SMALL_STATE(17183)] = 673234,
  [SMALL_STATE(17184)] = 673248,
  [SMALL_STATE(17185)] = 673262,
  [SMALL_STATE(17186)] = 673276,
  [SMALL_STATE(17187)] = 673290,
  [SMALL_STATE(17188)] = 673304,
  [SMALL_STATE(17189)] = 673318,
  [SMALL_STATE(17190)] = 673332,
  [SMALL_STATE(17191)] = 673346,
  [SMALL_STATE(17192)] = 673360,
  [SMALL_STATE(17193)] = 673374,
  [SMALL_STATE(17194)] = 673388,
  [SMALL_STATE(17195)] = 673402,
  [SMALL_STATE(17196)] = 673416,
  [SMALL_STATE(17197)] = 673430,
  [SMALL_STATE(17198)] = 673444,
  [SMALL_STATE(17199)] = 673458,
  [SMALL_STATE(17200)] = 673472,
  [SMALL_STATE(17201)] = 673486,
  [SMALL_STATE(17202)] = 673500,
  [SMALL_STATE(17203)] = 673514,
  [SMALL_STATE(17204)] = 673528,
  [SMALL_STATE(17205)] = 673542,
  [SMALL_STATE(17206)] = 673556,
  [SMALL_STATE(17207)] = 673570,
  [SMALL_STATE(17208)] = 673584,
  [SMALL_STATE(17209)] = 673598,
  [SMALL_STATE(17210)] = 673612,
  [SMALL_STATE(17211)] = 673626,
  [SMALL_STATE(17212)] = 673640,
  [SMALL_STATE(17213)] = 673654,
  [SMALL_STATE(17214)] = 673668,
  [SMALL_STATE(17215)] = 673682,
  [SMALL_STATE(17216)] = 673696,
  [SMALL_STATE(17217)] = 673710,
  [SMALL_STATE(17218)] = 673724,
  [SMALL_STATE(17219)] = 673738,
  [SMALL_STATE(17220)] = 673752,
  [SMALL_STATE(17221)] = 673766,
  [SMALL_STATE(17222)] = 673780,
  [SMALL_STATE(17223)] = 673794,
  [SMALL_STATE(17224)] = 673808,
  [SMALL_STATE(17225)] = 673822,
  [SMALL_STATE(17226)] = 673836,
  [SMALL_STATE(17227)] = 673850,
  [SMALL_STATE(17228)] = 673864,
  [SMALL_STATE(17229)] = 673878,
  [SMALL_STATE(17230)] = 673892,
  [SMALL_STATE(17231)] = 673906,
  [SMALL_STATE(17232)] = 673920,
  [SMALL_STATE(17233)] = 673934,
  [SMALL_STATE(17234)] = 673948,
  [SMALL_STATE(17235)] = 673962,
  [SMALL_STATE(17236)] = 673976,
  [SMALL_STATE(17237)] = 673990,
  [SMALL_STATE(17238)] = 674004,
  [SMALL_STATE(17239)] = 674018,
  [SMALL_STATE(17240)] = 674032,
  [SMALL_STATE(17241)] = 674046,
  [SMALL_STATE(17242)] = 674060,
  [SMALL_STATE(17243)] = 674074,
  [SMALL_STATE(17244)] = 674088,
  [SMALL_STATE(17245)] = 674102,
  [SMALL_STATE(17246)] = 674116,
  [SMALL_STATE(17247)] = 674130,
  [SMALL_STATE(17248)] = 674144,
  [SMALL_STATE(17249)] = 674158,
  [SMALL_STATE(17250)] = 674172,
  [SMALL_STATE(17251)] = 674186,
  [SMALL_STATE(17252)] = 674200,
  [SMALL_STATE(17253)] = 674214,
  [SMALL_STATE(17254)] = 674228,
  [SMALL_STATE(17255)] = 674242,
  [SMALL_STATE(17256)] = 674256,
  [SMALL_STATE(17257)] = 674270,
  [SMALL_STATE(17258)] = 674284,
  [SMALL_STATE(17259)] = 674298,
  [SMALL_STATE(17260)] = 674312,
  [SMALL_STATE(17261)] = 674326,
  [SMALL_STATE(17262)] = 674340,
  [SMALL_STATE(17263)] = 674354,
  [SMALL_STATE(17264)] = 674368,
  [SMALL_STATE(17265)] = 674382,
  [SMALL_STATE(17266)] = 674396,
  [SMALL_STATE(17267)] = 674410,
  [SMALL_STATE(17268)] = 674424,
  [SMALL_STATE(17269)] = 674438,
  [SMALL_STATE(17270)] = 674452,
  [SMALL_STATE(17271)] = 674466,
  [SMALL_STATE(17272)] = 674480,
  [SMALL_STATE(17273)] = 674494,
  [SMALL_STATE(17274)] = 674508,
  [SMALL_STATE(17275)] = 674522,
  [SMALL_STATE(17276)] = 674536,
  [SMALL_STATE(17277)] = 674550,
  [SMALL_STATE(17278)] = 674564,
  [SMALL_STATE(17279)] = 674578,
  [SMALL_STATE(17280)] = 674592,
  [SMALL_STATE(17281)] = 674606,
  [SMALL_STATE(17282)] = 674620,
  [SMALL_STATE(17283)] = 674634,
  [SMALL_STATE(17284)] = 674648,
  [SMALL_STATE(17285)] = 674662,
  [SMALL_STATE(17286)] = 674676,
  [SMALL_STATE(17287)] = 674690,
  [SMALL_STATE(17288)] = 674704,
  [SMALL_STATE(17289)] = 674718,
  [SMALL_STATE(17290)] = 674732,
  [SMALL_STATE(17291)] = 674746,
  [SMALL_STATE(17292)] = 674760,
  [SMALL_STATE(17293)] = 674774,
  [SMALL_STATE(17294)] = 674788,
  [SMALL_STATE(17295)] = 674802,
  [SMALL_STATE(17296)] = 674816,
  [SMALL_STATE(17297)] = 674830,
  [SMALL_STATE(17298)] = 674844,
  [SMALL_STATE(17299)] = 674858,
  [SMALL_STATE(17300)] = 674872,
  [SMALL_STATE(17301)] = 674886,
  [SMALL_STATE(17302)] = 674900,
  [SMALL_STATE(17303)] = 674914,
  [SMALL_STATE(17304)] = 674928,
  [SMALL_STATE(17305)] = 674942,
  [SMALL_STATE(17306)] = 674956,
  [SMALL_STATE(17307)] = 674970,
  [SMALL_STATE(17308)] = 674984,
  [SMALL_STATE(17309)] = 674998,
  [SMALL_STATE(17310)] = 675012,
  [SMALL_STATE(17311)] = 675026,
  [SMALL_STATE(17312)] = 675040,
  [SMALL_STATE(17313)] = 675054,
  [SMALL_STATE(17314)] = 675068,
  [SMALL_STATE(17315)] = 675082,
  [SMALL_STATE(17316)] = 675096,
  [SMALL_STATE(17317)] = 675110,
  [SMALL_STATE(17318)] = 675124,
  [SMALL_STATE(17319)] = 675138,
  [SMALL_STATE(17320)] = 675152,
  [SMALL_STATE(17321)] = 675166,
  [SMALL_STATE(17322)] = 675180,
  [SMALL_STATE(17323)] = 675194,
  [SMALL_STATE(17324)] = 675208,
  [SMALL_STATE(17325)] = 675222,
  [SMALL_STATE(17326)] = 675236,
  [SMALL_STATE(17327)] = 675250,
  [SMALL_STATE(17328)] = 675264,
  [SMALL_STATE(17329)] = 675278,
  [SMALL_STATE(17330)] = 675292,
  [SMALL_STATE(17331)] = 675306,
  [SMALL_STATE(17332)] = 675320,
  [SMALL_STATE(17333)] = 675334,
  [SMALL_STATE(17334)] = 675348,
  [SMALL_STATE(17335)] = 675362,
  [SMALL_STATE(17336)] = 675376,
  [SMALL_STATE(17337)] = 675390,
  [SMALL_STATE(17338)] = 675404,
  [SMALL_STATE(17339)] = 675418,
  [SMALL_STATE(17340)] = 675432,
  [SMALL_STATE(17341)] = 675446,
  [SMALL_STATE(17342)] = 675460,
  [SMALL_STATE(17343)] = 675474,
  [SMALL_STATE(17344)] = 675488,
  [SMALL_STATE(17345)] = 675502,
  [SMALL_STATE(17346)] = 675516,
  [SMALL_STATE(17347)] = 675530,
  [SMALL_STATE(17348)] = 675544,
  [SMALL_STATE(17349)] = 675558,
  [SMALL_STATE(17350)] = 675572,
  [SMALL_STATE(17351)] = 675586,
  [SMALL_STATE(17352)] = 675600,
  [SMALL_STATE(17353)] = 675614,
  [SMALL_STATE(17354)] = 675628,
  [SMALL_STATE(17355)] = 675642,
  [SMALL_STATE(17356)] = 675656,
  [SMALL_STATE(17357)] = 675670,
  [SMALL_STATE(17358)] = 675684,
  [SMALL_STATE(17359)] = 675698,
  [SMALL_STATE(17360)] = 675712,
  [SMALL_STATE(17361)] = 675726,
  [SMALL_STATE(17362)] = 675740,
  [SMALL_STATE(17363)] = 675754,
  [SMALL_STATE(17364)] = 675768,
  [SMALL_STATE(17365)] = 675782,
  [SMALL_STATE(17366)] = 675796,
  [SMALL_STATE(17367)] = 675810,
  [SMALL_STATE(17368)] = 675824,
  [SMALL_STATE(17369)] = 675838,
  [SMALL_STATE(17370)] = 675852,
  [SMALL_STATE(17371)] = 675866,
  [SMALL_STATE(17372)] = 675880,
  [SMALL_STATE(17373)] = 675894,
  [SMALL_STATE(17374)] = 675908,
  [SMALL_STATE(17375)] = 675922,
  [SMALL_STATE(17376)] = 675936,
  [SMALL_STATE(17377)] = 675950,
  [SMALL_STATE(17378)] = 675964,
  [SMALL_STATE(17379)] = 675978,
  [SMALL_STATE(17380)] = 675992,
  [SMALL_STATE(17381)] = 676006,
  [SMALL_STATE(17382)] = 676020,
  [SMALL_STATE(17383)] = 676034,
  [SMALL_STATE(17384)] = 676048,
  [SMALL_STATE(17385)] = 676062,
  [SMALL_STATE(17386)] = 676076,
  [SMALL_STATE(17387)] = 676090,
  [SMALL_STATE(17388)] = 676104,
  [SMALL_STATE(17389)] = 676118,
  [SMALL_STATE(17390)] = 676132,
  [SMALL_STATE(17391)] = 676146,
  [SMALL_STATE(17392)] = 676160,
  [SMALL_STATE(17393)] = 676174,
  [SMALL_STATE(17394)] = 676188,
  [SMALL_STATE(17395)] = 676202,
  [SMALL_STATE(17396)] = 676216,
  [SMALL_STATE(17397)] = 676230,
  [SMALL_STATE(17398)] = 676244,
  [SMALL_STATE(17399)] = 676258,
  [SMALL_STATE(17400)] = 676272,
  [SMALL_STATE(17401)] = 676286,
  [SMALL_STATE(17402)] = 676300,
  [SMALL_STATE(17403)] = 676314,
  [SMALL_STATE(17404)] = 676328,
  [SMALL_STATE(17405)] = 676342,
  [SMALL_STATE(17406)] = 676356,
  [SMALL_STATE(17407)] = 676370,
  [SMALL_STATE(17408)] = 676384,
  [SMALL_STATE(17409)] = 676398,
  [SMALL_STATE(17410)] = 676412,
  [SMALL_STATE(17411)] = 676426,
  [SMALL_STATE(17412)] = 676440,
  [SMALL_STATE(17413)] = 676454,
  [SMALL_STATE(17414)] = 676468,
  [SMALL_STATE(17415)] = 676482,
  [SMALL_STATE(17416)] = 676496,
  [SMALL_STATE(17417)] = 676510,
  [SMALL_STATE(17418)] = 676524,
  [SMALL_STATE(17419)] = 676538,
  [SMALL_STATE(17420)] = 676552,
  [SMALL_STATE(17421)] = 676566,
  [SMALL_STATE(17422)] = 676580,
  [SMALL_STATE(17423)] = 676594,
  [SMALL_STATE(17424)] = 676608,
  [SMALL_STATE(17425)] = 676622,
  [SMALL_STATE(17426)] = 676636,
  [SMALL_STATE(17427)] = 676650,
  [SMALL_STATE(17428)] = 676664,
  [SMALL_STATE(17429)] = 676678,
  [SMALL_STATE(17430)] = 676692,
  [SMALL_STATE(17431)] = 676706,
  [SMALL_STATE(17432)] = 676720,
  [SMALL_STATE(17433)] = 676734,
  [SMALL_STATE(17434)] = 676748,
  [SMALL_STATE(17435)] = 676762,
  [SMALL_STATE(17436)] = 676776,
  [SMALL_STATE(17437)] = 676790,
  [SMALL_STATE(17438)] = 676804,
  [SMALL_STATE(17439)] = 676818,
  [SMALL_STATE(17440)] = 676832,
  [SMALL_STATE(17441)] = 676846,
  [SMALL_STATE(17442)] = 676860,
  [SMALL_STATE(17443)] = 676874,
  [SMALL_STATE(17444)] = 676888,
  [SMALL_STATE(17445)] = 676902,
  [SMALL_STATE(17446)] = 676916,
  [SMALL_STATE(17447)] = 676930,
  [SMALL_STATE(17448)] = 676944,
  [SMALL_STATE(17449)] = 676958,
  [SMALL_STATE(17450)] = 676972,
  [SMALL_STATE(17451)] = 676986,
  [SMALL_STATE(17452)] = 677000,
  [SMALL_STATE(17453)] = 677014,
  [SMALL_STATE(17454)] = 677028,
  [SMALL_STATE(17455)] = 677042,
  [SMALL_STATE(17456)] = 677056,
  [SMALL_STATE(17457)] = 677070,
  [SMALL_STATE(17458)] = 677084,
  [SMALL_STATE(17459)] = 677098,
  [SMALL_STATE(17460)] = 677112,
  [SMALL_STATE(17461)] = 677126,
  [SMALL_STATE(17462)] = 677140,
  [SMALL_STATE(17463)] = 677154,
  [SMALL_STATE(17464)] = 677168,
  [SMALL_STATE(17465)] = 677182,
  [SMALL_STATE(17466)] = 677196,
  [SMALL_STATE(17467)] = 677210,
  [SMALL_STATE(17468)] = 677224,
  [SMALL_STATE(17469)] = 677238,
  [SMALL_STATE(17470)] = 677252,
  [SMALL_STATE(17471)] = 677266,
  [SMALL_STATE(17472)] = 677280,
  [SMALL_STATE(17473)] = 677294,
  [SMALL_STATE(17474)] = 677308,
  [SMALL_STATE(17475)] = 677322,
  [SMALL_STATE(17476)] = 677336,
  [SMALL_STATE(17477)] = 677350,
  [SMALL_STATE(17478)] = 677364,
  [SMALL_STATE(17479)] = 677378,
  [SMALL_STATE(17480)] = 677392,
  [SMALL_STATE(17481)] = 677406,
  [SMALL_STATE(17482)] = 677420,
  [SMALL_STATE(17483)] = 677434,
  [SMALL_STATE(17484)] = 677448,
  [SMALL_STATE(17485)] = 677462,
  [SMALL_STATE(17486)] = 677476,
  [SMALL_STATE(17487)] = 677490,
  [SMALL_STATE(17488)] = 677504,
  [SMALL_STATE(17489)] = 677518,
  [SMALL_STATE(17490)] = 677532,
  [SMALL_STATE(17491)] = 677546,
  [SMALL_STATE(17492)] = 677560,
  [SMALL_STATE(17493)] = 677574,
  [SMALL_STATE(17494)] = 677588,
  [SMALL_STATE(17495)] = 677602,
  [SMALL_STATE(17496)] = 677616,
  [SMALL_STATE(17497)] = 677630,
  [SMALL_STATE(17498)] = 677644,
  [SMALL_STATE(17499)] = 677658,
  [SMALL_STATE(17500)] = 677672,
  [SMALL_STATE(17501)] = 677686,
  [SMALL_STATE(17502)] = 677700,
  [SMALL_STATE(17503)] = 677714,
  [SMALL_STATE(17504)] = 677728,
  [SMALL_STATE(17505)] = 677742,
  [SMALL_STATE(17506)] = 677756,
  [SMALL_STATE(17507)] = 677770,
  [SMALL_STATE(17508)] = 677784,
  [SMALL_STATE(17509)] = 677798,
  [SMALL_STATE(17510)] = 677812,
  [SMALL_STATE(17511)] = 677826,
  [SMALL_STATE(17512)] = 677840,
  [SMALL_STATE(17513)] = 677854,
  [SMALL_STATE(17514)] = 677868,
  [SMALL_STATE(17515)] = 677882,
  [SMALL_STATE(17516)] = 677896,
  [SMALL_STATE(17517)] = 677910,
  [SMALL_STATE(17518)] = 677924,
  [SMALL_STATE(17519)] = 677938,
  [SMALL_STATE(17520)] = 677952,
  [SMALL_STATE(17521)] = 677966,
  [SMALL_STATE(17522)] = 677980,
  [SMALL_STATE(17523)] = 677994,
  [SMALL_STATE(17524)] = 678008,
  [SMALL_STATE(17525)] = 678022,
  [SMALL_STATE(17526)] = 678036,
  [SMALL_STATE(17527)] = 678050,
  [SMALL_STATE(17528)] = 678064,
  [SMALL_STATE(17529)] = 678078,
  [SMALL_STATE(17530)] = 678092,
  [SMALL_STATE(17531)] = 678106,
  [SMALL_STATE(17532)] = 678120,
  [SMALL_STATE(17533)] = 678134,
  [SMALL_STATE(17534)] = 678148,
  [SMALL_STATE(17535)] = 678162,
  [SMALL_STATE(17536)] = 678176,
  [SMALL_STATE(17537)] = 678190,
  [SMALL_STATE(17538)] = 678204,
  [SMALL_STATE(17539)] = 678218,
  [SMALL_STATE(17540)] = 678232,
  [SMALL_STATE(17541)] = 678246,
  [SMALL_STATE(17542)] = 678260,
  [SMALL_STATE(17543)] = 678274,
  [SMALL_STATE(17544)] = 678288,
  [SMALL_STATE(17545)] = 678302,
  [SMALL_STATE(17546)] = 678316,
  [SMALL_STATE(17547)] = 678330,
  [SMALL_STATE(17548)] = 678344,
  [SMALL_STATE(17549)] = 678358,
  [SMALL_STATE(17550)] = 678372,
  [SMALL_STATE(17551)] = 678386,
  [SMALL_STATE(17552)] = 678400,
  [SMALL_STATE(17553)] = 678414,
  [SMALL_STATE(17554)] = 678428,
  [SMALL_STATE(17555)] = 678442,
  [SMALL_STATE(17556)] = 678456,
  [SMALL_STATE(17557)] = 678470,
  [SMALL_STATE(17558)] = 678484,
  [SMALL_STATE(17559)] = 678498,
  [SMALL_STATE(17560)] = 678512,
  [SMALL_STATE(17561)] = 678526,
  [SMALL_STATE(17562)] = 678540,
  [SMALL_STATE(17563)] = 678554,
  [SMALL_STATE(17564)] = 678568,
  [SMALL_STATE(17565)] = 678582,
  [SMALL_STATE(17566)] = 678596,
  [SMALL_STATE(17567)] = 678610,
  [SMALL_STATE(17568)] = 678624,
  [SMALL_STATE(17569)] = 678638,
  [SMALL_STATE(17570)] = 678652,
  [SMALL_STATE(17571)] = 678666,
  [SMALL_STATE(17572)] = 678680,
  [SMALL_STATE(17573)] = 678694,
  [SMALL_STATE(17574)] = 678708,
  [SMALL_STATE(17575)] = 678722,
  [SMALL_STATE(17576)] = 678736,
  [SMALL_STATE(17577)] = 678750,
  [SMALL_STATE(17578)] = 678764,
  [SMALL_STATE(17579)] = 678778,
  [SMALL_STATE(17580)] = 678792,
  [SMALL_STATE(17581)] = 678806,
  [SMALL_STATE(17582)] = 678820,
  [SMALL_STATE(17583)] = 678834,
  [SMALL_STATE(17584)] = 678848,
  [SMALL_STATE(17585)] = 678862,
  [SMALL_STATE(17586)] = 678876,
  [SMALL_STATE(17587)] = 678890,
  [SMALL_STATE(17588)] = 678904,
  [SMALL_STATE(17589)] = 678918,
  [SMALL_STATE(17590)] = 678932,
  [SMALL_STATE(17591)] = 678946,
  [SMALL_STATE(17592)] = 678960,
  [SMALL_STATE(17593)] = 678974,
  [SMALL_STATE(17594)] = 678988,
  [SMALL_STATE(17595)] = 679002,
  [SMALL_STATE(17596)] = 679016,
  [SMALL_STATE(17597)] = 679030,
  [SMALL_STATE(17598)] = 679044,
  [SMALL_STATE(17599)] = 679058,
  [SMALL_STATE(17600)] = 679072,
  [SMALL_STATE(17601)] = 679086,
  [SMALL_STATE(17602)] = 679100,
  [SMALL_STATE(17603)] = 679114,
  [SMALL_STATE(17604)] = 679128,
  [SMALL_STATE(17605)] = 679142,
  [SMALL_STATE(17606)] = 679156,
  [SMALL_STATE(17607)] = 679170,
  [SMALL_STATE(17608)] = 679184,
  [SMALL_STATE(17609)] = 679198,
  [SMALL_STATE(17610)] = 679212,
  [SMALL_STATE(17611)] = 679226,
  [SMALL_STATE(17612)] = 679240,
  [SMALL_STATE(17613)] = 679254,
  [SMALL_STATE(17614)] = 679268,
  [SMALL_STATE(17615)] = 679282,
  [SMALL_STATE(17616)] = 679296,
  [SMALL_STATE(17617)] = 679310,
  [SMALL_STATE(17618)] = 679324,
  [SMALL_STATE(17619)] = 679338,
  [SMALL_STATE(17620)] = 679352,
  [SMALL_STATE(17621)] = 679366,
  [SMALL_STATE(17622)] = 679380,
  [SMALL_STATE(17623)] = 679394,
  [SMALL_STATE(17624)] = 679408,
  [SMALL_STATE(17625)] = 679422,
  [SMALL_STATE(17626)] = 679436,
  [SMALL_STATE(17627)] = 679450,
  [SMALL_STATE(17628)] = 679464,
  [SMALL_STATE(17629)] = 679478,
  [SMALL_STATE(17630)] = 679492,
  [SMALL_STATE(17631)] = 679506,
  [SMALL_STATE(17632)] = 679520,
  [SMALL_STATE(17633)] = 679534,
  [SMALL_STATE(17634)] = 679548,
  [SMALL_STATE(17635)] = 679562,
  [SMALL_STATE(17636)] = 679576,
  [SMALL_STATE(17637)] = 679590,
  [SMALL_STATE(17638)] = 679604,
  [SMALL_STATE(17639)] = 679618,
  [SMALL_STATE(17640)] = 679632,
  [SMALL_STATE(17641)] = 679646,
  [SMALL_STATE(17642)] = 679660,
  [SMALL_STATE(17643)] = 679674,
  [SMALL_STATE(17644)] = 679688,
  [SMALL_STATE(17645)] = 679702,
  [SMALL_STATE(17646)] = 679716,
  [SMALL_STATE(17647)] = 679730,
  [SMALL_STATE(17648)] = 679744,
  [SMALL_STATE(17649)] = 679758,
  [SMALL_STATE(17650)] = 679772,
  [SMALL_STATE(17651)] = 679786,
  [SMALL_STATE(17652)] = 679800,
  [SMALL_STATE(17653)] = 679814,
  [SMALL_STATE(17654)] = 679828,
  [SMALL_STATE(17655)] = 679842,
  [SMALL_STATE(17656)] = 679856,
  [SMALL_STATE(17657)] = 679870,
  [SMALL_STATE(17658)] = 679884,
  [SMALL_STATE(17659)] = 679898,
  [SMALL_STATE(17660)] = 679912,
  [SMALL_STATE(17661)] = 679926,
  [SMALL_STATE(17662)] = 679940,
  [SMALL_STATE(17663)] = 679954,
  [SMALL_STATE(17664)] = 679968,
  [SMALL_STATE(17665)] = 679982,
  [SMALL_STATE(17666)] = 679996,
  [SMALL_STATE(17667)] = 680010,
  [SMALL_STATE(17668)] = 680024,
  [SMALL_STATE(17669)] = 680038,
  [SMALL_STATE(17670)] = 680052,
  [SMALL_STATE(17671)] = 680066,
  [SMALL_STATE(17672)] = 680080,
  [SMALL_STATE(17673)] = 680094,
  [SMALL_STATE(17674)] = 680108,
  [SMALL_STATE(17675)] = 680122,
  [SMALL_STATE(17676)] = 680136,
  [SMALL_STATE(17677)] = 680150,
  [SMALL_STATE(17678)] = 680164,
  [SMALL_STATE(17679)] = 680178,
  [SMALL_STATE(17680)] = 680192,
  [SMALL_STATE(17681)] = 680206,
  [SMALL_STATE(17682)] = 680220,
  [SMALL_STATE(17683)] = 680234,
  [SMALL_STATE(17684)] = 680248,
  [SMALL_STATE(17685)] = 680262,
  [SMALL_STATE(17686)] = 680276,
  [SMALL_STATE(17687)] = 680290,
  [SMALL_STATE(17688)] = 680304,
  [SMALL_STATE(17689)] = 680318,
  [SMALL_STATE(17690)] = 680332,
  [SMALL_STATE(17691)] = 680346,
  [SMALL_STATE(17692)] = 680360,
  [SMALL_STATE(17693)] = 680374,
  [SMALL_STATE(17694)] = 680388,
  [SMALL_STATE(17695)] = 680402,
  [SMALL_STATE(17696)] = 680416,
  [SMALL_STATE(17697)] = 680430,
  [SMALL_STATE(17698)] = 680444,
  [SMALL_STATE(17699)] = 680458,
  [SMALL_STATE(17700)] = 680472,
  [SMALL_STATE(17701)] = 680486,
  [SMALL_STATE(17702)] = 680500,
  [SMALL_STATE(17703)] = 680514,
  [SMALL_STATE(17704)] = 680528,
  [SMALL_STATE(17705)] = 680542,
  [SMALL_STATE(17706)] = 680556,
  [SMALL_STATE(17707)] = 680570,
  [SMALL_STATE(17708)] = 680584,
  [SMALL_STATE(17709)] = 680598,
  [SMALL_STATE(17710)] = 680612,
  [SMALL_STATE(17711)] = 680626,
  [SMALL_STATE(17712)] = 680640,
  [SMALL_STATE(17713)] = 680654,
  [SMALL_STATE(17714)] = 680668,
  [SMALL_STATE(17715)] = 680682,
  [SMALL_STATE(17716)] = 680696,
  [SMALL_STATE(17717)] = 680710,
  [SMALL_STATE(17718)] = 680724,
  [SMALL_STATE(17719)] = 680738,
  [SMALL_STATE(17720)] = 680752,
  [SMALL_STATE(17721)] = 680766,
  [SMALL_STATE(17722)] = 680780,
  [SMALL_STATE(17723)] = 680794,
  [SMALL_STATE(17724)] = 680808,
  [SMALL_STATE(17725)] = 680822,
  [SMALL_STATE(17726)] = 680836,
  [SMALL_STATE(17727)] = 680850,
  [SMALL_STATE(17728)] = 680864,
  [SMALL_STATE(17729)] = 680878,
  [SMALL_STATE(17730)] = 680892,
  [SMALL_STATE(17731)] = 680906,
  [SMALL_STATE(17732)] = 680920,
  [SMALL_STATE(17733)] = 680934,
  [SMALL_STATE(17734)] = 680948,
  [SMALL_STATE(17735)] = 680962,
  [SMALL_STATE(17736)] = 680976,
  [SMALL_STATE(17737)] = 680990,
  [SMALL_STATE(17738)] = 681004,
  [SMALL_STATE(17739)] = 681018,
  [SMALL_STATE(17740)] = 681032,
  [SMALL_STATE(17741)] = 681046,
  [SMALL_STATE(17742)] = 681060,
  [SMALL_STATE(17743)] = 681074,
  [SMALL_STATE(17744)] = 681088,
  [SMALL_STATE(17745)] = 681102,
  [SMALL_STATE(17746)] = 681116,
  [SMALL_STATE(17747)] = 681130,
  [SMALL_STATE(17748)] = 681144,
  [SMALL_STATE(17749)] = 681158,
  [SMALL_STATE(17750)] = 681172,
  [SMALL_STATE(17751)] = 681186,
  [SMALL_STATE(17752)] = 681200,
  [SMALL_STATE(17753)] = 681214,
  [SMALL_STATE(17754)] = 681228,
  [SMALL_STATE(17755)] = 681242,
  [SMALL_STATE(17756)] = 681256,
  [SMALL_STATE(17757)] = 681270,
  [SMALL_STATE(17758)] = 681284,
  [SMALL_STATE(17759)] = 681298,
  [SMALL_STATE(17760)] = 681312,
  [SMALL_STATE(17761)] = 681326,
  [SMALL_STATE(17762)] = 681340,
  [SMALL_STATE(17763)] = 681354,
  [SMALL_STATE(17764)] = 681368,
  [SMALL_STATE(17765)] = 681382,
  [SMALL_STATE(17766)] = 681396,
  [SMALL_STATE(17767)] = 681410,
  [SMALL_STATE(17768)] = 681424,
  [SMALL_STATE(17769)] = 681438,
  [SMALL_STATE(17770)] = 681452,
  [SMALL_STATE(17771)] = 681466,
  [SMALL_STATE(17772)] = 681480,
  [SMALL_STATE(17773)] = 681494,
  [SMALL_STATE(17774)] = 681508,
  [SMALL_STATE(17775)] = 681522,
  [SMALL_STATE(17776)] = 681536,
  [SMALL_STATE(17777)] = 681550,
  [SMALL_STATE(17778)] = 681564,
  [SMALL_STATE(17779)] = 681578,
  [SMALL_STATE(17780)] = 681592,
  [SMALL_STATE(17781)] = 681606,
  [SMALL_STATE(17782)] = 681620,
  [SMALL_STATE(17783)] = 681634,
  [SMALL_STATE(17784)] = 681648,
  [SMALL_STATE(17785)] = 681662,
  [SMALL_STATE(17786)] = 681676,
  [SMALL_STATE(17787)] = 681690,
  [SMALL_STATE(17788)] = 681704,
  [SMALL_STATE(17789)] = 681718,
  [SMALL_STATE(17790)] = 681732,
  [SMALL_STATE(17791)] = 681746,
  [SMALL_STATE(17792)] = 681760,
  [SMALL_STATE(17793)] = 681774,
  [SMALL_STATE(17794)] = 681788,
  [SMALL_STATE(17795)] = 681802,
  [SMALL_STATE(17796)] = 681816,
  [SMALL_STATE(17797)] = 681830,
  [SMALL_STATE(17798)] = 681844,
  [SMALL_STATE(17799)] = 681858,
  [SMALL_STATE(17800)] = 681872,
  [SMALL_STATE(17801)] = 681886,
  [SMALL_STATE(17802)] = 681900,
  [SMALL_STATE(17803)] = 681914,
  [SMALL_STATE(17804)] = 681928,
  [SMALL_STATE(17805)] = 681942,
  [SMALL_STATE(17806)] = 681956,
  [SMALL_STATE(17807)] = 681970,
  [SMALL_STATE(17808)] = 681984,
  [SMALL_STATE(17809)] = 681998,
  [SMALL_STATE(17810)] = 682012,
  [SMALL_STATE(17811)] = 682026,
  [SMALL_STATE(17812)] = 682040,
  [SMALL_STATE(17813)] = 682054,
  [SMALL_STATE(17814)] = 682068,
  [SMALL_STATE(17815)] = 682082,
  [SMALL_STATE(17816)] = 682096,
  [SMALL_STATE(17817)] = 682110,
  [SMALL_STATE(17818)] = 682124,
  [SMALL_STATE(17819)] = 682138,
  [SMALL_STATE(17820)] = 682152,
  [SMALL_STATE(17821)] = 682166,
  [SMALL_STATE(17822)] = 682180,
  [SMALL_STATE(17823)] = 682194,
  [SMALL_STATE(17824)] = 682208,
  [SMALL_STATE(17825)] = 682222,
  [SMALL_STATE(17826)] = 682236,
  [SMALL_STATE(17827)] = 682250,
  [SMALL_STATE(17828)] = 682264,
  [SMALL_STATE(17829)] = 682278,
  [SMALL_STATE(17830)] = 682292,
  [SMALL_STATE(17831)] = 682306,
  [SMALL_STATE(17832)] = 682320,
  [SMALL_STATE(17833)] = 682334,
  [SMALL_STATE(17834)] = 682348,
  [SMALL_STATE(17835)] = 682362,
  [SMALL_STATE(17836)] = 682376,
  [SMALL_STATE(17837)] = 682390,
  [SMALL_STATE(17838)] = 682404,
  [SMALL_STATE(17839)] = 682418,
  [SMALL_STATE(17840)] = 682432,
  [SMALL_STATE(17841)] = 682446,
  [SMALL_STATE(17842)] = 682460,
  [SMALL_STATE(17843)] = 682474,
  [SMALL_STATE(17844)] = 682488,
  [SMALL_STATE(17845)] = 682502,
  [SMALL_STATE(17846)] = 682516,
  [SMALL_STATE(17847)] = 682530,
  [SMALL_STATE(17848)] = 682544,
  [SMALL_STATE(17849)] = 682558,
  [SMALL_STATE(17850)] = 682572,
  [SMALL_STATE(17851)] = 682586,
  [SMALL_STATE(17852)] = 682600,
  [SMALL_STATE(17853)] = 682614,
  [SMALL_STATE(17854)] = 682628,
  [SMALL_STATE(17855)] = 682642,
  [SMALL_STATE(17856)] = 682656,
  [SMALL_STATE(17857)] = 682670,
  [SMALL_STATE(17858)] = 682684,
  [SMALL_STATE(17859)] = 682698,
  [SMALL_STATE(17860)] = 682712,
  [SMALL_STATE(17861)] = 682726,
  [SMALL_STATE(17862)] = 682740,
  [SMALL_STATE(17863)] = 682754,
  [SMALL_STATE(17864)] = 682768,
  [SMALL_STATE(17865)] = 682782,
  [SMALL_STATE(17866)] = 682796,
  [SMALL_STATE(17867)] = 682810,
  [SMALL_STATE(17868)] = 682824,
  [SMALL_STATE(17869)] = 682838,
  [SMALL_STATE(17870)] = 682852,
  [SMALL_STATE(17871)] = 682866,
  [SMALL_STATE(17872)] = 682880,
  [SMALL_STATE(17873)] = 682894,
  [SMALL_STATE(17874)] = 682908,
  [SMALL_STATE(17875)] = 682922,
  [SMALL_STATE(17876)] = 682936,
  [SMALL_STATE(17877)] = 682950,
  [SMALL_STATE(17878)] = 682964,
  [SMALL_STATE(17879)] = 682978,
  [SMALL_STATE(17880)] = 682992,
  [SMALL_STATE(17881)] = 683006,
  [SMALL_STATE(17882)] = 683020,
  [SMALL_STATE(17883)] = 683034,
  [SMALL_STATE(17884)] = 683048,
  [SMALL_STATE(17885)] = 683062,
  [SMALL_STATE(17886)] = 683076,
  [SMALL_STATE(17887)] = 683090,
  [SMALL_STATE(17888)] = 683104,
  [SMALL_STATE(17889)] = 683118,
  [SMALL_STATE(17890)] = 683132,
  [SMALL_STATE(17891)] = 683146,
  [SMALL_STATE(17892)] = 683160,
  [SMALL_STATE(17893)] = 683174,
  [SMALL_STATE(17894)] = 683188,
  [SMALL_STATE(17895)] = 683202,
  [SMALL_STATE(17896)] = 683216,
  [SMALL_STATE(17897)] = 683230,
  [SMALL_STATE(17898)] = 683244,
  [SMALL_STATE(17899)] = 683258,
  [SMALL_STATE(17900)] = 683272,
  [SMALL_STATE(17901)] = 683286,
  [SMALL_STATE(17902)] = 683300,
  [SMALL_STATE(17903)] = 683314,
  [SMALL_STATE(17904)] = 683328,
  [SMALL_STATE(17905)] = 683342,
  [SMALL_STATE(17906)] = 683356,
  [SMALL_STATE(17907)] = 683370,
  [SMALL_STATE(17908)] = 683384,
  [SMALL_STATE(17909)] = 683398,
  [SMALL_STATE(17910)] = 683412,
  [SMALL_STATE(17911)] = 683426,
  [SMALL_STATE(17912)] = 683440,
  [SMALL_STATE(17913)] = 683454,
  [SMALL_STATE(17914)] = 683468,
  [SMALL_STATE(17915)] = 683482,
  [SMALL_STATE(17916)] = 683496,
  [SMALL_STATE(17917)] = 683510,
  [SMALL_STATE(17918)] = 683524,
  [SMALL_STATE(17919)] = 683538,
  [SMALL_STATE(17920)] = 683552,
  [SMALL_STATE(17921)] = 683566,
  [SMALL_STATE(17922)] = 683580,
  [SMALL_STATE(17923)] = 683594,
  [SMALL_STATE(17924)] = 683608,
  [SMALL_STATE(17925)] = 683622,
  [SMALL_STATE(17926)] = 683636,
  [SMALL_STATE(17927)] = 683650,
  [SMALL_STATE(17928)] = 683664,
  [SMALL_STATE(17929)] = 683678,
  [SMALL_STATE(17930)] = 683692,
  [SMALL_STATE(17931)] = 683706,
  [SMALL_STATE(17932)] = 683720,
  [SMALL_STATE(17933)] = 683734,
  [SMALL_STATE(17934)] = 683748,
  [SMALL_STATE(17935)] = 683762,
  [SMALL_STATE(17936)] = 683776,
  [SMALL_STATE(17937)] = 683790,
  [SMALL_STATE(17938)] = 683804,
  [SMALL_STATE(17939)] = 683818,
  [SMALL_STATE(17940)] = 683832,
  [SMALL_STATE(17941)] = 683846,
  [SMALL_STATE(17942)] = 683860,
  [SMALL_STATE(17943)] = 683874,
  [SMALL_STATE(17944)] = 683888,
  [SMALL_STATE(17945)] = 683902,
  [SMALL_STATE(17946)] = 683916,
  [SMALL_STATE(17947)] = 683930,
  [SMALL_STATE(17948)] = 683944,
  [SMALL_STATE(17949)] = 683958,
  [SMALL_STATE(17950)] = 683972,
  [SMALL_STATE(17951)] = 683986,
  [SMALL_STATE(17952)] = 684000,
  [SMALL_STATE(17953)] = 684014,
  [SMALL_STATE(17954)] = 684028,
  [SMALL_STATE(17955)] = 684042,
  [SMALL_STATE(17956)] = 684056,
  [SMALL_STATE(17957)] = 684070,
  [SMALL_STATE(17958)] = 684084,
  [SMALL_STATE(17959)] = 684098,
  [SMALL_STATE(17960)] = 684112,
  [SMALL_STATE(17961)] = 684126,
  [SMALL_STATE(17962)] = 684140,
  [SMALL_STATE(17963)] = 684154,
  [SMALL_STATE(17964)] = 684168,
  [SMALL_STATE(17965)] = 684182,
  [SMALL_STATE(17966)] = 684196,
  [SMALL_STATE(17967)] = 684210,
  [SMALL_STATE(17968)] = 684224,
  [SMALL_STATE(17969)] = 684238,
  [SMALL_STATE(17970)] = 684252,
  [SMALL_STATE(17971)] = 684266,
  [SMALL_STATE(17972)] = 684280,
  [SMALL_STATE(17973)] = 684294,
  [SMALL_STATE(17974)] = 684308,
  [SMALL_STATE(17975)] = 684322,
  [SMALL_STATE(17976)] = 684336,
  [SMALL_STATE(17977)] = 684350,
  [SMALL_STATE(17978)] = 684364,
  [SMALL_STATE(17979)] = 684378,
  [SMALL_STATE(17980)] = 684392,
  [SMALL_STATE(17981)] = 684406,
  [SMALL_STATE(17982)] = 684420,
  [SMALL_STATE(17983)] = 684434,
  [SMALL_STATE(17984)] = 684448,
  [SMALL_STATE(17985)] = 684462,
  [SMALL_STATE(17986)] = 684476,
  [SMALL_STATE(17987)] = 684490,
  [SMALL_STATE(17988)] = 684504,
  [SMALL_STATE(17989)] = 684518,
  [SMALL_STATE(17990)] = 684532,
  [SMALL_STATE(17991)] = 684546,
  [SMALL_STATE(17992)] = 684560,
  [SMALL_STATE(17993)] = 684574,
  [SMALL_STATE(17994)] = 684588,
  [SMALL_STATE(17995)] = 684602,
  [SMALL_STATE(17996)] = 684616,
  [SMALL_STATE(17997)] = 684630,
  [SMALL_STATE(17998)] = 684644,
  [SMALL_STATE(17999)] = 684658,
  [SMALL_STATE(18000)] = 684672,
  [SMALL_STATE(18001)] = 684686,
  [SMALL_STATE(18002)] = 684700,
  [SMALL_STATE(18003)] = 684714,
  [SMALL_STATE(18004)] = 684728,
  [SMALL_STATE(18005)] = 684742,
  [SMALL_STATE(18006)] = 684756,
  [SMALL_STATE(18007)] = 684770,
  [SMALL_STATE(18008)] = 684784,
  [SMALL_STATE(18009)] = 684798,
  [SMALL_STATE(18010)] = 684812,
  [SMALL_STATE(18011)] = 684826,
  [SMALL_STATE(18012)] = 684840,
  [SMALL_STATE(18013)] = 684854,
  [SMALL_STATE(18014)] = 684868,
  [SMALL_STATE(18015)] = 684882,
  [SMALL_STATE(18016)] = 684896,
  [SMALL_STATE(18017)] = 684910,
  [SMALL_STATE(18018)] = 684924,
  [SMALL_STATE(18019)] = 684938,
  [SMALL_STATE(18020)] = 684952,
  [SMALL_STATE(18021)] = 684966,
  [SMALL_STATE(18022)] = 684980,
  [SMALL_STATE(18023)] = 684994,
  [SMALL_STATE(18024)] = 685008,
  [SMALL_STATE(18025)] = 685022,
  [SMALL_STATE(18026)] = 685036,
  [SMALL_STATE(18027)] = 685050,
  [SMALL_STATE(18028)] = 685064,
  [SMALL_STATE(18029)] = 685078,
  [SMALL_STATE(18030)] = 685092,
  [SMALL_STATE(18031)] = 685106,
  [SMALL_STATE(18032)] = 685120,
  [SMALL_STATE(18033)] = 685134,
  [SMALL_STATE(18034)] = 685148,
  [SMALL_STATE(18035)] = 685162,
  [SMALL_STATE(18036)] = 685176,
  [SMALL_STATE(18037)] = 685190,
  [SMALL_STATE(18038)] = 685204,
  [SMALL_STATE(18039)] = 685218,
  [SMALL_STATE(18040)] = 685232,
  [SMALL_STATE(18041)] = 685246,
  [SMALL_STATE(18042)] = 685260,
  [SMALL_STATE(18043)] = 685274,
  [SMALL_STATE(18044)] = 685288,
  [SMALL_STATE(18045)] = 685302,
  [SMALL_STATE(18046)] = 685316,
  [SMALL_STATE(18047)] = 685330,
  [SMALL_STATE(18048)] = 685344,
  [SMALL_STATE(18049)] = 685358,
  [SMALL_STATE(18050)] = 685372,
  [SMALL_STATE(18051)] = 685386,
  [SMALL_STATE(18052)] = 685400,
  [SMALL_STATE(18053)] = 685414,
  [SMALL_STATE(18054)] = 685428,
  [SMALL_STATE(18055)] = 685442,
  [SMALL_STATE(18056)] = 685456,
  [SMALL_STATE(18057)] = 685470,
  [SMALL_STATE(18058)] = 685484,
  [SMALL_STATE(18059)] = 685498,
  [SMALL_STATE(18060)] = 685512,
  [SMALL_STATE(18061)] = 685526,
  [SMALL_STATE(18062)] = 685540,
  [SMALL_STATE(18063)] = 685554,
  [SMALL_STATE(18064)] = 685568,
  [SMALL_STATE(18065)] = 685582,
  [SMALL_STATE(18066)] = 685596,
  [SMALL_STATE(18067)] = 685610,
  [SMALL_STATE(18068)] = 685624,
  [SMALL_STATE(18069)] = 685638,
  [SMALL_STATE(18070)] = 685652,
  [SMALL_STATE(18071)] = 685666,
  [SMALL_STATE(18072)] = 685680,
  [SMALL_STATE(18073)] = 685694,
  [SMALL_STATE(18074)] = 685708,
  [SMALL_STATE(18075)] = 685722,
  [SMALL_STATE(18076)] = 685736,
  [SMALL_STATE(18077)] = 685750,
  [SMALL_STATE(18078)] = 685764,
  [SMALL_STATE(18079)] = 685778,
  [SMALL_STATE(18080)] = 685792,
  [SMALL_STATE(18081)] = 685806,
  [SMALL_STATE(18082)] = 685820,
  [SMALL_STATE(18083)] = 685834,
  [SMALL_STATE(18084)] = 685848,
  [SMALL_STATE(18085)] = 685862,
  [SMALL_STATE(18086)] = 685876,
  [SMALL_STATE(18087)] = 685890,
  [SMALL_STATE(18088)] = 685904,
  [SMALL_STATE(18089)] = 685918,
  [SMALL_STATE(18090)] = 685932,
  [SMALL_STATE(18091)] = 685946,
  [SMALL_STATE(18092)] = 685960,
  [SMALL_STATE(18093)] = 685974,
  [SMALL_STATE(18094)] = 685988,
  [SMALL_STATE(18095)] = 686002,
  [SMALL_STATE(18096)] = 686016,
  [SMALL_STATE(18097)] = 686030,
  [SMALL_STATE(18098)] = 686044,
  [SMALL_STATE(18099)] = 686058,
  [SMALL_STATE(18100)] = 686072,
  [SMALL_STATE(18101)] = 686086,
  [SMALL_STATE(18102)] = 686100,
  [SMALL_STATE(18103)] = 686114,
  [SMALL_STATE(18104)] = 686128,
  [SMALL_STATE(18105)] = 686142,
  [SMALL_STATE(18106)] = 686156,
  [SMALL_STATE(18107)] = 686170,
  [SMALL_STATE(18108)] = 686184,
  [SMALL_STATE(18109)] = 686198,
  [SMALL_STATE(18110)] = 686212,
  [SMALL_STATE(18111)] = 686226,
  [SMALL_STATE(18112)] = 686240,
  [SMALL_STATE(18113)] = 686254,
  [SMALL_STATE(18114)] = 686268,
  [SMALL_STATE(18115)] = 686282,
  [SMALL_STATE(18116)] = 686296,
  [SMALL_STATE(18117)] = 686310,
  [SMALL_STATE(18118)] = 686324,
  [SMALL_STATE(18119)] = 686338,
  [SMALL_STATE(18120)] = 686352,
  [SMALL_STATE(18121)] = 686366,
  [SMALL_STATE(18122)] = 686380,
  [SMALL_STATE(18123)] = 686394,
  [SMALL_STATE(18124)] = 686408,
  [SMALL_STATE(18125)] = 686422,
  [SMALL_STATE(18126)] = 686436,
  [SMALL_STATE(18127)] = 686450,
  [SMALL_STATE(18128)] = 686464,
  [SMALL_STATE(18129)] = 686478,
  [SMALL_STATE(18130)] = 686492,
  [SMALL_STATE(18131)] = 686506,
  [SMALL_STATE(18132)] = 686520,
  [SMALL_STATE(18133)] = 686534,
  [SMALL_STATE(18134)] = 686548,
  [SMALL_STATE(18135)] = 686562,
  [SMALL_STATE(18136)] = 686576,
  [SMALL_STATE(18137)] = 686590,
  [SMALL_STATE(18138)] = 686604,
  [SMALL_STATE(18139)] = 686618,
  [SMALL_STATE(18140)] = 686632,
  [SMALL_STATE(18141)] = 686646,
  [SMALL_STATE(18142)] = 686660,
  [SMALL_STATE(18143)] = 686674,
  [SMALL_STATE(18144)] = 686688,
  [SMALL_STATE(18145)] = 686702,
  [SMALL_STATE(18146)] = 686716,
  [SMALL_STATE(18147)] = 686730,
  [SMALL_STATE(18148)] = 686744,
  [SMALL_STATE(18149)] = 686758,
  [SMALL_STATE(18150)] = 686772,
  [SMALL_STATE(18151)] = 686786,
  [SMALL_STATE(18152)] = 686800,
  [SMALL_STATE(18153)] = 686814,
  [SMALL_STATE(18154)] = 686828,
  [SMALL_STATE(18155)] = 686842,
  [SMALL_STATE(18156)] = 686856,
  [SMALL_STATE(18157)] = 686870,
  [SMALL_STATE(18158)] = 686884,
  [SMALL_STATE(18159)] = 686898,
  [SMALL_STATE(18160)] = 686912,
  [SMALL_STATE(18161)] = 686926,
  [SMALL_STATE(18162)] = 686940,
  [SMALL_STATE(18163)] = 686954,
  [SMALL_STATE(18164)] = 686968,
  [SMALL_STATE(18165)] = 686982,
  [SMALL_STATE(18166)] = 686996,
  [SMALL_STATE(18167)] = 687010,
  [SMALL_STATE(18168)] = 687024,
  [SMALL_STATE(18169)] = 687038,
  [SMALL_STATE(18170)] = 687052,
  [SMALL_STATE(18171)] = 687066,
  [SMALL_STATE(18172)] = 687080,
  [SMALL_STATE(18173)] = 687094,
  [SMALL_STATE(18174)] = 687108,
  [SMALL_STATE(18175)] = 687122,
  [SMALL_STATE(18176)] = 687136,
  [SMALL_STATE(18177)] = 687150,
  [SMALL_STATE(18178)] = 687164,
  [SMALL_STATE(18179)] = 687178,
  [SMALL_STATE(18180)] = 687192,
  [SMALL_STATE(18181)] = 687206,
  [SMALL_STATE(18182)] = 687220,
  [SMALL_STATE(18183)] = 687234,
  [SMALL_STATE(18184)] = 687248,
  [SMALL_STATE(18185)] = 687262,
  [SMALL_STATE(18186)] = 687276,
  [SMALL_STATE(18187)] = 687290,
  [SMALL_STATE(18188)] = 687304,
  [SMALL_STATE(18189)] = 687318,
  [SMALL_STATE(18190)] = 687332,
  [SMALL_STATE(18191)] = 687346,
  [SMALL_STATE(18192)] = 687360,
  [SMALL_STATE(18193)] = 687374,
  [SMALL_STATE(18194)] = 687388,
  [SMALL_STATE(18195)] = 687402,
  [SMALL_STATE(18196)] = 687416,
  [SMALL_STATE(18197)] = 687430,
  [SMALL_STATE(18198)] = 687444,
  [SMALL_STATE(18199)] = 687458,
  [SMALL_STATE(18200)] = 687472,
  [SMALL_STATE(18201)] = 687486,
  [SMALL_STATE(18202)] = 687500,
  [SMALL_STATE(18203)] = 687514,
  [SMALL_STATE(18204)] = 687528,
  [SMALL_STATE(18205)] = 687542,
  [SMALL_STATE(18206)] = 687556,
  [SMALL_STATE(18207)] = 687570,
  [SMALL_STATE(18208)] = 687584,
  [SMALL_STATE(18209)] = 687598,
  [SMALL_STATE(18210)] = 687612,
  [SMALL_STATE(18211)] = 687626,
  [SMALL_STATE(18212)] = 687640,
  [SMALL_STATE(18213)] = 687654,
  [SMALL_STATE(18214)] = 687668,
  [SMALL_STATE(18215)] = 687682,
  [SMALL_STATE(18216)] = 687696,
  [SMALL_STATE(18217)] = 687710,
  [SMALL_STATE(18218)] = 687724,
  [SMALL_STATE(18219)] = 687738,
  [SMALL_STATE(18220)] = 687752,
  [SMALL_STATE(18221)] = 687766,
  [SMALL_STATE(18222)] = 687780,
  [SMALL_STATE(18223)] = 687794,
  [SMALL_STATE(18224)] = 687808,
  [SMALL_STATE(18225)] = 687822,
  [SMALL_STATE(18226)] = 687836,
  [SMALL_STATE(18227)] = 687850,
  [SMALL_STATE(18228)] = 687864,
  [SMALL_STATE(18229)] = 687878,
  [SMALL_STATE(18230)] = 687892,
  [SMALL_STATE(18231)] = 687906,
  [SMALL_STATE(18232)] = 687920,
  [SMALL_STATE(18233)] = 687934,
  [SMALL_STATE(18234)] = 687948,
  [SMALL_STATE(18235)] = 687962,
  [SMALL_STATE(18236)] = 687976,
  [SMALL_STATE(18237)] = 687990,
  [SMALL_STATE(18238)] = 688004,
  [SMALL_STATE(18239)] = 688018,
  [SMALL_STATE(18240)] = 688032,
  [SMALL_STATE(18241)] = 688046,
  [SMALL_STATE(18242)] = 688060,
  [SMALL_STATE(18243)] = 688074,
  [SMALL_STATE(18244)] = 688088,
  [SMALL_STATE(18245)] = 688102,
  [SMALL_STATE(18246)] = 688116,
  [SMALL_STATE(18247)] = 688130,
  [SMALL_STATE(18248)] = 688144,
  [SMALL_STATE(18249)] = 688158,
  [SMALL_STATE(18250)] = 688172,
  [SMALL_STATE(18251)] = 688186,
  [SMALL_STATE(18252)] = 688200,
  [SMALL_STATE(18253)] = 688214,
  [SMALL_STATE(18254)] = 688228,
  [SMALL_STATE(18255)] = 688242,
  [SMALL_STATE(18256)] = 688256,
  [SMALL_STATE(18257)] = 688270,
  [SMALL_STATE(18258)] = 688284,
  [SMALL_STATE(18259)] = 688298,
  [SMALL_STATE(18260)] = 688312,
  [SMALL_STATE(18261)] = 688326,
  [SMALL_STATE(18262)] = 688340,
  [SMALL_STATE(18263)] = 688354,
  [SMALL_STATE(18264)] = 688368,
  [SMALL_STATE(18265)] = 688382,
  [SMALL_STATE(18266)] = 688396,
  [SMALL_STATE(18267)] = 688410,
  [SMALL_STATE(18268)] = 688424,
  [SMALL_STATE(18269)] = 688438,
  [SMALL_STATE(18270)] = 688452,
  [SMALL_STATE(18271)] = 688466,
  [SMALL_STATE(18272)] = 688480,
  [SMALL_STATE(18273)] = 688494,
  [SMALL_STATE(18274)] = 688508,
  [SMALL_STATE(18275)] = 688522,
  [SMALL_STATE(18276)] = 688536,
  [SMALL_STATE(18277)] = 688550,
  [SMALL_STATE(18278)] = 688564,
  [SMALL_STATE(18279)] = 688578,
  [SMALL_STATE(18280)] = 688592,
  [SMALL_STATE(18281)] = 688606,
  [SMALL_STATE(18282)] = 688620,
  [SMALL_STATE(18283)] = 688634,
  [SMALL_STATE(18284)] = 688648,
  [SMALL_STATE(18285)] = 688662,
  [SMALL_STATE(18286)] = 688676,
  [SMALL_STATE(18287)] = 688690,
  [SMALL_STATE(18288)] = 688704,
  [SMALL_STATE(18289)] = 688718,
  [SMALL_STATE(18290)] = 688732,
  [SMALL_STATE(18291)] = 688746,
  [SMALL_STATE(18292)] = 688760,
  [SMALL_STATE(18293)] = 688774,
  [SMALL_STATE(18294)] = 688788,
  [SMALL_STATE(18295)] = 688802,
  [SMALL_STATE(18296)] = 688816,
  [SMALL_STATE(18297)] = 688830,
  [SMALL_STATE(18298)] = 688844,
  [SMALL_STATE(18299)] = 688858,
  [SMALL_STATE(18300)] = 688872,
  [SMALL_STATE(18301)] = 688886,
  [SMALL_STATE(18302)] = 688900,
  [SMALL_STATE(18303)] = 688914,
  [SMALL_STATE(18304)] = 688928,
  [SMALL_STATE(18305)] = 688942,
  [SMALL_STATE(18306)] = 688956,
  [SMALL_STATE(18307)] = 688970,
  [SMALL_STATE(18308)] = 688984,
  [SMALL_STATE(18309)] = 688998,
  [SMALL_STATE(18310)] = 689012,
  [SMALL_STATE(18311)] = 689026,
  [SMALL_STATE(18312)] = 689040,
  [SMALL_STATE(18313)] = 689054,
  [SMALL_STATE(18314)] = 689068,
  [SMALL_STATE(18315)] = 689082,
  [SMALL_STATE(18316)] = 689096,
  [SMALL_STATE(18317)] = 689110,
  [SMALL_STATE(18318)] = 689124,
  [SMALL_STATE(18319)] = 689138,
  [SMALL_STATE(18320)] = 689152,
  [SMALL_STATE(18321)] = 689166,
  [SMALL_STATE(18322)] = 689180,
  [SMALL_STATE(18323)] = 689194,
  [SMALL_STATE(18324)] = 689208,
  [SMALL_STATE(18325)] = 689222,
  [SMALL_STATE(18326)] = 689236,
  [SMALL_STATE(18327)] = 689250,
  [SMALL_STATE(18328)] = 689264,
  [SMALL_STATE(18329)] = 689278,
  [SMALL_STATE(18330)] = 689292,
  [SMALL_STATE(18331)] = 689306,
  [SMALL_STATE(18332)] = 689320,
  [SMALL_STATE(18333)] = 689334,
  [SMALL_STATE(18334)] = 689348,
  [SMALL_STATE(18335)] = 689362,
  [SMALL_STATE(18336)] = 689376,
  [SMALL_STATE(18337)] = 689390,
  [SMALL_STATE(18338)] = 689404,
  [SMALL_STATE(18339)] = 689418,
  [SMALL_STATE(18340)] = 689432,
  [SMALL_STATE(18341)] = 689446,
  [SMALL_STATE(18342)] = 689460,
  [SMALL_STATE(18343)] = 689474,
  [SMALL_STATE(18344)] = 689488,
  [SMALL_STATE(18345)] = 689502,
  [SMALL_STATE(18346)] = 689516,
  [SMALL_STATE(18347)] = 689530,
  [SMALL_STATE(18348)] = 689544,
  [SMALL_STATE(18349)] = 689558,
  [SMALL_STATE(18350)] = 689572,
  [SMALL_STATE(18351)] = 689586,
  [SMALL_STATE(18352)] = 689600,
  [SMALL_STATE(18353)] = 689614,
  [SMALL_STATE(18354)] = 689628,
  [SMALL_STATE(18355)] = 689642,
  [SMALL_STATE(18356)] = 689656,
  [SMALL_STATE(18357)] = 689670,
  [SMALL_STATE(18358)] = 689684,
  [SMALL_STATE(18359)] = 689698,
  [SMALL_STATE(18360)] = 689712,
  [SMALL_STATE(18361)] = 689726,
  [SMALL_STATE(18362)] = 689740,
  [SMALL_STATE(18363)] = 689754,
  [SMALL_STATE(18364)] = 689768,
  [SMALL_STATE(18365)] = 689782,
  [SMALL_STATE(18366)] = 689796,
  [SMALL_STATE(18367)] = 689810,
  [SMALL_STATE(18368)] = 689824,
  [SMALL_STATE(18369)] = 689838,
  [SMALL_STATE(18370)] = 689852,
  [SMALL_STATE(18371)] = 689866,
  [SMALL_STATE(18372)] = 689880,
  [SMALL_STATE(18373)] = 689894,
  [SMALL_STATE(18374)] = 689908,
  [SMALL_STATE(18375)] = 689922,
  [SMALL_STATE(18376)] = 689936,
  [SMALL_STATE(18377)] = 689950,
  [SMALL_STATE(18378)] = 689964,
  [SMALL_STATE(18379)] = 689978,
  [SMALL_STATE(18380)] = 689992,
  [SMALL_STATE(18381)] = 690006,
  [SMALL_STATE(18382)] = 690020,
  [SMALL_STATE(18383)] = 690034,
  [SMALL_STATE(18384)] = 690048,
  [SMALL_STATE(18385)] = 690062,
  [SMALL_STATE(18386)] = 690076,
  [SMALL_STATE(18387)] = 690090,
  [SMALL_STATE(18388)] = 690104,
  [SMALL_STATE(18389)] = 690118,
  [SMALL_STATE(18390)] = 690132,
  [SMALL_STATE(18391)] = 690146,
  [SMALL_STATE(18392)] = 690160,
  [SMALL_STATE(18393)] = 690174,
  [SMALL_STATE(18394)] = 690188,
  [SMALL_STATE(18395)] = 690202,
  [SMALL_STATE(18396)] = 690216,
  [SMALL_STATE(18397)] = 690230,
  [SMALL_STATE(18398)] = 690244,
  [SMALL_STATE(18399)] = 690258,
  [SMALL_STATE(18400)] = 690272,
  [SMALL_STATE(18401)] = 690286,
  [SMALL_STATE(18402)] = 690300,
  [SMALL_STATE(18403)] = 690314,
  [SMALL_STATE(18404)] = 690328,
  [SMALL_STATE(18405)] = 690342,
  [SMALL_STATE(18406)] = 690356,
  [SMALL_STATE(18407)] = 690370,
  [SMALL_STATE(18408)] = 690384,
  [SMALL_STATE(18409)] = 690398,
  [SMALL_STATE(18410)] = 690412,
  [SMALL_STATE(18411)] = 690426,
  [SMALL_STATE(18412)] = 690440,
  [SMALL_STATE(18413)] = 690454,
  [SMALL_STATE(18414)] = 690468,
  [SMALL_STATE(18415)] = 690482,
  [SMALL_STATE(18416)] = 690496,
  [SMALL_STATE(18417)] = 690510,
  [SMALL_STATE(18418)] = 690524,
  [SMALL_STATE(18419)] = 690538,
  [SMALL_STATE(18420)] = 690552,
  [SMALL_STATE(18421)] = 690566,
  [SMALL_STATE(18422)] = 690580,
  [SMALL_STATE(18423)] = 690594,
  [SMALL_STATE(18424)] = 690608,
  [SMALL_STATE(18425)] = 690622,
  [SMALL_STATE(18426)] = 690636,
  [SMALL_STATE(18427)] = 690650,
  [SMALL_STATE(18428)] = 690664,
  [SMALL_STATE(18429)] = 690678,
  [SMALL_STATE(18430)] = 690692,
  [SMALL_STATE(18431)] = 690706,
  [SMALL_STATE(18432)] = 690720,
  [SMALL_STATE(18433)] = 690734,
  [SMALL_STATE(18434)] = 690748,
  [SMALL_STATE(18435)] = 690762,
  [SMALL_STATE(18436)] = 690776,
  [SMALL_STATE(18437)] = 690790,
  [SMALL_STATE(18438)] = 690804,
  [SMALL_STATE(18439)] = 690818,
  [SMALL_STATE(18440)] = 690832,
  [SMALL_STATE(18441)] = 690846,
  [SMALL_STATE(18442)] = 690860,
  [SMALL_STATE(18443)] = 690874,
  [SMALL_STATE(18444)] = 690888,
  [SMALL_STATE(18445)] = 690902,
  [SMALL_STATE(18446)] = 690916,
  [SMALL_STATE(18447)] = 690930,
  [SMALL_STATE(18448)] = 690944,
  [SMALL_STATE(18449)] = 690958,
  [SMALL_STATE(18450)] = 690972,
  [SMALL_STATE(18451)] = 690986,
  [SMALL_STATE(18452)] = 691000,
  [SMALL_STATE(18453)] = 691014,
  [SMALL_STATE(18454)] = 691028,
  [SMALL_STATE(18455)] = 691042,
  [SMALL_STATE(18456)] = 691056,
  [SMALL_STATE(18457)] = 691070,
  [SMALL_STATE(18458)] = 691084,
  [SMALL_STATE(18459)] = 691098,
  [SMALL_STATE(18460)] = 691112,
  [SMALL_STATE(18461)] = 691126,
  [SMALL_STATE(18462)] = 691140,
  [SMALL_STATE(18463)] = 691154,
  [SMALL_STATE(18464)] = 691168,
  [SMALL_STATE(18465)] = 691182,
  [SMALL_STATE(18466)] = 691196,
  [SMALL_STATE(18467)] = 691210,
  [SMALL_STATE(18468)] = 691224,
  [SMALL_STATE(18469)] = 691238,
  [SMALL_STATE(18470)] = 691252,
  [SMALL_STATE(18471)] = 691266,
  [SMALL_STATE(18472)] = 691280,
  [SMALL_STATE(18473)] = 691294,
  [SMALL_STATE(18474)] = 691308,
  [SMALL_STATE(18475)] = 691322,
  [SMALL_STATE(18476)] = 691336,
  [SMALL_STATE(18477)] = 691350,
  [SMALL_STATE(18478)] = 691364,
  [SMALL_STATE(18479)] = 691378,
  [SMALL_STATE(18480)] = 691392,
  [SMALL_STATE(18481)] = 691406,
  [SMALL_STATE(18482)] = 691420,
  [SMALL_STATE(18483)] = 691434,
  [SMALL_STATE(18484)] = 691448,
  [SMALL_STATE(18485)] = 691462,
  [SMALL_STATE(18486)] = 691476,
  [SMALL_STATE(18487)] = 691490,
  [SMALL_STATE(18488)] = 691504,
  [SMALL_STATE(18489)] = 691518,
  [SMALL_STATE(18490)] = 691532,
  [SMALL_STATE(18491)] = 691546,
  [SMALL_STATE(18492)] = 691560,
  [SMALL_STATE(18493)] = 691574,
  [SMALL_STATE(18494)] = 691588,
  [SMALL_STATE(18495)] = 691602,
  [SMALL_STATE(18496)] = 691616,
  [SMALL_STATE(18497)] = 691630,
  [SMALL_STATE(18498)] = 691644,
  [SMALL_STATE(18499)] = 691658,
  [SMALL_STATE(18500)] = 691672,
  [SMALL_STATE(18501)] = 691686,
  [SMALL_STATE(18502)] = 691700,
  [SMALL_STATE(18503)] = 691714,
  [SMALL_STATE(18504)] = 691728,
  [SMALL_STATE(18505)] = 691742,
  [SMALL_STATE(18506)] = 691756,
  [SMALL_STATE(18507)] = 691770,
  [SMALL_STATE(18508)] = 691784,
  [SMALL_STATE(18509)] = 691798,
  [SMALL_STATE(18510)] = 691812,
  [SMALL_STATE(18511)] = 691826,
  [SMALL_STATE(18512)] = 691840,
  [SMALL_STATE(18513)] = 691854,
  [SMALL_STATE(18514)] = 691868,
  [SMALL_STATE(18515)] = 691882,
  [SMALL_STATE(18516)] = 691896,
  [SMALL_STATE(18517)] = 691910,
  [SMALL_STATE(18518)] = 691924,
  [SMALL_STATE(18519)] = 691938,
  [SMALL_STATE(18520)] = 691952,
  [SMALL_STATE(18521)] = 691966,
  [SMALL_STATE(18522)] = 691980,
  [SMALL_STATE(18523)] = 691994,
  [SMALL_STATE(18524)] = 692008,
  [SMALL_STATE(18525)] = 692022,
  [SMALL_STATE(18526)] = 692036,
  [SMALL_STATE(18527)] = 692050,
  [SMALL_STATE(18528)] = 692064,
  [SMALL_STATE(18529)] = 692078,
  [SMALL_STATE(18530)] = 692092,
  [SMALL_STATE(18531)] = 692106,
  [SMALL_STATE(18532)] = 692120,
  [SMALL_STATE(18533)] = 692134,
  [SMALL_STATE(18534)] = 692148,
  [SMALL_STATE(18535)] = 692152,
  [SMALL_STATE(18536)] = 692156,
  [SMALL_STATE(18537)] = 692160,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15212),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15194),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 0),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4608),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12943),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16687),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12058),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12937),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12936),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12935),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8226),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4300),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12062),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12064),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2228),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4326),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(763),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(954),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4008),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(968),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4457),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4339),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9958),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9046),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9948),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12071),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12916),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8198),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6735),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5110),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5111),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2414),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4315),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4308),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4307),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1863),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2269),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12914),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12912),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4608),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9679),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6859),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6859),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6860),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10468),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(682),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2371),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2401),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2465),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6791),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5241),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8577),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6459),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4295),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2315),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4324),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(699),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1006),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4009),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4534),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4328),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12092),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12884),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6825),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5205),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2412),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4309),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4288),
  [145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4274),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1858),
  [149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15109),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2324),
  [153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12845),
  [155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12846),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5241),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9153),
  [161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8201),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8201),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8206),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8208),
  [169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2327),
  [173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8192),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6504),
  [179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8768),
  [181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10378),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11402),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9008),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11202),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8525),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11009),
  [193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13622),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14032),
  [197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7911),
  [199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11297),
  [201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11803),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11120),
  [205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11239),
  [207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10014),
  [209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9085),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7832),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7177),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5701),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13675),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12113),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14493),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6816),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10890),
  [227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7817),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6186),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9911),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12196),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11944),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17991),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10662),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8543),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8983),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10783),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10302),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13185),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11534),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13857),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8146),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9655),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10608),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11354),
  [263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9205),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10819),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14434),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9790),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9683),
  [273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6659),
  [275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11139),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13416),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11790),
  [281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11230),
  [283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12532),
  [285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11220),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11947),
  [289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11759),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8729),
  [293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9507),
  [295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8605),
  [297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10876),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10477),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9435),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11646),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9169),
  [307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9325),
  [309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10223),
  [311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7745),
  [313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8470),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11088),
  [317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6206),
  [319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10446),
  [321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10397),
  [323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13533),
  [325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10140),
  [327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5396),
  [329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7096),
  [331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10693),
  [333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10206),
  [335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14433),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11079),
  [339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13297),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9709),
  [343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6125),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10927),
  [347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11135),
  [349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9680),
  [351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10152),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8385),
  [355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10684),
  [357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11169),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10880),
  [361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8515),
  [363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5844),
  [365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10356),
  [367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10715),
  [369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16673),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10768),
  [373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13582),
  [375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11887),
  [377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14053),
  [379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13987),
  [381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10631),
  [383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10393),
  [385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9066),
  [387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10055),
  [389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10563),
  [391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11095),
  [393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9619),
  [395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10610),
  [397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11481),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12331),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10106),
  [403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13677),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13367),
  [407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10111),
  [409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5764),
  [411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6869),
  [413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9500),
  [415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14822),
  [417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13117),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10748),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10208),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8728),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7612),
  [427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9103),
  [429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4195),
  [431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9753),
  [433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7025),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9894),
  [437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6572),
  [439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5665),
  [441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8840),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9898),
  [445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 4),
  [447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8477),
  [449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9666),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9874),
  [453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9134),
  [455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 3),
  [457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8236),
  [459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10028),
  [461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10522),
  [463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 2),
  [465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6846),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10964),
  [469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7715),
  [471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6772),
  [473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7219),
  [475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8688),
  [477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9573),
  [479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7679),
  [481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8809),
  [483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 1),
  [485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10193),
  [487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8970),
  [489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5518),
  [491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12634),
  [493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4201),
  [497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12802),
  [499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12814),
  [501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12815),
  [503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8189),
  [505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4305),
  [507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12145),
  [509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12144),
  [511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2209),
  [513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4323),
  [515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(816),
  [517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1070),
  [519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4004),
  [521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(999),
  [523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4523),
  [525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4329),
  [527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12133),
  [529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12566),
  [531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7012),
  [533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5179),
  [535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2413),
  [537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4289),
  [539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4291),
  [541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4304),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1870),
  [545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14855),
  [547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2359),
  [549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12527),
  [551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12648),
  [553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5518),
  [555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9855),
  [557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9763),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9763),
  [561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9770),
  [563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9857),
  [565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(832),
  [567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2210),
  [569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2298),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9757),
  [573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16563),
  [575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8994),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18336),
  [579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9143),
  [581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14687),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16599),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16601),
  [587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 2, .production_id = 24),
  [589] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_clause, 2, .production_id = 24),
  [591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4311),
  [593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2368),
  [595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(702),
  [597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1226),
  [599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4035),
  [601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1015),
  [603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4330),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5207),
  [607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14823),
  [609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2348),
  [611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9196),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(650),
  [615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2193),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14950),
  [619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14886),
  [621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18217),
  [625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4273),
  [627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2238),
  [629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(809),
  [631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1436),
  [633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3991),
  [635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1558),
  [637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4338),
  [639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5377),
  [641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14763),
  [643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2330),
  [645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9197),
  [647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(672),
  [649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2391),
  [651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14743),
  [653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14968),
  [655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11629),
  [657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5197),
  [659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__block, 2),
  [661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__block, 2),
  [663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14996),
  [665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14977),
  [667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__block, 3),
  [669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14620),
  [671] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__block, 3),
  [673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_block, 3),
  [675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11471),
  [677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6028),
  [679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_block, 2),
  [681] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(5518),
  [684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1),
  [686] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(138),
  [689] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(8189),
  [692] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(2209),
  [695] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(6028),
  [698] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(816),
  [701] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(1070),
  [704] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(4004),
  [707] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(999),
  [710] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(4523),
  [713] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(13384),
  [716] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(2413),
  [719] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(1870),
  [722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1),
  [724] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(2359),
  [727] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(12527),
  [730] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(12648),
  [733] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(5518),
  [736] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(9855),
  [739] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(9763),
  [742] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(9763),
  [745] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(9770),
  [748] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(9857),
  [751] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(832),
  [754] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(2210),
  [757] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(2298),
  [760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [762] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(9757),
  [765] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(5241),
  [768] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(141),
  [771] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(6459),
  [774] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(2315),
  [777] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(5197),
  [780] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(699),
  [783] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(1006),
  [786] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(4009),
  [789] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(1005),
  [792] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(4534),
  [795] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(13265),
  [798] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(2412),
  [801] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(1858),
  [804] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(2324),
  [807] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(12845),
  [810] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(12846),
  [813] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(5241),
  [816] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(9753),
  [819] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(8201),
  [822] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(8201),
  [825] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(8206),
  [828] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(8208),
  [831] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(727),
  [834] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(2327),
  [837] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(2401),
  [840] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(184),
  [843] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_self_type, 2, .dynamic_precedence = 1), SHIFT(8192),
  [846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5497),
  [848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [850] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 1),
  [852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7781),
  [854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2366),
  [856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5673),
  [858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(821),
  [860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(928),
  [862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3981),
  [864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(926),
  [866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4466),
  [868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1861),
  [870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2349),
  [872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12572),
  [874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12574),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5497),
  [878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8785),
  [880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8787),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8787),
  [884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8789),
  [886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9879),
  [888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(711),
  [890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2329),
  [892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2175),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8762),
  [896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(776),
  [898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(759),
  [900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(837),
  [902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(825),
  [904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4567),
  [906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10525),
  [908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postfix_expression, 2),
  [912] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_postfix_expression, 2),
  [914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4868),
  [916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2381),
  [918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4544),
  [920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(811),
  [922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4480),
  [924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12976),
  [926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2592),
  [928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1869),
  [930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12724),
  [932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12543),
  [934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4567),
  [936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4827),
  [938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5516),
  [940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5516),
  [942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5514),
  [944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5679),
  [946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5524),
  [948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4702),
  [950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10619),
  [952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5273),
  [956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2362),
  [958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4634),
  [960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4502),
  [962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2647),
  [964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12830),
  [968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12882),
  [970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4702),
  [972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5143),
  [974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6446),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6446),
  [978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6447),
  [980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6762),
  [982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6259),
  [984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4771),
  [986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10486),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5142),
  [992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2375),
  [994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4781),
  [996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4497),
  [998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2640),
  [1000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1876),
  [1002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12728),
  [1004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12475),
  [1006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4771),
  [1008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5146),
  [1010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6137),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6137),
  [1014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6141),
  [1016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6583),
  [1018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6120),
  [1020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4918),
  [1022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10568),
  [1024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [1026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5707),
  [1028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2399),
  [1030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4884),
  [1032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4490),
  [1034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2652),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1872),
  [1038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12628),
  [1040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12616),
  [1042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4918),
  [1044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5737),
  [1046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7320),
  [1048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7320),
  [1050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7317),
  [1052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6845),
  [1054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7334),
  [1056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5063),
  [1058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10634),
  [1060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [1062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5991),
  [1064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2143),
  [1066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5038),
  [1068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4520),
  [1070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2654),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [1074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12569),
  [1076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12908),
  [1078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5063),
  [1080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6041),
  [1082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6900),
  [1084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6900),
  [1086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6899),
  [1088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7233),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6912),
  [1092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5026),
  [1094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10480),
  [1096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [1098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6027),
  [1100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2334),
  [1102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4989),
  [1104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4511),
  [1106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2653),
  [1108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [1110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12560),
  [1112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12689),
  [1114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5026),
  [1116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5819),
  [1118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7087),
  [1120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7087),
  [1122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7086),
  [1124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7018),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7092),
  [1128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5283),
  [1130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10496),
  [1132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [1134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6236),
  [1136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2111),
  [1138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5285),
  [1140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4508),
  [1142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2650),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1877),
  [1146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12615),
  [1148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12901),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5283),
  [1152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6445),
  [1154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7970),
  [1156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7970),
  [1158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7969),
  [1160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7727),
  [1162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7987),
  [1164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5247),
  [1166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10516),
  [1168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [1170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6668),
  [1172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2389),
  [1174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5250),
  [1176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4531),
  [1178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2904),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1885),
  [1182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12900),
  [1184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12840),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5247),
  [1188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6749),
  [1190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7888),
  [1192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7888),
  [1194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7503),
  [1196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7676),
  [1198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7882),
  [1200] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_expression, 1),
  [1202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_expression, 1),
  [1204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(730),
  [1206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1627),
  [1208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4030),
  [1210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1100),
  [1212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13329),
  [1214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2233),
  [1216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7348),
  [1218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(587),
  [1220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2117),
  [1222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2303),
  [1224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6072),
  [1226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10584),
  [1228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [1230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7347),
  [1232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2232),
  [1234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5498),
  [1236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4484),
  [1238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2770),
  [1240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [1242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12749),
  [1244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12722),
  [1246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6072),
  [1248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6940),
  [1250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8833),
  [1252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8833),
  [1254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8834),
  [1256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8806),
  [1258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8813),
  [1260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(755),
  [1262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1676),
  [1264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4014),
  [1266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1480),
  [1268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13025),
  [1270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2382),
  [1272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7323),
  [1274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(589),
  [1276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2386),
  [1278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2099),
  [1280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4522),
  [1282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10501),
  [1284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [1286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7570),
  [1288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2293),
  [1290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4526),
  [1292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4453),
  [1294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2688),
  [1296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1865),
  [1298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12863),
  [1300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12627),
  [1302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4522),
  [1304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8150),
  [1306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5184),
  [1308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5184),
  [1310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5185),
  [1312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8958),
  [1314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5182),
  [1316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(695),
  [1318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1596),
  [1320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4032),
  [1322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1435),
  [1324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13119),
  [1326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2294),
  [1328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7371),
  [1330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(591),
  [1332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2333),
  [1334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2393),
  [1336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5824),
  [1338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10458),
  [1340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [1342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7280),
  [1344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2311),
  [1346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5825),
  [1348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4530),
  [1350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2875),
  [1352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1879),
  [1354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12946),
  [1356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12784),
  [1358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5824),
  [1360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6901),
  [1362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8349),
  [1364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8349),
  [1366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8356),
  [1368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8837),
  [1370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8342),
  [1372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(911),
  [1374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4015),
  [1376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1135),
  [1378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13209),
  [1380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6669),
  [1382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(593),
  [1384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2357),
  [1386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1452),
  [1388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4001),
  [1390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1673),
  [1392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13365),
  [1394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2131),
  [1396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6826),
  [1398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(594),
  [1400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2281),
  [1402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2183),
  [1404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(834),
  [1406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1352),
  [1408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4007),
  [1410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1227),
  [1412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13357),
  [1414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2145),
  [1416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8193),
  [1418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(595),
  [1420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2220),
  [1422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2153),
  [1424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5939),
  [1426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10523),
  [1428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [1430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6910),
  [1432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2350),
  [1434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5929),
  [1436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4518),
  [1438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3397),
  [1440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1867),
  [1442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12602),
  [1444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12576),
  [1446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5939),
  [1448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6993),
  [1450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8462),
  [1452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8462),
  [1454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8464),
  [1456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8484),
  [1458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8458),
  [1460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(854),
  [1462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1376),
  [1464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3998),
  [1466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1576),
  [1468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13349),
  [1470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2192),
  [1472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7647),
  [1474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(597),
  [1476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2177),
  [1478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2221),
  [1480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(771),
  [1482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1394),
  [1484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3997),
  [1486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [1488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13404),
  [1490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2199),
  [1492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8004),
  [1494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(598),
  [1496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2406),
  [1498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1173),
  [1500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3994),
  [1502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1375),
  [1504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13283),
  [1506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6704),
  [1508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(599),
  [1510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2385),
  [1512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4581),
  [1514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10564),
  [1516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [1518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8830),
  [1520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2267),
  [1522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4553),
  [1524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4455),
  [1526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3384),
  [1528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1881),
  [1530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12759),
  [1532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12907),
  [1534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4581),
  [1536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8866),
  [1538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5996),
  [1540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5996),
  [1542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5993),
  [1544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9672),
  [1546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6005),
  [1548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [1550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1335),
  [1552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3996),
  [1554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1535),
  [1556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13348),
  [1558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2268),
  [1560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7731),
  [1562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(601),
  [1564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2118),
  [1566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2201),
  [1568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5783),
  [1570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10646),
  [1572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [1574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7037),
  [1576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2198),
  [1578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5715),
  [1580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4500),
  [1582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3595),
  [1584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1862),
  [1586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12647),
  [1588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12803),
  [1590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5783),
  [1592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7410),
  [1594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8446),
  [1596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8446),
  [1598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8447),
  [1600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8679),
  [1602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8429),
  [1604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(947),
  [1606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4017),
  [1608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(952),
  [1610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13165),
  [1612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6781),
  [1614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(603),
  [1616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2158),
  [1618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(794),
  [1620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1030),
  [1622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4020),
  [1624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1256),
  [1626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13241),
  [1628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2369),
  [1630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8196),
  [1632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(604),
  [1634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2187),
  [1636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2170),
  [1638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4574),
  [1640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10423),
  [1642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [1644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8490),
  [1646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2146),
  [1648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4596),
  [1650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4481),
  [1652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3962),
  [1654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1884),
  [1656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12925),
  [1658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12725),
  [1660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4574),
  [1662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8461),
  [1664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5668),
  [1666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5668),
  [1668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5669),
  [1670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9899),
  [1672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5667),
  [1674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6717),
  [1676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10430),
  [1678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [1680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7902),
  [1682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2178),
  [1684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6579),
  [1686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4444),
  [1688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3197),
  [1690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1874),
  [1692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12542),
  [1694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12831),
  [1696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6717),
  [1698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7797),
  [1700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9358),
  [1702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9358),
  [1704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9357),
  [1706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9544),
  [1708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9369),
  [1710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(988),
  [1712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3979),
  [1714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1216),
  [1716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13233),
  [1718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6939),
  [1720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(607),
  [1722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2229),
  [1724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10580),
  [1726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6646),
  [1728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(768),
  [1730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(998),
  [1732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4006),
  [1734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1372),
  [1736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13242),
  [1738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7609),
  [1740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(609),
  [1742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2332),
  [1744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6200),
  [1746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10537),
  [1748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [1750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7954),
  [1752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2190),
  [1754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6180),
  [1756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4489),
  [1758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3324),
  [1760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1878),
  [1762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12688),
  [1764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12923),
  [1766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6200),
  [1768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7901),
  [1770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9101),
  [1772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9101),
  [1774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9121),
  [1776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9117),
  [1778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9079),
  [1780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [1782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1313),
  [1784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4024),
  [1786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1184),
  [1788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13352),
  [1790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2116),
  [1792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8934),
  [1794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(611),
  [1796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2142),
  [1798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2258),
  [1800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(907),
  [1802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4028),
  [1804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(987),
  [1806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13176),
  [1808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8082),
  [1810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(612),
  [1812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2219),
  [1814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4680),
  [1816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10605),
  [1818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [1820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9145),
  [1822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2115),
  [1824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4797),
  [1826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4525),
  [1828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3974),
  [1830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1857),
  [1832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12469),
  [1834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12753),
  [1836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4680),
  [1838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9367),
  [1840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6406),
  [1842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6406),
  [1844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6503),
  [1846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10013),
  [1848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6729),
  [1850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(883),
  [1852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3978),
  [1854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1029),
  [1856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13193),
  [1858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6937),
  [1860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(614),
  [1862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2305),
  [1864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(868),
  [1866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3990),
  [1868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1081),
  [1870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13203),
  [1872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2341),
  [1874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8241),
  [1876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(615),
  [1878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2392),
  [1880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2313),
  [1882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(694),
  [1884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1577),
  [1886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4034),
  [1888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1271),
  [1890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13359),
  [1892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2169),
  [1894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8560),
  [1896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(616),
  [1898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2236),
  [1900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2250),
  [1902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(788),
  [1904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1037),
  [1906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4029),
  [1908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(960),
  [1910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13278),
  [1912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2300),
  [1914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8486),
  [1916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(617),
  [1918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2120),
  [1920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2322),
  [1922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(795),
  [1924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1269),
  [1926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4021),
  [1928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1145),
  [1930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13343),
  [1932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2197),
  [1934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8667),
  [1936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(618),
  [1938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2109),
  [1940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2278),
  [1942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [1944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1636),
  [1946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4016),
  [1948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1099),
  [1950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13070),
  [1952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8502),
  [1954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(619),
  [1956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2363),
  [1958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1442),
  [1960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3992),
  [1962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1309),
  [1964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13217),
  [1966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7011),
  [1968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(620),
  [1970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2206),
  [1972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3975),
  [1974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6575),
  [1976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10389),
  [1978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [1980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7806),
  [1982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2291),
  [1984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6417),
  [1986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4527),
  [1988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3976),
  [1990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1859),
  [1992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12468),
  [1994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12760),
  [1996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6575),
  [1998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7971),
  [2000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9333),
  [2002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9333),
  [2004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9380),
  [2006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9084),
  [2008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9332),
  [2010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [2012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(914),
  [2014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3993),
  [2016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1001),
  [2018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13197),
  [2020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2159),
  [2022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8812),
  [2024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(623),
  [2026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2134),
  [2028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1217),
  [2030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3986),
  [2032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1412),
  [2034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13296),
  [2036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8213),
  [2038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(624),
  [2040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2246),
  [2042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(698),
  [2044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1536),
  [2046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4018),
  [2048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1454),
  [2050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13383),
  [2052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2107),
  [2054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8409),
  [2056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(625),
  [2058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2374),
  [2060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10576),
  [2062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3977),
  [2064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8607),
  [2066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1492),
  [2068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4013),
  [2070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1606),
  [2072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13389),
  [2074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8046),
  [2076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(627),
  [2078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2353),
  [2080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4671),
  [2082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10459),
  [2084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [2086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9247),
  [2088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2339),
  [2090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4658),
  [2092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4454),
  [2094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3973),
  [2096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1866),
  [2098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12913),
  [2100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12558),
  [2102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4671),
  [2104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9359),
  [2106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6362),
  [2108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6362),
  [2110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6359),
  [2112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10196),
  [2114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6365),
  [2116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(830),
  [2118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1321),
  [2120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4002),
  [2122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1597),
  [2124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12952),
  [2126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2285),
  [2128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8884),
  [2130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(629),
  [2132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2354),
  [2134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2255),
  [2136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(681),
  [2138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1608),
  [2140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3995),
  [2142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1522),
  [2144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12992),
  [2146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2397),
  [2148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9106),
  [2150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(630),
  [2152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2396),
  [2154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2100),
  [2156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4239),
  [2158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(800),
  [2160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1604),
  [2162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4011),
  [2164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1140),
  [2166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13236),
  [2168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8288),
  [2170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(635),
  [2172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2166),
  [2174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [2176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4251),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [2180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4266),
  [2182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [2184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4233),
  [2186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [2188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4228),
  [2190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(953),
  [2192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4027),
  [2194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [2196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13223),
  [2198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8682),
  [2200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(637),
  [2202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2302),
  [2204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4212),
  [2206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [2208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1413),
  [2210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4000),
  [2212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1620),
  [2214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13358),
  [2216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8036),
  [2218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(639),
  [2220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2214),
  [2222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4216),
  [2224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(734),
  [2226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [2228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4213),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [2232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4252),
  [2234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [2236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4246),
  [2238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [2240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4232),
  [2242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(767),
  [2244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10625),
  [2246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8807),
  [2248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9805),
  [2250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4267),
  [2252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(773),
  [2254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4235),
  [2256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(769),
  [2258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [2260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4219),
  [2262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(820),
  [2264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13166),
  [2266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(856),
  [2268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1520),
  [2270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3988),
  [2272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [2274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13260),
  [2276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2234),
  [2278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9076),
  [2280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(651),
  [2282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2245),
  [2284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1257),
  [2286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3980),
  [2288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1451),
  [2290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13326),
  [2292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8695),
  [2294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(652),
  [2296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2225),
  [2298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(833),
  [2300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1108),
  [2302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3982),
  [2304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1038),
  [2306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13292),
  [2308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2384),
  [2310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8953),
  [2312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(653),
  [2314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2319),
  [2316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1251),
  [2318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3984),
  [2320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1431),
  [2322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13198),
  [2324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8623),
  [2326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(654),
  [2328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2231),
  [2330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4265),
  [2332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(803),
  [2334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1083),
  [2336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4025),
  [2338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1296),
  [2340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13251),
  [2342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9097),
  [2344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(791),
  [2346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2139),
  [2348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4241),
  [2350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(783),
  [2352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1674),
  [2354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4026),
  [2356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(932),
  [2358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13256),
  [2360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10020),
  [2362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1791),
  [2364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2128),
  [2366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4222),
  [2368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(814),
  [2370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1136),
  [2372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4012),
  [2374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1334),
  [2376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13271),
  [2378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8061),
  [2380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(678),
  [2382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2217),
  [2384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4211),
  [2386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(757),
  [2388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4220),
  [2390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4238),
  [2392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4263),
  [2394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4269),
  [2396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4215),
  [2398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4243),
  [2400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(741),
  [2402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [2404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4270),
  [2406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(683),
  [2408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(918),
  [2410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4033),
  [2412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1677),
  [2414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13115),
  [2416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10161),
  [2418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1840),
  [2420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2275),
  [2422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4236),
  [2424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4255),
  [2426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(751),
  [2428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4244),
  [2430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(839),
  [2432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1142),
  [2434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4022),
  [2436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1637),
  [2438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13024),
  [2440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8701),
  [2442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(669),
  [2444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2318),
  [2446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4229),
  [2448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4230),
  [2450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(736),
  [2452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1183),
  [2454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4010),
  [2456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1109),
  [2458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13334),
  [2460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9921),
  [2462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1105),
  [2464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2287),
  [2466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13305),
  [2468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4248),
  [2470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(787),
  [2472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4264),
  [2474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(855),
  [2476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1143),
  [2478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3999),
  [2480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1071),
  [2482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13317),
  [2484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9892),
  [2486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1187),
  [2488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2387),
  [2490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10471),
  [2492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3983),
  [2494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4231),
  [2496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(782),
  [2498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [2500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4240),
  [2502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(844),
  [2504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1297),
  [2506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3989),
  [2508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1491),
  [2510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13331),
  [2512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9363),
  [2514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(716),
  [2516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2346),
  [2518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4260),
  [2520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(818),
  [2522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4227),
  [2524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [2526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [2528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13220),
  [2530] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4671),
  [2533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_expression, 1),
  [2535] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(155),
  [2538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_expression, 1),
  [2540] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4658),
  [2543] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3973),
  [2546] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1866),
  [2549] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(4671),
  [2552] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9076),
  [2555] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2313),
  [2558] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4567),
  [2561] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(132),
  [2564] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4544),
  [2567] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2592),
  [2570] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1869),
  [2573] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(4567),
  [2576] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(7371),
  [2579] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2393),
  [2582] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4581),
  [2585] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(137),
  [2588] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4553),
  [2591] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3384),
  [2594] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1881),
  [2597] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(4581),
  [2600] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8409),
  [2603] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2221),
  [2606] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4918),
  [2609] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(145),
  [2612] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4884),
  [2615] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2652),
  [2618] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1872),
  [2621] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(4918),
  [2624] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8241),
  [2627] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5241),
  [2630] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(141),
  [2633] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5197),
  [2636] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3975),
  [2639] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1858),
  [2642] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(5241),
  [2645] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9196),
  [2648] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2401),
  [2651] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5783),
  [2654] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(150),
  [2657] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5715),
  [2660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(704),
  [2662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1557),
  [2664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4031),
  [2666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1395),
  [2668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13213),
  [2670] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3595),
  [2673] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1862),
  [2676] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(5783),
  [2679] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9971),
  [2682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1055),
  [2684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2286),
  [2686] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2258),
  [2689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [2691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1478),
  [2693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4036),
  [2695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1353),
  [2697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13311),
  [2699] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2412),
  [2702] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8481),
  [2705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(705),
  [2707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2212),
  [2709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8481),
  [2711] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5063),
  [2714] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(149),
  [2717] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5038),
  [2720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(828),
  [2722] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2654),
  [2725] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1871),
  [2728] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(5063),
  [2731] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8213),
  [2734] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2278),
  [2737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [2739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1434),
  [2741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4019),
  [2743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1314),
  [2745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13366),
  [2747] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9843),
  [2750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(978),
  [2752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2173),
  [2754] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5247),
  [2757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(152),
  [2760] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5250),
  [2763] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2904),
  [2766] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1885),
  [2769] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(5247),
  [2772] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9363),
  [2775] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2201),
  [2778] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8502),
  [2781] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5283),
  [2784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(147),
  [2787] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5285),
  [2790] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2650),
  [2793] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1877),
  [2796] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(5283),
  [2799] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6939),
  [2802] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2303),
  [2805] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6704),
  [2808] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5939),
  [2811] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(136),
  [2814] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5929),
  [2817] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3397),
  [2820] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1867),
  [2823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(5939),
  [2826] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9921),
  [2829] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2322),
  [2832] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5497),
  [2835] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(134),
  [2838] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5673),
  [2841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(740),
  [2843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(958),
  [2845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4023),
  [2847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(915),
  [2849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13229),
  [2851] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3983),
  [2854] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1861),
  [2857] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(5497),
  [2860] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(10418),
  [2863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1882),
  [2865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2307),
  [2867] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2175),
  [2870] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5026),
  [2873] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(129),
  [2876] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4989),
  [2879] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2653),
  [2882] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1860),
  [2885] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(5026),
  [2888] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(7323),
  [2891] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2099),
  [2894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(799),
  [2896] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8036),
  [2899] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6575),
  [2902] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(128),
  [2905] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6417),
  [2908] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3976),
  [2911] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1859),
  [2914] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(6575),
  [2917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9106),
  [2920] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2100),
  [2923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13265),
  [2925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1086),
  [2927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4003),
  [2929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1598),
  [2931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13153),
  [2933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9054),
  [2935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(728),
  [2937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2264),
  [2939] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4771),
  [2942] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(131),
  [2945] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4781),
  [2948] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2640),
  [2951] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1876),
  [2954] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(4771),
  [2957] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(7609),
  [2960] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2183),
  [2963] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5518),
  [2966] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(138),
  [2969] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6028),
  [2972] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3977),
  [2975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1870),
  [2978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(5518),
  [2981] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9197),
  [2984] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2298),
  [2987] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9892),
  [2990] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6669),
  [2993] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9753),
  [2996] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6717),
  [2999] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(151),
  [3002] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6579),
  [3005] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3197),
  [3008] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1874),
  [3011] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(6717),
  [3014] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8884),
  [3017] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2255),
  [3020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [3022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(874),
  [3024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4005),
  [3026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(873),
  [3028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13112),
  [3030] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(10627),
  [3033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1875),
  [3035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2188),
  [3037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8061),
  [3040] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8701),
  [3043] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4702),
  [3046] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(148),
  [3049] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4634),
  [3052] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2647),
  [3055] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1883),
  [3058] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(4702),
  [3061] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6937),
  [3064] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(7731),
  [3067] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4522),
  [3070] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(156),
  [3073] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4526),
  [3076] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2688),
  [3079] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1865),
  [3082] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(4522),
  [3085] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8004),
  [3088] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(10161),
  [3091] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8667),
  [3094] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5824),
  [3097] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(133),
  [3100] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5825),
  [3103] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2875),
  [3106] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1879),
  [3109] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(5824),
  [3112] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8082),
  [3115] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2170),
  [3118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(721),
  [3120] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2413),
  [3123] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9054),
  [3126] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6072),
  [3129] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(153),
  [3132] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(5498),
  [3135] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2770),
  [3138] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1864),
  [3141] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(6072),
  [3144] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8046),
  [3147] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2153),
  [3150] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8785),
  [3153] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4680),
  [3156] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(142),
  [3159] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4797),
  [3162] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3974),
  [3165] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1857),
  [3168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(4680),
  [3171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8953),
  [3174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [3176] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8623),
  [3179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9097),
  [3182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(7011),
  [3185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4574),
  [3188] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(130),
  [3191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4596),
  [3194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3962),
  [3197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1884),
  [3200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(4574),
  [3203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8812),
  [3206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(836),
  [3208] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8695),
  [3211] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8288),
  [3214] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(4608),
  [3217] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(143),
  [3220] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8807),
  [3223] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2414),
  [3226] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1863),
  [3229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(4608),
  [3232] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9679),
  [3235] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6200),
  [3238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(139),
  [3241] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6180),
  [3244] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3324),
  [3247] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(1878),
  [3250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), SHIFT(6200),
  [3253] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8682),
  [3256] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2250),
  [3259] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8486),
  [3262] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(10020),
  [3265] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(7647),
  [3268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13384),
  [3270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(9855),
  [3273] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8193),
  [3276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(7348),
  [3279] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8934),
  [3282] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6781),
  [3285] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8560),
  [3288] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(6826),
  [3291] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(8196),
  [3294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [3296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [3298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [3300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [3302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9843),
  [3304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1880),
  [3306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10627),
  [3308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9971),
  [3310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10379),
  [3312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [3314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2129),
  [3316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4477),
  [3318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1868),
  [3320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12806),
  [3322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12649),
  [3324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10882),
  [3326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11114),
  [3328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11114),
  [3330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11117),
  [3332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10947),
  [3334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11102),
  [3336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10418),
  [3338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1935),
  [3340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6639),
  [3342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2093),
  [3344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6792),
  [3346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2088),
  [3348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10955),
  [3350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1973),
  [3352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9144),
  [3354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1947),
  [3356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8474),
  [3358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1931),
  [3360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7215),
  [3362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1887),
  [3364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8253),
  [3366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1953),
  [3368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7182),
  [3370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1956),
  [3372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8318),
  [3374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1916),
  [3376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7759),
  [3378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2057),
  [3380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8646),
  [3382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2075),
  [3384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6573),
  [3386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2026),
  [3388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8774),
  [3390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2027),
  [3392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9828),
  [3394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1906),
  [3396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7247),
  [3398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2082),
  [3400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5710),
  [3402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1934),
  [3404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10070),
  [3406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2019),
  [3408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6637),
  [3410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1902),
  [3412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8746),
  [3414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2091),
  [3416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5407),
  [3418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1982),
  [3420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8863),
  [3422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1917),
  [3424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6413),
  [3426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1899),
  [3428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7694),
  [3430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2083),
  [3432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5786),
  [3434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1979),
  [3436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5383),
  [3438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2084),
  [3440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8199),
  [3442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2067),
  [3444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5789),
  [3446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1988),
  [3448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7162),
  [3450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1925),
  [3452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9302),
  [3454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1894),
  [3456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9334),
  [3458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2096),
  [3460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5388),
  [3462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1967),
  [3464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9774),
  [3466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1968),
  [3468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13898),
  [3470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2077),
  [3472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4933),
  [3474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1912),
  [3476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5316),
  [3478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2073),
  [3480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10534),
  [3482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1924),
  [3484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8302),
  [3486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2081),
  [3488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6748),
  [3490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2012),
  [3492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7496),
  [3494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1913),
  [3496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9108),
  [3498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1984),
  [3500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10113),
  [3502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1919),
  [3504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4957),
  [3506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2072),
  [3508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8764),
  [3510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1946),
  [3512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5753),
  [3514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2065),
  [3516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9136),
  [3518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1962),
  [3520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8297),
  [3522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1891),
  [3524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8508),
  [3526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1895),
  [3528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5358),
  [3530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2037),
  [3532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9278),
  [3534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2094),
  [3536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14546),
  [3538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1954),
  [3540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6768),
  [3542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2064),
  [3544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8875),
  [3546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1991),
  [3548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5541),
  [3550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2071),
  [3552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8534),
  [3554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2063),
  [3556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7876),
  [3558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1978),
  [3560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9849),
  [3562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1888),
  [3564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6023),
  [3566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1989),
  [3568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6871),
  [3570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1993),
  [3572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7554),
  [3574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2000),
  [3576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5248),
  [3578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2060),
  [3580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7828),
  [3582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2051),
  [3584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11468),
  [3586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1896),
  [3588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7697),
  [3590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2046),
  [3592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7021),
  [3594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1985),
  [3596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5739),
  [3598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2003),
  [3600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5617),
  [3602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2053),
  [3604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7220),
  [3606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1900),
  [3608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7396),
  [3610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2092),
  [3612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12685),
  [3614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2068),
  [3616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9581),
  [3618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2008),
  [3620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5983),
  [3622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2011),
  [3624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7529),
  [3626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2050),
  [3628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6210),
  [3630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1910),
  [3632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13919),
  [3634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2036),
  [3636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4861),
  [3638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2085),
  [3640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8414),
  [3642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1994),
  [3644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5222),
  [3646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1961),
  [3648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9673),
  [3650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2044),
  [3652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7298),
  [3654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1972),
  [3656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8948),
  [3658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2020),
  [3660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7509),
  [3662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1914),
  [3664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13044),
  [3666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1980),
  [3668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6862),
  [3670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1992),
  [3672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6479),
  [3674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2042),
  [3676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7630),
  [3678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2039),
  [3680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10593),
  [3682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1922),
  [3684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13032),
  [3686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2045),
  [3688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5794),
  [3690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2066),
  [3692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8614),
  [3694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2022),
  [3696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6571),
  [3698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2017),
  [3700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4656),
  [3702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1886),
  [3704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9851),
  [3706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1960),
  [3708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14337),
  [3710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1998),
  [3712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5820),
  [3714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2049),
  [3716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8103),
  [3718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2047),
  [3720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7440),
  [3722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2048),
  [3724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6363),
  [3726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2061),
  [3728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7597),
  [3730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1933),
  [3732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7782),
  [3734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2030),
  [3736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9865),
  [3738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1926),
  [3740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14637),
  [3742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2018),
  [3744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13723),
  [3746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1970),
  [3748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7452),
  [3750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2069),
  [3752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8365),
  [3754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2074),
  [3756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5359),
  [3758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2025),
  [3760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10127),
  [3762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1937),
  [3764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9571),
  [3766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2078),
  [3768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6212),
  [3770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1892),
  [3772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12767),
  [3774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1999),
  [3776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4857),
  [3778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2086),
  [3780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6158),
  [3782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2097),
  [3784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7331),
  [3786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1983),
  [3788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9226),
  [3790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2015),
  [3792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7566),
  [3794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2040),
  [3796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6947),
  [3798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1944),
  [3800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7944),
  [3802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1904),
  [3804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6118),
  [3806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1958),
  [3808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8277),
  [3810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2016),
  [3812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13455),
  [3814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2014),
  [3816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8487),
  [3818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1923),
  [3820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9526),
  [3822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1948),
  [3824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5620),
  [3826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2005),
  [3828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9310),
  [3830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1938),
  [3832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8370),
  [3834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1898),
  [3836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8169),
  [3838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1955),
  [3840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9543),
  [3842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1951),
  [3844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6153),
  [3846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2001),
  [3848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6271),
  [3850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2006),
  [3852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7315),
  [3854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9063),
  [3856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10271),
  [3858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6682),
  [3860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7915),
  [3862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5623),
  [3864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8923),
  [3866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7125),
  [3868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9978),
  [3870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7090),
  [3872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7993),
  [3874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9232),
  [3876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7486),
  [3878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10812),
  [3880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4820),
  [3882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8346),
  [3884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5725),
  [3886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5502),
  [3888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7830),
  [3890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5180),
  [3892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6128),
  [3894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7615),
  [3896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7197),
  [3898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8517),
  [3900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5465),
  [3902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8784),
  [3904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6407),
  [3906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1368),
  [3908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1360),
  [3910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7081),
  [3912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1336),
  [3914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9468),
  [3916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1389),
  [3918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1402),
  [3920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1420),
  [3922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1311),
  [3924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9915),
  [3926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6949),
  [3928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1500),
  [3930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1285),
  [3932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(929),
  [3934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1471),
  [3936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1265),
  [3938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9378),
  [3940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1433),
  [3942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5535),
  [3944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(931),
  [3946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1245),
  [3948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(985),
  [3950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1305),
  [3952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11082),
  [3954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [3956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1223),
  [3958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1476),
  [3960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1466),
  [3962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1197),
  [3964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7511),
  [3966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10141),
  [3968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1178),
  [3970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1157),
  [3972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1204),
  [3974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9189),
  [3976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(879),
  [3978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1565),
  [3980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9426),
  [3982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1133),
  [3984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1518),
  [3986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1542),
  [3988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1115),
  [3990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8913),
  [3992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1093),
  [3994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(875),
  [3996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1552),
  [3998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9625),
  [4000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1121),
  [4002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8798),
  [4004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1067),
  [4006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1589),
  [4008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1599),
  [4010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7132),
  [4012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1051),
  [4014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(971),
  [4016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6299),
  [4018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1472),
  [4020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1315),
  [4022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8078),
  [4024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9707),
  [4026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1639),
  [4028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1660),
  [4030] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exprs_in_parens, 2),
  [4032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1027),
  [4034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1366),
  [4036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1045),
  [4038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10172),
  [4040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(897),
  [4042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1649),
  [4044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1682),
  [4046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exprs_in_parens, 3),
  [4048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1010),
  [4050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9995),
  [4052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10577),
  [4054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7779),
  [4056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1691),
  [4058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1566),
  [4060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8397),
  [4062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1091),
  [4064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6387),
  [4066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(965),
  [4068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8924),
  [4070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1556),
  [4072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [4074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [4076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(696),
  [4078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [4080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(718),
  [4082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(843),
  [4084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(739),
  [4086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(688),
  [4088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(785),
  [4090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(706),
  [4092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(831),
  [4094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [4096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(790),
  [4098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(840),
  [4100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(823),
  [4102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(819),
  [4104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [4106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(731),
  [4108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(805),
  [4110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(807),
  [4112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(686),
  [4114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(758),
  [4116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [4118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [4120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(849),
  [4122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(700),
  [4124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(722),
  [4126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [4128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(753),
  [4130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [4132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(852),
  [4134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(756),
  [4136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(797),
  [4138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(804),
  [4140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(808),
  [4142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(685),
  [4144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(848),
  [4146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(815),
  [4148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(835),
  [4150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(829),
  [4152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(801),
  [4154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(732),
  [4156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(747),
  [4158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(752),
  [4160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(847),
  [4162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [4164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(761),
  [4166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(737),
  [4168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(745),
  [4170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [4172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(770),
  [4174] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_modifier, 1),
  [4176] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__soft_identifier, 1),
  [4178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_modifier, 1),
  [4180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__soft_identifier, 1),
  [4182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4657),
  [4184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18415),
  [4186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [4188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4888),
  [4190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3632),
  [4192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11989),
  [4194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4694),
  [4196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9406),
  [4198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2487),
  [4200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4657),
  [4202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5060),
  [4204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12788),
  [4206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12788),
  [4208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12692),
  [4210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [4212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12787),
  [4214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5031),
  [4216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18040),
  [4218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [4220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5476),
  [4222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3683),
  [4224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11745),
  [4226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4910),
  [4228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9287),
  [4230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2476),
  [4232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5031),
  [4234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5494),
  [4236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11644),
  [4238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11644),
  [4240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11642),
  [4242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [4244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11647),
  [4246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5208),
  [4248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18461),
  [4250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [4252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5918),
  [4254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3354),
  [4256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12050),
  [4258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5209),
  [4260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8987),
  [4262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2497),
  [4264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5208),
  [4266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5511),
  [4268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13603),
  [4270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13603),
  [4272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13600),
  [4274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [4276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13607),
  [4278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7385),
  [4280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18212),
  [4282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [4284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8094),
  [4286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3430),
  [4288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11892),
  [4290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7346),
  [4292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9223),
  [4294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2498),
  [4296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7385),
  [4298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7713),
  [4300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12126),
  [4302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12126),
  [4304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12125),
  [4306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [4308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12127),
  [4310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5094),
  [4312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18441),
  [4314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [4316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5286),
  [4318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3747),
  [4320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12024),
  [4322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5046),
  [4324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9268),
  [4326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2492),
  [4328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5094),
  [4330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5257),
  [4332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12958),
  [4334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12958),
  [4336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12961),
  [4338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [4340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12956),
  [4342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7539),
  [4344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8501),
  [4346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3676),
  [4348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11729),
  [4350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7531),
  [4352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2483),
  [4354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7539),
  [4356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8494),
  [4358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [4360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6576),
  [4362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18075),
  [4364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [4366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6913),
  [4368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3484),
  [4370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11747),
  [4372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6632),
  [4374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9238),
  [4376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2475),
  [4378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6576),
  [4380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10225),
  [4382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12018),
  [4384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12018),
  [4386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12020),
  [4388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12014),
  [4390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7208),
  [4392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18398),
  [4394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [4396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7708),
  [4398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3318),
  [4400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11972),
  [4402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7211),
  [4404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8966),
  [4406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2486),
  [4408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7208),
  [4410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8054),
  [4412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12382),
  [4414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12382),
  [4416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12280),
  [4418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [4420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12292),
  [4422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6399),
  [4424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18445),
  [4426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [4428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7256),
  [4430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3368),
  [4432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12031),
  [4434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6393),
  [4436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9190),
  [4438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2485),
  [4440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6399),
  [4442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7420),
  [4444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11978),
  [4446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11978),
  [4448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11977),
  [4450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [4452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11979),
  [4454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10289),
  [4456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [4458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10120),
  [4460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [4462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5328),
  [4464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18348),
  [4466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [4468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5510),
  [4470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3272),
  [4472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11917),
  [4474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5299),
  [4476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9052),
  [4478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2484),
  [4480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5328),
  [4482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6086),
  [4484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13536),
  [4486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13536),
  [4488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13534),
  [4490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [4492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13540),
  [4494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10329),
  [4496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [4498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10278),
  [4500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10044),
  [4502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10096),
  [4504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [4506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10060),
  [4508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [4510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10114),
  [4512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4696),
  [4514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4826),
  [4516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3362),
  [4518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11907),
  [4520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4719),
  [4522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2494),
  [4524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4696),
  [4526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4828),
  [4528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [4530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5882),
  [4532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18417),
  [4534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [4536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6610),
  [4538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3794),
  [4540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11996),
  [4542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5891),
  [4544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9466),
  [4546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2479),
  [4548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5882),
  [4550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6597),
  [4552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13946),
  [4554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13946),
  [4556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13899),
  [4558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [4560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13956),
  [4562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5868),
  [4564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18420),
  [4566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [4568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6472),
  [4570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3928),
  [4572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12002),
  [4574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5872),
  [4576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9292),
  [4578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2495),
  [4580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5868),
  [4582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6450),
  [4584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13758),
  [4586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13758),
  [4588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13911),
  [4590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [4592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13768),
  [4594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5264),
  [4596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18373),
  [4598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [4600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6034),
  [4602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3207),
  [4604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11921),
  [4606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5277),
  [4608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9517),
  [4610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2490),
  [4612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5264),
  [4614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5634),
  [4616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13453),
  [4618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13453),
  [4620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13443),
  [4622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13450),
  [4624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4445),
  [4626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18388),
  [4628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [4630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4627),
  [4632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3417),
  [4634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11973),
  [4636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4459),
  [4638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9319),
  [4640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2496),
  [4642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4445),
  [4644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4595),
  [4646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11561),
  [4648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11561),
  [4650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11557),
  [4652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [4654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11576),
  [4656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10233),
  [4658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10179),
  [4660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4601),
  [4662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18116),
  [4664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [4666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4785),
  [4668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3869),
  [4670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11805),
  [4672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4594),
  [4674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9234),
  [4676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2488),
  [4678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4601),
  [4680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4707),
  [4682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11743),
  [4684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11743),
  [4686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11742),
  [4688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [4690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11819),
  [4692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4547),
  [4694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4672),
  [4696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3242),
  [4698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12033),
  [4700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4546),
  [4702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2481),
  [4704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4547),
  [4706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4786),
  [4708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10129),
  [4710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10265),
  [4712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6328),
  [4714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18200),
  [4716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [4718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7024),
  [4720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3509),
  [4722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11788),
  [4724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6589),
  [4726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9388),
  [4728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2480),
  [4730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6328),
  [4732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7367),
  [4734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13248),
  [4736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13248),
  [4738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13247),
  [4740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [4742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13253),
  [4744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10361),
  [4746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7022),
  [4748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [4750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4635),
  [4752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4945),
  [4754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3515),
  [4756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11926),
  [4758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4703),
  [4760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2489),
  [4762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4635),
  [4764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4838),
  [4766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [4768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10188),
  [4770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10136),
  [4772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [4774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5800),
  [4776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18443),
  [4778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [4780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6177),
  [4782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3533),
  [4784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12030),
  [4786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5812),
  [4788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9472),
  [4790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2491),
  [4792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5800),
  [4794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6148),
  [4796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13757),
  [4798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13757),
  [4800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13865),
  [4802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13905),
  [4804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10310),
  [4806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10093),
  [4808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10238),
  [4810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10040),
  [4812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6330),
  [4814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7189),
  [4816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3844),
  [4818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11765),
  [4820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6291),
  [4822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2482),
  [4824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6330),
  [4826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7283),
  [4828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [4830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5145),
  [4832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18188),
  [4834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [4836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5953),
  [4838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3582),
  [4840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11877),
  [4842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5192),
  [4844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9437),
  [4846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2493),
  [4848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5145),
  [4850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5935),
  [4852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13687),
  [4854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13687),
  [4856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13699),
  [4858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13665),
  [4860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10039),
  [4862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10355),
  [4864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [4866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10156),
  [4868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5967),
  [4870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6709),
  [4872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3231),
  [4874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11953),
  [4876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5977),
  [4878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2478),
  [4880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5967),
  [4882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6191),
  [4884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10197),
  [4886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5087),
  [4888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18451),
  [4890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [4892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5290),
  [4894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3256),
  [4896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12035),
  [4898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5088),
  [4900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9172),
  [4902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2477),
  [4904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5087),
  [4906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5355),
  [4908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13007),
  [4910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13007),
  [4912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13008),
  [4914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13004),
  [4916] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__case_pattern, 3, .production_id = 50),
  [4918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__case_pattern, 3, .production_id = 50),
  [4920] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__case_pattern, 2, .production_id = 50),
  [4922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__case_pattern, 2, .production_id = 50),
  [4924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__shebang, 1),
  [4926] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__shebang, 1),
  [4928] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_self_type, 3, .dynamic_precedence = 1),
  [4930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_self_type, 3, .dynamic_precedence = 1),
  [4932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9006),
  [4934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9208),
  [4936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2573),
  [4938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9179),
  [4940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5839),
  [4942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18001),
  [4944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [4946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6386),
  [4948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11831),
  [4950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5853),
  [4952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11126),
  [4954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9692),
  [4956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2619),
  [4958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2471),
  [4960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13985),
  [4962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5839),
  [4964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9988),
  [4966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16641),
  [4968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9100),
  [4970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16650),
  [4972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6642),
  [4974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9088),
  [4976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7540),
  [4978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7851),
  [4980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9315),
  [4982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13968),
  [4984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5954),
  [4986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5039),
  [4988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6931),
  [4990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6787),
  [4992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7340),
  [4994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10941),
  [4996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4850),
  [4998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8029),
  [5000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9745),
  [5002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8910),
  [5004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6324),
  [5006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8043),
  [5008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6234),
  [5010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7457),
  [5012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8961),
  [5014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6306),
  [5016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14090),
  [5018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9778),
  [5020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5165),
  [5022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9912),
  [5024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7652),
  [5026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6482),
  [5028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6744),
  [5030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16619),
  [5032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9178),
  [5034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5363),
  [5036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6923),
  [5038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7752),
  [5040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8309),
  [5042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9459),
  [5044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14130),
  [5046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7819),
  [5048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10960),
  [5050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8048),
  [5052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9668),
  [5054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7594),
  [5056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6731),
  [5058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6831),
  [5060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8532),
  [5062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10334),
  [5064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6906),
  [5066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9440),
  [5068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5190),
  [5070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4922),
  [5072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7661),
  [5074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5995),
  [5076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8710),
  [5078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8636),
  [5080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6698),
  [5082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7662),
  [5084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7483),
  [5086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7142),
  [5088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8827),
  [5090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8921),
  [5092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6894),
  [5094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14034),
  [5096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5778),
  [5098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8914),
  [5100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16614),
  [5102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5776),
  [5104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6007),
  [5106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8792),
  [5108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5367),
  [5110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5466),
  [5112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6818),
  [5114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7922),
  [5116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5843),
  [5118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4682),
  [5120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7923),
  [5122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8681),
  [5124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3680),
  [5126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11865),
  [5128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7986),
  [5130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2588),
  [5132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7923),
  [5134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7753),
  [5136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_wildcard, 1),
  [5138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6057),
  [5140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13546),
  [5142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11453),
  [5144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4803),
  [5146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4775),
  [5148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7747),
  [5150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8552),
  [5152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6068),
  [5154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11994),
  [5156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12812),
  [5158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8544),
  [5160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12612),
  [5162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8444),
  [5164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4387),
  [5166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4641),
  [5168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6815),
  [5170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9370),
  [5172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6492),
  [5174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6819),
  [5176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14155),
  [5178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7743),
  [5180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4645),
  [5182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10316),
  [5184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6276),
  [5186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8387),
  [5188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5079),
  [5190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13147),
  [5192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5926),
  [5194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8831),
  [5196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5080),
  [5198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4966),
  [5200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8338),
  [5202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4997),
  [5204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9062),
  [5206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8386),
  [5208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11366),
  [5210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8401),
  [5212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4362),
  [5214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5637),
  [5216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13079),
  [5218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14064),
  [5220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9055),
  [5222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12193),
  [5224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14006),
  [5226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8832),
  [5228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8324),
  [5230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8449),
  [5232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4778),
  [5234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5276),
  [5236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10076),
  [5238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8380),
  [5240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6438),
  [5242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8364),
  [5244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7407),
  [5246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5416),
  [5248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7808),
  [5250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5321),
  [5252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6037),
  [5254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6400),
  [5256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6586),
  [5258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5315),
  [5260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10081),
  [5262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13528),
  [5264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6439),
  [5266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6779),
  [5268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7816),
  [5270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7401),
  [5272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8576),
  [5274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6554),
  [5276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13268),
  [5278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6877),
  [5280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8582),
  [5282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8435),
  [5284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6501),
  [5286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13270),
  [5288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14117),
  [5290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5240),
  [5292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5200),
  [5294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9521),
  [5296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8090),
  [5298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8638),
  [5300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6477),
  [5302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6489),
  [5304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5029),
  [5306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7172),
  [5308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4836),
  [5310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6551),
  [5312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6686),
  [5314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6030),
  [5316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13325),
  [5318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5114),
  [5320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11942),
  [5322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8032),
  [5324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5412),
  [5326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6082),
  [5328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9221),
  [5330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4974),
  [5332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8483),
  [5334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6162),
  [5336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9293),
  [5338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6478),
  [5340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9962),
  [5342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6114),
  [5344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11853),
  [5346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6179),
  [5348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8053),
  [5350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8603),
  [5352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6167),
  [5354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6172),
  [5356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11792),
  [5358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4582),
  [5360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9212),
  [5362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12096),
  [5364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7136),
  [5366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8069),
  [5368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8066),
  [5370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6121),
  [5372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12003),
  [5374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4584),
  [5376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5624),
  [5378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11575),
  [5380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14015),
  [5382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11208),
  [5384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4897),
  [5386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4837),
  [5388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12207),
  [5390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5713),
  [5392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6099),
  [5394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11578),
  [5396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5927),
  [5398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8057),
  [5400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7128),
  [5402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9699),
  [5404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11195),
  [5406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8904),
  [5408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9415),
  [5410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11421),
  [5412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10572),
  [5414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4996),
  [5416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5107),
  [5418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8793),
  [5420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8055),
  [5422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5645),
  [5424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6129),
  [5426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5718),
  [5428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5267),
  [5430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9682),
  [5432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5304),
  [5434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10490),
  [5436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9282),
  [5438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7327),
  [5440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13364),
  [5442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5303),
  [5444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8608),
  [5446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4717),
  [5448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13901),
  [5450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7571),
  [5452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11941),
  [5454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9018),
  [5456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13085),
  [5458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6841),
  [5460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8308),
  [5462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8639),
  [5464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6300),
  [5466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5244),
  [5468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5272),
  [5470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6304),
  [5472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7349),
  [5474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9274),
  [5476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4881),
  [5478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11761),
  [5480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8093),
  [5482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8906),
  [5484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6374),
  [5486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6326),
  [5488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11348),
  [5490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6426),
  [5492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7109),
  [5494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7316),
  [5496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8978),
  [5498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5001),
  [5500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7628),
  [5502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11769),
  [5504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13556),
  [5506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6321),
  [5508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6839),
  [5510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9628),
  [5512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13870),
  [5514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5105),
  [5516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9421),
  [5518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6372),
  [5520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12451),
  [5522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12455),
  [5524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8088),
  [5526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6836),
  [5528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5018),
  [5530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11767),
  [5532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9662),
  [5534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5000),
  [5536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5478),
  [5538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13318),
  [5540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7117),
  [5542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8585),
  [5544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6591),
  [5546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7269),
  [5548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8991),
  [5550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7232),
  [5552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4964),
  [5554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7114),
  [5556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7252),
  [5558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12236),
  [5560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5437),
  [5562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7262),
  [5564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8005),
  [5566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11851),
  [5568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8907),
  [5570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7303),
  [5572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11756),
  [5574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7302),
  [5576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7638),
  [5578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13511),
  [5580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13527),
  [5582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5339),
  [5584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7839),
  [5586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7111),
  [5588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7636),
  [5590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4815),
  [5592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13314),
  [5594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4557),
  [5596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7924),
  [5598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7925),
  [5600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5894),
  [5602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7732),
  [5604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5754),
  [5606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7989),
  [5608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9155),
  [5610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7469),
  [5612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8721),
  [5614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6975),
  [5616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8267),
  [5618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9236),
  [5620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5439),
  [5622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4810),
  [5624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7591),
  [5626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4948),
  [5628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12118),
  [5630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7384),
  [5632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9225),
  [5634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7812),
  [5636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4946),
  [5638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8268),
  [5640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4784),
  [5642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9965),
  [5644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10053),
  [5646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8731),
  [5648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7821),
  [5650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5141),
  [5652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4848),
  [5654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5805),
  [5656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7957),
  [5658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9123),
  [5660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13399),
  [5662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5115),
  [5664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10058),
  [5666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6648),
  [5668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5881),
  [5670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13574),
  [5672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5134),
  [5674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5631),
  [5676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8282),
  [5678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7958),
  [5680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8224),
  [5682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9049),
  [5684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7530),
  [5686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6930),
  [5688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7930),
  [5690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5288),
  [5692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5287),
  [5694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12106),
  [5696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11908),
  [5698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5998),
  [5700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8340),
  [5702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11861),
  [5704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6084),
  [5706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11525),
  [5708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6127),
  [5710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4395),
  [5712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12620),
  [5714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7433),
  [5716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12959),
  [5718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4824),
  [5720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6741),
  [5722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7336),
  [5724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11424),
  [5726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11913),
  [5728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6056),
  [5730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5480),
  [5732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9305),
  [5734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6988),
  [5736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4409),
  [5738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12955),
  [5740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6436),
  [5742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12283),
  [5744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5703),
  [5746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7997),
  [5748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7996),
  [5750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9191),
  [5752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8927),
  [5754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5994),
  [5756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5275),
  [5758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13258),
  [5760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4825),
  [5762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7284),
  [5764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10338),
  [5766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11071),
  [5768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6989),
  [5770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6578),
  [5772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12098),
  [5774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8407),
  [5776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5187),
  [5778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7282),
  [5780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7992),
  [5782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6699),
  [5784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7445),
  [5786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9254),
  [5788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7450),
  [5790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9057),
  [5792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6694),
  [5794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11331),
  [5796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5700),
  [5798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13602),
  [5800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8171),
  [5802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6369),
  [5804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13605),
  [5806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8106),
  [5808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13868),
  [5810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5457),
  [5812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4723),
  [5814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7574),
  [5816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6829),
  [5818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6242),
  [5820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8100),
  [5822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13735),
  [5824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11111),
  [5826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13310),
  [5828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13902),
  [5830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6965),
  [5832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13315),
  [5834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6272),
  [5836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7322),
  [5838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6216),
  [5840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6341),
  [5842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7818),
  [5844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6279),
  [5846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5606),
  [5848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7756),
  [5850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9068),
  [5852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6361),
  [5854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6278),
  [5856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9092),
  [5858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4773),
  [5860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6166),
  [5862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8411),
  [5864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12287),
  [5866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6169),
  [5868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6958),
  [5870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13368),
  [5872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4559),
  [5874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5014),
  [5876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6663),
  [5878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5950),
  [5880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7339),
  [5882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5956),
  [5884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5607),
  [5886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4777),
  [5888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5007),
  [5890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6984),
  [5892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8089),
  [5894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12625),
  [5896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5460),
  [5898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7072),
  [5900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5809),
  [5902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8033),
  [5904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5329),
  [5906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7948),
  [5908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6616),
  [5910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8559),
  [5912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6063),
  [5914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5529),
  [5916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7263),
  [5918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8417),
  [5920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11346),
  [5922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8095),
  [5924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8205),
  [5926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5574),
  [5928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6611),
  [5930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12231),
  [5932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4783),
  [5934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9012),
  [5936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5531),
  [5938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11552),
  [5940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10288),
  [5942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4859),
  [5944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12392),
  [5946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9870),
  [5948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6584),
  [5950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13938),
  [5952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13545),
  [5954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12624),
  [5956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7079),
  [5958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7382),
  [5960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5959),
  [5962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9880),
  [5964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5519),
  [5966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11339),
  [5968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5429),
  [5970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5960),
  [5972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7931),
  [5974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13257),
  [5976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4652),
  [5978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7411),
  [5980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7491),
  [5982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8643),
  [5984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6134),
  [5986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9393),
  [5988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5428),
  [5990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6848),
  [5992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5567),
  [5994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4931),
  [5996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12391),
  [5998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5893),
  [6000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7518),
  [6002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7444),
  [6004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7505),
  [6006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4912),
  [6008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7492),
  [6010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8666),
  [6012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4654),
  [6014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7507),
  [6016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7940),
  [6018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11547),
  [6020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12951),
  [6022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9820),
  [6024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12352),
  [6026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13327),
  [6028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14270),
  [6030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6892),
  [6032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7341),
  [6034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9818),
  [6036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6747),
  [6038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7261),
  [6040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4740),
  [6042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6248),
  [6044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6491),
  [6046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5280),
  [6048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7775),
  [6050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7434),
  [6052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5131),
  [6054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7774),
  [6056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13656),
  [6058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8597),
  [6060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8661),
  [6062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6486),
  [6064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7112),
  [6066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12334),
  [6068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7465),
  [6070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5930),
  [6072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6476),
  [6074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10297),
  [6076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5278),
  [6078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11798),
  [6080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6193),
  [6082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7467),
  [6084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7468),
  [6086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7166),
  [6088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5932),
  [6090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7442),
  [6092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6649),
  [6094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9610),
  [6096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13304),
  [6098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8937),
  [6100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9606),
  [6102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7118),
  [6104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6683),
  [6106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8595),
  [6108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8801),
  [6110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6020),
  [6112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11838),
  [6114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13083),
  [6116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6943),
  [6118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6019),
  [6120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4882),
  [6122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7988),
  [6124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5132),
  [6126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12589),
  [6128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6695),
  [6130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8918),
  [6132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6851),
  [6134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7342),
  [6136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6973),
  [6138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6160),
  [6140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8047),
  [6142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12591),
  [6144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7528),
  [6146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13162),
  [6148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5629),
  [6150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6759),
  [6152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11403),
  [6154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7236),
  [6156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6250),
  [6158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13301),
  [6160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12762),
  [6162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7235),
  [6164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13672),
  [6166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7524),
  [6168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4768),
  [6170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6195),
  [6172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4899),
  [6174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6763),
  [6176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6966),
  [6178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13601),
  [6180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9384),
  [6182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13163),
  [6184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8315),
  [6186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9104),
  [6188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11802),
  [6190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8396),
  [6192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2609),
  [6194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8315),
  [6196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8846),
  [6198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2526),
  [6200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6343),
  [6202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9455),
  [6204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18450),
  [6206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [6208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9776),
  [6210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12034),
  [6212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9457),
  [6214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2601),
  [6216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9455),
  [6218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9360),
  [6220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16578),
  [6222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16578),
  [6224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16577),
  [6226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16576),
  [6228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8670),
  [6230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18512),
  [6232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [6234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9322),
  [6236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11716),
  [6238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8783),
  [6240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2554),
  [6242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8670),
  [6244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8358),
  [6246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2536),
  [6248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4732),
  [6250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2542),
  [6252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5125),
  [6254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8141),
  [6256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8869),
  [6258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11783),
  [6260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8049),
  [6262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2574),
  [6264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8141),
  [6266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7513),
  [6268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5862),
  [6270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18194),
  [6272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [6274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6104),
  [6276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12006),
  [6278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5867),
  [6280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2585),
  [6282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5862),
  [6284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5695),
  [6286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6838),
  [6288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8099),
  [6290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11781),
  [6292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6921),
  [6294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2519),
  [6296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6838),
  [6298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7402),
  [6300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8795),
  [6302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9552),
  [6304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11843),
  [6306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8717),
  [6308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2529),
  [6310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8795),
  [6312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8692),
  [6314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2614),
  [6316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4661),
  [6318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7241),
  [6320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18096),
  [6322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [6324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7898),
  [6326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11923),
  [6328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7251),
  [6330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2595),
  [6332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7241),
  [6334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7480),
  [6336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6347),
  [6338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18206),
  [6340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [6342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7424),
  [6344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12007),
  [6346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6344),
  [6348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2520),
  [6350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6347),
  [6352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6696),
  [6354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11766),
  [6356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2499),
  [6358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4621),
  [6360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4788),
  [6362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18427),
  [6364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [6366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4960),
  [6368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12041),
  [6370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4790),
  [6372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2546),
  [6374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4788),
  [6376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4753),
  [6378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5211),
  [6380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18436),
  [6382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [6384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5946),
  [6386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12049),
  [6388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5212),
  [6390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2539),
  [6392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5211),
  [6394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5401),
  [6396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2513),
  [6398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5818),
  [6400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11842),
  [6402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5895),
  [6404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18182),
  [6406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [6408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6693),
  [6410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11995),
  [6412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5901),
  [6414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2528),
  [6416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5895),
  [6418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5859),
  [6420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5072),
  [6422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18103),
  [6424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [6426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5340),
  [6428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11983),
  [6430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5064),
  [6432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2547),
  [6434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5072),
  [6436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4977),
  [6438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7350),
  [6440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18128),
  [6442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [6444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7791),
  [6446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11784),
  [6448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7428),
  [6450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2558),
  [6452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7350),
  [6454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7038),
  [6456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11813),
  [6458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11813),
  [6460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11812),
  [6462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11817),
  [6464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8811),
  [6466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18033),
  [6468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [6470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9298),
  [6472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11728),
  [6474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8669),
  [6476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2634),
  [6478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8811),
  [6480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8503),
  [6482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12140),
  [6484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12140),
  [6486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12142),
  [6488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12138),
  [6490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7234),
  [6492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7884),
  [6494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11938),
  [6496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7246),
  [6498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2625),
  [6500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7234),
  [6502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7459),
  [6504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7863),
  [6506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18218),
  [6508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [6510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8377),
  [6512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12008),
  [6514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7862),
  [6516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2582),
  [6518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7863),
  [6520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8147),
  [6522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11929),
  [6524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2535),
  [6526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5987),
  [6528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7952),
  [6530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8628),
  [6532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11854),
  [6534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8024),
  [6536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2616),
  [6538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7952),
  [6540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7921),
  [6542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5780),
  [6544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18454),
  [6546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [6548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6292),
  [6550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12005),
  [6552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5782),
  [6554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2551),
  [6556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5780),
  [6558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5982),
  [6560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6060),
  [6562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18089),
  [6564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [6566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6634),
  [6568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11919),
  [6570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6069),
  [6572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2533),
  [6574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6060),
  [6576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5717),
  [6578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6385),
  [6580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18368),
  [6582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [6584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7266),
  [6586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12029),
  [6588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6381),
  [6590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2571),
  [6592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6385),
  [6594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6582),
  [6596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2522),
  [6598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6255),
  [6600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7134),
  [6602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7784),
  [6604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12040),
  [6606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7135),
  [6608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2572),
  [6610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7134),
  [6612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7495),
  [6614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18170),
  [6616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [6618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11839),
  [6620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17994),
  [6622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17994),
  [6624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17993),
  [6626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17992),
  [6628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2507),
  [6630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4449),
  [6632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6537),
  [6634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18134),
  [6636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [6638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6820),
  [6640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11786),
  [6642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6443),
  [6644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2560),
  [6646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6537),
  [6648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6337),
  [6650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11277),
  [6652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11277),
  [6654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11380),
  [6656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11370),
  [6658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2538),
  [6660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5003),
  [6662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4632),
  [6664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4766),
  [6666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12010),
  [6668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4606),
  [6670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2628),
  [6672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4632),
  [6674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4616),
  [6676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7792),
  [6678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8791),
  [6680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11954),
  [6682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7780),
  [6684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2543),
  [6686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7792),
  [6688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7765),
  [6690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2516),
  [6692] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7259),
  [6694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2505),
  [6696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4906),
  [6698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5215),
  [6700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18419),
  [6702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [6704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5981),
  [6706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12038),
  [6708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5219),
  [6710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2631),
  [6712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5215),
  [6714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5482),
  [6716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6457),
  [6718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18019),
  [6720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [6722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7119),
  [6724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11726),
  [6726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6181),
  [6728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2612),
  [6730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6457),
  [6732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6329),
  [6734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11291),
  [6736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11291),
  [6738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11290),
  [6740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11314),
  [6742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2564),
  [6744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5307),
  [6746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2600),
  [6748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5231),
  [6750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2626),
  [6752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4914),
  [6754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4998),
  [6756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5302),
  [6758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12013),
  [6760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4840),
  [6762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2627),
  [6764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4998),
  [6766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4984),
  [6768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2604),
  [6770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5571),
  [6772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6418),
  [6774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18421),
  [6776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [6778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7226),
  [6780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12039),
  [6782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6414),
  [6784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2586),
  [6786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6418),
  [6788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6643),
  [6790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5975),
  [6792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18158),
  [6794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [6796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6194),
  [6798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11826),
  [6800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5810),
  [6802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2605),
  [6804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5975),
  [6806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5755),
  [6808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10951),
  [6810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10951),
  [6812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10953),
  [6814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10950),
  [6816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18054),
  [6818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [6820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11730),
  [6822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11886),
  [6824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11886),
  [6826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11884),
  [6828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11888),
  [6830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6232),
  [6832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7150),
  [6834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11937),
  [6836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6227),
  [6838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2611),
  [6840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6232),
  [6842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6117),
  [6844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2596),
  [6846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4620),
  [6848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2531),
  [6850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5536),
  [6852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2632),
  [6854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5395),
  [6856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5432),
  [6858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5848),
  [6860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11823),
  [6862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5475),
  [6864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2527),
  [6866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5432),
  [6868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5096),
  [6870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6925),
  [6872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7660),
  [6874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11807),
  [6876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6890),
  [6878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2561),
  [6880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6925),
  [6882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6809),
  [6884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6268),
  [6886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7406),
  [6888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11815),
  [6890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6580),
  [6892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2587),
  [6894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6268),
  [6896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6574),
  [6898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11822),
  [6900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5013),
  [6902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18343),
  [6904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [6906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5291),
  [6908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12015),
  [6910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5010),
  [6912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2620),
  [6914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5013),
  [6916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5011),
  [6918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4714),
  [6920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18026),
  [6922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [6924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4865),
  [6926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11914),
  [6928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4659),
  [6930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2577),
  [6932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4714),
  [6934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4637),
  [6936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2553),
  [6938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7904),
  [6940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6376),
  [6942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18353),
  [6944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [6946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7292),
  [6948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12023),
  [6950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6373),
  [6952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2584),
  [6954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6376),
  [6956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6428),
  [6958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2506),
  [6960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6619),
  [6962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2504),
  [6964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4670),
  [6966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5979),
  [6968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18378),
  [6970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [6972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6496),
  [6974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11948),
  [6976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5980),
  [6978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2590),
  [6980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5979),
  [6982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6043),
  [6984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11010),
  [6986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11010),
  [6988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11029),
  [6990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10958),
  [6992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2563),
  [6994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6872),
  [6996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7458),
  [6998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8184),
  [7000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11899),
  [7002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7415),
  [7004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2603),
  [7006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7458),
  [7008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7238),
  [7010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11903),
  [7012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9854),
  [7014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4151),
  [7016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4303),
  [7018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11006),
  [7020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3489),
  [7022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9716),
  [7024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2160),
  [7026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4039),
  [7028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12924),
  [7030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9854),
  [7032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10598),
  [7034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11310),
  [7036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4169),
  [7038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4058),
  [7040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4042),
  [7042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4069),
  [7044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4072),
  [7046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4081),
  [7048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4112),
  [7050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4116),
  [7052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4141),
  [7054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4067),
  [7056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4076),
  [7058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4114),
  [7060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4126),
  [7062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_identifier, 1),
  [7064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifier, 1),
  [7066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4104),
  [7068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4135),
  [7070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4093),
  [7072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4040),
  [7074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4094),
  [7076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4047),
  [7078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4120),
  [7080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4133),
  [7082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4149),
  [7084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4123),
  [7086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4148),
  [7088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4046),
  [7090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4154),
  [7092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4150),
  [7094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4143),
  [7096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4121),
  [7098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4152),
  [7100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4038),
  [7102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4138),
  [7104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4137),
  [7106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4139),
  [7108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4146),
  [7110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4134),
  [7112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4132),
  [7114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4130),
  [7116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4155),
  [7118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4128),
  [7120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4129),
  [7122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4118),
  [7124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4105),
  [7126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4127),
  [7128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4153),
  [7130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4131),
  [7132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4145),
  [7134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4064),
  [7136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4147),
  [7138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4044),
  [7140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4045),
  [7142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4140),
  [7144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4037),
  [7146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4096),
  [7148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4070),
  [7150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4088),
  [7152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4095),
  [7154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4103),
  [7156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4100),
  [7158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4098),
  [7160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4089),
  [7162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4113),
  [7164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4110),
  [7166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4119),
  [7168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4122),
  [7170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4109),
  [7172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4111),
  [7174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4124),
  [7176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4125),
  [7178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4099),
  [7180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4101),
  [7182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4142),
  [7184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4108),
  [7186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4090),
  [7188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4091),
  [7190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4087),
  [7192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4092),
  [7194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4073),
  [7196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4071),
  [7198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4156),
  [7200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4117),
  [7202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4084),
  [7204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4086),
  [7206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4115),
  [7208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4041),
  [7210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4097),
  [7212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4055),
  [7214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4082),
  [7216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4074),
  [7218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4043),
  [7220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4049),
  [7222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4053),
  [7224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4051),
  [7226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4077),
  [7228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4107),
  [7230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4066),
  [7232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4075),
  [7234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4061),
  [7236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4063),
  [7238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4054),
  [7240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4059),
  [7242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4078),
  [7244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4079),
  [7246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4057),
  [7248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4056),
  [7250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4083),
  [7252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4085),
  [7254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4068),
  [7256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4065),
  [7258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4060),
  [7260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4052),
  [7262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4302),
  [7264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4312),
  [7266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9120),
  [7268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10508),
  [7270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10548),
  [7272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11253),
  [7274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerators, 2),
  [7276] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerators, 3),
  [7278] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerators, 2),
  [7280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerators, 3),
  [7282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4313),
  [7284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2176),
  [7286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10515),
  [7288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11373),
  [7290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14969),
  [7292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15067),
  [7294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10502),
  [7296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12854),
  [7298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11455),
  [7300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3883),
  [7302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12122),
  [7304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10585),
  [7306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4317),
  [7308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12526),
  [7310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10502),
  [7312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10203),
  [7314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10998),
  [7316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12836),
  [7318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12141),
  [7320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10314),
  [7322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10939),
  [7324] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), REDUCE(sym__if_condition, 1, .dynamic_precedence = 4),
  [7327] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), REDUCE(sym__if_condition, 1, .dynamic_precedence = 4),
  [7330] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__if_condition, 1, .dynamic_precedence = 4),
  [7332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__if_condition, 1, .dynamic_precedence = 4),
  [7334] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3),
  [7336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3),
  [7338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10122),
  [7340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10956),
  [7342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10661),
  [7344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11778),
  [7346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3464),
  [7348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10538),
  [7350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4298),
  [7352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12601),
  [7354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10661),
  [7356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10137),
  [7358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11483),
  [7360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10132),
  [7362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11462),
  [7364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10575),
  [7366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11456),
  [7368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3823),
  [7370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10614),
  [7372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4277),
  [7374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11970),
  [7376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12865),
  [7378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10575),
  [7380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10615),
  [7382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11316),
  [7384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12046),
  [7386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10358),
  [7388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11480),
  [7390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10309),
  [7392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11461),
  [7394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12047),
  [7396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10103),
  [7398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11409),
  [7400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10098),
  [7402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11446),
  [7404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11951),
  [7406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11328),
  [7408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10332),
  [7410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10972),
  [7412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12461),
  [7414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10019),
  [7416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11640),
  [7418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10015),
  [7420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11641),
  [7422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12042),
  [7424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10059),
  [7426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11077),
  [7428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11306),
  [7430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12458),
  [7432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10324),
  [7434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11619),
  [7436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11250),
  [7438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11866),
  [7440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10090),
  [7442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11034),
  [7444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10326),
  [7446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11584),
  [7448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12344),
  [7450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10262),
  [7452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11035),
  [7454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10405),
  [7456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11221),
  [7458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12060),
  [7460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12017),
  [7462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [7464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14228),
  [7466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8059),
  [7468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12440),
  [7470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2472),
  [7472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12060),
  [7474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12016),
  [7476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15086),
  [7478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_transparent_modifier, 1),
  [7480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10046),
  [7482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11108),
  [7484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9762),
  [7486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10696),
  [7488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10438),
  [7490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11227),
  [7492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10411),
  [7494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11182),
  [7496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9796),
  [7498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10750),
  [7500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10827),
  [7502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11556),
  [7504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10821),
  [7506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11535),
  [7508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_open_modifier, 1),
  [7510] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_modifier, 1),
  [7512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10816),
  [7514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11517),
  [7516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10628),
  [7518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11367),
  [7520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9814),
  [7522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10770),
  [7524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10642),
  [7526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11363),
  [7528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10182),
  [7530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10966),
  [7532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10602),
  [7534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11353),
  [7536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10535),
  [7538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11224),
  [7540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10408),
  [7542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11263),
  [7544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10105),
  [7546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10995),
  [7548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10599),
  [7550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11398),
  [7552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10291),
  [7554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10938),
  [7556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_wildcard, 1),
  [7558] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__if_condition, 2, .dynamic_precedence = 4),
  [7560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__if_condition, 2, .dynamic_precedence = 4),
  [7562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_identifier, 1, .production_id = 7),
  [7564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stable_identifier, 3),
  [7566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10009),
  [7568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10006),
  [7570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7003),
  [7572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9845),
  [7574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7006),
  [7576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stable_type_identifier, 3),
  [7578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14873),
  [7580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14854),
  [7582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13064),
  [7584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4379),
  [7586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8805),
  [7588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8820),
  [7590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8819),
  [7592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8814),
  [7594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4380),
  [7596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13808),
  [7598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14873),
  [7600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15040),
  [7602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [7604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7750),
  [7606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9046),
  [7608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12844),
  [7610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6735),
  [7612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5111),
  [7614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6509),
  [7616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6508),
  [7618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6507),
  [7620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6506),
  [7622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10663),
  [7624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [7626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [7628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [7630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4405),
  [7632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4403),
  [7634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14003),
  [7636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4440),
  [7638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4388),
  [7640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14790),
  [7642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12691),
  [7644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16677),
  [7646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12854),
  [7648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4275),
  [7650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12122),
  [7652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12239),
  [7654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9597),
  [7656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9611),
  [7658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12234),
  [7660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12705),
  [7662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18504),
  [7664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4411),
  [7666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4365),
  [7668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13406),
  [7670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4361),
  [7672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4364),
  [7674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13436),
  [7676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation, 2, .production_id = 3),
  [7678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation, 2, .production_id = 3),
  [7680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3750),
  [7682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1811),
  [7684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12521),
  [7686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4431),
  [7688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4428),
  [7690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14839),
  [7692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__annotated_type, 1),
  [7694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__annotated_type, 1),
  [7696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3407),
  [7698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9131),
  [7700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [7702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12859),
  [7704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4398),
  [7706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4376),
  [7708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13827),
  [7710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4367),
  [7712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4378),
  [7714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13438),
  [7716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12740),
  [7718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16567),
  [7720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12836),
  [7722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4310),
  [7724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12141),
  [7726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12187),
  [7728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12183),
  [7730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12770),
  [7732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11605),
  [7734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4314),
  [7736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4384),
  [7738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4383),
  [7740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14762),
  [7742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11417),
  [7744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4306),
  [7746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12222),
  [7748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12801),
  [7750] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_application, 1),
  [7752] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_application, 1),
  [7754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8160),
  [7756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4292),
  [7758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4426),
  [7760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4424),
  [7762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14727),
  [7764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12281),
  [7766] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__infix_type_choice, 1),
  [7768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18433),
  [7770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [7772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__infix_type_choice, 1),
  [7774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7646),
  [7776] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_type, 2, .production_id = 40),
  [7778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_type, 2, .production_id = 40),
  [7780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13836),
  [7782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18011),
  [7784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13908),
  [7786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3405),
  [7788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13836),
  [7790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13950),
  [7792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13557),
  [7794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13502),
  [7796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 5),
  [7798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13991),
  [7800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 3),
  [7802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13504),
  [7804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14774),
  [7806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18408),
  [7808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [7810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13087),
  [7812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3466),
  [7814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12944),
  [7816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3485),
  [7818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1833),
  [7820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12761),
  [7822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14661),
  [7824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_type, 1),
  [7826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14674),
  [7828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13823),
  [7830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13989),
  [7832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_projected_type, 3, .production_id = 82),
  [7834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14721),
  [7836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14781),
  [7838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3817),
  [7840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9444),
  [7842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [7844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12864),
  [7846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 4),
  [7848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13851),
  [7850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12664),
  [7852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18431),
  [7854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [7856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13336),
  [7858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12659),
  [7860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3398),
  [7862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12664),
  [7864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12550),
  [7866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13559),
  [7868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13888),
  [7870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 4),
  [7872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3678),
  [7874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9071),
  [7876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1854),
  [7878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12885),
  [7880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type, 1),
  [7882] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type, 1),
  [7884] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_types, 1),
  [7886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14696),
  [7888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13550),
  [7890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14747),
  [7892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_singleton_type, 3),
  [7894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13564),
  [7896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13842),
  [7898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 5),
  [7900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7947),
  [7902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3800),
  [7904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1754),
  [7906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12888),
  [7908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13931),
  [7910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14845),
  [7912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 3),
  [7914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13997),
  [7916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11727),
  [7918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18363),
  [7920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [7922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12412),
  [7924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11711),
  [7926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3895),
  [7928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11727),
  [7930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11847),
  [7932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [7934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3612),
  [7936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1793),
  [7938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12778),
  [7940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11669),
  [7942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18068),
  [7944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [7946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11869),
  [7948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11675),
  [7950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3757),
  [7952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11669),
  [7954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11430),
  [7956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13521),
  [7958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18047),
  [7960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [7962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13893),
  [7964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13515),
  [7966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3441),
  [7968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13521),
  [7970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13475),
  [7972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1672),
  [7974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16674),
  [7976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16178),
  [7978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7706),
  [7980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9557),
  [7982] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2, .production_id = 41),
  [7984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13551),
  [7986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13567),
  [7988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7258),
  [7990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7028),
  [7992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7265),
  [7994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3860),
  [7996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7258),
  [7998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7416),
  [8000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9266),
  [8002] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_identifier, 1, .production_id = 7),
  [8004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12405),
  [8006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18459),
  [8008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [8010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8042),
  [8012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1746),
  [8014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18440),
  [8016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [8018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7330),
  [8020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6971),
  [8022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7276),
  [8024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3900),
  [8026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7330),
  [8028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7418),
  [8030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8625),
  [8032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8591),
  [8034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8648),
  [8036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3700),
  [8038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8625),
  [8040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8285),
  [8042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7769),
  [8044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7551),
  [8046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7847),
  [8048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3314),
  [8050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7769),
  [8052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8225),
  [8054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9392),
  [8056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9222),
  [8058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8963),
  [8060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3462),
  [8062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9392),
  [8064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8995),
  [8066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16161),
  [8068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18284),
  [8070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [8072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7613),
  [8074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18448),
  [8076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [8078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7724),
  [8080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18260),
  [8082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [8084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7664),
  [8086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8182),
  [8088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7589),
  [8090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3252),
  [8092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7664),
  [8094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7587),
  [8096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3820),
  [8098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1795),
  [8100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12587),
  [8102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3792),
  [8104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1774),
  [8106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12706),
  [8108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9477),
  [8110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7572),
  [8112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_annotation_repeat1, 2),
  [8114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2),
  [8116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1811),
  [8119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8244),
  [8121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation, 3, .production_id = 53),
  [8123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation, 3, .production_id = 53),
  [8125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10235),
  [8127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18266),
  [8129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [8131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10021),
  [8133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10269),
  [8135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3306),
  [8137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10235),
  [8139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10205),
  [8141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15243),
  [8143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4734),
  [8145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18272),
  [8147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [8149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4807),
  [8151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4755),
  [8153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3268),
  [8155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4734),
  [8157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4706),
  [8159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8275),
  [8161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7865),
  [8163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8217),
  [8165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3263),
  [8167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8275),
  [8169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7625),
  [8171] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_expression, 3, .production_id = 63),
  [8173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_expression, 3, .production_id = 63),
  [8175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13274),
  [8177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2237),
  [8179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6730),
  [8181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6290),
  [8183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6678),
  [8185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3967),
  [8187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6730),
  [8189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6155),
  [8191] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prefix_expression, 2),
  [8193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prefix_expression, 2),
  [8195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18314),
  [8197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [8199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7174),
  [8201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7497),
  [8203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7181),
  [8205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3244),
  [8207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7174),
  [8209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6795),
  [8211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5375),
  [8213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18278),
  [8215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [8217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5461),
  [8219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5385),
  [8221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3190),
  [8223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5375),
  [8225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5102),
  [8227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3447),
  [8229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9209),
  [8231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1778),
  [8233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12899),
  [8235] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2),
  [8237] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2), SHIFT_REPEAT(6735),
  [8240] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2), SHIFT_REPEAT(5111),
  [8243] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2), SHIFT_REPEAT(6509),
  [8246] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2), SHIFT_REPEAT(6508),
  [8249] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2), SHIFT_REPEAT(6507),
  [8252] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_modifiers_repeat1, 2), SHIFT_REPEAT(6506),
  [8255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_modifiers_repeat1, 2),
  [8257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9374),
  [8259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4939),
  [8261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18061),
  [8263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [8265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4958),
  [8267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5041),
  [8269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3182),
  [8271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4939),
  [8273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5062),
  [8275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6327),
  [8277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6219),
  [8279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6207),
  [8281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3907),
  [8283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6327),
  [8285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6136),
  [8287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4930),
  [8289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18432),
  [8291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [8293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5032),
  [8295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4876),
  [8297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3406),
  [8299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4930),
  [8301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4943),
  [8303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4210),
  [8305] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__postfix_expression_choice, 1),
  [8307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_body, 2),
  [8309] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_body, 2),
  [8311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4207),
  [8313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4210),
  [8315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1782),
  [8317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [8319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8245),
  [8321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5875),
  [8323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5674),
  [8325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5886),
  [8327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3235),
  [8329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5875),
  [8331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5767),
  [8333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5309),
  [8335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5487),
  [8337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5344),
  [8339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3212),
  [8341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5309),
  [8343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5160),
  [8345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3498),
  [8347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1827),
  [8349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12578),
  [8351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3581),
  [8353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9213),
  [8355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1802),
  [8357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12818),
  [8359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6353),
  [8361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6233),
  [8363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6422),
  [8365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3516),
  [8367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6353),
  [8369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6499),
  [8371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5481),
  [8373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18152),
  [8375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [8377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5174),
  [8379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5450),
  [8381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3508),
  [8383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5481),
  [8385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5397),
  [8387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3460),
  [8389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1726),
  [8391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12933),
  [8393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7599),
  [8395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7543),
  [8397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7603),
  [8399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3282),
  [8401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7599),
  [8403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7844),
  [8405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3418),
  [8407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1739),
  [8409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12874),
  [8411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8883),
  [8413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8304),
  [8415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8804),
  [8417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3276),
  [8419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8883),
  [8421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8325),
  [8423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7297),
  [8425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6875),
  [8427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7309),
  [8429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3423),
  [8431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7297),
  [8433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7063),
  [8435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 1),
  [8437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6404),
  [8439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6224),
  [8441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6403),
  [8443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3696),
  [8445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6404),
  [8447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6388),
  [8449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5831),
  [8451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6088),
  [8453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5836),
  [8455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3459),
  [8457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5831),
  [8459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6085),
  [8461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3468),
  [8463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9339),
  [8465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1772),
  [8467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12904),
  [8469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5527),
  [8471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17980),
  [8473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [8475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5880),
  [8477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5521),
  [8479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3625),
  [8481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5527),
  [8483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5936),
  [8485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotated_type, 2),
  [8487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotated_type, 2),
  [8489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18414),
  [8491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [8493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8263),
  [8495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3590),
  [8497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1770),
  [8499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12786),
  [8501] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_type, 1),
  [8503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18435),
  [8505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [8507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7631),
  [8509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3774),
  [8511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9259),
  [8513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1805),
  [8515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12929),
  [8517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stable_type_identifier, 3),
  [8519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9237),
  [8521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13145),
  [8523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1707),
  [8525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_type, 2, .production_id = 41),
  [8527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_singleton_type, 3),
  [8529] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_projected_type, 3, .production_id = 82),
  [8531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 4),
  [8533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3924),
  [8535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9233),
  [8537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [8539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12668),
  [8541] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 5),
  [8543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9003),
  [8545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18413),
  [8547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [8549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8215),
  [8551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18465),
  [8553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [8555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8278),
  [8557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13144),
  [8559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15097),
  [8561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18437),
  [8563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [8565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7623),
  [8567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16099),
  [8569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13002),
  [8571] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1793),
  [8574] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1833),
  [8577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7914),
  [8579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7807),
  [8581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1815),
  [8583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 3),
  [8585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 4),
  [8587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 5),
  [8589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3690),
  [8591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1780),
  [8593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12858),
  [8595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3565),
  [8597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1808),
  [8599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12739),
  [8601] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2),
  [8603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2),
  [8605] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9131),
  [8608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1786),
  [8610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15746),
  [8612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3758),
  [8614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1766),
  [8616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12821),
  [8618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16009),
  [8620] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1744),
  [8623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9186),
  [8625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16304),
  [8627] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9557),
  [8630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3764),
  [8632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1787),
  [8634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12546),
  [8636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9260),
  [8638] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 3),
  [8640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9299),
  [8642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12081),
  [8644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1732),
  [8646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12264),
  [8648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12190),
  [8650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7526),
  [8652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1721),
  [8654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3662),
  [8656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9206),
  [8658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [8660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12871),
  [8662] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_wildcard, 1),
  [8664] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1754),
  [8667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3780),
  [8669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1757),
  [8671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12903),
  [8673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18460),
  [8675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [8677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8075),
  [8679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12077),
  [8681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3367),
  [8683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [8685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12662),
  [8687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 4),
  [8689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4),
  [8691] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1726),
  [8694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 3),
  [8696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3),
  [8698] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1827),
  [8701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8988),
  [8703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 2),
  [8705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2),
  [8707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18164),
  [8709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [8711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7913),
  [8713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12336),
  [8715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3258),
  [8717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9536),
  [8719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [8721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12579),
  [8723] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1795),
  [8726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3475),
  [8728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [8730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12870),
  [8732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9204),
  [8734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12082),
  [8736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18449),
  [8738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [8740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7786),
  [8742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3492),
  [8744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1831),
  [8746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12551),
  [8748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1774),
  [8751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [8753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18455),
  [8755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [8757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7899),
  [8759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8091),
  [8761] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9374),
  [8764] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1739),
  [8767] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_annotation_repeat1, 1),
  [8769] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9444),
  [8772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1235),
  [8774] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1746),
  [8777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7892),
  [8779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12102),
  [8781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16121),
  [8783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18452),
  [8785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [8787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7837),
  [8789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3543),
  [8791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1818),
  [8793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12563),
  [8795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3236),
  [8797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1789),
  [8799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12553),
  [8801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3480),
  [8803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1834),
  [8805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12517),
  [8807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [8809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1810),
  [8811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18434),
  [8813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [8815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7639),
  [8817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1545),
  [8819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12366),
  [8821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13345),
  [8823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15819),
  [8825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9064),
  [8827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7871),
  [8829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3184),
  [8831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9342),
  [8833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1850),
  [8835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12564),
  [8837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15324),
  [8839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13320),
  [8841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9306),
  [8843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13073),
  [8845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15741),
  [8847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12394),
  [8849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8020),
  [8851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3558),
  [8853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9137),
  [8855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1794),
  [8857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12723),
  [8859] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9266),
  [8862] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9477),
  [8865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3192),
  [8867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9218),
  [8869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1760),
  [8871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12516),
  [8873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1835),
  [8875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1756),
  [8877] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1761),
  [8880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16243),
  [8882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3571),
  [8884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1749),
  [8886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12635),
  [8888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9051),
  [8890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9542),
  [8892] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14),
  [8894] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18272),
  [8897] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(96),
  [8900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14),
  [8902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1771),
  [8904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3455),
  [8906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1855),
  [8908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12679),
  [8910] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9071),
  [8913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18467),
  [8915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [8917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8145),
  [8919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8148),
  [8921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3647),
  [8923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1750),
  [8925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12799),
  [8927] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unit, 2),
  [8929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unit, 2),
  [8931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bindings, 2),
  [8933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16324),
  [8935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1783),
  [8937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18466),
  [8939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [8941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8256),
  [8943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3315),
  [8945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9398),
  [8947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1733),
  [8949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12643),
  [8951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15382),
  [8953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18290),
  [8955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [8957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7659),
  [8959] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9209),
  [8962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3815),
  [8964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1856),
  [8966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12698),
  [8968] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1780),
  [8971] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18061),
  [8974] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(73),
  [8977] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9186),
  [8980] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81),
  [8982] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81),
  [8984] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8160),
  [8987] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9003),
  [8990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [8992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3629),
  [8994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [8996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12556),
  [8998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13208),
  [9000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3656),
  [9002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1839),
  [9004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12530),
  [9006] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1808),
  [9009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1385),
  [9011] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1766),
  [9014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1817),
  [9016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3987),
  [9018] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1),
  [9020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3985),
  [9022] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1),
  [9024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2364),
  [9026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3987),
  [9028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [9030] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9213),
  [9033] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9299),
  [9036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12132),
  [9038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16357),
  [9040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18462),
  [9042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [9044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8115),
  [9046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3554),
  [9048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9345),
  [9050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1798),
  [9052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12656),
  [9054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12172),
  [9056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1295),
  [9058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3495),
  [9060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [9062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12792),
  [9064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1611),
  [9066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15574),
  [9068] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18432),
  [9071] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(51),
  [9074] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 1),
  [9076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 1),
  [9078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2335),
  [9080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13031),
  [9082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1740),
  [9084] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1770),
  [9087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18358),
  [9089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [9091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7945),
  [9093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7576),
  [9095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12095),
  [9097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16358),
  [9099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1631),
  [9101] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1787),
  [9104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8063),
  [9106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18416),
  [9108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [9110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8191),
  [9112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1458),
  [9114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12388),
  [9116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1757),
  [9119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7646),
  [9122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12066),
  [9124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3874),
  [9126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [9128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12605),
  [9130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3482),
  [9132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9448),
  [9134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [9136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12838),
  [9138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13330),
  [9140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1813),
  [9142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3910),
  [9144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1712),
  [9146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12708),
  [9148] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9260),
  [9151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8956),
  [9153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1074),
  [9155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12229),
  [9157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3951),
  [9159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9391),
  [9161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1830),
  [9163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12715),
  [9165] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1721),
  [9168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12055),
  [9170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9314),
  [9172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9432),
  [9174] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1732),
  [9177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18422),
  [9179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [9181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8019),
  [9183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [9185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9237),
  [9188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3335),
  [9190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [9192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12537),
  [9194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1381),
  [9196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3937),
  [9198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1710),
  [9200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12697),
  [9202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8067),
  [9204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [9206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15225),
  [9208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9033),
  [9210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12094),
  [9212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3959),
  [9214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1720),
  [9216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12736),
  [9218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9408),
  [9220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16192),
  [9222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3476),
  [9224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [9226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12499),
  [9228] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9339),
  [9231] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1815),
  [9234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9341),
  [9236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9083),
  [9238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18418),
  [9240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [9242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8128),
  [9244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12291),
  [9246] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(8988),
  [9249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9036),
  [9251] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18278),
  [9254] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(79),
  [9257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12061),
  [9259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4062),
  [9261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4050),
  [9263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2140),
  [9265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4062),
  [9267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [9269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3419),
  [9271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8967),
  [9273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1718),
  [9275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12581),
  [9277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1678),
  [9279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3940),
  [9281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1731),
  [9283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12785),
  [9285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8087),
  [9287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4183),
  [9289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4181),
  [9291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4183),
  [9293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16680),
  [9295] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_access_modifier, 1),
  [9297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12991),
  [9299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access_modifier, 1),
  [9301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1422),
  [9303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9159),
  [9305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2282),
  [9307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18457),
  [9309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [9311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7991),
  [9313] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 80),
  [9315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 80),
  [9317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12324),
  [9319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1475),
  [9321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4157),
  [9323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4165),
  [9325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2249),
  [9327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4157),
  [9329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(585),
  [9331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18082),
  [9333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [9335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8137),
  [9337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4080),
  [9339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4144),
  [9341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2098),
  [9343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4080),
  [9345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(581),
  [9347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1554),
  [9349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1651),
  [9351] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9204),
  [9354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2205),
  [9356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1002),
  [9358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2345),
  [9360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(955),
  [9362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16372),
  [9364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1752),
  [9366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1490),
  [9368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifiers, 1),
  [9370] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1789),
  [9373] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18343),
  [9376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(21),
  [9379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12104),
  [9381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18428),
  [9383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [9385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7783),
  [9387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18438),
  [9389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [9391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7607),
  [9393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(888),
  [9395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12981),
  [9397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1529),
  [9399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3478),
  [9401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9164),
  [9403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1779),
  [9405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12509),
  [9407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16462),
  [9409] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 1),
  [9411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 1),
  [9413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__non_null_literal, 1),
  [9415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__non_null_literal, 1),
  [9417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_literal, 1),
  [9419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_literal, 1),
  [9421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18439),
  [9423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [9425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7891),
  [9427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15568),
  [9429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3289),
  [9431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1775),
  [9433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12594),
  [9435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1745),
  [9437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16573),
  [9439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18442),
  [9441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [9443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7553),
  [9445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16413),
  [9447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1714),
  [9449] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indented_block, 3),
  [9451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indented_block, 3),
  [9453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1768),
  [9455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8209),
  [9457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3375),
  [9459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [9461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12586),
  [9463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1499),
  [9465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18444),
  [9467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [9469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7634),
  [9471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4160),
  [9473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4166),
  [9475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2388),
  [9477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4160),
  [9479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(584),
  [9481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12135),
  [9483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13029),
  [9485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1728),
  [9487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9513),
  [9489] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8042),
  [9492] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9206),
  [9495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1693),
  [9497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9419),
  [9499] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1855),
  [9502] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7947),
  [9505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16352),
  [9507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1703),
  [9510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9075),
  [9512] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9064),
  [9515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__indented_template_body, 5),
  [9517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__indented_template_body, 5),
  [9519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__indented_template_body, 4),
  [9521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__indented_template_body, 4),
  [9523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8946),
  [9525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13111),
  [9527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12441),
  [9529] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9051),
  [9532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9127),
  [9534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_block, 3),
  [9536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_block, 3),
  [9538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1834),
  [9541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9324),
  [9543] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1831),
  [9546] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9259),
  [9549] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7613),
  [9552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9584),
  [9554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15807),
  [9556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body, 3),
  [9558] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__braced_template_body, 3),
  [9560] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9306),
  [9563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16213),
  [9565] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1810),
  [9568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3903),
  [9570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [9572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12898),
  [9574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15922),
  [9576] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1716),
  [9579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3296),
  [9581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1777),
  [9583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12488),
  [9585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1711),
  [9587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16653),
  [9589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9541),
  [9591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3530),
  [9593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1820),
  [9595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12663),
  [9597] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1818),
  [9600] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9542),
  [9603] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1764),
  [9606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3238),
  [9608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9060),
  [9610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1848),
  [9612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12771),
  [9614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4178),
  [9616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__postfix_expression_choice, 1),
  [9618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4170),
  [9620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4178),
  [9622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(608),
  [9624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12375),
  [9626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body, 2),
  [9628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__braced_template_body, 2),
  [9630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12191),
  [9632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12410),
  [9634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1819),
  [9636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [9638] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18152),
  [9641] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(120),
  [9644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7778),
  [9646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2124),
  [9648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3317),
  [9650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [9652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12505),
  [9654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__end_marker, 2, .production_id = 12),
  [9656] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__end_marker, 2, .production_id = 12),
  [9658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13159),
  [9660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1799),
  [9662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18468),
  [9664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [9666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8111),
  [9668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3634),
  [9670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1800),
  [9672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12791),
  [9674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__end_marker, 2),
  [9676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__end_marker, 2),
  [9678] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1749),
  [9681] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9233),
  [9684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3307),
  [9686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9490),
  [9688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [9690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12637),
  [9692] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7724),
  [9695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3682),
  [9697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1788),
  [9699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12843),
  [9701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3621),
  [9703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1809),
  [9705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12582),
  [9707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indented_cases, 3),
  [9709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indented_cases, 3),
  [9711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9585),
  [9713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3661),
  [9715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [9717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12781),
  [9719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12255),
  [9721] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7706),
  [9724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indented_block, 4),
  [9726] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indented_block, 4),
  [9728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3716),
  [9730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1773),
  [9732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12894),
  [9734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15878),
  [9736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7654),
  [9738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_body, 1),
  [9740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_body, 1),
  [9742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3833),
  [9744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3760),
  [9746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1644),
  [9748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16061),
  [9750] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8215),
  [9753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18383),
  [9755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [9757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8038),
  [9759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3557),
  [9761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16037),
  [9763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18458),
  [9765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [9767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8003),
  [9769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3391),
  [9771] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1797),
  [9774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3343),
  [9776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9061),
  [9778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1724),
  [9780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12699),
  [9782] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1839),
  [9785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9520),
  [9787] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(8956),
  [9790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3566),
  [9792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 5),
  [9794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 5),
  [9796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12431),
  [9798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3908),
  [9800] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__refinement, 1, .production_id = 37),
  [9802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__refinement, 1, .production_id = 37),
  [9804] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_type, 2, .production_id = 38),
  [9806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_type, 2, .production_id = 38),
  [9808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1584),
  [9810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4173),
  [9812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4167),
  [9814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2213),
  [9816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4173),
  [9818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(592),
  [9820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(890),
  [9822] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9137),
  [9825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1203),
  [9827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_type, 3, .production_id = 40),
  [9829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_type, 3, .production_id = 40),
  [9831] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8244),
  [9834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3881),
  [9836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4162),
  [9838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4159),
  [9840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2103),
  [9842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4162),
  [9844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(582),
  [9846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3638),
  [9848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8965),
  [9850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18456),
  [9852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [9854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7966),
  [9856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3337),
  [9858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4168),
  [9860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4179),
  [9862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2344),
  [9864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4168),
  [9866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(588),
  [9868] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8278),
  [9871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4158),
  [9873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4163),
  [9875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2207),
  [9877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4158),
  [9879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(583),
  [9881] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1856),
  [9884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12240),
  [9886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3415),
  [9888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1725),
  [9890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_splice_expression, 4),
  [9892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_splice_expression, 4),
  [9894] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 4),
  [9896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 4),
  [9898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2265),
  [9900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2377),
  [9902] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1783),
  [9905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3608),
  [9907] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1720),
  [9910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3717),
  [9912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [9914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12471),
  [9916] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8263),
  [9919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18176),
  [9921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [9923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7879),
  [9925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2165),
  [9927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3288),
  [9929] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 3, .production_id = 64),
  [9931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 3, .production_id = 64),
  [9933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3858),
  [9935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1751),
  [9937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12893),
  [9939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(934),
  [9941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3445),
  [9943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3645),
  [9945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9147),
  [9947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13361),
  [9949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1742),
  [9951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3598),
  [9953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1320),
  [9955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 3, .production_id = 61),
  [9957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, .production_id = 61),
  [9959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3613),
  [9961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1785),
  [9963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12604),
  [9965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3620),
  [9967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16264),
  [9969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instance_expression, 3, .production_id = 14),
  [9971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_expression, 3, .production_id = 14),
  [9973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3222),
  [9975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3922),
  [9977] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3),
  [9979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3),
  [9981] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, .production_id = 19),
  [9983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, .production_id = 19),
  [9985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9535),
  [9987] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_function, 2, .production_id = 18),
  [9989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_function, 2, .production_id = 18),
  [9991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3599),
  [9993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1767),
  [9995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12618),
  [9997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15371),
  [9999] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_splice_expression, 2),
  [10001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_splice_expression, 2),
  [10003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3703),
  [10005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3474),
  [10007] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8245),
  [10010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8129),
  [10012] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1781),
  [10015] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_instance_expression, 2),
  [10017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_instance_expression, 2),
  [10019] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2),
  [10021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2),
  [10023] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1750),
  [10026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2284),
  [10028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1841),
  [10030] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9314),
  [10033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3807),
  [10035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3450),
  [10037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3818),
  [10039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3804),
  [10041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3933),
  [10043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1014),
  [10045] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1), SHIFT(18426),
  [10048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [10050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7815),
  [10052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3835),
  [10054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3461),
  [10056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12202),
  [10058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3926),
  [10060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3188),
  [10062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3791),
  [10064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9128),
  [10066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12184),
  [10068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13393),
  [10070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1803),
  [10072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1098),
  [10074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3381),
  [10076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16221),
  [10078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1275),
  [10080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3749),
  [10082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3216),
  [10084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3722),
  [10086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3493),
  [10088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3942),
  [10090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12435),
  [10092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3950),
  [10094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3726),
  [10096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18453),
  [10098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [10100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7869),
  [10102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7718),
  [10104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12252),
  [10106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3294),
  [10108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4176),
  [10110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13195),
  [10112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4172),
  [10114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2340),
  [10116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4176),
  [10118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(590),
  [10120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [10122] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_type, 3, .production_id = 63),
  [10124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_type, 3, .production_id = 63),
  [10126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18463),
  [10128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [10130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8142),
  [10132] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1710),
  [10135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3240),
  [10137] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1817),
  [10140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8947),
  [10142] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1704),
  [10145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3819),
  [10147] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9536),
  [10150] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18436),
  [10153] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(42),
  [10156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12165),
  [10158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13259),
  [10160] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7623),
  [10163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18224),
  [10165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [10167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7678),
  [10169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3532),
  [10171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3958),
  [10173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [10175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12932),
  [10177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3435),
  [10179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3964),
  [10181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2189),
  [10183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15924),
  [10185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3679),
  [10187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [10189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7789),
  [10191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7572),
  [10194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1432),
  [10196] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9432),
  [10199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3592),
  [10201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12326),
  [10203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1), SHIFT(18308),
  [10206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18446),
  [10208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [10210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7663),
  [10212] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7631),
  [10215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3275),
  [10217] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9033),
  [10220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_colon_argument, 1),
  [10222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_colon_argument, 1),
  [10224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3655),
  [10226] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quote_expression, 2),
  [10228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quote_expression, 2),
  [10230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3425),
  [10232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1849),
  [10234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12651),
  [10236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3501),
  [10238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1826),
  [10240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12610),
  [10242] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolated_string_expression, 2, .production_id = 20),
  [10244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolated_string_expression, 2, .production_id = 20),
  [10246] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9342),
  [10249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3568),
  [10251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8973),
  [10253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_application, 2, .production_id = 39),
  [10255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_application, 2, .production_id = 39),
  [10257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2147),
  [10259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3327),
  [10261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1765),
  [10263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12669),
  [10265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3666),
  [10267] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1825),
  [10270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3868),
  [10272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3539),
  [10274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(876),
  [10276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16183),
  [10278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12101),
  [10280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3802),
  [10282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9013),
  [10284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9032),
  [10286] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolated_string, 2),
  [10288] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolated_string, 2),
  [10290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1708),
  [10292] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9218),
  [10295] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quote_expression, 4),
  [10297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quote_expression, 4),
  [10299] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolated_string, 3),
  [10301] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolated_string, 3),
  [10303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12462),
  [10305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12276),
  [10307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1497),
  [10309] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(17980),
  [10312] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(13),
  [10315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3827),
  [10317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3382),
  [10319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3559),
  [10321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3547),
  [10323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3295),
  [10325] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9341),
  [10328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3956),
  [10330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3627),
  [10332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4180),
  [10334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4177),
  [10336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2105),
  [10338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4180),
  [10340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(586),
  [10342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1182),
  [10344] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1712),
  [10347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12402),
  [10349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9230),
  [10351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3553),
  [10353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3784),
  [10355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_colon_argument, 3, .production_id = 134),
  [10357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_colon_argument, 3, .production_id = 134),
  [10359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12248),
  [10361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3761),
  [10363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1441),
  [10365] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18419),
  [10368] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(28),
  [10371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1701),
  [10373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3377),
  [10375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1755),
  [10377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12741),
  [10379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3426),
  [10381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9304),
  [10383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1842),
  [10385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12710),
  [10387] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9408),
  [10390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1719),
  [10392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12054),
  [10394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16381),
  [10396] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9083),
  [10399] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1736),
  [10402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3340),
  [10404] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1836),
  [10407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9534),
  [10409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9373),
  [10411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3775),
  [10413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18430),
  [10415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [10417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7737),
  [10419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12385),
  [10421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18423),
  [10423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [10425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7928),
  [10427] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9345),
  [10430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [10432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8155),
  [10434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12397),
  [10436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16301),
  [10438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1264),
  [10440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16250),
  [10442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13041),
  [10444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12353),
  [10446] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9075),
  [10449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16119),
  [10451] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7899),
  [10454] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9513),
  [10457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1758),
  [10459] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(3383),
  [10462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(572),
  [10464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1350),
  [10466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12178),
  [10468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(573),
  [10470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1202),
  [10472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1), SHIFT(18110),
  [10475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4191),
  [10477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4184),
  [10479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2325),
  [10481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4191),
  [10483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(602),
  [10485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4192),
  [10487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13215),
  [10489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4194),
  [10491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2390),
  [10493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4192),
  [10495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [10497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4189),
  [10499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4188),
  [10501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2337),
  [10503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4189),
  [10505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [10507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18425),
  [10509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [10511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7858),
  [10513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9419),
  [10516] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9448),
  [10519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7837),
  [10522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9389),
  [10524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18302),
  [10526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [10528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7744),
  [10530] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7639),
  [10533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1729),
  [10535] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1820),
  [10538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1711),
  [10541] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18089),
  [10544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(126),
  [10547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12434),
  [10549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12080),
  [10551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12177),
  [10553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4182),
  [10555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4190),
  [10557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2113),
  [10559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4182),
  [10561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(596),
  [10563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9046),
  [10566] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9585),
  [10569] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18194),
  [10572] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(91),
  [10575] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1768),
  [10578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13018),
  [10580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12243),
  [10582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9245),
  [10584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18464),
  [10586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [10588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8218),
  [10590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(675),
  [10592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1853),
  [10594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12091),
  [10596] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1777),
  [10599] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7807),
  [10602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9017),
  [10604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9773),
  [10606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3719),
  [10608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4276),
  [10610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12515),
  [10612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11243),
  [10614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9627),
  [10616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4279),
  [10618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2156),
  [10620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11295),
  [10622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4282),
  [10624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9773),
  [10626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4294),
  [10628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16002),
  [10630] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9159),
  [10633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15737),
  [10635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3872),
  [10637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [10639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12922),
  [10641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_access_modifier, 2),
  [10643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access_modifier, 2),
  [10645] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1775),
  [10648] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7526),
  [10651] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1734),
  [10654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8985),
  [10656] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7913),
  [10659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [10661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7544),
  [10663] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8075),
  [10666] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1714),
  [10669] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(8946),
  [10672] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1838),
  [10675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12383),
  [10677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_transparent_modifier, 1),
  [10679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_open_modifier, 1),
  [10681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_modifier, 1),
  [10683] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1800),
  [10686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8240),
  [10688] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1), SHIFT(18248),
  [10691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1034),
  [10693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16297),
  [10695] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18182),
  [10698] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(35),
  [10701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2376),
  [10703] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9398),
  [10706] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9127),
  [10709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8980),
  [10711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2224),
  [10713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_access_qualifier, 3),
  [10715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access_qualifier, 3),
  [10717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9014),
  [10719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18403),
  [10721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [10723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8138),
  [10725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9418),
  [10727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12409),
  [10729] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18454),
  [10732] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(60),
  [10735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12147),
  [10737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3896),
  [10739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1738),
  [10741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12804),
  [10743] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7786),
  [10746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15564),
  [10748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3826),
  [10750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1737),
  [10752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12683),
  [10754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3267),
  [10756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1822),
  [10758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12481),
  [10760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12299),
  [10762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8969),
  [10764] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7914),
  [10767] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1843),
  [10770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18393),
  [10772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [10774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8116),
  [10776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1139),
  [10778] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9324),
  [10781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2157),
  [10783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12456),
  [10785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12307),
  [10787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1591),
  [10789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(571),
  [10791] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9391),
  [10794] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1731),
  [10797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2152),
  [10799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12954),
  [10801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1254),
  [10803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [10805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3215),
  [10807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1812),
  [10809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12491),
  [10811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12160),
  [10813] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9584),
  [10816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2309),
  [10818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2130),
  [10820] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1788),
  [10823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4185),
  [10825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4193),
  [10827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2308),
  [10829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4185),
  [10831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(610),
  [10833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [10835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1828),
  [10837] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1773),
  [10840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2216),
  [10842] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1816),
  [10845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [10847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3181),
  [10849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1769),
  [10851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12540),
  [10853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_modifiers_repeat1, 1),
  [10855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3271),
  [10857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9470),
  [10859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [10861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12866),
  [10863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9295),
  [10865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2253),
  [10867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4186),
  [10869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4187),
  [10871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2171),
  [10873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4186),
  [10875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(605),
  [10877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3668),
  [10879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1762),
  [10881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12493),
  [10883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2144),
  [10885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3706),
  [10887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [10889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12852),
  [10891] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1767),
  [10894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12226),
  [10896] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifiers, 1),
  [10898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1056),
  [10900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18296),
  [10902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [10904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7696),
  [10906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12360),
  [10908] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1809),
  [10911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4200),
  [10913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4198),
  [10915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2262),
  [10917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4200),
  [10919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(646),
  [10921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1094),
  [10923] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_opaque_modifier, 1),
  [10925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4202),
  [10927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13219),
  [10929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4196),
  [10931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2247),
  [10933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4202),
  [10935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(628),
  [10937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4318),
  [10939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14455),
  [10941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11830),
  [10943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11829),
  [10945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9385),
  [10947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11828),
  [10949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14505),
  [10951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12053),
  [10953] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9060),
  [10956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12269),
  [10958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12251),
  [10960] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9013),
  [10963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1717),
  [10966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3677),
  [10968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1723),
  [10970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12592),
  [10972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12877),
  [10974] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7871),
  [10977] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7659),
  [10980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18429),
  [10982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [10984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7751),
  [10986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12857),
  [10988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1634),
  [10990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15231),
  [10992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13610),
  [10994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2367),
  [10996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13633),
  [10998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18447),
  [11000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [11002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7673),
  [11004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(981),
  [11006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1790),
  [11008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1722),
  [11010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2383),
  [11012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(626),
  [11014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9211),
  [11016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1177),
  [11018] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1708),
  [11021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15960),
  [11023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9050),
  [11025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18242),
  [11027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [11029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7579),
  [11031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1702),
  [11033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2164),
  [11035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(621),
  [11037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18206),
  [11040] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(78),
  [11043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12087),
  [11045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18424),
  [11047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7874),
  [11049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10933),
  [11051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12163),
  [11053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9286),
  [11055] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1713),
  [11058] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9147),
  [11061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10932),
  [11063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [11065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7972),
  [11067] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9541),
  [11070] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18353),
  [11073] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(36),
  [11076] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8191),
  [11079] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9230),
  [11082] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1759),
  [11085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3287),
  [11087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1829),
  [11089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12508),
  [11091] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9520),
  [11094] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9164),
  [11097] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1841),
  [11100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13211),
  [11102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [11104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18140),
  [11106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [11108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7983),
  [11110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9535),
  [11113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1727),
  [11116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type, 1), SHIFT(63),
  [11119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18368),
  [11122] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(61),
  [11125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9534),
  [11128] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8091),
  [11131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9036),
  [11134] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8115),
  [11137] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1845),
  [11140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1725),
  [11143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_capture_pattern, 3, .production_id = 88),
  [11145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_capture_pattern, 3, .production_id = 88),
  [11147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12180),
  [11149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3867),
  [11151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1753),
  [11153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12869),
  [11155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9462),
  [11157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12439),
  [11159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4205),
  [11161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4204),
  [11163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2407),
  [11165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4205),
  [11167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(622),
  [11169] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(8973),
  [11172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9423),
  [11174] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_pattern, 3, .production_id = 63),
  [11176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_pattern, 3, .production_id = 63),
  [11178] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8256),
  [11181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13056),
  [11183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16032),
  [11185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7892),
  [11188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8145),
  [11191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(8967),
  [11194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alternative_pattern, 3),
  [11196] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alternative_pattern, 3),
  [11198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1852),
  [11200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9490),
  [11203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4197),
  [11205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4199),
  [11207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2355),
  [11209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4197),
  [11211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(613),
  [11213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type, 1), SHIFT(37),
  [11216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13170),
  [11218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16241),
  [11220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1847),
  [11222] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1826),
  [11225] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1765),
  [11228] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18421),
  [11231] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(7),
  [11234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9525),
  [11236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12063),
  [11238] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7945),
  [11241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1755),
  [11244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12182),
  [11246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12275),
  [11248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16272),
  [11250] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8019),
  [11253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12364),
  [11255] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8020),
  [11258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12332),
  [11260] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9128),
  [11263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [11265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12348),
  [11267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18338),
  [11269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [11271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7885),
  [11273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13005),
  [11275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12068),
  [11277] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18427),
  [11280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(119),
  [11283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3574),
  [11285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1806),
  [11287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12766),
  [11289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9583),
  [11291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3943),
  [11293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12868),
  [11295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12022),
  [11297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4281),
  [11299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12304),
  [11301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4280),
  [11303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4272),
  [11305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16278),
  [11307] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1758),
  [11310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12365),
  [11312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18236),
  [11314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [11316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7626),
  [11318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2239),
  [11320] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9304),
  [11323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [11325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7833),
  [11327] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8067),
  [11330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12437),
  [11332] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18096),
  [11335] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(107),
  [11338] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8063),
  [11341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18230),
  [11343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [11345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7643),
  [11347] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(8980),
  [11350] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8111),
  [11353] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8137),
  [11356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1849),
  [11359] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9017),
  [11362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16268),
  [11364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1738),
  [11367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4259),
  [11369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11301),
  [11371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3576),
  [11373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12682),
  [11375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11777),
  [11377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2466),
  [11379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2317),
  [11381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4299),
  [11383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4296),
  [11385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4293),
  [11387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16132),
  [11389] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7783),
  [11392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12432),
  [11394] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18026),
  [11397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(22),
  [11400] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8128),
  [11403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12454),
  [11405] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(8965),
  [11408] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9032),
  [11411] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1), SHIFT(18332),
  [11414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12303),
  [11416] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8148),
  [11419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3830),
  [11421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13054),
  [11423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12862),
  [11425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12242),
  [11427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4290),
  [11429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1318),
  [11431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4287),
  [11433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4286),
  [11435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16093),
  [11437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3727),
  [11439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1326),
  [11441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12268),
  [11443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3649),
  [11445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1293),
  [11447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9336),
  [11449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3654),
  [11451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1294),
  [11453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2464),
  [11455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11835),
  [11457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9116),
  [11459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12457),
  [11461] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7991),
  [11464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1709),
  [11466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2645),
  [11469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), REDUCE(sym_binding, 1, .dynamic_precedence = 10, .production_id = 2),
  [11472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18001),
  [11475] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(4),
  [11478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4257),
  [11480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12421),
  [11482] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9418),
  [11485] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1751),
  [11488] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(8947),
  [11491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8152),
  [11493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3399),
  [11495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9067),
  [11497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [11499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12816),
  [11501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type, 1), SHIFT(72),
  [11504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2365),
  [11506] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9295),
  [11509] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1706),
  [11512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2114),
  [11514] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1), SHIFT(18146),
  [11517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15949),
  [11519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1231),
  [11521] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9373),
  [11524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3969),
  [11526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1624),
  [11528] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9061),
  [11531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3968),
  [11533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1614),
  [11535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4209),
  [11537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4208),
  [11539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2290),
  [11541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4209),
  [11543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(645),
  [11545] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7607),
  [11548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1853),
  [11551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4322),
  [11553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12173),
  [11555] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1762),
  [11558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3737),
  [11560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(865),
  [11562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3742),
  [11564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(948),
  [11566] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7891),
  [11569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12408),
  [11571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4242),
  [11573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11931),
  [11575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4221),
  [11577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12045),
  [11579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12037),
  [11581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2261),
  [11583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9059),
  [11585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2409),
  [11587] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1737),
  [11590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2297),
  [11592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12176),
  [11594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3755),
  [11596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1206),
  [11598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3752),
  [11600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1208),
  [11602] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9014),
  [11605] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1785),
  [11608] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7634),
  [11611] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7553),
  [11614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1345),
  [11616] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7576),
  [11619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12215),
  [11621] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_type, 1),
  [11623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_type, 1),
  [11625] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7879),
  [11628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2125),
  [11630] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8087),
  [11633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2342),
  [11635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18254),
  [11637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [11639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7510),
  [11641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12245),
  [11643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7789),
  [11646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18103),
  [11649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(86),
  [11652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1796),
  [11655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [11657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8040),
  [11659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12119),
  [11661] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8038),
  [11664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1628),
  [11666] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_infix_expression, 4, .production_id = 111),
  [11668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infix_expression, 4, .production_id = 111),
  [11670] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7654),
  [11673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__structural_type, 1, .production_id = 8),
  [11675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structural_type, 1, .production_id = 8),
  [11677] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1715),
  [11680] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7663),
  [11683] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_lambda, 7, .production_id = 181),
  [11685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_lambda, 7, .production_id = 181),
  [11687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_lambda, 6, .production_id = 175),
  [11689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_lambda, 6, .production_id = 175),
  [11691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15460),
  [11693] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1812),
  [11696] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7678),
  [11699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_lambda, 6, .production_id = 174),
  [11701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_lambda, 6, .production_id = 174),
  [11703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12358),
  [11705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__indented_type_cases, 3),
  [11707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__indented_type_cases, 3),
  [11709] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9245),
  [11712] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1741),
  [11715] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9286),
  [11718] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9389),
  [11721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_lambda, 5, .production_id = 163),
  [11723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_lambda, 5, .production_id = 163),
  [11725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [11727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7813),
  [11729] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8209),
  [11732] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9470),
  [11735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1747),
  [11737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_type, 2, .production_id = 76),
  [11739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type, 2, .production_id = 76),
  [11741] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1769),
  [11744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2167),
  [11746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12453),
  [11748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1822),
  [11751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2270),
  [11753] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7815),
  [11756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9321),
  [11758] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(8969),
  [11761] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7869),
  [11764] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1), SHIFT(18326),
  [11767] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18218),
  [11770] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(3),
  [11773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2110),
  [11775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_class_pattern_repeat1, 2),
  [11777] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8142),
  [11780] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7966),
  [11783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12105),
  [11785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2203),
  [11787] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arrow_then_type, 2, .production_id = 123),
  [11789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arrow_then_type, 2, .production_id = 123),
  [11791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2240),
  [11793] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(8985),
  [11796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1007),
  [11798] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9462),
  [11801] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9211),
  [11804] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7778),
  [11807] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1), SHIFT(18122),
  [11810] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8003),
  [11813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12947),
  [11815] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_type, 3),
  [11817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_type, 3),
  [11819] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18512),
  [11822] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(29),
  [11825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11473),
  [11827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11868),
  [11829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11478),
  [11831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3376),
  [11833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11473),
  [11835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11568),
  [11837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [11839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12789),
  [11841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13306),
  [11843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12774),
  [11845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3897),
  [11847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12789),
  [11849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12571),
  [11851] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1829),
  [11854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12084),
  [11856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8044),
  [11858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8416),
  [11860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8112),
  [11862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3745),
  [11864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8044),
  [11866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8173),
  [11868] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8138),
  [11871] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9006),
  [11874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2323),
  [11876] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7737),
  [11879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3707),
  [11881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4351),
  [11883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12652),
  [11885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13092),
  [11887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12650),
  [11889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3189),
  [11891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12652),
  [11893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12928),
  [11895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8050),
  [11897] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type_identifier, 1, .production_id = 7), SHIFT(2645),
  [11900] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type_identifier, 1, .production_id = 7), REDUCE(sym_binding, 1, .dynamic_precedence = 10, .production_id = 2),
  [11903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12194),
  [11905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12700),
  [11907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12200),
  [11909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3889),
  [11911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12194),
  [11913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12153),
  [11915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2638),
  [11917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8218),
  [11920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2347),
  [11922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11400),
  [11924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11515),
  [11926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11404),
  [11928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3763),
  [11930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11400),
  [11932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11258),
  [11934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11507),
  [11936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12019),
  [11938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11523),
  [11940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3911),
  [11942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11507),
  [11944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11479),
  [11946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11232),
  [11948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11516),
  [11950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11211),
  [11952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3624),
  [11954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11232),
  [11956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11387),
  [11958] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9050),
  [11961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12212),
  [11963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12600),
  [11965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12221),
  [11967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3715),
  [11969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12212),
  [11971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12057),
  [11973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10298),
  [11975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12089),
  [11977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3439),
  [11979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10298),
  [11981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11744),
  [11983] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7718),
  [11986] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7744),
  [11989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13272),
  [11991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13628),
  [11993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13275),
  [11995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3521),
  [11997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13272),
  [11999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13246),
  [12001] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8155),
  [12004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10937),
  [12006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11394),
  [12008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10952),
  [12010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3325),
  [12012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10937),
  [12014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11042),
  [12016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11321),
  [12018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11987),
  [12020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11241),
  [12022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3326),
  [12024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11321),
  [12026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11511),
  [12028] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1753),
  [12031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12208),
  [12033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4316),
  [12035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13240),
  [12037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4284),
  [12039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4316),
  [12041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1076),
  [12043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10946),
  [12045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11393),
  [12047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11103),
  [12049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3929),
  [12051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10946),
  [12053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11124),
  [12055] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1723),
  [12058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11305),
  [12060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13895),
  [12062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11356),
  [12064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3932),
  [12066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11305),
  [12068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13432),
  [12070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11859),
  [12072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12465),
  [12074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11858),
  [12076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3465),
  [12078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11859),
  [12080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11779),
  [12082] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7544),
  [12085] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7858),
  [12088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12528),
  [12090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13344),
  [12092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12500),
  [12094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3473),
  [12096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12528),
  [12098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12686),
  [12100] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9525),
  [12103] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8116),
  [12106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13264),
  [12108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13548),
  [12110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13282),
  [12112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3481),
  [12114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13264),
  [12116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13321),
  [12118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13294),
  [12120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13678),
  [12122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13266),
  [12124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3741),
  [12126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13294),
  [12128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13107),
  [12130] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__type, 1), SHIFT(18320),
  [12133] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9116),
  [12136] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7928),
  [12139] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9423),
  [12142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12655),
  [12144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13191),
  [12146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12654),
  [12148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3257),
  [12150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12655),
  [12152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12780),
  [12154] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8129),
  [12157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11658),
  [12159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12438),
  [12161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11596),
  [12163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3691),
  [12165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11658),
  [12167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11774),
  [12169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3781),
  [12171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(1672),
  [12174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16236),
  [12176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7803),
  [12178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7804),
  [12180] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__start_val, 2),
  [12182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__start_val, 2),
  [12184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6886),
  [12186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6885),
  [12188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8240),
  [12191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7579),
  [12194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__start_var, 2),
  [12196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__start_var, 2),
  [12198] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7874),
  [12201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__start_val, 3),
  [12203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__start_val, 3),
  [12205] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__start_var, 3),
  [12207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__start_var, 3),
  [12209] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7983),
  [12212] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7696),
  [12215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1806),
  [12218] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1747),
  [12221] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type, 1), SHIFT(55),
  [12224] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7673),
  [12227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6333),
  [12229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6332),
  [12231] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9059),
  [12234] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9067),
  [12237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9129),
  [12239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9109),
  [12241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8624),
  [12243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8618),
  [12245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8313),
  [12247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8319),
  [12249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8612),
  [12251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8495),
  [12253] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9583),
  [12256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7846),
  [12258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7845),
  [12260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5426),
  [12262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5422),
  [12264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9113),
  [12266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9105),
  [12268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9984),
  [12270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9916),
  [12272] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_type, 1), SHIFT(2639),
  [12275] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_type, 1), REDUCE(sym_binding, 1, .dynamic_precedence = 10),
  [12278] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7751),
  [12281] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9336),
  [12284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9429),
  [12286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9443),
  [12288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__start_var, 1),
  [12290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__start_var, 1),
  [12292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__start_val, 1),
  [12294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__start_val, 1),
  [12296] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7972),
  [12299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6109),
  [12301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6142),
  [12303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5526),
  [12305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5532),
  [12307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5915),
  [12309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5913),
  [12311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8529),
  [12313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8526),
  [12315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13053),
  [12317] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7643),
  [12320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15840),
  [12322] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(18266),
  [12325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_instance_expression, 2, .production_id = 14), SHIFT(110),
  [12328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_extension_definition_repeat1, 2),
  [12330] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_extension_definition_repeat1, 2), SHIFT_REPEAT(10663),
  [12333] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7626),
  [12336] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7833),
  [12339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12117),
  [12341] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7885),
  [12344] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_expression, 1), SHIFT(2639),
  [12347] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_expression, 1), REDUCE(sym_binding, 1, .dynamic_precedence = 10),
  [12350] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9321),
  [12353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14507),
  [12355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16609),
  [12357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2651),
  [12359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14929),
  [12361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11440),
  [12363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16974),
  [12365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [12367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17062),
  [12369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [12371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17221),
  [12373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [12375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 1, .production_id = 2),
  [12377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8027),
  [12379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9320),
  [12381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12850),
  [12383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4334),
  [12385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 1, .production_id = 2), SHIFT(15237),
  [12388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17104),
  [12390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [12392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17333),
  [12394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [12396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16952),
  [12398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [12400] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7813),
  [12403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13583),
  [12405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18472),
  [12407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17389),
  [12409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [12411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3925),
  [12413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12796),
  [12415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17040),
  [12417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [12419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17101),
  [12421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [12423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14484),
  [12425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17209),
  [12427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [12429] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7510),
  [12432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16930),
  [12434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [12436] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8040),
  [12439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10962),
  [12441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2470),
  [12443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14199),
  [12445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17293),
  [12447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [12449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16981),
  [12451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [12453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16996),
  [12455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [12457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17230),
  [12459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [12461] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8152),
  [12464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17251),
  [12466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [12468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17018),
  [12470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [12472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16863),
  [12474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [12476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17508),
  [12478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [12480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16908),
  [12482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [12484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16768),
  [12486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [12488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3421),
  [12490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [12492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12607),
  [12494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17272),
  [12496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [12498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17636),
  [12500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [12502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16760),
  [12504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [12506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16837),
  [12508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [12510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14770),
  [12512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14737),
  [12514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10928),
  [12516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2474),
  [12518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11122),
  [12520] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8050),
  [12523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10717),
  [12525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14591),
  [12527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14251),
  [12529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3525),
  [12531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9094),
  [12533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1784),
  [12535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12696),
  [12537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14838),
  [12539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10706),
  [12541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14772),
  [12543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14412),
  [12545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14710),
  [12547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8186),
  [12549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9554),
  [12551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13370),
  [12553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4327),
  [12555] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 1, .production_id = 2), SHIFT(15825),
  [12558] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stable_identifier, 3),
  [12560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1844),
  [12562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3392),
  [12564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12783),
  [12566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3500),
  [12568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12596),
  [12570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3534),
  [12572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9416),
  [12574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1792),
  [12576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12733),
  [12578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__using_parameters_clause, 4),
  [12580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14035),
  [12582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 4),
  [12584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10991),
  [12586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 4, .production_id = 121),
  [12588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 4, .production_id = 15),
  [12590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 5, .production_id = 121),
  [12592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 5),
  [12594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__using_parameters_clause, 5),
  [12596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 6),
  [12598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__using_parameters_clause, 6),
  [12600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14080),
  [12602] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1776),
  [12605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 3),
  [12607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 3, .production_id = 15),
  [12609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3879),
  [12611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12835),
  [12613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3704),
  [12615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12489),
  [12617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10926),
  [12619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14195),
  [12621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12152),
  [12623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14104),
  [12625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typed_pattern, 3, .production_id = 87),
  [12627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_declaration, 4, .production_id = 102),
  [12629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_declaration, 4, .production_id = 102),
  [12631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1493),
  [12633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_pattern, 3, .production_id = 87),
  [12635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14124),
  [12637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_val_declaration, 4, .production_id = 102),
  [12639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_val_declaration, 4, .production_id = 102),
  [12641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1481),
  [12643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7903),
  [12645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(941),
  [12647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 1),
  [12649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 2),
  [12651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12329),
  [12653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13963),
  [12655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(942),
  [12657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10954),
  [12659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 2, .production_id = 21),
  [12661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 2, .production_id = 21), SHIFT(15237),
  [12664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10940),
  [12666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3850),
  [12668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [12670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12718),
  [12672] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1733),
  [12675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_extension_definition_repeat1, 1),
  [12677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13833),
  [12679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1801),
  [12681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13957),
  [12683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1035),
  [12685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9906),
  [12687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3357),
  [12689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3352),
  [12691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3904),
  [12693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3541),
  [12695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1807),
  [12697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12466),
  [12699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8101),
  [12701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat_pattern, 2, .production_id = 50),
  [12703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat_pattern, 2, .production_id = 50),
  [12705] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 2, .production_id = 21), SHIFT(15825),
  [12708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_given_pattern, 2, .production_id = 48),
  [12710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_pattern, 2, .production_id = 48),
  [12712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3880),
  [12714] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_class_pattern, 5, .production_id = 151),
  [12716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_class_pattern, 5, .production_id = 151),
  [12718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12373),
  [12720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1513),
  [12722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1510),
  [12724] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1848),
  [12727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_pattern, 3),
  [12729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 3),
  [12731] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_class_pattern, 4, .production_id = 128),
  [12733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_class_pattern, 4, .production_id = 128),
  [12735] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_pattern, 4),
  [12737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 4),
  [12739] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_class_pattern, 6, .production_id = 168),
  [12741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_class_pattern, 6, .production_id = 168),
  [12743] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1779),
  [12746] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_class_pattern, 3, .production_id = 89),
  [12748] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_class_pattern, 3, .production_id = 89),
  [12750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3728),
  [12752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12930),
  [12754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [12756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3842),
  [12758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3555),
  [12760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(901),
  [12762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3546),
  [12764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3805),
  [12766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3822),
  [12768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12533),
  [12770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3305),
  [12772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12155),
  [12774] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9385),
  [12777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3580),
  [12779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1039),
  [12781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17089),
  [12783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17296),
  [12785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18132),
  [12787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17022),
  [12789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17024),
  [12791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17044),
  [12793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16755),
  [12795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17046),
  [12797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14377),
  [12799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12490),
  [12801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12449),
  [12803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14362),
  [12805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14377),
  [12807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12758),
  [12809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17065),
  [12811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 2, .production_id = 2),
  [12813] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 2, .production_id = 2), SHIFT(15237),
  [12816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17067),
  [12818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17152),
  [12820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17086),
  [12822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17088),
  [12824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12250),
  [12826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17107),
  [12828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17109),
  [12830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17128),
  [12832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17130),
  [12834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17149),
  [12836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18169),
  [12838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15424),
  [12840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17151),
  [12842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17170),
  [12844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17002),
  [12846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ascription_expression, 3, .dynamic_precedence = 4),
  [12848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11904),
  [12850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17157),
  [12852] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1842),
  [12855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17000),
  [12857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17172),
  [12859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16980),
  [12861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17631),
  [12863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17623),
  [12865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 3, .production_id = 21),
  [12867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, .production_id = 21), SHIFT(15237),
  [12870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14423),
  [12872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14383),
  [12874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14423),
  [12876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12557),
  [12878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17191),
  [12880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16978),
  [12882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17193),
  [12884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12463),
  [12886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17206),
  [12888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17212),
  [12890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17214),
  [12892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17890),
  [12894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16634),
  [12896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17233),
  [12898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16958),
  [12900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17235),
  [12902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17254),
  [12904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3536),
  [12906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12694),
  [12908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16956),
  [12910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16936),
  [12912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16934),
  [12914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17256),
  [12916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16914),
  [12918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17751),
  [12920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17746),
  [12922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9987),
  [12924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17884),
  [12926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16912),
  [12928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12220),
  [12930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3828),
  [12932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9523),
  [12934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12847),
  [12936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16892),
  [12938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16890),
  [12940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9998),
  [12942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17489),
  [12944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18301),
  [12946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17561),
  [12948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17081),
  [12950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17275),
  [12952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16868),
  [12954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17496),
  [12956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16866),
  [12958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3731),
  [12960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9528),
  [12962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12513),
  [12964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17031),
  [12966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17277),
  [12968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 1, .production_id = 11),
  [12970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18512),
  [12972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4425),
  [12974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12032),
  [12976] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 1, .production_id = 11), SHIFT(14850),
  [12979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16844),
  [12981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17025),
  [12983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16842),
  [12985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16819),
  [12987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16817),
  [12989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16967),
  [12991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17210),
  [12993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12131),
  [12995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16799),
  [12997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16965),
  [12999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17298),
  [13001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16910),
  [13003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16794),
  [13005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16904),
  [13007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17316),
  [13009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17318),
  [13011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16792),
  [13013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17336),
  [13015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17551),
  [13017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17338),
  [13019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17355),
  [13021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17357),
  [13023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 1, .production_id = 2),
  [13025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17374),
  [13027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17376),
  [13029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16767),
  [13031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17494),
  [13033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17393),
  [13035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15237),
  [13037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17395),
  [13039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16765),
  [13041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16737),
  [13043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17412),
  [13045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17261),
  [13047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12695),
  [13049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12258),
  [13051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17414),
  [13053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17431),
  [13055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17433),
  [13057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16735),
  [13059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17450),
  [13061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17452),
  [13063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16716),
  [13065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17688),
  [13067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17682),
  [13069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16714),
  [13071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17463),
  [13073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17438),
  [13075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17627),
  [13077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16645),
  [13079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17465),
  [13081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17625),
  [13083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17616),
  [13085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17476),
  [13087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16698),
  [13089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17808),
  [13091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17866),
  [13093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17428),
  [13095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17614),
  [13097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17605),
  [13099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17603),
  [13101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17593),
  [13103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17591),
  [13105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17581),
  [13107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17478),
  [13109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17579),
  [13111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17569),
  [13113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17567),
  [13115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17812),
  [13117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17556),
  [13119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16850),
  [13121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3491),
  [13123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12539),
  [13125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17554),
  [13127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17543),
  [13129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17541),
  [13131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16845),
  [13133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17380),
  [13135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17371),
  [13137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17325),
  [13139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16802),
  [13141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17322),
  [13143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16696),
  [13145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1724),
  [13148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18094),
  [13150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17530),
  [13152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17528),
  [13154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17517),
  [13156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17515),
  [13158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16752),
  [13160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17504),
  [13162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17502),
  [13164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17265),
  [13166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17857),
  [13168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17491),
  [13170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__indentable_expression, 1),
  [13172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3692),
  [13174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15116),
  [13176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_expression, 2),
  [13178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_expression, 2),
  [13180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18096),
  [13182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7688),
  [13184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_expression, 3, .production_id = 47),
  [13186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, .production_id = 62),
  [13188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_expression, 5, .production_id = 127),
  [13190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9972),
  [13192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expr_case_clause, 3, .production_id = 71),
  [13194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13789),
  [13196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12143),
  [13198] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 2, .production_id = 2), SHIFT(15825),
  [13201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1824),
  [13203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12271),
  [13205] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1832),
  [13208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12285),
  [13210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12076),
  [13212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1730),
  [13215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9094),
  [13218] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, .production_id = 21), SHIFT(15825),
  [13221] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1784),
  [13224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3349),
  [13226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 1, .production_id = 2),
  [13228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8131),
  [13230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3947),
  [13232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3948),
  [13234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3339),
  [13236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12237),
  [13238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_expression, 3, .production_id = 13),
  [13240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 3, .production_id = 42),
  [13242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expression, 3, .production_id = 60),
  [13244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18431),
  [13246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14217),
  [13248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_expression, 4, .production_id = 86),
  [13250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15051),
  [13252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_expression, 4, .production_id = 90),
  [13254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 2),
  [13256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 2, .production_id = 91),
  [13258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finally_clause, 2),
  [13260] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_expression, 4, .production_id = 13),
  [13262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 4, .production_id = 98),
  [13264] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_while_expression, 4, .production_id = 101),
  [13266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expression, 4, .production_id = 110),
  [13268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_match_expression, 3, .production_id = 60), REDUCE(sym_match_expression, 4, .production_id = 110),
  [13271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_block, 2),
  [13273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lazy_parameter_type, 2, .production_id = 48),
  [13275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeated_parameter_type, 2, .production_id = 89),
  [13277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12379),
  [13279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18408),
  [13281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 5, .production_id = 126),
  [13283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 6, .production_id = 149),
  [13285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_expression, 6, .production_id = 150),
  [13287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 6, .production_id = 155),
  [13289] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 5, .production_id = 126), REDUCE(sym_if_expression, 6, .production_id = 155),
  [13292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 7, .production_id = 169),
  [13294] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 6, .production_id = 149), REDUCE(sym_if_expression, 7, .production_id = 169),
  [13297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4419),
  [13299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11872),
  [13301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 1, .production_id = 11), SHIFT(14657),
  [13304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3470),
  [13306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12707),
  [13308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 1, .production_id = 2),
  [13310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10467),
  [13312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13047),
  [13314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7701),
  [13316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3965),
  [13318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12750),
  [13320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1772),
  [13323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12995),
  [13325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3193),
  [13327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12987),
  [13329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12995),
  [13331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5503),
  [13333] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type_identifier, 1, .production_id = 7), SHIFT(12377),
  [13336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12413),
  [13338] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type_identifier, 1, .production_id = 7), SHIFT(8059),
  [13341] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type_identifier, 1, .production_id = 7), SHIFT(10467),
  [13344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14894),
  [13346] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 1),
  [13348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 1),
  [13350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [13352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1743),
  [13354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9754),
  [13356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3892),
  [13358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12614),
  [13360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3522),
  [13362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12772),
  [13364] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 5, .production_id = 96),
  [13366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 5, .production_id = 96),
  [13368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5596),
  [13370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6035),
  [13372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5175),
  [13374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4981),
  [13376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1805),
  [13379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12279),
  [13381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12848),
  [13383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14364),
  [13385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5233),
  [13387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5301),
  [13389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10424),
  [13391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8009),
  [13393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6854),
  [13395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5119),
  [13397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5027),
  [13399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8920),
  [13401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8265),
  [13403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11334),
  [13405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16615),
  [13407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9777),
  [13409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12103),
  [13411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12048),
  [13413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5021),
  [13415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4754),
  [13417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12920),
  [13419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6902),
  [13421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6331),
  [13423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4687),
  [13425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4579),
  [13427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5082),
  [13429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4639),
  [13431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9499),
  [13433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8951),
  [13435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8062),
  [13437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7061),
  [13439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7310),
  [13441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6468),
  [13443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4903),
  [13445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5068),
  [13447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5077),
  [13449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5067),
  [13451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3701),
  [13453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12881),
  [13455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5587),
  [13457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6070),
  [13459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4638),
  [13461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4743),
  [13463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5271),
  [13465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5320),
  [13467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9447),
  [13469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8903),
  [13471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13290),
  [13473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12837),
  [13475] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1801),
  [13478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13530),
  [13480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12966),
  [13482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10290),
  [13484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10101),
  [13486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9201),
  [13488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8379),
  [13490] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 4, .production_id = 77),
  [13492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 4, .production_id = 77),
  [13494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 4, .production_id = 55),
  [13496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 4, .production_id = 55),
  [13498] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 4, .production_id = 96),
  [13500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 4, .production_id = 96),
  [13502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 4, .production_id = 21),
  [13504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 4, .production_id = 21),
  [13506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11848),
  [13508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11563),
  [13510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5317),
  [13512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4880),
  [13514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12510),
  [13516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6051),
  [13518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5332),
  [13520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3657),
  [13522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12813),
  [13524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10791),
  [13526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12232),
  [13528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10894),
  [13530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7376),
  [13532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6662),
  [13534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3934),
  [13536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9471),
  [13538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1814),
  [13540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12790),
  [13542] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1807),
  [13545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11298),
  [13547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10957),
  [13549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12428),
  [13551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11536),
  [13553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11333),
  [13555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13673),
  [13557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13101),
  [13559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14553),
  [13561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7101),
  [13563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6539),
  [13565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7432),
  [13567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7217),
  [13569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6766),
  [13571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5656),
  [13573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8264),
  [13575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10514),
  [13577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13413),
  [13579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5155),
  [13581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4978),
  [13583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8919),
  [13585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7777),
  [13587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13800),
  [13589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13621),
  [13591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7937),
  [13593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7855),
  [13595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7437),
  [13597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6517),
  [13599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7361),
  [13601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6746),
  [13603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8074),
  [13605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7239),
  [13607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7180),
  [13609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6942),
  [13611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6143),
  [13613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5965),
  [13615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13386),
  [13617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12598),
  [13619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4756),
  [13621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4571),
  [13623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5419),
  [13625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5323),
  [13627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12711),
  [13629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6203),
  [13631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5896),
  [13633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13204),
  [13635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15025),
  [13637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9598),
  [13639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9425),
  [13641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8514),
  [13643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8568),
  [13645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13081),
  [13647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12849),
  [13649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11900),
  [13651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11674),
  [13653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6983),
  [13655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7103),
  [13657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5440),
  [13659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4879),
  [13661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12318),
  [13663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11966),
  [13665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6297),
  [13667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6062),
  [13669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6518),
  [13671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6396),
  [13673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8578),
  [13675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8632),
  [13677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6435),
  [13679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5955),
  [13681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11875),
  [13683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11524),
  [13685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8249),
  [13687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7091),
  [13689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5747),
  [13691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6092),
  [13693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9600),
  [13695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5748),
  [13697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5387),
  [13699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4729),
  [13701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4562),
  [13703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8757),
  [13705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8179),
  [13707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6870),
  [13709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7017),
  [13711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6602),
  [13713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6021),
  [13715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12822),
  [13717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12235),
  [13719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4402),
  [13721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4321),
  [13723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_applications, 1, .production_id = 67),
  [13725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4487),
  [13727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4486),
  [13729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12254),
  [13731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12000),
  [13733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5865),
  [13735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5281),
  [13737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3529),
  [13739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12631),
  [13741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13338),
  [13743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12486),
  [13745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6980),
  [13747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6653),
  [13749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7555),
  [13751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8010),
  [13753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7477),
  [13755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6319),
  [13757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 2, .production_id = 30),
  [13759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5938),
  [13761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5389),
  [13763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6739),
  [13765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5906),
  [13767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13501),
  [13769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13319),
  [13771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3469),
  [13773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14883),
  [13775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11375),
  [13777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10903),
  [13779] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 2),
  [13781] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 2),
  [13783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7927),
  [13785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6857),
  [13787] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 3, .production_id = 42),
  [13789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 3, .production_id = 42),
  [13791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4891),
  [13793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4692),
  [13795] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 3, .production_id = 77),
  [13797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 3, .production_id = 77),
  [13799] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 3, .production_id = 35),
  [13801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 3, .production_id = 35),
  [13803] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 3, .production_id = 55),
  [13805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 3, .production_id = 55),
  [13807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14832),
  [13809] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 3, .production_id = 21),
  [13811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 3, .production_id = 21),
  [13813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7564),
  [13815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7373),
  [13817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6562),
  [13819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6716),
  [13821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 3, .production_id = 2),
  [13823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 3, .production_id = 2),
  [13825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9511),
  [13827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8825),
  [13829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7867),
  [13831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7392),
  [13833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7975),
  [13835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6813),
  [13837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7562),
  [13839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7878),
  [13841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4877),
  [13843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4698),
  [13845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11465),
  [13847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11340),
  [13849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5729),
  [13851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5100),
  [13853] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1821),
  [13856] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 2, .production_id = 2),
  [13858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 2, .production_id = 2),
  [13860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6173),
  [13862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6267),
  [13864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6997),
  [13866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6519),
  [13868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5474),
  [13870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4926),
  [13872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4952),
  [13874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4752),
  [13876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16603),
  [13878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6410),
  [13880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6715),
  [13882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6360),
  [13884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5670),
  [13886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3743),
  [13888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4555),
  [13890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4478),
  [13892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8734),
  [13894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7637),
  [13896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7275),
  [13898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6335),
  [13900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5907),
  [13902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5306),
  [13904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13969),
  [13906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12111),
  [13908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14076),
  [13910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14036),
  [13912] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 2, .production_id = 42),
  [13914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 2, .production_id = 42),
  [13916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 2, .production_id = 44),
  [13918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 2, .production_id = 44), SHIFT(14850),
  [13921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15009),
  [13923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1823),
  [13925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13254),
  [13927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12684),
  [13929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12630),
  [13931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12445),
  [13933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__given_constructor, 2, .production_id = 35),
  [13935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__given_constructor, 2, .production_id = 35),
  [13937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6427),
  [13939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5643),
  [13941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8330),
  [13943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8041),
  [13945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7360),
  [13947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6289),
  [13949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6441),
  [13951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5795),
  [13953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7716),
  [13955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7962),
  [13957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8281),
  [13959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6824),
  [13961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5984),
  [13963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5292),
  [13965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9409),
  [13967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8602),
  [13969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8445),
  [13971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8239),
  [13973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7209),
  [13975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6734),
  [13977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8378),
  [13979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7953),
  [13981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13381),
  [13983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12473),
  [13985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6145),
  [13987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6071),
  [13989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11950),
  [13991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11447),
  [13993] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9416),
  [13996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12225),
  [13998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16532),
  [14000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5730),
  [14002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9099),
  [14004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [14006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3789),
  [14008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9031),
  [14010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9099),
  [14012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10230),
  [14014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [14016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3444),
  [14018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10279),
  [14020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10230),
  [14022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3564),
  [14024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15187),
  [14026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8279),
  [14028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16663),
  [14030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6050),
  [14032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6596),
  [14034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [14036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3467),
  [14038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6528),
  [14040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6596),
  [14042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16616),
  [14044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5937),
  [14046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16469),
  [14048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5857),
  [14050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16672),
  [14052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6103),
  [14054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8284),
  [14056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16421),
  [14058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6049),
  [14060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 2, .production_id = 55),
  [14062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13100),
  [14064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 2, .production_id = 21),
  [14066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13099),
  [14068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7389),
  [14070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11967),
  [14072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11590),
  [14074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8465),
  [14076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3788),
  [14078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8466),
  [14080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6061),
  [14082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16477),
  [14084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5721),
  [14086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6170),
  [14088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5814),
  [14090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14860),
  [14092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6008),
  [14094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7203),
  [14096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3639),
  [14098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12547),
  [14100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 5, .production_id = 143),
  [14102] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 5, .production_id = 143), SHIFT(15237),
  [14105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9243),
  [14107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7886),
  [14109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16501),
  [14111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5553),
  [14113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6091),
  [14115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13252),
  [14117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16586),
  [14119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5691),
  [14121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10804),
  [14123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10878),
  [14125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10804),
  [14127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10798),
  [14129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6461),
  [14131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5988),
  [14133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4541),
  [14135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13133),
  [14137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16570),
  [14139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5552),
  [14141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5742),
  [14143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11385),
  [14145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [14147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3358),
  [14149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11284),
  [14151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11385),
  [14153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9819),
  [14155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [14157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3350),
  [14159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9793),
  [14161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9819),
  [14163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11960),
  [14165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6409),
  [14167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_constructor_repeat1, 2),
  [14169] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_constructor_repeat1, 2), SHIFT_REPEAT(10467),
  [14172] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_constructor_repeat1, 2), SHIFT_REPEAT(15406),
  [14175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_expression, 2, .production_id = 13),
  [14177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [14179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1662),
  [14181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16405),
  [14183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6003),
  [14185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14147),
  [14187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6157),
  [14189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12638),
  [14191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8301),
  [14193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9284),
  [14195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [14197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3909),
  [14199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9224),
  [14201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9284),
  [14203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5813),
  [14205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [14207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3927),
  [14209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5773),
  [14211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5813),
  [14213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5702),
  [14215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__class_constructor_repeat1, 2),
  [14217] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__class_constructor_repeat1, 2), SHIFT_REPEAT(4334),
  [14220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__class_constructor_repeat1, 2), SHIFT_REPEAT(15237),
  [14223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5467),
  [14225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5928),
  [14227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12110),
  [14229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5902),
  [14231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5696),
  [14233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [14235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [14237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6383),
  [14239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_enum_case, 1, .production_id = 2),
  [14241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4391),
  [14243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4337),
  [14245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10317),
  [14247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [14249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3617),
  [14251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10339),
  [14253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10317),
  [14255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16488),
  [14257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5693),
  [14259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7318),
  [14261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [14263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3610),
  [14265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7358),
  [14267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7318),
  [14269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 4, .production_id = 116),
  [14271] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 4, .production_id = 116), SHIFT(15237),
  [14274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 4, .production_id = 115),
  [14276] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 4, .production_id = 115), SHIFT(15237),
  [14279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5744),
  [14281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6566),
  [14283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 4, .production_id = 21),
  [14285] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 4, .production_id = 21), SHIFT(15237),
  [14288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12171),
  [14290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 2, .production_id = 21),
  [14292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11963),
  [14294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6852),
  [14296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [14298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3593),
  [14300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6802),
  [14302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6852),
  [14304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16649),
  [14306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12459),
  [14308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9919),
  [14310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [14312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3619),
  [14314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9795),
  [14316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9919),
  [14318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16385),
  [14320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5837),
  [14322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [14324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3614),
  [14326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5659),
  [14328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8296),
  [14330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [14332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3606),
  [14334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8372),
  [14336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8296),
  [14338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4941),
  [14340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6613),
  [14342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16647),
  [14344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5752),
  [14346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7684),
  [14348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6957),
  [14350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4452),
  [14352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4456),
  [14354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16432),
  [14356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5903),
  [14358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5850),
  [14360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7378),
  [14362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4887),
  [14364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9135),
  [14366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5732),
  [14368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6907),
  [14370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11477),
  [14372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16408),
  [14374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5626),
  [14376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11550),
  [14378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [14380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3270),
  [14382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11450),
  [14384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11550),
  [14386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [14388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3269),
  [14390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5846),
  [14392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8007),
  [14394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6138),
  [14396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11351),
  [14398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14152),
  [14400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7558),
  [14402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6018),
  [14404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13309),
  [14406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7824),
  [14408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [14410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3944),
  [14412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7823),
  [14414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7824),
  [14416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7377),
  [14418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [14420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3935),
  [14422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7405),
  [14424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7377),
  [14426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16435),
  [14428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5750),
  [14430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7959),
  [14432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5842),
  [14434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16461),
  [14436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5584),
  [14438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9390),
  [14440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [14442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3457),
  [14444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9317),
  [14446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9390),
  [14448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [14450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3451),
  [14452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13491),
  [14454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11599),
  [14456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5925),
  [14458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7596),
  [14460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [14462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [14464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14538),
  [14466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 3, .production_id = 96),
  [14468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13192),
  [14470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6799),
  [14472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16395),
  [14474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5660),
  [14476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5999),
  [14478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8900),
  [14480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [14482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3801),
  [14484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8917),
  [14486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8900),
  [14488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [14490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3809),
  [14492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11069),
  [14494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [14496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3813),
  [14498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11164),
  [14500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11069),
  [14502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7749),
  [14504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16533),
  [14506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5758),
  [14508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7157),
  [14510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3187),
  [14512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4386),
  [14514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7482),
  [14516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 3, .production_id = 66),
  [14518] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, .production_id = 66), SHIFT(15237),
  [14521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 3, .production_id = 2),
  [14523] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, .production_id = 2), SHIFT(15237),
  [14526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5615),
  [14528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5689),
  [14530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8183),
  [14532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 3, .production_id = 65),
  [14534] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, .production_id = 65), SHIFT(15237),
  [14537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5686),
  [14539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5632),
  [14541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6002),
  [14543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5921),
  [14545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5920),
  [14547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11355),
  [14549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8911),
  [14551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12218),
  [14553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13124),
  [14555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9578),
  [14557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [14559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3894),
  [14561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9566),
  [14563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9578),
  [14565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [14567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3884),
  [14569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16513),
  [14571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5642),
  [14573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12826),
  [14575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11985),
  [14577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6382),
  [14579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6189),
  [14581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8634),
  [14583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6026),
  [14585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4872),
  [14587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13392),
  [14589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6615),
  [14591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8727),
  [14593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5769),
  [14595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5572),
  [14597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6976),
  [14599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 2, .production_id = 44), SHIFT(14657),
  [14602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11731),
  [14604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16485),
  [14606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5538),
  [14608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8756),
  [14610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [14612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3303),
  [14614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8808),
  [14616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8756),
  [14618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6555),
  [14620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [14622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3298),
  [14624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9808),
  [14626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [14628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3198),
  [14630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9968),
  [14632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9808),
  [14634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [14636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3234),
  [14638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12262),
  [14640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6213),
  [14642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5533),
  [14644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5446),
  [14646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8030),
  [14648] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1794),
  [14651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [14653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1530),
  [14655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14357),
  [14657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5685),
  [14659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6095),
  [14661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [14663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3952),
  [14665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13379),
  [14667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5559),
  [14669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_constructor, 2, .production_id = 22),
  [14671] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 2, .production_id = 22), SHIFT(15237),
  [14674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [14676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3971),
  [14678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5499),
  [14680] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1748),
  [14683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4427),
  [14685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4332),
  [14687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9594),
  [14689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [14691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3796),
  [14693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9599),
  [14695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9594),
  [14697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [14699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3793),
  [14701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4704),
  [14703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9799),
  [14705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7950),
  [14707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13089),
  [14709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15150),
  [14711] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7903),
  [14714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4745),
  [14716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5618),
  [14718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12189),
  [14720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7198),
  [14722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5513),
  [14724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11503),
  [14726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8644),
  [14728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [14730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3243),
  [14732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8641),
  [14734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8644),
  [14736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7089),
  [14738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5159),
  [14740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13877),
  [14742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7423),
  [14744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6176),
  [14746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5684),
  [14748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9900),
  [14750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11279),
  [14752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13552),
  [14754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6692),
  [14756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [14758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3232),
  [14760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8935),
  [14762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5563),
  [14764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [14766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3281),
  [14768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3573),
  [14770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9485),
  [14772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1763),
  [14774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12536),
  [14776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6064),
  [14778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13653),
  [14780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10353),
  [14782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5405),
  [14784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5170),
  [14786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16516),
  [14788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6357),
  [14790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [14792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3697),
  [14794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6351),
  [14796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6357),
  [14798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [14800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3686),
  [14802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5681),
  [14804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11844),
  [14806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7394),
  [14808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7866),
  [14810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [14812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3299),
  [14814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7502),
  [14816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7866),
  [14818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5885),
  [14820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9596),
  [14822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7365),
  [14824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8008),
  [14826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [14828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3806),
  [14830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8000),
  [14832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8008),
  [14834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [14836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3816),
  [14838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13313),
  [14840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13137),
  [14842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16451),
  [14844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6012),
  [14846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9091),
  [14848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5610),
  [14850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5294),
  [14852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4793),
  [14854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [14856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11661),
  [14858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [14860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3729),
  [14862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5070),
  [14864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11332),
  [14866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [14868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3714),
  [14870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11274),
  [14872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11332),
  [14874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9187),
  [14876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5912),
  [14878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11294),
  [14880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8986),
  [14882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6078),
  [14884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5870),
  [14886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5682),
  [14888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7998),
  [14890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4870),
  [14892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16441),
  [14894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5639),
  [14896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13449),
  [14898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [14900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3372),
  [14902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5059),
  [14904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4802),
  [14906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5709),
  [14908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8200),
  [14910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7306),
  [14912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5760),
  [14914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6808),
  [14916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5251),
  [14918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [14920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3602),
  [14922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [14924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3591),
  [14926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6046),
  [14928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5124),
  [14930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5279),
  [14932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14514),
  [14934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [14936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3437),
  [14938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [14940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3424),
  [14942] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1760),
  [14945] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1850),
  [14948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10526),
  [14950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [14952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3390),
  [14954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10425),
  [14956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10526),
  [14958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [14960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3490),
  [14962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [14964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3395),
  [14966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5726),
  [14968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16558),
  [14970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5509),
  [14972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8663),
  [14974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [14976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3537),
  [14978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [14980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3396),
  [14982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [14984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3404),
  [14986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5706),
  [14988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5874),
  [14990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12297),
  [14992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5534),
  [14994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12108),
  [14996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [14998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8156),
  [15000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4832),
  [15002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5798),
  [15004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12427),
  [15006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [15008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3551),
  [15010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16675),
  [15012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18011),
  [15014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [15016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9832),
  [15018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [15020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [15022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [15024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [15026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [15028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1390),
  [15030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1461),
  [15032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [15034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3548),
  [15036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16550),
  [15038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1494),
  [15040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1512),
  [15042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8894),
  [15044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1560),
  [15046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [15048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [15050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13682),
  [15052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [15054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [15056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18470),
  [15058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16631),
  [15060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [15062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1128),
  [15064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [15066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [15068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [15070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14856),
  [15072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [15074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6475),
  [15076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10613),
  [15078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [15080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16660),
  [15082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12490),
  [15084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4278),
  [15086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12449),
  [15088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12422),
  [15090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9661),
  [15092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9671),
  [15094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12447),
  [15096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12529),
  [15098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [15100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [15102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [15104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10005),
  [15106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [15108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [15110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13779),
  [15112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 2, .production_id = 31),
  [15114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16661),
  [15116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16597),
  [15118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(676),
  [15120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1617),
  [15122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [15124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [15126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8423),
  [15128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [15130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7734),
  [15132] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(8101),
  [15135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [15137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [15139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 2, .production_id = 45),
  [15141] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 2, .production_id = 45), SHIFT(14850),
  [15144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9944),
  [15146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16559),
  [15148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12695),
  [15150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4283),
  [15152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12258),
  [15154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12265),
  [15156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12259),
  [15158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12676),
  [15160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 2, .production_id = 2),
  [15162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [15164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1671),
  [15166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [15168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16642),
  [15170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [15172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10112),
  [15174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [15176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1393),
  [15178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10003),
  [15180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3829),
  [15182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14934),
  [15184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [15186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 3, .production_id = 73),
  [15188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16610),
  [15190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [15192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [15194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7148),
  [15196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 3, .production_id = 84),
  [15198] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 3, .production_id = 84), SHIFT(14850),
  [15201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3808),
  [15203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15074),
  [15205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18181),
  [15207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator, 3),
  [15209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2160),
  [15211] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1743),
  [15214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 3, .production_id = 21),
  [15216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 3, .production_id = 55),
  [15218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1579),
  [15220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12327),
  [15222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [15224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [15226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8745),
  [15228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16526),
  [15230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16627),
  [15232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13441),
  [15234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16547),
  [15236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [15238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [15240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_constructor, 1, .production_id = 2),
  [15242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3618),
  [15244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3628),
  [15246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17951),
  [15248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [15250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [15252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6281),
  [15254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16591),
  [15256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [15258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [15260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8877),
  [15262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16557),
  [15264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16554),
  [15266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [15268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1440),
  [15270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator, 4),
  [15272] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9528),
  [15275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_constructor, 4, .production_id = 96),
  [15277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16546),
  [15279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1525),
  [15281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9080),
  [15283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [15285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16506),
  [15287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16565),
  [15289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [15291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14545),
  [15293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17859),
  [15295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16538),
  [15297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14940),
  [15299] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1837),
  [15302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4297),
  [15304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8175),
  [15306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16530),
  [15308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16520),
  [15310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9595),
  [15312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16536),
  [15314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1483),
  [15316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10176),
  [15318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16523),
  [15320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16495),
  [15322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1253),
  [15324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16515),
  [15326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16508),
  [15328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1798),
  [15331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11020),
  [15333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16504),
  [15335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16479),
  [15337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3771),
  [15339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3770),
  [15341] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 5, .production_id = 143), SHIFT(15825),
  [15344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12156),
  [15346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16499),
  [15348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16480),
  [15350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9257),
  [15352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16493),
  [15354] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1830),
  [15357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9864),
  [15359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16486),
  [15361] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_constructor_repeat1, 2), SHIFT_REPEAT(10514),
  [15364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_constructor_repeat1, 2), SHIFT_REPEAT(15871),
  [15367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5628),
  [15369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16473),
  [15371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13709),
  [15373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13711),
  [15375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16476),
  [15377] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 4, .production_id = 116), SHIFT(15825),
  [15380] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 4, .production_id = 115), SHIFT(15825),
  [15383] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 4, .production_id = 21), SHIFT(15825),
  [15386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__class_constructor_repeat1, 2), SHIFT_REPEAT(4327),
  [15389] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__class_constructor_repeat1, 2), SHIFT_REPEAT(15825),
  [15392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16448),
  [15394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16471),
  [15396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4301),
  [15398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12170),
  [15400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12541),
  [15402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16468),
  [15404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16438),
  [15406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6878),
  [15408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12116),
  [15410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16455),
  [15412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16457),
  [15414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7649),
  [15416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16445),
  [15418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13606),
  [15420] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9523),
  [15423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16425),
  [15425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1824),
  [15428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_applications, 2, .production_id = 117),
  [15430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16403),
  [15432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7053),
  [15434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9810),
  [15436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4285),
  [15438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16434),
  [15440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16420),
  [15442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9792),
  [15444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16383),
  [15446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, .production_id = 117),
  [15448] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, .production_id = 117), SHIFT_REPEAT(4487),
  [15451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, .production_id = 117),
  [15453] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, .production_id = 117), SHIFT_REPEAT(4486),
  [15456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16389),
  [15458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16410),
  [15460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16430),
  [15462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9216),
  [15464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16399),
  [15466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16443),
  [15468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13202),
  [15470] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, .production_id = 66), SHIFT(15825),
  [15473] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, .production_id = 2), SHIFT(15825),
  [15476] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 3, .production_id = 65), SHIFT(15825),
  [15479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16401),
  [15481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16390),
  [15483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9498),
  [15485] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_constructor, 2, .production_id = 22), SHIFT(15825),
  [15488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16416),
  [15490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameters, 2),
  [15492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109),
  [15494] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), REDUCE(sym_if_expression, 4, .production_id = 109),
  [15497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17836),
  [15500] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1507),
  [15503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14047),
  [15505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3712),
  [15507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3693),
  [15509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15153),
  [15511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12411),
  [15513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3230),
  [15515] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class_parameters, 2), REDUCE(sym_class_parameters, 3),
  [15518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameters, 3),
  [15520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [15522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [15524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 3, .production_id = 94),
  [15526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [15528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [15530] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1718),
  [15533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 2, .production_id = 54),
  [15535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14931),
  [15537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15156),
  [15539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12175),
  [15541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13769),
  [15543] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1846),
  [15546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [15548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [15550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9941),
  [15552] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class_parameters, 3), REDUCE(sym_class_parameters, 4),
  [15555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameters, 4),
  [15557] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17656),
  [15560] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1370),
  [15563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46),
  [15565] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17651),
  [15568] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1346),
  [15571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [15573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [15575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [15577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [15579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3279),
  [15581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [15583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [15585] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class_parameters, 4), REDUCE(sym_class_parameters, 5),
  [15588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameters, 5),
  [15590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14525),
  [15592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9913),
  [15594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13882),
  [15596] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class_parameters, 5), REDUCE(sym_class_parameters, 6),
  [15599] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, .production_id = 14),
  [15601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameters, 6),
  [15603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, .production_id = 14),
  [15605] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_class_parameters, 6), REDUCE(sym_class_parameters, 7),
  [15608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameters, 7),
  [15610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9784),
  [15612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15008),
  [15614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [15616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [15618] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, .production_id = 117), SHIFT_REPEAT(4456),
  [15621] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, .production_id = 117), SHIFT_REPEAT(4452),
  [15624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [15626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [15628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1453),
  [15630] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(16986),
  [15633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1312),
  [15635] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(16964),
  [15638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [15640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [15642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13724),
  [15644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__class_constructor_repeat1, 1),
  [15646] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 2, .production_id = 45), SHIFT(14657),
  [15649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [15651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extends_clause, 2, .production_id = 68),
  [15653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3237),
  [15655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3899),
  [15657] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__class_definition, 3, .production_id = 84), SHIFT(14657),
  [15660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1260),
  [15662] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17304),
  [15665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1632),
  [15667] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17311),
  [15670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1640),
  [15672] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17831),
  [15675] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1523),
  [15678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3560),
  [15680] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17612),
  [15683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [15685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3223),
  [15687] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17124),
  [15690] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1421),
  [15693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator, 1),
  [15695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [15697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1160),
  [15699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14112),
  [15701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [15703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [15705] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17881),
  [15708] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1443),
  [15711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [15713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [15715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15037),
  [15717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3331),
  [15719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_constructor, 2, .production_id = 21),
  [15721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_package_identifier_repeat1, 2),
  [15723] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17731),
  [15726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1538),
  [15728] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17622),
  [15731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1495),
  [15733] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17850),
  [15736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1479),
  [15738] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17893),
  [15741] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1429),
  [15744] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17867),
  [15747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1465),
  [15749] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17923),
  [15752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1373),
  [15755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_derives_clause, 2, .production_id = 48),
  [15757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11735),
  [15759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12577),
  [15761] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(16785),
  [15764] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1134),
  [15767] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17926),
  [15770] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1365),
  [15773] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7701),
  [15776] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7688),
  [15779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [15781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [15783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [15785] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17165),
  [15788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [15790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14930),
  [15792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17564),
  [15794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1406),
  [15796] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17117),
  [15799] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1411),
  [15802] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17693),
  [15805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [15807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_derives_clause, 3, .production_id = 118),
  [15809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_constructor_repeat1, 1),
  [15811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17559),
  [15813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [15815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enumerator_repeat1, 2),
  [15817] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumerator_repeat1, 2), SHIFT_REPEAT(2160),
  [15820] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1814),
  [15823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [15825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1653),
  [15827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [15829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [15831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1148),
  [15833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [15835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1700),
  [15837] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17257),
  [15840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [15842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3245),
  [15844] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17278),
  [15847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1592),
  [15849] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(16885),
  [15852] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1090),
  [15855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14953),
  [15857] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(16880),
  [15860] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1095),
  [15863] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17177),
  [15866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [15868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [15870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9933),
  [15872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9850),
  [15874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [15876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14109),
  [15878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [15880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [15882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [15884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_derives_clause_repeat1, 2, .production_id = 146),
  [15886] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_derives_clause_repeat1, 2, .production_id = 146), SHIFT_REPEAT(11735),
  [15889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14265),
  [15891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [15893] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9471),
  [15896] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17790),
  [15899] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1594),
  [15902] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17778),
  [15905] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1602),
  [15908] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(16796),
  [15911] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1130),
  [15914] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17909),
  [15917] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1410),
  [15920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3646),
  [15922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 5, .production_id = 164),
  [15924] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17400),
  [15927] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1587),
  [15930] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17809),
  [15933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [15935] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17803),
  [15938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [15940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4493),
  [15942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4495),
  [15944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3195),
  [15946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2429),
  [15948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_guard, 2, .production_id = 49),
  [15950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4416),
  [15952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__full_enum_def, 1, .production_id = 145),
  [15954] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__full_enum_def, 1, .production_id = 145), SHIFT(17694),
  [15957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__full_enum_def, 2, .production_id = 161),
  [15959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4369),
  [15961] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__full_enum_def, 2, .production_id = 161), SHIFT(17885),
  [15964] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17179),
  [15967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [15969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17912),
  [15972] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1401),
  [15975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_derives_clause_repeat1, 2, .production_id = 48),
  [15977] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17407),
  [15980] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1564),
  [15983] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(16833),
  [15986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [15988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3673),
  [15990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14941),
  [15992] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__block, 1),
  [15994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [15996] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(16839),
  [15999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [16001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [16003] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 3, .production_id = 95),
  [16005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14582),
  [16007] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17351),
  [16010] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1670),
  [16013] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_definition_repeat1, 2), SHIFT_REPEAT(9485),
  [16016] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_derives_clause_repeat1, 2, .production_id = 146), SHIFT_REPEAT(11891),
  [16019] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17030),
  [16022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [16024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 4, .production_id = 148),
  [16026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 4, .production_id = 129),
  [16028] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotation_repeat1, 2), SHIFT_REPEAT(1763),
  [16031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_expression, 2, .production_id = 32),
  [16033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10685),
  [16035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11891),
  [16037] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17361),
  [16040] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1683),
  [16043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_clause, 2, .production_id = 3),
  [16045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_expression, 1, .production_id = 5),
  [16047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10815),
  [16049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3379),
  [16051] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17749),
  [16054] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1652),
  [16057] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__full_enum_def, 2, .production_id = 161), SHIFT(17694),
  [16060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4516),
  [16062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17459),
  [16065] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1287),
  [16068] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17761),
  [16071] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1648),
  [16074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(16928),
  [16077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [16079] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__full_enum_def, 1, .production_id = 145), SHIFT(17885),
  [16082] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17118),
  [16085] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(975),
  [16088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extends_clause, 3, .production_id = 68),
  [16090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14333),
  [16092] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(16921),
  [16095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [16097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14988),
  [16099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16745),
  [16101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [16103] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17168),
  [16106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1463),
  [16108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12498),
  [16110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16750),
  [16112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [16114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14237),
  [16116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17445),
  [16119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1348),
  [16122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4465),
  [16124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4463),
  [16126] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17123),
  [16129] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(966),
  [16132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [16134] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17701),
  [16137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [16139] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17710),
  [16142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1681),
  [16144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4515),
  [16146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17609),
  [16149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1211),
  [16152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17599),
  [16155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1125),
  [16158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14577),
  [16160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14578),
  [16162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12157),
  [16164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_package_identifier_repeat1, 2), SHIFT_REPEAT(13261),
  [16167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17019),
  [16170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [16172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10793),
  [16174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_import_declaration_repeat1, 2, .production_id = 75),
  [16176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_import_declaration_repeat1, 2, .production_id = 75), SHIFT_REPEAT(12609),
  [16179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [16181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 1, .production_id = 1),
  [16183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [16185] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_package_identifier_repeat1, 2), SHIFT_REPEAT(13021),
  [16188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_constructor, 2, .production_id = 54),
  [16190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2),
  [16192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_block, 1),
  [16194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [16196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17405),
  [16198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [16200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17410),
  [16202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [16204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17984),
  [16206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [16208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4432),
  [16210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11879),
  [16212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [16214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [16216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3213),
  [16218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declaration, 5, .production_id = 133),
  [16220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_package_identifier_repeat1, 2), SHIFT_REPEAT(13201),
  [16223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(16721),
  [16226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [16228] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(16712),
  [16231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [16233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3803),
  [16235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declaration, 4, .production_id = 114),
  [16237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18474),
  [16239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [16241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, .production_id = 117), SHIFT_REPEAT(4495),
  [16244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3483),
  [16246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17271),
  [16249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(909),
  [16252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17266),
  [16255] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(892),
  [16258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__full_enum_def_repeat1, 2),
  [16260] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__full_enum_def_repeat1, 2), SHIFT_REPEAT(4337),
  [16263] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__full_enum_def_repeat1, 2), SHIFT_REPEAT(17694),
  [16266] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17010),
  [16269] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1332),
  [16272] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(16972),
  [16275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [16277] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7998),
  [16280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(16877),
  [16283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [16285] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17226),
  [16288] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1543),
  [16291] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(16775),
  [16294] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1220),
  [16297] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17547),
  [16300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(913),
  [16303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declaration, 6, .production_id = 158),
  [16305] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17565),
  [16308] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(945),
  [16311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__full_enum_def_repeat1, 2), SHIFT_REPEAT(4332),
  [16314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__full_enum_def_repeat1, 2), SHIFT_REPEAT(17885),
  [16317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(16982),
  [16320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [16322] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(16694),
  [16325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1195),
  [16328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3751),
  [16330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declaration, 3, .production_id = 59),
  [16332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(16873),
  [16335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [16337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [16339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [16341] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(16780),
  [16344] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1224),
  [16347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17362),
  [16349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [16351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17367),
  [16353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [16355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [16357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3766),
  [16359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declaration, 2, .production_id = 16),
  [16361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [16363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [16365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(16690),
  [16368] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1198),
  [16371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [16373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [16375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_constructor, 3, .production_id = 94),
  [16377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10709),
  [16379] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17219),
  [16382] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1526),
  [16385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 3, .production_id = 33),
  [16387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12609),
  [16389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 3, .production_id = 33),
  [16391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_identifier, 1),
  [16393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13021),
  [16395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [16397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1155),
  [16399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_identifier, 2),
  [16401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 2, .production_id = 6),
  [16403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 2, .production_id = 6),
  [16405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [16407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [16409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17224),
  [16412] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(877),
  [16415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17323),
  [16418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [16420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17832),
  [16422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1459),
  [16424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [16426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3630),
  [16428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3702),
  [16430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lower_bound, 2, .production_id = 48),
  [16432] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, .production_id = 117), SHIFT_REPEAT(4516),
  [16435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [16437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declaration, 4, .production_id = 97),
  [16439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12342),
  [16441] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17312),
  [16444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [16446] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17141),
  [16449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(881),
  [16452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17037),
  [16455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1339),
  [16458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enumerator_repeat1, 1),
  [16460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3723),
  [16462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17814),
  [16464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [16466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2102),
  [16468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7205),
  [16470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17059),
  [16472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [16474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17075),
  [16476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [16478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6175),
  [16480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5188),
  [16482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4206),
  [16484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12744),
  [16486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9800),
  [16488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5504),
  [16490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17716),
  [16493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1698),
  [16496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8642),
  [16498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, .production_id = 117), SHIFT_REPEAT(4515),
  [16501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_constructor, 3, .production_id = 95),
  [16503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [16505] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17727),
  [16508] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1690),
  [16511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1675),
  [16513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upper_bound, 2, .production_id = 48),
  [16515] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17458),
  [16518] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1221),
  [16521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9249),
  [16523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12346),
  [16525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15137),
  [16527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12341),
  [16529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15139),
  [16531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [16533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16633),
  [16535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16632),
  [16537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12338),
  [16539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15140),
  [16541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17513),
  [16544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(980),
  [16547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enumerators_repeat1, 2),
  [16549] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17500),
  [16552] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1052),
  [16555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_selectors, 5),
  [16557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [16559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16607),
  [16561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16606),
  [16563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17897),
  [16566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [16568] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17448),
  [16571] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1201),
  [16574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3659),
  [16576] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(18289),
  [16579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [16581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3291),
  [16583] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, .production_id = 117), SHIFT_REPEAT(4493),
  [16586] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(18154),
  [16589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [16591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9439),
  [16593] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17506),
  [16596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [16598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_selectors, 4),
  [16600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4224),
  [16602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6159),
  [16604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6622),
  [16606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7999),
  [16608] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumerator_repeat1, 2), SHIFT_REPEAT(2176),
  [16611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8197),
  [16613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7074),
  [16615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7105),
  [16617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16828),
  [16619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1230),
  [16621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16747),
  [16623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [16625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5734),
  [16627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1616),
  [16629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__top_level_definition, 1),
  [16631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8724),
  [16633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator, 5),
  [16635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7541),
  [16637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12128),
  [16639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15078),
  [16641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_expression, 4, .production_id = 32),
  [16643] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_import_declaration_repeat1, 2, .production_id = 75), SHIFT_REPEAT(12744),
  [16646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7439),
  [16648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_as_renamed_identifier, 3, .production_id = 147),
  [16650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_selectors, 3),
  [16652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_parameter_repeat1, 2),
  [16654] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_parameter_repeat1, 2), SHIFT_REPEAT(3339),
  [16657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3970),
  [16659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__enum_block_repeat1, 2),
  [16661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9641),
  [16663] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat2, 2, .production_id = 117), SHIFT_REPEAT(4463),
  [16666] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__constructor_applications_repeat1, 2, .production_id = 117), SHIFT_REPEAT(4465),
  [16669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3699),
  [16671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8369),
  [16673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10987),
  [16675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2033),
  [16677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__exprs_in_parens, 1),
  [16679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9000),
  [16681] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17511),
  [16684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1316),
  [16686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8855),
  [16688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6421),
  [16690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_constructor, 4, .production_id = 129),
  [16692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_import_declaration_repeat1, 2, .production_id = 6),
  [16694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12430),
  [16696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14900),
  [16698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_expression, 3, .production_id = 5),
  [16700] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17919),
  [16703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [16705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12415),
  [16707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14913),
  [16709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5654),
  [16711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 5, .production_id = 136),
  [16713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2511),
  [16715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6945),
  [16717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 4, .production_id = 125),
  [16719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2606),
  [16721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7493),
  [16723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12641),
  [16725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_case_definitions, 2),
  [16727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 4, .production_id = 70),
  [16729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__definition_body, 2, .production_id = 13),
  [16731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 3, .production_id = 72),
  [16733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2565),
  [16735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9396),
  [16737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 3, .production_id = 74),
  [16739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 4, .production_id = 69),
  [16741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_definition, 2, .production_id = 10),
  [16743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2637),
  [16745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4709),
  [16747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2524),
  [16749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6323),
  [16751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 2, .production_id = 9),
  [16753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2509),
  [16755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5947),
  [16757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 4, .production_id = 108),
  [16759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3527),
  [16761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2556),
  [16763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5348),
  [16765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 2),
  [16767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2537),
  [16769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6302),
  [16771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 2, .production_id = 10),
  [16773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2622),
  [16775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5787),
  [16777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_val_declaration, 5, .production_id = 130),
  [16779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2576),
  [16781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6691),
  [16783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2501),
  [16785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7552),
  [16787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2608),
  [16789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8874),
  [16791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_declaration, 5, .production_id = 130),
  [16793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 5, .production_id = 131),
  [16795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 5, .production_id = 132),
  [16797] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2), SHIFT_REPEAT(562),
  [16800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2599),
  [16802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6720),
  [16804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 5, .production_id = 135),
  [16806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2559),
  [16808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7729),
  [16810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2557),
  [16812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6928),
  [16814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 3, .production_id = 26),
  [16816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_definition, 5, .production_id = 137),
  [16818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 5, .production_id = 138),
  [16820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 5, .production_id = 139),
  [16822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2610),
  [16824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8905),
  [16826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4171),
  [16828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerators, 1),
  [16830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4106),
  [16832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2602),
  [16834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7667),
  [16836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2597),
  [16838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8671),
  [16840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 5, .production_id = 140),
  [16842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3825),
  [16844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 3, .production_id = 141),
  [16846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_definition, 2, .production_id = 4),
  [16848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17665),
  [16850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [16852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 4),
  [16854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17659),
  [16856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [16858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2589),
  [16860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5195),
  [16862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [16864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__full_enum_def_repeat1, 1),
  [16866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2598),
  [16868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8573),
  [16870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_case_definitions, 3),
  [16872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12906),
  [16874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2562),
  [16876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8343),
  [16878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2635),
  [16880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7949),
  [16882] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension_definition, 2, .production_id = 13),
  [16884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3320),
  [16886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3798),
  [16888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2525),
  [16890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8108),
  [16892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_definition, 3, .production_id = 26),
  [16894] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_parameter_repeat2, 2), SHIFT_REPEAT(3349),
  [16897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_parameter_repeat2, 2),
  [16899] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 3, .production_id = 58),
  [16901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_case_definitions, 4),
  [16903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2581),
  [16905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7004),
  [16907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, .production_id = 56),
  [16909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2629),
  [16911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5366),
  [16913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2518),
  [16915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8021),
  [16917] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(17076),
  [16920] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1003),
  [16923] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2), SHIFT_REPEAT(561),
  [16926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2636),
  [16928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5830),
  [16930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2500),
  [16932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9069),
  [16934] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(17069),
  [16937] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1011),
  [16940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2544),
  [16942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5176),
  [16944] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumerators_repeat1, 2), SHIFT_REPEAT(4175),
  [16947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2503),
  [16949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9379),
  [16951] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(16932),
  [16954] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 3, .production_id = 46), SHIFT(1062),
  [16957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14555),
  [16959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10365),
  [16961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12074),
  [16963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12395),
  [16965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 3, .production_id = 57),
  [16967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3746),
  [16969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(16926),
  [16972] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_expression, 4, .production_id = 109), SHIFT(1068),
  [16975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17753),
  [16977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [16979] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_case_definitions_repeat1, 2), SHIFT_REPEAT(12641),
  [16982] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_case_definitions_repeat1, 2),
  [16984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_template_body, 3),
  [16986] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 4, .production_id = 120),
  [16988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2617),
  [16990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5756),
  [16992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2550),
  [16994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6737),
  [16996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__structural_instance, 3, .production_id = 78),
  [16998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2593),
  [17000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7650),
  [17002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 4, .production_id = 79),
  [17004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 5, .production_id = 124),
  [17006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2545),
  [17008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9946),
  [17010] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_val_definition, 4, .production_id = 103),
  [17012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 5, .production_id = 119),
  [17014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2618),
  [17016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8925),
  [17018] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compound_type_repeat1, 2, .production_id = 81), SHIFT_REPEAT(7655),
  [17021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension_definition, 3, .production_id = 52),
  [17023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3949),
  [17025] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension_definition, 3, .production_id = 51),
  [17027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_val_definition, 6, .production_id = 152),
  [17029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 2, .production_id = 17),
  [17031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_definition, 6, .production_id = 152),
  [17033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 3, .production_id = 83),
  [17035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17766),
  [17037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [17039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__extension_template_body, 2),
  [17041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [17043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 6, .production_id = 154),
  [17045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 3, .production_id = 85),
  [17047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 6, .production_id = 156),
  [17049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4102),
  [17051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 6, .production_id = 157),
  [17053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2549),
  [17055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6505),
  [17057] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 4, .production_id = 159),
  [17059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2578),
  [17061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6850),
  [17063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2521),
  [17065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9717),
  [17067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4175),
  [17069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4136),
  [17071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2532),
  [17073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7441),
  [17075] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_case_definitions_repeat1, 2), SHIFT_REPEAT(12906),
  [17078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2457),
  [17080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 3),
  [17082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2575),
  [17084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7583),
  [17086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2591),
  [17088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4916),
  [17090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2523),
  [17092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8928),
  [17094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2502),
  [17096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7843),
  [17098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2624),
  [17100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8781),
  [17102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2541),
  [17104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9733),
  [17106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 5, .production_id = 165),
  [17108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 5, .production_id = 166),
  [17110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 6, .production_id = 177),
  [17112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_definition, 2, .production_id = 43),
  [17114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_definition, 4, .production_id = 106),
  [17116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_template_body, 4),
  [17118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 7, .production_id = 170),
  [17120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 7, .production_id = 171),
  [17122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 4, .production_id = 113),
  [17124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 5, .production_id = 166),
  [17126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2579),
  [17128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8570),
  [17130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 6, .production_id = 153),
  [17132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2510),
  [17134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5040),
  [17136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2514),
  [17138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7312),
  [17140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2512),
  [17142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6784),
  [17144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 4, .production_id = 112),
  [17146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 2, .production_id = 15),
  [17148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3615),
  [17150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2633),
  [17152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6805),
  [17154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 3, .production_id = 36),
  [17156] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumerators_repeat1, 2), SHIFT_REPEAT(4171),
  [17159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_parameter, 6, .production_id = 176),
  [17161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 6, .production_id = 177),
  [17163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_definition, 3, .production_id = 23),
  [17165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2607),
  [17167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7139),
  [17169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [17171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9026),
  [17173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__extension_template_body, 3),
  [17175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 6, .production_id = 180),
  [17177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2623),
  [17179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5968),
  [17181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2530),
  [17183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6229),
  [17185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2570),
  [17187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9713),
  [17189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extension_definition, 4, .production_id = 92),
  [17191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 4, .production_id = 93),
  [17193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2517),
  [17195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4860),
  [17197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 7, .production_id = 182),
  [17199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_definition, 3, .production_id = 25),
  [17201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 7, .production_id = 182),
  [17203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 8, .production_id = 183),
  [17205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2583),
  [17207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9401),
  [17209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4048),
  [17211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2555),
  [17213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9195),
  [17215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2567),
  [17217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7840),
  [17219] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 5, .production_id = 172),
  [17221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2569),
  [17223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8058),
  [17225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2),
  [17227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2580),
  [17229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10341),
  [17231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2630),
  [17233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5451),
  [17235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14701),
  [17237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10659),
  [17239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_given_definition, 4, .production_id = 107),
  [17241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2594),
  [17243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6001),
  [17245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2548),
  [17247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7686),
  [17249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 4, .production_id = 106),
  [17251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3429),
  [17253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2613),
  [17255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6881),
  [17257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_definition, 4, .production_id = 105),
  [17259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__definition_body, 1, .production_id = 29),
  [17261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__object_definition, 2, .production_id = 28),
  [17263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_definition, 4, .production_id = 103),
  [17265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14884),
  [17267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16302),
  [17269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14888),
  [17271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16140),
  [17273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9981),
  [17275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4254),
  [17277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4271),
  [17279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7577),
  [17281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16502),
  [17283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6934),
  [17285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8436),
  [17287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10755),
  [17289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5757),
  [17291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11758),
  [17293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10999),
  [17295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12350),
  [17297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16492),
  [17299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10159),
  [17301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16585),
  [17303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_indented_cases_repeat1, 2),
  [17305] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_indented_cases_repeat1, 2), SHIFT_REPEAT(4254),
  [17308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14945),
  [17310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15906),
  [17312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13692),
  [17314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9313),
  [17316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12717),
  [17318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [17320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [17322] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_indented_cases_repeat1, 2), SHIFT_REPEAT(4271),
  [17325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12355),
  [17327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10908),
  [17329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 6, .production_id = 179),
  [17331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2312),
  [17333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9214),
  [17335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12339),
  [17337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13915),
  [17339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11958),
  [17341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8915),
  [17343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14107),
  [17345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6627),
  [17347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 5, .production_id = 167),
  [17349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2299),
  [17351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13598),
  [17353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14905),
  [17355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16380),
  [17357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16478),
  [17359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12335),
  [17361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14375),
  [17363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14914),
  [17365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16089),
  [17367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 5, .production_id = 167),
  [17369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2295),
  [17371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9741),
  [17373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9732),
  [17375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [17377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5641),
  [17379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4174),
  [17381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4164),
  [17383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15152),
  [17385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9093),
  [17387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10210),
  [17389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9931),
  [17391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7449),
  [17393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16519),
  [17395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_namespace_selectors_repeat1, 2),
  [17397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14962),
  [17399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16234),
  [17401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14965),
  [17403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16177),
  [17405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13731),
  [17407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9041),
  [17409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15011),
  [17411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15304),
  [17413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7720),
  [17415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6202),
  [17417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2644),
  [17419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 4, .production_id = 160),
  [17421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2271),
  [17423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10680),
  [17425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12274),
  [17427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9394),
  [17429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 4, .production_id = 102),
  [17431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2259),
  [17433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8307),
  [17435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5591),
  [17437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_identifiers_repeat1, 2),
  [17439] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_identifiers_repeat1, 2), SHIFT_REPEAT(13519),
  [17442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16452),
  [17444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16472),
  [17446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6530),
  [17448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5653),
  [17450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14173),
  [17452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10280),
  [17454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2540),
  [17456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14261),
  [17458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13750),
  [17460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6462),
  [17462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8480),
  [17464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerators, 5),
  [17466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11703),
  [17468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16665),
  [17470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8522),
  [17472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, .production_id = 102),
  [17474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2241),
  [17476] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2), SHIFT_REPEAT(563),
  [17479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16456),
  [17481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13492),
  [17483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13390),
  [17485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2),
  [17487] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2), SHIFT_REPEAT(215),
  [17490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15085),
  [17492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15852),
  [17494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10769),
  [17496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10567),
  [17498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8252),
  [17500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10997),
  [17502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5790),
  [17504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3841),
  [17506] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_derives_clause_repeat1, 2, .production_id = 146), SHIFT_REPEAT(11925),
  [17509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7243),
  [17511] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__indented_type_cases_repeat1, 2), SHIFT_REPEAT(5757),
  [17514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__indented_type_cases_repeat1, 2),
  [17516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3891),
  [17518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6868),
  [17520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14187),
  [17522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15032),
  [17524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16212),
  [17526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15021),
  [17528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16129),
  [17530] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__enum_block_repeat1, 2), SHIFT_REPEAT(570),
  [17533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13128),
  [17535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10507),
  [17537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11935),
  [17539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10989),
  [17541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7062),
  [17543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15007),
  [17545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16347),
  [17547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8383),
  [17549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16447),
  [17551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16542),
  [17553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12359),
  [17555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9786),
  [17557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_enum_case, 2, .production_id = 30),
  [17559] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumerators_repeat1, 2), SHIFT_REPEAT(4174),
  [17562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2642),
  [17564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 3, .production_id = 142),
  [17566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [17568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 3, .production_id = 99),
  [17570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2204),
  [17572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13810),
  [17574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6585),
  [17576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [17578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3442),
  [17580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7665),
  [17582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11159),
  [17584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2648),
  [17586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 1, .production_id = 2),
  [17588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2408),
  [17590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifiers, 4),
  [17592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13519),
  [17594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5823),
  [17596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9653),
  [17598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16436),
  [17600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12657),
  [17602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11925),
  [17604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5312),
  [17606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7048),
  [17608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11197),
  [17610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [17612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11625),
  [17614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13205),
  [17616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerators, 4),
  [17618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8926),
  [17620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8763),
  [17622] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2), SHIFT_REPEAT(566),
  [17625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13647),
  [17627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15099),
  [17629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16030),
  [17631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16424),
  [17633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16422),
  [17635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8957),
  [17637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12052),
  [17639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13965),
  [17641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15081),
  [17643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16028),
  [17645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14387),
  [17647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12330),
  [17649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_type_repeat1, 2), SHIFT_REPEAT(3487),
  [17652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_type_repeat1, 2),
  [17654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 3, .production_id = 99),
  [17656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2154),
  [17658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13126),
  [17660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2646),
  [17662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_parameter, 2, .production_id = 3),
  [17664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2101),
  [17666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13439),
  [17668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12186),
  [17670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15093),
  [17672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16314),
  [17674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7270),
  [17676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_parameter_repeat1, 1),
  [17678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7168),
  [17680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17885),
  [17682] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_val_declaration_repeat1, 2, .production_id = 3), REDUCE(sym_identifiers, 3),
  [17685] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_val_declaration_repeat1, 2, .production_id = 3), SHIFT(13519),
  [17688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifiers, 3),
  [17690] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__enum_block_repeat1, 2), SHIFT_REPEAT(569),
  [17693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15146),
  [17695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16247),
  [17697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2508),
  [17699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13996),
  [17701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16412),
  [17703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_view_bound, 2, .production_id = 48),
  [17705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11593),
  [17707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2515),
  [17709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10915),
  [17711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11349),
  [17713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6658),
  [17715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11656),
  [17717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10901),
  [17719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11753),
  [17721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5469),
  [17723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12129),
  [17725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12124),
  [17727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12123),
  [17729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12819),
  [17731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11897),
  [17733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6408),
  [17735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [17737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16400),
  [17739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4161),
  [17741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15170),
  [17743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15926),
  [17745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [17747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8857),
  [17749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10814),
  [17751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9638),
  [17753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13813),
  [17755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18007),
  [17757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13155),
  [17759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13477),
  [17761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5555),
  [17763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16561),
  [17765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11051),
  [17767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14009),
  [17769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7880),
  [17771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12085),
  [17773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16391),
  [17775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10629),
  [17777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11109),
  [17779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17694),
  [17781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12320),
  [17783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7785),
  [17785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12861),
  [17787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15181),
  [17789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16281),
  [17791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8725),
  [17793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10475),
  [17795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16396),
  [17797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3713),
  [17799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6701),
  [17801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9163),
  [17803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9540),
  [17805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11206),
  [17807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3057),
  [17809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15310),
  [17811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9952),
  [17813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16685),
  [17815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15194),
  [17817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18535),
  [17819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2657),
  [17821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2773),
  [17823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3217),
  [17825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2663),
  [17827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12810),
  [17829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2659),
  [17831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7754),
  [17833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2726),
  [17835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8609),
  [17837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18536),
  [17839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2745),
  [17841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2674),
  [17843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9842),
  [17845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2778),
  [17847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2677),
  [17849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6778),
  [17851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2680),
  [17853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13148),
  [17855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15212),
  [17857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18534),
  [17859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18529),
  [17861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6608),
  [17863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2662),
  [17865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11991),
  [17867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2693),
  [17869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2671),
  [17871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6707),
  [17873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2694),
  [17875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15316),
  [17877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11627),
  [17879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16666),
  [17881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2725),
  [17883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2682),
  [17885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2683),
  [17887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2717),
  [17889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13415),
  [17891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15044),
  [17893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2699),
  [17895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8835),
  [17897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2728),
  [17899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6546),
  [17901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10517),
  [17903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2714),
  [17905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6645),
  [17907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2732),
  [17909] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_comment_repeat1, 2), SHIFT_REPEAT(16685),
  [17912] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_comment_repeat1, 2),
  [17914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2736),
  [17916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4335),
  [17918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18355),
  [17920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_object, 3, .production_id = 25),
  [17922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_clause, 3, .production_id = 27),
  [17924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2723),
  [17926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2724),
  [17928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6581),
  [17930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7362),
  [17932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13071),
  [17934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2759),
  [17936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6334),
  [17938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2741),
  [17940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6548),
  [17942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2742),
  [17944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6535),
  [17946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2765),
  [17948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4580),
  [17950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2796),
  [17952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8776),
  [17954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11177),
  [17956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3103),
  [17958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14119),
  [17960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2767),
  [17962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3254),
  [17964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2774),
  [17966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2722),
  [17968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2734),
  [17970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8113),
  [17972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2756),
  [17974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2758),
  [17976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2059),
  [17978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10499),
  [17980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3193),
  [17982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11626),
  [17984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17626),
  [17986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2792),
  [17988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11634),
  [17990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2910),
  [17992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9969),
  [17994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2779),
  [17996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5055),
  [17998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2801),
  [18000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5263),
  [18002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11630),
  [18004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17624),
  [18006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11632),
  [18008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17615),
  [18010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2908),
  [18012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7938),
  [18014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2806),
  [18016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11648),
  [18018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16689),
  [18020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2821),
  [18022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11652),
  [18024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17604),
  [18026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11653),
  [18028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17602),
  [18030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2786),
  [18032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2843),
  [18034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2790),
  [18036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11654),
  [18038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17592),
  [18040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11655),
  [18042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17590),
  [18044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2833),
  [18046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7337),
  [18048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2811),
  [18050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13904),
  [18052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2825),
  [18054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5050),
  [18056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2836),
  [18058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5002),
  [18060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3597),
  [18062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11657),
  [18064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17580),
  [18066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3640),
  [18068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2839),
  [18070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11663),
  [18072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17578),
  [18074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2854),
  [18076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3665),
  [18078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11664),
  [18080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17568),
  [18082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3681),
  [18084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2830),
  [18086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2831),
  [18088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11665),
  [18090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17566),
  [18092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2793),
  [18094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10549),
  [18096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11670),
  [18098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17555),
  [18100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2871),
  [18102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8652),
  [18104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2840),
  [18106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6315),
  [18108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2855),
  [18110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5246),
  [18112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2876),
  [18114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7641),
  [18116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11676),
  [18118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17553),
  [18120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11677),
  [18122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17542),
  [18124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2879),
  [18126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11678),
  [18128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17540),
  [18130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2882),
  [18132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14477),
  [18134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11691),
  [18136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17529),
  [18138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10583),
  [18140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2857),
  [18142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2864),
  [18144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11692),
  [18146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17527),
  [18148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14490),
  [18150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11693),
  [18152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17516),
  [18154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2899),
  [18156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4685),
  [18158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2881),
  [18160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7108),
  [18162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2885),
  [18164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4613),
  [18166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2901),
  [18168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4950),
  [18170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11694),
  [18172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17514),
  [18174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8167),
  [18176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2903),
  [18178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11696),
  [18180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17503),
  [18182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2907),
  [18184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11697),
  [18186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17501),
  [18188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11701),
  [18190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17490),
  [18192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11529),
  [18194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17488),
  [18196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2886),
  [18198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2887),
  [18200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4377),
  [18202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11660),
  [18204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17477),
  [18206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11489),
  [18208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2920),
  [18210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5409),
  [18212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2933),
  [18214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7932),
  [18216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11633),
  [18218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17475),
  [18220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2922),
  [18222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6605),
  [18224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11628),
  [18226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17464),
  [18228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11621),
  [18230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17462),
  [18232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2924),
  [18234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11614),
  [18236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17451),
  [18238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3027),
  [18240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11610),
  [18242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17449),
  [18244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11608),
  [18246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17432),
  [18248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2917),
  [18250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2919),
  [18252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11607),
  [18254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17430),
  [18256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9868),
  [18258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11606),
  [18260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17413),
  [18262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2945),
  [18264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12948),
  [18266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2928),
  [18268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7964),
  [18270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3048),
  [18272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8816),
  [18274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2947),
  [18276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12963),
  [18278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11603),
  [18280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17411),
  [18282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11410),
  [18284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18211),
  [18286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2676),
  [18288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10088),
  [18290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2949),
  [18292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11600),
  [18294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17394),
  [18296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2958),
  [18298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3414),
  [18300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11597),
  [18302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17392),
  [18304] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_parameter_repeat2, 1),
  [18306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2941),
  [18308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2943),
  [18310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7133),
  [18312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13173),
  [18314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11592),
  [18316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17375),
  [18318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2977),
  [18320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5484),
  [18322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2953),
  [18324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6032),
  [18326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2959),
  [18328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6208),
  [18330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2980),
  [18332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6705),
  [18334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11591),
  [18336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17373),
  [18338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11179),
  [18340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2981),
  [18342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11589),
  [18344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17356),
  [18346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2985),
  [18348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11587),
  [18350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17354),
  [18352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2552),
  [18354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16636),
  [18356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2964),
  [18358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2973),
  [18360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11143),
  [18362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11586),
  [18364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17337),
  [18366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3007),
  [18368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7453),
  [18370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2982),
  [18372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9256),
  [18374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2990),
  [18376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6238),
  [18378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3012),
  [18380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5605),
  [18382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11583),
  [18384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17335),
  [18386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11581),
  [18388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17317),
  [18390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3018),
  [18392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2730),
  [18394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3031),
  [18396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11580),
  [18398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17315),
  [18400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2826),
  [18402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2672),
  [18404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6849),
  [18406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3004),
  [18408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3006),
  [18410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11573),
  [18412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17297),
  [18414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11408),
  [18416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17295),
  [18418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3041),
  [18420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5455),
  [18422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3023),
  [18424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6955),
  [18426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3034),
  [18428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6948),
  [18430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3043),
  [18432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6617),
  [18434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11303),
  [18436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11546),
  [18438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17276),
  [18440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11539),
  [18442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17274),
  [18444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3136),
  [18446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2828),
  [18448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3053),
  [18450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding, 3, .dynamic_precedence = 10, .production_id = 99),
  [18452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11501),
  [18454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17255),
  [18456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8945),
  [18458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3035),
  [18460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3039),
  [18462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11495),
  [18464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17253),
  [18466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2645),
  [18468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding, 1, .dynamic_precedence = 10, .production_id = 2),
  [18470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3068),
  [18472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7484),
  [18474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3050),
  [18476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8098),
  [18478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3150),
  [18480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8102),
  [18482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3079),
  [18484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7490),
  [18486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11494),
  [18488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17234),
  [18490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2639),
  [18492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding, 1, .dynamic_precedence = 10),
  [18494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11490),
  [18496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17232),
  [18498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3083),
  [18500] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_bindings_repeat1, 2), SHIFT_REPEAT(11997),
  [18503] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_bindings_repeat1, 2),
  [18505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3093),
  [18507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binding, 3, .dynamic_precedence = 10, .production_id = 100),
  [18509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11486),
  [18511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17213),
  [18513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3061),
  [18515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3063),
  [18517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11485),
  [18519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17211),
  [18521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2838),
  [18523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11814),
  [18525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_val_declaration_repeat1, 2, .production_id = 104),
  [18527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_val_declaration_repeat1, 2, .production_id = 104), SHIFT_REPEAT(13053),
  [18530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3107),
  [18532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6522),
  [18534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3087),
  [18536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12433),
  [18538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3097),
  [18540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8123),
  [18542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3111),
  [18544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6498),
  [18546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11476),
  [18548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17192),
  [18550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11474),
  [18552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17190),
  [18554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2804),
  [18556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3120),
  [18558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11460),
  [18560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17171),
  [18562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3125),
  [18564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11443),
  [18566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17169),
  [18568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2055),
  [18570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8194),
  [18572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3101),
  [18574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3102),
  [18576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11442),
  [18578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17150),
  [18580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11436),
  [18582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17148),
  [18584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3090),
  [18586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6780),
  [18588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3122),
  [18590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12323),
  [18592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3133),
  [18594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5600),
  [18596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3162),
  [18598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13160),
  [18600] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interpolated_string_repeat2, 2), SHIFT_REPEAT(15310),
  [18603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interpolated_string_repeat2, 2),
  [18605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2816),
  [18607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6828),
  [18609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3163),
  [18611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11435),
  [18613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17129),
  [18615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3180),
  [18617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11434),
  [18619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17127),
  [18621] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interpolated_string_repeat1, 2), SHIFT_REPEAT(15316),
  [18624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interpolated_string_repeat1, 2),
  [18626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3137),
  [18628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3141),
  [18630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11433),
  [18632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17108),
  [18634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11432),
  [18636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17106),
  [18638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3173),
  [18640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4747),
  [18642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3168),
  [18644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13298),
  [18646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3178),
  [18648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13660),
  [18650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3172),
  [18652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7520),
  [18654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4400),
  [18656] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2), SHIFT_REPEAT(2102),
  [18659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11428),
  [18661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17087),
  [18663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3169),
  [18665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4441),
  [18667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3161),
  [18669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11427),
  [18671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17085),
  [18673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11422),
  [18675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17066),
  [18677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3176),
  [18679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3175),
  [18681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11418),
  [18683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17064),
  [18685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3139),
  [18687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9744),
  [18689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3164),
  [18691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6755),
  [18693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3158),
  [18695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6752),
  [18697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3131),
  [18699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7470),
  [18701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11416),
  [18703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17045),
  [18705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2090),
  [18707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8932),
  [18709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11414),
  [18711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17043),
  [18713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3130),
  [18715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11413),
  [18717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17023),
  [18719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3123),
  [18721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11411),
  [18723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17021),
  [18725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11690),
  [18727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18127),
  [18729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11445),
  [18731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17001),
  [18733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3155),
  [18735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3149),
  [18737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_context_bound, 2, .production_id = 48),
  [18739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11458),
  [18741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16999),
  [18743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2670),
  [18745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3073),
  [18747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5398),
  [18749] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, .production_id = 122), SHIFT_REPEAT(8104),
  [18752] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, .production_id = 122),
  [18754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2655),
  [18756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13697),
  [18758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3072),
  [18760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11323),
  [18762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11463),
  [18764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16979),
  [18766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10922),
  [18768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11475),
  [18770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16977),
  [18772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3065),
  [18774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2621),
  [18776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3049),
  [18778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3259),
  [18780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11492),
  [18782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16957),
  [18784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10931),
  [18786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3085),
  [18788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2954),
  [18790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11497),
  [18792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16955),
  [18794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2615),
  [18796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3024),
  [18798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13232),
  [18800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3052),
  [18802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5579),
  [18804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3045),
  [18806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5586),
  [18808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3020),
  [18810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8413),
  [18812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11498),
  [18814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16935),
  [18816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2845),
  [18818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8976),
  [18820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11500),
  [18822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16933),
  [18824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2996),
  [18826] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2), SHIFT_REPEAT(11203),
  [18829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2),
  [18831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2976),
  [18833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11502),
  [18835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16913),
  [18837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3037),
  [18839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3025),
  [18841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11509),
  [18843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16911),
  [18845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11514),
  [18847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16891),
  [18849] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_class_pattern_repeat1, 2), SHIFT_REPEAT(4276),
  [18852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2890),
  [18854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5841),
  [18856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2994),
  [18858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5456),
  [18860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2975),
  [18862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12227),
  [18864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2952),
  [18866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11932),
  [18868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11520),
  [18870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16889),
  [18872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4256),
  [18874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8984),
  [18876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2951),
  [18878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11540),
  [18880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16867),
  [18882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2937),
  [18884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11542),
  [18886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16688),
  [18888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2969),
  [18890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2968),
  [18892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11551),
  [18894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16843),
  [18896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11558),
  [18898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16840),
  [18900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2893),
  [18902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7400),
  [18904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2948),
  [18906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4823),
  [18908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2926),
  [18910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5644),
  [18912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2884),
  [18914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13302),
  [18916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8388),
  [18918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11559),
  [18920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16818),
  [18922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2883),
  [18924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4360),
  [18926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2856),
  [18928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11562),
  [18930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16815),
  [18932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4392),
  [18934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2898),
  [18936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2896),
  [18938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11577),
  [18940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16793),
  [18942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11582),
  [18944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16790),
  [18946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2812),
  [18948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7616),
  [18950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2867),
  [18952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5435),
  [18954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2851),
  [18956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4829),
  [18958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2794),
  [18960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4983),
  [18962] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_parameters_repeat1, 2), SHIFT_REPEAT(4476),
  [18965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_parameters_repeat1, 2),
  [18967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11594),
  [18969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16766),
  [18971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2691),
  [18973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2785),
  [18975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_full_enum_case, 2, .production_id = 144),
  [18977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2686),
  [18979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11601),
  [18981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16763),
  [18983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2740),
  [18985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2813),
  [18987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11602),
  [18989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16736),
  [18991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11609),
  [18993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16733),
  [18995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2684),
  [18997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5008),
  [18999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2780),
  [19001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4841),
  [19003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2738),
  [19005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4842),
  [19007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2675),
  [19009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4648),
  [19011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10489),
  [19013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11615),
  [19015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16715),
  [19017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2665),
  [19019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2668),
  [19021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11620),
  [19023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16713),
  [19025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11635),
  [19027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16697),
  [19029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3109),
  [19031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4789),
  [19033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2702),
  [19035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2912),
  [19037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8748),
  [19039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11688),
  [19041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16695),
  [19043] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_lambda_repeat1, 2, .production_id = 122), SHIFT_REPEAT(12001),
  [19046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_lambda_repeat1, 2, .production_id = 122),
  [19048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11695),
  [19050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16754),
  [19052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2681),
  [19054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6009),
  [19056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2658),
  [19058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4770),
  [19060] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__using_parameters_clause_repeat1, 2), REDUCE(aux_sym_tuple_type_repeat1, 2),
  [19063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2711),
  [19065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5324),
  [19067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11415),
  [19069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16757),
  [19071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3799),
  [19073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2679),
  [19075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4852),
  [19077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2712),
  [19079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2715),
  [19081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11569),
  [19083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16800),
  [19085] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__using_parameters_clause_repeat1, 2), SHIFT_REPEAT(2643),
  [19088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__using_parameters_clause_repeat1, 2),
  [19090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11685),
  [19092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16803),
  [19094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2704),
  [19096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2706),
  [19098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11679),
  [19100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16846),
  [19102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2743),
  [19104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6065),
  [19106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2669),
  [19108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2749),
  [19110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6079),
  [19112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11671),
  [19114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16851),
  [19116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2716),
  [19118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10086),
  [19120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2757),
  [19122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2783),
  [19124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11579),
  [19126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16909),
  [19128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4406),
  [19130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2729),
  [19132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13228),
  [19134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11574),
  [19136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16916),
  [19138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__full_enum_def, 2, .production_id = 162),
  [19140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2776),
  [19142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2914),
  [19144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2799),
  [19146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6107),
  [19148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2803),
  [19150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5305),
  [19152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11570),
  [19154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16966),
  [19156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2918),
  [19158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2777),
  [19160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2807),
  [19162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11565),
  [19164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16969),
  [19166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2808),
  [19168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_namespace_selectors_repeat1, 2), SHIFT_REPEAT(10777),
  [19171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11553),
  [19173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17029),
  [19175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2784),
  [19177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11616),
  [19179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2797),
  [19181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8118),
  [19183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11545),
  [19185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17032),
  [19187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2847),
  [19189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12450),
  [19191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4442),
  [19193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__full_enum_def, 3, .production_id = 173),
  [19195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2848),
  [19197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11532),
  [19199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17084),
  [19201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7763),
  [19203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11407),
  [19205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17096),
  [19207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2827),
  [19209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2872),
  [19211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7305),
  [19213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3953),
  [19215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11423),
  [19217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17153),
  [19219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2829),
  [19221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2874),
  [19223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11451),
  [19225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17158),
  [19227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2925),
  [19229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5122),
  [19231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2062),
  [19233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7767),
  [19235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2849),
  [19237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8080),
  [19239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2877),
  [19241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13510),
  [19243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11484),
  [19245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17207),
  [19247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3930),
  [19249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11566),
  [19251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17216),
  [19253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2878),
  [19255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3898),
  [19257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2870),
  [19259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11992),
  [19261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11604),
  [19263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17263),
  [19265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2685),
  [19267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8362),
  [19269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2939),
  [19271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8337),
  [19273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11698),
  [19275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17268),
  [19277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8360),
  [19279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2927),
  [19281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11686),
  [19283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17324),
  [19285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2894),
  [19287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2895),
  [19289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3463),
  [19291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11683),
  [19293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17327),
  [19295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2934),
  [19297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5289),
  [19299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2697),
  [19301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2935),
  [19303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11682),
  [19305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17378),
  [19307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11680),
  [19309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17385),
  [19311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2942),
  [19313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11527),
  [19315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2929),
  [19317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8022),
  [19319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2970),
  [19321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7286),
  [19323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11639),
  [19325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17437),
  [19327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2978),
  [19329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11624),
  [19331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17440),
  [19333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2700),
  [19335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7741),
  [19337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2962),
  [19339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11595),
  [19341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17495),
  [19343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2988),
  [19345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13589),
  [19347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11541),
  [19349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17386),
  [19351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2963),
  [19353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2991),
  [19355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2731),
  [19357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5420),
  [19359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11585),
  [19361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17558),
  [19363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2979),
  [19365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7984),
  [19367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3026),
  [19369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3019),
  [19371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6164),
  [19373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11531),
  [19375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17563),
  [19377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3029),
  [19379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3022),
  [19381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11469),
  [19383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17629),
  [19385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2986),
  [19387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11320),
  [19389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9402),
  [19391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3047),
  [19393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7264),
  [19395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11464),
  [19397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17632),
  [19399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3108),
  [19401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3033),
  [19403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4990),
  [19405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2021),
  [19407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6135),
  [19409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3038),
  [19411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3077),
  [19413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4649),
  [19415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11618),
  [19417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17687),
  [19419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3042),
  [19421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3095),
  [19423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11617),
  [19425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17689),
  [19427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11505),
  [19429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17748),
  [19431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11504),
  [19433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17752),
  [19435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3100),
  [19437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9822),
  [19439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2737),
  [19441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6512),
  [19443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3067),
  [19445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7082),
  [19447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3106),
  [19449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3567),
  [19451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3044),
  [19453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8655),
  [19455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3112),
  [19457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5282),
  [19459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3075),
  [19461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7926),
  [19463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3127),
  [19465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2748),
  [19467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3129),
  [19469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6192),
  [19471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11700),
  [19473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17863),
  [19475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3174),
  [19477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11638),
  [19479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17869),
  [19481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3144),
  [19483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6022),
  [19485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3121),
  [19487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3148),
  [19489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3124),
  [19491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3152),
  [19493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12588),
  [19495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9431),
  [19497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3160),
  [19499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3166),
  [19501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7240),
  [19503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3140),
  [19505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7121),
  [19507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3170),
  [19509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2755),
  [19511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3171),
  [19513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13671),
  [19515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3147),
  [19517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7130),
  [19519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3117),
  [19521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3116),
  [19523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7689),
  [19525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15168),
  [19527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3113),
  [19529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3058),
  [19531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11555),
  [19533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3167),
  [19535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3098),
  [19537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3132),
  [19539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3092),
  [19541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4864),
  [19543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3086),
  [19545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3074),
  [19547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5961),
  [19549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3110),
  [19551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6245),
  [19553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3069),
  [19555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8162),
  [19557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3066),
  [19559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12621),
  [19561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3099),
  [19563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13150),
  [19565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3036),
  [19567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2795),
  [19569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5399),
  [19571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3030),
  [19573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5957),
  [19575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4341),
  [19577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17759),
  [19579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3028),
  [19581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3016),
  [19583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6211),
  [19585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3056),
  [19587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3011),
  [19589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3054),
  [19591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3005),
  [19593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13316),
  [19595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7083),
  [19597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10992),
  [19599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3002),
  [19601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11018),
  [19603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3017),
  [19605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9110),
  [19607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2791),
  [19609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9539),
  [19611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2956),
  [19613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7218),
  [19615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3941),
  [19617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2028),
  [19619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8134),
  [19621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2966),
  [19623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2960),
  [19625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3114),
  [19627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3902),
  [19629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3607),
  [19631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2938),
  [19633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6006),
  [19635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3938),
  [19637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3945),
  [19639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2769),
  [19641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8127),
  [19643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2916),
  [19645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6011),
  [19647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8119),
  [19649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2824),
  [19651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3118),
  [19653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2815),
  [19655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4363),
  [19657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2805),
  [19659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9294),
  [19661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7060),
  [19663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10930),
  [19665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2800),
  [19667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6033),
  [19669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11145),
  [19671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11162),
  [19673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2763),
  [19675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2754),
  [19677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2762),
  [19679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9556),
  [19681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2753),
  [19683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6156),
  [19685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12418),
  [19687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2747),
  [19689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2744),
  [19691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13069),
  [19693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15082),
  [19695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2809),
  [19697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8558),
  [19699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3134),
  [19701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7451),
  [19703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4418),
  [19705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3720),
  [19707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4413),
  [19709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2721),
  [19711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2719),
  [19713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11138),
  [19715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11136),
  [19717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2708),
  [19719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7413),
  [19721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2568),
  [19723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3733),
  [19725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3735),
  [19727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4389),
  [19729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3738),
  [19731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2707),
  [19733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8601),
  [19735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3739),
  [19737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2766),
  [19739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9184),
  [19741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [19743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9616),
  [19745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3479),
  [19747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4408),
  [19749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10648),
  [19751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4399),
  [19753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4375),
  [19755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4368),
  [19757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2660),
  [19759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4247),
  [19761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2661),
  [19763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3156),
  [19765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7456),
  [19767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11488),
  [19769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17904),
  [19771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2664),
  [19773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8513),
  [19775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9587),
  [19777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2810),
  [19779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2666),
  [19781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8489),
  [19783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10010),
  [19785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2818),
  [19787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6864),
  [19789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12362),
  [19791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11508),
  [19793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17889),
  [19795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11023),
  [19797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2667),
  [19799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4417),
  [19801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3734),
  [19803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1909),
  [19805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9957),
  [19807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2673),
  [19809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14242),
  [19811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2701),
  [19813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2789),
  [19815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11217),
  [19817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2703),
  [19819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15084),
  [19821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2727),
  [19823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8421),
  [19825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6844),
  [19827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12267),
  [19829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11061),
  [19831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11064),
  [19833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2733),
  [19835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9311),
  [19837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3096),
  [19839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2862),
  [19841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6967),
  [19843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2692),
  [19845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3091),
  [19847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11930),
  [19849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2750),
  [19851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2695),
  [19853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2751),
  [19855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3528),
  [19857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4401),
  [19859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3472),
  [19861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3589),
  [19863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3412),
  [19865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3225),
  [19867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3831),
  [19869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3400),
  [19871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3644),
  [19873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3420),
  [19875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3261),
  [19877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3795),
  [19879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3695),
  [19881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3360),
  [19883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3486),
  [19885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3583),
  [19887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3297),
  [19889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3972),
  [19891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3577),
  [19893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7478),
  [19895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11084),
  [19897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11085),
  [19899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2772),
  [19901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6270),
  [19903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2566),
  [19905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2869),
  [19907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8026),
  [19909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4218),
  [19911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3089),
  [19913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7537),
  [19915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4393),
  [19917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4414),
  [19919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2819),
  [19921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1971),
  [19923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9371),
  [19925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2820),
  [19927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3311),
  [19929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2888),
  [19931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2822),
  [19933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6318),
  [19935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3084),
  [19937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7448),
  [19939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11234),
  [19941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2834),
  [19943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7308),
  [19945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6834),
  [19947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14458),
  [19949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2891),
  [19951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7435),
  [19953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2775),
  [19955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5583),
  [19957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3611),
  [19959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2029),
  [19961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9767),
  [19963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14944),
  [19965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2860),
  [19967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2863),
  [19969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11212),
  [19971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2868),
  [19973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7250),
  [19975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4394),
  [19977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2788),
  [19979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9765),
  [19981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2798),
  [19983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2880),
  [19985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7758),
  [19987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3000),
  [19989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12044),
  [19991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2802),
  [19993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4382),
  [19995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4226),
  [19997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11668),
  [19999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17820),
  [20001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4374),
  [20003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2906),
  [20005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11636),
  [20007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17811),
  [20009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4371),
  [20011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2998),
  [20013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15018),
  [20015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2909),
  [20017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7366),
  [20019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2913),
  [20021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7838),
  [20023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3304),
  [20025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3283),
  [20027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3923),
  [20029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3401),
  [20031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3641),
  [20033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3759),
  [20035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3840),
  [20037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3710),
  [20039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2967),
  [20041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5357),
  [20043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6842),
  [20045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14454),
  [20047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9635),
  [20049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2923),
  [20051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5733),
  [20053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6887),
  [20055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12915),
  [20057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2837),
  [20059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7565),
  [20061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2993),
  [20063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13801),
  [20065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3453),
  [20067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2087),
  [20069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6420),
  [20071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1952),
  [20073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7575),
  [20075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2842),
  [20077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9615),
  [20079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9593),
  [20081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2961),
  [20083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6905),
  [20085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12876),
  [20087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2971),
  [20089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2846),
  [20091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2984),
  [20093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9024),
  [20095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15083),
  [20097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2987),
  [20099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5690),
  [20101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2853),
  [20103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2995),
  [20105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4731),
  [20107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3520),
  [20109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3010),
  [20111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2974),
  [20113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6168),
  [20115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3014),
  [20117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7353),
  [20119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12199),
  [20121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6941),
  [20123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13561),
  [20125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2889),
  [20127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7561),
  [20129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3385),
  [20131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2897),
  [20133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9246),
  [20135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3032),
  [20137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3228),
  [20139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3214),
  [20141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3689),
  [20143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3578),
  [20145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3322),
  [20147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3955),
  [20149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3871),
  [20151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3859),
  [20153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2656),
  [20155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12246),
  [20157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3055),
  [20159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4800),
  [20161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6962),
  [20163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13615),
  [20165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2900),
  [20167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2905),
  [20169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3076),
  [20171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12978),
  [20173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2873),
  [20175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2865),
  [20177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5978),
  [20179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14915),
  [20181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11811),
  [20183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3157),
  [20185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3159),
  [20187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2940),
  [20189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11737),
  [20191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3671),
  [20193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3177),
  [20195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6954),
  [20197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2079),
  [20199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8400),
  [20201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2058),
  [20203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9977),
  [20205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2852),
  [20207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11801),
  [20209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2944),
  [20211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4366),
  [20213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3179),
  [20215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9343),
  [20217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11775),
  [20219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2950),
  [20221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3078),
  [20223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7272),
  [20225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2957),
  [20227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1928),
  [20229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9433),
  [20231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3765),
  [20233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3203),
  [20235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3329),
  [20237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3870),
  [20239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2965),
  [20241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8523),
  [20243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14961),
  [20245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2832),
  [20247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6253),
  [20249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6243),
  [20251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3151),
  [20253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3003),
  [20255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13907),
  [20257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3142),
  [20259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3290),
  [20261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2041),
  [20263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10145),
  [20265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3115),
  [20267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5128),
  [20269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3094),
  [20271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8684),
  [20273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3009),
  [20275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6303),
  [20277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14887),
  [20279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6308),
  [20281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3104),
  [20283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6865),
  [20285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5949),
  [20287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3013),
  [20289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3105),
  [20291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3119),
  [20293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3015),
  [20295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3725),
  [20297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2761),
  [20299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3740),
  [20301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3456),
  [20303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8611),
  [20305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3060),
  [20307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4874),
  [20309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3389),
  [20311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3051),
  [20313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2752),
  [20315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11115),
  [20317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3046),
  [20319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5517),
  [20321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3071),
  [20323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5565),
  [20325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8649),
  [20327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3040),
  [20329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8254),
  [20331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2009),
  [20333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7140),
  [20335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2735),
  [20337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8650),
  [20339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14957),
  [20341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3082),
  [20343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1901),
  [20345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9338),
  [20347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3088),
  [20349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3146),
  [20351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13063),
  [20353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3001),
  [20355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3886),
  [20357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2713),
  [20359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6448),
  [20361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9834),
  [20363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2997),
  [20365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3128),
  [20367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12028),
  [20369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3888),
  [20371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3914),
  [20373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3845),
  [20375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2972),
  [20377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11030),
  [20379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1997),
  [20381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8773),
  [20383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11024),
  [20385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3135),
  [20387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6424),
  [20389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9875),
  [20391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3143),
  [20393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3126),
  [20395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10315),
  [20397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14882),
  [20399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3081),
  [20401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3153),
  [20403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15031),
  [20405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2936),
  [20407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2932),
  [20409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3059),
  [20411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10255),
  [20413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2902),
  [20415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12130),
  [20417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3165),
  [20419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11405),
  [20421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3603),
  [20423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1981),
  [20425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8890),
  [20427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3154),
  [20429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8893),
  [20431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10248),
  [20433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3839),
  [20435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2892),
  [20437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9258),
  [20439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3145),
  [20441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3138),
  [20443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2687),
  [20445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2690),
  [20447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10263),
  [20449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3021),
  [20451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12311),
  [20453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2861),
  [20455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2696),
  [20457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9023),
  [20459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15144),
  [20461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2859),
  [20463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11733),
  [20465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2835),
  [20467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8975),
  [20469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3080),
  [20471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8770),
  [20473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3403),
  [20475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1893),
  [20477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7067),
  [20479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1965),
  [20481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9150),
  [20483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2823),
  [20485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7076),
  [20487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3280),
  [20489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3070),
  [20491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9893),
  [20493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11705),
  [20495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3064),
  [20497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2709),
  [20499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5164),
  [20501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10247),
  [20503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3062),
  [20505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2983),
  [20507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7472),
  [20509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2787),
  [20511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6959),
  [20513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2782),
  [20515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3008),
  [20517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6481),
  [20519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2768),
  [20521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7143),
  [20523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15182),
  [20525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3605),
  [20527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [20529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10148),
  [20531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2955),
  [20533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2746),
  [20535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11946),
  [20537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2999),
  [20539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8085),
  [20541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2946),
  [20543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6926),
  [20545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2992),
  [20547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14910),
  [20549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2989),
  [20551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2760),
  [20553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2764),
  [20555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8479),
  [20557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2720),
  [20559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2931),
  [20561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8178),
  [20563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2718),
  [20565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3718),
  [20567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1941),
  [20569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11052),
  [20571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2710),
  [20573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7793),
  [20575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9375),
  [20577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2921),
  [20579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10062),
  [20581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8424),
  [20583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2698),
  [20585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13883),
  [20587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15102),
  [20589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2866),
  [20591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12429),
  [20593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2915),
  [20595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2771),
  [20597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8097),
  [20599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1911),
  [20601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6917),
  [20603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2911),
  [20605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3572),
  [20607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2930),
  [20609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9124),
  [20611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8384),
  [20613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2678),
  [20615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2689),
  [20617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2858),
  [20619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8314),
  [20621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3762),
  [20623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2781),
  [20625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12270),
  [20627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1930),
  [20629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5577),
  [20631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2705),
  [20633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8353),
  [20635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9575),
  [20637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2850),
  [20639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6830),
  [20641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8381),
  [20643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2739),
  [20645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7301),
  [20647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2844),
  [20649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15016),
  [20651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2817),
  [20653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2841),
  [20655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2814),
  [20657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [20659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [20661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16124),
  [20663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1554),
  [20665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1568),
  [20667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [20669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [20671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [20673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2251),
  [20675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [20677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [20679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [20681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16209),
  [20683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2194),
  [20685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [20687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [20689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [20691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2296),
  [20693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [20695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1504),
  [20697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [20699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [20701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16014),
  [20703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [20705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [20707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16293),
  [20709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [20711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [20713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [20715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2358),
  [20717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [20719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [20721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [20723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [20725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1693),
  [20727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [20729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1679),
  [20731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1625),
  [20733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16373),
  [20735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2405),
  [20737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [20739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2123),
  [20741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [20743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [20745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [20747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [20749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [20751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1456),
  [20753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [20755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15905),
  [20757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [20759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1392),
  [20761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16354),
  [20763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2370),
  [20765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [20767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1153),
  [20769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1156),
  [20771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [20773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16321),
  [20775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [20777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [20779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [20781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [20783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1228),
  [20785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2331),
  [20787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [20789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [20791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [20793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16288),
  [20795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2150),
  [20797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [20799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [20801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [20803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2277),
  [20805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [20807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1388),
  [20809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1432),
  [20811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1381),
  [20813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15756),
  [20815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [20817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [20819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [20821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1350),
  [20823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [20825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [20827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [20829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16254),
  [20831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [20833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [20835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2223),
  [20837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [20839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [20841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [20843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [20845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16219),
  [20847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2191),
  [20849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [20851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [20853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1514),
  [20855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [20857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [20859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [20861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15668),
  [20863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [20865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1529),
  [20867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16184),
  [20869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [20871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [20873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [20875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2137),
  [20877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [20879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3194),
  [20881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [20883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [20885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1591),
  [20887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [20889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [20891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [20893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [20895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16147),
  [20897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2106),
  [20899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1667),
  [20901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [20903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3183),
  [20905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [20907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1694),
  [20909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1695),
  [20911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1331),
  [20913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [20915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1644),
  [20917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [20919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [20921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15425),
  [20923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [20925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [20927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16097),
  [20929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [20931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [20933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2242),
  [20935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [20937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [20939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [20941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [20943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3351),
  [20945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [20947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3355),
  [20949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [20951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1186),
  [20953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [20955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1678),
  [20957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1532),
  [20959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1528),
  [20961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1545),
  [20963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16042),
  [20965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15228),
  [20967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [20969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1488),
  [20971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [20973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [20975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1482),
  [20977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1295),
  [20979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1672),
  [20981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [20983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2202),
  [20985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1458),
  [20987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [20989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [20991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1444),
  [20993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [20995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3544),
  [20997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [20999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3552),
  [21001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1624),
  [21003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [21005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1656),
  [21007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1422),
  [21009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [21011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [21013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1385),
  [21015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [21017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [21019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15930),
  [21021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12568),
  [21023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12380),
  [21025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [21027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2252),
  [21029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [21031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [21033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [21035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [21037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [21039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [21041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15197),
  [21043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3915),
  [21045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [21047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3893),
  [21049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [21051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [21053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [21055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [21057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15377),
  [21059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [21061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1122),
  [21063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [21065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [21067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [21069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [21071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2431),
  [21073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 2),
  [21075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__aliased_interpolation_identifier, 1),
  [21077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__dollar_escape, 2),
  [21079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [21081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 3, .production_id = 71),
  [21083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_indented_cases_repeat1, 1),
  [21085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_case_clause, 3, .production_id = 178),
  [21087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_types, 5, .dynamic_precedence = 1),
  [21089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_renamed_identifier, 3, .production_id = 147),
  [21091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15466),
  [21093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__indented_type_cases_repeat1, 1),
  [21095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_types, 4, .dynamic_precedence = 1),
  [21097] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_lambda_repeat1, 2, .production_id = 15),
  [21099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [21101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_given_by_type, 2),
  [21103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1237),
  [21105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [21107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [21109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [21111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [21113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bindings, 5),
  [21115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_types, 3, .dynamic_precedence = 1),
  [21117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, .production_id = 15),
  [21119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bindings, 2),
  [21121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_types, 2, .dynamic_precedence = 1),
  [21123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_val_declaration_repeat1, 2, .production_id = 3),
  [21125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bindings, 4),
  [21127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15632),
  [21129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15546),
  [21131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1163),
  [21133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [21135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [21137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variant_type_parameter, 2, .production_id = 15),
  [21139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variant_type_parameter, 2),
  [21141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_contravariant_type_parameter, 2, .production_id = 15),
  [21143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_covariant_type_parameter, 2, .production_id = 15),
  [21145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12732),
  [21147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12223),
  [21149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [21151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [21153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15709),
  [21155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [21157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2151),
  [21159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bindings, 3),
  [21161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [21163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variant_type_parameter, 1, .production_id = 34),
  [21165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variant_type_parameter, 1),
  [21167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15753),
  [21169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__interpolated_string_start, 1),
  [21171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [21173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [21175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3797),
  [21177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1318),
  [21179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3837),
  [21181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [21183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [21185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [21187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [21189] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_comment_repeat1, 1),
  [21191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [21193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3946),
  [21195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3670),
  [21197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1199),
  [21199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9508),
  [21201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6650),
  [21203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15949),
  [21205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [21207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3265),
  [21209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3264),
  [21211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3262),
  [21213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3260),
  [21215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9442),
  [21217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2437),
  [21219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6607),
  [21221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6606),
  [21223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1950),
  [21225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8617),
  [21227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9275),
  [21229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1188),
  [21231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8531),
  [21233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15840),
  [21235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [21237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3248),
  [21239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3250),
  [21241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3251),
  [21243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3255),
  [21245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11005),
  [21247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6970),
  [21249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2447),
  [21251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [21253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11028),
  [21255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6995),
  [21257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9846),
  [21259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6953),
  [21261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1959),
  [21263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6223),
  [21265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11140),
  [21267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15746),
  [21269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1943),
  [21271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17989),
  [21273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3346),
  [21275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8174),
  [21277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3347),
  [21279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3348),
  [21281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3353),
  [21283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1164),
  [21285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7973),
  [21287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2432),
  [21289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2452),
  [21291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1162),
  [21293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7761),
  [21295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [21297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6073),
  [21299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8177),
  [21301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [21303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3370),
  [21305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6933),
  [21307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3388),
  [21309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3393),
  [21311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5876),
  [21313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3394),
  [21315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8950),
  [21317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15614),
  [21319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8930),
  [21321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3496),
  [21323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7314),
  [21325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3497),
  [21327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3499),
  [21329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3502),
  [21331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16026),
  [21333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1963),
  [21335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2415),
  [21337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10690),
  [21339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17986),
  [21341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [21343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6884),
  [21345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7313),
  [21347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17985),
  [21349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1229),
  [21351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [21353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [21355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6514),
  [21357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10382),
  [21359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [21361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10677),
  [21363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15382),
  [21365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10934),
  [21367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3642),
  [21369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2422),
  [21371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3643),
  [21373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3650),
  [21375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3651),
  [21377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10043),
  [21379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [21381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2434),
  [21383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3637),
  [21385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3550),
  [21387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10749),
  [21389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3562),
  [21391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3563),
  [21393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10914),
  [21395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1936),
  [21397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7762),
  [21399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8363),
  [21401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16119),
  [21403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1974),
  [21405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15225),
  [21407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9885),
  [21409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3730),
  [21411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3732),
  [21413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3736),
  [21415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3744),
  [21417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6840),
  [21419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10391),
  [21421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2435),
  [21423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10887),
  [21425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9082),
  [21427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6817),
  [21429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10401),
  [21431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1250),
  [21433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [21435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [21437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9824),
  [21439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [21441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11078),
  [21443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2460),
  [21445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8660),
  [21447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15258),
  [21449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8506),
  [21451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [21453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3861),
  [21455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12794),
  [21457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3863),
  [21459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3864),
  [21461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3865),
  [21463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3772),
  [21465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3776),
  [21467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2425),
  [21469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11092),
  [21471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3777),
  [21473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3778),
  [21475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8654),
  [21477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1927),
  [21479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9405),
  [21481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6112),
  [21483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1977),
  [21485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9410),
  [21487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15564),
  [21489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16187),
  [21491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9171),
  [21493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6956),
  [21495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3954),
  [21497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3957),
  [21499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3966),
  [21501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11147),
  [21503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8471),
  [21505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2449),
  [21507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [21509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [21511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8433),
  [21513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [21515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1268),
  [21517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9476),
  [21519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [21521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [21523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11283),
  [21525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13474),
  [21527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6724),
  [21529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [21531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15737),
  [21533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2454),
  [21535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3885),
  [21537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3882),
  [21539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3878),
  [21541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3876),
  [21543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11304),
  [21545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1918),
  [21547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2459),
  [21549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6679),
  [21551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9160),
  [21553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9561),
  [21555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9618),
  [21557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3921),
  [21559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1986),
  [21561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14020),
  [21563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15813),
  [21565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3919),
  [21567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3918),
  [21569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3785),
  [21571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3782),
  [21573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3768),
  [21575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3724),
  [21577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11337),
  [21579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3917),
  [21581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13532),
  [21583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16264),
  [21585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [21587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [21589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9261),
  [21591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7527),
  [21593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13658),
  [21595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [21597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11770),
  [21599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [21601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5404),
  [21603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15931),
  [21605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [21607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [21609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3663),
  [21611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3660),
  [21613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3652),
  [21615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3633),
  [21617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8419),
  [21619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8035),
  [21621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2439),
  [21623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11741),
  [21625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1908),
  [21627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5400),
  [21629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8310),
  [21631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7464),
  [21633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9377),
  [21635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2002),
  [21637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16025),
  [21639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13500),
  [21641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3526),
  [21643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3519),
  [21645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3507),
  [21647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3504),
  [21649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2436),
  [21651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8468),
  [21653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2448),
  [21655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11797),
  [21657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1310),
  [21659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3790),
  [21661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3787),
  [21663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3786),
  [21665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [21667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3779),
  [21669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16581),
  [21671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2010),
  [21673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [21675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11319),
  [21677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16100),
  [21679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8312),
  [21681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8335),
  [21683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3369),
  [21685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3361),
  [21687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3359),
  [21689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3356),
  [21691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16318),
  [21693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [21695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2421),
  [21697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8485),
  [21699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [21701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11330),
  [21703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [21705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13090),
  [21707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8334),
  [21709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10723),
  [21711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7363),
  [21713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7635),
  [21715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16185),
  [21717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3227),
  [21719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3206),
  [21721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3204),
  [21723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3201),
  [21725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1890),
  [21727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10731),
  [21729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2453),
  [21731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8320),
  [21733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13026),
  [21735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11344),
  [21737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [21739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8327),
  [21741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [21743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12979),
  [21745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16588),
  [21747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13553),
  [21749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16257),
  [21751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [21753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11841),
  [21755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3312),
  [21757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3266),
  [21759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3321),
  [21761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3328),
  [21763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3631),
  [21765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8434),
  [21767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2443),
  [21769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3626),
  [21771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [21773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3623),
  [21775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3616),
  [21777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11821),
  [21779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [21781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16381),
  [21783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8459),
  [21785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [21787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5973),
  [21789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16325),
  [21791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9430),
  [21793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3338),
  [21795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3319),
  [21797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3477),
  [21799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3488),
  [21801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5341),
  [21803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2034),
  [21805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2419),
  [21807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7787),
  [21809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11528),
  [21811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11794),
  [21813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8561),
  [21815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5295),
  [21817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [21819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [21821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6305),
  [21823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16379),
  [21825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9548),
  [21827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3684),
  [21829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3698),
  [21831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3705),
  [21833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3708),
  [21835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8610),
  [21837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [21839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2450),
  [21841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10439),
  [21843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5284),
  [21845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9677),
  [21847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1369),
  [21849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [21851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2430),
  [21853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10441),
  [21855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1387),
  [21857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3512),
  [21859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9725),
  [21861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16352),
  [21863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3506),
  [21865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3936),
  [21867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3862),
  [21869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3316),
  [21871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3853),
  [21873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3505),
  [21875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11165),
  [21877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2423),
  [21879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9382),
  [21881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3503),
  [21883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [21885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13568),
  [21887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12139),
  [21889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16351),
  [21891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10444),
  [21893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8606),
  [21895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16328),
  [21897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1907),
  [21899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3866),
  [21901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3854),
  [21903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3843),
  [21905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3905),
  [21907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10074),
  [21909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2441),
  [21911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [21913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12151),
  [21915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9162),
  [21917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [21919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [21921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6358),
  [21923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10077),
  [21925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11472),
  [21927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12198),
  [21929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [21931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [21933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16301),
  [21935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [21937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3596),
  [21939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3721),
  [21941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3711),
  [21943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3709),
  [21945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7068),
  [21947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5346),
  [21949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2462),
  [21951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2426),
  [21953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11425),
  [21955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6375),
  [21957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11181),
  [21959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10253),
  [21961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [21963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1945),
  [21965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2013),
  [21967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16272),
  [21969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12253),
  [21971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3579),
  [21973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3575),
  [21975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3570),
  [21977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3569),
  [21979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3413),
  [21981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3411),
  [21983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2428),
  [21985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6204),
  [21987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3410),
  [21989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3409),
  [21991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16324),
  [21993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [21995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9235),
  [21997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7046),
  [21999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6310),
  [22001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [22003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8974),
  [22005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16243),
  [22007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1470),
  [22009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3458),
  [22011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3454),
  [22013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3452),
  [22015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3446),
  [22017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12606),
  [22019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8954),
  [22021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2424),
  [22023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [22025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6252),
  [22027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [22029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9002),
  [22031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1398),
  [22033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10587),
  [22035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12590),
  [22037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9895),
  [22039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1976),
  [22041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9469),
  [22043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16213),
  [22045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6918),
  [22047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3386),
  [22049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3380),
  [22051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3373),
  [22053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3371),
  [22055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2451),
  [22057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1932),
  [22059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9634),
  [22061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2442),
  [22063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9027),
  [22065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9122),
  [22067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10571),
  [22069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3313),
  [22071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3310),
  [22073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [22075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16189),
  [22077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3309),
  [22079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3438),
  [22081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3293),
  [22083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3286),
  [22085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3284),
  [22087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6867),
  [22089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3308),
  [22091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2427),
  [22093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1541),
  [22095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8799),
  [22097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16296),
  [22099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13646),
  [22101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9125),
  [22103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [22105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10553),
  [22107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1546),
  [22109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8788),
  [22111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [22113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11237),
  [22115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16162),
  [22117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13619),
  [22119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3205),
  [22121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3202),
  [22123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3200),
  [22125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3199),
  [22127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10762),
  [22129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2004),
  [22131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2458),
  [22133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8347),
  [22135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5576),
  [22137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1966),
  [22139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5582),
  [22141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5354),
  [22143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8753),
  [22145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16130),
  [22147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2433),
  [22149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3218),
  [22151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3219),
  [22153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3221),
  [22155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3233),
  [22157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [22159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [22161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2417),
  [22163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3229),
  [22165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [22167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3226),
  [22169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5646),
  [22171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3224),
  [22173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [22175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10102),
  [22177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3220),
  [22179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6835),
  [22181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11327),
  [22183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [22185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16101),
  [22187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16268),
  [22189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3341),
  [22191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3342),
  [22193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3344),
  [22195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3345),
  [22197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [22199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10108),
  [22201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2445),
  [22203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6569),
  [22205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11031),
  [22207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6800),
  [22209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5213),
  [22211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2031),
  [22213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8460),
  [22215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11053),
  [22217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2043),
  [22219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16073),
  [22221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3427),
  [22223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3443),
  [22225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3448),
  [22227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3323),
  [22229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11329),
  [22231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6040),
  [22233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11003),
  [22235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10109),
  [22237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [22239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6052),
  [22241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2461),
  [22243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [22245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11062),
  [22247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10993),
  [22249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1647),
  [22251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [22253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16037),
  [22255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11870),
  [22257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3523),
  [22259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3531),
  [22261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3535),
  [22263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3538),
  [22265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11269),
  [22267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14359),
  [22269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3208),
  [22271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [22273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3209),
  [22275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3210),
  [22277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11874),
  [22279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3211),
  [22281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1657),
  [22283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14352),
  [22285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16241),
  [22287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11091),
  [22289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6932),
  [22291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16013),
  [22293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3584),
  [22295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3594),
  [22297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3600),
  [22299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3601),
  [22301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10144),
  [22303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9518),
  [22305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [22307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9366),
  [22309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2054),
  [22311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11880),
  [22313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7700),
  [22315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11119),
  [22317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [22319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7705),
  [22321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [22323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3669),
  [22325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3672),
  [22327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3674),
  [22329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3675),
  [22331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11137),
  [22333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10183),
  [22335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1686),
  [22337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [22339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13250),
  [22341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14688),
  [22343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2418),
  [22345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [22347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [22349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10428),
  [22351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13262),
  [22353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3273),
  [22355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2038),
  [22357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3810),
  [22359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3811),
  [22361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3812),
  [22363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3814),
  [22365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14655),
  [22367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3274),
  [22369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3277),
  [22371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11710),
  [22373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9157),
  [22375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3278),
  [22377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3434),
  [22379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11724),
  [22381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16214),
  [22383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2076),
  [22385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13277),
  [22387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3901),
  [22389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3906),
  [22391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3913),
  [22393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3920),
  [22395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7430),
  [22397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10400),
  [22399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1569),
  [22401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [22403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7455),
  [22405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9020),
  [22407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10436),
  [22409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [22411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6342),
  [22413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [22415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12658),
  [22417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1430),
  [22419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [22421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3961),
  [22423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3960),
  [22425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3939),
  [22427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3931),
  [22429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11229),
  [22431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6309),
  [22433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2444),
  [22435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12842),
  [22437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12709),
  [22439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2024),
  [22441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10249),
  [22443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8892),
  [22445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3363),
  [22447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1996),
  [22449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3857),
  [22451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3963),
  [22453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3852),
  [22455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3851),
  [22457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9015),
  [22459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3364),
  [22461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3365),
  [22463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6249),
  [22465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3366),
  [22467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13955),
  [22469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16183),
  [22471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11228),
  [22473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1159),
  [22475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [22477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8856),
  [22479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14450),
  [22481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [22483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3773),
  [22485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3769),
  [22487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3767),
  [22489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3756),
  [22491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11909),
  [22493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13999),
  [22495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6527),
  [22497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11225),
  [22499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [22501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [22503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [22505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11915),
  [22507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3653),
  [22509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3635),
  [22511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3622),
  [22513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3609),
  [22515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14798),
  [22517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6721),
  [22519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6456),
  [22521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1939),
  [22523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9873),
  [22525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8775),
  [22527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3422),
  [22529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3416),
  [22531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3408),
  [22533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3402),
  [22535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1964),
  [22537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11200),
  [22539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2456),
  [22541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13043),
  [22543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11943),
  [22545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3374),
  [22547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3302),
  [22549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3301),
  [22551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3300),
  [22553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14626),
  [22555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3431),
  [22557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3432),
  [22559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3433),
  [22561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [22563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [22565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8715),
  [22567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [22569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3191),
  [22571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3186),
  [22573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3185),
  [22575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3253),
  [22577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1299),
  [22579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14476),
  [22581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16156),
  [22583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9399),
  [22585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13040),
  [22587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [22589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14706),
  [22591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [22593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3241),
  [22595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3246),
  [22597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3247),
  [22599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3249),
  [22601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2035),
  [22603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11093),
  [22605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10026),
  [22607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9434),
  [22609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1920),
  [22611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8645),
  [22613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3330),
  [22615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3332),
  [22617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3334),
  [22619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3336),
  [22621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7137),
  [22623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13023),
  [22625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1940),
  [22627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13269),
  [22629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11080),
  [22631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3428),
  [22633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3436),
  [22635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3440),
  [22637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3449),
  [22639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14488),
  [22641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2440),
  [22643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [22645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13017),
  [22647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11067),
  [22649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [22651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3510),
  [22653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7183),
  [22655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3540),
  [22657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3542),
  [22659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3545),
  [22661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3556),
  [22663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3511),
  [22665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1384),
  [22667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11426),
  [22669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3513),
  [22671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8439),
  [22673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3514),
  [22675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1391),
  [22677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [22679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3648),
  [22681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3658),
  [22683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3561),
  [22685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3667),
  [22687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16121),
  [22689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11412),
  [22691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [22693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5863),
  [22695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8399),
  [22697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8540),
  [22699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1942),
  [22701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3748),
  [22703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3753),
  [22705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3754),
  [22707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3664),
  [22709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6293),
  [22711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10154),
  [22713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1903),
  [22715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3890),
  [22717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3912),
  [22719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3783),
  [22721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3916),
  [22723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13346),
  [22725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7798),
  [22727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5879),
  [22729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11491),
  [22731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [22733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7811),
  [22735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5892),
  [22737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3856),
  [22739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3855),
  [22741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3834),
  [22743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3824),
  [22745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1428),
  [22747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [22749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10089),
  [22751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1921),
  [22753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1467),
  [22755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [22757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3636),
  [22759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3604),
  [22761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3494),
  [22763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12217),
  [22765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6106),
  [22767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [22769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1474),
  [22771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3585),
  [22773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3524),
  [22775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3518),
  [22777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3517),
  [22779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3471),
  [22781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3586),
  [22783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12211),
  [22785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3587),
  [22787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3588),
  [22789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6123),
  [22791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7138),
  [22793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16083),
  [22795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11785),
  [22797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9979),
  [22799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8696),
  [22801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [22803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7355),
  [22805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9461),
  [22807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12204),
  [22809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7171),
  [22811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [22813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9407),
  [22815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7185),
  [22817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [22819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1383),
  [22821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9929),
  [22823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [22825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1555),
  [22827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5826),
  [22829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7722),
  [22831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7409),
  [22833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10214),
  [22835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [22837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2095),
  [22839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5797),
  [22841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2455),
  [22843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7977),
  [22845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7417),
  [22847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7674),
  [22849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7896),
  [22851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12230),
  [22853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8398),
  [22855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3685),
  [22857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1969),
  [22859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10155),
  [22861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3687),
  [22863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3688),
  [22865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3694),
  [22867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5770),
  [22869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7658),
  [22871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1578),
  [22873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4346),
  [22875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16032),
  [22877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1612),
  [22879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11796),
  [22881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8437),
  [22883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9667),
  [22885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1646),
  [22887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11345),
  [22889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10433),
  [22891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5822),
  [22893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2070),
  [22895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [22897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [22899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [22901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5602),
  [22903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9631),
  [22905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11324),
  [22907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1692),
  [22909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5593),
  [22911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5793),
  [22913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9591),
  [22915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4253),
  [22917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9620),
  [22919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6419),
  [22921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [22923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2032),
  [22925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12075),
  [22927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1548),
  [22929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [22931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11307),
  [22933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2446),
  [22935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10775),
  [22937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10970),
  [22939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2052),
  [22941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9445),
  [22943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10847),
  [22945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1688),
  [22947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3873),
  [22949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6532),
  [22951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3875),
  [22953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1650),
  [22955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3877),
  [22957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3887),
  [22959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [22961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9283),
  [22963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8640),
  [22965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10873),
  [22967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4331),
  [22969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9697),
  [22971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [22973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1493),
  [22975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [22977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15960),
  [22979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1445),
  [22981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [22983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10883),
  [22985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1975),
  [22987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8658),
  [22989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2007),
  [22991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8227),
  [22993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9760),
  [22995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10753),
  [22997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1600),
  [22999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11213),
  [23001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9691),
  [23003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8210),
  [23005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [23007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12036),
  [23009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10713),
  [23011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [23013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1582),
  [23015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8723),
  [23017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10045),
  [23019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7671),
  [23021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [23023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9623),
  [23025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10104),
  [23027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4261),
  [23029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [23031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1553),
  [23033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9858),
  [23035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9605),
  [23037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10138),
  [23039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3849),
  [23041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1550),
  [23043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3848),
  [23045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3847),
  [23047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [23049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1537),
  [23051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2438),
  [23053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13629),
  [23055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9165),
  [23057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3846),
  [23059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7790),
  [23061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1905),
  [23063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9801),
  [23065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14438),
  [23067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13639),
  [23069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [23071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [23073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [23075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [23077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9809),
  [23079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13578),
  [23081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1501),
  [23083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1489),
  [23085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11662),
  [23087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9331),
  [23089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [23091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2468),
  [23093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7826),
  [23095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4320),
  [23097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9028),
  [23099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11666),
  [23101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14536),
  [23103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1469),
  [23105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8972),
  [23107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9954),
  [23109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9955),
  [23111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3838),
  [23113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13897),
  [23115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2080),
  [23117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13350),
  [23119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3836),
  [23121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11667),
  [23123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3832),
  [23125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1464),
  [23127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7887),
  [23129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3821),
  [23131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1457),
  [23133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11201),
  [23135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10667),
  [23137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1929),
  [23139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8796),
  [23141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1685),
  [23143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11199),
  [23145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9976),
  [23147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1437),
  [23149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3196),
  [23151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4350),
  [23153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8737),
  [23155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15145),
  [23157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3239),
  [23159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3285),
  [23161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15878),
  [23163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11196),
  [23165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1425),
  [23167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1417),
  [23169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13062),
  [23171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [23173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1510),
  [23175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15122),
  [23177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6261),
  [23179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10116),
  [23181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3333),
  [23183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6215),
  [23185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11002),
  [23187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15136),
  [23189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1408),
  [23191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10119),
  [23193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10994),
  [23195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [23197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [23199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8068),
  [23201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11187),
  [23203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1513),
  [23205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7357),
  [23207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1889),
  [23209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1498),
  [23211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6465),
  [23213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11186),
  [23215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1371),
  [23217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6655),
  [23219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11185),
  [23221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [23223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7158),
  [23225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2473),
  [23227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6126),
  [23229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2469),
  [23231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10449),
  [23233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15063),
  [23235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5827),
  [23237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12381),
  [23239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7141),
  [23241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4268),
  [23243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5840),
  [23245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8125),
  [23247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7129),
  [23249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13717),
  [23251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11004),
  [23253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16562),
  [23255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4980),
  [23257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2416),
  [23259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8130),
  [23261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8132),
  [23263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13693),
  [23265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13689),
  [23267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15028),
  [23269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15027),
  [23271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1915),
  [23273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11506),
  [23275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4995),
  [23277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13716),
  [23279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9251),
  [23281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8780),
  [23283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10195),
  [23285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6452),
  [23287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9328),
  [23289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6254),
  [23291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9404),
  [23293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9630),
  [23295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5962),
  [23297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9344),
  [23299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9740),
  [23301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9365),
  [23303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9882),
  [23305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13412),
  [23307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [23309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7122),
  [23311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8255),
  [23313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8519),
  [23315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [23317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [23319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12162),
  [23321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13417),
  [23323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8545),
  [23325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13473),
  [23327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9510),
  [23329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9833),
  [23331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7321),
  [23333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [23335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7324),
  [23337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7581),
  [23339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9563),
  [23341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6119),
  [23343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6132),
  [23345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7592),
  [23347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6184),
  [23349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [23351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9551),
  [23353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6196),
  [23355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13590),
  [23357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10184),
  [23359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5349),
  [23361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10601),
  [23363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [23365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10758),
  [23367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5351),
  [23369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10200),
  [23371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10130),
  [23373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13597),
  [23375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9727),
  [23377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [23379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8354),
  [23381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9723),
  [23383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8355),
  [23385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9714),
  [23387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10133),
  [23389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13604),
  [23391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [23393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9698),
  [23395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7611),
  [23397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9126),
  [23399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9694),
  [23401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7610),
  [23403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9685),
  [23405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [23407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10839),
  [23409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11026),
  [23411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8505),
  [23413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6349),
  [23415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9863),
  [23417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8507),
  [23419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [23421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6354),
  [23423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8511),
  [23425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11072),
  [23427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10716),
  [23429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7427),
  [23431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9860),
  [23433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [23435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10746),
  [23437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7431),
  [23439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7841),
  [23441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11125),
  [23443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10586),
  [23445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10594),
  [23447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [23449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5807),
  [23451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8687),
  [23453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10582),
  [23455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5806),
  [23457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10570),
  [23459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9840),
  [23461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [23463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10503),
  [23465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9604),
  [23467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10573),
  [23469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9608),
  [23471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10588),
  [23473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9612),
  [23475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [23477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9835),
  [23479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10454),
  [23481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13570),
  [23483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4863),
  [23485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11459),
  [23487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13573),
  [23489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [23491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4862),
  [23493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13636),
  [23495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9654),
  [23497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7645),
  [23499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3292),
  [23501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9519),
  [23503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [23505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7504),
  [23507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11449),
  [23509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9515),
  [23511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7506),
  [23513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9506),
  [23515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7656),
  [23517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [23519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11554),
  [23521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10825),
  [23523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7598),
  [23525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7501),
  [23527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8172),
  [23529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14785),
  [23531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [23533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7600),
  [23535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7499),
  [23537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7285),
  [23539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7605),
  [23541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10857),
  [23543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [23545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7279),
  [23547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10891),
  [23549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10450),
  [23551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7521),
  [23553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12361),
  [23555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [23557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10421),
  [23559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7523),
  [23561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10063),
  [23563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10410),
  [23565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3378),
  [23567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [23569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6214),
  [23571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12374),
  [23573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6218),
  [23575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3387),
  [23577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body2, 4),
  [23579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [23581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10012),
  [23583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5640),
  [23585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12378),
  [23587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10754),
  [23589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10359),
  [23591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [23593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5636),
  [23595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10363),
  [23597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7204),
  [23599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10810),
  [23601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7200),
  [23603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [23605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10384),
  [23607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7549),
  [23609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10879),
  [23611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10390),
  [23613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7550),
  [23615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [23617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10395),
  [23619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [23621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14543),
  [23623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14532),
  [23625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7849),
  [23627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [23629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9351),
  [23631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5561),
  [23633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13910),
  [23635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8488),
  [23637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9347),
  [23639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [23641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5557),
  [23643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9335),
  [23645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7889),
  [23647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8520),
  [23649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [23651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7897),
  [23653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8706),
  [23655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6743),
  [23657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8548),
  [23659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8594),
  [23661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [23663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8707),
  [23665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6754),
  [23667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8720),
  [23669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14716),
  [23671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2641),
  [23673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [23675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8862),
  [23677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8656),
  [23679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8850),
  [23681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10463),
  [23683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5599),
  [23685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [23687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8616),
  [23689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12552),
  [23691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10465),
  [23693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5612),
  [23695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10473),
  [23697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [23699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9177),
  [23701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12597),
  [23703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9115),
  [23705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9231),
  [23707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4947),
  [23709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [23711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12608),
  [23713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9803),
  [23715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9227),
  [23717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4949),
  [23719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14526),
  [23721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [23723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9215),
  [23725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8747),
  [23727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9811),
  [23729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8730),
  [23731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3549),
  [23733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [23735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13168),
  [23737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__self_type_ascription, 2),
  [23739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5333),
  [23741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18133),
  [23743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body2, 3),
  [23745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [23747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9817),
  [23749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13849),
  [23751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13169),
  [23753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16622),
  [23755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5322),
  [23757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [23759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13180),
  [23761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10539),
  [23763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13763),
  [23765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10542),
  [23767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14659),
  [23769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [23771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11999),
  [23773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14041),
  [23775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13740),
  [23777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10293),
  [23779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11993),
  [23781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [23783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14007),
  [23785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6961),
  [23787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11986),
  [23789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4929),
  [23791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10285),
  [23793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [23795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4924),
  [23797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9111),
  [23799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9350),
  [23801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10283),
  [23803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9107),
  [23805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [23807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9346),
  [23809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9095),
  [23811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5393),
  [23813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7842),
  [23815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5394),
  [23817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [23819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7809),
  [23821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6552),
  [23823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7683),
  [23825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7850),
  [23827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [23829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [23831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10655),
  [23833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [23835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7814),
  [23837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7685),
  [23839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7827),
  [23841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [23843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5781),
  [23845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13732),
  [23847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5777),
  [23849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11056),
  [23851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8735),
  [23853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [23855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13739),
  [23857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9047),
  [23859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11060),
  [23861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8738),
  [23863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11105),
  [23865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [23867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5411),
  [23869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9072),
  [23871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5414),
  [23873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7170),
  [23875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7257),
  [23877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [23879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9077),
  [23881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14764),
  [23883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9903),
  [23885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10668),
  [23887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [23889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [23891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7254),
  [23893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10366),
  [23895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5705),
  [23897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9887),
  [23899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5699),
  [23901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [23903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11820),
  [23905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7746),
  [23907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9881),
  [23909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7829),
  [23911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2649),
  [23913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [23915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11810),
  [23917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7748),
  [23919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11795),
  [23921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6593),
  [23923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10845),
  [23925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [23927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6600),
  [23929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10228),
  [23931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7228),
  [23933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10856),
  [23935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10884),
  [23937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [23939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10227),
  [23941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7227),
  [23943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10226),
  [23945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8248),
  [23947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10889),
  [23949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [23951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8247),
  [23953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13941),
  [23955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6672),
  [23957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10870),
  [23959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10866),
  [23961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [23963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13978),
  [23965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body1, 2),
  [23967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6666),
  [23969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14038),
  [23971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2467),
  [23973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [23975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6793),
  [23977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10850),
  [23979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body2, 2),
  [23981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16638),
  [23983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [23985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6796),
  [23987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10212),
  [23989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7195),
  [23991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2463),
  [23993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [23995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10842),
  [23997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10092),
  [23999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10211),
  [24001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [24003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7188),
  [24005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10833),
  [24007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10209),
  [24009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8426),
  [24011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [24013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10082),
  [24015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4342),
  [24017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8430),
  [24019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18537),
  [24021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [24023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13374),
  [24025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12214),
  [24027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7173),
  [24029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10080),
  [24031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [24033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5746),
  [24035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13371),
  [24037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5970),
  [24039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13369),
  [24041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [24043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8190),
  [24045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5735),
  [24047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8181),
  [24049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13935),
  [24051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [24053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5217),
  [24055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15460),
  [24057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5727),
  [24059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6563),
  [24061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [24063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10041),
  [24065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13909),
  [24067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5218),
  [24069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13983),
  [24071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [24073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6756),
  [24075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10032),
  [24077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6761),
  [24079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10167),
  [24081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [24083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5237),
  [24085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10018),
  [24087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11156),
  [24089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10163),
  [24091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [24093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5239),
  [24095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10157),
  [24097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8546),
  [24099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11153),
  [24101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [24103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8550),
  [24105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10512),
  [24107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10199),
  [24109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [24111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5941),
  [24113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10510),
  [24115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11148),
  [24117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [24119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10149),
  [24121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14808),
  [24123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6837),
  [24125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10143),
  [24127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [24129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [24131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [24133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [24135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [24137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [24139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [24141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [24143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [24145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [24147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [24149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [24151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [24153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [24155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [24157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [24159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [24161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [24163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [24165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [24167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [24169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [24171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [24173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [24175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [24177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [24179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [24181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [24183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [24185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [24187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [24189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [24191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [24193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [24195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [24197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [24199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [24201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [24203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [24205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [24207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [24209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [24211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [24213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [24215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [24217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [24219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [24221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [24223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [24225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [24227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [24229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [24231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [24233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [24235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [24237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [24239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9553),
  [24241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6547),
  [24243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12797),
  [24245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2638),
  [24247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14812),
  [24249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [24251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1987),
  [24253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14017),
  [24255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10704),
  [24257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9547),
  [24259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8631),
  [24261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4642),
  [24263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10708),
  [24265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14495),
  [24267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8627),
  [24269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4647),
  [24271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8626),
  [24273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__braced_template_body1, 1),
  [24275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16658),
  [24277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8615),
  [24279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14501),
  [24281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8630),
  [24283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14502),
  [24285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [24287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8139),
  [24289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13719),
  [24291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6843),
  [24293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18357),
  [24295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6665),
  [24297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8140),
  [24299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13866),
  [24301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8096),
  [24303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_opaque_modifier, 1),
  [24305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6681),
  [24307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8144),
  [24309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8092),
  [24311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6689),
  [24313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6823),
  [24315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8551),
  [24317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [24319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8790),
  [24321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4245),
  [24323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8547),
  [24325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4319),
  [24327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8786),
  [24329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10699),
  [24331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16669),
  [24333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8535),
  [24335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9502),
  [24337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9839),
  [24339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9253),
  [24341] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [24343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9487),
  [24345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18498),
  [24347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9458),
  [24349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2420),
  [24351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9255),
  [24353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment, 2),
  [24355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_comment, 2),
  [24357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_comment, 3),
  [24359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 4),
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_scala_external_scanner_create(void);
void tree_sitter_scala_external_scanner_destroy(void *);
bool tree_sitter_scala_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_scala_external_scanner_serialize(void *, char *);
void tree_sitter_scala_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef _WIN32
#define extern __declspec(dllexport)
#endif

extern const TSLanguage *tree_sitter_scala(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym__alpha_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_scala_external_scanner_create,
      tree_sitter_scala_external_scanner_destroy,
      tree_sitter_scala_external_scanner_scan,
      tree_sitter_scala_external_scanner_serialize,
      tree_sitter_scala_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
